-- ---------------------------------------------------------
-- data pack install script example
--
-- add a description here: Mono-substance drugs as available in India
-- license: GPL v2 or later, manually transferred 3rd party data
-- provided by Vaibhav Banait
--
-- http://wiki.gnumed.de/bin/view/Gnumed/GmManualReferenceData
-- ---------------------------------------------------------
-- enable this if running locally via
-- psql -d gnumed_vXX -U gm-dbo -f install-data-pack.sql
--SET default_transaction_read_only TO OFF;

-- ---------------------------------------------------------
-- drop staging tables if needed
\unset ON_ERROR_STOP
DROP TABLE staging.india_drugs CASCADE;
\set ON_ERROR_STOP 1

-- ---------------------------------------------------------
-- run everything else in one transaction
BEGIN;

-- create staging tables as needed --
CREATE TABLE staging.india_drugs (
	brand_name text,
	substance text,
	form text,
	strength numeric,
	unit text
);

-- ---------------------------------------------------------
-- insert data in staging table

-- line #1
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'E 0.06 (Sun)',
	'17 Beta Oestradiol',
	'GEL',
	gm.nullify_empty_string('0.06')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'E 0.06 (Sun)'
);

-- line #2
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESTROFEM 2 (Novo Nordisk)',
	'17 Beta Oestradiol',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESTROFEM 2 (Novo Nordisk)'
);

-- line #3
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1,8', u'strength_2': u'', u'substance': u'17 Beta Oestradiol', u'always_empty': u'', u'form': u'', u'brand': u'ETS PATCH', u'strength_3': u'', u'company': u'Emcure', u'unit': u'mg'}

-- line #4
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3', u'strength_2': u'', u'substance': u'17 Beta Oestradiol', u'always_empty': u'', u'form': u'', u'brand': u'OESTROGEL', u'strength_3': u'', u'company': u'Chemech', u'unit': u'mg/5G'}

-- line #5
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'5-FLUCEL 250 (CELON(VIVILON))',
	'5-Fluorouracil',
	'AMP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '5-FLUCEL 250 (CELON(VIVILON))'
);

-- line #6
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'5-FLUCEL 500 (CELON(VIVILON))',
	'5-Fluorouracil',
	'AMP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '5-FLUCEL 500 (CELON(VIVILON))'
);

-- line #7
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'5-FLUOROURACIL 250 (Vhb)',
	'5-Fluorouracil',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '5-FLUOROURACIL 250 (Vhb)'
);

-- line #8
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'5-FLUOROURACIL 500 (Vhb)',
	'5-Fluorouracil',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg/10ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '5-FLUOROURACIL 500 (Vhb)'
);

-- line #9
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'5FU-CBC 250 (CH.Bhagat)',
	'5-Fluorouracil',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '5FU-CBC 250 (CH.Bhagat)'
);

-- line #10
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'5FU-CBC 500 (CH.Bhagat)',
	'5-Fluorouracil',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '5FU-CBC 500 (CH.Bhagat)'
);

-- line #11
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'5 FU PAR 250 (Parenteral)',
	'5-Fluorouracil',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '5 FU PAR 250 (Parenteral)'
);

-- line #12
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'5 FU PAR 500 (Parenteral)',
	'5-Fluorouracil',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg/10ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '5 FU PAR 500 (Parenteral)'
);

-- line #13
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIVEFLURD 50 (Gsk)',
	'5-Fluorouracil',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIVEFLURD 50 (Gsk)'
);

-- line #14
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIVOCIL 250 (Cytomed(Alkem))',
	'5-Fluorouracil',
	'AMP',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIVOCIL 250 (Cytomed(Alkem))'
);

-- line #15
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIVOCIL 500 (Cytomed(Alkem))',
	'5-Fluorouracil',
	'AMP',
	gm.nullify_empty_string('500')::numeric,
	'mg/10ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIVOCIL 500 (Cytomed(Alkem))'
);

-- line #16
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIVOFLU 250 (Dabur Ph.)',
	'5-Fluorouracil',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIVOFLU 250 (Dabur Ph.)'
);

-- line #17
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIVOFLU 500 (Dabur Ph.)',
	'5-Fluorouracil',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIVOFLU 500 (Dabur Ph.)'
);

-- line #18
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOCIL 50 (VHB)',
	'5-Fluorouracil',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOCIL 50 (VHB)'
);

-- line #19
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLONIDA 1 (Nicholas)',
	'5-Fluorouracil',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLONIDA 1 (Nicholas)'
);

-- line #20
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUCIL 250 (Samarth)',
	'5-Fluorouracil',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUCIL 250 (Samarth)'
);

-- line #21
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUCIL 500 (Samarth)',
	'5-Fluorouracil',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUCIL 500 (Samarth)'
);

-- line #22
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUDIN 250 (Biological E.)',
	'5-Fluorouracil',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUDIN 250 (Biological E.)'
);

-- line #23
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUDIN 500 (Biological E.)',
	'5-Fluorouracil',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUDIN 500 (Biological E.)'
);

-- line #24
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUONCO 250 (Vhb)',
	'5-Fluorouracil',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUONCO 250 (Vhb)'
);

-- line #25
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUONCO 250 (Vhb)',
	'5-Fluorouracil',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUONCO 250 (Vhb)'
);

-- line #26
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUONCO 500 (Vhb)',
	'5-Fluorouracil',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUONCO 500 (Vhb)'
);

-- line #27
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUOROURACIL-VHB 250 (Vhb)',
	'5-Fluorouracil',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUOROURACIL-VHB 250 (Vhb)'
);

-- line #28
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUOROURACIL-VHB 500 (Vhb)',
	'5-Fluorouracil',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUOROURACIL-VHB 500 (Vhb)'
);

-- line #29
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUOROURACIL-VHB 250 (Vhb)',
	'5-Fluorouracil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUOROURACIL-VHB 250 (Vhb)'
);

-- line #30
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLURACIL 250 (Biochem)',
	'5-Fluorouracil',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLURACIL 250 (Biochem)'
);

-- line #31
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLURACIL 250 (Biochem)',
	'5-Fluorouracil',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLURACIL 250 (Biochem)'
);

-- line #32
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLURACIL 500 (Biochem)',
	'5-Fluorouracil',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLURACIL 500 (Biochem)'
);

-- line #33
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUTAS 250 (Intas)',
	'5-Fluorouracil',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUTAS 250 (Intas)'
);

-- line #34
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUTAS 500 (Intas)',
	'5-Fluorouracil',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUTAS 500 (Intas)'
);

-- line #35
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONCOFLOUR 250 (United Bio.)',
	'5-Fluorouracil',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONCOFLOUR 250 (United Bio.)'
);

-- line #36
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'5-HTPN 100 (MOLEKULE)',
	'5-HYDROXYTRYTOPHAN',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '5-HTPN 100 (MOLEKULE)'
);

-- line #37
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'5-HTPN 50 (MOLEKULE)',
	'5-HYDROXYTRYTOPHAN',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '5-HTPN 50 (MOLEKULE)'
);

-- line #38
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACAMPTAS 333 (Intas)',
	'AACAMPROSATE',
	'TAB',
	gm.nullify_empty_string('333')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACAMPTAS 333 (Intas)'
);

-- line #39
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ABAMUNE 300 (Cipla)',
	'ABACAVIR',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ABAMUNE 300 (Cipla)'
);

-- line #40
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ABAVIR 300 (HETERO HC.)',
	'ABACAVIR',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ABAVIR 300 (HETERO HC.)'
);

-- line #41
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ABEC 300 (EMCURE(ARV))',
	'ABACAVIR',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ABEC 300 (EMCURE(ARV))'
);

-- line #42
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ABHOPE 300 (Macleods)',
	'ABACAVIR',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ABHOPE 300 (Macleods)'
);

-- line #43
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAXIMAB 2 (Lupin)',
	'Abciximab',
	'VIAL',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAXIMAB 2 (Lupin)'
);

-- line #44
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REOPRO 2 (Eli Lilly)',
	'Abciximab',
	'V',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REOPRO 2 (Eli Lilly)'
);

-- line #45
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ABACUS-50 50 (Nucron Ph.)',
	'Acarbose',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ABACUS-50 50 (Nucron Ph.)'
);

-- line #46
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACARB 25 (Mano)',
	'Acarbose',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACARB 25 (Mano)'
);

-- line #47
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACAREX 25 (INTRA(VISION))',
	'Acarbose',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACAREX 25 (INTRA(VISION))'
);

-- line #48
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASUCROSE 25 (Wockhardt)',
	'Acarbose',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASUCROSE 25 (Wockhardt)'
);

-- line #49
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARB 25 (Mano)',
	'Acarbose',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARB 25 (Mano)'
);

-- line #50
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIABOSE 25 (Cardicare)',
	'Acarbose',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIABOSE 25 (Cardicare)'
);

-- line #51
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIACARB 25 (Bal Ph.)',
	'Acarbose',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIACARB 25 (Bal Ph.)'
);

-- line #52
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DISCARB 25 (Bal Ph.)',
	'Acarbose',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DISCARB 25 (Bal Ph.)'
);

-- line #53
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUBOSE 50 (Otsira)',
	'Acarbose',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUBOSE 50 (Otsira)'
);

-- line #54
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUCAR 25 (Healtheon)',
	'Acarbose',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUCAR 25 (Healtheon)'
);

-- line #55
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUCAR 50 (Healtheon)',
	'Acarbose',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUCAR 50 (Healtheon)'
);

-- line #56
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUCOBAY 25 (Bayer)',
	'Acarbose',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUCOBAY 25 (Bayer)'
);

-- line #57
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUCOBAY 50 (Bayer)',
	'Acarbose',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUCOBAY 50 (Bayer)'
);

-- line #58
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUCOBOSE 50 (Medley)',
	'Acarbose',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUCOBOSE 50 (Medley)'
);

-- line #59
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUDASE 50 (Alkem)',
	'Acarbose',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUDASE 50 (Alkem)'
);

-- line #60
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYCO AC 25 (U S V)',
	'Acarbose',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYCO AC 25 (U S V)'
);

-- line #61
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYCO AC 50 (U S V)',
	'Acarbose',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYCO AC 50 (U S V)'
);

-- line #62
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'K CARB 25 (Blue Cross)',
	'Acarbose',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'K CARB 25 (Blue Cross)'
);

-- line #63
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'K CARB 50 (Blue Cross)',
	'Acarbose',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'K CARB 50 (Blue Cross)'
);

-- line #64
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REBOSE 25 (Sun)',
	'Acarbose',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REBOSE 25 (Sun)'
);

-- line #65
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REBOSE 50 (Sun)',
	'Acarbose',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REBOSE 50 (Sun)'
);

-- line #66
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RECARB 25 (Bal Ph.)',
	'Acarbose',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RECARB 25 (Bal Ph.)'
);

-- line #67
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RECARB 50 (Bal Ph.)',
	'Acarbose',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RECARB 50 (Bal Ph.)'
);

-- line #68
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AB-FLO 100 (Lupin)',
	'ACEBROPHYLLINE',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AB-FLO 100 (Lupin)'
);

-- line #69
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AB PHYLLINE 100 (Sun)',
	'ACEBROPHYLLINE',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AB PHYLLINE 100 (Sun)'
);

-- line #70
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AB PHYLLINE 200 (Sun)',
	'ACEBROPHYLLINE',
	'SR',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AB PHYLLINE 200 (Sun)'
);

-- line #71
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACEBROFACT 100 (German R.)',
	'ACEBROPHYLLINE',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACEBROFACT 100 (German R.)'
);

-- line #72
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACEBROLIN 100 (Elder)',
	'ACEBROPHYLLINE',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACEBROLIN 100 (Elder)'
);

-- line #73
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACEBROLIN 50 (Elder)',
	'ACEBROPHYLLINE',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACEBROLIN 50 (Elder)'
);

-- line #74
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACELAST 100 (Ranbaxy)',
	'ACEBROPHYLLINE',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACELAST 100 (Ranbaxy)'
);

-- line #75
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACELAST 100 (Ranbaxy)',
	'ACEBROPHYLLINE',
	'SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACELAST 100 (Ranbaxy)'
);

-- line #76
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AFASMA 100 (Tasmed)',
	'ACEBROPHYLLINE',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AFASMA 100 (Tasmed)'
);

-- line #77
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'A-PHYL 100 (Franco I.)',
	'ACEBROPHYLLINE',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'A-PHYL 100 (Franco I.)'
);

-- line #78
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'A-PHYL 10 (Franco I.)',
	'ACEBROPHYLLINE',
	'SYRUP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'A-PHYL 10 (Franco I.)'
);

-- line #79
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASCOVENT 100 (Glenmark)',
	'ACEBROPHYLLINE',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASCOVENT 100 (Glenmark)'
);

-- line #80
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'ACEBROPHYLLINE', u'always_empty': u'', u'form': u'SYR', u'brand': u'ASCOVENT', u'strength_3': u'', u'company': u'Glenmark', u'unit': u''}

-- line #81
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BESTOFYLINE-A 100 (Bestochem)',
	'ACEBROPHYLLINE',
	'CAP/SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg/10'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BESTOFYLINE-A 100 (Bestochem)'
);

-- line #82
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIGBRO 100 (Intas)',
	'ACEBROPHYLLINE',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIGBRO 100 (Intas)'
);

-- line #83
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIGBRO 200 (Intas)',
	'ACEBROPHYLLINE',
	'OD',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIGBRO 200 (Intas)'
);

-- line #84
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BROFY 100 (BIOMAX BIO.)',
	'ACEBROPHYLLINE',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BROFY 100 (BIOMAX BIO.)'
);

-- line #85
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELU BM 100 (Corona)',
	'ACEBROPHYLLINE',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELU BM 100 (Corona)'
);

-- line #86
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100', u'strength_2': u'', u'substance': u'ACEBROPHYLLINE', u'always_empty': u'', u'form': u'', u'brand': u'ETILITE', u'strength_3': u'', u'company': u'Ranbaxy', u'unit': u'mg'}

-- line #87
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LESURIDE 12.5 (Sun)',
	'ACEBROPHYLLINE',
	'INJ',
	gm.nullify_empty_string('12.5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LESURIDE 12.5 (Sun)'
);

-- line #88
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACPHYLLINE 50 (Macleods)',
	'ACEBROPHYLLINE',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACPHYLLINE 50 (Macleods)'
);

-- line #89
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHYLIN-A 100 (Obsurge)',
	'ACEBROPHYLLINE',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHYLIN-A 100 (Obsurge)'
);

-- line #90
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHYLLIN-AC 100 (RND LAB)',
	'ACEBROPHYLLINE',
	'CAP/SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg/50'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHYLLIN-AC 100 (RND LAB)'
);

-- line #91
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESPIRA ACE 100 (Geno Ph.)',
	'ACEBROPHYLLINE',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESPIRA ACE 100 (Geno Ph.)'
);

-- line #92
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ABATE 200 (GENESIS)',
	'Aceclofenac',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ABATE 200 (GENESIS)'
);

-- line #93
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ABDAL 100 (MADHAV BIO.)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ABDAL 100 (MADHAV BIO.)'
);

-- line #94
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AB PHYLLINE 10 (Sun)',
	'Aceclofenac',
	'SYR',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AB PHYLLINE 10 (Sun)'
);

-- line #95
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACB 100 (VENSAT)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACB 100 (VENSAT)'
);

-- line #96
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACCEPT 1.5 (Vivid Bio.)',
	'Aceclofenac',
	'GEL',
	gm.nullify_empty_string('1.5')::numeric,
	'3'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACCEPT 1.5 (Vivid Bio.)'
);

-- line #97
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACCEPT 100 (Vivid Bio.)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACCEPT 100 (Vivid Bio.)'
);

-- line #98
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACEACT 200 (Active Hc.)',
	'Aceclofenac',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACEACT 200 (Active Hc.)'
);

-- line #99
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACEBLOC 100 (Biochem)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACEBLOC 100 (Biochem)'
);

-- line #100
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACECLAN 200 (ANTHUS)',
	'Aceclofenac',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACECLAN 200 (ANTHUS)'
);

-- line #101
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACECLAN 100 (ANTHUS)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACECLAN 100 (ANTHUS)'
);

-- line #102
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACECLONIJ 100 (Sunij)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACECLONIJ 100 (Sunij)'
);

-- line #103
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACECLO SR 200 (Aristo)',
	'Aceclofenac',
	'FC TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACECLO SR 200 (Aristo)'
);

-- line #104
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACECLO 100 (Aristo)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACECLO 100 (Aristo)'
);

-- line #105
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACEDRUG 100 (MEDISYS)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACEDRUG 100 (MEDISYS)'
);

-- line #106
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACEFEN 100 (SALUD CARE)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACEFEN 100 (SALUD CARE)'
);

-- line #107
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACEFLAM 150 (MEDICON PH.)',
	'Aceclofenac',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACEFLAM 150 (MEDICON PH.)'
);

-- line #108
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACEFORCE 100 (AKUM(PLETHICO))',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACEFORCE 100 (AKUM(PLETHICO))'
);

-- line #109
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACEJET 150 (Themis Med.)',
	'Aceclofenac',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg(TCL-S 101)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACEJET 150 (Themis Med.)'
);

-- line #110
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACELOFAN 200 (ACTO)',
	'Aceclofenac',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACELOFAN 200 (ACTO)'
);

-- line #111
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACELOFAN 100 (ACTO)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACELOFAN 100 (ACTO)'
);

-- line #112
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACEMOVE 150 (Sanat)',
	'Aceclofenac',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACEMOVE 150 (Sanat)'
);

-- line #113
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACEMOVE SR 200 (Sanat)',
	'ACECLOFENAC',
	'FC TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACEMOVE SR 200 (Sanat)'
);

-- line #114
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACEMOVE 100 (Sanat)',
	'ACECLOFENAC',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACEMOVE 100 (Sanat)'
);

-- line #115
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACEMUTE 100 (MEDISTREAM)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACEMUTE 100 (MEDISTREAM)'
);

-- line #116
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACENAC 150 (Medley)',
	'Aceclofenac',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg(LYPHOLIZED FORM)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACENAC 150 (Medley)'
);

-- line #117
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACENAC 100 (Medley)',
	'ACECLOFENAC',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACENAC 100 (Medley)'
);

-- line #118
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACENEM 200 (NEMI PH.)',
	'Aceclofenac',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg(SR)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACENEM 200 (NEMI PH.)'
);

-- line #119
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACENEZ 150 (Wintech)',
	'Aceclofenac',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACENEZ 150 (Wintech)'
);

-- line #120
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACENEZ 200 (Wintech)',
	'Aceclofenac',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACENEZ 200 (Wintech)'
);

-- line #121
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACENT 150 (Intra Lab)',
	'Aceclofenac',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACENT 150 (Intra Lab)'
);

-- line #122
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACENT 100 (Intra Lab)',
	'Aceclofenac',
	'MD TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACENT 100 (Intra Lab)'
);

-- line #123
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACENT 100 (Intra Lab)',
	'Aceclofenac',
	'SR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACENT 100 (Intra Lab)'
);

-- line #124
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACENT 100 (Intra Lab)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACENT 100 (Intra Lab)'
);

-- line #125
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACERAN 100 (Indica)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACERAN 100 (Indica)'
);

-- line #126
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACERAP 100 (Rapross)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACERAP 100 (Rapross)'
);

-- line #127
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACERNA 100 (Indica)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACERNA 100 (Indica)'
);

-- line #128
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACERON 200 (Cosme F.)',
	'Aceclofenac',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACERON 200 (Cosme F.)'
);

-- line #129
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACE 100 (NRB-INDIA)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACE 100 (NRB-INDIA)'
);

-- line #130
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACETUFF 100 (SERVOCARE)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACETUFF 100 (SERVOCARE)'
);

-- line #131
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACEX-100 100 (LEXMARK PH.)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACEX-100 100 (LEXMARK PH.)'
);

-- line #132
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACICLOFLEX sr 200 (GRANDIX)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACICLOFLEX sr 200 (GRANDIX)'
);

-- line #133
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACICLOFLEX 100 (GRANDIX)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACICLOFLEX 100 (GRANDIX)'
);

-- line #134
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACIFACT 100 (MEDICO HEALTH)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACIFACT 100 (MEDICO HEALTH)'
);

-- line #135
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACIFON 100 (Zenon Hc.)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACIFON 100 (Zenon Hc.)'
);

-- line #136
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACIKY 100 (CHEMO HC.)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACIKY 100 (CHEMO HC.)'
);

-- line #137
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACILEX 100 (Lexus)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACILEX 100 (Lexus)'
);

-- line #138
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACI 200 (PLUS INDIA)',
	'Aceclofenac',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACI 200 (PLUS INDIA)'
);

-- line #139
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACIZ 100 (Ritz Ph.)',
	'Aceclofenac',
	'SR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACIZ 100 (Ritz Ph.)'
);

-- line #140
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACIZ SR 200 (Ritz Ph.)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACIZ SR 200 (Ritz Ph.)'
);

-- line #141
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACIZ 100 (Ritz Ph.)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACIZ 100 (Ritz Ph.)'
);

-- line #142
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACLOCTA 100 (Natco Ph.)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACLOCTA 100 (Natco Ph.)'
);

-- line #143
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACLOFEN 100 (Ind-Swift)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACLOFEN 100 (Ind-Swift)'
);

-- line #144
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Aceclofenac', u'always_empty': u'', u'form': u'TAB', u'brand': u'ACLOFLAM', u'strength_3': u'', u'company': u'Morepen', u'unit': u''}

-- line #145
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACLO 100 (Cure Quick)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACLO 100 (Cure Quick)'
);

-- line #146
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACLOVA 200 (SIGNOVA)',
	'Aceclofenac',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACLOVA 200 (SIGNOVA)'
);

-- line #147
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACOTA 100 (Cadila Ph.)',
	'ACECLOFENAC',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACOTA 100 (Cadila Ph.)'
);

-- line #148
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACQ 200 (Que Ph.)',
	'Aceclofenac',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACQ 200 (Que Ph.)'
);

-- line #149
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AC 100 (Mmc Hc.)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AC 100 (Mmc Hc.)'
);

-- line #150
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTON-OR 100 (Apex Labs.)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTON-OR 100 (Apex Labs.)'
);

-- line #151
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACUFEN 200 (Pulse Ph.)',
	'Aceclofenac',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACUFEN 200 (Pulse Ph.)'
);

-- line #152
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACUFLAM 200 (Bergen)',
	'Aceclofenac',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACUFLAM 200 (Bergen)'
);

-- line #153
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACUFLAM 100 (ALKEM)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACUFLAM 100 (ALKEM)'
);

-- line #154
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AKILOS 100 (Unison)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AKILOS 100 (Unison)'
);

-- line #155
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALGESIA 200 (Macleods)',
	'Aceclofenac',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALGESIA 200 (Macleods)'
);

-- line #156
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALGESIA 100 (Macleods)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALGESIA 100 (Macleods)'
);

-- line #157
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALLPAIN 100 (Meyer Org.)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALLPAIN 100 (Meyer Org.)'
);

-- line #158
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALLPAIN 200 (Meyer Org.)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALLPAIN 200 (Meyer Org.)'
);

-- line #159
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALNASE 200 (ALNA BIO.)',
	'Aceclofenac',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALNASE 200 (ALNA BIO.)'
);

-- line #160
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALNASE 100 (ALNA BIO.)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALNASE 100 (ALNA BIO.)'
);

-- line #161
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALONAC 100 (EAST WEST)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALONAC 100 (EAST WEST)'
);

-- line #162
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALOO 200 (Bestochem)',
	'Aceclofenac',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALOO 200 (Bestochem)'
);

-- line #163
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALOO 50 (Bestochem)',
	'Aceclofenac',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALOO 50 (Bestochem)'
);

-- line #164
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALTO 100 (PHARMATECH)',
	'Aceclofenac',
	'SR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALTO 100 (PHARMATECH)'
);

-- line #165
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALTO 200 (PHARMATECH)',
	'Aceclofenac',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALTO 200 (PHARMATECH)'
);

-- line #166
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALTRAFLAM 100 (Croslands)',
	'Aceclofenac',
	'DISTAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALTRAFLAM 100 (Croslands)'
);

-- line #167
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALTRAFLAM 200 (Ranbaxy)',
	'Aceclofenac',
	'OD',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALTRAFLAM 200 (Ranbaxy)'
);

-- line #168
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALTRAFLAM 200 (Croslands)',
	'Aceclofenac',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALTRAFLAM 200 (Croslands)'
);

-- line #169
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALTRAFLAM 100 (Croslands)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALTRAFLAM 100 (Croslands)'
);

-- line #170
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANEED 100 (SLANEY HC.)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANEED 100 (SLANEY HC.)'
);

-- line #171
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARFLUR 150 (F D C)',
	'Aceclofenac',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARFLUR 150 (F D C)'
);

-- line #172
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AROFF BCD 100 (Unichem)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AROFF BCD 100 (Unichem)'
);

-- line #173
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AROFF 100 (Unichem)',
	'Aceclofenac',
	'FC TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AROFF 100 (Unichem)'
);

-- line #174
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AROFF 200 (Unichem)',
	'Aceclofenac',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AROFF 200 (Unichem)'
);

-- line #175
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARRESTIN 200 (Svizera)',
	'Aceclofenac',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARRESTIN 200 (Svizera)'
);

-- line #176
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARRESTIN 100 (Svizera)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARRESTIN 100 (Svizera)'
);

-- line #177
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASONAC 200 (Zee Lab)',
	'Aceclofenac',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASONAC 200 (Zee Lab)'
);

-- line #178
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASONAC 100 (Zee Lab)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASONAC 100 (Zee Lab)'
);

-- line #179
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASTAR 200 (D.R.John''S)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASTAR 200 (D.R.John''S)'
);

-- line #180
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATOFEN 100 (Atoz Ph.)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATOFEN 100 (Atoz Ph.)'
);

-- line #181
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXSOL 200 (SIGMAN)',
	'Aceclofenac',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXSOL 200 (SIGMAN)'
);

-- line #182
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIONAC 100 (SANCHEZ LAB.)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIONAC 100 (SANCHEZ LAB.)'
);

-- line #183
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANEFO 100 (Medopharm)',
	'Aceclofenac',
	'FC TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANEFO 100 (Medopharm)'
);

-- line #184
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARNIL-AC 100 (AZINE HC.)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARNIL-AC 100 (AZINE HC.)'
);

-- line #185
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CATRIX 200 (Corolla(Triton))',
	'Aceclofenac',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CATRIX 200 (Corolla(Triton))'
);

-- line #186
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CATRIX 100 (Corolla(Triton))',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CATRIX 100 (Corolla(Triton))'
);

-- line #187
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CECO 100 (USP LIFE)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CECO 100 (USP LIFE)'
);

-- line #188
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELFAST 200 (Indchemie)',
	'Aceclofenac',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELFAST 200 (Indchemie)'
);

-- line #189
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELONAC 100 (Embiotic Lab.)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELONAC 100 (Embiotic Lab.)'
);

-- line #190
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CROFT 100 (Franco I.)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CROFT 100 (Franco I.)'
);

-- line #191
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYNAC 100 (CYNO PH.)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYNAC 100 (CYNO PH.)'
);

-- line #192
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLACE 100 (STADCHEM)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLACE 100 (STADCHEM)'
);

-- line #193
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIPT 100 (RHINE BIO.)',
	'Aceclofenac',
	'FC TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIPT 100 (RHINE BIO.)'
);

-- line #194
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIPT 200 (RHINE BIO.)',
	'Aceclofenac',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIPT 200 (RHINE BIO.)'
);

-- line #195
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLACE 100 (LUCIFER & H.)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLACE 100 (LUCIFER & H.)'
);

-- line #196
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLOCHEK 200 (Indoco Rem.)',
	'Aceclofenac',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLOCHEK 200 (Indoco Rem.)'
);

-- line #197
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLOCHEK 100 (Indoco Rem.)',
	'ACECLOFENAC',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLOCHEK 100 (Indoco Rem.)'
);

-- line #198
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLOKIND 200 (Mankind)',
	'ACECLOFENAC',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLOKIND 200 (Mankind)'
);

-- line #199
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLOKIND 100 (Mankind)',
	'ACECLOFENAC',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLOKIND 100 (Mankind)'
);

-- line #200
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLOLAX 100 (Helax Hc.)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLOLAX 100 (Helax Hc.)'
);

-- line #201
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200', u'strength_2': u'', u'substance': u'Aceclofenac', u'always_empty': u'', u'form': u'', u'brand': u'DOLOSTAT SRTAB', u'strength_3': u'', u'company': u'Blue Cross', u'unit': u'mg'}

-- line #202
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLOSTAT 100 (Blue Cross)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLOSTAT 100 (Blue Cross)'
);

-- line #203
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLOUR 100 (SAVIOUR)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLOUR 100 (SAVIOUR)'
);

-- line #204
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLOWIN 200 (Micro Labs)',
	'Aceclofenac',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLOWIN 200 (Micro Labs)'
);

-- line #205
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLOWIN 100 (Micro Labs)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLOWIN 100 (Micro Labs)'
);

-- line #206
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ECLONAC 100 (Jagsonpal)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ECLONAC 100 (Jagsonpal)'
);

-- line #207
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERINAC 200 (ERIS LIFE)',
	'Aceclofenac',
	'SR',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERINAC 200 (ERIS LIFE)'
);

-- line #208
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUDAC 100 (Cadex Lab)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUDAC 100 (Cadex Lab)'
);

-- line #209
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FASTNAC 200 (LUPINOVA)',
	'Aceclofenac',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FASTNAC 200 (LUPINOVA)'
);

-- line #210
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FENBEST 200 (MANEESH HC.)',
	'Aceclofenac',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FENBEST 200 (MANEESH HC.)'
);

-- line #211
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FENBEST 100 (Maneesh)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FENBEST 100 (Maneesh)'
);

-- line #212
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEPRA 500 (TRITON(CALYX))',
	'Aceclofenac',
	'SR TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEPRA 500 (TRITON(CALYX))'
);

-- line #213
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEPRA 100 (TRITON(CALYX))',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEPRA 100 (TRITON(CALYX))'
);

-- line #214
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FICO 200 (EMCURE)',
	'Aceclofenac',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FICO 200 (EMCURE)'
);

-- line #215
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FICO 100 (Emcure)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FICO 100 (Emcure)'
);

-- line #216
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLAMACE 200 (Biomax Lab)',
	'Aceclofenac',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLAMACE 200 (Biomax Lab)'
);

-- line #217
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLAMACE 100 (Biomax Lab)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLAMACE 100 (Biomax Lab)'
);

-- line #218
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLAXINAC 200 (SOLITAIRE(RADIX))',
	'Aceclofenac',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLAXINAC 200 (SOLITAIRE(RADIX))'
);

-- line #219
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLEXIDOL 100 (Cipla)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg(IN BETA-CYCLODEXTRN.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLEXIDOL 100 (Cipla)'
);

-- line #220
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORTAFEN 100 (Alembic)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORTAFEN 100 (Alembic)'
);

-- line #221
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Aceclofenac', u'always_empty': u'', u'form': u'GEL', u'brand': u'HIFENAC', u'strength_3': u'', u'company': u'Intas', u'unit': u''}

-- line #222
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIFENAC 200 (Intas)',
	'Aceclofenac',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIFENAC 200 (Intas)'
);

-- line #223
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIFENAC 100 (Intas)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIFENAC 100 (Intas)'
);

-- line #224
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIFENAC 200 (Intas)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIFENAC 200 (Intas)'
);

-- line #225
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HINAC 100 (Intas)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HINAC 100 (Intas)'
);

-- line #226
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ICOBIT 200 (Cubit Hc.)',
	'Aceclofenac',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ICOBIT 200 (Cubit Hc.)'
);

-- line #227
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ICOBIT 100 (Cubit Hc.)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ICOBIT 100 (Cubit Hc.)'
);

-- line #228
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISIKO 100 (Siesta Ph.)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISIKO 100 (Siesta Ph.)'
);

-- line #229
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KINECTINE 100 (A.F.D.)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KINECTINE 100 (A.F.D.)'
);

-- line #230
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEAP 200 (Comed Chem.)',
	'Aceclofenac',
	'ER TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEAP 200 (Comed Chem.)'
);

-- line #231
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEAP 100 (Comed Chem.)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEAP 100 (Comed Chem.)'
);

-- line #232
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LETGO 200 (ORION BIOTECH.)',
	'Aceclofenac',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg S.R.'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LETGO 200 (ORION BIOTECH.)'
);

-- line #233
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LETGO 100 (ORION BIOTECH.)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LETGO 100 (ORION BIOTECH.)'
);

-- line #234
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAHANAC 200 (ZUVENTUS)',
	'Aceclofenac',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAHANAC 200 (ZUVENTUS)'
);

-- line #235
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDIDOL 100 (MEDISTREAM)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDIDOL 100 (MEDISTREAM)'
);

-- line #236
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICRONAC 200 (MICRO HC.)',
	'Aceclofenac',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICRONAC 200 (MICRO HC.)'
);

-- line #237
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICRONAC 100 (MICRO HC.)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICRONAC 100 (MICRO HC.)'
);

-- line #238
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOBIRIDE 100 (Merck)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOBIRIDE 100 (Merck)'
);

-- line #239
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOBIRIDE 200 (Merck)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg S.R.'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOBIRIDE 200 (Merck)'
);

-- line #240
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOVACE 100 (Alkem)',
	'Aceclofenac',
	'FC TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOVACE 100 (Alkem)'
);

-- line #241
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOVACE 200 (ALKEM)',
	'Aceclofenac',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOVACE 200 (ALKEM)'
);

-- line #242
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOVEXX 100 (Cipla)',
	'Aceclofenac',
	'FC TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOVEXX 100 (Cipla)'
);

-- line #243
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOVIZ 200 (AUSTER)',
	'Aceclofenac',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOVIZ 200 (AUSTER)'
);

-- line #244
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOVIZ 100 (AUSTER)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOVIZ 100 (AUSTER)'
);

-- line #245
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOVIZ 100 (AUSTER)',
	'ACECLOFENAC',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOVIZ 100 (AUSTER)'
);

-- line #246
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOVON 200 (Ipca)',
	'Aceclofenac',
	'CR SR CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOVON 200 (Ipca)'
);

-- line #247
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOVON 150 (Ipca)',
	'Aceclofenac',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOVON 150 (Ipca)'
);

-- line #248
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOVON 100 (Ipca)',
	'ACECLOFENAC',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOVON 100 (Ipca)'
);

-- line #249
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NACKU 200 (RISHAB(KUREKEMI))',
	'Aceclofenac',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NACKU 200 (RISHAB(KUREKEMI))'
);

-- line #250
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAID 100 (Winsome Lab)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAID 100 (Winsome Lab)'
);

-- line #251
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIPLONAC 200 (NPIL)',
	'Aceclofenac',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIPLONAC 200 (NPIL)'
);

-- line #252
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIPLONAC 100 (NPIL)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIPLONAC 100 (NPIL)'
);

-- line #253
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVOFLAM 200 (Captab)',
	'Aceclofenac',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVOFLAM 200 (Captab)'
);

-- line #254
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUSAID 100 (MOLEKULE)',
	'Aceclofenac',
	'FC TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUSAID 100 (MOLEKULE)'
);

-- line #255
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUSAID 5 (MOLEKULE)',
	'Aceclofenac',
	'GEL',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUSAID 5 (MOLEKULE)'
);

-- line #256
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUSAID SR 200 (MOLEKULE)',
	'Aceclofenac',
	'FC TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUSAID SR 200 (MOLEKULE)'
);

-- line #257
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLFENAC 100 (Olcare)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLFENAC 100 (Olcare)'
);

-- line #258
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSTEONEC 200 (STARTOS)',
	'Aceclofenac',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSTEONEC 200 (STARTOS)'
);

-- line #259
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAINIL 100 (Cipla)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAINIL 100 (Cipla)'
);

-- line #260
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAINOUT 100 (ETHIX HC.)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAINOUT 100 (ETHIX HC.)'
);

-- line #261
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANACE 100 (PSYCOREM)',
	'Aceclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANACE 100 (PSYCOREM)'
);

-- line #262
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARFLEX 200 (FLAMINGO PH.)',
	'Aceclofenac',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg S.R.'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARFLEX 200 (FLAMINGO PH.)'
);

-- line #263
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEALE 100 (Irm Ph.)',
	'Aceclofenac',
	'FC TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEALE 100 (Irm Ph.)'
);

-- line #264
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEALE 200 (Irm Ph.)',
	'Aceclofenac',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEALE 200 (Irm Ph.)'
);

-- line #265
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RALIWIZ 200 (Wisdom Ph.)',
	'Aceclofenac',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RALIWIZ 200 (Wisdom Ph.)'
);

-- line #266
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACITROM 1 (Piramal Hc.)',
	'Acenocoumarol',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACITROM 1 (Piramal Hc.)'
);

-- line #267
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACITROM 2 (Piramal Hc.)',
	'Acenocoumarol',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACITROM 2 (Piramal Hc.)'
);

-- line #268
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACITROM 3 (Piramal Hc.)',
	'Acenocoumarol',
	'TAB',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACITROM 3 (Piramal Hc.)'
);

-- line #269
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACITROM 4 (Piramal Hc.)',
	'Acenocoumarol',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACITROM 4 (Piramal Hc.)'
);

-- line #270
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NISTROM 1 (NEISS)',
	'Acenocoumarol',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NISTROM 1 (NEISS)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NISTROM 2 (NEISS)',
	'Acenocoumarol',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NISTROM 2 (NEISS)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NISTROM 3 (NEISS)',
	'Acenocoumarol',
	'TAB',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NISTROM 3 (NEISS)'
);

-- line #271
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDALGIN 250 (Medoz Ph.)',
	'Acetaminophen',
	'SUS',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDALGIN 250 (Medoz Ph.)'
);

-- line #272
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACETAMIDE 250 (Micro V.)',
	'Acetazolamide',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACETAMIDE 250 (Micro V.)'
);

-- line #273
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTAMIDE 250 (Micro V.)',
	'Acetazolamide',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTAMIDE 250 (Micro V.)'
);

-- line #274
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTAMID 250 (Jawa Ph.)',
	'Acetazolamide',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTAMID 250 (Jawa Ph.)'
);

-- line #275
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVVA 250 (Intas)',
	'Acetazolamide',
	'SR CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVVA 250 (Intas)'
);

-- line #276
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVVA 250 (Intas)',
	'Acetazolamide',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVVA 250 (Intas)'
);

-- line #277
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIAMOX 250 (Wyeth)',
	'Acetazolamide',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIAMOX 250 (Wyeth)'
);

-- line #278
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IOPAR 250 (F D C)',
	'Acetazolamide',
	'SR CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IOPAR 250 (F D C)'
);

-- line #279
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'P-20 250 (Sunways)',
	'Acetazolamide',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'P-20 250 (Sunways)'
);

-- line #280
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANCEL 400 (CELON(REVILON))',
	'Acetylcysteine',
	'AMP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANCEL 400 (CELON(REVILON))'
);

-- line #281
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CILOL 1000 (NEON)',
	'Acetylcysteine',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CILOL 1000 (NEON)'
);

-- line #282
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CILOL 200 (NEON)',
	'Acetylcysteine',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CILOL 200 (NEON)'
);

-- line #283
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CILOL 400 (NEON)',
	'Acetylcysteine',
	'INJ',
	gm.nullify_empty_string('400')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CILOL 400 (NEON)'
);

-- line #284
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EFETIL 600 (Intas)',
	'Acetylcysteine',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EFETIL 600 (Intas)'
);

-- line #285
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EVANAC 600 (CELON)',
	'Acetylcysteine',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg(N-ACETYLCYSTEINE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EVANAC 600 (CELON)'
);

-- line #286
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUMUCIL 200 (Elder)',
	'Acetylcysteine',
	'DT TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUMUCIL 200 (Elder)'
);

-- line #287
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUTON 600 (Indo French)',
	'Acetylcysteine',
	'CAP',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUTON 600 (Indo French)'
);

-- line #288
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDINAC 200 (Kirti Works)',
	'Acetylcysteine',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDINAC 200 (Kirti Works)'
);

-- line #289
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUMENAC 600 (Lupin)',
	'Acetylcysteine',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg(N-ACETYL.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUMENAC 600 (Lupin)'
);

-- line #290
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUCARE 1 (VHB(CRITICAL CARE))',
	'Acetylcysteine',
	'AMP',
	gm.nullify_empty_string('1')::numeric,
	'G/5ml'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUCARE 1 (VHB(CRITICAL CARE))'
);

-- line #291
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUCARE 200 (VHB(CRITICAL CARE))',
	'Acetylcysteine',
	'AMP',
	gm.nullify_empty_string('200')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUCARE 200 (VHB(CRITICAL CARE))'
);

-- line #292
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUCARE 400 (VHB(CRITICAL CARE))',
	'Acetylcysteine',
	'AMP',
	gm.nullify_empty_string('400')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUCARE 400 (VHB(CRITICAL CARE))'
);

-- line #293
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUCARE 200 (VHB)',
	'Acetylcysteine',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUCARE 200 (VHB)'
);

-- line #294
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUCARE 400 (VHB)',
	'Acetylcysteine',
	'INJ',
	gm.nullify_empty_string('400')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUCARE 400 (VHB)'
);

-- line #295
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUCOHELP 1 (NEISS)',
	'Acetylcysteine',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'gm'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUCOHELP 1 (NEISS)'
);

-- line #296
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUCOMELT 1000 (Venus Rem.)',
	'Acetylcysteine',
	'AMP',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUCOMELT 1000 (Venus Rem.)'
);

-- line #297
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUCOMELT 200 (Venus Rem.)',
	'Acetylcysteine',
	'AMP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUCOMELT 200 (Venus Rem.)'
);

-- line #298
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUCOMELT 600 (Venus Rem.)',
	'Acetylcysteine',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUCOMELT 600 (Venus Rem.)'
);

-- line #299
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUCOMIX 200 (Samarth)',
	'Acetylcysteine',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUCOMIX 200 (Samarth)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUCOMIX 1000 (Samarth)',
	'Acetylcysteine',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUCOMIX 1000 (Samarth)'
);

-- line #300
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUCOMIX 200 (Samarth)',
	'Acetylcysteine',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUCOMIX 200 (Samarth)'
);

-- line #301
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUCOMIX 20 (Samarth)',
	'Acetylcysteine',
	'SOL',
	gm.nullify_empty_string('20')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUCOMIX 20 (Samarth)'
);

-- line #302
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUCOMIX 600 (Samarth)',
	'Acetylcysteine',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUCOMIX 600 (Samarth)'
);

-- line #303
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUCOSYS 400 (United Bio.)',
	'Acetylcysteine',
	'INJ',
	gm.nullify_empty_string('400')::numeric,
	'mg(20'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUCOSYS 400 (United Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUCOSYS 1000 (United Bio.)',
	'Acetylcysteine',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg(20'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUCOSYS 1000 (United Bio.)'
);

-- line #304
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUCOTAB 600 (RESPICARE(GERMAN R.))',
	'Acetylcysteine',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUCOTAB 600 (RESPICARE(GERMAN R.))'
);

-- line #305
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'5ML', u'substance': u'Acetylcysteine', u'always_empty': u'', u'form': u'AMP', u'brand': u'MUCOTYLE', u'strength_3': u'', u'company': u'SG PH.', u'unit': u''}

-- line #306
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUCOTYLE 200 (SG PH.)',
	'Acetylcysteine',
	'AMP',
	gm.nullify_empty_string('200')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUCOTYLE 200 (SG PH.)'
);

-- line #307
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2G', u'strength_2': u'10ML', u'substance': u'Acetylcysteine', u'always_empty': u'', u'form': u'AMP', u'brand': u'MUCOTYLE', u'strength_3': u'', u'company': u'SG PH.', u'unit': u''}

-- line #308
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUCYST 1000 (Neon)',
	'Acetylcysteine',
	'AMP',
	gm.nullify_empty_string('1000')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUCYST 1000 (Neon)'
);

-- line #309
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUCYST 400 (Neon)',
	'Acetylcysteine',
	'AMP',
	gm.nullify_empty_string('400')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUCYST 400 (Neon)'
);

-- line #310
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Acetylcysteine', u'always_empty': u'', u'form': u'AMP', u'brand': u'NACEL', u'strength_3': u'', u'company': u'CELON(REVILON)', u'unit': u''}

-- line #311
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NACEL 200 (CELON(REVILON))',
	'Acetylcysteine',
	'AMP',
	gm.nullify_empty_string('200')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NACEL 200 (CELON(REVILON))'
);

-- line #312
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NACEL 600 (CELON(REVILON))',
	'Acetylcysteine',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NACEL 600 (CELON(REVILON))'
);

-- line #313
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NACFIL 600 (Fourrts(SP.))',
	'Acetylcysteine',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NACFIL 600 (Fourrts(SP.))'
);

-- line #314
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRONAC 200 (Astrum Hc.)',
	'Acetylcysteine',
	'SOL',
	gm.nullify_empty_string('200')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRONAC 200 (Astrum Hc.)'
);

-- line #315
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRONAC 600 (Astrum Hc.)',
	'Acetylcysteine',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRONAC 600 (Astrum Hc.)'
);

-- line #316
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250', u'strength_2': u'', u'substance': u'ACIPIMOX', u'always_empty': u'', u'form': u'', u'brand': u'ACIPICAP', u'strength_3': u'', u'company': u'Zydus cnd', u'unit': u'mg'}

-- line #317
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIMOREX 250 (CDC)',
	'ACIPIMOX',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIMOREX 250 (CDC)'
);

-- line #318
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACERET 10 (Gracewell)',
	'ACITRETIN',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACERET 10 (Gracewell)'
);

-- line #319
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACERET 25 (Gracewell)',
	'ACITRETIN',
	'CAP',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACERET 25 (Gracewell)'
);

-- line #320
-- ignoring line: empty field [company]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10', u'strength_2': u'', u'substance': u'ACITRETIN', u'always_empty': u'', u'form': u'CAP', u'brand': u'ACETEC', u'strength_3': u'', u'company': u'', u'unit': u'mg'}

-- line #321
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACETEC 25 (Dr.Reddy''S)',
	'ACITRETIN',
	'CAP',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACETEC 25 (Dr.Reddy''S)'
);

-- line #322
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100', u'strength_2': u'', u'substance': u'ACTARIT', u'always_empty': u'', u'form': u'', u'brand': u'ARAMACT', u'strength_3': u'', u'company': u'Macleods', u'unit': u'mg'}

-- line #323
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIMOL 40 (Wallace)',
	'Activated Dimethicone',
	'DPS',
	gm.nullify_empty_string('40')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIMOL 40 (Wallace)'
);

-- line #324
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIMOL 40 (Wallace)',
	'Activated Dimethicone',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIMOL 40 (Wallace)'
);

-- line #325
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACICET 400 (KIVI LABS)',
	'Acyclovir',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACICET 400 (KIVI LABS)'
);

-- line #326
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACIHERPIN 5 (AGIO PH.)',
	'Acyclovir',
	'CRM',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACIHERPIN 5 (AGIO PH.)'
);

-- line #327
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACIHERPIN 200 (AGIO PH.)',
	'Acyclovir',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACIHERPIN 200 (AGIO PH.)'
);

-- line #328
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACIHERPIN 400 (AGIO PH.)',
	'Acyclovir',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACIHERPIN 400 (AGIO PH.)'
);

-- line #329
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACIHERPIN 800 (AGIO PH.)',
	'Acyclovir',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACIHERPIN 800 (AGIO PH.)'
);

-- line #330
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACIVIR 5 (Cipla)',
	'Acyclovir',
	'CRM',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACIVIR 5 (Cipla)'
);

-- line #331
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACIVIR 200 (Cipla)',
	'Acyclovir',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACIVIR 200 (Cipla)'
);

-- line #332
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACIVIR 400 (Cipla)',
	'Acyclovir',
	'DT',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACIVIR 400 (Cipla)'
);

-- line #333
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACIVIR 800 (Cipla)',
	'Acyclovir',
	'DT',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACIVIR 800 (Cipla)'
);

-- line #334
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACIVIR 25 (Cipla)',
	'Acyclovir',
	'INF',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACIVIR 25 (Cipla)'
);

-- line #335
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACIVIR 3 (Cipla)',
	'Acyclovir',
	'OINT',
	gm.nullify_empty_string('3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACIVIR 3 (Cipla)'
);

-- line #336
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACIV 200 (Zee Lab)',
	'Acyclovir',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACIV 200 (Zee Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACIV 800 (Zee Lab)',
	'Acyclovir',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACIV 800 (Zee Lab)'
);

-- line #337
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACIV 400 (Zee Lab)',
	'Acyclovir',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACIV 400 (Zee Lab)'
);

-- line #338
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACLOR 5 (Gujarat Ph.)',
	'Acyclovir',
	'CRM',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACLOR 5 (Gujarat Ph.)'
);

-- line #339
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACLOVIR 200 (Ind-Swift)',
	'Acyclovir',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACLOVIR 200 (Ind-Swift)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACLOVIR 400 (Ind-Swift)',
	'Acyclovir',
	'DT',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACLOVIR 400 (Ind-Swift)'
);

-- line #340
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Acyclovir', u'always_empty': u'', u'form': u'TAB', u'brand': u'ACLOVIR', u'strength_3': u'', u'company': u'MEDICON PH.', u'unit': u''}

-- line #341
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACVIRALL 200 (Finecure)',
	'Acyclovir',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACVIRALL 200 (Finecure)'
);

-- line #342
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACVIRALL 400 (Finecure)',
	'Acyclovir',
	'DT',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACVIRALL 400 (Finecure)'
);

-- line #343
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACYCLOR 400 (Cipla)',
	'Acyclovir',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACYCLOR 400 (Cipla)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACYCLOR 800 (Cipla)',
	'Acyclovir',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACYCLOR 800 (Cipla)'
);

-- line #344
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACYCLOR 200 (TALENT LAB.)',
	'Acyclovir',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACYCLOR 200 (TALENT LAB.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACYCLOR 400 (TALENT LAB.)',
	'Acyclovir',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACYCLOR 400 (TALENT LAB.)'
);

-- line #345
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACYCLOR 800 (TALENT LAB.)',
	'Acyclovir',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACYCLOR 800 (TALENT LAB.)'
);

-- line #346
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACYCLOVIR 500 (CH.Bhagat)',
	'Acyclovir',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACYCLOVIR 500 (CH.Bhagat)'
);

-- line #347
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXOVIR 250 (Samarth)',
	'Acyclovir',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg(SOD)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXOVIR 250 (Samarth)'
);

-- line #348
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXOVIR 500 (Samarth)',
	'Acyclovir',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg(SOD.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXOVIR 500 (Samarth)'
);

-- line #349
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXOVIR 200 (Samarth)',
	'Acyclovir',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXOVIR 200 (Samarth)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXOVIR 400 (Samarth)',
	'Acyclovir',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXOVIR 400 (Samarth)'
);

-- line #350
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXOVIR 800 (Samarth)',
	'Acyclovir',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXOVIR 800 (Samarth)'
);

-- line #351
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEVIRIN 250 (United Bio.)',
	'Acyclovir',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEVIRIN 250 (United Bio.)'
);

-- line #352
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOVIRAX 5 (Maneesh)',
	'Acyclovir',
	'CRM',
	gm.nullify_empty_string('5')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOVIRAX 5 (Maneesh)'
);

-- line #353
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOVIRAX 200 (Maneesh)',
	'Acyclovir',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOVIRAX 200 (Maneesh)'
);

-- line #354
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOVIRAX 400 (Maneesh)',
	'Acyclovir',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOVIRAX 400 (Maneesh)'
);

-- line #355
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOVIRAX 800 (Maneesh)',
	'Acyclovir',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOVIRAX 800 (Maneesh)'
);

-- line #356
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYCLEX 200 (AXYZEN LIFE)',
	'Acyclovir',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYCLEX 200 (AXYZEN LIFE)'
);

-- line #357
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYCLOVIR 5 (Zydus Cadila)',
	'Acyclovir',
	'CRM',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYCLOVIR 5 (Zydus Cadila)'
);

-- line #358
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYCLOVIR 3 (Zydus Cad.)',
	'Acyclovir',
	'EYE OINT',
	gm.nullify_empty_string('3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYCLOVIR 3 (Zydus Cad.)'
);

-- line #359
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYCLOVIR 200 (Zydus Cadila)',
	'Acyclovir',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYCLOVIR 200 (Zydus Cadila)'
);

-- line #360
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYLOVIR 3 (Zydus Cadila)',
	'Acyclovir',
	'EYE OINT',
	gm.nullify_empty_string('3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYLOVIR 3 (Zydus Cadila)'
);

-- line #361
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EFCURE 600 (EMCURE(ARV))',
	'Acyclovir',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EFCURE 600 (EMCURE(ARV))'
);

-- line #362
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HERPERAX 5 (Micro V.)',
	'Acyclovir',
	'CRM',
	gm.nullify_empty_string('5')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HERPERAX 5 (Micro V.)'
);

-- line #363
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HERPERAX 3 (Micro Labs)',
	'Acyclovir',
	'EYE OINT',
	gm.nullify_empty_string('3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HERPERAX 3 (Micro Labs)'
);

-- line #364
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HERPERAX 5 (GRATIA)',
	'Acyclovir',
	'OINT',
	gm.nullify_empty_string('5')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HERPERAX 5 (GRATIA)'
);

-- line #365
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HERPERAX 200 (Micro V.)',
	'Acyclovir',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HERPERAX 200 (Micro V.)'
);

-- line #366
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HERPERAX 400 (Micro V.)',
	'Acyclovir',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HERPERAX 400 (Micro V.)'
);

-- line #367
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HERPERAX 800 (Micro V.)',
	'Acyclovir',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HERPERAX 800 (Micro V.)'
);

-- line #368
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HERPESAFE 5 (Alkem)',
	'Acyclovir',
	'CRM %',
	gm.nullify_empty_string('5')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HERPESAFE 5 (Alkem)'
);

-- line #369
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HERPESAFE 200 (Alkem)',
	'Acyclovir',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HERPESAFE 200 (Alkem)'
);

-- line #370
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HERPESAFE 400 (Alkem)',
	'Acyclovir',
	'DT',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HERPESAFE 400 (Alkem)'
);

-- line #371
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HERPESAFE 800 (Alkem)',
	'Acyclovir',
	'DT',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HERPESAFE 800 (Alkem)'
);

-- line #372
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HERPEX 5 (Torrent)',
	'Acyclovir',
	'CRM',
	gm.nullify_empty_string('5')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HERPEX 5 (Torrent)'
);

-- line #373
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HERPEX 800 (Torrent)',
	'Acyclovir',
	'DT',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HERPEX 800 (Torrent)'
);

-- line #374
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3', u'strength_2': u'', u'substance': u'Acyclovir', u'always_empty': u'', u'form': u'', u'brand': u'HERPEX OPHTHAL', u'strength_3': u'', u'company': u'Torrent', u'unit': u'%'}

-- line #375
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HERPEX 200 (Torrent)',
	'Acyclovir',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HERPEX 200 (Torrent)'
);

-- line #376
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HERPIKIND 200 (LIFESTAR)',
	'Acyclovir',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HERPIKIND 200 (LIFESTAR)'
);

-- line #377
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HERPIKIND 400 (LIFESTAR)',
	'Acyclovir',
	'DT',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HERPIKIND 400 (LIFESTAR)'
);

-- line #378
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HERPIKIND 800 (LIFESTAR)',
	'Acyclovir',
	'DT',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HERPIKIND 800 (LIFESTAR)'
);

-- line #379
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50G', u'strength_2': u'', u'substance': u'Acyclovir', u'always_empty': u'', u'form': u'OINT', u'brand': u'HERPIKIND', u'strength_3': u'', u'company': u'LIFESTAR', u'unit': u''}

-- line #380
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HERPIN 200 (Apex Form.)',
	'Acyclovir',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HERPIN 200 (Apex Form.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HERPIN 800 (Apex Form.)',
	'Acyclovir',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HERPIN 800 (Apex Form.)'
);

-- line #381
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HERZOVIR 250 (CH.Bhagat)',
	'Acyclovir',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HERZOVIR 250 (CH.Bhagat)'
);

-- line #382
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HERZOVIR 500 (CH.Bhagat)',
	'Acyclovir',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HERZOVIR 500 (CH.Bhagat)'
);

-- line #383
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IND 400 (Mcneil & A.)',
	'Acyclovir',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IND 400 (Mcneil & A.)'
);

-- line #384
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KOVIRAN 250 (KOLSON''S)',
	'Acyclovir',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KOVIRAN 250 (KOLSON''S)'
);

-- line #385
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOVIR 200 (Eli Lilly)',
	'Acyclovir',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOVIR 200 (Eli Lilly)'
);

-- line #386
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOVIR 400 (Eli Lilly)',
	'Acyclovir',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOVIR 400 (Eli Lilly)'
);

-- line #387
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOVIR 800 (Eli Lilly)',
	'Acyclovir',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOVIR 800 (Eli Lilly)'
);

-- line #388
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NISIVIR 500 (NEISS)',
	'Acyclovir',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NISIVIR 500 (NEISS)'
);

-- line #389
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCURAX 200 (Ipca)',
	'Acyclovir',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCURAX 200 (Ipca)'
);

-- line #390
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCURAX 400 (Ipca)',
	'Acyclovir',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCURAX 400 (Ipca)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCURAX 800 (Ipca)',
	'Acyclovir',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCURAX 800 (Ipca)'
);

-- line #391
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCUVIR 3 (F D C)',
	'Acyclovir',
	'CRM/OINT',
	gm.nullify_empty_string('3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCUVIR 3 (F D C)'
);

-- line #392
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCUVIR 400 (F D C)',
	'Acyclovir',
	'DT',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCUVIR 400 (F D C)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCUVIR 800 (F D C)',
	'Acyclovir',
	'DT',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCUVIR 800 (F D C)'
);

-- line #393
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3', u'strength_2': u'', u'substance': u'Acyclovir', u'always_empty': u'', u'form': u'', u'brand': u'OCUVIR OPTICOPS', u'strength_3': u'', u'company': u'F D C', u'unit': u'%'}

-- line #394
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCUVIR SKIN 5 (FDC(SELECT))',
	'Acyclovir',
	'CRM',
	gm.nullify_empty_string('5')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCUVIR SKIN 5 (FDC(SELECT))'
);

-- line #395
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCUVIR 1200 (F D C)',
	'Acyclovir',
	'SR TAB',
	gm.nullify_empty_string('1200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCUVIR 1200 (F D C)'
);

-- line #396
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCUVIR 800 (F D C)',
	'Acyclovir',
	'SUS',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCUVIR 800 (F D C)'
);

-- line #397
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCUVIR 200 (F D C)',
	'Acyclovir',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCUVIR 200 (F D C)'
);

-- line #398
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OKAVIR 200 (Cipla)',
	'Acyclovir',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OKAVIR 200 (Cipla)'
);

-- line #399
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OKAVIR 400 (Cipla)',
	'Acyclovir',
	'DT',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OKAVIR 400 (Cipla)'
);

-- line #400
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OKAVIR SKIN 5 (Cipla)',
	'Acyclovir',
	'CRM',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OKAVIR SKIN 5 (Cipla)'
);

-- line #401
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OVIR 100 (Osper)',
	'Acyclovir',
	'VIAL',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OVIR 100 (Osper)'
);

-- line #402
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OVIR 250 (Osper)',
	'Acyclovir',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OVIR 250 (Osper)'
);

-- line #403
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIDOHERP 5 (Rpg Life)',
	'Acyclovir',
	'CRM',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIDOHERP 5 (Rpg Life)'
);

-- line #404
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIDOHERP 200 (Rpg Life)',
	'Acyclovir',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIDOHERP 200 (Rpg Life)'
);

-- line #405
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACFREE 0.1 (Ochoa)',
	'Adapalene',
	'GEL',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACFREE 0.1 (Ochoa)'
);

-- line #406
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACHILLES 0.1 (Sandoz)',
	'Adapalene',
	'OINT',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACHILLES 0.1 (Sandoz)'
);

-- line #407
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACLENE 0.1 (Cipla)',
	'Adapalene',
	'GEL',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACLENE 0.1 (Cipla)'
);

-- line #408
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACNERIL 1 (Sun)',
	'Adapalene',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACNERIL 1 (Sun)'
);

-- line #409
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADAFERIN 0.1 (Galderma)',
	'Adapalene',
	'GEL',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADAFERIN 0.1 (Galderma)'
);

-- line #410
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADAPEN 0.1 (Intas)',
	'Adapalene',
	'GEL',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADAPEN 0.1 (Intas)'
);

-- line #411
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADAPLE 0.1 (Wallace)',
	'Adapalene',
	'GEL',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADAPLE 0.1 (Wallace)'
);

-- line #412
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADARET 0.1 (Cosme Hc.)',
	'Adapalene',
	'GEL',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADARET 0.1 (Cosme Hc.)'
);

-- line #413
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADIFF 0.1 (Ipca)',
	'Adapalene',
	'GEL',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADIFF 0.1 (Ipca)'
);

-- line #414
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADLENE-AD 0.1 (PSYCOREM)',
	'Adapalene',
	'GEL',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADLENE-AD 0.1 (PSYCOREM)'
);

-- line #415
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADMARK 0.1 (Unimarck)',
	'Adapalene',
	'GEL',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADMARK 0.1 (Unimarck)'
);

-- line #416
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALANGEL 0.1 (Systopic)',
	'Adapalene',
	'GEL',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALANGEL 0.1 (Systopic)'
);

-- line #417
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALAN 0.1 (Systopic)',
	'Adapalene',
	'GEL',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALAN 0.1 (Systopic)'
);

-- line #418
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALENE 0.1 (Le Sante)',
	'Adapalene',
	'GEL',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALENE 0.1 (Le Sante)'
);

-- line #419
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APALENE 0.1 (Elder)',
	'Adapalene',
	'GEL',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APALENE 0.1 (Elder)'
);

-- line #420
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DERIVA 0.1 (Gracewell)',
	'Adapalene',
	'GEL',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DERIVA 0.1 (Gracewell)'
);

-- line #421
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DERIVA MS 0.1 (Gracewell)',
	'Adapalene',
	'GEL',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DERIVA MS 0.1 (Gracewell)'
);

-- line #422
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADESERA 10 (Cipla)',
	'Adefovir dipivoxil',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADESERA 10 (Cipla)'
);

-- line #423
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADFOVIR 10 (Sun)',
	'Adefovir dipivoxil',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADFOVIR 10 (Sun)'
);

-- line #424
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEPTRAL 400 (Abbott)',
	'ADEMETIONINE',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg(SD4)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEPTRAL 400 (Abbott)'
);

-- line #425
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADENOCOR 3 (Torrent)',
	'Adenosine',
	'INJ',
	gm.nullify_empty_string('3')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADENOCOR 3 (Torrent)'
);

-- line #426
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADENOJECT 3 (Sun)',
	'Adenosine',
	'AMP',
	gm.nullify_empty_string('3')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADENOJECT 3 (Sun)'
);

-- line #427
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADENOZ 6 (CELON(REVILON))',
	'Adenosine',
	'AMP',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADENOZ 6 (CELON(REVILON))'
);

-- line #428
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CADSINE 3 (Gland Ph.)',
	'Adenosine',
	'INJ',
	gm.nullify_empty_string('3')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CADSINE 3 (Gland Ph.)'
);

-- line #429
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARNOSINE 30 (Samarth)',
	'Adenosine',
	'INJ',
	gm.nullify_empty_string('30')::numeric,
	'mg/10ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARNOSINE 30 (Samarth)'
);

-- line #430
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARNOSINE 6 (Samarth)',
	'Adenosine',
	'INJ',
	gm.nullify_empty_string('6')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARNOSINE 6 (Samarth)'
);

-- line #431
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000MCG', u'strength_2': u'', u'substance': u'Adenosylcobalamin', u'always_empty': u'', u'form': u'TAB', u'brand': u'ADENOMIN', u'strength_3': u'', u'company': u'Ordain Hc.', u'unit': u''}

-- line #432
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Adenosylcobalamin', u'always_empty': u'', u'form': u'CAP', u'brand': u'ADENOSYL', u'strength_3': u'', u'company': u'Bioplasma', u'unit': u''}

-- line #433
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Adenosylcobalamin', u'always_empty': u'', u'form': u'OD CAP', u'brand': u'ADENOSYL', u'strength_3': u'', u'company': u'Bioplasma', u'unit': u''}

-- line #434
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'ADHATODA VASICA APIES WEBBIANA TYLOPHORA INDICA ETC.', u'always_empty': u'', u'form': u'CAP', u'brand': u'BREETH', u'strength_3': u'', u'company': u'PINK HEALTH', u'unit': u''}

-- line #435
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'ADRENALINE', u'always_empty': u'', u'form': u'INJ', u'brand': u'ARDULIN', u'strength_3': u'', u'company': u'VHB', u'unit': u''}

-- line #436
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APRICOL 2.5 (Indus)',
	'Adrenochrome Monosemicarbazone',
	'F. INJ',
	gm.nullify_empty_string('2.5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APRICOL 2.5 (Indus)'
);

-- line #437
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOT 5 (Shrinivas)',
	'Adrenochrome Monosemicarbazone',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOT 5 (Shrinivas)'
);

-- line #438
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KERUTIN-C 1 (Mercury)',
	'Adrenochrome Monosemicarbazone',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML(+2'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KERUTIN-C 1 (Mercury)'
);

-- line #439
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KLOG 10 (Global Med.)',
	'Adrenochrome Monosemicarbazone',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KLOG 10 (Global Med.)'
);

-- line #440
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MERITIN-C 1 (Mercury Hc.)',
	'Adrenochrome Monosemicarbazone',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MERITIN-C 1 (Mercury Hc.)'
);

-- line #441
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PFICHROME 1 (Pfiscar Ind.)',
	'Adrenochrome Monosemicarbazone',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PFICHROME 1 (Pfiscar Ind.)'
);

-- line #442
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'A-1 400 (Greenco Bio.)',
	'Albendazole',
	'CHEW TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'A-1 400 (Greenco Bio.)'
);

-- line #443
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ABD-1 200 (Franklin)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ABD-1 200 (Franklin)'
);

-- line #444
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ABD-1 400 (Franklin)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ABD-1 400 (Franklin)'
);

-- line #445
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ABWAL 400 (Wallace)',
	'Albendazole',
	'SUSP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ABWAL 400 (Wallace)'
);

-- line #446
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ABWAL 400 (Wallace)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ABWAL 400 (Wallace)'
);

-- line #447
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ABY 400 (ARCUS LABS)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ABY 400 (ARCUS LABS)'
);

-- line #448
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ABZOLE 200 (Arbro Ph.)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ABZOLE 200 (Arbro Ph.)'
);

-- line #449
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ABZOLE 200 (Euphoric)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ABZOLE 200 (Euphoric)'
);

-- line #450
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ABZOLE 400 (Arbro Ph.)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ABZOLE 400 (Arbro Ph.)'
);

-- line #451
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ABZOLE 400 (Euphoric)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ABZOLE 400 (Euphoric)'
);

-- line #452
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ABZ 200 (Indoco Rem.)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ABZ 200 (Indoco Rem.)'
);

-- line #453
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ABZ 400 (Indoco Rem.)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ABZ 400 (Indoco Rem.)'
);

-- line #454
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AH-1 400 (Obsurge)',
	'Albendazole',
	'CHEW TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AH-1 400 (Obsurge)'
);

-- line #455
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AH-1 200 (Obsurge)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AH-1 200 (Obsurge)'
);

-- line #456
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AIBACARE 400 (Dcm Lab)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AIBACARE 400 (Dcm Lab)'
);

-- line #457
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBA 400 (Zetek Ph.)',
	'Albendazole',
	'CHEW TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBA 400 (Zetek Ph.)'
);

-- line #458
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBAMAA 200 (Lifeon)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBAMAA 200 (Lifeon)'
);

-- line #459
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBAN 400 (CHEMO HC.)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBAN 400 (CHEMO HC.)'
);

-- line #460
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBA 400 (Nac Int.)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBA 400 (Nac Int.)'
);

-- line #461
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBAZEN 400 (Kaizen Ph.)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBAZEN 400 (Kaizen Ph.)'
);

-- line #462
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBAZIO 200 (AGIO PH.)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBAZIO 200 (AGIO PH.)'
);

-- line #463
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBAZIO 400 (AGIO PH.)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBAZIO 400 (AGIO PH.)'
);

-- line #464
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBAZOLE 400 (Wings)',
	'Albendazole',
	'DT',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBAZOLE 400 (Wings)'
);

-- line #465
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBAZOLE 200 (Wings)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBAZOLE 200 (Wings)'
);

-- line #466
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBEKON 200 (Briskon)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBEKON 200 (Briskon)'
);

-- line #467
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBEKON 400 (Briskon)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBEKON 400 (Briskon)'
);

-- line #468
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBENDA 200 (Alpha Lab)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBENDA 200 (Alpha Lab)'
);

-- line #469
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBENDA 400 (Alpha Lab)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBENDA 400 (Alpha Lab)'
);

-- line #470
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBENDOL 200 (Micro Nova)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBENDOL 200 (Micro Nova)'
);

-- line #471
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBENDOL 400 (Micro Nova)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBENDOL 400 (Micro Nova)'
);

-- line #472
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBEND 200 (Drakt Int.)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBEND 200 (Drakt Int.)'
);

-- line #473
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBEND 400 (Drakt Int.)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBEND 400 (Drakt Int.)'
);

-- line #474
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBENT 200 (ACTO)',
	'Albendazole',
	'SUSP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBENT 200 (ACTO)'
);

-- line #475
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBENT 400 (ACTO)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBENT 400 (ACTO)'
);

-- line #476
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBEPRA 400 (ROHVEESHPRA PH.)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBEPRA 400 (ROHVEESHPRA PH.)'
);

-- line #477
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBESAN 400 (Sanify)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBESAN 400 (Sanify)'
);

-- line #478
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBESTAR 400 (MINOVA)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBESTAR 400 (MINOVA)'
);

-- line #479
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBEST 200 (Nestor)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBEST 200 (Nestor)'
);

-- line #480
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBEST 400 (Nestor)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBEST 400 (Nestor)'
);

-- line #481
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBET 400 (Depone)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBET 400 (Depone)'
);

-- line #482
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBEX 200 (Saga Lab)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBEX 200 (Saga Lab)'
);

-- line #483
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBEX 400 (Saga Lab)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBEX 400 (Saga Lab)'
);

-- line #484
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBEZOLE 200 (Khandelwal)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBEZOLE 200 (Khandelwal)'
);

-- line #485
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBEZOLE 400 (Khandelwal)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBEZOLE 400 (Khandelwal)'
);

-- line #486
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBID 200 (SHINE PH.)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBID 200 (SHINE PH.)'
);

-- line #487
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBID 400 (SHINE PH.)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBID 400 (SHINE PH.)'
);

-- line #488
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBOL 400 (EAST WEST)',
	'Albendazole',
	'SUSP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBOL 400 (EAST WEST)'
);

-- line #489
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBOL 400 (EAST WEST)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBOL 400 (EAST WEST)'
);

-- line #490
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBOM 400 (Om Bio.)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBOM 400 (Om Bio.)'
);

-- line #491
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBOVEN 400 (VENCARE)',
	'Albendazole',
	'CHEW TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBOVEN 400 (VENCARE)'
);

-- line #492
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBOVEN 200 (VENCARE)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBOVEN 200 (VENCARE)'
);

-- line #493
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBRODO 200 (Shalaks)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBRODO 200 (Shalaks)'
);

-- line #494
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBRODO 400 (Shalaks)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBRODO 400 (Shalaks)'
);

-- line #495
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Albendazole', u'always_empty': u'', u'form': u'TAB/SUS', u'brand': u'ALBUS', u'strength_3': u'', u'company': u'Rhombus', u'unit': u''}

-- line #496
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALDEZOLE 200 (Alde Medi.)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALDEZOLE 200 (Alde Medi.)'
);

-- line #497
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALDEZOLE 400 (Alde Medi.)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALDEZOLE 400 (Alde Medi.)'
);

-- line #498
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALIZA 200 (Ascent Lab)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALIZA 200 (Ascent Lab)'
);

-- line #499
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALIZA 400 (Ascent Lab)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALIZA 400 (Ascent Lab)'
);

-- line #500
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALMET 400 (Mamta Ph.)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALMET 400 (Mamta Ph.)'
);

-- line #501
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALMINTH 200 (Torrent)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALMINTH 200 (Torrent)'
);

-- line #502
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALMINTH 200 (Torrent)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALMINTH 200 (Torrent)'
);

-- line #503
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALMINTH 200 (Torrent)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALMINTH 200 (Torrent)'
);

-- line #504
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALMINTH 400 (Torrent)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALMINTH 400 (Torrent)'
);

-- line #505
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALMIX 200 (Merril Ph.)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALMIX 200 (Merril Ph.)'
);

-- line #506
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALMIX 400 (Merril Ph.)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALMIX 400 (Merril Ph.)'
);

-- line #507
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALONE 200 (Acron Ph.)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALONE 200 (Acron Ph.)'
);

-- line #508
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALONE 400 (Acron Ph.)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALONE 400 (Acron Ph.)'
);

-- line #509
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AL 200 (Radicura)',
	'Albendazole',
	'SUSP',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AL 200 (Radicura)'
);

-- line #510
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AL 400 (Radicura)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AL 400 (Radicura)'
);

-- line #511
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALTEC 200 (Zee Lab)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALTEC 200 (Zee Lab)'
);

-- line #512
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALTEC 400 (Zee Lab)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALTEC 400 (Zee Lab)'
);

-- line #513
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALVELA 200 (Shrinivas)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALVELA 200 (Shrinivas)'
);

-- line #514
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALVELA 250 (Shrinivas)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALVELA 250 (Shrinivas)'
);

-- line #515
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALVELA 400 (Shrinivas)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALVELA 400 (Shrinivas)'
);

-- line #516
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALWORM 200 (Medopharm)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALWORM 200 (Medopharm)'
);

-- line #517
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALWORM 200 (Vega Lab)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALWORM 200 (Vega Lab)'
);

-- line #518
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALWORM 400 (Medopharm)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALWORM 400 (Medopharm)'
);

-- line #519
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZAD 200 (Merind)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZAD 200 (Merind)'
);

-- line #520
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZAD 400 (Merind)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZAD 400 (Merind)'
);

-- line #521
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZOKAN 400 (Kansas Lab)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZOKAN 400 (Kansas Lab)'
);

-- line #522
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZOLE 400 (Healthgaurd)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZOLE 400 (Healthgaurd)'
);

-- line #523
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZOL 400 (Bal Ph.)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZOL 400 (Bal Ph.)'
);

-- line #524
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANTHEL 200 (Lincoln)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANTHEL 200 (Lincoln)'
);

-- line #525
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANTHEL 400 (Lincoln)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANTHEL 400 (Lincoln)'
);

-- line #526
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANTIWORM 200 (Hi-Tec)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANTIWORM 200 (Hi-Tec)'
);

-- line #527
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANTIWORM 400 (Hi-Tec)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANTIWORM 400 (Hi-Tec)'
);

-- line #528
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AQUIBEND 200 (Aquila)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AQUIBEND 200 (Aquila)'
);

-- line #529
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AQUIBEND 400 (Aquila)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AQUIBEND 400 (Aquila)'
);

-- line #530
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATBEND 200 (Atoz Ph.)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATBEND 200 (Atoz Ph.)'
);

-- line #531
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATBEND 400 (Atoz Ph.)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATBEND 400 (Atoz Ph.)'
);

-- line #532
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVIBAND 200 (Avalanche)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVIBAND 200 (Avalanche)'
);

-- line #533
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVIBAND 400 (Avalanche)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVIBAND 400 (Avalanche)'
);

-- line #534
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZEBEND 400 (ABLAZE HC)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZEBEND 400 (ABLAZE HC)'
);

-- line #535
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZOLE 400 (Dial Ph.)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZOLE 400 (Dial Ph.)'
);

-- line #536
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZ 200 (Cure Quick)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZ 200 (Cure Quick)'
);

-- line #537
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Albendazole', u'always_empty': u'', u'form': u'SYP', u'brand': u'AZ', u'strength_3': u'', u'company': u'NIVCA', u'unit': u''}

-- line #538
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZ 400 (NIVCA)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZ 400 (NIVCA)'
);

-- line #539
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BAND 400 (VENSAT)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BAND 400 (VENSAT)'
);

-- line #540
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3000', u'strength_2': u'', u'substance': u'Albendazole', u'always_empty': u'', u'form': u'', u'brand': u'BANDYKIND', u'strength_3': u'', u'company': u'Mankind', u'unit': u'mg'}

-- line #541
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BANDYKIND 25 (Mankind)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BANDYKIND 25 (Mankind)'
);

-- line #542
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BANDY 200 (Mankind)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BANDY 200 (Mankind)'
);

-- line #543
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BANDY 400 (Mankind)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BANDY 400 (Mankind)'
);

-- line #544
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BANOCIDE 120 (GSK)',
	'Albendazole',
	'SYR',
	gm.nullify_empty_string('120')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BANOCIDE 120 (GSK)'
);

-- line #545
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BANTAP 200 (Baroque)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BANTAP 200 (Baroque)'
);

-- line #546
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BANTAP 400 (Baroque)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BANTAP 400 (Baroque)'
);

-- line #547
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BANTHEL 200 (Candor Bio.)',
	'Albendazole',
	'LIQ',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BANTHEL 200 (Candor Bio.)'
);

-- line #548
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BANTHEL 400 (Candor Bio.)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BANTHEL 400 (Candor Bio.)'
);

-- line #549
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BELZOLE 400 (LUSTRE)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BELZOLE 400 (LUSTRE)'
);

-- line #550
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENAZOL 400 (Mars Rem.)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENAZOL 400 (Mars Rem.)'
);

-- line #551
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Albendazole', u'always_empty': u'', u'form': u'LIQ', u'brand': u'BENDAL', u'strength_3': u'', u'company': u'AXYZEN LIFE', u'unit': u''}

-- line #552
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENDAL 400 (AXYZEN LIFE)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENDAL 400 (AXYZEN LIFE)'
);

-- line #553
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENDEX 200 (Protec)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENDEX 200 (Protec)'
);

-- line #554
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENDEX 400 (Protec)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENDEX 400 (Protec)'
);

-- line #555
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENROD 200 (Intra(INVISION))',
	'Albendazole',
	'SUSP',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENROD 200 (Intra(INVISION))'
);

-- line #556
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENROD 400 (Intra Lab)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENROD 400 (Intra Lab)'
);

-- line #557
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BINDAZ 400 (Life Line)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BINDAZ 400 (Life Line)'
);

-- line #558
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIWOM 200 (Zydus VACC.)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIWOM 200 (Zydus VACC.)'
);

-- line #559
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIWOM 400 (Zydus VACC.)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIWOM 400 (Zydus VACC.)'
);

-- line #560
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-BAND 400 (Corona)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-BAND 400 (Corona)'
);

-- line #561
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEZOLE 200 (Shinto Org.)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEZOLE 200 (Shinto Org.)'
);

-- line #562
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEZOLE 200 (Shinto Org.)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEZOLE 200 (Shinto Org.)'
);

-- line #563
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEZOLE 400 (Shinto Org.)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEZOLE 400 (Shinto Org.)'
);

-- line #564
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIDAZOLE 200 (Juggat)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIDAZOLE 200 (Juggat)'
);

-- line #565
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIDAZOLE 400 (Juggat)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIDAZOLE 400 (Juggat)'
);

-- line #566
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CINEL 200 (Biocin Hc.)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CINEL 200 (Biocin Hc.)'
);

-- line #567
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CINEL 400 (Biocin Hc.)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CINEL 400 (Biocin Hc.)'
);

-- line #568
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLEARWORM 200 (INVISION(INFALIFE))',
	'Albendazole',
	'SUSP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLEARWORM 200 (INVISION(INFALIFE))'
);

-- line #569
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COMBANTRIN-A 200 (Pfizer)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COMBANTRIN-A 200 (Pfizer)'
);

-- line #570
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COMBANTRIN-A 400 (Pfizer)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COMBANTRIN-A 400 (Pfizer)'
);

-- line #571
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COMBANTRIN 200 (Pfizer)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COMBANTRIN 200 (Pfizer)'
);

-- line #572
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COMBANTRIN 400 (Pfizer)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COMBANTRIN 400 (Pfizer)'
);

-- line #573
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUWARM 400 (Cubit Hc.)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUWARM 400 (Cubit Hc.)'
);

-- line #574
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYBEND 400 (Cyper Ph.)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYBEND 400 (Cyper Ph.)'
);

-- line #575
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAZO 400 (Osper)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAZO 400 (Osper)'
);

-- line #576
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DISPEL 200 (Indchemie)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DISPEL 200 (Indchemie)'
);

-- line #577
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DISPEL 200 (Indchemie)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DISPEL 200 (Indchemie)'
);

-- line #578
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DISPEL 400 (Indchemie)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DISPEL 400 (Indchemie)'
);

-- line #579
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'D-WORM 200 (Graf Lab.)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'D-WORM 200 (Graf Lab.)'
);

-- line #580
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'D-WORM 400 (Graf Lab.)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'D-WORM 400 (Graf Lab.)'
);

-- line #581
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'E-BEND 400 (MARLINE BIO.)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'E-BEND 400 (MARLINE BIO.)'
);

-- line #582
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EBEX CHW 400 (MADHAV BIO.)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EBEX CHW 400 (MADHAV BIO.)'
);

-- line #583
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EBEX 200 (MADHAV BIO.)',
	'Albendazole',
	'SUSP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EBEX 200 (MADHAV BIO.)'
);

-- line #584
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EJECTIL-P 200 (Profic)',
	'Albendazole',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EJECTIL-P 200 (Profic)'
);

-- line #585
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EJECTIL 400 (Profic)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EJECTIL 400 (Profic)'
);

-- line #586
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELBEND 200 (Overseas Hc.)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELBEND 200 (Overseas Hc.)'
);

-- line #587
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELBEND 400 (Overseas Hc.)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELBEND 400 (Overseas Hc.)'
);

-- line #588
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELBENOL 400 (Ind-Swift)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELBENOL 400 (Ind-Swift)'
);

-- line #589
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELEBEN 200 (Ind-Swift)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELEBEN 200 (Ind-Swift)'
);

-- line #590
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELEBEN 400 (Ind-Swift)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELEBEN 400 (Ind-Swift)'
);

-- line #591
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELMINEX 200 (Cachet)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELMINEX 200 (Cachet)'
);

-- line #592
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELMINEX 400 (Cachet)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELMINEX 400 (Cachet)'
);

-- line #593
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELMINOVA 200 (Yash Ph.)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELMINOVA 200 (Yash Ph.)'
);

-- line #594
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELMINOVA 400 (Yash Ph.)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELMINOVA 400 (Yash Ph.)'
);

-- line #595
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMANTHAL 200 (M.M. Labs)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMANTHAL 200 (M.M. Labs)'
);

-- line #596
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMANTHAL 400 (M.M. Labs)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMANTHAL 400 (M.M. Labs)'
);

-- line #597
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMZOLE 200 (Malcom Ph.)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMZOLE 200 (Malcom Ph.)'
);

-- line #598
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMZOLE 400 (Malcom Ph.)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMZOLE 400 (Malcom Ph.)'
);

-- line #599
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENBENOL 400 (Ind-Swift)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENBENOL 400 (Ind-Swift)'
);

-- line #600
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERAWORM 200 (Marc Lab)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERAWORM 200 (Marc Lab)'
);

-- line #601
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERAWORM 400 (Marc Lab)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERAWORM 400 (Marc Lab)'
);

-- line #602
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXPORM 200 (Ravian)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXPORM 200 (Ravian)'
);

-- line #603
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXPORM 400 (Ravian)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXPORM 400 (Ravian)'
);

-- line #604
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXZOL 400 (Vantage)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXZOL 400 (Vantage)'
);

-- line #605
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FYBEND 400 (Phytochem)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FYBEND 400 (Phytochem)'
);

-- line #606
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEKARE 400 (Gsk)',
	'Albendazole',
	'CAPTAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEKARE 400 (Gsk)'
);

-- line #607
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEKARE 200 (Gsk)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEKARE 200 (Gsk)'
);

-- line #608
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GOWORM 400 (Svizera)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GOWORM 400 (Svizera)'
);

-- line #609
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GOWORM 400 (Svizera)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GOWORM 400 (Svizera)'
);

-- line #610
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HELMANIL 400 (Galpha)',
	'Albendazole',
	'CHEW TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HELMANIL 400 (Galpha)'
);

-- line #611
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HELMANIL 200 (Galpha)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HELMANIL 200 (Galpha)'
);

-- line #612
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HELMANOL 400 (Merit Org.)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HELMANOL 400 (Merit Org.)'
);

-- line #613
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HELMAPAX 400 (Bipl(Radico Lab))',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HELMAPAX 400 (Bipl(Radico Lab))'
);

-- line #614
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HELMAX 400 (Unimax Lab)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HELMAX 400 (Unimax Lab)'
);

-- line #615
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HELMEX 200 (Mars)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HELMEX 200 (Mars)'
);

-- line #616
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HELMEX 400 (Mars)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HELMEX 400 (Mars)'
);

-- line #617
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYMIN 200 (Intra Lab)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYMIN 200 (Intra Lab)'
);

-- line #618
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYMIN 400 (Intra Lab)',
	'Albendazole',
	'SUSP',
	gm.nullify_empty_string('400')::numeric,
	'mg/10ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYMIN 400 (Intra Lab)'
);

-- line #619
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYMIN 400 (Intra Lab)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYMIN 400 (Intra Lab)'
);

-- line #620
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYZOLE 400 (Trio Rem.)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYZOLE 400 (Trio Rem.)'
);

-- line #621
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEXORM 200 (Cadex Lab)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEXORM 200 (Cadex Lab)'
);

-- line #622
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEXORM 400 (Cadex Lab)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEXORM 400 (Cadex Lab)'
);

-- line #623
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KIRAJA 200 (Medizone)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KIRAJA 200 (Medizone)'
);

-- line #624
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KIRAJA 400 (Medizone)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KIRAJA 400 (Medizone)'
);

-- line #625
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KNOW OUT 400 (Maneesh Hc.)',
	'Albendazole',
	'SUSP',
	gm.nullify_empty_string('400')::numeric,
	'mg/10ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KNOW OUT 400 (Maneesh Hc.)'
);

-- line #626
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KNOW-OUT 400 (Maneesh Hc.)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KNOW-OUT 400 (Maneesh Hc.)'
);

-- line #627
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEMTUFF 400 (LEMON PH.)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEMTUFF 400 (LEMON PH.)'
);

-- line #628
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEZOLE 400 (Goodluck Ph.)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEZOLE 400 (Goodluck Ph.)'
);

-- line #629
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUPIBEND 200 (Lupin)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUPIBEND 200 (Lupin)'
);

-- line #630
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUPIBEND 400 (Lupin)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUPIBEND 400 (Lupin)'
);

-- line #631
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDIMINTH 400 (Medico)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDIMINTH 400 (Medico)'
);

-- line #632
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILIBEND 200 (Glenmark)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILIBEND 200 (Glenmark)'
);

-- line #633
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILIBEND 400 (Glenmark)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILIBEND 400 (Glenmark)'
);

-- line #634
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOMINTH 200 (Makers)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOMINTH 200 (Makers)'
);

-- line #635
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOMINTH 400 (Makers)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOMINTH 400 (Makers)'
);

-- line #636
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MORBAND 200 (Moraceae)',
	'Albendazole',
	'SUSP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MORBAND 200 (Moraceae)'
);

-- line #637
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MORBAND 400 (Moraceae)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MORBAND 400 (Moraceae)'
);

-- line #638
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOREZOLE 200 (Morepen)',
	'Albendazole',
	'SYR',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOREZOLE 200 (Morepen)'
);

-- line #639
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEMOFEX 200 (Pharma synth)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEMOFEX 200 (Pharma synth)'
);

-- line #640
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEMOFEX 400 (Pharma synth)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEMOFEX 400 (Pharma synth)'
);

-- line #641
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEMOZOLE 200 (Ipca)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEMOZOLE 200 (Ipca)'
);

-- line #642
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEMOZOLE 400 (Ipca)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEMOZOLE 400 (Ipca)'
);

-- line #643
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOMIN 400 (Neo Ph.)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOMIN 400 (Neo Ph.)'
);

-- line #644
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NILWORM 200 (Allure Rem.)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NILWORM 200 (Allure Rem.)'
);

-- line #645
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NILWORM 400 (Allure Rem.)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NILWORM 400 (Allure Rem.)'
);

-- line #646
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOWORM 200 (Alkem)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOWORM 200 (Alkem)'
);

-- line #647
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOWORM 400 (Alkem)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOWORM 400 (Alkem)'
);

-- line #648
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUBEND 200 (Kramer)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUBEND 200 (Kramer)'
);

-- line #649
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUBEND 400 (Kramer)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUBEND 400 (Kramer)'
);

-- line #650
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OBEN 200 (Armour Rem.)',
	'Albendazole',
	'SYR',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OBEN 200 (Armour Rem.)'
);

-- line #651
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFBEND 200 (Obzone Ph.)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFBEND 200 (Obzone Ph.)'
);

-- line #652
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFBEND 400 (Obzone Ph.)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFBEND 400 (Obzone Ph.)'
);

-- line #653
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLBAN 200 (Indoco Rem.)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLBAN 200 (Indoco Rem.)'
);

-- line #654
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLBAN 400 (Indoco Rem.)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLBAN 400 (Indoco Rem.)'
);

-- line #655
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLBEZ 200 (Olcare)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLBEZ 200 (Olcare)'
);

-- line #656
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLBEZ 400 (Olcare)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLBEZ 400 (Olcare)'
);

-- line #657
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLWORM 200 (Biochem)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLWORM 200 (Biochem)'
);

-- line #658
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLWORM 400 (Biochem)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLWORM 400 (Biochem)'
);

-- line #659
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMNITEL 200 (Pharmed)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMNITEL 200 (Pharmed)'
);

-- line #660
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMNITEL 400 (Pharmed)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMNITEL 400 (Pharmed)'
);

-- line #661
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSEBEN 200 (Roselabs)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSEBEN 200 (Roselabs)'
);

-- line #662
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSEBEN 400 (ROSE LABS)',
	'Albendazole',
	'SYR',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSEBEN 400 (ROSE LABS)'
);

-- line #663
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSEBEN 400 (Roselabs)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSEBEN 400 (Roselabs)'
);

-- line #664
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANAMINT 200 (Seagull)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANAMINT 200 (Seagull)'
);

-- line #665
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANAMINT 400 (Seagull)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANAMINT 400 (Seagull)'
);

-- line #666
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REWOLE 200 (Relish)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REWOLE 200 (Relish)'
);

-- line #667
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REWOLE 400 (Relish)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REWOLE 400 (Relish)'
);

-- line #668
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REZOL 200 (Chemo D.)',
	'Albendazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REZOL 200 (Chemo D.)'
);

-- line #669
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REZOL 400 (Chemo D.)',
	'Albendazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REZOL 400 (Chemo D.)'
);

-- line #670
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.5G', u'strength_2': u'', u'substance': u'ALCLOMETASONE DIPROPIONATE', u'always_empty': u'', u'form': u'CRM', u'brand': u'ACLOMET', u'strength_3': u'', u'company': u'Ajanta Ph.', u'unit': u''}

-- line #671
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALENOST 10 (Macleods)',
	'Alendronate Sod.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALENOST 10 (Macleods)'
);

-- line #672
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALENOST 70 (Macleods)',
	'Alendronate Sod.',
	'TAB',
	gm.nullify_empty_string('70')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALENOST 70 (Macleods)'
);

-- line #673
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIFOSA 10 (Troikaa)',
	'Alendronate Sod.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIFOSA 10 (Troikaa)'
);

-- line #674
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIFOSA 35 (Troikaa)',
	'Alendronate Sod.',
	'TAB',
	gm.nullify_empty_string('35')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIFOSA 35 (Troikaa)'
);

-- line #675
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIFOSA 5 (Troikaa)',
	'Alendronate Sod.',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIFOSA 5 (Troikaa)'
);

-- line #676
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIFOSA 70 (Troikaa)',
	'Alendronate Sod.',
	'TAB',
	gm.nullify_empty_string('70')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIFOSA 70 (Troikaa)'
);

-- line #677
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DENFOS 35 (Dr.Reddy''S)',
	'Alendronate Sod.',
	'TAB',
	gm.nullify_empty_string('35')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DENFOS 35 (Dr.Reddy''S)'
);

-- line #678
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DENFOS 5 (Dr.Reddy''S)',
	'Alendronate Sod.',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DENFOS 5 (Dr.Reddy''S)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DENFOS 10 (Dr.Reddy''S)',
	'Alendronate Sod.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DENFOS 10 (Dr.Reddy''S)'
);

-- line #679
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DENFOS 70 (Dr.Reddy''S)',
	'Alendronate Sod.',
	'TAB',
	gm.nullify_empty_string('70')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DENFOS 70 (Dr.Reddy''S)'
);

-- line #680
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DRONAL 10 (Orchid Hc.)',
	'Alendronate Sod.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DRONAL 10 (Orchid Hc.)'
);

-- line #681
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSTEOFOS 10 (Cipla)',
	'Alendronate Sod.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSTEOFOS 10 (Cipla)'
);

-- line #682
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSTEOFOS 35 (Cipla)',
	'Alendronate Sod.',
	'TAB',
	gm.nullify_empty_string('35')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSTEOFOS 35 (Cipla)'
);

-- line #683
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSTEOFOS 5 (Cipla)',
	'Alendronate Sod.',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSTEOFOS 5 (Cipla)'
);

-- line #684
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSTEOFOS 70 (Cipla)',
	'Alendronate Sod.',
	'TAB',
	gm.nullify_empty_string('70')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSTEOFOS 70 (Cipla)'
);

-- line #685
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PORONIL 10 (Finecure)',
	'Alendronate Sod.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PORONIL 10 (Finecure)'
);

-- line #686
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RALENOST 10 (Croslands)',
	'Alendronate Sod.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RALENOST 10 (Croslands)'
);

-- line #687
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESTOFOS 10 (Sun)',
	'Alendronate Sod.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESTOFOS 10 (Sun)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESTOFOS 70 (Sun)',
	'Alendronate Sod.',
	'TAB',
	gm.nullify_empty_string('70')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESTOFOS 70 (Sun)'
);

-- line #688
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.25MCG', u'strength_2': u'', u'substance': u'Alfacalcidol', u'always_empty': u'', u'form': u'CAP', u'brand': u'ALFABOL', u'strength_3': u'', u'company': u'Meridian', u'unit': u''}

-- line #689
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.25 MCG', u'strength_2': u'', u'substance': u'Alfacalcidol', u'always_empty': u'', u'form': u'CAP', u'brand': u'ALFABON-D', u'strength_3': u'', u'company': u'Modi Mundi', u'unit': u''}

-- line #690
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.25MCG', u'strength_2': u'', u'substance': u'Alfacalcidol', u'always_empty': u'', u'form': u'CAP', u'brand': u'ALFACAL SOFGEL', u'strength_3': u'', u'company': u'Macleods', u'unit': u''}

-- line #691
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.5MCG', u'strength_2': u'', u'substance': u'Alfacalcidol', u'always_empty': u'', u'form': u'CAP', u'brand': u'ALFACAL SOFGEL', u'strength_3': u'', u'company': u'Macleods', u'unit': u''}

-- line #692
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.25MCG', u'strength_2': u'', u'substance': u'Alfacalcidol', u'always_empty': u'', u'form': u'CAPS', u'brand': u'ALFA', u'strength_3': u'', u'company': u'Mark Rem.', u'unit': u''}

-- line #693
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.25MCG', u'strength_2': u'', u'substance': u'Alfacalcidol', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALFACIP', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #694
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1MCG', u'strength_2': u'', u'substance': u'Alfacalcidol', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALFACIP', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #695
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,25', u'strength_2': u'1;MCG', u'substance': u'Alfacalcidol', u'always_empty': u'', u'form': u'CAP', u'brand': u'ALFA D3', u'strength_3': u'', u'company': u'GSK', u'unit': u''}

-- line #696
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,25', u'strength_2': u'1;MCG', u'substance': u'Alfacalcidol', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALFA-D3', u'strength_3': u'', u'company': u'GSK', u'unit': u''}

-- line #697
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.25MCG', u'strength_2': u'', u'substance': u'Alfacalcidol', u'always_empty': u'', u'form': u'CAP', u'brand': u'ALFARICH', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #698
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.25MCG', u'strength_2': u'', u'substance': u'Alfacalcidol', u'always_empty': u'', u'form': u'CAP', u'brand': u'ALFASET', u'strength_3': u'', u'company': u'Orchid Hc.', u'unit': u''}

-- line #699
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.25MCG', u'strength_2': u'', u'substance': u'Alfacalcidol', u'always_empty': u'', u'form': u'CAP', u'brand': u'ALPHA CALCIROL', u'strength_3': u'', u'company': u'Cadila Ph.', u'unit': u''}

-- line #700
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.25MCG', u'strength_2': u'', u'substance': u'Alfacalcidol', u'always_empty': u'', u'form': u'CAP', u'brand': u'ALPHA D3', u'strength_3': u'', u'company': u'Gsk', u'unit': u''}

-- line #701
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1MCG', u'strength_2': u'', u'substance': u'Alfacalcidol', u'always_empty': u'', u'form': u'CAP', u'brand': u'ALPHA D3', u'strength_3': u'', u'company': u'Gsk', u'unit': u''}

-- line #702
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.25MCG', u'strength_2': u'', u'substance': u'Alfacalcidol', u'always_empty': u'', u'form': u'CAP', u'brand': u'ALPHADOL', u'strength_3': u'', u'company': u'Panacea', u'unit': u''}

-- line #703
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1MCG', u'strength_2': u'', u'substance': u'Alfacalcidol', u'always_empty': u'', u'form': u'CAP', u'brand': u'ALPHADOL', u'strength_3': u'', u'company': u'Panacea', u'unit': u''}

-- line #704
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.25MCG', u'strength_2': u'', u'substance': u'Alfacalcidol', u'always_empty': u'', u'form': u'CAP', u'brand': u'BONYDIL', u'strength_3': u'', u'company': u'Ar-Ex Labs.', u'unit': u''}

-- line #705
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.25MCG', u'strength_2': u'', u'substance': u'Alfacalcidol', u'always_empty': u'', u'form': u'SG TAB', u'brand': u'CALCIT', u'strength_3': u'', u'company': u'Zydus Bio.', u'unit': u''}

-- line #706
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.25MCG', u'strength_2': u'', u'substance': u'Alfacalcidol', u'always_empty': u'', u'form': u'CAP', u'brand': u'CALFA-D', u'strength_3': u'', u'company': u'Kee Ph.', u'unit': u''}

-- line #707
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.25MCG', u'strength_2': u'', u'substance': u'Alfacalcidol', u'always_empty': u'', u'form': u'CAP', u'brand': u'EVODOL', u'strength_3': u'', u'company': u'Shreya', u'unit': u''}

-- line #708
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1MCG', u'strength_2': u'', u'substance': u'Alfacalcidol', u'always_empty': u'', u'form': u'CAP', u'brand': u'EVODOL', u'strength_3': u'', u'company': u'Shreya', u'unit': u''}

-- line #709
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.25MCG', u'strength_2': u'', u'substance': u'Alfacalcidol', u'always_empty': u'', u'form': u'CAP', u'brand': u'GR-ALFA', u'strength_3': u'', u'company': u'German R.', u'unit': u''}

-- line #710
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.25MCG', u'strength_2': u'', u'substance': u'Alfacalcidol', u'always_empty': u'', u'form': u'CAP', u'brand': u'GR ALPHA', u'strength_3': u'', u'company': u'German R.', u'unit': u''}

-- line #711
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'WITH MILK CALCIUM', u'strength_2': u'', u'substance': u'Alfacalcidol', u'always_empty': u'', u'form': u'TAB', u'brand': u'MILKAL', u'strength_3': u'', u'company': u'Mcneil & ARGUS', u'unit': u''}

-- line #712
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.25MCG', u'strength_2': u'', u'substance': u'Alfacalcidol', u'always_empty': u'', u'form': u'CAP', u'brand': u'MINROSET', u'strength_3': u'', u'company': u'Win-Medicare', u'unit': u''}

-- line #713
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,25', u'strength_2': u'1;MCG', u'substance': u'Alfacalcidol', u'always_empty': u'', u'form': u'CAP', u'brand': u'ONE ALPHA', u'strength_3': u'', u'company': u'RANBAXY(CONSUMER HC)', u'unit': u''}

-- line #714
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.25MCG', u'strength_2': u'', u'substance': u'Alfacalcidol', u'always_empty': u'', u'form': u'TAB', u'brand': u'ONE ALPHA', u'strength_3': u'', u'company': u'Croslands', u'unit': u''}

-- line #715
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1MCG', u'strength_2': u'', u'substance': u'Alfacalcidol', u'always_empty': u'', u'form': u'TAB', u'brand': u'ONE ALPHA', u'strength_3': u'', u'company': u'Croslands', u'unit': u''}

-- line #716
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.25MCG', u'strength_2': u'', u'substance': u'Alfacalcidol', u'always_empty': u'', u'form': u'CAP', u'brand': u'QTR ALFA', u'strength_3': u'', u'company': u'Wallace', u'unit': u''}

-- line #717
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALFOO 10 (Dr.Reddy''S)',
	'ALFUZOSIN HCL.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALFOO 10 (Dr.Reddy''S)'
);

-- line #718
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALFUSIN 10 (Cipla)',
	'ALFUZOSIN HCL.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALFUSIN 10 (Cipla)'
);

-- line #719
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATFUL 10 (EMCURE)',
	'ALFUZOSIN HCL.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATFUL 10 (EMCURE)'
);

-- line #720
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EFZU 10 (OVERSEAS MED.)',
	'ALFUZOSIN HCL.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EFZU 10 (OVERSEAS MED.)'
);

-- line #721
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUAL 10 (Alkem)',
	'ALFUZOSIN HCL.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUAL 10 (Alkem)'
);

-- line #722
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FULFLO 10 (Alembic)',
	'ALFUZOSIN HCL.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FULFLO 10 (Alembic)'
);

-- line #723
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROFUZO 10 (NEISS)',
	'ALFUZOSIN HCL.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROFUZO 10 (NEISS)'
);

-- line #724
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RASILEZ 150 (Novartis)',
	'ALISKIREN',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RASILEZ 150 (Novartis)'
);

-- line #725
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RASILEZ 300 (Novartis)',
	'ALISKIREN',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RASILEZ 300 (Novartis)'
);

-- line #726
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MASSE 2 (Ethnor)',
	'Allantoin',
	'CRM',
	gm.nullify_empty_string('2')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MASSE 2 (Ethnor)'
);

-- line #727
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALIGOUT 100 (Finecure)',
	'Allopurinol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALIGOUT 100 (Finecure)'
);

-- line #728
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALLGORIC 100 (Kamron)',
	'Allopurinol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALLGORIC 100 (Kamron)'
);

-- line #729
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALLORIC 100 (Parasol)',
	'Allopurinol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALLORIC 100 (Parasol)'
);

-- line #730
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALORIC 100 (INTAS)',
	'Allopurinol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALORIC 100 (INTAS)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALORIC 300 (INTAS)',
	'Allopurinol',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALORIC 300 (INTAS)'
);

-- line #731
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVERY 100 (Organic Lab)',
	'Allopurinol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVERY 100 (Organic Lab)'
);

-- line #732
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPLORIC 100 (Cipla)',
	'Allopurinol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPLORIC 100 (Cipla)'
);

-- line #733
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPLORIC 300 (Cipla)',
	'Allopurinol',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPLORIC 300 (Cipla)'
);

-- line #734
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYNOL 100 (Dynamic)',
	'Allopurinol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYNOL 100 (Dynamic)'
);

-- line #735
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EDORIN 100 (CONDOR(EDRIC))',
	'Allopurinol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'300'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EDORIN 100 (CONDOR(EDRIC))'
);

-- line #736
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GUDLORIC-100 100 (Mankind)',
	'Allopurinol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GUDLORIC-100 100 (Mankind)'
);

-- line #737
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GURIK 100 (Zee Lab)',
	'Allopurinol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GURIK 100 (Zee Lab)'
);

-- line #738
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LODIRIC 250 (Novartis)',
	'Allopurinol',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LODIRIC 250 (Novartis)'
);

-- line #739
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LODIRIC 100 (Novartis)',
	'Allopurinol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LODIRIC 100 (Novartis)'
);

-- line #740
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOGOUT 250 (Inga)',
	'Allopurinol',
	'CR CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOGOUT 250 (Inga)'
);

-- line #741
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOGOUT 250 (Inga)',
	'Allopurinol',
	'SR CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOGOUT 250 (Inga)'
);

-- line #742
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOGOUT 100 (Inga)',
	'Allopurinol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOGOUT 100 (Inga)'
);

-- line #743
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Allopurinol', u'always_empty': u'', u'form': u'TAB', u'brand': u'LOPNOL', u'strength_3': u'', u'company': u'WEST COAST', u'unit': u''}

-- line #744
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PURINOL 100 (HANBURYS)',
	'Allopurinol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'300'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PURINOL 100 (HANBURYS)'
);

-- line #745
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALESE 5 (Zee Lab)',
	'Allyloestrenol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALESE 5 (Zee Lab)'
);

-- line #746
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALLYNOL 5 (VHB)',
	'Allyloestrenol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALLYNOL 5 (VHB)'
);

-- line #747
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALLYTRY 5 (Intra Lab)',
	'Allyloestrenol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALLYTRY 5 (Intra Lab)'
);

-- line #748
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALNOL 5 (ROSE LABS)',
	'Allyloestrenol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALNOL 5 (ROSE LABS)'
);

-- line #749
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANIN 5 (Ind-Swift)',
	'Allyloestrenol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANIN 5 (Ind-Swift)'
);

-- line #750
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASTANOL 5 (Rekvina)',
	'Allyloestrenol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASTANOL 5 (Rekvina)'
);

-- line #751
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASTRANAL 5 (Stanmark)',
	'Allyloestrenol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASTRANAL 5 (Stanmark)'
);

-- line #752
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ECOGEST 5 (Taurus Lab)',
	'Allyloestrenol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ECOGEST 5 (Taurus Lab)'
);

-- line #753
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FETUGARD 5 (Gsk)',
	'Allyloestrenol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FETUGARD 5 (Gsk)'
);

-- line #754
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FULTERM 5 (Micro Nova)',
	'Allyloestrenol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FULTERM 5 (Micro Nova)'
);

-- line #755
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GESTIN 5 (Walter B.)',
	'Allyloestrenol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GESTIN 5 (Walter B.)'
);

-- line #756
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRAVIDA 5 (Evacare)',
	'Allyloestrenol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRAVIDA 5 (Evacare)'
);

-- line #757
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRAVIDIN 5 (Zydus A.)',
	'Allyloestrenol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRAVIDIN 5 (Zydus A.)'
);

-- line #758
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRAVINOL 5 (Corolla(Triton))',
	'Allyloestrenol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRAVINOL 5 (Corolla(Triton))'
);

-- line #759
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GYANAETONE 5 (Parasol)',
	'Allyloestrenol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GYANAETONE 5 (Parasol)'
);

-- line #760
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GYNEROL 5 (Intra(INVISION))',
	'Allyloestrenol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GYNEROL 5 (Intra(INVISION))'
);

-- line #761
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GYNONYS 5 (Uni-Sank.)',
	'Allyloestrenol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GYNONYS 5 (Uni-Sank.)'
);

-- line #762
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IUGR 5 (Candor Bio.)',
	'Allyloestrenol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IUGR 5 (Candor Bio.)'
);

-- line #763
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAINTANE 5 (Jagsonpal)',
	'Allyloestrenol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAINTANE 5 (Jagsonpal)'
);

-- line #764
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIDAGEST 5 (Systopic)',
	'Allyloestrenol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIDAGEST 5 (Systopic)'
);

-- line #765
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIDANOL 5 (Unicure)',
	'Allyloestrenol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIDANOL 5 (Unicure)'
);

-- line #766
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGMAIN 5 (Symbiosis Lab.)',
	'Allyloestrenol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGMAIN 5 (Symbiosis Lab.)'
);

-- line #767
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGULAR 5 (Helios Ph.)',
	'Allyloestrenol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGULAR 5 (Helios Ph.)'
);

-- line #768
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROFAR 25 (Infar)',
	'Allyloestrenol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROFAR 25 (Infar)'
);

-- line #769
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROFER 25 (Organon)',
	'Allyloestrenol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROFER 25 (Organon)'
);

-- line #770
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROGYN 5 (G.C.M. Lab)',
	'Allyloestrenol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROGYN 5 (G.C.M. Lab)'
);

-- line #771
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROPEG 5 (Unimarck)',
	'Allyloestrenol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROPEG 5 (Unimarck)'
);

-- line #772
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'8', u'strength_2': u'', u'substance': u'ALMOND OIL', u'always_empty': u'', u'form': u'', u'brand': u'CETAPHIL BAR', u'strength_3': u'', u'company': u'Galderma', u'unit': u'%'}

-- line #773
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JULA 50 (Fem care)',
	'Aloe Extract',
	'GEL',
	gm.nullify_empty_string('50')::numeric,
	'%W/W(JUICE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JULA 50 (Fem care)'
);

-- line #774
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALOVEN 10 (VENSAT)',
	'ALOE VERA',
	'CRM',
	gm.nullify_empty_string('10')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALOVEN 10 (VENSAT)'
);

-- line #775
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'CALAMINE 8 ', u' %', u'IN A MOISHIRING LOTION BASE CONTAINING DIMETHICONE & OLIVEM-800)', u'', u'', u'', u'', u'', u''], u'strength_1': u'10', u'strength_2': u'', u'substance': u'ALOE VERA GEL', u'always_empty': u'', u'form': u'', u'brand': u'ALLSUTH', u'strength_3': u'', u'company': u'Ipca', u'unit': u'% W/W( LIGHT LIQUID PARAFFIN 10'}

-- line #776
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DERMADEW CALOE 10 (H & H)',
	'ALOE VERA GEL',
	'LOT',
	gm.nullify_empty_string('10')::numeric,
	'% W/W( LIGHT LIQUID PARAFFIN 10'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DERMADEW CALOE 10 (H & H)'
);

-- line #777
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANSTAL 150 (Cipla)',
	'Alpha Amylase',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANSTAL 150 (Cipla)'
);

-- line #778
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GALAZYME-A 150 (Intra Lab)',
	'ALPHA GALACTOSIDASE',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GALAZYME-A 150 (Intra Lab)'
);

-- line #779
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GALTO 150 (Ordain Hc.)',
	'ALPHA GALACTOSIDASE',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GALTO 150 (Ordain Hc.)'
);

-- line #780
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50U.', u'strength_2': u'ML', u'substance': u'ALPHA GALACTOSIDASE', u'always_empty': u'', u'form': u'DPS', u'brand': u'LENO', u'strength_3': u'', u'company': u'Bestochem', u'unit': u''}

-- line #781
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LENO 150 (Bestochem)',
	'ALPHA GALACTOSIDASE',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LENO 150 (Bestochem)'
);

-- line #782
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'ALPHA KETO AMINO ACIDS', u'always_empty': u'', u'form': u'TAB', u'brand': u'RENOLOG', u'strength_3': u'', u'company': u'LA RENON', u'unit': u''}

-- line #783
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALA-100 100 (Alembic)',
	'Alpha Lipioic Acid',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALA-100 100 (Alembic)'
);

-- line #784
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALADIN 100 (Dr.Reddy''S)',
	'Alpha Lipioic Acid',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALADIN 100 (Dr.Reddy''S)'
);

-- line #785
-- ignoring line: field [strength_1] not numeric: >>>WITH MULTIVITAMIN<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'WITH MULTIVITAMIN', u'strength_2': u'', u'substance': u'Alpha Lipioic Acid', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALPHA CAD', u'strength_3': u'', u'company': u'SHRRISHTI HC.', u'unit': u'MULTIMINERAL'}

-- line #786
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPOCID 100 (Mano Ph.)',
	'Alpha Lipioic Acid',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPOCID 100 (Mano Ph.)'
);

-- line #787
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGALA 100 (SOFT HEALTH)',
	'Alpha Lipioic Acid',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGALA 100 (SOFT HEALTH)'
);

-- line #788
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AALP 0.25 (Medopharm)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AALP 0.25 (Medopharm)'
);

-- line #789
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AALP 0.5 (Medopharm)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AALP 0.5 (Medopharm)'
);

-- line #790
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AALP 1 (Medopharm)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AALP 1 (Medopharm)'
);

-- line #791
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AARAM 0.25 (Dcm Lab)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AARAM 0.25 (Dcm Lab)'
);

-- line #792
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALAM 0.5 (Rhombus)',
	'Alprazolam',
	'SR TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALAM 0.5 (Rhombus)'
);

-- line #793
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALAP 0.25 (Argus)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALAP 0.25 (Argus)'
);

-- line #794
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALAP 0.5 (Argus)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALAP 0.5 (Argus)'
);

-- line #795
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALARK 0.25 (Lanark)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALARK 0.25 (Lanark)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALARK 0.5 (Lanark)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALARK 0.5 (Lanark)'
);

-- line #796
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALARM 0.5 (Auroma Life)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALARM 0.5 (Auroma Life)'
);

-- line #797
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALEEZ 0.25 (Alde Medi.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALEEZ 0.25 (Alde Medi.)'
);

-- line #798
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALEEZ 0.5 (Alde Medi.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALEEZ 0.5 (Alde Medi.)'
);

-- line #799
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALEEZ 1 (Alde Medi.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALEEZ 1 (Alde Medi.)'
);

-- line #800
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALEP 0.5 (D.R.John''S)',
	'Alprazolam',
	'SR TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALEP 0.5 (D.R.John''S)'
);

-- line #801
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALEP 1 (D.R.John''S)',
	'Alprazolam',
	'SR TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALEP 1 (D.R.John''S)'
);

-- line #802
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALEP 0.25 (D.R.John''S)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALEP 0.25 (D.R.John''S)'
);

-- line #803
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALEP 1 (D.R.John''S)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALEP 1 (D.R.John''S)'
);

-- line #804
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALEP 5 (D.R.John''S)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALEP 5 (D.R.John''S)'
);

-- line #805
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALLTOP 0.25 (Ind-Swift)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALLTOP 0.25 (Ind-Swift)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALLTOP 1 (Ind-Swift)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALLTOP 1 (Ind-Swift)'
);

-- line #806
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALORA 0.5 (SHINE PH.)',
	'Alprazolam',
	'SR TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALORA 0.5 (SHINE PH.)'
);

-- line #807
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALORA 0.25 (SHINE PH.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALORA 0.25 (SHINE PH.)'
);

-- line #808
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALORA 0.5 (SHINE PH.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALORA 0.5 (SHINE PH.)'
);

-- line #809
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPAM 0.25 (Arbro Ph.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPAM 0.25 (Arbro Ph.)'
);

-- line #810
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPAM 0.5 (Arbro Ph.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPAM 0.5 (Arbro Ph.)'
);

-- line #811
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPAM 0.5 (Biocia Hc.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPAM 0.5 (Biocia Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPAM 1.5 (Biocia Hc.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPAM 1.5 (Biocia Hc.)'
);

-- line #812
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPAM 0.25 (Orison Ph.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPAM 0.25 (Orison Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPAM 0.5 (Orison Ph.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPAM 0.5 (Orison Ph.)'
);

-- line #813
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPAM 0.25 (Saga Lab)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPAM 0.25 (Saga Lab)'
);

-- line #814
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPAM 0.5 (Saga Lab)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPAM 0.5 (Saga Lab)'
);

-- line #815
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPAZ 0.5 (Morepen)',
	'Alprazolam',
	'SR TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPAZ 0.5 (Morepen)'
);

-- line #816
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPAZ 1.5 (Morepen)',
	'Alprazolam',
	'SR TAB',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPAZ 1.5 (Morepen)'
);

-- line #817
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPAZ 1 (Morepen)',
	'Alprazolam',
	'SR TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPAZ 1 (Morepen)'
);

-- line #818
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPAZ 0.25 (Rhombus)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPAZ 0.25 (Rhombus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPAZ 0.5 (Rhombus)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPAZ 0.5 (Rhombus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPAZ 1 (Rhombus)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPAZ 1 (Rhombus)'
);

-- line #819
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPICALM 0.25 (Norris Med.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPICALM 0.25 (Norris Med.)'
);

-- line #820
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPICALM 0.5 (Norris Med.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPICALM 0.5 (Norris Med.)'
);

-- line #821
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPOSE 0.25 (Osper)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPOSE 0.25 (Osper)'
);

-- line #822
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPOSE 0.5 (Osper)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPOSE 0.5 (Osper)'
);

-- line #823
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPRACONTIN 0.5 (Modi Mundi)',
	'Alprazolam',
	'CR TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPRACONTIN 0.5 (Modi Mundi)'
);

-- line #824
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPRADOL 0.25 (Skymax)',
	'Alprazolam',
	'MD TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPRADOL 0.25 (Skymax)'
);

-- line #825
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPRADOL 0.5 (Skymax)',
	'Alprazolam',
	'MD TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPRADOL 0.5 (Skymax)'
);

-- line #826
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPRAM 0.25 (Sain Med.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPRAM 0.25 (Sain Med.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPRAM 0.5 (Sain Med.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPRAM 0.5 (Sain Med.)'
);

-- line #827
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPRAM 0.25 (Trio Rem.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPRAM 0.25 (Trio Rem.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPRAM 0.5 (Trio Rem.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPRAM 0.5 (Trio Rem.)'
);

-- line #828
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPRAQUIL 0.25 (Lupin)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPRAQUIL 0.25 (Lupin)'
);

-- line #829
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPRAQUIL 0.5 (Lupin)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPRAQUIL 0.5 (Lupin)'
);

-- line #830
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPRAQUIL 1 (Lupin)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPRAQUIL 1 (Lupin)'
);

-- line #831
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPRA 0.25 (Avalanche)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPRA 0.25 (Avalanche)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPRA 0.5 (Avalanche)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPRA 0.5 (Avalanche)'
);

-- line #832
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPRAX 0.125 (TORRENT)',
	'Alprazolam',
	'MT TAB',
	gm.nullify_empty_string('0.125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPRAX 0.125 (TORRENT)'
);

-- line #833
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPRAX 0.25 (TORRENT)',
	'Alprazolam',
	'MT TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPRAX 0.25 (TORRENT)'
);

-- line #834
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPRAX 0.5 (TORRENT)',
	'Alprazolam',
	'MT TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPRAX 0.5 (TORRENT)'
);

-- line #835
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPRAX 0.5 (Torrent)',
	'Alprazolam',
	'SR TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPRAX 0.5 (Torrent)'
);

-- line #836
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPRAX 1.5 (Torrent)',
	'Alprazolam',
	'SR TAB',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPRAX 1.5 (Torrent)'
);

-- line #837
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPRAX 1 (Torrent)',
	'Alprazolam',
	'SR TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPRAX 1 (Torrent)'
);

-- line #838
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPRAX 0.25 (Torrent)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPRAX 0.25 (Torrent)'
);

-- line #839
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPRAX 0.5 (Torrent)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPRAX 0.5 (Torrent)'
);

-- line #840
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPRAX 1 (Torrent)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPRAX 1 (Torrent)'
);

-- line #841
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPRAZOL 0.25 (Theo Ph.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPRAZOL 0.25 (Theo Ph.)'
);

-- line #842
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPRAZOL 0.5 (Theo Ph.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPRAZOL 0.5 (Theo Ph.)'
);

-- line #843
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPRAZOL 1 (Theo Ph.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPRAZOL 1 (Theo Ph.)'
);

-- line #844
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPRAZONE 0.25 (Ozone Ph.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPRAZONE 0.25 (Ozone Ph.)'
);

-- line #845
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPRAZONE 0.25 (OZONE PH.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPRAZONE 0.25 (OZONE PH.)'
);

-- line #846
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPRAZONE 0.5 (Ozone Ph.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPRAZONE 0.5 (Ozone Ph.)'
);

-- line #847
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPRAZ 0.25 (Dynamic)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPRAZ 0.25 (Dynamic)'
);

-- line #848
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPRAZ 0.5 (Dynamic)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPRAZ 0.5 (Dynamic)'
);

-- line #849
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPROCALM 0.25 (Hitech Form.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPROCALM 0.25 (Hitech Form.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPROCALM 0.5 (Hitech Form.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPROCALM 0.5 (Hitech Form.)'
);

-- line #850
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPROCONTIN 0.5 (Modi Mundi)',
	'Alprazolam',
	'CR TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPROCONTIN 0.5 (Modi Mundi)'
);

-- line #851
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPROCONTIN 1.5 (Modi Mundi)',
	'Alprazolam',
	'CR TAB',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPROCONTIN 1.5 (Modi Mundi)'
);

-- line #852
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPROCONTIN 1 (Modi Mundi)',
	'Alprazolam',
	'CR TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPROCONTIN 1 (Modi Mundi)'
);

-- line #853
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPROENAR 0.25 (Modi Mundi)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPROENAR 0.25 (Modi Mundi)'
);

-- line #854
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPROENAR 0.5 (Modi Mundi)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPROENAR 0.5 (Modi Mundi)'
);

-- line #855
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPROMAN 0.25 (Shalman)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPROMAN 0.25 (Shalman)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPROMAN 0.5 (Shalman)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPROMAN 0.5 (Shalman)'
);

-- line #856
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPRORON 0.25 (Ronak Lab.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPRORON 0.25 (Ronak Lab.)'
);

-- line #857
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPRORON 0.5 (Ronak Lab.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPRORON 0.5 (Ronak Lab.)'
);

-- line #858
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPROSE 0.25 (Pharma synth)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPROSE 0.25 (Pharma synth)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPROSE 0.5 (Pharma synth)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPROSE 0.5 (Pharma synth)'
);

-- line #859
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPROSE 0.25 (Vivid Lab)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPROSE 0.25 (Vivid Lab)'
);

-- line #860
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPROSE 0.5 (Vivid Lab)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPROSE 0.5 (Vivid Lab)'
);

-- line #861
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPROTAME 0.25 (Bipl(Radico Lab))',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPROTAME 0.25 (Bipl(Radico Lab))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPROTAME 0.5 (Bipl(Radico Lab))',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPROTAME 0.5 (Bipl(Radico Lab))'
);

-- line #862
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPROZ 0.25 (Patson)',
	'ALPRAZOLAM',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPROZ 0.25 (Patson)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPROZ 0.5 (Patson)',
	'ALPRAZOLAM',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPROZ 0.5 (Patson)'
);

-- line #863
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALP 0.5 (KIVI HC.)',
	'Alprazolam',
	'SR TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALP 0.5 (KIVI HC.)'
);

-- line #864
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALP 0.25 (CASCA)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALP 0.25 (CASCA)'
);

-- line #865
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALP 0.5 (CASCA)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALP 0.5 (CASCA)'
);

-- line #866
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPVIRAM 0.5 (Parasol)',
	'Alprazolam',
	'SR TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPVIRAM 0.5 (Parasol)'
);

-- line #867
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPVIRAM 0.25 (Parasol)',
	'ALPRAZOLAM',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPVIRAM 0.25 (Parasol)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPVIRAM 0.5 (Parasol)',
	'ALPRAZOLAM',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPVIRAM 0.5 (Parasol)'
);

-- line #868
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALREST 0.25 (AXYZEN LIFE)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALREST 0.25 (AXYZEN LIFE)'
);

-- line #869
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALREST 0.5 (AXYZEN LIFE)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALREST 0.5 (AXYZEN LIFE)'
);

-- line #870
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALRIF 0.25 (Intra Lab)',
	'ALPRAZOLAM',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALRIF 0.25 (Intra Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALRIF 0.5 (Intra Lab)',
	'ALPRAZOLAM',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALRIF 0.5 (Intra Lab)'
);

-- line #871
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALRIF 1 (Intra Lab)',
	'ALPRAZOLAM',
	'XR TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALRIF 1 (Intra Lab)'
);

-- line #872
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALTAUR 0.25 (Taurus Lab)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALTAUR 0.25 (Taurus Lab)'
);

-- line #873
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALTAUR 0.5 (Taurus Lab)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALTAUR 0.5 (Taurus Lab)'
);

-- line #874
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZAC 0.25 (Franklin)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZAC 0.25 (Franklin)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZAC 0.5 (Franklin)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZAC 0.5 (Franklin)'
);

-- line #875
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZETP 0.25 (Taurus Lab)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZETP 0.25 (Taurus Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZETP 0.5 (Taurus Lab)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZETP 0.5 (Taurus Lab)'
);

-- line #876
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZEX 0.5 (Pil)',
	'Alprazolam',
	'SR TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZEX 0.5 (Pil)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZEX 1 (Pil)',
	'Alprazolam',
	'SR TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZEX 1 (Pil)'
);

-- line #877
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZEX 0.25 (Pil)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZEX 0.25 (Pil)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZEX 0.5 (Pil)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZEX 0.5 (Pil)'
);

-- line #878
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZEX 0.25 (Taurus Lab)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZEX 0.25 (Taurus Lab)'
);

-- line #879
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZEX 0.5 (Taurus Lab)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZEX 0.5 (Taurus Lab)'
);

-- line #880
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZIM 0.25 (Kim Lab)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZIM 0.25 (Kim Lab)'
);

-- line #881
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZOACT 0.25 (Active Hc.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZOACT 0.25 (Active Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZOACT 0.5 (Active Hc.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZOACT 0.5 (Active Hc.)'
);

-- line #882
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZOCUM 0.25 (TAJ PH.)',
	'Alprazolam',
	'SR TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg/0.5'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZOCUM 0.25 (TAJ PH.)'
);

-- line #883
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZOCUM 0.5 (TAJ PH.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg/1'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZOCUM 0.5 (TAJ PH.)'
);

-- line #884
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZOFT 0.25 (Allure Rem.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZOFT 0.25 (Allure Rem.)'
);

-- line #885
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZOKAM 0.5 (BARODA)',
	'Alprazolam',
	'SR TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZOKAM 0.5 (BARODA)'
);

-- line #886
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZOKAM 1 (BARODA)',
	'Alprazolam',
	'SR TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZOKAM 1 (BARODA)'
);

-- line #887
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZOKAM 0.25 (BARODA)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZOKAM 0.25 (BARODA)'
);

-- line #888
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZOKAM 0.5 (BARODA)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZOKAM 0.5 (BARODA)'
);

-- line #889
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZOLAM 0.5 (Sun)',
	'Alprazolam',
	'SR TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZOLAM 0.5 (Sun)'
);

-- line #890
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZOLAM 1.5 (Sun)',
	'Alprazolam',
	'SR TAB',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZOLAM 1.5 (Sun)'
);

-- line #891
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZOLAM 1 (Sun)',
	'Alprazolam',
	'SR TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZOLAM 1 (Sun)'
);

-- line #892
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZOLAM 0.125 (Sun)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZOLAM 0.125 (Sun)'
);

-- line #893
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZOLAM 0.25 (Sun)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg/0.5'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZOLAM 0.25 (Sun)'
);

-- line #894
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZOLAM 1 (Sun)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZOLAM 1 (Sun)'
);

-- line #895
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZOMAX 0.25 (Kamron)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZOMAX 0.25 (Kamron)'
);

-- line #896
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZOMAX 0.5 (Kamron)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZOMAX 0.5 (Kamron)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZOMAX 1 (Kamron)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZOMAX 1 (Kamron)'
);

-- line #897
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZOMIL 0.25 (Shaimil)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZOMIL 0.25 (Shaimil)'
);

-- line #898
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZOMIL 0.5 (Shaimil)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZOMIL 0.5 (Shaimil)'
);

-- line #899
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,25', u'strength_2': u'', u'substance': u'Alprazolam', u'always_empty': u'', u'form': u'', u'brand': u'ALZONE', u'strength_3': u'', u'company': u'NIVCA', u'unit': u'mg'}

-- line #900
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,5', u'strength_2': u'', u'substance': u'Alprazolam', u'always_empty': u'', u'form': u'', u'brand': u'ALZONE', u'strength_3': u'', u'company': u'NIVCA', u'unit': u'mg'}

-- line #901
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZONEX 0.25 (Marc Lab)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZONEX 0.25 (Marc Lab)'
);

-- line #902
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZONEX 0.5 (Marc Lab)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZONEX 0.5 (Marc Lab)'
);

-- line #903
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZONEX 1 (Marc Lab)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZONEX 1 (Marc Lab)'
);

-- line #904
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZOPAX 1.5 (LA DRUG)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZOPAX 1.5 (LA DRUG)'
);

-- line #905
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZOPAX 0.25 (LA PHARMA)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZOPAX 0.25 (LA PHARMA)'
);

-- line #906
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZOPAX 0.5 (LA PHARMA)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZOPAX 0.5 (LA PHARMA)'
);

-- line #907
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZOPAX 1 (LA PHARMA)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZOPAX 1 (LA PHARMA)'
);

-- line #908
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZOPAX 0.5 (LA PHARMA)',
	'Alprazolam',
	'XR TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZOPAX 0.5 (LA PHARMA)'
);

-- line #909
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZOPAX 1 (LA PHARMA)',
	'Alprazolam',
	'XR TAB',
	gm.nullify_empty_string('1')::numeric,
	'1.5'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZOPAX 1 (LA PHARMA)'
);

-- line #910
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZO 0.25 (Ochoa)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZO 0.25 (Ochoa)'
);

-- line #911
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZO 0.5 (Ochoa)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZO 0.5 (Ochoa)'
);

-- line #912
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZOT 0.5 (Pifer Ph.)',
	'Alprazolam',
	'SR TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZOT 0.5 (Pifer Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZOT 1 (Pifer Ph.)',
	'Alprazolam',
	'SR TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZOT 1 (Pifer Ph.)'
);

-- line #913
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZOT 1.5 (Pifer Ph.)',
	'Alprazolam',
	'SR TAB',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZOT 1.5 (Pifer Ph.)'
);

-- line #914
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZY-1 1 (OREVA DARMO.)',
	'Alprazolam',
	'SR TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZY-1 1 (OREVA DARMO.)'
);

-- line #915
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZY 0.25 (Zee Lab)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZY 0.25 (Zee Lab)'
);

-- line #916
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZY 0.5 (Zee Lab)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZY 0.5 (Zee Lab)'
);

-- line #917
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANAX 0.25 (Cachet)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANAX 0.25 (Cachet)'
);

-- line #918
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANAX 0.5 (Cachet)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANAX 0.5 (Cachet)'
);

-- line #919
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANDEP 0.25 (Ravian)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANDEP 0.25 (Ravian)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANDEP 0.5 (Ravian)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANDEP 0.5 (Ravian)'
);

-- line #920
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANTENA 0.25 (Cosmos Rem.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANTENA 0.25 (Cosmos Rem.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANTENA 0.5 (Cosmos Rem.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANTENA 0.5 (Cosmos Rem.)'
);

-- line #921
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANXERON 0.25 (TWILIGHT LIT.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANXERON 0.25 (TWILIGHT LIT.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANXERON 0.5 (TWILIGHT LIT.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANXERON 0.5 (TWILIGHT LIT.)'
);

-- line #922
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANXICALM 0.25 (Lupin)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANXICALM 0.25 (Lupin)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANXICALM 0.5 (Lupin)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANXICALM 0.5 (Lupin)'
);

-- line #923
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANXICARE 0.25 (Kee Ph.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANXICARE 0.25 (Kee Ph.)'
);

-- line #924
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANXICARE 0.5 (Kee Ph.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANXICARE 0.5 (Kee Ph.)'
);

-- line #925
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANXICARE 1 (Kee Ph.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANXICARE 1 (Kee Ph.)'
);

-- line #926
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANXICO 0.25 (Aglowmed)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANXICO 0.25 (Aglowmed)'
);

-- line #927
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANXIGON 0.25 (Blue Cross)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANXIGON 0.25 (Blue Cross)'
);

-- line #928
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANXIGON 0.5 (Blue Cross)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANXIGON 0.5 (Blue Cross)'
);

-- line #929
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANXIGON 1 (Blue Cross)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANXIGON 1 (Blue Cross)'
);

-- line #930
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANXIOFF 0.25 (GH PH.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANXIOFF 0.25 (GH PH.)'
);

-- line #931
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANXIPRESS 0.25 (ARCUS LABS)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANXIPRESS 0.25 (ARCUS LABS)'
);

-- line #932
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANXIPRESS 0.5 (ARCUS LABS)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANXIPRESS 0.5 (ARCUS LABS)'
);

-- line #933
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANXIT 0.5 (Micro Labs)',
	'Alprazolam',
	'SR TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANXIT 0.5 (Micro Labs)'
);

-- line #934
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANXIT 1.5 (Synapse)',
	'Alprazolam',
	'SR TAB',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANXIT 1.5 (Synapse)'
);

-- line #935
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANXIT 1 (Synapse)',
	'Alprazolam',
	'SR TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANXIT 1 (Synapse)'
);

-- line #936
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANXIT 0.25 (Micro Labs)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANXIT 0.25 (Micro Labs)'
);

-- line #937
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANXIT 0.5 (Micro Labs)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANXIT 0.5 (Micro Labs)'
);

-- line #938
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANXIT 1 (Micro Labs)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANXIT 1 (Micro Labs)'
);

-- line #939
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANXOREL 0.5 (Life Med.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANXOREL 0.5 (Life Med.)'
);

-- line #940
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANXO 0.25 (Green Cross)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANXO 0.25 (Green Cross)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANXO 0.5 (Green Cross)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANXO 0.5 (Green Cross)'
);

-- line #941
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANXYL 0.25 (Waves Bio.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANXYL 0.25 (Waves Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANXYL 0.5 (Waves Bio.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANXYL 0.5 (Waves Bio.)'
);

-- line #942
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANZILUM 1.5 (Irm Ph.)',
	'Alprazolam',
	'SR TAB',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANZILUM 1.5 (Irm Ph.)'
);

-- line #943
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANZILUM 0.25 (Cadila Ph.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANZILUM 0.25 (Cadila Ph.)'
);

-- line #944
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANZILUM 0.5 (Cadila Ph.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANZILUM 0.5 (Cadila Ph.)'
);

-- line #945
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANZILUM 1 (Cadila Ph.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANZILUM 1 (Cadila Ph.)'
);

-- line #946
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANZI 0.5 (AZINE HC.)',
	'Alprazolam',
	'SR TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANZI 0.5 (AZINE HC.)'
);

-- line #947
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANZI 0.25 (Azime Hc.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANZI 0.25 (Azime Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANZI 0.5 (Azime Hc.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANZI 0.5 (Azime Hc.)'
);

-- line #948
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANZI 0.5 (Azime Hc.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANZI 0.5 (Azime Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANZI 1 (Azime Hc.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANZI 1 (Azime Hc.)'
);

-- line #949
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATAM 0.25 (Atoz Ph.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATAM 0.25 (Atoz Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATAM 0.5 (Atoz Ph.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATAM 0.5 (Atoz Ph.)'
);

-- line #950
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATREST 0.25 (Centaur)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATREST 0.25 (Centaur)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATREST 0.5 (Centaur)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATREST 0.5 (Centaur)'
);

-- line #951
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATSLEEP 0.25 (ATOPIC LAB.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATSLEEP 0.25 (ATOPIC LAB.)'
);

-- line #952
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATSLEEP 0.5 (ATOPIC LAB.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATSLEEP 0.5 (ATOPIC LAB.)'
);

-- line #953
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZELAM 0.25 (ABLAZE HC)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZELAM 0.25 (ABLAZE HC)'
);

-- line #954
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZELAM 0.5 (ABLAZE HC)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZELAM 0.5 (ABLAZE HC)'
);

-- line #955
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZOX 0.25 (Aarpik Ph.)',
	'Alprazolam',
	'SR TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZOX 0.25 (Aarpik Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZOX 0.5 (Aarpik Ph.)',
	'Alprazolam',
	'SR TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZOX 0.5 (Aarpik Ph.)'
);

-- line #956
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZOX 0.25 (Aarpik Ph.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZOX 0.25 (Aarpik Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZOX 0.5 (Aarpik Ph.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZOX 0.5 (Aarpik Ph.)'
);

-- line #957
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BALMUSA-D 0.5 (Panzer Ph.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BALMUSA-D 0.5 (Panzer Ph.)'
);

-- line #958
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BALMUSA 0.25 (Symbiotic)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BALMUSA 0.25 (Symbiotic)'
);

-- line #959
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENZOLAM 0.5 (Paras Lab)',
	'Alprazolam',
	'F. TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENZOLAM 0.5 (Paras Lab)'
);

-- line #960
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENZOLAM 0.25 (Medoz Ph.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENZOLAM 0.25 (Medoz Ph.)'
);

-- line #961
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENZOLAM 0.25 (Paras Lab)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENZOLAM 0.25 (Paras Lab)'
);

-- line #962
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BEREST 0.25 (ANVIK BIO.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BEREST 0.25 (ANVIK BIO.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BEREST 0.5 (ANVIK BIO.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BEREST 0.5 (ANVIK BIO.)'
);

-- line #963
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BESQUIL 0.25 (Rextar)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BESQUIL 0.25 (Rextar)'
);

-- line #964
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BESQUIL 0.5 (Rextar)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BESQUIL 0.5 (Rextar)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BESQUIL 1 (Rextar)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BESQUIL 1 (Rextar)'
);

-- line #965
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIO ZOLAM 0.25 (Bio-Drug)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIO ZOLAM 0.25 (Bio-Drug)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIO ZOLAM 0.5 (Bio-Drug)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIO ZOLAM 0.5 (Bio-Drug)'
);

-- line #966
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLIZ 0.25 (GRANDIX)',
	'Alprazolam',
	'MD TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLIZ 0.25 (GRANDIX)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLIZ 0.5 (GRANDIX)',
	'Alprazolam',
	'MD TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLIZ 0.5 (GRANDIX)'
);

-- line #967
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLIZ 1 (GRANDIX)',
	'Alprazolam',
	'MD TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLIZ 1 (GRANDIX)'
);

-- line #968
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRAZO 0.25 (Biocin Hc.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRAZO 0.25 (Biocin Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRAZO 0.5 (Biocin Hc.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRAZO 0.5 (Biocin Hc.)'
);

-- line #969
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIAL 0.25 (Caplet Ind.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIAL 0.25 (Caplet Ind.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIAL 0.5 (Caplet Ind.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIAL 0.5 (Caplet Ind.)'
);

-- line #970
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ECSIT 0.5 (Ecstacy)',
	'Alprazolam',
	'SR TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ECSIT 0.5 (Ecstacy)'
);

-- line #971
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELZOPAM 0.25 (Lancer)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELZOPAM 0.25 (Lancer)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELZOPAM 0.5 (Lancer)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELZOPAM 0.5 (Lancer)'
);

-- line #972
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EURELAX 0.25 (Euphoric)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EURELAX 0.25 (Euphoric)'
);

-- line #973
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EURELAX 0.5 (Euphoric)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EURELAX 0.5 (Euphoric)'
);

-- line #974
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAD 0.5 (Varun Life)',
	'Alprazolam',
	'SR TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAD 0.5 (Varun Life)'
);

-- line #975
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAD 0.25 (Varun Life)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAD 0.25 (Varun Life)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAD 0.5 (Varun Life)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAD 0.5 (Varun Life)'
);

-- line #976
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FINEZOL 0.25 (Finecure)',
	'ALPRAZOLAM',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FINEZOL 0.25 (Finecure)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FINEZOL 0.5 (Finecure)',
	'ALPRAZOLAM',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FINEZOL 0.5 (Finecure)'
);

-- line #977
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FINEZOL 1 (Finecure)',
	'ALPRAZOLAM',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FINEZOL 1 (Finecure)'
);

-- line #978
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GAD 0.25 (ENRICH PH.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GAD 0.25 (ENRICH PH.)'
);

-- line #979
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GAD 0.5 (ENRICH PH.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GAD 0.5 (ENRICH PH.)'
);

-- line #980
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIPOSE 0.5 (Olcare)',
	'Alprazolam',
	'SR TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIPOSE 0.5 (Olcare)'
);

-- line #981
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIPOSE 1 (Olcare)',
	'Alprazolam',
	'SR TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg/1.5'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIPOSE 1 (Olcare)'
);

-- line #982
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIPOSE 0.25 (Olcare)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIPOSE 0.25 (Olcare)'
);

-- line #983
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIPOSE 0.5 (Olcare)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIPOSE 0.5 (Olcare)'
);

-- line #984
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIPOSE 1 (Olcare)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIPOSE 1 (Olcare)'
);

-- line #985
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMPRESS 0.25 (Ferret Int.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMPRESS 0.25 (Ferret Int.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMPRESS 0.5 (Ferret Int.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMPRESS 0.5 (Ferret Int.)'
);

-- line #986
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INSLEEP 0.25 (Indica)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INSLEEP 0.25 (Indica)'
);

-- line #987
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JOLIDAY 0.25 (Mankind)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JOLIDAY 0.25 (Mankind)'
);

-- line #988
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JOLIDAY 0.5 (Mankind)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JOLIDAY 0.5 (Mankind)'
);

-- line #989
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JOLISTAR 0.25 (Mankind)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JOLISTAR 0.25 (Mankind)'
);

-- line #990
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JOLISTAR 0.5 (Mankind)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JOLISTAR 0.5 (Mankind)'
);

-- line #991
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KAPROLAM 0.25 (Kapl)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KAPROLAM 0.25 (Kapl)'
);

-- line #992
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KAPROLAM 0.5 (Kapl)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KAPROLAM 0.5 (Kapl)'
);

-- line #993
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAM 0.5 (TASMED)',
	'Alprazolam',
	'LA TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAM 0.5 (TASMED)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAM 1 (TASMED)',
	'Alprazolam',
	'LA TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAM 1 (TASMED)'
);

-- line #994
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAM 1.5 (TASMED)',
	'Alprazolam',
	'LA TAB',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAM 1.5 (TASMED)'
);

-- line #995
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAM 0.25 (TASMED)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAM 0.25 (TASMED)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAM 0.5 (TASMED)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAM 0.5 (TASMED)'
);

-- line #996
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LENIT 0.25 (Lenit Ph.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LENIT 0.25 (Lenit Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LENIT 0.5 (Lenit Ph.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LENIT 0.5 (Lenit Ph.)'
);

-- line #997
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORAL 0.5 (Captab)',
	'Alprazolam',
	'SR TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORAL 0.5 (Captab)'
);

-- line #998
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORAL 0.25 (Captab)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORAL 0.25 (Captab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORAL 0.5 (Captab)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORAL 0.5 (Captab)'
);

-- line #999
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'L-PEEZ 0.25 (VHB)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'L-PEEZ 0.25 (VHB)'
);

-- line #1000
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'L-PEEZ 0.5 (VHB)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'L-PEEZ 0.5 (VHB)'
);

-- line #1001
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUZARN 0.25 (Emcure)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUZARN 0.25 (Emcure)'
);

-- line #1002
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUZARN 0.5 (Emcure)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUZARN 0.5 (Emcure)'
);

-- line #1003
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOREST 0.5 (Mano)',
	'Alprazolam',
	'SR TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOREST 0.5 (Mano)'
);

-- line #1004
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOREST 1 (Mano)',
	'Alprazolam',
	'SR TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOREST 1 (Mano)'
);

-- line #1005
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOREST 0.25 (Mano)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOREST 0.25 (Mano)'
);

-- line #1006
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOREST 0.5 (Mano)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOREST 0.5 (Mano)'
);

-- line #1007
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOREST 0.75 (Mano)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOREST 0.75 (Mano)'
);

-- line #1008
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOREST 1 (Mano)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOREST 1 (Mano)'
);

-- line #1009
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MENTACALM 0.25 (Ornate Lab)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MENTACALM 0.25 (Ornate Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MENTACALM 0.5 (Ornate Lab)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MENTACALM 0.5 (Ornate Lab)'
);

-- line #1010
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOD-ZOLAM 0.5 (MODHIKE)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOD-ZOLAM 0.5 (MODHIKE)'
);

-- line #1011
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MORECALM 0.25 (Moraceae)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MORECALM 0.25 (Moraceae)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MORECALM 0.5 (Moraceae)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MORECALM 0.5 (Moraceae)'
);

-- line #1012
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOVAREST 0.5 (MOVA PH.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOVAREST 0.5 (MOVA PH.)'
);

-- line #1013
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAT 0.25 (Suvik Hit.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAT 0.25 (Suvik Hit.)'
);

-- line #1014
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAT 0.5 (Suvik Hit.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAT 0.5 (Suvik Hit.)'
);

-- line #1015
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAZOL 0.25 (Runa Ph.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAZOL 0.25 (Runa Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAZOL 0.5 (Runa Ph.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAZOL 0.5 (Runa Ph.)'
);

-- line #1016
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITRIL 0.25 (CLARIS)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITRIL 0.25 (CLARIS)'
);

-- line #1017
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITRIL 0.5 (CLARIS)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITRIL 0.5 (CLARIS)'
);

-- line #1018
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOREX 0.25 (Nordic Ph.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOREX 0.25 (Nordic Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOREX 0.5 (Nordic Ph.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOREX 0.5 (Nordic Ph.)'
);

-- line #1019
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOTENCE 0.25 (Crescent Th.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOTENCE 0.25 (Crescent Th.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOTENCE 0.5 (Crescent Th.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOTENCE 0.5 (Crescent Th.)'
);

-- line #1020
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOTENCE 1 (Crescent Th.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOTENCE 1 (Crescent Th.)'
);

-- line #1021
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONAPRACT 0.25 (Sayona)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONAPRACT 0.25 (Sayona)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONAPRACT 0.5 (Sayona)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONAPRACT 0.5 (Sayona)'
);

-- line #1022
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPTIZOLE 0.25 (TALENT LAB.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPTIZOLE 0.25 (TALENT LAB.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPTIZOLE 0.5 (TALENT LAB.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPTIZOLE 0.5 (TALENT LAB.)'
);

-- line #1023
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORTEN 0.5 (Chemo D.)',
	'Alprazolam',
	'F. TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORTEN 0.5 (Chemo D.)'
);

-- line #1024
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORTEN 0.25 (Chemo D.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORTEN 0.25 (Chemo D.)'
);

-- line #1025
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PACYL 0.5 (Jagsonpal)',
	'Alprazolam',
	'SR TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PACYL 0.5 (Jagsonpal)'
);

-- line #1026
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PACYL 1.5 (Jagsonpal)',
	'Alprazolam',
	'SR TAB',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PACYL 1.5 (Jagsonpal)'
);

-- line #1027
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PACYL 0.25 (Jagsonpal)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PACYL 0.25 (Jagsonpal)'
);

-- line #1028
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PACYL 0.5 (Jagsonpal)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PACYL 0.5 (Jagsonpal)'
);

-- line #1029
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'P CALM 0.25 (Winsome Lab)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'P CALM 0.25 (Winsome Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'P CALM 0.5 (Winsome Lab)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'P CALM 0.5 (Winsome Lab)'
);

-- line #1030
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'P CALM 1 (Winsome Lab)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'P CALM 1 (Winsome Lab)'
);

-- line #1031
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIZOLAM 0.25 (PSYCOREM)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIZOLAM 0.25 (PSYCOREM)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIZOLAM 0.5 (PSYCOREM)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIZOLAM 0.5 (PSYCOREM)'
);

-- line #1032
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIZOLAM 1 (PSYCOREM)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIZOLAM 1 (PSYCOREM)'
);

-- line #1033
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLAXID 0.25 (Svizera)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLAXID 0.25 (Svizera)'
);

-- line #1034
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLAXID 0.5 (Svizera)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLAXID 0.5 (Svizera)'
);

-- line #1035
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POIZE 0.25 (Systopic)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POIZE 0.25 (Systopic)'
);

-- line #1036
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POIZE 0.5 (Systopic)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POIZE 0.5 (Systopic)'
);

-- line #1037
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRALAM 0.25 (Ajanta Ph.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRALAM 0.25 (Ajanta Ph.)'
);

-- line #1038
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRALAM 0.5 (Ajanta Ph.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRALAM 0.5 (Ajanta Ph.)'
);

-- line #1039
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRALAM 1 (Ajanta Ph.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRALAM 1 (Ajanta Ph.)'
);

-- line #1040
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRAZAM 0.25 (Emil Ph.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRAZAM 0.25 (Emil Ph.)'
);

-- line #1041
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRAZAM 0.5 (Emil Ph.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRAZAM 0.5 (Emil Ph.)'
);

-- line #1042
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRAZ 0.25 (Dial Ph.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRAZ 0.25 (Dial Ph.)'
);

-- line #1043
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROCALM 0.25 (Radicura)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROCALM 0.25 (Radicura)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROCALM 0.5 (Radicura)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROCALM 0.5 (Radicura)'
);

-- line #1044
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROLAM 0.25 (Kapl)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROLAM 0.25 (Kapl)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROLAM 0.5 (Kapl)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROLAM 0.5 (Kapl)'
);

-- line #1045
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROLAM 0.5 (Kapl)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROLAM 0.5 (Kapl)'
);

-- line #1046
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROLAM 0.25 (Perk Ph.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROLAM 0.25 (Perk Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROLAM 0.5 (Perk Ph.)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROLAM 0.5 (Perk Ph.)'
);

-- line #1047
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROZAM 0.25 (Medicamen)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROZAM 0.25 (Medicamen)'
);

-- line #1048
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROZAM 0.5 (Medicamen)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROZAM 0.5 (Medicamen)'
);

-- line #1049
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROZOL 0.5 (Healthgaurd)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROZOL 0.5 (Healthgaurd)'
);

-- line #1050
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q-REST 0.25 (ALLENGE)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q-REST 0.25 (ALLENGE)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q-REST 0.5 (ALLENGE)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q-REST 0.5 (ALLENGE)'
);

-- line #1051
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUIET 0.25 (Ind-Swift)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUIET 0.25 (Ind-Swift)'
);

-- line #1052
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUIET 0.5 (Ind-Swift)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUIET 0.5 (Ind-Swift)'
);

-- line #1053
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESCALM 0.25 (Ultramark)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESCALM 0.25 (Ultramark)'
);

-- line #1054
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESCALM 0.5 (Ultramark)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESCALM 0.5 (Ultramark)'
);

-- line #1055
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESTYL 0.5 (Protec)',
	'Alprazolam',
	'SR TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESTYL 0.5 (Protec)'
);

-- line #1056
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESTYL 0.25 (Protec)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESTYL 0.25 (Protec)'
);

-- line #1057
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESTYL 0.5 (Protec)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESTYL 0.5 (Protec)'
);

-- line #1058
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESTYL 1 (Protec)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESTYL 1 (Protec)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESTYL 1.50 (Protec)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('1.50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESTYL 1.50 (Protec)'
);

-- line #1059
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESTYL 1 (Protec)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESTYL 1 (Protec)'
);

-- line #1060
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIAN 0.25 (Mapra)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIAN 0.25 (Mapra)'
);

-- line #1061
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIAN 0.5 (Mapra)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIAN 0.5 (Mapra)'
);

-- line #1062
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIAN 1 (Mapra)',
	'Alprazolam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIAN 1 (Mapra)'
);

-- line #1063
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Al-Prostadil-Prostaglandin E1', u'always_empty': u'', u'form': u'VR INJ', u'brand': u'PROSTIN', u'strength_3': u'', u'company': u'MAX', u'unit': u''}

-- line #1064
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2', u'strength_2': u'', u'substance': u'ALUMINIUM CHLORIDE', u'always_empty': u'', u'form': u'', u'brand': u'ALDRY', u'strength_3': u'', u'company': u'CURATIO HC.', u'unit': u'%'}

-- line #1065
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'ALUMINIUM CHLORIDE HEXAHYDRATE', u'always_empty': u'', u'form': u'', u'brand': u'ALDRY', u'strength_3': u'', u'company': u'CURATIO HC.', u'unit': u'%W/W'}

-- line #1066
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMANTREL 100 (Protec)',
	'Amantadine',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMANTREL 100 (Protec)'
);

-- line #1067
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEAMAN 100 (Nestor)',
	'Amantadine',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg(HCL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEAMAN 100 (Nestor)'
);

-- line #1068
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARKITIDIN 100 (Sun)',
	'Amantadine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARKITIDIN 100 (Sun)'
);

-- line #1069
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMBROLITE 10 (TABLETS I.)',
	'Ambroxol',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMBROLITE 10 (TABLETS I.)'
);

-- line #1070
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACOCONTIN 75 (Modi Mundi)',
	'Ambroxol Hcl.',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg C.R.'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACOCONTIN 75 (Modi Mundi)'
);

-- line #1071
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACOLYT 30 (Modi Mundi)',
	'Ambroxol Hcl.',
	'SYR',
	gm.nullify_empty_string('30')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACOLYT 30 (Modi Mundi)'
);

-- line #1072
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACOLYT 30 (Modi Mundi)',
	'Ambroxol Hcl.',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACOLYT 30 (Modi Mundi)'
);

-- line #1073
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMBRIL 7.5 (Svizera)',
	'Ambroxol Hcl.',
	'DPS',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMBRIL 7.5 (Svizera)'
);

-- line #1074
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMBRIL 30 (Svizera)',
	'Ambroxol Hcl.',
	'SYR',
	gm.nullify_empty_string('30')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMBRIL 30 (Svizera)'
);

-- line #1075
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMBRIL 30 (Svizera)',
	'Ambroxol Hcl.',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMBRIL 30 (Svizera)'
);

-- line #1076
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMBRODIL 7.5 (Aristo)',
	'Ambroxol Hcl.',
	'DPS',
	gm.nullify_empty_string('7.5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMBRODIL 7.5 (Aristo)'
);

-- line #1077
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMBRODIL 30 (Aristo)',
	'Ambroxol Hcl.',
	'SYR',
	gm.nullify_empty_string('30')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMBRODIL 30 (Aristo)'
);

-- line #1078
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMBRODIL 30 (Aristo)',
	'Ambroxol Hcl.',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMBRODIL 30 (Aristo)'
);

-- line #1079
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMBROLITE 7.5 (TABLETS I.)',
	'Ambroxol Hcl.',
	'DROPS',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMBROLITE 7.5 (TABLETS I.)'
);

-- line #1080
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMBROLITE 30 (TABLETS I.)',
	'Ambroxol Hcl.',
	'SUS',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMBROLITE 30 (TABLETS I.)'
);

-- line #1081
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMBROLITE 30 (TABLETS I.)',
	'Ambroxol Hcl.',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMBROLITE 30 (TABLETS I.)'
);

-- line #1082
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMSOL 75 (Kresp)',
	'Ambroxol Hcl.',
	'SR TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMSOL 75 (Kresp)'
);

-- line #1083
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AX 7.5 (EAST WEST)',
	'Ambroxol Hcl.',
	'DPS',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AX 7.5 (EAST WEST)'
);

-- line #1084
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COSCORIL 7.5 (Biological E.)',
	'Ambroxol Hcl.',
	'DPS',
	gm.nullify_empty_string('7.5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COSCORIL 7.5 (Biological E.)'
);

-- line #1085
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILOVENT 75 (Obsurge)',
	'Ambroxol Hcl.',
	'CAP',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILOVENT 75 (Obsurge)'
);

-- line #1086
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'15', u'strength_2': u'', u'substance': u'Ambroxol Hcl.', u'always_empty': u'', u'form': u'', u'brand': u'INHALEX REPULES', u'strength_3': u'', u'company': u'Cipla', u'unit': u'mg/2ML'}

-- line #1087
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KOFAREST 7.5 (Centaur)',
	'Ambroxol Hcl.',
	'DPS',
	gm.nullify_empty_string('7.5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KOFAREST 7.5 (Centaur)'
);

-- line #1088
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Ambroxol Hcl.', u'always_empty': u'', u'form': u'SR CAP', u'brand': u'LIQIX', u'strength_3': u'', u'company': u'Novartis', u'unit': u''}

-- line #1089
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUCOFORM 30 (Ajanta Ph.)',
	'Ambroxol Hcl.',
	'SYR',
	gm.nullify_empty_string('30')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUCOFORM 30 (Ajanta Ph.)'
);

-- line #1090
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUCOFORM 60 (Ajanta Ph.)',
	'Ambroxol Hcl.',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUCOFORM 60 (Ajanta Ph.)'
);

-- line #1091
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUCOLITE 7.5 (Dr.Reddy''S)',
	'Ambroxol Hcl.',
	'DPS',
	gm.nullify_empty_string('7.5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUCOLITE 7.5 (Dr.Reddy''S)'
);

-- line #1092
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUCOLITE 75 (Dr.Reddy''S)',
	'Ambroxol Hcl.',
	'SR CAP',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUCOLITE 75 (Dr.Reddy''S)'
);

-- line #1093
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUCOLITE 30 (Dr.Reddy''S)',
	'Ambroxol Hcl.',
	'SYR',
	gm.nullify_empty_string('30')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUCOLITE 30 (Dr.Reddy''S)'
);

-- line #1094
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUCOLITE 30 (Dr.Reddy''S)',
	'Ambroxol Hcl.',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUCOLITE 30 (Dr.Reddy''S)'
);

-- line #1095
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUCORESP 15 (AZINE HC.)',
	'Ambroxol Hcl.',
	'DPS',
	gm.nullify_empty_string('15')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUCORESP 15 (AZINE HC.)'
);

-- line #1096
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMFOS 500 (Vhb)',
	'AMIFOSTINE',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMFOS 500 (Vhb)'
);

-- line #1097
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIPHOS 500 (Dabur Ph.)',
	'Amifostine',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg(ANHY.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIPHOS 500 (Dabur Ph.)'
);

-- line #1098
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYTOFOS 500 (Sun)',
	'Amifostine',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYTOFOS 500 (Sun)'
);

-- line #1099
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHYOL 500 (Fulford)',
	'Amifostine',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHYOL 500 (Fulford)'
);

-- line #1100
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'M-FOST 500 (Shantha Bio.)',
	'Amifostine',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'M-FOST 500 (Shantha Bio.)'
);

-- line #1101
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAPROFOS 500 (MIRACALUS)',
	'AMIFOSTINE',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAPROFOS 500 (MIRACALUS)'
);

-- line #1102
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACIN 100 (Aabtac Life)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACIN 100 (Aabtac Life)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACIN 250 (Aabtac Life)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACIN 250 (Aabtac Life)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACIN 500 (Aabtac Life)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACIN 500 (Aabtac Life)'
);

-- line #1103
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADDCIN 500 (ADDPLUS)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADDCIN 500 (ADDPLUS)'
);

-- line #1104
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AEROBACT 100 (Elysium)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AEROBACT 100 (Elysium)'
);

-- line #1105
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AEROBACT 250 (Elysium)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AEROBACT 250 (Elysium)'
);

-- line #1106
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AEROBACT 500 (Elysium)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AEROBACT 500 (Elysium)'
);

-- line #1107
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AFCIN 100 (Alpha Arom.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AFCIN 100 (Alpha Arom.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AFCIN 250 (Alpha Arom.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AFCIN 250 (Alpha Arom.)'
);

-- line #1108
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AFCIN 500 (Alpha Arom.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AFCIN 500 (Alpha Arom.)'
);

-- line #1109
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AKCIN 100 (HAMPS BIO)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AKCIN 100 (HAMPS BIO)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AKCIN 500 (HAMPS BIO)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AKCIN 500 (HAMPS BIO)'
);

-- line #1110
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBEN 100 (Izen Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg(+ PRES.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBEN 100 (Izen Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBEN 250 (Izen Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg(+ PRES.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBEN 250 (Izen Ph.)'
);

-- line #1111
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBEN 500 (Izen Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg(+ PRES.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBEN 500 (Izen Ph.)'
);

-- line #1112
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMCASE 100 (Hi-Tec)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMCASE 100 (Hi-Tec)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMCASE 200 (Hi-Tec)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMCASE 200 (Hi-Tec)'
);

-- line #1113
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMCASE 500 (Hi-Tec)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMCASE 500 (Hi-Tec)'
);

-- line #1114
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMCIL-A 100 (Perk Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMCIL-A 100 (Perk Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMCIL-A 250 (Perk Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMCIL-A 250 (Perk Ph.)'
);

-- line #1115
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMCIL-A 500 (Perk Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMCIL-A 500 (Perk Ph.)'
);

-- line #1116
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMCIN 100 (Cadila Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMCIN 100 (Cadila Ph.)'
);

-- line #1117
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMCIN 250 (Cadila Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMCIN 250 (Cadila Ph.)'
);

-- line #1118
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMCIN 500 (Cadila Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMCIN 500 (Cadila Ph.)'
);

-- line #1119
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMEL 100 (Elf Biomed)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMEL 100 (Elf Biomed)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMEL 250 (Elf Biomed)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMEL 250 (Elf Biomed)'
);

-- line #1120
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMEL 500 (Elf Biomed)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMEL 500 (Elf Biomed)'
);

-- line #1121
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMEXEL 100 (Nicholas)',
	'Amikacin',
	'V',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMEXEL 100 (Nicholas)'
);

-- line #1122
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMEXEL 250 (Nicholas)',
	'Amikacin',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMEXEL 250 (Nicholas)'
);

-- line #1123
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMEXEL 500 (Nicholas)',
	'Amikacin',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMEXEL 500 (Nicholas)'
);

-- line #1124
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIACT 100 (Active Hc.)',
	'Amikacin',
	'AMP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIACT 100 (Active Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIACT 500 (Active Hc.)',
	'Amikacin',
	'AMP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIACT 500 (Active Hc.)'
);

-- line #1125
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIBIOTIC 100 (Neon)',
	'Amikacin',
	'V',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIBIOTIC 100 (Neon)'
);

-- line #1126
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIBIOTIC 250 (Neon)',
	'Amikacin',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIBIOTIC 250 (Neon)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIBIOTIC 500 (Neon)',
	'Amikacin',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIBIOTIC 500 (Neon)'
);

-- line #1127
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMICABA 125 (ACTO)',
	'Amikacin',
	'VIAL',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMICABA 125 (ACTO)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMICABA 250 (ACTO)',
	'Amikacin',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMICABA 250 (ACTO)'
);

-- line #1128
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMICA 500 (Swiss Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMICA 500 (Swiss Ph.)'
);

-- line #1129
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMICID 100 (Indus)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMICID 100 (Indus)'
);

-- line #1130
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMICID 250 (Indus)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMICID 250 (Indus)'
);

-- line #1131
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMICID 500 (Indus)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMICID 500 (Indus)'
);

-- line #1132
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMICIN 100 (Biochem)',
	'Amikacin',
	'V',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMICIN 100 (Biochem)'
);

-- line #1133
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMICIN 250 (Biochem)',
	'Amikacin',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMICIN 250 (Biochem)'
);

-- line #1134
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMICIN 500 (Biochem)',
	'Amikacin',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMICIN 500 (Biochem)'
);

-- line #1135
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMICIP 100 (Cipla)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMICIP 100 (Cipla)'
);

-- line #1136
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMICIP 250 (Cipla)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMICIP 250 (Cipla)'
);

-- line #1137
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMICIP 500 (Cipla)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMICIP 500 (Cipla)'
);

-- line #1138
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMICIT 500 (CITIZEN LAB.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMICIT 500 (CITIZEN LAB.)'
);

-- line #1139
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMICOM 100 (Comed)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMICOM 100 (Comed)'
);

-- line #1140
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMICOM 250 (Comed)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMICOM 250 (Comed)'
);

-- line #1141
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMICOM 500 (Comed)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMICOM 500 (Comed)'
);

-- line #1142
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIFIN 100 (Finesse Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIFIN 100 (Finesse Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIFIN 250 (Finesse Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIFIN 250 (Finesse Ph.)'
);

-- line #1143
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIFIN 500 (Finesse Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIFIN 500 (Finesse Ph.)'
);

-- line #1144
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMI 100 (Siesta)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMI 100 (Siesta)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMI 500 (Siesta)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMI 500 (Siesta)'
);

-- line #1145
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIJET 500 (HANBURYS)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIJET 500 (HANBURYS)'
);

-- line #1146
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIKACIN SULPHATE 100 (Samarth)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg(SULPHATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIKACIN SULPHATE 100 (Samarth)'
);

-- line #1147
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIKACIN SULPHATE 250 (Samarth)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg (SULPH.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIKACIN SULPHATE 250 (Samarth)'
);

-- line #1148
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIKACIN SULPHATE 500 (Samarth)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg(SULPH.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIKACIN SULPHATE 500 (Samarth)'
);

-- line #1149
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIKA 100 (Stanford)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIKA 100 (Stanford)'
);

-- line #1150
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIKA 500 (Stanford)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIKA 500 (Stanford)'
);

-- line #1151
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u' % PROPYL PARABEN;W/V)', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'125', u'strength_2': u'', u'substance': u'Amikacin', u'always_empty': u'', u'form': u'', u'brand': u'AMIKAMAC', u'strength_3': u'', u'company': u'Macleods', u'unit': u'mg(0.18 METHYL PARABEN'}

-- line #1152
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u' % PROPYL PARABEN;W/V)', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250', u'strength_2': u'', u'substance': u'Amikacin', u'always_empty': u'', u'form': u'', u'brand': u'AMIKAMAC', u'strength_3': u'', u'company': u'Macleods', u'unit': u'mg(0.18 METHYL PARABEN'}

-- line #1153
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u' % PROPYL PARABEN;W/V)', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50', u'strength_2': u'', u'substance': u'Amikacin', u'always_empty': u'', u'form': u'', u'brand': u'AMIKAMAC', u'strength_3': u'', u'company': u'Macleods', u'unit': u'mg(0.18 METHYL PARABEN'}

-- line #1154
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIKANEX 100 (N.A.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIKANEX 100 (N.A.)'
);

-- line #1155
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIKANEX 250 (N.A.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIKANEX 250 (N.A.)'
);

-- line #1156
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIKANEX 500 (N.A.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIKANEX 500 (N.A.)'
);

-- line #1157
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIKANIT 100 (Alde Medi.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIKANIT 100 (Alde Medi.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIKANIT 250 (Alde Medi.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIKANIT 250 (Alde Medi.)'
);

-- line #1158
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIKANIT 500 (Alde Medi.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIKANIT 500 (Alde Medi.)'
);

-- line #1159
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIKANTE 100 (CORE GESTRA)',
	'Amikacin',
	'VIAL',
	gm.nullify_empty_string('100')::numeric,
	'250'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIKANTE 100 (CORE GESTRA)'
);

-- line #1160
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIKAS 125 (CH.Bhagat)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIKAS 125 (CH.Bhagat)'
);

-- line #1161
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIKAS 250 (CH.Bhagat)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIKAS 250 (CH.Bhagat)'
);

-- line #1162
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIKAS 500 (CH.Bhagat)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIKAS 500 (CH.Bhagat)'
);

-- line #1163
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIKATER 100 (Guj.Terce)',
	'AMIKACIN',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIKATER 100 (Guj.Terce)'
);

-- line #1164
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIKATER 250 (GUJ. TE.)',
	'Amikacin',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIKATER 250 (GUJ. TE.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIKATER 500 (GUJ. TE.)',
	'Amikacin',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIKATER 500 (GUJ. TE.)'
);

-- line #1165
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIKEF 100 (Lupin)',
	'Amikacin',
	'V',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIKEF 100 (Lupin)'
);

-- line #1166
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIKEF 250 (Lupin)',
	'Amikacin',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIKEF 250 (Lupin)'
);

-- line #1167
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIKEF 500 (Lupin)',
	'Amikacin',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIKEF 500 (Lupin)'
);

-- line #1168
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIKIN 250 (P C INDIA)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIKIN 250 (P C INDIA)'
);

-- line #1169
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIKIN 500 (P C INDIA)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIKIN 500 (P C INDIA)'
);

-- line #1170
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIKON 100 (Konark Bio.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIKON 100 (Konark Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIKON 250 (Konark Bio.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIKON 250 (Konark Bio.)'
);

-- line #1171
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIKON 500 (Konark Bio.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIKON 500 (Konark Bio.)'
);

-- line #1172
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIMAC 100 (Ikon Rem)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIMAC 100 (Ikon Rem)'
);

-- line #1173
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIMAC 500 (Ikon Rem)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIMAC 500 (Ikon Rem)'
);

-- line #1174
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIMAX 100 (INNOVATIVE)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIMAX 100 (INNOVATIVE)'
);

-- line #1175
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIMAX 500 (INNOVATIVE)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIMAX 500 (INNOVATIVE)'
);

-- line #1176
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMINAT 100 (Natco Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMINAT 100 (Natco Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMINAT 250 (Natco Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMINAT 250 (Natco Ph.)'
);

-- line #1177
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMINAT 500 (Natco Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMINAT 500 (Natco Ph.)'
);

-- line #1178
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIN 100 (Eg Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIN 100 (Eg Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIN 250 (Eg Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIN 250 (Eg Ph.)'
);

-- line #1179
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIN 500 (Eg Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIN 500 (Eg Ph.)'
);

-- line #1180
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMINOCIN 100 (Meridian)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMINOCIN 100 (Meridian)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMINOCIN 250 (Meridian)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMINOCIN 250 (Meridian)'
);

-- line #1181
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMINOCIN 500 (Meridian)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMINOCIN 500 (Meridian)'
);

-- line #1182
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIROD 100 (Medoz Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIROD 100 (Medoz Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIROD 250 (Medoz Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIROD 250 (Medoz Ph.)'
);

-- line #1183
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIROD 500 (Medoz Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIROD 500 (Medoz Ph.)'
);

-- line #1184
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIRON 100 (Kamron)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIRON 100 (Kamron)'
);

-- line #1185
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIRON 250 (Kamron)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIRON 250 (Kamron)'
);

-- line #1186
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIRON 500 (Kamron)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIRON 500 (Kamron)'
);

-- line #1187
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMISAFE 100 (Indoco Rem.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMISAFE 100 (Indoco Rem.)'
);

-- line #1188
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMISAFE 250 (Indoco Rem.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMISAFE 250 (Indoco Rem.)'
);

-- line #1189
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMISAFE 500 (Indoco Rem.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMISAFE 500 (Indoco Rem.)'
);

-- line #1190
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100', u'strength_2': u'', u'substance': u'Amikacin', u'always_empty': u'', u'form': u'', u'brand': u'AMI-SOL', u'strength_3': u'', u'company': u'DIVINE LAB.', u'unit': u'mg'}

-- line #1191
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250', u'strength_2': u'', u'substance': u'Amikacin', u'always_empty': u'', u'form': u'', u'brand': u'AMI-SOL', u'strength_3': u'', u'company': u'DIVINE LAB.', u'unit': u'mg'}

-- line #1192
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500', u'strength_2': u'', u'substance': u'Amikacin', u'always_empty': u'', u'form': u'', u'brand': u'AMI-SOL', u'strength_3': u'', u'company': u'DIVINE LAB.', u'unit': u'mg'}

-- line #1193
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Amikacin', u'always_empty': u'', u'form': u'DROPS', u'brand': u'AMISOL EYE', u'strength_3': u'', u'company': u'DIVINE LAB.', u'unit': u''}

-- line #1194
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMISTAR 100 (Cadila Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMISTAR 100 (Cadila Ph.)'
);

-- line #1195
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMISTAR 250 (Cadila Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMISTAR 250 (Cadila Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMISTAR 500 (Cadila Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMISTAR 500 (Cadila Ph.)'
);

-- line #1196
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMISTER 100 (Sterfil)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMISTER 100 (Sterfil)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMISTER 250 (Sterfil)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMISTER 250 (Sterfil)'
);

-- line #1197
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMISTER 500 (Sterfil)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMISTER 500 (Sterfil)'
);

-- line #1198
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMISULF 100 (Samarth)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMISULF 100 (Samarth)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMISULF 250 (Samarth)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMISULF 250 (Samarth)'
);

-- line #1199
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMISULF 500 (Samarth)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMISULF 500 (Samarth)'
);

-- line #1200
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMITAX 50 (Alkem)',
	'Amikacin',
	'AMP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMITAX 50 (Alkem)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMITAX 100 (Alkem)',
	'Amikacin',
	'AMP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMITAX 100 (Alkem)'
);

-- line #1201
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMITAX MDV 500 (ALKEM)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg(BUFFER AGENT SODIUM CITRATE IP 2.5 W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMITAX MDV 500 (ALKEM)'
);

-- line #1202
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMITAX 100 (Alkem)',
	'Amikacin',
	'V',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMITAX 100 (Alkem)'
);

-- line #1203
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMITAX 250 (Alkem)',
	'Amikacin',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMITAX 250 (Alkem)'
);

-- line #1204
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMITAX 500 (Alkem)',
	'Amikacin',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMITAX 500 (Alkem)'
);

-- line #1205
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIV 100 (Zedip Form.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIV 100 (Zedip Form.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIV 250 (Zedip Form.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIV 250 (Zedip Form.)'
);

-- line #1206
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIV 500 (Zedip Form.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIV 500 (Zedip Form.)'
);

-- line #1207
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIXON 100 (Kentreck)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIXON 100 (Kentreck)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIXON 500 (Kentreck)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIXON 500 (Kentreck)'
);

-- line #1208
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIZA 100 (TRUMAC)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIZA 100 (TRUMAC)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIZA 250 (TRUMAC)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIZA 250 (TRUMAC)'
);

-- line #1209
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIZA 500 (TRUMAC)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIZA 500 (TRUMAC)'
);

-- line #1210
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIZEC 100 (Zee Lab)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIZEC 100 (Zee Lab)'
);

-- line #1211
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIZEC 250 (Zee Lab)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIZEC 250 (Zee Lab)'
);

-- line #1212
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIZEC 500 (Zee Lab)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIZEC 500 (Zee Lab)'
);

-- line #1213
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIZ 500 (Ritz Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg(+METHYLPARABEN 0.08'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIZ 500 (Ritz Ph.)'
);

-- line #1214
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMKEY 100 (Elder)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMKEY 100 (Elder)'
);

-- line #1215
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMKEY 250 (Elder)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMKEY 250 (Elder)'
);

-- line #1216
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMKEY 500 (Elder)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMKEY 500 (Elder)'
);

-- line #1217
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMKIN 100 (Shinto Org.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMKIN 100 (Shinto Org.)'
);

-- line #1218
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMKIN 250 (Shinto Org.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMKIN 250 (Shinto Org.)'
);

-- line #1219
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMKIN 500 (Shinto Org.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMKIN 500 (Shinto Org.)'
);

-- line #1220
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMK 100 (Kee Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMK 100 (Kee Ph.)'
);

-- line #1221
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMK 250 (Kee Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMK 250 (Kee Ph.)'
);

-- line #1222
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMK 500 (Kee Ph.)',
	'Amikacin',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMK 500 (Kee Ph.)'
);

-- line #1223
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMNEX 100 (Nexus)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMNEX 100 (Nexus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMNEX 250 (Nexus)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMNEX 250 (Nexus)'
);

-- line #1224
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMNEX 500 (Nexus)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMNEX 500 (Nexus)'
);

-- line #1225
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMOKA100/250/500 100 (ORION BIOTECH.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'250'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMOKA100/250/500 100 (ORION BIOTECH.)'
);

-- line #1226
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMRICIN 100 (AMRIT)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMRICIN 100 (AMRIT)'
);

-- line #1227
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMRICIN 250 (AMRIT)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMRICIN 250 (AMRIT)'
);

-- line #1228
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMRICIN 500 (AMRIT)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMRICIN 500 (AMRIT)'
);

-- line #1229
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMTOP 100 (Ind-Swift)',
	'Amikacin',
	'VIAL',
	gm.nullify_empty_string('100')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMTOP 100 (Ind-Swift)'
);

-- line #1230
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMTOP 100 (Ind-Swift)',
	'Amikacin',
	'V',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMTOP 100 (Ind-Swift)'
);

-- line #1231
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMTOP 250 (Ind-Swift)',
	'Amikacin',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMTOP 250 (Ind-Swift)'
);

-- line #1232
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMTOP 500 (Ind-Swift)',
	'Amikacin',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMTOP 500 (Ind-Swift)'
);

-- line #1233
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMYZEN100 100 (AXYZEN LIFE)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMYZEN100 100 (AXYZEN LIFE)'
);

-- line #1234
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMYZEN 250 (AXYZEN LIFE)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMYZEN 250 (AXYZEN LIFE)'
);

-- line #1235
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMYZEN 500 (AXYZEN LIFE)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMYZEN 500 (AXYZEN LIFE)'
);

-- line #1236
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANAMIKA 100 (Meridian)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANAMIKA 100 (Meridian)'
);

-- line #1237
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANAMIKA 250 (Meridian)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANAMIKA 250 (Meridian)'
);

-- line #1238
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANAMIKA 500 (Meridian)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANAMIKA 500 (Meridian)'
);

-- line #1239
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AQUACIN 100 (Bipl(Radico Lab))',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AQUACIN 100 (Bipl(Radico Lab))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AQUACIN 500 (Bipl(Radico Lab))',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AQUACIN 500 (Bipl(Radico Lab))'
);

-- line #1240
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATMIKA 100 (Atoz Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATMIKA 100 (Atoz Ph.)'
);

-- line #1241
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATMIKA 500 (Atoz Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATMIKA 500 (Atoz Ph.)'
);

-- line #1242
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVIKACIN 100 (Admac Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVIKACIN 100 (Admac Ph.)'
);

-- line #1243
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVIKACIN 250 (Admac Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVIKACIN 250 (Admac Ph.)'
);

-- line #1244
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVIKACIN 500 (Admac Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVIKACIN 500 (Admac Ph.)'
);

-- line #1245
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVMIK 100 (POSITIF(AFIVE))',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVMIK 100 (POSITIF(AFIVE))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVMIK 250 (POSITIF(AFIVE))',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVMIK 250 (POSITIF(AFIVE))'
);

-- line #1246
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVMIK 500 (POSITIF(AFIVE))',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVMIK 500 (POSITIF(AFIVE))'
);

-- line #1247
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXCIN 100 (LAKSUN)',
	'Amikacin',
	'VIAL',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXCIN 100 (LAKSUN)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXCIN 250 (LAKSUN)',
	'Amikacin',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXCIN 250 (LAKSUN)'
);

-- line #1248
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXCIN 500 (LAKSUN)',
	'Amikacin',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXCIN 500 (LAKSUN)'
);

-- line #1249
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACIKACIN 100 (Skymax)',
	'Amikacin',
	'V',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACIKACIN 100 (Skymax)'
);

-- line #1250
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACIKACIN 250 (Skymax)',
	'Amikacin',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACIKACIN 250 (Skymax)'
);

-- line #1251
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACIKACIN 500 (Skymax)',
	'Amikacin',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACIKACIN 500 (Skymax)'
);

-- line #1252
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BEKACIN 100 (Ultramark)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BEKACIN 100 (Ultramark)'
);

-- line #1253
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BEKACIN 250 (Ultramark)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BEKACIN 250 (Ultramark)'
);

-- line #1254
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BEKACIN 500 (Ultramark)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BEKACIN 500 (Ultramark)'
);

-- line #1255
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIKACIN 100 (Brooks Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIKACIN 100 (Brooks Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIKACIN 250 (Brooks Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIKACIN 250 (Brooks Ph.)'
);

-- line #1256
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIKACIN 500 (Brooks Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIKACIN 500 (Brooks Ph.)'
);

-- line #1257
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIKACIN 100 (Jarson Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIKACIN 100 (Jarson Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIKACIN 500 (Jarson Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIKACIN 500 (Jarson Ph.)'
);

-- line #1258
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOCIN 100 (Biocin Hc.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOCIN 100 (Biocin Hc.)'
);

-- line #1259
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOCIN 250 (Biocin Hc.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOCIN 250 (Biocin Hc.)'
);

-- line #1260
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOCIN 500 (Biocin Hc.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOCIN 500 (Biocin Hc.)'
);

-- line #1261
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOMICA 100 (Biosmith)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOMICA 100 (Biosmith)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOMICA 250 (Biosmith)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOMICA 250 (Biosmith)'
);

-- line #1262
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOMICA 500 (Biosmith)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOMICA 500 (Biosmith)'
);

-- line #1263
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLUMIKA IM IV 250 (Blue Cross)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLUMIKA IM IV 250 (Blue Cross)'
);

-- line #1264
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLUMIKA IM IV 500 (Blue Cross)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLUMIKA IM IV 500 (Blue Cross)'
);

-- line #1265
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRUKIN 100 (B.M.Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRUKIN 100 (B.M.Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRUKIN 250 (B.M.Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRUKIN 250 (B.M.Ph.)'
);

-- line #1266
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRUKIN 500 (B.M.Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRUKIN 500 (B.M.Ph.)'
);

-- line #1267
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CINAMICA 100 (SHREYA)',
	'Amikacin',
	'AMP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CINAMICA 100 (SHREYA)'
);

-- line #1268
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CINAMICA 250 (SHREYA)',
	'Amikacin',
	'AMP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CINAMICA 250 (SHREYA)'
);

-- line #1269
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CINAMICA 500 (SHREYA)',
	'Amikacin',
	'AMP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CINAMICA 500 (SHREYA)'
);

-- line #1270
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUMIK 500 (Curex)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUMIK 500 (Curex)'
);

-- line #1271
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CURESIN 100 (Cure Quick)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CURESIN 100 (Cure Quick)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CURESIN 250 (Cure Quick)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CURESIN 250 (Cure Quick)'
);

-- line #1272
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CURESIN 500 (Cure Quick)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CURESIN 500 (Cure Quick)'
);

-- line #1273
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIKACIN 100 (Devi Form.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIKACIN 100 (Devi Form.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIKACIN 250 (Devi Form.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIKACIN 250 (Devi Form.)'
);

-- line #1274
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIKACIN 500 (Devi Form.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIKACIN 500 (Devi Form.)'
);

-- line #1275
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELMIK 100 (Elfin Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELMIK 100 (Elfin Ph.)'
);

-- line #1276
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELMIK 250 (Elfin Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELMIK 250 (Elfin Ph.)'
);

-- line #1277
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELMIK 500 (Elfin Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELMIK 500 (Elfin Ph.)'
);

-- line #1278
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMCIN 250 (Captab)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMCIN 250 (Captab)'
);

-- line #1279
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMCIN 500 (Captab)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMCIN 500 (Captab)'
);

-- line #1280
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMICA 100 (Lincoln)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMICA 100 (Lincoln)'
);

-- line #1281
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMICA 250 (Lincoln)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMICA 250 (Lincoln)'
);

-- line #1282
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMICA 500 (Lincoln)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMICA 500 (Lincoln)'
);

-- line #1283
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMKA 100 (Global Med.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMKA 100 (Global Med.)'
);

-- line #1284
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMKA 250 (Global Med.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMKA 250 (Global Med.)'
);

-- line #1285
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMKA 500 (Global Med.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMKA 500 (Global Med.)'
);

-- line #1286
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Amikacin', u'always_empty': u'', u'form': u'', u'brand': u'ENAMIKA-100INJ', u'strength_3': u'', u'company': u'ENRICH PH.', u'unit': u''}

-- line #1287
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Amikacin', u'always_empty': u'', u'form': u'', u'brand': u'ENAMIKA-500INJ', u'strength_3': u'', u'company': u'ENRICH PH.', u'unit': u''}

-- line #1288
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERKACIN 100 (Brown & B.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERKACIN 100 (Brown & B.)'
);

-- line #1289
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERKACIN 250 (Brown & B.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERKACIN 250 (Brown & B.)'
);

-- line #1290
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERKACIN 500 (Brown & B.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERKACIN 500 (Brown & B.)'
);

-- line #1291
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EROCIN 100 (VENSAT)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EROCIN 100 (VENSAT)'
);

-- line #1292
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EROCIN 250 (VENSAT)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EROCIN 250 (VENSAT)'
);

-- line #1293
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EROCIN 500 (VENSAT)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EROCIN 500 (VENSAT)'
);

-- line #1294
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUMIK 100 (Euphoric)',
	'Amikacin',
	'V',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUMIK 100 (Euphoric)'
);

-- line #1295
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUMIK 250 (Euphoric)',
	'Amikacin',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUMIK 250 (Euphoric)'
);

-- line #1296
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUMIK 500 (Euphoric)',
	'Amikacin',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUMIK 500 (Euphoric)'
);

-- line #1297
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOKIN 100 (Forgo Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOKIN 100 (Forgo Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOKIN 250 (Forgo Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOKIN 250 (Forgo Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOKIN 500 (Forgo Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOKIN 500 (Forgo Ph.)'
);

-- line #1298
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FYMIKA 100 (Sanify)',
	'Amikacin',
	'AMP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FYMIKA 100 (Sanify)'
);

-- line #1299
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FYMIKA 250 (Sanify)',
	'Amikacin',
	'AMP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FYMIKA 250 (Sanify)'
);

-- line #1300
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FYMIKA 500 (Sanify)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FYMIKA 500 (Sanify)'
);

-- line #1301
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEMKA 100 (Global Med.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEMKA 100 (Global Med.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEMKA 250 (Global Med.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEMKA 250 (Global Med.)'
);

-- line #1302
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEMKA 500 (Global Med.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEMKA 500 (Global Med.)'
);

-- line #1303
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G-KACIN 100 (Graf Lab.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G-KACIN 100 (Graf Lab.)'
);

-- line #1304
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G-KACIN 250 (Graf Lab.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G-KACIN 250 (Graf Lab.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G-KACIN 500 (Graf Lab.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G-KACIN 500 (Graf Lab.)'
);

-- line #1305
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLOMIKA 100 (Globus)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLOMIKA 100 (Globus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLOMIKA 500 (Globus)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLOMIKA 500 (Globus)'
);

-- line #1306
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYKACIN 100 (Gland Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYKACIN 100 (Gland Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYKACIN 250 (Gland Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYKACIN 250 (Gland Ph.)'
);

-- line #1307
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYKACIN 125 (Gland Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYKACIN 125 (Gland Ph.)'
);

-- line #1308
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYKACIN 50 (Gland Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYKACIN 50 (Gland Ph.)'
);

-- line #1309
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'NA', u'strength_2': u'', u'substance': u'Amikacin', u'always_empty': u'', u'form': u'INJ', u'brand': u'GLYKACIN', u'strength_3': u'', u'company': u'Gland Ph.', u'unit': u''}

-- line #1310
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GROMIKA 100 (Growell)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GROMIKA 100 (Growell)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GROMIKA 250 (Growell)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GROMIKA 250 (Growell)'
);

-- line #1311
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GROMIKA 500 (Growell)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GROMIKA 500 (Growell)'
);

-- line #1312
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IDEG 100 (UNIKID)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IDEG 100 (UNIKID)'
);

-- line #1313
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INKACIN 100 (Intra Lab)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INKACIN 100 (Intra Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INKACIN 250 (Intra Lab)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INKACIN 250 (Intra Lab)'
);

-- line #1314
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INKACIN 500 (Intra Lab)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INKACIN 500 (Intra Lab)'
);

-- line #1315
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IVIMICIN 100 (F D C)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg(AS SULPH.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IVIMICIN 100 (F D C)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IVIMICIN 250 (F D C)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg(AS SULPH.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IVIMICIN 250 (F D C)'
);

-- line #1316
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IVIMICIN 500 (F D C)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg(AS SULPH.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IVIMICIN 500 (F D C)'
);

-- line #1317
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JYOMIK 100 (Biocin Hc.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JYOMIK 100 (Biocin Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JYOMIK 250 (Biocin Hc.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JYOMIK 250 (Biocin Hc.)'
);

-- line #1318
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JYOMIK 500 (Biocin Hc.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JYOMIK 500 (Biocin Hc.)'
);

-- line #1319
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KACINA 100 (Sayona)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KACINA 100 (Sayona)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KACINA 500 (Sayona)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KACINA 500 (Sayona)'
);

-- line #1320
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KACIZON 125 (Medizone)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KACIZON 125 (Medizone)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KACIZON 250 (Medizone)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KACIZON 250 (Medizone)'
);

-- line #1321
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KACIZON 500 (Medizone)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KACIZON 500 (Medizone)'
);

-- line #1322
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KAMICIN 500 (Healthgaurd)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KAMICIN 500 (Healthgaurd)'
);

-- line #1323
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KASINO 100 (MINOVA)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KASINO 100 (MINOVA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KASINO 250 (MINOVA)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KASINO 250 (MINOVA)'
);

-- line #1324
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KASINO 500 (MINOVA)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KASINO 500 (MINOVA)'
);

-- line #1325
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KAWACIN 100 (Synthiko)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KAWACIN 100 (Synthiko)'
);

-- line #1326
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KAWACIN 250 (Synthiko)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KAWACIN 250 (Synthiko)'
);

-- line #1327
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KAWACIN 500 (Synthiko)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KAWACIN 500 (Synthiko)'
);

-- line #1328
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'K-CIN 100 (Phytochem)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'K-CIN 100 (Phytochem)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'K-CIN 250 (Phytochem)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'K-CIN 250 (Phytochem)'
);

-- line #1329
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'K-CIN 500 (Phytochem)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'K-CIN 500 (Phytochem)'
);

-- line #1330
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEMIC 100 (Chemo D.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEMIC 100 (Chemo D.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEMIC 500 (Chemo D.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEMIC 500 (Chemo D.)'
);

-- line #1331
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEXIN 100 (Cadex Lab)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEXIN 100 (Cadex Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEXIN 250 (Cadex Lab)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEXIN 250 (Cadex Lab)'
);

-- line #1332
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEXIN 500 (Cadex Lab)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEXIN 500 (Cadex Lab)'
);

-- line #1333
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMIKA 100 (Lanark)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMIKA 100 (Lanark)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMIKA 250 (Lanark)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMIKA 250 (Lanark)'
);

-- line #1334
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMIKA 500 (Lanark)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMIKA 500 (Lanark)'
);

-- line #1335
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEMICIN 100 (ADMAC (LEE BENZ))',
	'Amikacin',
	'VIAL',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEMICIN 100 (ADMAC (LEE BENZ))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEMICIN 250 (ADMAC (LEE BENZ))',
	'Amikacin',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEMICIN 250 (ADMAC (LEE BENZ))'
);

-- line #1336
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEMICIN 500 (ADMAC (LEE BENZ))',
	'Amikacin',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEMICIN 500 (ADMAC (LEE BENZ))'
);

-- line #1337
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEMITAX 100 (LEMON PH.)',
	'Amikacin',
	'VIAL',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEMITAX 100 (LEMON PH.)'
);

-- line #1338
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEMITAX 250 (LEMON PH.)',
	'Amikacin',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEMITAX 250 (LEMON PH.)'
);

-- line #1339
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEMITAX 500 (LEMON PH.)',
	'Amikacin',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEMITAX 500 (LEMON PH.)'
);

-- line #1340
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEXCIN 100 (Lexus)',
	'Amikacin',
	'VIAL',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEXCIN 100 (Lexus)'
);

-- line #1341
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEXCIN 250 (Lexus)',
	'Amikacin',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEXCIN 250 (Lexus)'
);

-- line #1342
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEXCIN 500 (Lexus)',
	'Amikacin',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEXCIN 500 (Lexus)'
);

-- line #1343
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUPAMIK 100 (Lupin)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUPAMIK 100 (Lupin)'
);

-- line #1344
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUPAMIK 250 (Lupin)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUPAMIK 250 (Lupin)'
);

-- line #1345
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUPAMIK 500 (Lupin)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUPAMIK 500 (Lupin)'
);

-- line #1346
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALARACIN 100 (Malar Hc.)',
	'Amikacin',
	'VIAL',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALARACIN 100 (Malar Hc.)'
);

-- line #1347
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALARACIN 500 (Malar Hc.)',
	'Amikacin',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALARACIN 500 (Malar Hc.)'
);

-- line #1348
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALARCIN 100 (Malar Hc.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALARCIN 100 (Malar Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALARCIN 500 (Malar Hc.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALARCIN 500 (Malar Hc.)'
);

-- line #1349
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAXIN 500 (Khushal Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAXIN 500 (Khushal Ph.)'
);

-- line #1350
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MBKACIN 250 (Piramal Hc.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MBKACIN 250 (Piramal Hc.)'
);

-- line #1351
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MBKACIN 500 (Piramal Hc.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MBKACIN 500 (Piramal Hc.)'
);

-- line #1352
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100', u'strength_2': u'', u'substance': u'Amikacin', u'always_empty': u'', u'form': u'', u'brand': u'MBKACIN', u'strength_3': u'', u'company': u'Piramal Hc.', u'unit': u'mg'}

-- line #1353
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MCI 100 (Ravian)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MCI 100 (Ravian)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MCI 250 (Ravian)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MCI 250 (Ravian)'
);

-- line #1354
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MCI 500 (Ravian)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MCI 500 (Ravian)'
);

-- line #1355
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEFTIK 100 (Mefro Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEFTIK 100 (Mefro Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEFTIK 250 (Mefro Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEFTIK 250 (Mefro Ph.)'
);

-- line #1356
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEFTIK 500 (Mefro Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEFTIK 500 (Mefro Ph.)'
);

-- line #1357
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGAMICA 100 (Mapra)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGAMICA 100 (Mapra)'
);

-- line #1358
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGAMICA 250 (Mapra)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGAMICA 250 (Mapra)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGAMICA 500 (Mapra)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGAMICA 500 (Mapra)'
);

-- line #1359
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGAMICA 25 (Mapra)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGAMICA 25 (Mapra)'
);

-- line #1360
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGAMIKA 25 (Mapra)',
	'Amikacin',
	'AMP',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGAMIKA 25 (Mapra)'
);

-- line #1361
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGAMIKA 100 (Mapra)',
	'Amikacin',
	'V',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGAMIKA 100 (Mapra)'
);

-- line #1362
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGAMIKA 250 (Mapra)',
	'Amikacin',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGAMIKA 250 (Mapra)'
);

-- line #1363
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGAMIKA 500 (Mapra)',
	'Amikacin',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGAMIKA 500 (Mapra)'
);

-- line #1364
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICA 100 (Brawn Lab)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICA 100 (Brawn Lab)'
);

-- line #1365
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICA 250 (Brawn Lab)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICA 250 (Brawn Lab)'
);

-- line #1366
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICA 500 (Brawn Lab)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICA 500 (Brawn Lab)'
);

-- line #1367
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICAMAX 500 (R.B.REM.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICAMAX 500 (R.B.REM.)'
);

-- line #1368
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICIN 250 (Csc Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICIN 250 (Csc Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICIN 500 (Csc Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICIN 500 (Csc Ph.)'
);

-- line #1369
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIDAL 100 (Dallas Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIDAL 100 (Dallas Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIDAL 500 (Dallas Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIDAL 500 (Dallas Ph.)'
);

-- line #1370
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIKABEST 100 (Bestochem)',
	'Amikacin',
	'VIAL',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIKABEST 100 (Bestochem)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIKABEST 250 (Bestochem)',
	'Amikacin',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIKABEST 250 (Bestochem)'
);

-- line #1371
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIKABEST 500 (Bestochem)',
	'Amikacin',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIKABEST 500 (Bestochem)'
);

-- line #1372
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIKABIT 100 (Cubit Hc.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIKABIT 100 (Cubit Hc.)'
);

-- line #1373
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIKABIT 250 (Cubit Hc.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIKABIT 250 (Cubit Hc.)'
);

-- line #1374
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIKABIT 500 (Cubit Hc.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIKABIT 500 (Cubit Hc.)'
);

-- line #1375
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIKACIN 100 (Aristo)',
	'Amikacin',
	'V',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIKACIN 100 (Aristo)'
);

-- line #1376
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIKACIN 250 (Aristo)',
	'Amikacin',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIKACIN 250 (Aristo)'
);

-- line #1377
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIKACIN 500 (Aristo)',
	'Amikacin',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIKACIN 500 (Aristo)'
);

-- line #1378
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIKAFINE 100 (Finecure)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIKAFINE 100 (Finecure)'
);

-- line #1379
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIKAFINE 250 (Finecure)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIKAFINE 250 (Finecure)'
);

-- line #1380
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIKAFINE 500 (Finecure)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIKAFINE 500 (Finecure)'
);

-- line #1381
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIKA 100 (Oscar Rem.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIKA 100 (Oscar Rem.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIKA 250 (Oscar Rem.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIKA 250 (Oscar Rem.)'
);

-- line #1382
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIKA 500 (Oscar Rem.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIKA 500 (Oscar Rem.)'
);

-- line #1383
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIKAJECT 100 (Troikaa)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIKAJECT 100 (Troikaa)'
);

-- line #1384
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIKAJECT 250 (Troikaa)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIKAJECT 250 (Troikaa)'
);

-- line #1385
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIKAJECT 500 (Troikaa)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIKAJECT 500 (Troikaa)'
);

-- line #1386
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIKARED 100 (Redson)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIKARED 100 (Redson)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIKARED 250 (Redson)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIKARED 250 (Redson)'
);

-- line #1387
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIKARED 500 (Redson)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIKARED 500 (Redson)'
);

-- line #1388
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIKARED 125 (Redson)',
	'Amikacin',
	'V',
	gm.nullify_empty_string('125')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIKARED 125 (Redson)'
);

-- line #1389
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIKARED 250 (Redson)',
	'Amikacin',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIKARED 250 (Redson)'
);

-- line #1390
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIKARED 50 (Redson)',
	'Amikacin',
	'V',
	gm.nullify_empty_string('50')::numeric,
	'mg /ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIKARED 50 (Redson)'
);

-- line #1391
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIKAROM 100 (Rhombus)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIKAROM 100 (Rhombus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIKAROM 250 (Rhombus)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIKAROM 250 (Rhombus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIKAROM 500 (Rhombus)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIKAROM 500 (Rhombus)'
);

-- line #1392
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIKASET 100 (TALENT LAB.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIKASET 100 (TALENT LAB.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIKASET 250 (TALENT LAB.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIKASET 250 (TALENT LAB.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIKASET 500 (TALENT LAB.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIKASET 500 (TALENT LAB.)'
);

-- line #1393
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIKASTAR 100 (Mankind)',
	'Amikacin',
	'V',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIKASTAR 100 (Mankind)'
);

-- line #1394
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIKASTAR 250 (Mankind)',
	'Amikacin',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIKASTAR 250 (Mankind)'
);

-- line #1395
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIKASTAR 500 (Mankind)',
	'Amikacin',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIKASTAR 500 (Mankind)'
);

-- line #1396
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIKATAX 100 (ALKEM)',
	'Amikacin',
	'VIAL',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIKATAX 100 (ALKEM)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIKATAX 250 (ALKEM)',
	'Amikacin',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIKATAX 250 (ALKEM)'
);

-- line #1397
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIKATAX 500 (ALKEM)',
	'Amikacin',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIKATAX 500 (ALKEM)'
);

-- line #1398
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIKEP 100 (Kepsee)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIKEP 100 (Kepsee)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIKEP 250 (Kepsee)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIKEP 250 (Kepsee)'
);

-- line #1399
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIKEP 500 (Kepsee)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIKEP 500 (Kepsee)'
);

-- line #1400
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIK 100 (Galpha)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIK 100 (Galpha)'
);

-- line #1401
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIK 250 (Galpha)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIK 250 (Galpha)'
);

-- line #1402
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIK 500 (Galpha)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIK 500 (Galpha)'
);

-- line #1403
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIKOZ 100 (Vivid Lab)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIKOZ 100 (Vivid Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIKOZ 250 (Vivid Lab)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIKOZ 250 (Vivid Lab)'
);

-- line #1404
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIKOZ 500 (Vivid Lab)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIKOZ 500 (Vivid Lab)'
);

-- line #1405
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILAMIK 250 (Elder)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILAMIK 250 (Elder)'
);

-- line #1406
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILAMIK 500 (Elder)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILAMIK 500 (Elder)'
);

-- line #1407
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MINAKIN 100 (Dolphin)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MINAKIN 100 (Dolphin)'
);

-- line #1408
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MINAKIN 250 (Dolphin)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MINAKIN 250 (Dolphin)'
);

-- line #1409
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MINAKIN 500 (Dolphin)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MINAKIN 500 (Dolphin)'
);

-- line #1410
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MINOCIN 100 (Vega Lab)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MINOCIN 100 (Vega Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MINOCIN 250 (Vega Lab)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MINOCIN 250 (Vega Lab)'
);

-- line #1411
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MINOCIN 500 (Vega Lab)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MINOCIN 500 (Vega Lab)'
);

-- line #1412
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOCIN 100 (Maan)',
	'Amikacin',
	'V',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOCIN 100 (Maan)'
);

-- line #1413
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOCIN 250 (Maan)',
	'Amikacin',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOCIN 250 (Maan)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOCIN 500 (Maan)',
	'Amikacin',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOCIN 500 (Maan)'
);

-- line #1414
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOCIN 500 (Maan)',
	'Amikacin',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOCIN 500 (Maan)'
);

-- line #1415
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYKIN 100 (Solitaire)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYKIN 100 (Solitaire)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYKIN 250 (Solitaire)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYKIN 250 (Solitaire)'
);

-- line #1416
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYKIN 500 (Solitaire)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYKIN 500 (Solitaire)'
);

-- line #1417
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYOKAN 100 (Ophthal R.)',
	'Amikacin',
	'V',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYOKAN 100 (Ophthal R.)'
);

-- line #1418
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYOKAN 250 (Ophthal R.)',
	'Amikacin',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYOKAN 250 (Ophthal R.)'
);

-- line #1419
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYOKAN 500 (Ophthal R.)',
	'Amikacin',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYOKAN 500 (Ophthal R.)'
);

-- line #1420
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIACIN 100 (Nac Int.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIACIN 100 (Nac Int.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIACIN 250 (Nac Int.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIACIN 250 (Nac Int.)'
);

-- line #1421
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIACIN 500 (Nac Int.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIACIN 500 (Nac Int.)'
);

-- line #1422
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NICAKIM 100 (Pfiscar Ind.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NICAKIM 100 (Pfiscar Ind.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NICAKIM 250 (Pfiscar Ind.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NICAKIM 250 (Pfiscar Ind.)'
);

-- line #1423
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NICAKIM 500 (Pfiscar Ind.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NICAKIM 500 (Pfiscar Ind.)'
);

-- line #1424
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NICIN 100 (Nitin Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NICIN 100 (Nitin Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NICIN 250 (Nitin Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NICIN 250 (Nitin Ph.)'
);

-- line #1425
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NICIN 500 (Nitin Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NICIN 500 (Nitin Ph.)'
);

-- line #1426
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIKA 100 (Briskon)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIKA 100 (Briskon)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIKA 500 (Briskon)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIKA 500 (Briskon)'
);

-- line #1427
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIK 100 (Sanjeevani Bio.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIK 100 (Sanjeevani Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIK 500 (Sanjeevani Bio.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIK 500 (Sanjeevani Bio.)'
);

-- line #1428
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMICIN 100 (Emcure)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMICIN 100 (Emcure)'
);

-- line #1429
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMICIN 250 (Emcure)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMICIN 250 (Emcure)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMICIN 500 (Emcure)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMICIN 500 (Emcure)'
);

-- line #1430
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NISKACIN 500 (NEISS)',
	'Amikacin',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NISKACIN 500 (NEISS)'
);

-- line #1431
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOSOMIK 100 (Aglowmed)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOSOMIK 100 (Aglowmed)'
);

-- line #1432
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOSOMIK 250 (Aglowmed)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'500'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOSOMIK 250 (Aglowmed)'
);

-- line #1433
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVACIN 100 (Radicura)',
	'Amikacin',
	'VIAL',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVACIN 100 (Radicura)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVACIN 250 (Radicura)',
	'Amikacin',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVACIN 250 (Radicura)'
);

-- line #1434
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVACIN 500 (Radicura)',
	'Amikacin',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVACIN 500 (Radicura)'
);

-- line #1435
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVAMIC 100 (Novagen Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVAMIC 100 (Novagen Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVAMIC 250 (Novagen Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVAMIC 250 (Novagen Ph.)'
);

-- line #1436
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVAMIC 500 (Novagen Ph.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVAMIC 500 (Novagen Ph.)'
);

-- line #1437
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMIKIN 100 (Om Bio.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMIKIN 100 (Om Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMIKIN 250 (Om Bio.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMIKIN 250 (Om Bio.)'
);

-- line #1438
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMIKIN 500 (Om Bio.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMIKIN 500 (Om Bio.)'
);

-- line #1439
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMNIKACIN 100 (Cipla)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMNIKACIN 100 (Cipla)'
);

-- line #1440
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMNIKACIN 250 (Cipla)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMNIKACIN 250 (Cipla)'
);

-- line #1441
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMNIKACIN 500 (Cipla)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMNIKACIN 500 (Cipla)'
);

-- line #1442
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORKACIN 100 (Orchid Hc.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORKACIN 100 (Orchid Hc.)'
);

-- line #1443
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORKACIN 250 (Orchid Hc.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORKACIN 250 (Orchid Hc.)'
);

-- line #1444
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORKACIN 500 (Orchid Hc.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORKACIN 500 (Orchid Hc.)'
);

-- line #1445
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARK 100 (MADHAV BIO.)',
	'Amikacin',
	'VIAL',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARK 100 (MADHAV BIO.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARK 250 (MADHAV BIO.)',
	'Amikacin',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARK 250 (MADHAV BIO.)'
);

-- line #1446
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARK 500 (MADHAV BIO.)',
	'Amikacin',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARK 500 (MADHAV BIO.)'
);

-- line #1447
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIMIKACIN 100 (Hal)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIMIKACIN 100 (Hal)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIMIKACIN 500 (Hal)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIMIKACIN 500 (Hal)'
);

-- line #1448
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROCIN 100 (Prohealth)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROCIN 100 (Prohealth)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROCIN 250 (Prohealth)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROCIN 250 (Prohealth)'
);

-- line #1449
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROCIN 500 (Prohealth)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROCIN 500 (Prohealth)'
);

-- line #1450
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RANICIN 100 (Dynamic)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RANICIN 100 (Dynamic)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RANICIN 250 (Dynamic)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RANICIN 250 (Dynamic)'
);

-- line #1451
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RANICIN 500 (Dynamic)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RANICIN 500 (Dynamic)'
);

-- line #1452
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REOKIN 500 (Radix Bio.)',
	'Amikacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REOKIN 500 (Radix Bio.)'
);

-- line #1453
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIKARAS 100 (RASS HC.)',
	'Amikacin',
	'VIAL',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIKARAS 100 (RASS HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIKARAS 250 (RASS HC.)',
	'Amikacin',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIKARAS 250 (RASS HC.)'
);

-- line #1454
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIKARAS 500 (RASS HC.)',
	'Amikacin',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIKARAS 500 (RASS HC.)'
);

-- line #1455
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Aminacrine Hcl.', u'always_empty': u'', u'form': u'CRM', u'brand': u'ACRINOL', u'strength_3': u'', u'company': u'Unicure', u'unit': u''}

-- line #1456
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALAMIN 5.32 (Albert D.)',
	'Amino Acids',
	'SN INF',
	gm.nullify_empty_string('5.32')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALAMIN 5.32 (Albert D.)'
);

-- line #1457
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'ESSENTIAL AMINO ACIDS', u'strength_2': u'', u'substance': u'Amino Acids', u'always_empty': u'', u'form': u'TAB', u'brand': u'LAMINO', u'strength_3': u'', u'company': u'LA RENON', u'unit': u''}

-- line #1458
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIRMIN HEPA % 8 (NIRLIFE HEALTH)',
	'Amino Acids',
	'INF',
	gm.nullify_empty_string('8')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIRMIN HEPA % 8 (NIRLIFE HEALTH)'
);

-- line #1459
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIRMIN NEPHRO 7 (NIRLIFE HEALTH)',
	'Amino Acids',
	'INF',
	gm.nullify_empty_string('7')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIRMIN NEPHRO 7 (NIRLIFE HEALTH)'
);

-- line #1460
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIRMIN PLUS 10 (NIRLIFE HEALTH)',
	'Amino Acids',
	'INF',
	gm.nullify_empty_string('10')::numeric,
	'%W/V WITH ELECTORLYTES'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIRMIN PLUS 10 (NIRLIFE HEALTH)'
);

-- line #1461
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIRMIN -S 5 (NIRLIFE HEALTH)',
	'Amino Acids',
	'INF',
	gm.nullify_empty_string('5')::numeric,
	'%W/V AND SORBITOL 5'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIRMIN -S 5 (NIRLIFE HEALTH)'
);

-- line #1462
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5', u'strength_2': u'', u'substance': u'Aminocaproic Acid', u'always_empty': u'', u'form': u'', u'brand': u'AMOCAP', u'strength_3': u'', u'company': u'CELON(REVILON)', u'unit': u'mg'}

-- line #1463
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HAMOSTAT 500 (Samarth)',
	'Aminocaproic Acid',
	'AMP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HAMOSTAT 500 (Samarth)'
);

-- line #1464
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5G', u'strength_2': u'', u'substance': u'Aminocaproic Acid', u'always_empty': u'', u'form': u'V', u'brand': u'HAMOSTAT', u'strength_3': u'', u'company': u'Samarth', u'unit': u''}

-- line #1465
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEMOCID 250 (Gsk)',
	'Aminocaproic Acid',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEMOCID 250 (Gsk)'
);

-- line #1466
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMINOPHYLLINE 250 (Gsk)',
	'Aminophylline',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMINOPHYLLINE 250 (Gsk)'
);

-- line #1467
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMINOPHYLLINE 100 (Gsk)',
	'Aminophylline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMINOPHYLLINE 100 (Gsk)'
);

-- line #1468
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MINOPHYL 25 (Neon)',
	'Aminophylline',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/MI'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MINOPHYL 25 (Neon)'
);

-- line #1469
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MINOPHYL 100 (Neon)',
	'Aminophylline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MINOPHYL 100 (Neon)'
);

-- line #1470
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'225', u'strength_2': u'', u'substance': u'Aminophylline', u'always_empty': u'', u'form': u'', u'brand': u'PHYLLOCONTIN', u'strength_3': u'', u'company': u'Modi Mundi', u'unit': u'mg(HYDR.)'}

-- line #1471
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'350', u'strength_2': u'', u'substance': u'Aminophylline', u'always_empty': u'', u'form': u'', u'brand': u'PHYLLOCONTIN', u'strength_3': u'', u'company': u'Modi Mundi', u'unit': u'mg(HYDR.)'}

-- line #1472
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALDARONE 50 (Zydus A.)',
	'Amiodarone Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALDARONE 50 (Zydus A.)'
);

-- line #1473
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALDARONE 200 (Zydus A.)',
	'Amiodarone Hcl.',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALDARONE 200 (Zydus A.)'
);

-- line #1474
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIODAR 100 (Cardicare)',
	'Amiodarone Hcl.',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIODAR 100 (Cardicare)'
);

-- line #1475
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIODAR 200 (Cardicare)',
	'Amiodarone Hcl.',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIODAR 200 (Cardicare)'
);

-- line #1476
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIODON 50 (Neon)',
	'Amiodarone Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg(BENZYL ALCOHOL 2'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIODON 50 (Neon)'
);

-- line #1477
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIODON 50 (Vhb)',
	'Amiodarone Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/3ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIODON 50 (Vhb)'
);

-- line #1478
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIPACE 100 (Lupin)',
	'Amiodarone Hcl.',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIPACE 100 (Lupin)'
);

-- line #1479
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIPACE 200 (Lupin)',
	'Amiodarone Hcl.',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIPACE 200 (Lupin)'
);

-- line #1480
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDASOL 150 (SG PH.)',
	'Amiodarone Hcl.',
	'AMP',
	gm.nullify_empty_string('150')::numeric,
	'mg/3ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDASOL 150 (SG PH.)'
);

-- line #1481
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDICHEK 50 (Gland Ph.)',
	'Amiodarone Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDICHEK 50 (Gland Ph.)'
);

-- line #1482
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORDARONE 50 (Sanofi Aventis)',
	'Amiodarone Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORDARONE 50 (Sanofi Aventis)'
);

-- line #1483
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORDARONE 100 (Sanofi Aventis)',
	'Amiodarone Hcl.',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORDARONE 100 (Sanofi Aventis)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORDARONE 200 (Sanofi Aventis)',
	'Amiodarone Hcl.',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORDARONE 200 (Sanofi Aventis)'
);

-- line #1484
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Amiodarone Hcl.', u'always_empty': u'', u'form': u'INJ', u'brand': u'CORDASOL', u'strength_3': u'', u'company': u'SG PH.', u'unit': u''}

-- line #1485
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DURON 150 (Samarth)',
	'Amiodarone Hcl.',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DURON 150 (Samarth)'
);

-- line #1486
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DURON 100 (Samarth)',
	'Amiodarone Hcl.',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DURON 100 (Samarth)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DURON 200 (Samarth)',
	'Amiodarone Hcl.',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DURON 200 (Samarth)'
);

-- line #1487
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Amiodarone Hcl.', u'always_empty': u'', u'form': u'INJ', u'brand': u'EURTHMIC', u'strength_3': u'', u'company': u'Troikaa', u'unit': u''}

-- line #1488
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EURYTHMIC 50 (Troikaa)',
	'Amiodarone Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EURYTHMIC 50 (Troikaa)'
);

-- line #1489
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EURYTHMIC PFS 50 (Troikaa)',
	'Amiodarone Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EURYTHMIC PFS 50 (Troikaa)'
);

-- line #1490
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EURYTHMIC 100 (Troikaa)',
	'Amiodarone Hcl.',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EURYTHMIC 100 (Troikaa)'
);

-- line #1491
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EURYTHMIC 200 (Troikaa)',
	'Amiodarone Hcl.',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EURYTHMIC 200 (Troikaa)'
);

-- line #1492
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PACENORM-I 50 (Emcure)',
	'Amiodarone Hcl.',
	'V',
	gm.nullify_empty_string('50')::numeric,
	'mg(+BENZYL ALCOHOL 85.2'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PACENORM-I 50 (Emcure)'
);

-- line #1493
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PACENORM 100 (Emcure)',
	'Amiodarone Hcl.',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PACENORM 100 (Emcure)'
);

-- line #1494
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PACENORM 200 (Emcure)',
	'Amiodarone Hcl.',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PACENORM 200 (Emcure)'
);

-- line #1495
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANARONE 100 (Panacea)',
	'Amiodarone Hcl.',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANARONE 100 (Panacea)'
);

-- line #1496
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANARONE 200 (Panacea)',
	'Amiodarone Hcl.',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANARONE 200 (Panacea)'
);

-- line #1497
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Amiodarone Hcl.', u'always_empty': u'', u'form': u'TAB', u'brand': u'PANARON', u'strength_3': u'', u'company': u'Khandelwal', u'unit': u''}

-- line #1498
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMAZEO 100 (Torrent)',
	'AMISULPRIDE',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMAZEO 100 (Torrent)'
);

-- line #1499
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMAZEO 200 (Torrent)',
	'AMISULPRIDE',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMAZEO 200 (Torrent)'
);

-- line #1500
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMAZEO 400 (Torrent)',
	'AMISULPRIDE',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMAZEO 400 (Torrent)'
);

-- line #1501
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMAZEO 50 (Torrent)',
	'AMISULPRIDE',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMAZEO 50 (Torrent)'
);

-- line #1502
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMAZEO 200 (Torrent)',
	'AMISULPRIDE',
	'OD TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMAZEO 200 (Torrent)'
);

-- line #1503
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMAZEO 400 (Torrent)',
	'AMISULPRIDE',
	'OD TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMAZEO 400 (Torrent)'
);

-- line #1504
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMAZEO 100 (Torrent)',
	'AMISULPRIDE',
	'OD',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMAZEO 100 (Torrent)'
);

-- line #1505
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMGRACE 100 (LA DRUG)',
	'AMISULPRIDE',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMGRACE 100 (LA DRUG)'
);

-- line #1506
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMGRACE 200 (LA DRUG)',
	'AMISULPRIDE',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMGRACE 200 (LA DRUG)'
);

-- line #1507
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMGRACE 50 (LA DRUG)',
	'AMISULPRIDE',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMGRACE 50 (LA DRUG)'
);

-- line #1508
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50', u'strength_2': u'', u'substance': u'AMISULPRIDE', u'always_empty': u'', u'form': u'', u'brand': u'AMICALM', u'strength_3': u'', u'company': u'Triton', u'unit': u'mg'}

-- line #1509
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIGOLD 100 (Lupin)',
	'AMISULPRIDE',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIGOLD 100 (Lupin)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIGOLD 200 (Lupin)',
	'AMISULPRIDE',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIGOLD 200 (Lupin)'
);

-- line #1510
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIGOLD 50 (Lupin)',
	'AMISULPRIDE',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIGOLD 50 (Lupin)'
);

-- line #1511
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMISYT 50 (EAST WEST)',
	'AMISULPRIDE',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMISYT 50 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMISYT 100 (EAST WEST)',
	'AMISULPRIDE',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMISYT 100 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMISYT 200 (EAST WEST)',
	'AMISULPRIDE',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMISYT 200 (EAST WEST)'
);

-- line #1512
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIVAL 100 (Ranbaxy)',
	'AMISULPRIDE',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIVAL 100 (Ranbaxy)'
);

-- line #1513
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIVAL 200 (Ranbaxy)',
	'AMISULPRIDE',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIVAL 200 (Ranbaxy)'
);

-- line #1514
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIVAL 50 (Ranbaxy)',
	'AMISULPRIDE',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIVAL 50 (Ranbaxy)'
);

-- line #1515
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100', u'strength_2': u'', u'substance': u'AMISULPRIDE', u'always_empty': u'', u'form': u'', u'brand': u'CENRIDE', u'strength_3': u'', u'company': u'USV CENTRA', u'unit': u'mg'}

-- line #1516
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200', u'strength_2': u'', u'substance': u'AMISULPRIDE', u'always_empty': u'', u'form': u'', u'brand': u'CENRIDE', u'strength_3': u'', u'company': u'USV CENTRA', u'unit': u'mg'}

-- line #1517
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100', u'strength_2': u'', u'substance': u'AMISULPRIDE', u'always_empty': u'', u'form': u'', u'brand': u'KIVIPRIDE', u'strength_3': u'', u'company': u'KIVI HC.', u'unit': u'mg'}

-- line #1518
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50', u'strength_2': u'', u'substance': u'AMISULPRIDE', u'always_empty': u'', u'form': u'', u'brand': u'KIVIPRIDE', u'strength_3': u'', u'company': u'KIVI HC.', u'unit': u'mg'}

-- line #1519
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100', u'strength_2': u'', u'substance': u'AMISULPRIDE', u'always_empty': u'', u'form': u'', u'brand': u'MAXPRIDE', u'strength_3': u'', u'company': u'Micro Labs', u'unit': u'mg'}

-- line #1520
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50', u'strength_2': u'', u'substance': u'AMISULPRIDE', u'always_empty': u'', u'form': u'', u'brand': u'MAXPRIDE', u'strength_3': u'', u'company': u'Micro Labs', u'unit': u'mg'}

-- line #1521
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOSULF 100 (MOVA PH.)',
	'AMISULPRIDE',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOSULF 100 (MOVA PH.)'
);

-- line #1522
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOSULF 50 (MOVA PH.)',
	'AMISULPRIDE',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOSULF 50 (MOVA PH.)'
);

-- line #1523
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORMENTA 100 (Ipca)',
	'AMISULPRIDE',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORMENTA 100 (Ipca)'
);

-- line #1524
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORMENTA 200 (Ipca)',
	'AMISULPRIDE',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORMENTA 200 (Ipca)'
);

-- line #1525
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORMENTA 300 (Ipca)',
	'AMISULPRIDE',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORMENTA 300 (Ipca)'
);

-- line #1526
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORMENTA 400 (Ipca)',
	'AMISULPRIDE',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORMENTA 400 (Ipca)'
);

-- line #1527
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORMENTA 50 (Ipca)',
	'AMISULPRIDE',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORMENTA 50 (Ipca)'
);

-- line #1528
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PSYTAS-100 100 (Tasmed)',
	'AMISULPRIDE',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PSYTAS-100 100 (Tasmed)'
);

-- line #1529
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PSYTAS-50 50 (Tasmed)',
	'AMISULPRIDE',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PSYTAS-50 50 (Tasmed)'
);

-- line #1530
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ABAMAX 25 (Cyper Ph.)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ABAMAX 25 (Cyper Ph.)'
);

-- line #1531
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMILITE 10 (Elite Ph.)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMILITE 10 (Elite Ph.)'
);

-- line #1532
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMILITE 25 (Elite Ph.)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMILITE 25 (Elite Ph.)'
);

-- line #1533
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMILITE 75 (Elite Ph.)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMILITE 75 (Elite Ph.)'
);

-- line #1534
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIT 10 (Mano)',
	'Amitriptyline',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIT 10 (Mano)'
);

-- line #1535
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMITONE 10 (Intas)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMITONE 10 (Intas)'
);

-- line #1536
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMITONE 25 (Intas)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMITONE 25 (Intas)'
);

-- line #1537
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMITONE 75 (Intas)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMITONE 75 (Intas)'
);

-- line #1538
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMITOR 50 (Torrent)',
	'Amitriptyline',
	'SR TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMITOR 50 (Torrent)'
);

-- line #1539
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMITOR 10 (Torrent)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMITOR 10 (Torrent)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMITOR 25 (Torrent)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMITOR 25 (Torrent)'
);

-- line #1540
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMITOR 75 (Torrent)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMITOR 75 (Torrent)'
);

-- line #1541
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMITRAC 25 (MINOVA(PSYCHONOVA))',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMITRAC 25 (MINOVA(PSYCHONOVA))'
);

-- line #1542
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMITRIP 10 (EAST WEST)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMITRIP 10 (EAST WEST)'
);

-- line #1543
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMITRIP 25 (EAST WEST)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMITRIP 25 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMITRIP 50 (EAST WEST)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMITRIP 50 (EAST WEST)'
);

-- line #1544
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMITRIP 75 (EAST WEST)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMITRIP 75 (EAST WEST)'
);

-- line #1545
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMITRYN 10 (K.C. Lab)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMITRYN 10 (K.C. Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMITRYN 25 (K.C. Lab)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMITRYN 25 (K.C. Lab)'
);

-- line #1546
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMITRYN 50 (K.C. Lab)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMITRYN 50 (K.C. Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMITRYN 75 (K.C. Lab)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMITRYN 75 (K.C. Lab)'
);

-- line #1547
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIT 10 (Mano)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIT 10 (Mano)'
);

-- line #1548
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIT 25 (Mano)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIT 25 (Mano)'
);

-- line #1549
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIT 50 (Mano)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIT 50 (Mano)'
);

-- line #1550
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIT 75 (Mano)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIT 75 (Mano)'
);

-- line #1551
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLINE 10 (Torrent)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLINE 10 (Torrent)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLINE 25 (Torrent)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLINE 25 (Torrent)'
);

-- line #1552
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLINE 75 (Torrent)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLINE 75 (Torrent)'
);

-- line #1553
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMYPRES 25 (PSYCOREM)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMYPRES 25 (PSYCOREM)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMYPRES 50 (PSYCOREM)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMYPRES 50 (PSYCOREM)'
);

-- line #1554
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMYPRES 75 (PSYCOREM)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMYPRES 75 (PSYCOREM)'
);

-- line #1555
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANITRYP 10 (Anikem Lab.)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANITRYP 10 (Anikem Lab.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANITRYP 25 (Anikem Lab.)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANITRYP 25 (Anikem Lab.)'
);

-- line #1556
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CENTRYP 25 (U S V)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CENTRYP 25 (U S V)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CENTRYP 75 (U S V)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CENTRYP 75 (U S V)'
);

-- line #1557
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIPROL 25 (Olcare)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIPROL 25 (Olcare)'
);

-- line #1558
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELAVIL 10 (Cyril Ph.)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'25'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELAVIL 10 (Cyril Ph.)'
);

-- line #1559
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELAVIL 50 (Cyril Ph.)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'75'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELAVIL 50 (Cyril Ph.)'
);

-- line #1560
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELIWEL 10 (Sun)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELIWEL 10 (Sun)'
);

-- line #1561
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELIWEL 25 (Sun)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELIWEL 25 (Sun)'
);

-- line #1562
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELIWEL 75 (Sun)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELIWEL 75 (Sun)'
);

-- line #1563
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELMO 10 (Shaimil)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELMO 10 (Shaimil)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELMO 25 (Shaimil)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELMO 25 (Shaimil)'
);

-- line #1564
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELMO 75 (Shaimil)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELMO 75 (Shaimil)'
);

-- line #1565
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GOLDEP 10 (Glenmark)',
	'Amitriptyline',
	'SR TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GOLDEP 10 (Glenmark)'
);

-- line #1566
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GOLDEP 25 (Glenmark)',
	'Amitriptyline',
	'SR TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GOLDEP 25 (Glenmark)'
);

-- line #1567
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GOLDEP 75 (Glenmark)',
	'Amitriptyline',
	'SR TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GOLDEP 75 (Glenmark)'
);

-- line #1568
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HARWEL 10 (Taurus Lab)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HARWEL 10 (Taurus Lab)'
);

-- line #1569
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HARWEL 25 (Taurus Lab)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HARWEL 25 (Taurus Lab)'
);

-- line #1570
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HARWEL 75 (Taurus Lab)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HARWEL 75 (Taurus Lab)'
);

-- line #1571
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KAMITRIN 25 (Saga Lab)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KAMITRIN 25 (Saga Lab)'
);

-- line #1572
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LATILIN 25 (LA DRUG)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LATILIN 25 (LA DRUG)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LATILIN 50 (LA DRUG)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LATILIN 50 (LA DRUG)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LATILIN 75 (LA DRUG)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LATILIN 75 (LA DRUG)'
);

-- line #1573
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MITRA-25 25 (ROSE LABS)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MITRA-25 25 (ROSE LABS)'
);

-- line #1574
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MITRA 25 (ROSE LABS)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MITRA 25 (ROSE LABS)'
);

-- line #1575
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MITRIP 25 (OREVA DARMO.)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MITRIP 25 (OREVA DARMO.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MITRIP 50 (OREVA DARMO.)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MITRIP 50 (OREVA DARMO.)'
);

-- line #1576
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MITRYP 10 (BARODA)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MITRYP 10 (BARODA)'
);

-- line #1577
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODEP 10 (Crescent Th.)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODEP 10 (Crescent Th.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODEP 25 (Crescent Th.)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODEP 25 (Crescent Th.)'
);

-- line #1578
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODEP 50 (Crescent Th.)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODEP 50 (Crescent Th.)'
);

-- line #1579
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELIDEP 10 (Reliance)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELIDEP 10 (Reliance)'
);

-- line #1580
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELIDEP 25 (Reliance)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELIDEP 25 (Reliance)'
);

-- line #1581
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELIDEP 50 (Reliance)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELIDEP 50 (Reliance)'
);

-- line #1582
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELIDEP 75 (Reliance)',
	'Amitriptyline',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELIDEP 75 (Reliance)'
);

-- line #1583
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50', u'strength_2': u'', u'substance': u'AMLEXANOX', u'always_empty': u'', u'form': u'', u'brand': u'LEXANOX', u'strength_3': u'', u'company': u'Macleods', u'unit': u'mg'}

-- line #1584
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'A-1 5 (Patson)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'A-1 5 (Patson)'
);

-- line #1585
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AAMINS 5 (MEDISYS)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AAMINS 5 (MEDISYS)'
);

-- line #1586
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACORD-5 5 (Intra(INVISION))',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACORD-5 5 (Intra(INVISION))'
);

-- line #1587
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADBLOCK 5 (Olcare)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADBLOCK 5 (Olcare)'
);

-- line #1588
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADIPIN 10 (Sain Med.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADIPIN 10 (Sain Med.)'
);

-- line #1589
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADIPIN 2.5 (Sain Med.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADIPIN 2.5 (Sain Med.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADIPIN 5 (Sain Med.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADIPIN 5 (Sain Med.)'
);

-- line #1590
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADP 10 (Caplet Ind.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADP 10 (Caplet Ind.)'
);

-- line #1591
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADP 2.5 (Caplet Ind.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADP 2.5 (Caplet Ind.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADP 5 (Caplet Ind.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADP 5 (Caplet Ind.)'
);

-- line #1592
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AGLODEPIN 5 (Aglowmed)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AGLODEPIN 5 (Aglowmed)'
);

-- line #1593
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALDO 5 (SHINE PH.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALDO 5 (SHINE PH.)'
);

-- line #1594
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AM-5 5 (Orchid Hc.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AM-5 5 (Orchid Hc.)'
);

-- line #1595
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMADAY 10 (Ajanta Ph.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMADAY 10 (Ajanta Ph.)'
);

-- line #1596
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMADAY 2.5 (Ajanta Ph.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMADAY 2.5 (Ajanta Ph.)'
);

-- line #1597
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMADAY 5 (Ajanta Ph.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMADAY 5 (Ajanta Ph.)'
);

-- line #1598
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMANAT 10 (Sun)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMANAT 10 (Sun)'
);

-- line #1599
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMANAT 5 (Sun)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMANAT 5 (Sun)'
);

-- line #1600
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMCARDIA 2.5 (J. B. Chem.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMCARDIA 2.5 (J. B. Chem.)'
);

-- line #1601
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMCARDIA 5 (J. B. Chem.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMCARDIA 5 (J. B. Chem.)'
);

-- line #1602
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMCARD 10 (Systopic)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMCARD 10 (Systopic)'
);

-- line #1603
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMCARD 2.5 (Systopic)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMCARD 2.5 (Systopic)'
);

-- line #1604
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMCARD 5 (Systopic)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMCARD 5 (Systopic)'
);

-- line #1605
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMCA 5 (Prochem)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMCA 5 (Prochem)'
);

-- line #1606
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMCHECK 10 (Indoco Rem.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMCHECK 10 (Indoco Rem.)'
);

-- line #1607
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMCHECK 2.5 (Indoco Rem.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMCHECK 2.5 (Indoco Rem.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMCHECK 5 (Indoco Rem.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMCHECK 5 (Indoco Rem.)'
);

-- line #1608
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMCHEK 10 (Indoco Rem.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMCHEK 10 (Indoco Rem.)'
);

-- line #1609
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMCHEK 2.5 (Indoco Rem.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMCHEK 2.5 (Indoco Rem.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMCHEK 5 (Indoco Rem.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMCHEK 5 (Indoco Rem.)'
);

-- line #1610
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMDEPIN 10 (Irm Ph.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMDEPIN 10 (Irm Ph.)'
);

-- line #1611
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMDEPIN 2.5 (Irm Ph.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMDEPIN 2.5 (Irm Ph.)'
);

-- line #1612
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMDEPIN 5 (Irm Ph.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMDEPIN 5 (Irm Ph.)'
);

-- line #1613
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMDIP 5 (Dallas Ph.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMDIP 5 (Dallas Ph.)'
);

-- line #1614
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMFIRST 10 (SINSAN PH.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMFIRST 10 (SINSAN PH.)'
);

-- line #1615
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMFIRST 2.5 (SINSAN PH.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMFIRST 2.5 (SINSAN PH.)'
);

-- line #1616
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMFIRST 5 (SINSAN PH.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMFIRST 5 (SINSAN PH.)'
);

-- line #1617
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMICARDIA 10 (Noir)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMICARDIA 10 (Noir)'
);

-- line #1618
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMICARDIA 5 (Noir)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMICARDIA 5 (Noir)'
);

-- line #1619
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLAN-S 1.25 (VHB(CRONUS))',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('1.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLAN-S 1.25 (VHB(CRONUS))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLAN-S 2.5 (VHB(CRONUS))',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLAN-S 2.5 (VHB(CRONUS))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLAN-S 5 (VHB(CRONUS))',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLAN-S 5 (VHB(CRONUS))'
);

-- line #1620
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLAN 10 (VHB(CRONUS))',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLAN 10 (VHB(CRONUS))'
);

-- line #1621
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLAN 2.5 (VHB(CRONUS))',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLAN 2.5 (VHB(CRONUS))'
);

-- line #1622
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLAN 5 (VHB(CRONUS))',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLAN 5 (VHB(CRONUS))'
);

-- line #1623
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLIBON 2.5 (Novartis)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLIBON 2.5 (Novartis)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLIBON 5 (Novartis)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLIBON 5 (Novartis)'
);

-- line #1624
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLICA 10 (Cadex Lab)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLICA 10 (Cadex Lab)'
);

-- line #1625
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLICA 2.5 (Cadex Lab)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLICA 2.5 (Cadex Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLICA 5 (Cadex Lab)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLICA 5 (Cadex Lab)'
);

-- line #1626
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLIN 5 (Lincoln)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLIN 5 (Lincoln)'
);

-- line #1627
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLION 10 (Stallion)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLION 10 (Stallion)'
);

-- line #1628
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLION 5 (Stallion)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLION 5 (Stallion)'
);

-- line #1629
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLIP 5 (Cipla)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLIP 5 (Cipla)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLIP 10 (Cipla)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLIP 10 (Cipla)'
);

-- line #1630
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLO-5 5 (Taurus Lab)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLO-5 5 (Taurus Lab)'
);

-- line #1631
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOACT 2.5 (Active Hc.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOACT 2.5 (Active Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOACT 5 (Active Hc.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOACT 5 (Active Hc.)'
);

-- line #1632
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOBENZ 5 (ARCUS LABS)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOBENZ 5 (ARCUS LABS)'
);

-- line #1633
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOCAN 5 (Candor Bio.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOCAN 5 (Candor Bio.)'
);

-- line #1634
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOCARD-S 2.5 (Intra Lab)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg)S-AMLODIPINE'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOCARD-S 2.5 (Intra Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOCARD-S 5 (Intra Lab)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg)S-AMLODIPINE'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOCARD-S 5 (Intra Lab)'
);

-- line #1635
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLO CB 2.5 (SHRRISHTI HC.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLO CB 2.5 (SHRRISHTI HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLO CB 5 (SHRRISHTI HC.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLO CB 5 (SHRRISHTI HC.)'
);

-- line #1636
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLO-CB 2.5 (SHRRISHTI HC.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLO-CB 2.5 (SHRRISHTI HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLO-CB 5 (SHRRISHTI HC.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLO-CB 5 (SHRRISHTI HC.)'
);

-- line #1637
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOCOM 5 (Comed)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOCOM 5 (Comed)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOCOM 10 (Comed)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOCOM 10 (Comed)'
);

-- line #1638
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOCOM 2.5 (Comed Chem.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOCOM 2.5 (Comed Chem.)'
);

-- line #1639
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOCOR 10 (Torrent)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOCOR 10 (Torrent)'
);

-- line #1640
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOCOR 2.5 (Torrent)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOCOR 2.5 (Torrent)'
);

-- line #1641
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOCOR 5 (Torrent)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOCOR 5 (Torrent)'
);

-- line #1642
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOC 10 (Globus)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOC 10 (Globus)'
);

-- line #1643
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOC 5 (Globus)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOC 5 (Globus)'
);

-- line #1644
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLODAC 10 (Zydus A.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLODAC 10 (Zydus A.)'
);

-- line #1645
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLODAC 2.5 (Zydus A.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLODAC 2.5 (Zydus A.)'
);

-- line #1646
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLODAC 5 (Zydus A.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLODAC 5 (Zydus A.)'
);

-- line #1647
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOGARD 10 (Pfizer)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOGARD 10 (Pfizer)'
);

-- line #1648
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOGARD 2.5 (Pfizer)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOGARD 2.5 (Pfizer)'
);

-- line #1649
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOGARD 5 (Pfizer)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOGARD 5 (Pfizer)'
);

-- line #1650
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOGEN 10 (Alkem)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOGEN 10 (Alkem)'
);

-- line #1651
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOGEN 2.5 (Alkem)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOGEN 2.5 (Alkem)'
);

-- line #1652
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOGEN 5 (Alkem)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOGEN 5 (Alkem)'
);

-- line #1653
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOKATH 5 (Life Med.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOKATH 5 (Life Med.)'
);

-- line #1654
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOKIND 10 (Mankind)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOKIND 10 (Mankind)'
);

-- line #1655
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOKIND 2.5 (Mankind)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOKIND 2.5 (Mankind)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOKIND 5 (Mankind)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOKIND 5 (Mankind)'
);

-- line #1656
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOKOS 10 (R.B.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOKOS 10 (R.B.)'
);

-- line #1657
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOKOS 2.5 (R.B.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOKOS 2.5 (R.B.)'
);

-- line #1658
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOKOS 5 (R.B.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOKOS 5 (R.B.)'
);

-- line #1659
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOLAND 5 (L & V PH.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOLAND 5 (L & V PH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOLAND 10 (L & V PH.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOLAND 10 (L & V PH.)'
);

-- line #1660
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOL 10 (Themis Med.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOL 10 (Themis Med.)'
);

-- line #1661
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOL 5 (Themis Med.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOL 5 (Themis Med.)'
);

-- line #1662
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLONG 10 (Carsyon)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLONG 10 (Carsyon)'
);

-- line #1663
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLONG 2.5 (Carsyon)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLONG 2.5 (Carsyon)'
);

-- line #1664
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLONG 5 (Carsyon)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLONG 5 (Carsyon)'
);

-- line #1665
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLONG 7.5 (Carsyon)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLONG 7.5 (Carsyon)'
);

-- line #1666
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOPIN 10 (U S V)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOPIN 10 (U S V)'
);

-- line #1667
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOPIN 2.5 (U S V)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOPIN 2.5 (U S V)'
);

-- line #1668
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOPIN 5 (U S V)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOPIN 5 (U S V)'
);

-- line #1669
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOPRES 10 (Cipla)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOPRES 10 (Cipla)'
);

-- line #1670
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOPRES 2.5 (Cipla)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOPRES 2.5 (Cipla)'
);

-- line #1671
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOPRES 5 (Cipla)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOPRES 5 (Cipla)'
);

-- line #1672
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOSAFE 10 (Otsira)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOSAFE 10 (Otsira)'
);

-- line #1673
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOSAFE 2.5 (Otsira)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOSAFE 2.5 (Otsira)'
);

-- line #1674
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOSAFE 5 (Otsira)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOSAFE 5 (Otsira)'
);

-- line #1675
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOSTAT 5 (Biochem)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOSTAT 5 (Biochem)'
);

-- line #1676
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOSUN 10 (Sun)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOSUN 10 (Sun)'
);

-- line #1677
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOSUN 2.5 (Sun)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOSUN 2.5 (Sun)'
);

-- line #1678
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOSUN 5 (Sun)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOSUN 5 (Sun)'
);

-- line #1679
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOSYL 10 (Nicholas)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOSYL 10 (Nicholas)'
);

-- line #1680
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOSYL 2.5 (Nicholas)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOSYL 2.5 (Nicholas)'
);

-- line #1681
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOSYL 5 (Nicholas)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOSYL 5 (Nicholas)'
);

-- line #1682
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOSYN 5 (SYNAGE LC.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOSYN 5 (SYNAGE LC.)'
);

-- line #1683
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLO 10 (Mano)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLO 10 (Mano)'
);

-- line #1684
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLO 2.5 (Mano)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLO 2.5 (Mano)'
);

-- line #1685
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLO 5 (Mano)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLO 5 (Mano)'
);

-- line #1686
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLO 7.5 (Mano)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLO 7.5 (Mano)'
);

-- line #1687
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOTAB 5 (Cure Quick)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOTAB 5 (Cure Quick)'
);

-- line #1688
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOTRAC 2.5 (Intra Lab)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOTRAC 2.5 (Intra Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOTRAC 5 (Intra Lab)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOTRAC 5 (Intra Lab)'
);

-- line #1689
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOTRUST 2.5 (Centaur)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOTRUST 2.5 (Centaur)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOTRUST 5 (Centaur)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOTRUST 5 (Centaur)'
);

-- line #1690
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOT 10 (TRUMAC)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOT 10 (TRUMAC)'
);

-- line #1691
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOVAS 10 (Macleods)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOVAS 10 (Macleods)'
);

-- line #1692
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOVAS 2.5 (Macleods)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOVAS 2.5 (Macleods)'
);

-- line #1693
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOVAS 5 (Macleods)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOVAS 5 (Macleods)'
);

-- line #1694
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOVIN 2.5 (EAST WEST)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOVIN 2.5 (EAST WEST)'
);

-- line #1695
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOVIN 5 (EAST WEST)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOVIN 5 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOVIN 10 (EAST WEST)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOVIN 10 (EAST WEST)'
);

-- line #1696
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOZED 5 (Zota PH.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOZED 5 (Zota PH.)'
);

-- line #1697
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOZ 10 (Shreya)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOZ 10 (Shreya)'
);

-- line #1698
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOZ 2.5 (Shreya)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOZ 2.5 (Shreya)'
);

-- line #1699
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOZ 5 (Shreya)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOZ 5 (Shreya)'
);

-- line #1700
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMODEP 10 (F D C)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMODEP 10 (F D C)'
);

-- line #1701
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMODEP 5 (F D C)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMODEP 5 (F D C)'
);

-- line #1702
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMOM 5 (Riasma Life)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMOM 5 (Riasma Life)'
);

-- line #1703
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMONE 5 (TALENT PH.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMONE 5 (TALENT PH.)'
);

-- line #1704
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMOPINE 5 (Shinto Org.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMOPINE 5 (Shinto Org.)'
);

-- line #1705
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMOPIN 5 (Finecure)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMOPIN 5 (Finecure)'
);

-- line #1706
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMO 5 (TASMED)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg(BESYLATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMO 5 (TASMED)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMO 10 (TASMED)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg(BESYLATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMO 10 (TASMED)'
);

-- line #1707
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMPINE-RL 2.5 (SUNIJ PHARMA)',
	'Amlodipine',
	'CAP',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMPINE-RL 2.5 (SUNIJ PHARMA)'
);

-- line #1708
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMPINE 2.5 (Sunij)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMPINE 2.5 (Sunij)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMPINE 5 (Sunij)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMPINE 5 (Sunij)'
);

-- line #1709
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMPREZ 5 (Croslands)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMPREZ 5 (Croslands)'
);

-- line #1710
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10', u'strength_2': u'', u'substance': u'Amlodipine', u'always_empty': u'', u'form': u'', u'brand': u'AMPREZ TA', u'strength_3': u'', u'company': u'Croslands', u'unit': u'mg'}

-- line #1711
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMRAP 5 (Rapross)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg(BESYLATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMRAP 5 (Rapross)'
);

-- line #1712
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMSACH 10 (SPPL)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMSACH 10 (SPPL)'
);

-- line #1713
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMSACH 2.5 (SPPL)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMSACH 2.5 (SPPL)'
);

-- line #1714
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMSACH 5 (SPPL)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMSACH 5 (SPPL)'
);

-- line #1715
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMSET 5 (Pulse Ph.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMSET 5 (Pulse Ph.)'
);

-- line #1716
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMTAS 10 (Intas)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMTAS 10 (Intas)'
);

-- line #1717
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMTAS 2.5 (Intas)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMTAS 2.5 (Intas)'
);

-- line #1718
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMTAS 5 (Intas)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMTAS 5 (Intas)'
);

-- line #1719
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMZEL 5 (Zee Lab)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMZEL 5 (Zee Lab)'
);

-- line #1720
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANGICAM 2.5 (Blue Cross)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANGICAM 2.5 (Blue Cross)'
);

-- line #1721
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANGICAM 5 (Blue Cross)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANGICAM 5 (Blue Cross)'
);

-- line #1722
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANGIGUARD 5 (Ind-Swift)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANGIGUARD 5 (Ind-Swift)'
);

-- line #1723
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASOMEX 5 (Emcure)',
	'Amlodipine',
	'TM TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg(S(-)AMLODIPINE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASOMEX 5 (Emcure)'
);

-- line #1724
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5', u'strength_2': u'', u'substance': u'Amlodipine', u'always_empty': u'', u'form': u'TAB', u'brand': u'ATEMOS', u'strength_3': u'', u'company': u'GENESIS', u'unit': u''}

-- line #1725
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXCARD 5 (AXYZEN LIFE)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXCARD 5 (AXYZEN LIFE)'
);

-- line #1726
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BP-MIDE 5 (Elder)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BP-MIDE 5 (Elder)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BP-MIDE 10 (Elder)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BP-MIDE 10 (Elder)'
);

-- line #1727
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALCHEK 10 (Ipca)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALCHEK 10 (Ipca)'
);

-- line #1728
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALCHEK 2.5 (Ipca)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALCHEK 2.5 (Ipca)'
);

-- line #1729
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALCHEK 5 (Ipca)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALCHEK 5 (Ipca)'
);

-- line #1730
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALOCK 5 (Kapeetus)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALOCK 5 (Kapeetus)'
);

-- line #1731
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAMLODIP 10 (LA RENON)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAMLODIP 10 (LA RENON)'
);

-- line #1732
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAMLODIP 5 (LA RENON)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAMLODIP 5 (LA RENON)'
);

-- line #1733
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C AMLO 10 (Corona)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C AMLO 10 (Corona)'
);

-- line #1734
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C AMLO 5 (Corona)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C AMLO 5 (Corona)'
);

-- line #1735
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAMLO 10 (GRANDIX)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAMLO 10 (GRANDIX)'
);

-- line #1736
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAMLO 2.5 (GRANDIX)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAMLO 2.5 (GRANDIX)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAMLO 5 (GRANDIX)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAMLO 5 (GRANDIX)'
);

-- line #1737
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANDEZ 4 (Ind-Swift)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANDEZ 4 (Ind-Swift)'
);

-- line #1738
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANDEZ 8 (Ind-Swift)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANDEZ 8 (Ind-Swift)'
);

-- line #1739
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDIL 2.5 (Dial Ph.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDIL 2.5 (Dial Ph.)'
);

-- line #1740
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDIL 5 (Dial Ph.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDIL 5 (Dial Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDIL 10 (Dial Ph.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDIL 10 (Dial Ph.)'
);

-- line #1741
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDPIN 2.5 (Ultramark)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDPIN 2.5 (Ultramark)'
);

-- line #1742
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDPIN 5 (Ultramark)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDPIN 5 (Ultramark)'
);

-- line #1743
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARD 10 (Jagsonpal)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARD 10 (Jagsonpal)'
);

-- line #1744
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARD 2.5 (Jagsonpal)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARD 2.5 (Jagsonpal)'
);

-- line #1745
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARD 5 (Jagsonpal)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARD 5 (Jagsonpal)'
);

-- line #1746
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARD 5 (Rhombus)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARD 5 (Rhombus)'
);

-- line #1747
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARVASC 10 (Argus)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARVASC 10 (Argus)'
);

-- line #1748
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARVASC 5 (Argus)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARVASC 5 (Argus)'
);

-- line #1749
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORVADIL 10 (Unichem)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORVADIL 10 (Unichem)'
);

-- line #1750
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORVADIL 2.5 (Unichem)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORVADIL 2.5 (Unichem)'
);

-- line #1751
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORVADIL 5 (Unichem)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORVADIL 5 (Unichem)'
);

-- line #1752
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEFIDIN 5 (Lupin)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEFIDIN 5 (Lupin)'
);

-- line #1753
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIAVASC 5 (Biological E.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIAVASC 5 (Biological E.)'
);

-- line #1754
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILSAVE 4 (Lupin)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILSAVE 4 (Lupin)'
);

-- line #1755
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILSAVE 8 (Lupin)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILSAVE 8 (Lupin)'
);

-- line #1756
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIP 10 (Pentacare)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIP 10 (Pentacare)'
);

-- line #1757
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIP 2.5 (Pentacare)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIP 2.5 (Pentacare)'
);

-- line #1758
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIP 5 (Pentacare)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIP 5 (Pentacare)'
);

-- line #1759
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMADINE 2.5 (Merck)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMADINE 2.5 (Merck)'
);

-- line #1760
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMADINE 5 (Merck)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMADINE 5 (Merck)'
);

-- line #1761
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMIDINE 10 (Elfin Ph.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMIDINE 10 (Elfin Ph.)'
);

-- line #1762
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMIDINE 2.5 (Elfin Ph.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMIDINE 2.5 (Elfin Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMIDINE 5 (Elfin Ph.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMIDINE 5 (Elfin Ph.)'
);

-- line #1763
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESLO 1.25 (Zuventus)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('1.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESLO 1.25 (Zuventus)'
);

-- line #1764
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESLO 2.5 (Zuventus)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESLO 2.5 (Zuventus)'
);

-- line #1765
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESLO 5 (Zuventus)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESLO 5 (Zuventus)'
);

-- line #1766
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GAMLO 2.5 (CMGBT)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GAMLO 2.5 (CMGBT)'
);

-- line #1767
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GAMLO 5 (CMGBT)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GAMLO 5 (CMGBT)'
);

-- line #1768
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KLODIP 10 (Kopran)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KLODIP 10 (Kopran)'
);

-- line #1769
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KLODIP 2.5 (Kopran)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KLODIP 2.5 (Kopran)'
);

-- line #1770
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KLODIP 5 (Kopran)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KLODIP 5 (Kopran)'
);

-- line #1771
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMA 10 (Stadmed)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMA 10 (Stadmed)'
);

-- line #1772
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMA 2.5 (Stadmed)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMA 2.5 (Stadmed)'
);

-- line #1773
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMA 5 (Stadmed)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMA 5 (Stadmed)'
);

-- line #1774
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEODIP 5 (Phytochem)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEODIP 5 (Phytochem)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEODIP 10 (Phytochem)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEODIP 10 (Phytochem)'
);

-- line #1775
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOMADIP 2.5 (MOVA PH.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOMADIP 2.5 (MOVA PH.)'
);

-- line #1776
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOMADIP 5 (MOVA PH.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOMADIP 5 (MOVA PH.)'
);

-- line #1777
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUPIDIP 10 (Lupin)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUPIDIP 10 (Lupin)'
);

-- line #1778
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUPIDIP 2.5 (Lupin)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUPIDIP 2.5 (Lupin)'
);

-- line #1779
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUPIDIP 5 (Lupin)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUPIDIP 5 (Lupin)'
);

-- line #1780
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALODIP 2.5 (SIGNOVA)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALODIP 2.5 (SIGNOVA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALODIP 5 (SIGNOVA)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALODIP 5 (SIGNOVA)'
);

-- line #1781
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILOPIN 2.5 (BARODA)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILOPIN 2.5 (BARODA)'
);

-- line #1782
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILOPIN 5 (BARODA)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILOPIN 5 (BARODA)'
);

-- line #1783
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYAMLO 5 (WISCON)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYAMLO 5 (WISCON)'
);

-- line #1784
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYOCLOX 10 (Wockhardt)',
	'Amlodipine',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYOCLOX 10 (Wockhardt)'
);

-- line #1785
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYODIPINE 2.5 (Lark Lab)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYODIPINE 2.5 (Lark Lab)'
);

-- line #1786
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYODIPINE 5 (Lark Lab)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYODIPINE 5 (Lark Lab)'
);

-- line #1787
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYODURA 2.5 (Wockhardt)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYODURA 2.5 (Wockhardt)'
);

-- line #1788
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYODURA 5 (Wockhardt)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYODURA 5 (Wockhardt)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYODURA 10 (Wockhardt)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYODURA 10 (Wockhardt)'
);

-- line #1789
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2,5', u'strength_2': u'', u'substance': u'Amlodipine', u'always_empty': u'', u'form': u'', u'brand': u'MYODURA', u'strength_3': u'', u'company': u'Wockhardt', u'unit': u'mg'}

-- line #1790
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5', u'strength_2': u'', u'substance': u'Amlodipine', u'always_empty': u'', u'form': u'', u'brand': u'MYODURA', u'strength_3': u'', u'company': u'Wockhardt', u'unit': u'mg'}

-- line #1791
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Amlodipine', u'always_empty': u'', u'form': u'TAB', u'brand': u'MYOZAR', u'strength_3': u'', u'company': u'Wockhardt', u'unit': u''}

-- line #1792
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIPIDOL 2.5 (Alde Medi.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIPIDOL 2.5 (Alde Medi.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIPIDOL 5 (Alde Medi.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIPIDOL 5 (Alde Medi.)'
);

-- line #1793
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORVATE 2.5 (TAJ PH.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORVATE 2.5 (TAJ PH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORVATE 5 (TAJ PH.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORVATE 5 (TAJ PH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORVATE 10 (TAJ PH.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORVATE 10 (TAJ PH.)'
);

-- line #1794
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUMLO 10 (Emcure)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUMLO 10 (Emcure)'
);

-- line #1795
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUMLO 2.5 (Emcure)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUMLO 2.5 (Emcure)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUMLO 5 (Emcure)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUMLO 5 (Emcure)'
);

-- line #1796
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODIPIN 10 (Biocin Hc.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODIPIN 10 (Biocin Hc.)'
);

-- line #1797
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODIPIN 2.5 (Biocin Hc.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODIPIN 2.5 (Biocin Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODIPIN 5 (Biocin Hc.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODIPIN 5 (Biocin Hc.)'
);

-- line #1798
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLMECIP 5 (Cipla)',
	'Amlodipine',
	'AM TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLMECIP 5 (Cipla)'
);

-- line #1799
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPIN 2.5 (Baroque)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPIN 2.5 (Baroque)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPIN 5 (Baroque)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPIN 5 (Baroque)'
);

-- line #1800
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANDIP 5 (Tnt Life)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANDIP 5 (Tnt Life)'
);

-- line #1801
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PDPINE 5 (Pharma Drugs)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PDPINE 5 (Pharma Drugs)'
);

-- line #1802
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PICDEPIN-5 5 (CAPIC LAB.)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PICDEPIN-5 5 (CAPIC LAB.)'
);

-- line #1803
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PINLO 2.5 (AQUALIFE)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PINLO 2.5 (AQUALIFE)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PINLO 5 (AQUALIFE)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PINLO 5 (AQUALIFE)'
);

-- line #1804
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIMODIL 10 (Medley)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIMODIL 10 (Medley)'
);

-- line #1805
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIMODIL 2.5 (Medley)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIMODIL 2.5 (Medley)'
);

-- line #1806
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIMODIL 5 (Medley)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIMODIL 5 (Medley)'
);

-- line #1807
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIMODIL 10 (VAZOKARE)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIMODIL 10 (VAZOKARE)'
);

-- line #1808
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIMODIL 2.5 (VAZOKARE)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIMODIL 2.5 (VAZOKARE)'
);

-- line #1809
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIMODIL 5 (VAZOKARE)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIMODIL 5 (VAZOKARE)'
);

-- line #1810
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q-SPIN 2.5 (QCHECK)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg(S-AMLODIPINE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q-SPIN 2.5 (QCHECK)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q-SPIN 5 (QCHECK)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg(S-AMLODIPINE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q-SPIN 5 (QCHECK)'
);

-- line #1811
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REDIPIL 2.5 (Dr.Reddy''S)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REDIPIL 2.5 (Dr.Reddy''S)'
);

-- line #1812
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REDIPIL 5 (Dr.Reddy''S)',
	'Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REDIPIL 5 (Dr.Reddy''S)'
);

-- line #1813
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIRYTH-150 150 (Emcure)',
	'AMODAFINIL',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIRYTH-150 150 (Emcure)'
);

-- line #1814
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIRYTH-50 50 (Emcure)',
	'AMODAFINIL',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIRYTH-50 50 (Emcure)'
);

-- line #1815
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOCERYL 0.25 (Galderma)',
	'AMOROLFINE',
	'CRM',
	gm.nullify_empty_string('0.25')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOCERYL 0.25 (Galderma)'
);

-- line #1816
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5', u'strength_2': u'', u'substance': u'AMOROLFINE', u'always_empty': u'', u'form': u'', u'brand': u'LOCERYL NAIL LACQUER', u'strength_3': u'', u'company': u'Galderma', u'unit': u'%'}

-- line #1817
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5', u'strength_2': u'', u'substance': u'AMOROLFINE', u'always_empty': u'', u'form': u'', u'brand': u'LOCERYL NAIL LACQUER', u'strength_3': u'', u'company': u'Galderma', u'unit': u'%W/V'}

-- line #1818
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AM LAQER 5 (Sun)',
	'AMOROLPHIN HCL.',
	'SOL',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AM LAQER 5 (Sun)'
);

-- line #1819
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,25', u'strength_2': u'', u'substance': u'AMOROLPHIN HCL.', u'always_empty': u'', u'form': u'', u'brand': u'LIVAFIN', u'strength_3': u'', u'company': u'Liva Hc.', u'unit': u'%(AMOROLFINE)'}

-- line #1820
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMOLIFE 50 (La Drug)',
	'Amoxapine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMOLIFE 50 (La Drug)'
);

-- line #1821
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEMOLOX 100 (Wyeth)',
	'Amoxapine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEMOLOX 100 (Wyeth)'
);

-- line #1822
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEMOLOX 50 (Wyeth)',
	'Amoxapine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEMOLOX 50 (Wyeth)'
);

-- line #1823
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPSAC 50 (Theo Ph.)',
	'Amoxapine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPSAC 50 (Theo Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPSAC 100 (Theo Ph.)',
	'Amoxapine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPSAC 100 (Theo Ph.)'
);

-- line #1824
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KAMIPOX 50 (K.C. Lab)',
	'Amoxapine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KAMIPOX 50 (K.C. Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KAMIPOX 100 (K.C. Lab)',
	'Amoxapine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KAMIPOX 100 (K.C. Lab)'
);

-- line #1825
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORAZ 50 (RECOUPE)',
	'Amoxapine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORAZ 50 (RECOUPE)'
);

-- line #1826
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXAMINE 100 (PSYCOREM)',
	'Amoxapine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXAMINE 100 (PSYCOREM)'
);

-- line #1827
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXAMINE 50 (PSYCOREM)',
	'Amoxapine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXAMINE 50 (PSYCOREM)'
);

-- line #1828
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACEMOX 250 (ACE LAB.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACEMOX 250 (ACE LAB.)'
);

-- line #1829
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACEMOX 250 (Integrated)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACEMOX 250 (Integrated)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACEMOX 500 (Integrated)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACEMOX 500 (Integrated)'
);

-- line #1830
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACEMOX 125 (ACE LAB.)',
	'Amoxycillin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACEMOX 125 (ACE LAB.)'
);

-- line #1831
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACEMOX 250 (ACE LAB.)',
	'Amoxycillin',
	'D.SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACEMOX 250 (ACE LAB.)'
);

-- line #1832
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACEMOX 250 (Integrated)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACEMOX 250 (Integrated)'
);

-- line #1833
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACMOX 250 (Acme Ph)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACMOX 250 (Acme Ph)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACMOX 500 (Acme Ph)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACMOX 500 (Acme Ph)'
);

-- line #1834
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACMOX 250 (Acme Ph)',
	'Amoxycillin',
	'DS TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACMOX 250 (Acme Ph)'
);

-- line #1835
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACMOX 125 (Acme Ph)',
	'Amoxycillin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACMOX 125 (Acme Ph)'
);

-- line #1836
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACMOX 125 (Acme Ph)',
	'Amoxycillin',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACMOX 125 (Acme Ph)'
);

-- line #1837
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTIMOX 250 (Active Hc.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTIMOX 250 (Active Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTIMOX 500 (Active Hc.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTIMOX 500 (Active Hc.)'
);

-- line #1838
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTIMOX 125 (Active Hc.)',
	'Amoxycillin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTIMOX 125 (Active Hc.)'
);

-- line #1839
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTIMOX 250 (Active Hc.)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTIMOX 250 (Active Hc.)'
);

-- line #1840
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADMOXIN 250 (Admac Ph.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADMOXIN 250 (Admac Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADMOXIN 500 (Admac Ph.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADMOXIN 500 (Admac Ph.)'
);

-- line #1841
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AFYMOX 250 (Sanify)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AFYMOX 250 (Sanify)'
);

-- line #1842
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AIMOX 250 (AIMCO PH.)',
	'Amoxycillin',
	'TAB/CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AIMOX 250 (AIMCO PH.)'
);

-- line #1843
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALLMOX 250 (Lincoln)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALLMOX 250 (Lincoln)'
);

-- line #1844
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALLMOX 500 (Lincoln)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALLMOX 500 (Lincoln)'
);

-- line #1845
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALLMOX 125 (Lincoln)',
	'Amoxycillin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALLMOX 125 (Lincoln)'
);

-- line #1846
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALLMOX 250 (Lincoln)',
	'Amoxycillin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALLMOX 250 (Lincoln)'
);

-- line #1847
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALLMOX 500 (Lincoln)',
	'Amoxycillin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALLMOX 500 (Lincoln)'
);

-- line #1848
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALLMOX 125 (Lincoln)',
	'Amoxycillin',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALLMOX 125 (Lincoln)'
);

-- line #1849
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALLMOX 250 (Lincoln)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALLMOX 250 (Lincoln)'
);

-- line #1850
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALUMOX 250 (Allure Rem.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALUMOX 250 (Allure Rem.)'
);

-- line #1851
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALUMOX 500 (Allure Rem.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALUMOX 500 (Allure Rem.)'
);

-- line #1852
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALUMOX KID 250 (Allure Rem.)',
	'Amoxycillin',
	'F. TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALUMOX KID 250 (Allure Rem.)'
);

-- line #1853
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALUMOX 125 (Allure Rem.)',
	'Amoxycillin',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALUMOX 125 (Allure Rem.)'
);

-- line #1854
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMBAC-D 125 (Medinova Lab)',
	'Amoxycillin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMBAC-D 125 (Medinova Lab)'
);

-- line #1855
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMBAC 250 (Medinova Lab)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMBAC 250 (Medinova Lab)'
);

-- line #1856
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMBAC 125 (Medinova Lab)',
	'Amoxycillin',
	'READYMIX',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMBAC 125 (Medinova Lab)'
);

-- line #1857
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMBAC 500 (Medinova Lab)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMBAC 500 (Medinova Lab)'
);

-- line #1858
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMOLAC 125 (MEDISYS)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMOLAC 125 (MEDISYS)'
);

-- line #1859
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMOLIN 125 (Dynamic)',
	'Amoxycillin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMOLIN 125 (Dynamic)'
);

-- line #1860
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMOTID 250 (Dolphin)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMOTID 250 (Dolphin)'
);

-- line #1861
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMOTID 500 (Dolphin)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMOTID 500 (Dolphin)'
);

-- line #1862
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMOTID 250 (Dolphin)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMOTID 250 (Dolphin)'
);

-- line #1863
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMOTID 125 (Dolphin)',
	'Amoxycillin',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMOTID 125 (Dolphin)'
);

-- line #1864
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMOTID 125 (Dolphin)',
	'Amoxycillin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMOTID 125 (Dolphin)'
);

-- line #1865
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMOTRI 125 (VIBRANT PH.)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMOTRI 125 (VIBRANT PH.)'
);

-- line #1866
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMOXIL 250 (German R.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMOXIL 250 (German R.)'
);

-- line #1867
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMOXIL 500 (German R.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMOXIL 500 (German R.)'
);

-- line #1868
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMOXIL 125 (German R.)',
	'Amoxycillin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMOXIL 125 (German R.)'
);

-- line #1869
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMOXINAT 250 (Natco Ph.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMOXINAT 250 (Natco Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMOXINAT 500 (Natco Ph.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMOXINAT 500 (Natco Ph.)'
);

-- line #1870
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMOXINGA 250 (Inga)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMOXINGA 250 (Inga)'
);

-- line #1871
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMOXINGA 500 (Inga)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMOXINGA 500 (Inga)'
);

-- line #1872
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMOXINGA 250 (Inga)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMOXINGA 250 (Inga)'
);

-- line #1873
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMOXINGA 125 (Inga)',
	'Amoxycillin',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMOXINGA 125 (Inga)'
);

-- line #1874
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMOXINGA 125 (Inga)',
	'Amoxycillin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMOXINGA 125 (Inga)'
);

-- line #1875
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMOXIPEN 250 (P C INDIA)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMOXIPEN 250 (P C INDIA)'
);

-- line #1876
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMOXIPEN 500 (P C INDIA)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMOXIPEN 500 (P C INDIA)'
);

-- line #1877
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMOXIPEN-D 125 (P C INDIA)',
	'Amoxycillin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMOXIPEN-D 125 (P C INDIA)'
);

-- line #1878
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMOXIPEN 125 (P C INDIA)',
	'Amoxycillin',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMOXIPEN 125 (P C INDIA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMOXIPEN 250 (P C INDIA)',
	'Amoxycillin',
	'KT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMOXIPEN 250 (P C INDIA)'
);

-- line #1879
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMOXIPEN 250 (P C INDIA)',
	'Amoxycillin',
	'SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMOXIPEN 250 (P C INDIA)'
);

-- line #1880
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMOXIVAN 250 (Khandelwal)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMOXIVAN 250 (Khandelwal)'
);

-- line #1881
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMOXIVAN 500 (Khandelwal)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMOXIVAN 500 (Khandelwal)'
);

-- line #1882
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMOXIVAN-D 125 (Khandelwal)',
	'Amoxycillin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMOXIVAN-D 125 (Khandelwal)'
);

-- line #1883
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMOXYBID 250 (GSK)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMOXYBID 250 (GSK)'
);

-- line #1884
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMOXYBID 500 (GSK)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMOXYBID 500 (GSK)'
);

-- line #1885
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMOXYBID-D 125 (GSK)',
	'Amoxycillin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMOXYBID-D 125 (GSK)'
);

-- line #1886
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMOXYCILLIN 125 (Dopson Ph.)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMOXYCILLIN 125 (Dopson Ph.)'
);

-- line #1887
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMOXYCILLIN 250 (Dopson Ph.)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMOXYCILLIN 250 (Dopson Ph.)'
);

-- line #1888
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMOXYN 250 (Saga Lab)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMOXYN 250 (Saga Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMOXYN 500 (Saga Lab)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMOXYN 500 (Saga Lab)'
);

-- line #1889
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMOXYN 125 (Saga Lab)',
	'Amoxycillin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMOXYN 125 (Saga Lab)'
);

-- line #1890
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMOXYN 250 (Saga Lab)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMOXYN 250 (Saga Lab)'
);

-- line #1891
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMOXYN 125 (Saga Lab)',
	'Amoxycillin',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMOXYN 125 (Saga Lab)'
);

-- line #1892
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMOXYPEN 500 (INVISION)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMOXYPEN 500 (INVISION)'
);

-- line #1893
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMOXYPEN 125 (INVISION)',
	'Amoxycillin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMOXYPEN 125 (INVISION)'
);

-- line #1894
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMOXYPEN 250 (INVISION)',
	'Amoxycillin',
	'DT TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMOXYPEN 250 (INVISION)'
);

-- line #1895
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMYN 250 (Kopran)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMYN 250 (Kopran)'
);

-- line #1896
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMYN 500 (Kopran)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMYN 500 (Kopran)'
);

-- line #1897
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMYN-D 125 (Kopran)',
	'Amoxycillin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMYN-D 125 (Kopran)'
);

-- line #1898
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMYN 750 (Kopran)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMYN 750 (Kopran)'
);

-- line #1899
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMYN 125 (Kopran)',
	'Amoxycillin',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMYN 125 (Kopran)'
);

-- line #1900
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANIMOX 125 (Anikem Lab.)',
	'AMOXYCILLIN',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANIMOX 125 (Anikem Lab.)'
);

-- line #1901
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANIMOX 250 (Anikem Lab.)',
	'Amoxycillin',
	'DT/500 CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANIMOX 250 (Anikem Lab.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANIMOX 500 (Anikem Lab.)',
	'Amoxycillin',
	'DT/500 CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANIMOX 500 (Anikem Lab.)'
);

-- line #1902
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANIMOX 125 (Anikem Lab.)',
	'AMOXYCILLIN',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANIMOX 125 (Anikem Lab.)'
);

-- line #1903
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANTIMOX 125 (EAST WEST)',
	'Amoxycillin',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANTIMOX 125 (EAST WEST)'
);

-- line #1904
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APIMOX 250 (ALICON PH.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APIMOX 250 (ALICON PH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APIMOX 500 (ALICON PH.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APIMOX 500 (ALICON PH.)'
);

-- line #1905
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APIMOX 125 (ALICON PH.)',
	'Amoxycillin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APIMOX 125 (ALICON PH.)'
);

-- line #1906
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APIMOX 250 (ALICON PH.)',
	'Amoxycillin',
	'DT TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APIMOX 250 (ALICON PH.)'
);

-- line #1907
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APIMOX 125 (ALICON PH.)',
	'Amoxycillin',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APIMOX 125 (ALICON PH.)'
);

-- line #1908
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APPRIMOX-KID 125 (Rhombic)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APPRIMOX-KID 125 (Rhombic)'
);

-- line #1909
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APPRIMOX 250 (Rhombic)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APPRIMOX 250 (Rhombic)'
);

-- line #1910
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARISTOMOX 250 (Aristo)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARISTOMOX 250 (Aristo)'
);

-- line #1911
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARISTOMOX 500 (Aristo)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARISTOMOX 500 (Aristo)'
);

-- line #1912
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARISTOMOX-D 125 (Aristo)',
	'Amoxycillin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARISTOMOX-D 125 (Aristo)'
);

-- line #1913
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARISTOMOX 125 (Aristo)',
	'Amoxycillin',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARISTOMOX 125 (Aristo)'
);

-- line #1914
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATMOX 250 (Atoz Ph.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATMOX 250 (Atoz Ph.)'
);

-- line #1915
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATMOX 500 (Atoz Ph.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATMOX 500 (Atoz Ph.)'
);

-- line #1916
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATMOX 125 (Atoz Ph.)',
	'Amoxycillin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATMOX 125 (Atoz Ph.)'
);

-- line #1917
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATMOX 125 (Atoz Ph.)',
	'Amoxycillin',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATMOX 125 (Atoz Ph.)'
);

-- line #1918
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATMOX 250 (Atoz Ph.)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATMOX 250 (Atoz Ph.)'
);

-- line #1919
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXCEL 250 (Candor Bio.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXCEL 250 (Candor Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXCEL 500 (Candor Bio.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXCEL 500 (Candor Bio.)'
);

-- line #1920
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXYMOX 500 (AXYZEN LIFE)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXYMOX 500 (AXYZEN LIFE)'
);

-- line #1921
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXYMOX 250 (AXYZEN LIFE)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXYMOX 250 (AXYZEN LIFE)'
);

-- line #1922
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXYMOX 125 (AXYZEN LIFE)',
	'Amoxycillin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXYMOX 125 (AXYZEN LIFE)'
);

-- line #1923
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACTOL 250 (Medoz Ph.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACTOL 250 (Medoz Ph.)'
);

-- line #1924
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACTOL 500 (Medoz Ph.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACTOL 500 (Medoz Ph.)'
);

-- line #1925
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACTOL 125 (Medoz Ph.)',
	'Amoxycillin',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACTOL 125 (Medoz Ph.)'
);

-- line #1926
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENIMOX 250 (Baroque)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENIMOX 250 (Baroque)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENIMOX 500 (Baroque)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENIMOX 500 (Baroque)'
);

-- line #1927
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENIMOX 125 (Baroque)',
	'Amoxycillin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENIMOX 125 (Baroque)'
);

-- line #1928
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENIMOX 125 (Baroque)',
	'Amoxycillin',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENIMOX 125 (Baroque)'
);

-- line #1929
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENIMOX 250 (Baroque)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENIMOX 250 (Baroque)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENIMOX 500 (Baroque)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENIMOX 500 (Baroque)'
);

-- line #1930
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETMOX 250 (UNI OR.)',
	'Amoxycillin',
	'DT TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETMOX 250 (UNI OR.)'
);

-- line #1931
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETMOX 500 (UNI OR.)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETMOX 500 (UNI OR.)'
);

-- line #1932
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIGMOX 250 (Astrazeneca)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIGMOX 250 (Astrazeneca)'
);

-- line #1933
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIG MOX 250 (Astrazeneca)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIG MOX 250 (Astrazeneca)'
);

-- line #1934
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOMOXIL 250 (Biochem)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOMOXIL 250 (Biochem)'
);

-- line #1935
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOMOXIL 500 (Biochem)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOMOXIL 500 (Biochem)'
);

-- line #1936
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOMOXIL 100 (Biochem)',
	'Amoxycillin',
	'DPS',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOMOXIL 100 (Biochem)'
);

-- line #1937
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOMOXIL 250 (Biochem)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOMOXIL 250 (Biochem)'
);

-- line #1938
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOMOXIL 125 (Biochem)',
	'Amoxycillin',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOMOXIL 125 (Biochem)'
);

-- line #1939
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOMOXIL 125 (Biochem)',
	'Amoxycillin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOMOXIL 125 (Biochem)'
);

-- line #1940
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BITAMOX 250 (Bombay T.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BITAMOX 250 (Bombay T.)'
);

-- line #1941
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BITAMOX 500 (Bombay T.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BITAMOX 500 (Bombay T.)'
);

-- line #1942
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BITAMOX-D 125 (Bombay T.)',
	'Amoxycillin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BITAMOX-D 125 (Bombay T.)'
);

-- line #1943
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLISMOX 250 (Bliss)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLISMOX 250 (Bliss)'
);

-- line #1944
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLISMOX 500 (Bliss)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLISMOX 500 (Bliss)'
);

-- line #1945
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLUMOX 250 (Blue Cross)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLUMOX 250 (Blue Cross)'
);

-- line #1946
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLUMOX 500 (Blue Cross)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLUMOX 500 (Blue Cross)'
);

-- line #1947
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLUMOX-D 125 (Blue Cross)',
	'Amoxycillin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLUMOX-D 125 (Blue Cross)'
);

-- line #1948
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLUMOX 250 (Blue Cross)',
	'Amoxycillin',
	'DT TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLUMOX 250 (Blue Cross)'
);

-- line #1949
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLUMOX 500 (Blue Cross)',
	'Amoxycillin',
	'DT TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLUMOX 500 (Blue Cross)'
);

-- line #1950
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLUMOX-P 125 (Blue Cross)',
	'Amoxycillin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLUMOX-P 125 (Blue Cross)'
);

-- line #1951
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLUMOX-P 125 (Blue Cross)',
	'Amoxycillin',
	'DT TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLUMOX-P 125 (Blue Cross)'
);

-- line #1952
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRIMOX 250 (Briskon)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRIMOX 250 (Briskon)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRIMOX 500 (Briskon)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRIMOX 500 (Briskon)'
);

-- line #1953
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRIMOX 125 (Briskon)',
	'Amoxycillin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRIMOX 125 (Briskon)'
);

-- line #1954
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRIMOX 250 (Briskon)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRIMOX 250 (Briskon)'
);

-- line #1955
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BROMOX 250 (TALENT LAB.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BROMOX 250 (TALENT LAB.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BROMOX 500 (TALENT LAB.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BROMOX 500 (TALENT LAB.)'
);

-- line #1956
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BROMOX 125 (TALENT LAB.)',
	'Amoxycillin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BROMOX 125 (TALENT LAB.)'
);

-- line #1957
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BROMOX 125 (TALENT LAB.)',
	'Amoxycillin',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BROMOX 125 (TALENT LAB.)'
);

-- line #1958
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAREMOX-D 125 (Olcare)',
	'Amoxycillin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAREMOX-D 125 (Olcare)'
);

-- line #1959
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAREMOX 250 (Olcare)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAREMOX 250 (Olcare)'
);

-- line #1960
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAREMOX 500 (Olcare)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAREMOX 500 (Olcare)'
);

-- line #1961
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIDOMEX 250 (Sanofi Aventis)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIDOMEX 250 (Sanofi Aventis)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIDOMEX 500 (Sanofi Aventis)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIDOMEX 500 (Sanofi Aventis)'
);

-- line #1962
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIDOMEX 125 (Sanofi Aventis)',
	'Amoxycillin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIDOMEX 125 (Sanofi Aventis)'
);

-- line #1963
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIDOMEX 125 (Sanofi Aventis)',
	'Amoxycillin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIDOMEX 125 (Sanofi Aventis)'
);

-- line #1964
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CILIMOX 250 (INVISION(INFALIFE))',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CILIMOX 250 (INVISION(INFALIFE))'
);

-- line #1965
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPMOX 250 (Cipla)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPMOX 250 (Cipla)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPMOX 500 (Cipla)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPMOX 500 (Cipla)'
);

-- line #1966
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250', u'strength_2': u'', u'substance': u'Amoxycillin', u'always_empty': u'', u'form': u'', u'brand': u'CLEARMOX DT250', u'strength_3': u'', u'company': u'Indoco Rem.', u'unit': u'mg'}

-- line #1967
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-MOX 125 (Corona)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-MOX 125 (Corona)'
);

-- line #1968
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-MOX 250 (Corona)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-MOX 250 (Corona)'
);

-- line #1969
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-MOX 500 (Corona)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-MOX 500 (Corona)'
);

-- line #1970
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COBEX 250 (ORION BIOTECH.)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COBEX 250 (ORION BIOTECH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COBEX 500 (ORION BIOTECH.)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COBEX 500 (ORION BIOTECH.)'
);

-- line #1971
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COMOXYL 250 (Concept)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COMOXYL 250 (Concept)'
);

-- line #1972
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COMOXYL 500 (Concept)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COMOXYL 500 (Concept)'
);

-- line #1973
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COMOXYL 125 (Concept)',
	'Amoxycillin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COMOXYL 125 (Concept)'
);

-- line #1974
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COMOXYL 250 (Concept)',
	'Amoxycillin',
	'F. TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COMOXYL 250 (Concept)'
);

-- line #1975
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COMOXYL 125 (Concept)',
	'Amoxycillin',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COMOXYL 125 (Concept)'
);

-- line #1976
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORMOX 125 (Corona)',
	'Amoxycillin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORMOX 125 (Corona)'
);

-- line #1977
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORMOX 250 (Corona)',
	'Amoxycillin',
	'DT/KID TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORMOX 250 (Corona)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORMOX 125 (Corona)',
	'Amoxycillin',
	'DT/KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORMOX 125 (Corona)'
);

-- line #1978
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAMOXY 250 (Dabur Ph.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAMOXY 250 (Dabur Ph.)'
);

-- line #1979
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAMOXY 500 (Dabur Ph.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAMOXY 500 (Dabur Ph.)'
);

-- line #1980
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAMOXY 125 (Dabur Ph.)',
	'Amoxycillin',
	'DPS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAMOXY 125 (Dabur Ph.)'
);

-- line #1981
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAMOXY 125 (Dabur Ph.)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAMOXY 125 (Dabur Ph.)'
);

-- line #1982
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAMOXY 250 (Dabur Ph.)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAMOXY 250 (Dabur Ph.)'
);

-- line #1983
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAMOXY GF 500 (Dabur Ph.)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAMOXY GF 500 (Dabur Ph.)'
);

-- line #1984
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAMOXY 125 (Dabur Ph.)',
	'Amoxycillin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAMOXY 125 (Dabur Ph.)'
);

-- line #1985
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DELAMIN 250 (Hal)',
	'Amoxycillin',
	'CAP/DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DELAMIN 250 (Hal)'
);

-- line #1986
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DELAMIN 500 (Hal)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DELAMIN 500 (Hal)'
);

-- line #1987
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DELAMIN 125 (Hal)',
	'Amoxycillin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DELAMIN 125 (Hal)'
);

-- line #1988
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DELAMIN 125 (Hal)',
	'Amoxycillin',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DELAMIN 125 (Hal)'
);

-- line #1989
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEMOX 250 (Dynamic)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEMOX 250 (Dynamic)'
);

-- line #1990
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEMOX 500 (Dynamic)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEMOX 500 (Dynamic)'
);

-- line #1991
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEMOXIN 250 (Alde Medi.)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEMOXIN 250 (Alde Medi.)'
);

-- line #1992
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEMOXIN 500 (Alde Medi.)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEMOXIN 500 (Alde Medi.)'
);

-- line #1993
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEMOX 125 (Dynamic)',
	'Amoxycillin',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEMOX 125 (Dynamic)'
);

-- line #1994
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEXAMOX KID 250 (TRIDENT PH.)',
	'Amoxycillin',
	'F. TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEXAMOX KID 250 (TRIDENT PH.)'
);

-- line #1995
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICIMOX 250 (Indoco Rem.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICIMOX 250 (Indoco Rem.)'
);

-- line #1996
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICIMOX 500 (Indoco Rem.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICIMOX 500 (Indoco Rem.)'
);

-- line #1997
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICIMOX 250 (Indoco Rem.)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICIMOX 250 (Indoco Rem.)'
);

-- line #1998
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICIMOX 125 (Indoco Rem.)',
	'Amoxycillin',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICIMOX 125 (Indoco Rem.)'
);

-- line #1999
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILMOX 250 (Dial Ph.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILMOX 250 (Dial Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILMOX 500 (Dial Ph.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILMOX 500 (Dial Ph.)'
);

-- line #2000
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILMOX 250 (Dial Ph.)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILMOX 250 (Dial Ph.)'
);

-- line #2001
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DURAMOX 500 (Ophthal R.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DURAMOX 500 (Ophthal R.)'
);

-- line #2002
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DURAMOX 250 (Ophthal R.)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DURAMOX 250 (Ophthal R.)'
);

-- line #2003
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DURAMOX 125 (Ophthal R.)',
	'Amoxycillin',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DURAMOX 125 (Ophthal R.)'
);

-- line #2004
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYNAMOX 250 (Micro Labs)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYNAMOX 250 (Micro Labs)'
);

-- line #2005
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYNAMOX 500 (Micro Labs)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYNAMOX 500 (Micro Labs)'
);

-- line #2006
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYNAMOX-D 125 (Micro Labs)',
	'Amoxycillin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYNAMOX-D 125 (Micro Labs)'
);

-- line #2007
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYNAMOX 250 (Micro Labs)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYNAMOX 250 (Micro Labs)'
);

-- line #2008
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'125', u'strength_2': u'', u'substance': u'Amoxycillin', u'always_empty': u'', u'form': u'', u'brand': u'DYNAMOX KID ATAB', u'strength_3': u'', u'company': u'Micro Labs', u'unit': u'mg'}

-- line #2009
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'E AMOX 500 (MARLINE BIO.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'E AMOX 500 (MARLINE BIO.)'
);

-- line #2010
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'E AMOX CL 250 (MARLINE BIO.)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'E AMOX CL 250 (MARLINE BIO.)'
);

-- line #2011
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ECOMOX 250 (Trinicare)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ECOMOX 250 (Trinicare)'
);

-- line #2012
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EDOMOX 250 (Medopharm)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EDOMOX 250 (Medopharm)'
);

-- line #2013
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EDOMOX 500 (Medopharm)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EDOMOX 500 (Medopharm)'
);

-- line #2014
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EDOMOX 125 (Medopharm)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EDOMOX 125 (Medopharm)'
);

-- line #2015
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EDOMOX 250 (Medopharm)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EDOMOX 250 (Medopharm)'
);

-- line #2016
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELMOXYN 250 (Camlin)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELMOXYN 250 (Camlin)'
);

-- line #2017
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELMOXYN 500 (Camlin)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELMOXYN 500 (Camlin)'
);

-- line #2018
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELMOXYN 125 (Camlin)',
	'Amoxycillin',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELMOXYN 125 (Camlin)'
);

-- line #2019
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMIMOX 250 (Emil Ph.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMIMOX 250 (Emil Ph.)'
);

-- line #2020
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMIMOX 500 (Emil Ph.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMIMOX 500 (Emil Ph.)'
);

-- line #2021
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMIMOX 125 (Emil Ph.)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMIMOX 125 (Emil Ph.)'
);

-- line #2022
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMIMOX 250 (Emil Ph.)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMIMOX 250 (Emil Ph.)'
);

-- line #2023
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMIMOX 250 (Emil Ph.)',
	'Amoxycillin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMIMOX 250 (Emil Ph.)'
);

-- line #2024
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMIMOX 500 (Emil Ph.)',
	'Amoxycillin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMIMOX 500 (Emil Ph.)'
);

-- line #2025
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMIMOX 125 (Emil Ph.)',
	'Amoxycillin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMIMOX 125 (Emil Ph.)'
);

-- line #2026
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMTO 250 (Cadex Lab)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMTO 250 (Cadex Lab)'
);

-- line #2027
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EROX 125 (Eros Ph.)',
	'Amoxycillin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'250'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EROX 125 (Eros Ph.)'
);

-- line #2028
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EROX 250 (Eros Ph.)',
	'Amoxycillin',
	'DT TAB/CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EROX 250 (Eros Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EROX 250 (Eros Ph.)',
	'Amoxycillin',
	'DT TAB/CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EROX 250 (Eros Ph.)'
);

-- line #2029
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EROX 500 (Eros Ph.)',
	'Amoxycillin',
	'DT TAB/CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EROX 500 (Eros Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EROX 500 (Eros Ph.)',
	'Amoxycillin',
	'DT TAB/CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EROX 500 (Eros Ph.)'
);

-- line #2030
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EROX 125 (Eros Ph.)',
	'Amoxycillin',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EROX 125 (Eros Ph.)'
);

-- line #2031
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHIMOX 250 (Ethilex Hc.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHIMOX 250 (Ethilex Hc.)'
);

-- line #2032
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHIMOX 500 (Ethilex Hc.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHIMOX 500 (Ethilex Hc.)'
);

-- line #2033
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHIMOX 125 (Ethilex Hc.)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHIMOX 125 (Ethilex Hc.)'
);

-- line #2034
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHIMOX 250 (Ethilex Hc.)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHIMOX 250 (Ethilex Hc.)'
);

-- line #2035
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUPHOMOX 500 (Euphoric)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUPHOMOX 500 (Euphoric)'
);

-- line #2036
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUPHOMOX 125 (Euphoric)',
	'Amoxycillin',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUPHOMOX 125 (Euphoric)'
);

-- line #2037
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUPHOMOX 250 (Euphoric)',
	'Amoxycillin',
	'KID TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUPHOMOX 250 (Euphoric)'
);

-- line #2038
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FELMOX 250 (Karlin)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FELMOX 250 (Karlin)'
);

-- line #2039
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FINEMOX 500 (Finecure)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FINEMOX 500 (Finecure)'
);

-- line #2040
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FINEMOX-D 125 (Finecure)',
	'Amoxycillin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FINEMOX-D 125 (Finecure)'
);

-- line #2041
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FINEMOX 250 (Finecure)',
	'Amoxycillin',
	'DT/CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FINEMOX 250 (Finecure)'
);

-- line #2042
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FINEMOX 125 (Finecure)',
	'Amoxycillin',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FINEMOX 125 (Finecure)'
);

-- line #2043
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLEMOXIN 250 (East India)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLEMOXIN 250 (East India)'
);

-- line #2044
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLEMOXIN 500 (East India)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLEMOXIN 500 (East India)'
);

-- line #2045
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLEMOXIN 125 (East India)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLEMOXIN 125 (East India)'
);

-- line #2046
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLEMOXIN 250 (East India)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLEMOXIN 250 (East India)'
);

-- line #2047
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLEMOXIN 125 (East India)',
	'Amoxycillin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLEMOXIN 125 (East India)'
);

-- line #2048
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORMOXY 250 (Health Care)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORMOXY 250 (Health Care)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORMOXY 500 (Health Care)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORMOXY 500 (Health Care)'
);

-- line #2049
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORMOXY 125 (Health Care)',
	'Amoxycillin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORMOXY 125 (Health Care)'
);

-- line #2050
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORMOXY 125 (Health Care)',
	'Amoxycillin',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORMOXY 125 (Health Care)'
);

-- line #2051
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FRENMOX 500 (Indo French)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FRENMOX 500 (Indo French)'
);

-- line #2052
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENMOX 125 (Cadila Ph.)',
	'Amoxycillin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENMOX 125 (Cadila Ph.)'
);

-- line #2053
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENMOX 125 (Genova)',
	'Amoxycillin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENMOX 125 (Genova)'
);

-- line #2054
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENMOX 125 (Cadila Ph.)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENMOX 125 (Cadila Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENMOX 250 (Cadila Ph.)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENMOX 250 (Cadila Ph.)'
);

-- line #2055
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENTODAL 250 (Malcom Ph.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENTODAL 250 (Malcom Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENTODAL 500 (Malcom Ph.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENTODAL 500 (Malcom Ph.)'
);

-- line #2056
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENTODAL-D 125 (Malcom Ph.)',
	'Amoxycillin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENTODAL-D 125 (Malcom Ph.)'
);

-- line #2057
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLAMOXIN 250 (Gsk)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLAMOXIN 250 (Gsk)'
);

-- line #2058
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLAMOXIN 500 (Gsk)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLAMOXIN 500 (Gsk)'
);

-- line #2059
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLAMOXIN-D 125 (Gsk)',
	'Amoxycillin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLAMOXIN-D 125 (Gsk)'
);

-- line #2060
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLAMOXIN 125 (Gsk)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLAMOXIN 125 (Gsk)'
);

-- line #2061
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLOMOX 500 (Globus)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLOMOX 500 (Globus)'
);

-- line #2062
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLOMOX 250 (Globus)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLOMOX 250 (Globus)'
);

-- line #2063
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G-MOXIL 125 (Green Cross)',
	'Amoxycillin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G-MOXIL 125 (Green Cross)'
);

-- line #2064
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G-MOXIL 250 (Green Cross)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G-MOXIL 250 (Green Cross)'
);

-- line #2065
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GROMAX-500 500 (Growell)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GROMAX-500 500 (Growell)'
);

-- line #2066
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GUTENMOX 250 (Merck)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GUTENMOX 250 (Merck)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GUTENMOX 500 (Merck)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GUTENMOX 500 (Merck)'
);

-- line #2067
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GUTENMOX 250 (Merck)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GUTENMOX 250 (Merck)'
);

-- line #2068
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GUTENMOX 250 (Merck)',
	'Amoxycillin',
	'DT TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GUTENMOX 250 (Merck)'
);

-- line #2069
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GUTENMOX 125 (Merck)',
	'Amoxycillin',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GUTENMOX 125 (Merck)'
);

-- line #2070
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIMOX 250 (Ultramark)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIMOX 250 (Ultramark)'
);

-- line #2071
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIMOX 500 (Ultramark)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIMOX 500 (Ultramark)'
);

-- line #2072
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIPEN-A 250 (Zydus Cadila(Mm))',
	'Amoxycillin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIPEN-A 250 (Zydus Cadila(Mm))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIPEN-A 500 (Zydus Cadila(Mm))',
	'Amoxycillin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIPEN-A 500 (Zydus Cadila(Mm))'
);

-- line #2073
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIPEN-A 125 (Zydus Cadila(Mm))',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIPEN-A 125 (Zydus Cadila(Mm))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIPEN-A 250 (Zydus Cadila(Mm))',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIPEN-A 250 (Zydus Cadila(Mm))'
);

-- line #2074
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIPEN 250 (Zydus Cadila)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIPEN 250 (Zydus Cadila)'
);

-- line #2075
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIPEN 500 (Zydus Cadila)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIPEN 500 (Zydus Cadila)'
);

-- line #2076
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIPEN 250 (Zydus Cadila)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIPEN 250 (Zydus Cadila)'
);

-- line #2077
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIPEN 250 (Zydus Cadila)',
	'Amoxycillin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIPEN 250 (Zydus Cadila)'
);

-- line #2078
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIPEN 500 (Zydus Cadila)',
	'Amoxycillin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIPEN 500 (Zydus Cadila)'
);

-- line #2079
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIPEN 125 (Zydus Cadila)',
	'Amoxycillin',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIPEN 125 (Zydus Cadila)'
);

-- line #2080
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIPEN-P 250 (Zydus Cadila(Mm))',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIPEN-P 250 (Zydus Cadila(Mm))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIPEN-P 500 (Zydus Cadila(Mm))',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIPEN-P 500 (Zydus Cadila(Mm))'
);

-- line #2081
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYCIMOX 250 (Pharmed)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYCIMOX 250 (Pharmed)'
);

-- line #2082
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYCIMOX 500 (Pharmed)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYCIMOX 500 (Pharmed)'
);

-- line #2083
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYCIMOX 125 (Pharmed)',
	'Amoxycillin',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYCIMOX 125 (Pharmed)'
);

-- line #2084
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYKIL 250 (Remedies)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYKIL 250 (Remedies)'
);

-- line #2085
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYKIL 500 (Remedies)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYKIL 500 (Remedies)'
);

-- line #2086
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYKIL 125 (Remedies)',
	'Amoxycillin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYKIL 125 (Remedies)'
);

-- line #2087
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IDIMOX 250 (Idpl)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IDIMOX 250 (Idpl)'
);

-- line #2088
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IDIMOX 500 (Idpl)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IDIMOX 500 (Idpl)'
);

-- line #2089
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IDIMOX 125 (Idpl)',
	'Amoxycillin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IDIMOX 125 (Idpl)'
);

-- line #2090
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMOX 250 (Ipca)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMOX 250 (Ipca)'
);

-- line #2091
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMOX 500 (Ipca)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMOX 500 (Ipca)'
);

-- line #2092
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMOX 125 (Ipca)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMOX 125 (Ipca)'
);

-- line #2093
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMOX 250 (Ipca)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMOX 250 (Ipca)'
);

-- line #2094
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INMOX 250 (Intra Lab)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INMOX 250 (Intra Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INMOX 500 (Intra Lab)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INMOX 500 (Intra Lab)'
);

-- line #2095
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INMOX-D 125 (Intra Lab)',
	'Amoxycillin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INMOX-D 125 (Intra Lab)'
);

-- line #2096
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INMOX 125 (Intra Lab)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INMOX 125 (Intra Lab)'
);

-- line #2097
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INMOX 250 (Intra Lab)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INMOX 250 (Intra Lab)'
);

-- line #2098
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IPHAMOX 250 (National)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IPHAMOX 250 (National)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IPHAMOX 500 (National)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IPHAMOX 500 (National)'
);

-- line #2099
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JESMOX 250 (M.K. Ph.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JESMOX 250 (M.K. Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JESMOX 500 (M.K. Ph.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JESMOX 500 (M.K. Ph.)'
);

-- line #2100
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JESMOX 125 (M.K. Ph.)',
	'Amoxycillin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JESMOX 125 (M.K. Ph.)'
);

-- line #2101
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JESMOX 125 (M.K. Ph.)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JESMOX 125 (M.K. Ph.)'
);

-- line #2102
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JESMOX 250 (M.K. Ph.)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JESMOX 250 (M.K. Ph.)'
);

-- line #2103
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JETMOX-D 125 (Elder)',
	'Amoxycillin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JETMOX-D 125 (Elder)'
);

-- line #2104
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JETMOX 125 (Elder)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JETMOX 125 (Elder)'
);

-- line #2105
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JETMOX 250 (Elder)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JETMOX 250 (Elder)'
);

-- line #2106
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JETMOX 500 (Elder)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JETMOX 500 (Elder)'
);

-- line #2107
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEMOX 250 (RISHAB(KUREKEMI))',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEMOX 250 (RISHAB(KUREKEMI))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEMOX 500 (RISHAB(KUREKEMI))',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEMOX 500 (RISHAB(KUREKEMI))'
);

-- line #2108
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'K-MOX 250 (Kim Lab)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'K-MOX 250 (Kim Lab)'
);

-- line #2109
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'K-MOX 500 (Kim Lab)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'K-MOX 500 (Kim Lab)'
);

-- line #2110
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'K-MOX 125 (Kim Lab)',
	'Amoxycillin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'K-MOX 125 (Kim Lab)'
);

-- line #2111
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KUROMOX 250 (Medicine & Kure)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KUROMOX 250 (Medicine & Kure)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KUROMOX 500 (Medicine & Kure)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KUROMOX 500 (Medicine & Kure)'
);

-- line #2112
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KUROMOX 125 (Medicine & Kure)',
	'Amoxycillin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KUROMOX 125 (Medicine & Kure)'
);

-- line #2113
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KUROMOX 125 (Medicine & Kure)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KUROMOX 125 (Medicine & Kure)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KUROMOX 250 (Medicine & Kure)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KUROMOX 250 (Medicine & Kure)'
);

-- line #2114
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LABMOX 125 (Laborate)',
	'Amoxycillin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LABMOX 125 (Laborate)'
);

-- line #2115
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LABMOX 125 (Laborate)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LABMOX 125 (Laborate)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LABMOX 250 (Laborate)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LABMOX 250 (Laborate)'
);

-- line #2116
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAKMOX 500 (LAKSUN)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAKMOX 500 (LAKSUN)'
);

-- line #2117
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAKMOX 250 (LAKSUN)',
	'Amoxycillin',
	'DT TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAKMOX 250 (LAKSUN)'
);

-- line #2118
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMOXY 250 (HETERO HC.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMOXY 250 (HETERO HC.)'
);

-- line #2119
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMOXY 500 (HETERO HC.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMOXY 500 (HETERO HC.)'
);

-- line #2120
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMOXY-D 125 (HETERO HC.)',
	'Amoxycillin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMOXY-D 125 (HETERO HC.)'
);

-- line #2121
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMOXY 250 (HETERO HC.)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMOXY 250 (HETERO HC.)'
);

-- line #2122
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMOXY 125 (HETERO HC.)',
	'Amoxycillin',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMOXY 125 (HETERO HC.)'
);

-- line #2123
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANMOX 250 (Lan Ph.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANMOX 250 (Lan Ph.)'
);

-- line #2124
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANMOX 500 (Lan Ph.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANMOX 500 (Lan Ph.)'
);

-- line #2125
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANMOX 125 (Lan Ph.)',
	'Amoxycillin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANMOX 125 (Lan Ph.)'
);

-- line #2126
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANMOX 250 (Lan Ph.)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANMOX 250 (Lan Ph.)'
);

-- line #2127
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANMOX 125 (Lan Ph.)',
	'Amoxycillin',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANMOX 125 (Lan Ph.)'
);

-- line #2128
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEXMOX 500 (Lexus)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEXMOX 500 (Lexus)'
);

-- line #2129
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEXMOX 125 (Lexus)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEXMOX 125 (Lexus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEXMOX 250 (Lexus)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEXMOX 250 (Lexus)'
);

-- line #2130
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINMOX 250 (Ajanta Ph.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINMOX 250 (Ajanta Ph.)'
);

-- line #2131
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINMOX 500 (Ajanta Ph.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINMOX 500 (Ajanta Ph.)'
);

-- line #2132
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINMOX 125 (Ajanta Ph.)',
	'Amoxycillin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINMOX 125 (Ajanta Ph.)'
);

-- line #2133
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINMOX 125 (Ajanta Ph.)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINMOX 125 (Ajanta Ph.)'
);

-- line #2134
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LMX 125 (Cadila)',
	'Amoxycillin',
	'ORAL SUSP',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LMX 125 (Cadila)'
);

-- line #2135
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOMOX 500 (Cubit Hc.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOMOX 500 (Cubit Hc.)'
);

-- line #2136
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOMOX 250 (Cubit Hc.)',
	'Amoxycillin',
	'DT TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOMOX 250 (Cubit Hc.)'
);

-- line #2137
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOMOXIN 500 (BHUVID RES.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOMOXIN 500 (BHUVID RES.)'
);

-- line #2138
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOMOX 125 (Cubit Hc.)',
	'Amoxycillin',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOMOX 125 (Cubit Hc.)'
);

-- line #2139
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOXYN 250 (A.F.D.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOXYN 250 (A.F.D.)'
);

-- line #2140
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOXYN 500 (A.F.D.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOXYN 500 (A.F.D.)'
);

-- line #2141
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOXYN 125 (A.F.D.)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOXYN 125 (A.F.D.)'
);

-- line #2142
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOXYN 250 (A.F.D.)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOXYN 250 (A.F.D.)'
);

-- line #2143
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOXYN 500 (A.F.D.)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOXYN 500 (A.F.D.)'
);

-- line #2144
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOXYN 125 (A.F.D.)',
	'Amoxycillin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOXYN 125 (A.F.D.)'
);

-- line #2145
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUPIMOX 250 (Lupin)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUPIMOX 250 (Lupin)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUPIMOX 500 (Lupin)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUPIMOX 500 (Lupin)'
);

-- line #2146
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUPIMOX 250 (Lupin)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUPIMOX 250 (Lupin)'
);

-- line #2147
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUPIMOX 500 (Lupin)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUPIMOX 500 (Lupin)'
);

-- line #2148
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUPIMOX 125 (Lupin)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUPIMOX 125 (Lupin)'
);

-- line #2149
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUPIMOX 250 (Lupin)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUPIMOX 250 (Lupin)'
);

-- line #2150
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAGCIL 250 (Neon)',
	'Amoxycillin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAGCIL 250 (Neon)'
);

-- line #2151
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAGCIL 500 (Neon)',
	'Amoxycillin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAGCIL 500 (Neon)'
);

-- line #2152
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOX 250 (Maan)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOX 250 (Maan)'
);

-- line #2153
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOX 500 (Maan)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOX 500 (Maan)'
);

-- line #2154
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOX-D 125 (Maan)',
	'Amoxycillin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOX-D 125 (Maan)'
);

-- line #2155
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOX 125 (Maan)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOX 125 (Maan)'
);

-- line #2156
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOX 250 (Maan)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOX 250 (Maan)'
);

-- line #2157
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOX 250 (Maan)',
	'Amoxycillin',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOX 250 (Maan)'
);

-- line #2158
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOX 500 (Maan)',
	'Amoxycillin',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOX 500 (Maan)'
);

-- line #2159
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAXMOX 250 (MAX)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAXMOX 250 (MAX)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAXMOX 500 (MAX)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAXMOX 500 (MAX)'
);

-- line #2160
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAXMOX 125 (MAX)',
	'Amoxycillin',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAXMOX 125 (MAX)'
);

-- line #2161
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAXMOX 250 (MAX)',
	'Amoxycillin',
	'KT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAXMOX 250 (MAX)'
);

-- line #2162
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDIMOX 250 (Medico)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDIMOX 250 (Medico)'
);

-- line #2163
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDIMOX 500 (Medico)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDIMOX 500 (Medico)'
);

-- line #2164
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDIMOX 125 (Medico)',
	'Amoxycillin',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDIMOX 125 (Medico)'
);

-- line #2165
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDIMOX 125 (Medico)',
	'Amoxycillin',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDIMOX 125 (Medico)'
);

-- line #2166
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDIMOX 250 (Medico)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDIMOX 250 (Medico)'
);

-- line #2167
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGAMOX 125 (Piramal Hc.)',
	'Amoxycillin',
	'DS',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGAMOX 125 (Piramal Hc.)'
);

-- line #2168
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'125', u'strength_2': u'', u'substance': u'Amoxycillin', u'always_empty': u'', u'form': u'', u'brand': u'MEGAMOX', u'strength_3': u'', u'company': u'Piramal Hc.', u'unit': u'mg'}

-- line #2169
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250', u'strength_2': u'', u'substance': u'Amoxycillin', u'always_empty': u'', u'form': u'', u'brand': u'MEGAMOX', u'strength_3': u'', u'company': u'Piramal Hc.', u'unit': u'mg'}

-- line #2170
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500', u'strength_2': u'', u'substance': u'Amoxycillin', u'always_empty': u'', u'form': u'', u'brand': u'MEGAMOX', u'strength_3': u'', u'company': u'Piramal Hc.', u'unit': u'mg'}

-- line #2171
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEROXIN 250 (Merit Org.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEROXIN 250 (Merit Org.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEROXIN 500 (Merit Org.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEROXIN 500 (Merit Org.)'
);

-- line #2172
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEROXIN 125 (Merit Org.)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEROXIN 125 (Merit Org.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEROXIN 250 (Merit Org.)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEROXIN 250 (Merit Org.)'
);

-- line #2173
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIXIMOX 250 (Cambridge Hc.)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIXIMOX 250 (Cambridge Hc.)'
);

-- line #2174
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'M-MOX PLUS 250 (Meridian)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'M-MOX PLUS 250 (Meridian)'
);

-- line #2175
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'M-MOX PLUS 500 (Meridian)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'M-MOX PLUS 500 (Meridian)'
);

-- line #2176
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOKCAN 250 (Cadila Ph.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOKCAN 250 (Cadila Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOKCAN 500 (Cadila Ph.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOKCAN 500 (Cadila Ph.)'
);

-- line #2177
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOKCAN-D 125 (Cadila Ph.)',
	'Amoxycillin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOKCAN-D 125 (Cadila Ph.)'
);

-- line #2178
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOKCAN 125 (Cadila Ph.)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOKCAN 125 (Cadila Ph.)'
);

-- line #2179
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOKCAN 250 (Cadila Ph.)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOKCAN 250 (Cadila Ph.)'
);

-- line #2180
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONAMOX 250 (Zee Lab)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONAMOX 250 (Zee Lab)'
);

-- line #2181
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONAMOX 500 (Zee Lab)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONAMOX 500 (Zee Lab)'
);

-- line #2182
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONAMOX 125 (Zee Lab)',
	'Amoxycillin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONAMOX 125 (Zee Lab)'
);

-- line #2183
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONAMOX 250 (Zee Lab)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONAMOX 250 (Zee Lab)'
);

-- line #2184
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONAMOX 500 (Zee Lab)',
	'Amoxycillin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONAMOX 500 (Zee Lab)'
);

-- line #2185
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOMOX 250 (Monokem)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOMOX 250 (Monokem)'
);

-- line #2186
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOMOX 500 (Monokem)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOMOX 500 (Monokem)'
);

-- line #2187
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOMOX-D 125 (Monokem)',
	'Amoxycillin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOMOX-D 125 (Monokem)'
);

-- line #2188
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOMOX 250 (Monokem)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOMOX 250 (Monokem)'
);

-- line #2189
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOMOX 125 (Monokem)',
	'Amoxycillin',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOMOX 125 (Monokem)'
);

-- line #2190
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOOXYBIOTIC 125 (Kapl)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOOXYBIOTIC 125 (Kapl)'
);

-- line #2191
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MORMOX 250 (Morepen)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MORMOX 250 (Morepen)'
);

-- line #2192
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MORMOX 500 (Morepen)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MORMOX 500 (Morepen)'
);

-- line #2193
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MORMOX 125 (Morepen)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MORMOX 125 (Morepen)'
);

-- line #2194
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MORMOX 250 (Morepen)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MORMOX 250 (Morepen)'
);

-- line #2195
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXAL 125 (Arvind Lab.)',
	'Amoxycillin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXAL 125 (Arvind Lab.)'
);

-- line #2196
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXAL 250 (Arvind Lab.)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXAL 250 (Arvind Lab.)'
);

-- line #2197
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXAL 125 (Arvind Lab.)',
	'Amoxycillin',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXAL 125 (Arvind Lab.)'
);

-- line #2198
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOX 200 (Rexcel)',
	'Amoxycillin',
	'BD DISTAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOX 200 (Rexcel)'
);

-- line #2199
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOX 400 (Rexcel)',
	'Amoxycillin',
	'BD DISTAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOX 400 (Rexcel)'
);

-- line #2200
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOX 200 (Ranbaxy)',
	'Amoxycillin',
	'BD REDIMIX',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOX 200 (Ranbaxy)'
);

-- line #2201
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOX 400 (Ranbaxy)',
	'Amoxycillin',
	'BD REDIMIX',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOX 400 (Ranbaxy)'
);

-- line #2202
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOX 200 (Ranbaxy)',
	'Amoxycillin',
	'BD SUSP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOX 200 (Ranbaxy)'
);

-- line #2203
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOX 400 (Ranbaxy)',
	'Amoxycillin',
	'BD SUSP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOX 400 (Ranbaxy)'
);

-- line #2204
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOX 875 (Ranbaxy)',
	'Amoxycillin',
	'BD TAB',
	gm.nullify_empty_string('875')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOX 875 (Ranbaxy)'
);

-- line #2205
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOX 250 (Rexcel)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOX 250 (Rexcel)'
);

-- line #2206
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOX 500 (Rexcel)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOX 500 (Rexcel)'
);

-- line #2207
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXCEE 250 (Chemo Bio.)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXCEE 250 (Chemo Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXCEE 500 (Chemo Bio.)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXCEE 500 (Chemo Bio.)'
);

-- line #2208
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXCEM DRY 125 (Beckcem)',
	'Amoxycillin',
	'POW',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXCEM DRY 125 (Beckcem)'
);

-- line #2209
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXCEM 250 (Beckcem)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXCEM 250 (Beckcem)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXCEM 500 (Beckcem)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXCEM 500 (Beckcem)'
);

-- line #2210
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250', u'strength_2': u'', u'substance': u'Amoxycillin', u'always_empty': u'', u'form': u'', u'brand': u'MOX CHW', u'strength_3': u'', u'company': u'Rexcel', u'unit': u'mg'}

-- line #2211
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXEL 500 (Medicamen)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXEL 500 (Medicamen)'
);

-- line #2212
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXEL 125 (Medicamen)',
	'Amoxycillin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXEL 125 (Medicamen)'
);

-- line #2213
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXEL 250 (Medicamen)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXEL 250 (Medicamen)'
);

-- line #2214
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXER 250 (Maneesh)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXER 250 (Maneesh)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXER 500 (Maneesh)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXER 500 (Maneesh)'
);

-- line #2215
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXIBACT 250 (Sun)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXIBACT 250 (Sun)'
);

-- line #2216
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXIBACT 500 (Sun)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXIBACT 500 (Sun)'
);

-- line #2217
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXIBACT 125 (Sun)',
	'Amoxycillin',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXIBACT 125 (Sun)'
);

-- line #2218
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Amoxycillin', u'always_empty': u'', u'form': u'CAP', u'brand': u'MOXICA -500', u'strength_3': u'', u'company': u'NIVCA', u'unit': u''}

-- line #2219
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXICA 250 (Indica)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXICA 250 (Indica)'
);

-- line #2220
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Amoxycillin', u'always_empty': u'', u'form': u'CAP', u'brand': u'MOXICA', u'strength_3': u'', u'company': u'NIVCA', u'unit': u''}

-- line #2221
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXICA 125 (Indica)',
	'Amoxycillin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXICA 125 (Indica)'
);

-- line #2222
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Amoxycillin', u'always_empty': u'', u'form': u'DT TAB', u'brand': u'MOXICA', u'strength_3': u'', u'company': u'NIVCA', u'unit': u''}

-- line #2223
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXICA-F 500 (Indica)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXICA-F 500 (Indica)'
);

-- line #2224
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'125', u'strength_2': u'', u'substance': u'Amoxycillin', u'always_empty': u'', u'form': u'', u'brand': u'MOXICA -K T', u'strength_3': u'', u'company': u'Indica', u'unit': u'mg'}

-- line #2225
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXICA 250 (Indica)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXICA 250 (Indica)'
);

-- line #2226
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXIC 125 (Mamta Ph.)',
	'Amoxycillin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXIC 125 (Mamta Ph.)'
);

-- line #2227
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXIC 250 (Mamta Ph.)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXIC 250 (Mamta Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXIC 500 (Mamta Ph.)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXIC 500 (Mamta Ph.)'
);

-- line #2228
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXIDAT 125 (DATLA)',
	'Amoxycillin',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXIDAT 125 (DATLA)'
);

-- line #2229
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXIDAY 250 (Chemo D.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXIDAY 250 (Chemo D.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXIDAY 500 (Chemo D.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXIDAY 500 (Chemo D.)'
);

-- line #2230
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXIDAY 125 (Chemo D.)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXIDAY 125 (Chemo D.)'
);

-- line #2231
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXIDAY 250 (Chemo D.)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXIDAY 250 (Chemo D.)'
);

-- line #2232
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXIFAST 500 (CHEMO HC.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXIFAST 500 (CHEMO HC.)'
);

-- line #2233
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXIFAST KID/250 125 (CHEMO HC.)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXIFAST KID/250 125 (CHEMO HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXIFAST KID/250 250 (CHEMO HC.)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXIFAST KID/250 250 (CHEMO HC.)'
);

-- line #2234
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXIGEM 500 (AXIS LIFE)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXIGEM 500 (AXIS LIFE)'
);

-- line #2235
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXIKIND 500 (Mankind)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXIKIND 500 (Mankind)'
);

-- line #2236
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXIKIND 250 (Mankind)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXIKIND 250 (Mankind)'
);

-- line #2237
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXIL DRY 125 (Beckcem)',
	'Amoxycillin',
	'POW',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXIL DRY 125 (Beckcem)'
);

-- line #2238
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXILEB 250 (Leben)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXILEB 250 (Leben)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXILEB 500 (Leben)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXILEB 500 (Leben)'
);

-- line #2239
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXILEB 125 (Leben)',
	'Amoxycillin',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXILEB 125 (Leben)'
);

-- line #2240
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXILEB 125 (Leben)',
	'Amoxycillin',
	'SUSP',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXILEB 125 (Leben)'
);

-- line #2241
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXILEB 250 (Leben)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXILEB 250 (Leben)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXILEB 500 (Leben)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXILEB 500 (Leben)'
);

-- line #2242
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXIL 250 (Beckcem)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXIL 250 (Beckcem)'
);

-- line #2243
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXIL 500 (Beckcem)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXIL 500 (Beckcem)'
);

-- line #2244
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXILUP 250 (LUPINOVA)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXILUP 250 (LUPINOVA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXILUP 500 (LUPINOVA)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXILUP 500 (LUPINOVA)'
);

-- line #2245
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXIMET 250 (Mount M.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXIMET 250 (Mount M.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXIMET 500 (Mount M.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXIMET 500 (Mount M.)'
);

-- line #2246
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXIMET 125 (Mount M.)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXIMET 125 (Mount M.)'
);

-- line #2247
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXIMON 250 (Cachet)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXIMON 250 (Cachet)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXIMON 500 (Cachet)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXIMON 500 (Cachet)'
);

-- line #2248
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXIMON 125 (Cachet)',
	'Amoxycillin',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXIMON 125 (Cachet)'
);

-- line #2249
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXINC 250 (Smiles Inc.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXINC 250 (Smiles Inc.)'
);

-- line #2250
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXIND 250 (Indu D.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXIND 250 (Indu D.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXIND 500 (Indu D.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXIND 500 (Indu D.)'
);

-- line #2251
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXIND 125 (Indu D.)',
	'Amoxycillin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXIND 125 (Indu D.)'
);

-- line #2252
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXIND KID 250 (Indu D.)',
	'Amoxycillin',
	'F.',
	gm.nullify_empty_string('250')::numeric,
	'mg DT'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXIND KID 250 (Indu D.)'
);

-- line #2253
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOX 250 (Rexcel)',
	'Amoxycillin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOX 250 (Rexcel)'
);

-- line #2254
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOX 500 (Rexcel)',
	'Amoxycillin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOX 500 (Rexcel)'
);

-- line #2255
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXINTA 250 (Intas)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXINTA 250 (Intas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXINTA 500 (Intas)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXINTA 500 (Intas)'
);

-- line #2256
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXINTA-D 125 (Intas)',
	'Amoxycillin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXINTA-D 125 (Intas)'
);

-- line #2257
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXIPAL 250 (Jagsonpal)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXIPAL 250 (Jagsonpal)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXIPAL 500 (Jagsonpal)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXIPAL 500 (Jagsonpal)'
);

-- line #2258
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXIPAL 125 (Jagsonpal)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXIPAL 125 (Jagsonpal)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXIPAL 250 (Jagsonpal)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXIPAL 250 (Jagsonpal)'
);

-- line #2259
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXISH 250 (Maneesh)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXISH 250 (Maneesh)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXISH 500 (Maneesh)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXISH 500 (Maneesh)'
);

-- line #2260
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXISH 125 (Maneesh)',
	'Amoxycillin',
	'KT/250DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXISH 125 (Maneesh)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXISH 250 (Maneesh)',
	'Amoxycillin',
	'KT/250DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXISH 250 (Maneesh)'
);

-- line #2261
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXI-T 250 (TALENT LAB.)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXI-T 250 (TALENT LAB.)'
);

-- line #2262
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOX 125 (Rexcel)',
	'Amoxycillin',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOX 125 (Rexcel)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOX 250 (Rexcel)',
	'Amoxycillin',
	'KID TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOX 250 (Rexcel)'
);

-- line #2263
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXODIN 250 (Healthcare)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXODIN 250 (Healthcare)'
);

-- line #2264
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOX REDIMIX 100 (Rexcel)',
	'AMOXYCILLIN',
	'DROPS',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOX REDIMIX 100 (Rexcel)'
);

-- line #2265
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOX SOFGEL 250 (Rexcel)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOX SOFGEL 250 (Rexcel)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOX SOFGEL 500 (Rexcel)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOX SOFGEL 500 (Rexcel)'
);

-- line #2266
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXSPEN 500 (MADHAV BIO.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXSPEN 500 (MADHAV BIO.)'
);

-- line #2267
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXSPEN 125 (MADHAV BIO.)',
	'Amoxycillin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXSPEN 125 (MADHAV BIO.)'
);

-- line #2268
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXSPEN 125 (MADHAV BIO.)',
	'Amoxycillin',
	'DT TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXSPEN 125 (MADHAV BIO.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXSPEN 250 (MADHAV BIO.)',
	'Amoxycillin',
	'DT TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXSPEN 250 (MADHAV BIO.)'
);

-- line #2269
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOX 125 (Rexcel)',
	'Amoxycillin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOX 125 (Rexcel)'
);

-- line #2270
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOX 250 (Rexcel)',
	'Amoxycillin',
	'SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOX 250 (Rexcel)'
);

-- line #2271
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOX 125 (Rexcel)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOX 125 (Rexcel)'
);

-- line #2272
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOX 250 (Rexcel)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOX 250 (Rexcel)'
);

-- line #2273
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOX 500 (Rexcel)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOX 500 (Rexcel)'
);

-- line #2274
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXTER 250 (Austere)',
	'Amoxycillin',
	'D.SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXTER 250 (Austere)'
);

-- line #2275
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXTER 125 (Austere)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXTER 125 (Austere)'
);

-- line #2276
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXTER 250 (Austere)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXTER 250 (Austere)'
);

-- line #2277
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXTID 250 (ALLENGE)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXTID 250 (ALLENGE)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXTID 500 (ALLENGE)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXTID 500 (ALLENGE)'
);

-- line #2278
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXTID 250 (ALLENGE)',
	'Amoxycillin',
	'DT TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXTID 250 (ALLENGE)'
);

-- line #2279
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXUP 250 (Ups Hc.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXUP 250 (Ups Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXUP 500 (Ups Hc.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXUP 500 (Ups Hc.)'
);

-- line #2280
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXUP 250 (Ups Hc.)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXUP 250 (Ups Hc.)'
);

-- line #2281
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXWIN 250 (Jaywin)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXWIN 250 (Jaywin)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXWIN 500 (Jaywin)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXWIN 500 (Jaywin)'
);

-- line #2282
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXWIN 125 (Jaywin)',
	'Amoxycillin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXWIN 125 (Jaywin)'
);

-- line #2283
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXWIN 125 (Jaywin)',
	'Amoxycillin',
	'KT/250 TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXWIN 125 (Jaywin)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXWIN 250 (Jaywin)',
	'Amoxycillin',
	'KT/250 TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXWIN 250 (Jaywin)'
);

-- line #2284
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXYBIOTIC 250 (Kapl)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXYBIOTIC 250 (Kapl)'
);

-- line #2285
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXYBIOTIC 500 (Kapl)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXYBIOTIC 500 (Kapl)'
);

-- line #2286
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXYBIOTIC 125 (Kapl)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXYBIOTIC 125 (Kapl)'
);

-- line #2287
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXYBIOTIC 250 (Kapl)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXYBIOTIC 250 (Kapl)'
);

-- line #2288
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXYBIOTIC 125 (Kapl)',
	'Amoxycillin',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXYBIOTIC 125 (Kapl)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXYBIOTIC 250 (Kapl)',
	'Amoxycillin',
	'KID TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXYBIOTIC 250 (Kapl)'
);

-- line #2289
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'M-OXY 500 (Antigen Hc.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'M-OXY 500 (Antigen Hc.)'
);

-- line #2290
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXYDIL 250 (Solvay Ph.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXYDIL 250 (Solvay Ph.)'
);

-- line #2291
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXYDIL 500 (Solvay Ph.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXYDIL 500 (Solvay Ph.)'
);

-- line #2292
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXYDIL-D 125 (Solvay Ph.)',
	'Amoxycillin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXYDIL-D 125 (Solvay Ph.)'
);

-- line #2293
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXYDIL 125 (Solvay Ph.)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXYDIL 125 (Solvay Ph.)'
);

-- line #2294
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXYDIL 250 (Solvay Ph.)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXYDIL 250 (Solvay Ph.)'
);

-- line #2295
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXYDIL 500 (Solvay Ph.)',
	'Amoxycillin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXYDIL 500 (Solvay Ph.)'
);

-- line #2296
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXYLAR 250 (Lark Labs)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXYLAR 250 (Lark Labs)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXYLAR 500 (Lark Labs)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXYLAR 500 (Lark Labs)'
);

-- line #2297
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXYLAR 100 (Lark Labs)',
	'Amoxycillin',
	'DPS',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXYLAR 100 (Lark Labs)'
);

-- line #2298
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXYLAR-D 125 (Lark Labs)',
	'Amoxycillin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXYLAR-D 125 (Lark Labs)'
);

-- line #2299
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXYLAR 125 (Lark Labs)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXYLAR 125 (Lark Labs)'
);

-- line #2300
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXYLIFE 250 (Life Line)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXYLIFE 250 (Life Line)'
);

-- line #2301
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXYLIFE 500 (Life Line)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXYLIFE 500 (Life Line)'
);

-- line #2302
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXYLIFE 250 (Life Line)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXYLIFE 250 (Life Line)'
);

-- line #2303
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXYLIFE 125 (Life Line)',
	'Amoxycillin',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXYLIFE 125 (Life Line)'
);

-- line #2304
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXYLIFE 125 (Life Line)',
	'Amoxycillin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXYLIFE 125 (Life Line)'
);

-- line #2305
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXYNOR 250 (Norris Med.)',
	'Amoxycillin',
	'CAPS',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXYNOR 250 (Norris Med.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXYNOR 500 (Norris Med.)',
	'Amoxycillin',
	'CAPS',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXYNOR 500 (Norris Med.)'
);

-- line #2306
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXYNOR 125 (Norris Med.)',
	'Amoxycillin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXYNOR 125 (Norris Med.)'
);

-- line #2307
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXYZEN 250 (Zenith Hc.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXYZEN 250 (Zenith Hc.)'
);

-- line #2308
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXYZEN 500 (Zenith Hc.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXYZEN 500 (Zenith Hc.)'
);

-- line #2309
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXYZEN 125 (Zenith Hc.)',
	'Amoxycillin',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXYZEN 125 (Zenith Hc.)'
);

-- line #2310
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXYZEN 250 (Zenith Hc.)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXYZEN 250 (Zenith Hc.)'
);

-- line #2311
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYMOX 250 (M.M. Labs)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYMOX 250 (M.M. Labs)'
);

-- line #2312
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYMOX 500 (M.M. Labs)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYMOX 500 (M.M. Labs)'
);

-- line #2313
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYMOX-D 125 (M.M. Labs)',
	'Amoxycillin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYMOX-D 125 (M.M. Labs)'
);

-- line #2314
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYMOX 250 (M.M. Labs)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYMOX 250 (M.M. Labs)'
);

-- line #2315
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYMOX 125 (M.M. Labs)',
	'Amoxycillin',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYMOX 125 (M.M. Labs)'
);

-- line #2316
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NATAMOX 250 (Natco Ph.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NATAMOX 250 (Natco Ph.)'
);

-- line #2317
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NATAMOX 500 (Natco Ph.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NATAMOX 500 (Natco Ph.)'
);

-- line #2318
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NATAMOX 100 (Natco Ph.)',
	'Amoxycillin',
	'DPS',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NATAMOX 100 (Natco Ph.)'
);

-- line #2319
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NATAMOX-D 125 (Natco Ph.)',
	'Amoxycillin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NATAMOX-D 125 (Natco Ph.)'
);

-- line #2320
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NATAMOX 125 (Natco Ph.)',
	'Amoxycillin',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NATAMOX 125 (Natco Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NATAMOX 250 (Natco Ph.)',
	'Amoxycillin',
	'KT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NATAMOX 250 (Natco Ph.)'
);

-- line #2321
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEPOMOX 250 (Ttk Hc.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEPOMOX 250 (Ttk Hc.)'
);

-- line #2322
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEPOMOX 500 (Ttk Hc.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEPOMOX 500 (Ttk Hc.)'
);

-- line #2323
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEPOMOX 125 (Ttk Hc.)',
	'Amoxycillin',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEPOMOX 125 (Ttk Hc.)'
);

-- line #2324
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOBAMOX 250 (Life Line)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOBAMOX 250 (Life Line)'
);

-- line #2325
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NODIMOX 125 (Alkem)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NODIMOX 125 (Alkem)'
);

-- line #2326
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NODIMOX 250 (Alkem)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NODIMOX 250 (Alkem)'
);

-- line #2327
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NODIMOX 500 (Alkem)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NODIMOX 500 (Alkem)'
);

-- line #2328
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NODIMOX 25 (Alkem)',
	'Amoxycillin',
	'D.SYR',
	gm.nullify_empty_string('25')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NODIMOX 25 (Alkem)'
);

-- line #2329
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NODIMOX 250 (Alkem)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NODIMOX 250 (Alkem)'
);

-- line #2330
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NODIMOX 500 (Alkem)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NODIMOX 500 (Alkem)'
);

-- line #2331
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORMOX 250 (NORTECH REM.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORMOX 250 (NORTECH REM.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORMOX 500 (NORTECH REM.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORMOX 500 (NORTECH REM.)'
);

-- line #2332
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORMOX 125 (NORTECH REM.)',
	'Amoxycillin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORMOX 125 (NORTECH REM.)'
);

-- line #2333
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVAMOX 250 (Cipla)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVAMOX 250 (Cipla)'
);

-- line #2334
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVAMOX 500 (Cipla)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVAMOX 500 (Cipla)'
);

-- line #2335
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVAMOX-D 125 (Cipla)',
	'Amoxycillin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVAMOX-D 125 (Cipla)'
);

-- line #2336
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVAMOX 125 (Cipla)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVAMOX 125 (Cipla)'
);

-- line #2337
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVAMOX 250 (Cipla)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVAMOX 250 (Cipla)'
);

-- line #2338
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVAMOX P 100 (Cipla)',
	'Amoxycillin',
	'DPS',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVAMOX P 100 (Cipla)'
);

-- line #2339
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100', u'strength_2': u'', u'substance': u'Amoxycillin', u'always_empty': u'', u'form': u'', u'brand': u'NOVAMOX REDIUSE', u'strength_3': u'', u'company': u'Cipla', u'unit': u'mg/5ML'}

-- line #2340
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250', u'strength_2': u'', u'substance': u'Amoxycillin', u'always_empty': u'', u'form': u'', u'brand': u'NOVAMOX REDIUSE', u'strength_3': u'', u'company': u'Cipla', u'unit': u'mg/5ML'}

-- line #2341
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVAMOX REDIUSE 125 (Cipla)',
	'Amoxycillin',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVAMOX REDIUSE 125 (Cipla)'
);

-- line #2342
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVOPEN-250 250 (Royal)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVOPEN-250 250 (Royal)'
);

-- line #2343
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVOPEN-500 500 (Royal)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVOPEN-500 500 (Royal)'
);

-- line #2344
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCTAMOX 250 (Medispan)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCTAMOX 250 (Medispan)'
);

-- line #2345
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCTAMOX 500 (Medispan)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCTAMOX 500 (Medispan)'
);

-- line #2346
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCTAMOX 125 (Medispan)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCTAMOX 125 (Medispan)'
);

-- line #2347
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCTAMOX 250 (Medispan)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCTAMOX 250 (Medispan)'
);

-- line #2348
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLMOXIN 250 (Olcare)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLMOXIN 250 (Olcare)'
);

-- line #2349
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLMOXIN 500 (Olcare)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLMOXIN 500 (Olcare)'
);

-- line #2350
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLMOXIN 125 (Olcare)',
	'Amoxycillin',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLMOXIN 125 (Olcare)'
);

-- line #2351
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLYMOX 250 (Shalaks)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLYMOX 250 (Shalaks)'
);

-- line #2352
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLYMOX 500 (Shalaks)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLYMOX 500 (Shalaks)'
);

-- line #2353
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLYMOX 125 (Shalaks)',
	'Amoxycillin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLYMOX 125 (Shalaks)'
);

-- line #2354
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLYMOX 125 (Shalaks)',
	'Amoxycillin',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLYMOX 125 (Shalaks)'
);

-- line #2355
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMOKSY 250 (Natura)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMOKSY 250 (Natura)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMOKSY 500 (Natura)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMOKSY 500 (Natura)'
);

-- line #2356
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONAMOX 125 (Sayona)',
	'Amoxycillin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONAMOX 125 (Sayona)'
);

-- line #2357
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONAMOX 250 (Sayona)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONAMOX 250 (Sayona)'
);

-- line #2358
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONAMOX 125 (Sayona)',
	'Amoxycillin',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONAMOX 125 (Sayona)'
);

-- line #2359
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPTIMOX 125 (Troikaa)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPTIMOX 125 (Troikaa)'
);

-- line #2360
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPTIMOX 250 (Troikaa)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPTIMOX 250 (Troikaa)'
);

-- line #2361
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPTIMOX 500 (Troikaa)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPTIMOX 500 (Troikaa)'
);

-- line #2362
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPTIMOX 250 (Troikaa)',
	'Amoxycillin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPTIMOX 250 (Troikaa)'
);

-- line #2363
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPTIMOX 500 (Troikaa)',
	'Amoxycillin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPTIMOX 500 (Troikaa)'
);

-- line #2364
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORGAMOX 250 (Shinto Org.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORGAMOX 250 (Shinto Org.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORGAMOX 500 (Shinto Org.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORGAMOX 500 (Shinto Org.)'
);

-- line #2365
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORGAMOX 250 (Shinto Org.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORGAMOX 250 (Shinto Org.)'
);

-- line #2366
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORGAMOX 250 (Shinto Org.)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORGAMOX 250 (Shinto Org.)'
);

-- line #2367
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORMOX 250 (Trio Ph.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORMOX 250 (Trio Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORMOX 500 (Trio Ph.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORMOX 500 (Trio Ph.)'
);

-- line #2368
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORMOX 125 (Trio Rem.)',
	'Amoxycillin',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORMOX 125 (Trio Rem.)'
);

-- line #2369
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORMOX 250 (Trio Rem.)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORMOX 250 (Trio Rem.)'
);

-- line #2370
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORYMOX 250 (Jrs Oryx.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORYMOX 250 (Jrs Oryx.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORYMOX 500 (Jrs Oryx.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORYMOX 500 (Jrs Oryx.)'
);

-- line #2371
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORYMOX 100 (Jrs Oryx.)',
	'Amoxycillin',
	'DPS',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORYMOX 100 (Jrs Oryx.)'
);

-- line #2372
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORYMOX 125 (Jrs Oryx.)',
	'Amoxycillin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORYMOX 125 (Jrs Oryx.)'
);

-- line #2373
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORYMOX 125 (Jrs Oryx.)',
	'Amoxycillin',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORYMOX 125 (Jrs Oryx.)'
);

-- line #2374
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSOMOX 250 (Osho Ph.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSOMOX 250 (Osho Ph.)'
);

-- line #2375
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSOMOX 500 (Osho Ph.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSOMOX 500 (Osho Ph.)'
);

-- line #2376
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSOMOX-D 125 (Osho Ph.)',
	'Amoxycillin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSOMOX-D 125 (Osho Ph.)'
);

-- line #2377
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSOMOX 250 (Osho Ph.)',
	'Amoxycillin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSOMOX 250 (Osho Ph.)'
);

-- line #2378
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSOMOX 500 (Osho Ph.)',
	'Amoxycillin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSOMOX 500 (Osho Ph.)'
);

-- line #2379
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSOMOX 250 (Osper)',
	'Amoxycillin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSOMOX 250 (Osper)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSOMOX 500 (Osper)',
	'Amoxycillin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSOMOX 500 (Osper)'
);

-- line #2380
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSOMOX 125 (Osho Ph.)',
	'Amoxycillin',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSOMOX 125 (Osho Ph.)'
);

-- line #2381
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSOMOX 250 (Osho Ph.)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSOMOX 250 (Osho Ph.)'
);

-- line #2382
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXIL 250 (Biocin Hc.)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXIL 250 (Biocin Hc.)'
);

-- line #2383
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXIL 125 (Biocin Hc.)',
	'Amoxycillin',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXIL 125 (Biocin Hc.)'
);

-- line #2384
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANMOX 500 (Kwik Hc.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANMOX 500 (Kwik Hc.)'
);

-- line #2385
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANMOX 250 (Kwik Hc.)',
	'Amoxycillin',
	'D.SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANMOX 250 (Kwik Hc.)'
);

-- line #2386
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANMOX 250 (Kwik Hc.)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANMOX 250 (Kwik Hc.)'
);

-- line #2387
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PATMOX 250 (Patson)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PATMOX 250 (Patson)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PATMOX 500 (Patson)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PATMOX 500 (Patson)'
);

-- line #2388
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PATMOX 250 (Patson)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PATMOX 250 (Patson)'
);

-- line #2389
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PATMOX KID 125 (Patson)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PATMOX KID 125 (Patson)'
);

-- line #2390
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PD-MOX 250 (Parenteral)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PD-MOX 250 (Parenteral)'
);

-- line #2391
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PD-MOX 500 (Parenteral)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PD-MOX 500 (Parenteral)'
);

-- line #2392
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PDMOX 125 (Parenteral)',
	'Amoxycillin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PDMOX 125 (Parenteral)'
);

-- line #2393
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENMOX 250 (SAFE PH.)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENMOX 250 (SAFE PH.)'
);

-- line #2394
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENMOX KID/250 125 (Esken)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENMOX KID/250 125 (Esken)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENMOX KID/250 250 (Esken)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENMOX KID/250 250 (Esken)'
);

-- line #2395
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEXOMOX 250 (Apex Labs.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEXOMOX 250 (Apex Labs.)'
);

-- line #2396
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEXOMOX 500 (Apex Labs.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEXOMOX 500 (Apex Labs.)'
);

-- line #2397
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEXOMOX 125 (Apex Labs.)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEXOMOX 125 (Apex Labs.)'
);

-- line #2398
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHENOXYL 250 (Zydus Cadila)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHENOXYL 250 (Zydus Cadila)'
);

-- line #2399
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHENOXYL 500 (Zydus Cadila)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHENOXYL 500 (Zydus Cadila)'
);

-- line #2400
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHENOXYL-D 125 (Zydus Cadila)',
	'Amoxycillin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHENOXYL-D 125 (Zydus Cadila)'
);

-- line #2401
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHENOXYL 125 (Zydus Cadila)',
	'Amoxycillin',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHENOXYL 125 (Zydus Cadila)'
);

-- line #2402
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHENOXYL 250 (Zydus Cadila)',
	'Amoxycillin',
	'KT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHENOXYL 250 (Zydus Cadila)'
);

-- line #2403
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POXILLIN 250 (Pifer Ph.)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POXILLIN 250 (Pifer Ph.)'
);

-- line #2404
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POXILLIN 125 (Pifer Ph.)',
	'Amoxycillin',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POXILLIN 125 (Pifer Ph.)'
);

-- line #2405
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POXILLIN 500 (Pifer Ph.)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POXILLIN 500 (Pifer Ph.)'
);

-- line #2406
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRESSMOX 500 (VERITAZ)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRESSMOX 500 (VERITAZ)'
);

-- line #2407
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRESSMOX 125 (VERITAZ)',
	'Amoxycillin',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRESSMOX 125 (VERITAZ)'
);

-- line #2408
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRESSMOX 250 (VERITAZ)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRESSMOX 250 (VERITAZ)'
);

-- line #2409
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PULMOXYL 250 (Brown & B.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PULMOXYL 250 (Brown & B.)'
);

-- line #2410
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PULMOXYL 500 (Brown & B.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PULMOXYL 500 (Brown & B.)'
);

-- line #2411
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PULMOXYL-D 125 (Brown & B.)',
	'Amoxycillin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PULMOXYL-D 125 (Brown & B.)'
);

-- line #2412
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PULMOXYL 250 (Brown & B.)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PULMOXYL 250 (Brown & B.)'
);

-- line #2413
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PULMOXYL 125 (Brown & B.)',
	'Amoxycillin',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PULMOXYL 125 (Brown & B.)'
);

-- line #2414
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PUREMOX 500 (Maneesh)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PUREMOX 500 (Maneesh)'
);

-- line #2415
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PUREMOX 250 (Maneesh)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PUREMOX 250 (Maneesh)'
);

-- line #2416
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RADIMOX 250 (Radicura)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RADIMOX 250 (Radicura)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RADIMOX 500 (Radicura)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RADIMOX 500 (Radicura)'
);

-- line #2417
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RADIMOX 125 (Radicura)',
	'Amoxycillin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RADIMOX 125 (Radicura)'
);

-- line #2418
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RADIMOX 125 (Radicura)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RADIMOX 125 (Radicura)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RADIMOX 250 (Radicura)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RADIMOX 250 (Radicura)'
);

-- line #2419
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RASMOX 500 (RASS HC.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RASMOX 500 (RASS HC.)'
);

-- line #2420
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'125', u'strength_2': u'', u'substance': u'Amoxycillin', u'always_empty': u'', u'form': u'', u'brand': u'RASMOX D SRY', u'strength_3': u'', u'company': u'RASS HC.', u'unit': u'mg/5ML'}

-- line #2421
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RASMOX 250 (RASS HC.)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RASMOX 250 (RASS HC.)'
);

-- line #2422
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REKMOX 250 (Rekvina)',
	'Amoxycillin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REKMOX 250 (Rekvina)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REKMOX 500 (Rekvina)',
	'Amoxycillin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REKMOX 500 (Rekvina)'
);

-- line #2423
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REKMOX 125 (Rekvina)',
	'Amoxycillin',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REKMOX 125 (Rekvina)'
);

-- line #2424
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REKMOX 250 (Rekvina)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REKMOX 250 (Rekvina)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REKMOX 500 (Rekvina)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REKMOX 500 (Rekvina)'
);

-- line #2425
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELAMOX 250 (Relax Ph.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELAMOX 250 (Relax Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELAMOX 500 (Relax Ph.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELAMOX 500 (Relax Ph.)'
);

-- line #2426
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELAMOX 125 (Relax Ph.)',
	'Amoxycillin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELAMOX 125 (Relax Ph.)'
);

-- line #2427
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELAMOX 250 (Relax Ph.)',
	'Amoxycillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELAMOX 250 (Relax Ph.)'
);

-- line #2428
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELAMOX 125 (Relax Ph.)',
	'Amoxycillin',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELAMOX 125 (Relax Ph.)'
);

-- line #2429
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REMOX 250 (SANCHEZ LAB.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REMOX 250 (SANCHEZ LAB.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REMOX 500 (SANCHEZ LAB.)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REMOX 500 (SANCHEZ LAB.)'
);

-- line #2430
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REXYL 250 (Relish)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REXYL 250 (Relish)'
);

-- line #2431
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REXYL 500 (Relish)',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REXYL 500 (Relish)'
);

-- line #2432
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REXYL KID-F 250 (Relish)',
	'Amoxycillin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REXYL KID-F 250 (Relish)'
);

-- line #2433
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REXYL 125 (Relish)',
	'Amoxycillin',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REXYL 125 (Relish)'
);

-- line #2434
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RICOMOX 250 (RISHAB(OROCHEM))',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RICOMOX 250 (RISHAB(OROCHEM))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RICOMOX 500 (RISHAB(OROCHEM))',
	'Amoxycillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RICOMOX 500 (RISHAB(OROCHEM))'
);

-- line #2435
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMFOCAN 50 (Dabur Ph.)',
	'Amphotericin-B',
	'V',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMFOCAN 50 (Dabur Ph.)'
);

-- line #2436
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMFOCARE 50 (Criticare)',
	'Amphotericin-B',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMFOCARE 50 (Criticare)'
);

-- line #2437
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMFOTEX 50 (Cytomed(Alkem))',
	'Amphotericin-B',
	'VIAL',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMFOTEX 50 (Cytomed(Alkem))'
);

-- line #2438
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMFY (LYOPHILIZED) 50 (Intas)',
	'Amphotericin-B',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMFY (LYOPHILIZED) 50 (Intas)'
);

-- line #2439
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMPHO-B 50 (VHB)',
	'Amphotericin-B',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMPHO-B 50 (VHB)'
);

-- line #2440
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMPHOCIL 50 (Criticare)',
	'Amphotericin-B',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg(IN COMPLEX WITH CHOLESTYL SULPHATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMPHOCIL 50 (Criticare)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMPHOCIL 100 (Criticare)',
	'Amphotericin-B',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg(IN COMPLEX WITH CHOLESTYL SULPHATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMPHOCIL 100 (Criticare)'
);

-- line #2441
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMPHODEX 50 (Samarth Life)',
	'Amphotericin-B',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMPHODEX 50 (Samarth Life)'
);

-- line #2442
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMPHOLIP 100 (Bharat S.)',
	'Amphotericin-B',
	'LIQ',
	gm.nullify_empty_string('100')::numeric,
	'mg(LIPID COM.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMPHOLIP 100 (Bharat S.)'
);

-- line #2443
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMPHOLIP 10 (Bharat S.)',
	'Amphotericin-B',
	'LIQ',
	gm.nullify_empty_string('10')::numeric,
	'mg(LIPID COM.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMPHOLIP 10 (Bharat S.)'
);

-- line #2444
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMPHOLIP 50 (Bharat S.)',
	'Amphotericin-B',
	'LIQ',
	gm.nullify_empty_string('50')::numeric,
	'mg(LIPID COM.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMPHOLIP 50 (Bharat S.)'
);

-- line #2445
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMPHOLYN 50 (LYKA LABS)',
	'Amphotericin-B',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMPHOLYN 50 (LYKA LABS)'
);

-- line #2446
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50', u'strength_2': u'', u'substance': u'Amphotericin-B', u'always_empty': u'', u'form': u'', u'brand': u'AMPHOMUL', u'strength_3': u'', u'company': u'Bharat S.', u'unit': u'mg'}

-- line #2447
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMPHOTIN 50 (United Bio.)',
	'Amphotericin-B',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMPHOTIN 50 (United Bio.)'
);

-- line #2448
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMPHOTIN-LIP 10 (United Bio.)',
	'Amphotericin-B',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg(LIPID COMPLEX)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMPHOTIN-LIP 10 (United Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMPHOTIN-LIP 20 (United Bio.)',
	'Amphotericin-B',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg(LIPID COMPLEX)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMPHOTIN-LIP 20 (United Bio.)'
);

-- line #2449
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMPHOTIN-LIP 50 (United Bio.)',
	'Amphotericin-B',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg(LIPID COMPLEX)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMPHOTIN-LIP 50 (United Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMPHOTIN-LIP 100 (United Bio.)',
	'Amphotericin-B',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg(LIPID COMPLEX)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMPHOTIN-LIP 100 (United Bio.)'
);

-- line #2450
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMPHOTRET 50 (Bharat S.)',
	'Amphotericin-B',
	'VIAL',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMPHOTRET 50 (Bharat S.)'
);

-- line #2451
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50ML', u'strength_2': u'', u'substance': u'Amphotericin-B', u'always_empty': u'', u'form': u'INJ', u'brand': u'EMPHOTER-B', u'strength_3': u'', u'company': u'Gufic Bio.', u'unit': u''}

-- line #2452
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'650', u'strength_2': u'', u'substance': u'Amphotericin-B', u'always_empty': u'', u'form': u'', u'brand': u'ENVOCIN', u'strength_3': u'', u'company': u'Ranbaxy', u'unit': u'mg'}

-- line #2453
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNGICIN 50 (NEW MEDICON)',
	'Amphotericin-B',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNGICIN 50 (NEW MEDICON)'
);

-- line #2454
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNGISOME 10 (Lifecare)',
	'Amphotericin-B',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg (LIPOSOMAL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNGISOME 10 (Lifecare)'
);

-- line #2455
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNGISOME 20 (Lifecare)',
	'Amphotericin-B',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg (LIPOSOMAL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNGISOME 20 (Lifecare)'
);

-- line #2456
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNGISOME 50 (Lifecare)',
	'Amphotericin-B',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg (LIPOSOMAL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNGISOME 50 (Lifecare)'
);

-- line #2457
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50', u'strength_2': u'', u'substance': u'Amphotericin-B', u'always_empty': u'', u'form': u'', u'brand': u'FUNGIZONE IV', u'strength_3': u'', u'company': u'Nicholas', u'unit': u'mg'}

-- line #2458
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10', u'strength_2': u'', u'substance': u'Amphotericin-B', u'always_empty': u'', u'form': u'', u'brand': u'LAMBIN', u'strength_3': u'', u'company': u'Sun', u'unit': u'mg (LIPOSOMAL)'}

-- line #2459
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50', u'strength_2': u'', u'substance': u'Amphotericin-B', u'always_empty': u'', u'form': u'', u'brand': u'LAMBIN', u'strength_3': u'', u'company': u'Sun', u'unit': u'mg/V (LIPOSONAL)'}

-- line #2460
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPHOLYN 50 (LYKA LABS)',
	'Amphotericin-B',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPHOLYN 50 (LYKA LABS)'
);

-- line #2461
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCOL 50 (Vhb)',
	'Amphotericin-B',
	'V',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCOL 50 (Vhb)'
);

-- line #2462
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUDOXA 20 (Zydus Bio.)',
	'Amphotericin-B',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg (LIPOSOMAL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUDOXA 20 (Zydus Bio.)'
);

-- line #2463
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHORICIN 50 (CH.Bhagat)',
	'Amphotericin-B',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHORICIN 50 (CH.Bhagat)'
);

-- line #2464
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHOSOME 10 (CIPLA)',
	'Amphotericin-B',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg(ENCAPSULATED IN LIPOSOMES)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHOSOME 10 (CIPLA)'
);

-- line #2465
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHOSOME 25 (CIPLA)',
	'Amphotericin-B',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg(ENCAPSULATED IN LIPOSOMES)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHOSOME 25 (CIPLA)'
);

-- line #2466
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHOSOME 50 (Cipla)',
	'Amphotericin-B',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg(AMPHOTERICIN EN CAPSULATED IN LIPOSOMES)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHOSOME 50 (Cipla)'
);

-- line #2467
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBERCILIN 250 (Sanofi Aventis)',
	'Ampicillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBERCILIN 250 (Sanofi Aventis)'
);

-- line #2468
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBERCILIN 500 (Sanofi Aventis)',
	'Ampicillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBERCILIN 500 (Sanofi Aventis)'
);

-- line #2469
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBERCILIN 100 (Sanofi Aventis)',
	'Ampicillin',
	'DPS',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBERCILIN 100 (Sanofi Aventis)'
);

-- line #2470
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBERCILIN 250 (Sanofi Aventis)',
	'Ampicillin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBERCILIN 250 (Sanofi Aventis)'
);

-- line #2471
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBERCILIN 500 (Sanofi Aventis)',
	'Ampicillin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBERCILIN 500 (Sanofi Aventis)'
);

-- line #2472
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBERCILIN 125 (Sanofi Aventis)',
	'Ampicillin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBERCILIN 125 (Sanofi Aventis)'
);

-- line #2473
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMPICILLIN 250 (Idpl)',
	'Ampicillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMPICILLIN 250 (Idpl)'
);

-- line #2474
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMPICILLIN 250 (Jagsonpal)',
	'Ampicillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMPICILLIN 250 (Jagsonpal)'
);

-- line #2475
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMPICILLIN 500 (Jagsonpal)',
	'Ampicillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMPICILLIN 500 (Jagsonpal)'
);

-- line #2476
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ampicillin', u'always_empty': u'', u'form': u'INJ', u'brand': u'AMPICILLIN', u'strength_3': u'', u'company': u'Zydus Cadila', u'unit': u''}

-- line #2477
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMPICILLIN 250 (Zydus Cadila)',
	'Ampicillin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMPICILLIN 250 (Zydus Cadila)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMPICILLIN 500 (Zydus Cadila)',
	'Ampicillin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMPICILLIN 500 (Zydus Cadila)'
);

-- line #2478
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ampicillin', u'always_empty': u'', u'form': u'V', u'brand': u'AMPICILLIN', u'strength_3': u'', u'company': u'Zydus Cadila', u'unit': u''}

-- line #2479
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMPICILLIN 250 (Zydus Cadila)',
	'Ampicillin',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMPICILLIN 250 (Zydus Cadila)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMPICILLIN 500 (Zydus Cadila)',
	'Ampicillin',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMPICILLIN 500 (Zydus Cadila)'
);

-- line #2480
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMPIDIL 250 (Solvay Ph.)',
	'Ampicillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMPIDIL 250 (Solvay Ph.)'
);

-- line #2481
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMPIDIL 125 (Solvay Ph.)',
	'Ampicillin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMPIDIL 125 (Solvay Ph.)'
);

-- line #2482
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMPI 500 (Pfiscar Ind.)',
	'Ampicillin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMPI 500 (Pfiscar Ind.)'
);

-- line #2483
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMPIJET 500 (Pharmed)',
	'Ampicillin',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMPIJET 500 (Pharmed)'
);

-- line #2484
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMPILIN 250 (HETERO HC.)',
	'Ampicillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMPILIN 250 (HETERO HC.)'
);

-- line #2485
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMPILIN 500 (HETERO HC.)',
	'Ampicillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMPILIN 500 (HETERO HC.)'
);

-- line #2486
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMPILIN 125 (HETERO HC.)',
	'Ampicillin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMPILIN 125 (HETERO HC.)'
);

-- line #2487
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMPILIN 250 (HETERO HC.)',
	'Ampicillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMPILIN 250 (HETERO HC.)'
);

-- line #2488
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMPILIN 125 (HETERO HC.)',
	'Ampicillin',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMPILIN 125 (HETERO HC.)'
);

-- line #2489
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMPILIN 250 (HETERO HC.)',
	'Ampicillin',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMPILIN 250 (HETERO HC.)'
);

-- line #2490
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMPILIN 500 (HETERO HC.)',
	'Ampicillin',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMPILIN 500 (HETERO HC.)'
);

-- line #2491
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMPIPEN 250 (Wyeth)',
	'Ampicillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMPIPEN 250 (Wyeth)'
);

-- line #2492
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMPIPEN 500 (Wyeth)',
	'Ampicillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMPIPEN 500 (Wyeth)'
);

-- line #2493
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMPIPEN 125 (Wyeth)',
	'Ampicillin',
	'POW',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMPIPEN 125 (Wyeth)'
);

-- line #2494
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMPISYN 250 (Cipla)',
	'Ampicillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMPISYN 250 (Cipla)'
);

-- line #2495
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMPISYN 500 (Cipla)',
	'Ampicillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMPISYN 500 (Cipla)'
);

-- line #2496
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMPISYN 125 (Cipla)',
	'Ampicillin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMPISYN 125 (Cipla)'
);

-- line #2497
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMPISYN 250 (Cipla)',
	'Ampicillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMPISYN 250 (Cipla)'
);

-- line #2498
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMPISYN 500 (Cipla)',
	'Ampicillin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMPISYN 500 (Cipla)'
);

-- line #2499
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ampicillin', u'always_empty': u'', u'form': u'VIAL', u'brand': u'AMPY', u'strength_3': u'', u'company': u'Global Med.', u'unit': u''}

-- line #2500
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMPY 250 (Global Med.)',
	'Ampicillin',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMPY 250 (Global Med.)'
);

-- line #2501
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMPY 500 (Global Med.)',
	'Ampicillin',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMPY 500 (Global Med.)'
);

-- line #2502
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMS-250 250 (Chemo D.)',
	'Ampicillin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMS-250 250 (Chemo D.)'
);

-- line #2503
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARISTOCILLIN 250 (Aristo)',
	'Ampicillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARISTOCILLIN 250 (Aristo)'
);

-- line #2504
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARISTOCILLIN 500 (Aristo)',
	'Ampicillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARISTOCILLIN 500 (Aristo)'
);

-- line #2505
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARISTOCILLIN 100 (Aristo)',
	'Ampicillin',
	'DPS',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARISTOCILLIN 100 (Aristo)'
);

-- line #2506
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARISTOCILLIN 125 (Aristo)',
	'Ampicillin',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARISTOCILLIN 125 (Aristo)'
);

-- line #2507
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARISTOCILLIN 125 (Aristo)',
	'Ampicillin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARISTOCILLIN 125 (Aristo)'
);

-- line #2508
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARISTOCILLIN 250 (Aristo)',
	'Ampicillin',
	'SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARISTOCILLIN 250 (Aristo)'
);

-- line #2509
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARISTOCILLIN 100 (Aristo)',
	'Ampicillin',
	'V',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARISTOCILLIN 100 (Aristo)'
);

-- line #2510
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARISTOCILLIN 250 (Aristo)',
	'Ampicillin',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARISTOCILLIN 250 (Aristo)'
);

-- line #2511
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARISTOCILLIN 500 (Aristo)',
	'Ampicillin',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARISTOCILLIN 500 (Aristo)'
);

-- line #2512
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACIPEN 250 (Alembic)',
	'Ampicillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACIPEN 250 (Alembic)'
);

-- line #2513
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACIPEN 500 (Alembic)',
	'Ampicillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACIPEN 500 (Alembic)'
);

-- line #2514
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACIPEN 250 (Alembic)',
	'Ampicillin',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACIPEN 250 (Alembic)'
);

-- line #2515
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACIPEN 500 (Alembic)',
	'Ampicillin',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACIPEN 500 (Alembic)'
);

-- line #2516
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BECKCILLIN 500 (Beckcem)',
	'Ampicillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BECKCILLIN 500 (Beckcem)'
);

-- line #2517
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOCILIN 250 (Biochem)',
	'Ampicillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOCILIN 250 (Biochem)'
);

-- line #2518
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOCILIN 100 (Biochem)',
	'Ampicillin',
	'DPS',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOCILIN 100 (Biochem)'
);

-- line #2519
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOCILIN 125 (Biochem)',
	'Ampicillin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOCILIN 125 (Biochem)'
);

-- line #2520
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOCILIN 250 (Biochem)',
	'Ampicillin',
	'SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOCILIN 250 (Biochem)'
);

-- line #2521
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOCILIN 100 (Biochem)',
	'Ampicillin',
	'V',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOCILIN 100 (Biochem)'
);

-- line #2522
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ampicillin', u'always_empty': u'', u'form': u'V', u'brand': u'BIOCILIN', u'strength_3': u'', u'company': u'Biochem', u'unit': u''}

-- line #2523
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOCILIN 250 (Biochem)',
	'Ampicillin',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOCILIN 250 (Biochem)'
);

-- line #2524
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOCILIN 500 (Biochem)',
	'Ampicillin',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOCILIN 500 (Biochem)'
);

-- line #2525
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOCILLIN 500 (Biochem)',
	'Ampicillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOCILLIN 500 (Biochem)'
);

-- line #2526
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOCILLIN 125 (Biochem)',
	'Ampicillin',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOCILLIN 125 (Biochem)'
);

-- line #2527
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLUCILLIN 250 (Blue Cross)',
	'Ampicillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLUCILLIN 250 (Blue Cross)'
);

-- line #2528
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BROACIL 250 (Idpl)',
	'Ampicillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BROACIL 250 (Idpl)'
);

-- line #2529
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BROACIL 500 (Idpl)',
	'Ampicillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BROACIL 500 (Idpl)'
);

-- line #2530
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BROACIL 125 (Idpl)',
	'Ampicillin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BROACIL 125 (Idpl)'
);

-- line #2531
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BROACIL 500 (Idpl)',
	'Ampicillin',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BROACIL 500 (Idpl)'
);

-- line #2532
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BROADICILIN 250 (Alkem)',
	'Ampicillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BROADICILIN 250 (Alkem)'
);

-- line #2533
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BROADICILIN 500 (Alkem)',
	'Ampicillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BROADICILIN 500 (Alkem)'
);

-- line #2534
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BROADICILIN 100 (Alkem)',
	'Ampicillin',
	'DPS',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BROADICILIN 100 (Alkem)'
);

-- line #2535
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BROADICILIN 125 (Alkem)',
	'Ampicillin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BROADICILIN 125 (Alkem)'
);

-- line #2536
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BROADICILIN 100 (Alkem)',
	'Ampicillin',
	'V',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BROADICILIN 100 (Alkem)'
);

-- line #2537
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BROADICILIN 250 (Alkem)',
	'Ampicillin',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BROADICILIN 250 (Alkem)'
);

-- line #2538
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BROADICILIN 500 (Alkem)',
	'Ampicillin',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BROADICILIN 500 (Alkem)'
);

-- line #2539
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-ALLIN 500 (Corona)',
	'Ampicillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-ALLIN 500 (Corona)'
);

-- line #2540
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAMPICILIN 250 (Cadila Ph.)',
	'Ampicillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg(ANHY.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAMPICILIN 250 (Cadila Ph.)'
);

-- line #2541
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAMPICILIN 500 (Cadila Ph.)',
	'Ampicillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAMPICILIN 500 (Cadila Ph.)'
);

-- line #2542
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAMPICILIN 125 (Cadila Ph.)',
	'Ampicillin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAMPICILIN 125 (Cadila Ph.)'
);

-- line #2543
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAMPICILIN 125 (Cadila Ph.)',
	'Ampicillin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAMPICILIN 125 (Cadila Ph.)'
);

-- line #2544
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAMPICILIN 250 (Cadila Ph.)',
	'Ampicillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAMPICILIN 250 (Cadila Ph.)'
);

-- line #2545
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAMPICILIN 500 (Cadila Ph.)',
	'Ampicillin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAMPICILIN 500 (Cadila Ph.)'
);

-- line #2546
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CINCILLIN 250 (Ind-Swift)',
	'Ampicillin',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CINCILLIN 250 (Ind-Swift)'
);

-- line #2547
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CINCILLIN 500 (Ind-Swift)',
	'Ampicillin',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CINCILLIN 500 (Ind-Swift)'
);

-- line #2548
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COCILIN 250 (Dynamic)',
	'Ampicillin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COCILIN 250 (Dynamic)'
);

-- line #2549
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COCILIN 500 (Dynamic)',
	'Ampicillin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COCILIN 500 (Dynamic)'
);

-- line #2550
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DABCILIN 250 (Dabur Ph.)',
	'Ampicillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DABCILIN 250 (Dabur Ph.)'
);

-- line #2551
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DABCILIN 500 (Dabur Ph.)',
	'Ampicillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DABCILIN 500 (Dabur Ph.)'
);

-- line #2552
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DABCILIN 125 (Dabur Ph.)',
	'Ampicillin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DABCILIN 125 (Dabur Ph.)'
);

-- line #2553
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DABCILIN 125 (Dabur Ph.)',
	'Ampicillin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DABCILIN 125 (Dabur Ph.)'
);

-- line #2554
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYNACIN 500 (Hal)',
	'Ampicillin',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYNACIN 500 (Hal)'
);

-- line #2555
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESKAYCILLIN 250 (Gsk)',
	'Ampicillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESKAYCILLIN 250 (Gsk)'
);

-- line #2556
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESKAYCILLIN 500 (Gsk)',
	'Ampicillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESKAYCILLIN 500 (Gsk)'
);

-- line #2557
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESKAYCILLIN 125 (Gsk)',
	'Ampicillin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESKAYCILLIN 125 (Gsk)'
);

-- line #2558
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESKAYCILLIN 250 (Gsk)',
	'Ampicillin',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESKAYCILLIN 250 (Gsk)'
);

-- line #2559
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESKAYCILLIN 500 (Gsk)',
	'Ampicillin',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESKAYCILLIN 500 (Gsk)'
);

-- line #2560
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FINCILLINE 500 (Finesse Ph.)',
	'Ampicillin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FINCILLINE 500 (Finesse Ph.)'
);

-- line #2561
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INGACILLIN 250 (Inga)',
	'Ampicillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INGACILLIN 250 (Inga)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INGACILLIN 500 (Inga)',
	'Ampicillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INGACILLIN 500 (Inga)'
);

-- line #2562
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INGACILLIN 250 (Inga)',
	'Ampicillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg/1/G.'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INGACILLIN 250 (Inga)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INGACILLIN 500 (Inga)',
	'Ampicillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg/1/G.'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INGACILLIN 500 (Inga)'
);

-- line #2563
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INGACILLIN 100 (Inga)',
	'Ampicillin',
	'DPS',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INGACILLIN 100 (Inga)'
);

-- line #2564
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JP-CILIN 250 (Jagsonpal)',
	'Ampicillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JP-CILIN 250 (Jagsonpal)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JP-CILIN 500 (Jagsonpal)',
	'Ampicillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JP-CILIN 500 (Jagsonpal)'
);

-- line #2565
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAXAMP 250 (MAX)',
	'Ampicillin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAXAMP 250 (MAX)'
);

-- line #2566
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAXAMP 500 (MAX)',
	'Ampicillin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAXAMP 500 (MAX)'
);

-- line #2567
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGASYN 250 (Cipla)',
	'Ampicillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGASYN 250 (Cipla)'
);

-- line #2568
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONACILIN 500 (Zee Lab)',
	'Ampicillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONACILIN 500 (Zee Lab)'
);

-- line #2569
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONACILIN 500 (Zee Lab)',
	'Ampicillin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONACILIN 500 (Zee Lab)'
);

-- line #2570
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOCILIN 1000 (Cipla)',
	'Ampicillin',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOCILIN 1000 (Cipla)'
);

-- line #2571
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOCILLIN 250 (Sanjivani)',
	'Ampicillin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOCILLIN 250 (Sanjivani)'
);

-- line #2572
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NATCOCILLIN 250 (Natco Ph.)',
	'Ampicillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NATCOCILLIN 250 (Natco Ph.)'
);

-- line #2573
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NATCOCILLIN 500 (Natco Ph.)',
	'Ampicillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NATCOCILLIN 500 (Natco Ph.)'
);

-- line #2574
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NATCOCILLIN 125 (Natco Ph.)',
	'Ampicillin',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NATCOCILLIN 125 (Natco Ph.)'
);

-- line #2575
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ampicillin', u'always_empty': u'', u'form': u'INJ', u'brand': u'NEOCILLIN', u'strength_3': u'', u'company': u'Neon', u'unit': u''}

-- line #2576
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOCILLIN 250 (Neon)',
	'Ampicillin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOCILLIN 250 (Neon)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOCILLIN 500 (Neon)',
	'Ampicillin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOCILLIN 500 (Neon)'
);

-- line #2577
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEPOCIL 250 (Ttk Hc.)',
	'Ampicillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEPOCIL 250 (Ttk Hc.)'
);

-- line #2578
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEPOCIL 500 (Ttk Hc.)',
	'Ampicillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEPOCIL 500 (Ttk Hc.)'
);

-- line #2579
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEPOCIL 125 (Ttk Hc.)',
	'Ampicillin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEPOCIL 125 (Ttk Hc.)'
);

-- line #2580
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEPOCIL 250 (Ttk Hc.)',
	'Ampicillin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEPOCIL 250 (Ttk Hc.)'
);

-- line #2581
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEPOCIL 500 (Ttk Hc.)',
	'Ampicillin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEPOCIL 500 (Ttk Hc.)'
);

-- line #2582
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLIN 125 (Gufic Bio.)',
	'Ampicillin',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLIN 125 (Gufic Bio.)'
);

-- line #2583
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORCILIN 250 (Trio Ph.)',
	'Ampicillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORCILIN 250 (Trio Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORCILIN 500 (Trio Ph.)',
	'Ampicillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORCILIN 500 (Trio Ph.)'
);

-- line #2584
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORCILIN 125 (Trio Rem.)',
	'Ampicillin',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORCILIN 125 (Trio Rem.)'
);

-- line #2585
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSOCILLIN 100 (Osper)',
	'Ampicillin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSOCILLIN 100 (Osper)'
);

-- line #2586
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSOCILLIN 250 (Osper)',
	'Ampicillin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSOCILLIN 250 (Osper)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSOCILLIN 500 (Osper)',
	'Ampicillin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSOCILLIN 500 (Osper)'
);

-- line #2587
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREMICILLIN 500 (PREM PH.)',
	'Ampicillin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREMICILLIN 500 (PREM PH.)'
);

-- line #2588
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRESSILIN 125 (VERITAZ)',
	'Ampicillin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRESSILIN 125 (VERITAZ)'
);

-- line #2589
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRESSILIN 250 (VERITAZ)',
	'Ampicillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRESSILIN 250 (VERITAZ)'
);

-- line #2590
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRESSILIN 500 (VERITAZ)',
	'Ampicillin',
	'DT',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRESSILIN 500 (VERITAZ)'
);

-- line #2591
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROPEN 500 (Brooks Ph.)',
	'Ampicillin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg(SOD.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROPEN 500 (Brooks Ph.)'
);

-- line #2592
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMICOR 100 (Samarth)',
	'Amrinone',
	'AMP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMICOR 100 (Samarth)'
);

-- line #2593
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMRISOL 100 (SG PH.)',
	'Amrinone',
	'VIAL',
	gm.nullify_empty_string('100')::numeric,
	'mg/20ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMRISOL 100 (SG PH.)'
);

-- line #2594
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDIOTONE 100 (Vhb)',
	'Amrinone',
	'AMP',
	gm.nullify_empty_string('100')::numeric,
	'mg/20ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDIOTONE 100 (Vhb)'
);

-- line #2595
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INOCOR 5 (N.A.)',
	'Amrinone',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML ( LACT.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INOCOR 5 (N.A.)'
);

-- line #2596
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'600', u'strength_2': u'', u'substance': u'AMTOLMETIN GUACIL', u'always_empty': u'', u'form': u'', u'brand': u'AMTORIL', u'strength_3': u'', u'company': u'Macleods', u'unit': u'mg'}

-- line #2597
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANALGIN 500 (Alkem)',
	'Analgin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANALGIN 500 (Alkem)'
);

-- line #2598
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANALGIN 500 (Idpl)',
	'Analgin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANALGIN 500 (Idpl)'
);

-- line #2599
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BARALGAN-M 500 (Sanofi Aventis)',
	'Analgin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BARALGAN-M 500 (Sanofi Aventis)'
);

-- line #2600
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BARALGAN-M 500 (Sanofi Aventis)',
	'Analgin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BARALGAN-M 500 (Sanofi Aventis)'
);

-- line #2601
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENALGIN 500 (Geno Ph.)',
	'Analgin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENALGIN 500 (Geno Ph.)'
);

-- line #2602
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METNIMEZ 5 (SUN)',
	'Analgin',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METNIMEZ 5 (SUN)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METNIMEZ 10 (SUN)',
	'Analgin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METNIMEZ 10 (SUN)'
);

-- line #2603
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVALGIN 0.5 (Sanofi Aventis)',
	'Analgin',
	'INJ',
	gm.nullify_empty_string('0.5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVALGIN 0.5 (Sanofi Aventis)'
);

-- line #2604
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVALGIN 500 (Sanofi Aventis)',
	'Analgin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVALGIN 500 (Sanofi Aventis)'
);

-- line #2605
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALTRAZ 1 (Cytomed(Alkem))',
	'ANASTRAZOLE',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALTRAZ 1 (Cytomed(Alkem))'
);

-- line #2606
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANABREZ 1 (Sun)',
	'ANASTRAZOLE',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANABREZ 1 (Sun)'
);

-- line #2607
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANASTROZOLE 1 (Khandelwal)',
	'ANASTRAZOLE',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANASTROZOLE 1 (Khandelwal)'
);

-- line #2608
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARMOTRAZ 1 (Cipla)',
	'ANASTRAZOLE',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARMOTRAZ 1 (Cipla)'
);

-- line #2609
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AROMITA 1 (Novatech)',
	'ANASTRAZOLE',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AROMITA 1 (Novatech)'
);

-- line #2610
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELINAL 1 (Emcure)',
	'ANASTRAZOLE',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELINAL 1 (Emcure)'
);

-- line #2611
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEMISTRA 1 (Zydus Bio.)',
	'ANASTRAZOLE',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEMISTRA 1 (Zydus Bio.)'
);

-- line #2612
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEMITRAZ 1 (Lupin)',
	'ANASTRAZOLE',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEMITRAZ 1 (Lupin)'
);

-- line #2613
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALTROL 1 (TAJ PH.)',
	'ANASTROZOLE',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALTROL 1 (TAJ PH.)'
);

-- line #2614
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANASTRA-1 1 (Wockhardt)',
	'ANASTROZOLE',
	'CAP',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANASTRA-1 1 (Wockhardt)'
);

-- line #2615
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANATERO 1 (HETERO HC.)',
	'ANASTROZOLE',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANATERO 1 (HETERO HC.)'
);

-- line #2616
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARMILON 1 (CELON(VIVILON))',
	'ANASTROZOLE',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARMILON 1 (CELON(VIVILON))'
);

-- line #2617
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AROMATAZ 1 (SVEN GENETECH)',
	'ANASTROZOLE',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AROMATAZ 1 (SVEN GENETECH)'
);

-- line #2618
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COSALON 50 (CENTUAR)',
	'ANASTROZOLE',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COSALON 50 (CENTUAR)'
);

-- line #2619
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEMNAZ 1 (UTTARA BIO.)',
	'ANASTROZOLE',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEMNAZ 1 (UTTARA BIO.)'
);

-- line #2620
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HONVAN 300 (German R.)',
	'ANASTROZOLE',
	'INJ',
	gm.nullify_empty_string('300')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HONVAN 300 (German R.)'
);

-- line #2621
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REDEST 1 (ONKOS(GLENMARK))',
	'ANASTROZOLE',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REDEST 1 (ONKOS(GLENMARK))'
);

-- line #2622
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERAXIS 100 (Pfizer)',
	'ANIDULAFUNGIN',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERAXIS 100 (Pfizer)'
);

-- line #2623
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'ANTIOXIDANT', u'always_empty': u'', u'form': u'TAB', u'brand': u'CASERA MCG', u'strength_3': u'', u'company': u'Croslands', u'unit': u''}

-- line #2624
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'ANTIOXIDANT', u'always_empty': u'', u'form': u'CAP', u'brand': u'LUCOROB', u'strength_3': u'', u'company': u'R.B.REM.', u'unit': u''}

-- line #2625
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'ANTI RABIES VACCINE ON HUMAN DIPLOID CELLS', u'always_empty': u'', u'form': u'INJ', u'brand': u'MIRV HDC', u'strength_3': u'', u'company': u'Serum Inst.', u'unit': u''}

-- line #2626
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'ANTI SNAKE VENOM SERUM', u'always_empty': u'', u'form': u'VENOM POLYVALENT INJ', u'brand': u'ANTISNAKE', u'strength_3': u'', u'company': u'Haffkine', u'unit': u''}

-- line #2627
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'ANTI SNAKE VENOM SERUM', u'always_empty': u'', u'form': u'VENOM POLYVALENT INJ', u'brand': u'ANTISNAKE', u'strength_3': u'', u'company': u'Serum Inst.', u'unit': u''}

-- line #2628
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.(POLYVALENT)', u'strength_2': u'', u'substance': u'ANTI SNAKE VENOM SERUM', u'always_empty': u'', u'form': u'INJ', u'brand': u'ASVS', u'strength_3': u'', u'company': u'Bharat S.', u'unit': u''}

-- line #2629
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATGAM 250 (Pharmacia)',
	'Anti Thymocyte Globulin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATGAM 250 (Pharmacia)'
);

-- line #2630
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYMPHOGLOBULINE 100 (Aventis Pas.)',
	'Anti Thymocyte Globulin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYMPHOGLOBULINE 100 (Aventis Pas.)'
);

-- line #2631
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATG 100 (Chemech)',
	'ANTI "T" LYMPHOTIC GLOBULIN',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATG 100 (Chemech)'
);

-- line #2632
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALFA 0.5 (Cipla)',
	'Apraclonidine Hcl.',
	'DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALFA 0.5 (Cipla)'
);

-- line #2633
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALFADROPS % 0.5 (Cipla)',
	'Apraclonidine Hcl.',
	'DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALFADROPS % 0.5 (Cipla)'
);

-- line #2634
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALFADROPS % 1 (Cipla)',
	'Apraclonidine Hcl.',
	'DPS',
	gm.nullify_empty_string('1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALFADROPS % 1 (Cipla)'
);

-- line #2635
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALFADROPS 1 (Cipla)',
	'Apraclonidine Hcl.',
	'DS EYE DPS',
	gm.nullify_empty_string('1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALFADROPS 1 (Cipla)'
);

-- line #2636
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALFA 1 (Cipla)',
	'Apraclonidine Hcl.',
	'DS DPS',
	gm.nullify_empty_string('1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALFA 1 (Cipla)'
);

-- line #2637
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APRECAP 125 (ONKOS(GLENMARK))',
	'APREPITANT',
	'CAP',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APRECAP 125 (ONKOS(GLENMARK))'
);

-- line #2638
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APRISTAR 125 (Lupin)',
	'APREPITANT',
	'KIT',
	gm.nullify_empty_string('125')::numeric,
	'mg(1C)+80'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APRISTAR 125 (Lupin)'
);

-- line #2639
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARRIWOK 125 (Wockhardt)',
	'APREPITANT',
	'CAP',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARRIWOK 125 (Wockhardt)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARRIWOK 80 (Wockhardt)',
	'APREPITANT',
	'CAP',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARRIWOK 80 (Wockhardt)'
);

-- line #2640
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMPOV 80 (Dr.Reddy''S)',
	'APREPITANT',
	'KIT',
	gm.nullify_empty_string('80')::numeric,
	'mg(A:EMPOV 125(1 CAP)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMPOV 80 (Dr.Reddy''S)'
);

-- line #2641
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APROGEN 14 (ALKEM)',
	'Aprotinin',
	'INJ',
	gm.nullify_empty_string('14')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APROGEN 14 (ALKEM)'
);

-- line #2642
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APROGEN 500 (ALKEM)',
	'Aprotinin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'000KIU'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APROGEN 500 (ALKEM)'
);

-- line #2643
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APRONIN 100 (CH.Bhagat)',
	'Aprotinin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'000KIU'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APRONIN 100 (CH.Bhagat)'
);

-- line #2644
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APRONIN 500 (CH.Bhagat)',
	'Aprotinin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'000KIU'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APRONIN 500 (CH.Bhagat)'
);

-- line #2645
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APROSTAT 500 (Samarth)',
	'Aprotinin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'000KIU'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APROSTAT 500 (Samarth)'
);

-- line #2646
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Aprotinin', u'always_empty': u'', u'form': u'INJ', u'brand': u'APROTEC', u'strength_3': u'', u'company': u'United Bio.', u'unit': u''}

-- line #2647
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APROTIN 100 (Vhb)',
	'Aprotinin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'000KIU'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APROTIN 100 (Vhb)'
);

-- line #2648
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APROTIN 500 (Vhb)',
	'Aprotinin',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'000KIU'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APROTIN 500 (Vhb)'
);

-- line #2649
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HAEMOPROT 1.4 (Troikaa)',
	'Aprotinin',
	'VIAL',
	gm.nullify_empty_string('1.4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HAEMOPROT 1.4 (Troikaa)'
);

-- line #2650
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Aprotinin', u'always_empty': u'', u'form': u'VIAL', u'brand': u'KALLISTAT', u'strength_3': u'', u'company': u'BIOSENA', u'unit': u''}

-- line #2651
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'15MCG', u'strength_2': u'', u'substance': u'ARFORMOTEROL TARTRATE', u'always_empty': u'', u'form': u'RES', u'brand': u'DERIFORM', u'strength_3': u'', u'company': u'RESPICARE(GERMAN R.)', u'unit': u''}

-- line #2652
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'22MCG', u'strength_2': u'', u'substance': u'ARFORMOTEROL TARTRATE', u'always_empty': u'', u'form': u'RES', u'brand': u'FORATEC', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #2653
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAYADERM 1 (ASTRA PH.)',
	'ARGYERIA SPECIOSA EXTRACT',
	'TUBE',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAYADERM 1 (ASTRA PH.)'
);

-- line #2654
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARENA 10 (TALENT LAB.)',
	'ARIPIPRAZOLE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARENA 10 (TALENT LAB.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARENA 20 (TALENT LAB.)',
	'ARIPIPRAZOLE',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARENA 20 (TALENT LAB.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARENA 30 (TALENT LAB.)',
	'ARIPIPRAZOLE',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARENA 30 (TALENT LAB.)'
);

-- line #2655
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARIVE 10 (Pentacare)',
	'ARIPIPRAZOLE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARIVE 10 (Pentacare)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARIVE 15 (Pentacare)',
	'ARIPIPRAZOLE',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARIVE 15 (Pentacare)'
);

-- line #2656
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARIVE 20 (Pentacare)',
	'ARIPIPRAZOLE',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARIVE 20 (Pentacare)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARIVE 30 (Pentacare)',
	'ARIPIPRAZOLE',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARIVE 30 (Pentacare)'
);

-- line #2657
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AREREP 10 (CENTRA(USV))',
	'ARIPIRAZOLE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AREREP 10 (CENTRA(USV))'
);

-- line #2658
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AREREP 15 (CENTRA(USV))',
	'ARIPIRAZOLE',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AREREP 15 (CENTRA(USV))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AREREP 30 (CENTRA(USV))',
	'ARIPIRAZOLE',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AREREP 30 (CENTRA(USV))'
);

-- line #2659
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARIA 10 (Nicholas)',
	'ARIPIRAZOLE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARIA 10 (Nicholas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARIA 15 (Nicholas)',
	'ARIPIRAZOLE',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARIA 15 (Nicholas)'
);

-- line #2660
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARIA 20 (Nicholas)',
	'ARIPIRAZOLE',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARIA 20 (Nicholas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARIA 30 (Nicholas)',
	'ARIPIRAZOLE',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARIA 30 (Nicholas)'
);

-- line #2661
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARIDUS 10 (Cadila Hc.)',
	'ARIPIRAZOLE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARIDUS 10 (Cadila Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARIDUS 15 (Cadila Hc.)',
	'ARIPIRAZOLE',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARIDUS 15 (Cadila Hc.)'
);

-- line #2662
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARIDUS 20 (Cadila Ph.)',
	'ARIPIRAZOLE',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARIDUS 20 (Cadila Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARIDUS 30 (Cadila Ph.)',
	'ARIPIRAZOLE',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARIDUS 30 (Cadila Ph.)'
);

-- line #2663
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARIFRIL 10 (La Drug)',
	'ARIPIRAZOLE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARIFRIL 10 (La Drug)'
);

-- line #2664
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARIFRIL 15 (La Drug)',
	'ARIPIRAZOLE',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARIFRIL 15 (La Drug)'
);

-- line #2665
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARILAN 10 (Synapse)',
	'ARIPIRAZOLE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARILAN 10 (Synapse)'
);

-- line #2666
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARILAN 15 (Synapse)',
	'ARIPIRAZOLE',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARILAN 15 (Synapse)'
);

-- line #2667
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARILAN 20 (Synapse)',
	'ARIPIRAZOLE',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARILAN 20 (Synapse)'
);

-- line #2668
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARILAN 30 (Synapse)',
	'ARIPIRAZOLE',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARILAN 30 (Synapse)'
);

-- line #2669
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARIP 10 (Torrent)',
	'ARIPIRAZOLE',
	'MT TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARIP 10 (Torrent)'
);

-- line #2670
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARIP 15 (Torrent)',
	'ARIPIRAZOLE',
	'MT TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARIP 15 (Torrent)'
);

-- line #2671
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARIP 20 (Torrent)',
	'ARIPIRAZOLE',
	'MT TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARIP 20 (Torrent)'
);

-- line #2672
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARIP 30 (Torrent)',
	'ARIPIRAZOLE',
	'MT TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARIP 30 (Torrent)'
);

-- line #2673
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARIP 5 (Torrent)',
	'ARIPIRAZOLE',
	'MT TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARIP 5 (Torrent)'
);

-- line #2674
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARIPRA 10 (Solus)',
	'ARIPIRAZOLE',
	'MT TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARIPRA 10 (Solus)'
);

-- line #2675
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARIPRA 15 (Solus)',
	'ARIPIRAZOLE',
	'MT TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARIPRA 15 (Solus)'
);

-- line #2676
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARIPRA 20 (Solus)',
	'ARIPIRAZOLE',
	'MT TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARIPRA 20 (Solus)'
);

-- line #2677
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARIPRA 30 (Solus)',
	'ARIPIRAZOLE',
	'MT TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARIPRA 30 (Solus)'
);

-- line #2678
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARIZE 20 (EAST WEST)',
	'ARIPIRAZOLE',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARIZE 20 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARIZE 30 (EAST WEST)',
	'ARIPIRAZOLE',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARIZE 30 (EAST WEST)'
);

-- line #2679
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARIZE 5 (EAST WEST)',
	'ARIPIRAZOLE',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARIZE 5 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARIZE 10 (EAST WEST)',
	'ARIPIRAZOLE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARIZE 10 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARIZE 15 (EAST WEST)',
	'ARIPIRAZOLE',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARIZE 15 (EAST WEST)'
);

-- line #2680
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARPIT 20 (Crescent Th.)',
	'ARIPIRAZOLE',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARPIT 20 (Crescent Th.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARPIT 30 (Crescent Th.)',
	'ARIPIRAZOLE',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARPIT 30 (Crescent Th.)'
);

-- line #2681
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARPIT 5 (Crescent Th.)',
	'ARIPIRAZOLE',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARPIT 5 (Crescent Th.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARPIT 10 (Crescent Th.)',
	'ARIPIRAZOLE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARPIT 10 (Crescent Th.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARPIT 15 (Crescent Th.)',
	'ARIPIRAZOLE',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARPIT 15 (Crescent Th.)'
);

-- line #2682
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARPIZOL 15 (Sun)',
	'ARIPIRAZOLE',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARPIZOL 15 (Sun)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARPIZOL 20 (Sun)',
	'ARIPIRAZOLE',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARPIZOL 20 (Sun)'
);

-- line #2683
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARPIZOL 30 (Sun)',
	'ARIPIRAZOLE',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARPIZOL 30 (Sun)'
);

-- line #2684
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARPIZOL 5 (Sun)',
	'ARIPIRAZOLE',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARPIZOL 5 (Sun)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARPIZOL 10 (Sun)',
	'ARIPIRAZOLE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARPIZOL 10 (Sun)'
);

-- line #2685
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARZA 10 (Mano)',
	'ARIPIRAZOLE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARZA 10 (Mano)'
);

-- line #2686
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARZA 15 (Mano)',
	'ARIPIRAZOLE',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARZA 15 (Mano)'
);

-- line #2687
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARZU 10 (Lupin)',
	'ARIPIRAZOLE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARZU 10 (Lupin)'
);

-- line #2688
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARZU 30 (Lupin)',
	'ARIPIRAZOLE',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARZU 30 (Lupin)'
);

-- line #2689
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5', u'strength_2': u'', u'substance': u'ARIPIRAZOLE', u'always_empty': u'', u'form': u'', u'brand': u'ASPRITO', u'strength_3': u'', u'company': u'Intas', u'unit': u'mg'}

-- line #2690
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASPRITO 10 (Intas)',
	'ARIPIRAZOLE',
	'MT TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASPRITO 10 (Intas)'
);

-- line #2691
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASPRITO 15 (Intas)',
	'ARIPIRAZOLE',
	'MT TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASPRITO 15 (Intas)'
);

-- line #2692
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASPRITO 20 (Intas)',
	'ARIPIRAZOLE',
	'MT TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASPRITO 20 (Intas)'
);

-- line #2693
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASPRITO 30 (Intas)',
	'ARIPIRAZOLE',
	'MT TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASPRITO 30 (Intas)'
);

-- line #2694
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASPRITO 10 (AQUILA)',
	'ARIPIRAZOLE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASPRITO 10 (AQUILA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASPRITO 15 (AQUILA)',
	'ARIPIRAZOLE',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASPRITO 15 (AQUILA)'
);

-- line #2695
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASPRITO 20 (AQUILA)',
	'ARIPIRAZOLE',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASPRITO 20 (AQUILA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASPRITO 30 (AQUILA)',
	'ARIPIRAZOLE',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASPRITO 30 (AQUILA)'
);

-- line #2696
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BILIFF 10 (Glenmark)',
	'ARIPIRAZOLE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BILIFF 10 (Glenmark)'
);

-- line #2697
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BILIFF 15 (Glenmark)',
	'ARIPIRAZOLE',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BILIFF 15 (Glenmark)'
);

-- line #2698
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BILIFF 30 (Glenmark)',
	'ARIPIRAZOLE',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BILIFF 30 (Glenmark)'
);

-- line #2699
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELRIP 10 (Elite Ph.)',
	'ARIPIRAZOLE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELRIP 10 (Elite Ph.)'
);

-- line #2700
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELRIP 15 (Elite Ph.)',
	'ARIPIRAZOLE',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELRIP 15 (Elite Ph.)'
);

-- line #2701
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELRIP 20 (Elite Ph.)',
	'ARIPIRAZOLE',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELRIP 20 (Elite Ph.)'
);

-- line #2702
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELRIP 30 (Elite Ph.)',
	'ARIPIRAZOLE',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELRIP 30 (Elite Ph.)'
);

-- line #2703
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIPRA-A 10 (PSYCOREM)',
	'ARIPIRAZOLE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIPRA-A 10 (PSYCOREM)'
);

-- line #2704
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIPRA-A 15 (PSYCOREM)',
	'ARIPIRAZOLE',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIPRA-A 15 (PSYCOREM)'
);

-- line #2705
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIPRA-A 20 (PSYCOREM)',
	'ARIPIRAZOLE',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIPRA-A 20 (PSYCOREM)'
);

-- line #2706
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIPRA-A 30 (PSYCOREM)',
	'ARIPIRAZOLE',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIPRA-A 30 (PSYCOREM)'
);

-- line #2707
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIPRA-A 5 (PSYCOREM)',
	'ARIPIRAZOLE',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIPRA-A 5 (PSYCOREM)'
);

-- line #2708
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REAL ONE 10 (NPIL)',
	'ARIPIRAZOLE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REAL ONE 10 (NPIL)'
);

-- line #2709
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REAL ONE 15 (NPIL)',
	'ARIPIRAZOLE',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REAL ONE 15 (NPIL)'
);

-- line #2710
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REAL ONE 20 (NPIL)',
	'ARIPIRAZOLE',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REAL ONE 20 (NPIL)'
);

-- line #2711
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REAL ONE 30 (NPIL)',
	'ARIPIRAZOLE',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REAL ONE 30 (NPIL)'
);

-- line #2712
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.25ML', u'strength_2': u'', u'substance': u'Aristha Oil', u'always_empty': u'', u'form': u'CAP', u'brand': u'NIMBOLA', u'strength_3': u'', u'company': u'Kee Ph.', u'unit': u''}

-- line #2713
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARMOD 150 (Emcure)',
	'ARMODAFINIL',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARMOD 150 (Emcure)'
);

-- line #2714
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARMOD 50 (Emcure)',
	'ARMODAFINIL',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARMOD 50 (Emcure)'
);

-- line #2715
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I', u'strength_2': u'', u'substance': u'ARSENIC TRIOXIDE', u'always_empty': u'', u'form': u'INJ', u'brand': u'ARSIKEM', u'strength_3': u'', u'company': u'Cytomed(Alkem)', u'unit': u''}

-- line #2716
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AARTEE 150 (Sienna Form.)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML(A & B)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AARTEE 150 (Sienna Form.)'
);

-- line #2717
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ABA 150 (Intra Lab)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ABA 150 (Intra Lab)'
);

-- line #2718
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AB 150 (Zee Lab)',
	'Arteether',
	'AT AMP',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML(A & B)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AB 150 (Zee Lab)'
);

-- line #2719
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ABC-9 150 (RASS HC.)',
	'Arteether',
	'AMP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ABC-9 150 (RASS HC.)'
);

-- line #2720
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AB-THER 150 (LAKSUN)',
	'Arteether',
	'AMP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AB-THER 150 (LAKSUN)'
);

-- line #2721
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AB-THER 150 (ROSE LABS)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML(A & B)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AB-THER 150 (ROSE LABS)'
);

-- line #2722
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ABTHER 150 (Ulticare)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML(A & B)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ABTHER 150 (Ulticare)'
);

-- line #2723
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTER 150 (Active Hc.)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTER 150 (Active Hc.)'
);

-- line #2724
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALFABET 150 (INVISION)',
	'Arteether',
	'AMP',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALFABET 150 (INVISION)'
);

-- line #2725
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPHABETAS 150 (SHRESHTHA)',
	'Arteether',
	'AMP',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPHABETAS 150 (SHRESHTHA)'
);

-- line #2726
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPHABET 150 (Intra(INVISION))',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML(A & B)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPHABET 150 (Intra(INVISION))'
);

-- line #2727
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANTHER 150 (NORTECH REM.)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML(A & B)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANTHER 150 (NORTECH REM.)'
);

-- line #2728
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANTI-M 150 (SANCHEZ LAB.)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML(A & B)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANTI-M 150 (SANCHEZ LAB.)'
);

-- line #2729
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARH 150 (Lincoln)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARH 150 (Lincoln)'
);

-- line #2730
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARH JR 75 (Lincoln)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARH JR 75 (Lincoln)'
);

-- line #2731
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARSIS 150 (ORION BIOTECH.)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML(A & B)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARSIS 150 (ORION BIOTECH.)'
);

-- line #2732
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARTARIN 150 (VHB)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML(A & B)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARTARIN 150 (VHB)'
);

-- line #2733
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARTEEMAL 150 (TALENT LAB.)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML(A & B)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARTEEMAL 150 (TALENT LAB.)'
);

-- line #2734
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARTEKAA 150 (Troikaa)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML(A & B)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARTEKAA 150 (Troikaa)'
);

-- line #2735
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARTEM-E 150 (Panjon)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML(A & B)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARTEM-E 150 (Panjon)'
);

-- line #2736
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARTEROL 150 (Royal)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARTEROL 150 (Royal)'
);

-- line #2737
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Arteether', u'always_empty': u'', u'form': u'INJ', u'brand': u'ARTIMAL', u'strength_3': u'', u'company': u'Indi Ph.', u'unit': u''}

-- line #2738
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARTIMD 75 (Indi Ph.)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('75')::numeric,
	'mg/2ML(A & B)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARTIMD 75 (Indi Ph.)'
);

-- line #2739
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'150', u'strength_2': u'', u'substance': u'Arteether', u'always_empty': u'', u'form': u'', u'brand': u'ARTIPARAM', u'strength_3': u'', u'company': u'Torrent', u'unit': u'mg(ARACHIS OIL )'}

-- line #2740
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARTIZ 150 (Ritz Ph.)',
	'Arteether',
	'VIAL',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML(A & B)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARTIZ 150 (Ritz Ph.)'
);

-- line #2741
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXHIT 150 (AXYZEN LIFE)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML(A & B)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXHIT 150 (AXYZEN LIFE)'
);

-- line #2742
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENTHER 75 (Bennet Ph.)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('75')::numeric,
	'mg/1ML(A & B)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENTHER 75 (Bennet Ph.)'
);

-- line #2743
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETAMOTIL 150 (Ipca)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETAMOTIL 150 (Ipca)'
);

-- line #2744
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BPTHER 150 (HAMPS BIO)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML(A & B)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BPTHER 150 (HAMPS BIO)'
);

-- line #2745
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHINGASU 150 (Ulticare)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML(A & B)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHINGASU 150 (Ulticare)'
);

-- line #2746
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHINGASU 75 (ULTICARE(ALKEM))',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('75')::numeric,
	'mg/ML(A &B)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHINGASU 75 (ULTICARE(ALKEM))'
);

-- line #2747
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Arteether', u'always_empty': u'', u'form': u'INJ', u'brand': u'CUMAL', u'strength_3': u'', u'company': u'Cubit Hc.', u'unit': u''}

-- line #2748
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYTHER 150 (CITIZEN LAB.)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML(ARACHIS OIL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYTHER 150 (CITIZEN LAB.)'
);

-- line #2749
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DMEL 150 (Admac Ph.)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DMEL 150 (Admac Ph.)'
);

-- line #2750
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMITHER 150 (Dominion)',
	'Arteether',
	'AMP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMITHER 150 (Dominion)'
);

-- line #2751
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOTHER 150 (Medoz Ph.)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML(A & B)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOTHER 150 (Medoz Ph.)'
);

-- line #2752
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUTHER 150 (Samarth)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUTHER 150 (Samarth)'
);

-- line #2753
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'E-DALTHER 150 (Dallas Ph.)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML(A & B)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'E-DALTHER 150 (Dallas Ph.)'
);

-- line #2754
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'E-FAL 150 (STAUNCH)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML(A & B)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'E-FAL 150 (STAUNCH)'
);

-- line #2755
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'E MAL 150 (Themis)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML(A & B)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'E MAL 150 (Themis)'
);

-- line #2756
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'E-MAL 150 (Themis Med.)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'E-MAL 150 (Themis Med.)'
);

-- line #2757
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMETHER 150 (BIOMAX BIO.)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML(A & B)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMETHER 150 (BIOMAX BIO.)'
);

-- line #2758
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENDOMAL 150 (ALMET)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENDOMAL 150 (ALMET)'
);

-- line #2759
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENDOMAL 75 (ALMET)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('75')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENDOMAL 75 (ALMET)'
);

-- line #2760
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EROD-M 150 (Bestochem)',
	'Arteether',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg(ALPHABETA)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EROD-M 150 (Bestochem)'
);

-- line #2761
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FALCICURE 150 (Sterfil)',
	'Arteether',
	'AMP',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML(A & B)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FALCICURE 150 (Sterfil)'
);

-- line #2762
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FALCICURE 75 (Sterfil)',
	'Arteether',
	'AMP',
	gm.nullify_empty_string('75')::numeric,
	'mg/2ML(A &B)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FALCICURE 75 (Sterfil)'
);

-- line #2763
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FALCIFAST 150 (Cipla)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML(A & B)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FALCIFAST 150 (Cipla)'
);

-- line #2764
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FALCITHER 150 (Medoz Ph.)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML(A & B)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FALCITHER 150 (Medoz Ph.)'
);

-- line #2765
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FALCITOP 150 (AGIO PH.)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FALCITOP 150 (AGIO PH.)'
);

-- line #2766
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FALCURE 150 (MEPRO PH.)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML(A & B)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FALCURE 150 (MEPRO PH.)'
);

-- line #2767
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FALCY 150 (Skymax)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FALCY 150 (Skymax)'
);

-- line #2768
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FALCY JR 75 (Skymax)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('75')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FALCY JR 75 (Skymax)'
);

-- line #2769
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'A & B', u'strength_2': u'', u'substance': u'Arteether', u'always_empty': u'', u'form': u'INJ', u'brand': u'FAL-I', u'strength_3': u'', u'company': u'Intracin', u'unit': u''}

-- line #2770
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FALPAR 150 (Dwd)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FALPAR 150 (Dwd)'
);

-- line #2771
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FALRAP-KID 75 (Rapross)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('75')::numeric,
	'mg(A & B IN ARACHIS OIL BASE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FALRAP-KID 75 (Rapross)'
);

-- line #2772
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FALTEEM 150 (Neuron Ph.)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML(A & B)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FALTEEM 150 (Neuron Ph.)'
);

-- line #2773
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FALTHER 150 (Shaimil)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML(A & B)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FALTHER 150 (Shaimil)'
);

-- line #2774
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Arteether', u'always_empty': u'', u'form': u'INJ', u'brand': u'FALZERO', u'strength_3': u'', u'company': u'Astrum Hc.', u'unit': u''}

-- line #2775
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLAMETHER 150 (FLAMINGO PH.)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLAMETHER 150 (FLAMINGO PH.)'
);

-- line #2776
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Arteether', u'always_empty': u'', u'form': u'BR INJ', u'brand': u'FOAL', u'strength_3': u'', u'company': u'Forgo Ph.', u'unit': u''}

-- line #2777
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLEETHER 75 (NEISS)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('75')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLEETHER 75 (NEISS)'
);

-- line #2778
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDITHER 150 (Indica)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML(A & B)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDITHER 150 (Indica)'
);

-- line #2779
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'150', u'strength_2': u'', u'substance': u'Arteether', u'always_empty': u'', u'form': u'', u'brand': u'KAMITHER IV', u'strength_3': u'', u'company': u'KAMSONS PH.', u'unit': u'mg/2ML(A & B)'}

-- line #2780
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Arteether', u'always_empty': u'', u'form': u'AMP', u'brand': u'LEMAL', u'strength_3': u'', u'company': u'Lexus', u'unit': u''}

-- line #2781
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEOTHER 150 (Leo Life)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEOTHER 150 (Leo Life)'
);

-- line #2782
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'L-THER 150 (Leben)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'L-THER 150 (Leben)'
);

-- line #2783
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAHATHER 150 (THEMIS MEDICARE)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAHATHER 150 (THEMIS MEDICARE)'
);

-- line #2784
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALACURE-F 150 (Patson)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML(A & B)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALACURE-F 150 (Patson)'
);

-- line #2785
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALANTE-R 150 (F D C)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML(A & B)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALANTE-R 150 (F D C)'
);

-- line #2786
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALARTHER 150 (Acron Ph.)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML(A & B)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALARTHER 150 (Acron Ph.)'
);

-- line #2787
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALATRIT 150 (Piramal Hc.)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg(ARACHIS OIL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALATRIT 150 (Piramal Hc.)'
);

-- line #2788
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALIAGO 150 (Secure)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML(A & B)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALIAGO 150 (Secure)'
);

-- line #2789
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALICURE 150 (Helios Ph.)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML(A & B)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALICURE 150 (Helios Ph.)'
);

-- line #2790
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALIGON-ART 150 (UNIJULES)',
	'Arteether',
	'AMP',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALIGON-ART 150 (UNIJULES)'
);

-- line #2791
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'150', u'strength_2': u'', u'substance': u'Arteether', u'always_empty': u'', u'form': u'', u'brand': u'MALIJET', u'strength_3': u'', u'company': u'Cachet', u'unit': u'mg/2ML'}

-- line #2792
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALIJET 150 (Cachet)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML(BETA)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALIJET 150 (Cachet)'
);

-- line #2793
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALNATE-R 150 (FDC(SELECT))',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALNATE-R 150 (FDC(SELECT))'
);

-- line #2794
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALOF 150 (GENX HC.)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALOF 150 (GENX HC.)'
);

-- line #2795
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALTHER 150 (Ind-Swift)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALTHER 150 (Ind-Swift)'
);

-- line #2796
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MATCH 150 (LIFESTAR)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML(A & B)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MATCH 150 (LIFESTAR)'
);

-- line #2797
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MDTHER 150 (MANEESH HC.)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg (ARACHIS OIL Q.S.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MDTHER 150 (MANEESH HC.)'
);

-- line #2798
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MDTHER 75 (MANEESH HC.)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('75')::numeric,
	'mg (ARACHIS OIL Q.S.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MDTHER 75 (MANEESH HC.)'
);

-- line #2799
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELOVAR 150 (Zota)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELOVAR 150 (Zota)'
);

-- line #2800
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MGO 150 (KPL LIFE)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML(A & B)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MGO 150 (KPL LIFE)'
);

-- line #2801
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIDTHER 75 (Maneesh)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('75')::numeric,
	'mg (+ARACHIS OIL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIDTHER 75 (Maneesh)'
);

-- line #2802
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MLA ALPHA 150 (Parasol)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML(A & B)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MLA ALPHA 150 (Parasol)'
);

-- line #2803
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Arteether', u'always_empty': u'', u'form': u'AMP', u'brand': u'MOSETHER', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #2804
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Arteether', u'always_empty': u'', u'form': u'INJ', u'brand': u'OLTIMATE', u'strength_3': u'', u'company': u'Olcare', u'unit': u''}

-- line #2805
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Arteether', u'always_empty': u'', u'form': u'INJ', u'brand': u'PALTHER', u'strength_3': u'', u'company': u'HEALTH BIO.', u'unit': u''}

-- line #2806
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARASIS 150 (SYNOPSIS)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML(A & B)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARASIS 150 (SYNOPSIS)'
);

-- line #2807
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q-THER 150 (Fairdeal Res.)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML(A & B)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q-THER 150 (Fairdeal Res.)'
);

-- line #2808
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QVEN 150 (VENSAT)',
	'Arteether',
	'AMP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QVEN 150 (VENSAT)'
);

-- line #2809
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAPITHER 150 (Ipca)',
	'Arteether',
	'AMP',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAPITHER 150 (Ipca)'
);

-- line #2810
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REETHER 150 (WISCON)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REETHER 150 (WISCON)'
);

-- line #2811
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIMAL 150 (Rhombus)',
	'Arteether',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML(A & B)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIMAL 150 (Rhombus)'
);

-- line #2812
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AB-THER EXTRA 80 (ROSE LABS)',
	'Artemether',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg/1ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AB-THER EXTRA 80 (ROSE LABS)'
);

-- line #2813
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARMOUR 80 (Shinto Org.)',
	'Artemether',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg/1ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARMOUR 80 (Shinto Org.)'
);

-- line #2814
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARTIMISA 40 (Rekvina)',
	'Artemether',
	'CAP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARTIMISA 40 (Rekvina)'
);

-- line #2815
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARTIMISA 80 (Rekvina)',
	'Artemether',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARTIMISA 80 (Rekvina)'
);

-- line #2816
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERYTHER 80 (Solitaire)',
	'Artemether',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg/1ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERYTHER 80 (Solitaire)'
);

-- line #2817
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FALCYDOL 40 (Skymax)',
	'Artemether',
	'CAP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FALCYDOL 40 (Skymax)'
);

-- line #2818
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FALCYDOL 80 (Skymax)',
	'Artemether',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FALCYDOL 80 (Skymax)'
);

-- line #2819
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LARITHER 80 (Ipca)',
	'Artemether',
	'AMP',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LARITHER 80 (Ipca)'
);

-- line #2820
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LARITHER 40 (Ipca)',
	'Artemether',
	'CAP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LARITHER 40 (Ipca)'
);

-- line #2821
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALITHER 40 (Themis)',
	'ARTEMETHER',
	'CAP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALITHER 40 (Themis)'
);

-- line #2822
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALITHER 80 (Themis)',
	'ARTEMETHER',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALITHER 80 (Themis)'
);

-- line #2823
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METHICAP 40 (Biomax Lab)',
	'Artemether',
	'CAP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METHICAP 40 (Biomax Lab)'
);

-- line #2824
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYTHER 80 (Phytochem)',
	'Artemether',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg/1ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYTHER 80 (Phytochem)'
);

-- line #2825
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PALUTHER 80 (Nicholas)',
	'Artemether',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PALUTHER 80 (Nicholas)'
);

-- line #2826
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ABA 60 (Intra Lab)',
	'Artesunate',
	'AT INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ABA 60 (Intra Lab)'
);

-- line #2827
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ABA 50 (Intra Lab)',
	'Artesunate',
	'AT TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ABA 50 (Intra Lab)'
);

-- line #2828
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AB-THER 50 (ROSE LABS)',
	'Artesunate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AB-THER 50 (ROSE LABS)'
);

-- line #2829
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALTINATE 50 (ALLENGE)',
	'Artesunate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALTINATE 50 (ALLENGE)'
);

-- line #2830
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANSUNATE 50 (Nippon Siy.)',
	'Artesunate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANSUNATE 50 (Nippon Siy.)'
);

-- line #2831
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANTI-FALCI 60 (Medicorp)',
	'Artesunate',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANTI-FALCI 60 (Medicorp)'
);

-- line #2832
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARH PLUS 60 (Lincoln)',
	'Artesunate',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARH PLUS 60 (Lincoln)'
);

-- line #2833
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50', u'strength_2': u'', u'substance': u'Artesunate', u'always_empty': u'', u'form': u'', u'brand': u'ARH PLUS', u'strength_3': u'', u'company': u'Lincoln', u'unit': u'mg'}

-- line #2834
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Artesunate', u'always_empty': u'', u'form': u'DS TAB', u'brand': u'ARSUFEE', u'strength_3': u'', u'company': u'STAUNCH', u'unit': u''}

-- line #2835
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARSUFEE 60 (STAUNCH)',
	'Artesunate',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARSUFEE 60 (STAUNCH)'
);

-- line #2836
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Artesunate', u'always_empty': u'', u'form': u'TAB', u'brand': u'ARSUFEE', u'strength_3': u'', u'company': u'STAUNCH', u'unit': u''}

-- line #2837
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Artesunate', u'always_empty': u'', u'form': u'VIAL', u'brand': u'ARTECA', u'strength_3': u'', u'company': u'NIVCA', u'unit': u''}

-- line #2838
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARTEMBIC-IV 60 (ALEMBIC)',
	'Artesunate',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARTEMBIC-IV 60 (ALEMBIC)'
);

-- line #2839
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARTESA 60 (ORION BIOTECH.)',
	'Artesunate',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARTESA 60 (ORION BIOTECH.)'
);

-- line #2840
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARTESA 50 (ORION BIOTECH.)',
	'Artesunate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARTESA 50 (ORION BIOTECH.)'
);

-- line #2841
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARTESTAR 50 (Intra(INVISION))',
	'Artesunate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARTESTAR 50 (Intra(INVISION))'
);

-- line #2842
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARTESTAR 60 (INVISION)',
	'Artesunate',
	'VIAL',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARTESTAR 60 (INVISION)'
);

-- line #2843
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARTFIN 50 (Zee Lab)',
	'Artesunate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARTFIN 50 (Zee Lab)'
);

-- line #2844
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARTH 60 (PLUS INDIA)',
	'Artesunate',
	'VIAL',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARTH 60 (PLUS INDIA)'
);

-- line #2845
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARTIDEX 50 (Cadex Lab)',
	'Artesunate',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARTIDEX 50 (Cadex Lab)'
);

-- line #2846
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARTIDEX 60 (Cadex Lab)',
	'Artesunate',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARTIDEX 60 (Cadex Lab)'
);

-- line #2847
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASUNATE 60 (ADLEY PHARMA.)',
	'Artesunate',
	'VIAL',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASUNATE 60 (ADLEY PHARMA.)'
);

-- line #2848
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATE 60 (RISHAB(KUREKEMI))',
	'Artesunate',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATE 60 (RISHAB(KUREKEMI))'
);

-- line #2849
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATRENTA 50 (Siesta Form.)',
	'Artesunate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATRENTA 50 (Siesta Form.)'
);

-- line #2850
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AT 50 (SHINCE)',
	'Artesunate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'100'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AT 50 (SHINCE)'
);

-- line #2851
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOART 60 (Biocin Hc.)',
	'Artesunate',
	'VIAL',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOART 60 (Biocin Hc.)'
);

-- line #2852
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALSUNATE 50 (Calibar Ph.)',
	'Artesunate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALSUNATE 50 (Calibar Ph.)'
);

-- line #2853
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHINSUNATE 60 (Alkem)',
	'Artesunate',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHINSUNATE 60 (Alkem)'
);

-- line #2854
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COROTHER PLUS 60 (Corona)',
	'Artesunate',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COROTHER PLUS 60 (Corona)'
);

-- line #2855
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUNATE 50 (Samarth)',
	'Artesunate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUNATE 50 (Samarth)'
);

-- line #2856
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENDOMAL 60 (ALMET)',
	'Artesunate',
	'AT INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENDOMAL 60 (ALMET)'
);

-- line #2857
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENDOMAL-O 50 (ALMET)',
	'Artesunate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENDOMAL-O 50 (ALMET)'
);

-- line #2858
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FALCHIL 60 (MEDHEAL PH.)',
	'Artesunate',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FALCHIL 60 (MEDHEAL PH.)'
);

-- line #2859
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FALCIAT 50 (Atoz Ph.)',
	'Artesunate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FALCIAT 50 (Atoz Ph.)'
);

-- line #2860
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FALCICARE 60 (UNITED LIFE)',
	'Artesunate',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FALCICARE 60 (UNITED LIFE)'
);

-- line #2861
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FALCICARE 50 (UNITED LIFE)',
	'Artesunate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FALCICARE 50 (UNITED LIFE)'
);

-- line #2862
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FALCIGO 60 (Zydus Cadila)',
	'Artesunate',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FALCIGO 60 (Zydus Cadila)'
);

-- line #2863
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FALCIGO 50 (Zydus Cadila)',
	'Artesunate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FALCIGO 50 (Zydus Cadila)'
);

-- line #2864
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FALCINA 50 (Sayona)',
	'Artesunate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FALCINA 50 (Sayona)'
);

-- line #2865
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FALCINEZ 50 (Wintech)',
	'Artesunate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FALCINEZ 50 (Wintech)'
);

-- line #2866
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FALCINEZ 60 (Wintech)',
	'Artesunate',
	'VIAL',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FALCINEZ 60 (Wintech)'
);

-- line #2867
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FALCINIL 60 (Zuventus)',
	'Artesunate',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FALCINIL 60 (Zuventus)'
);

-- line #2868
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FALCINIL 50 (Zuventus)',
	'Artesunate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FALCINIL 50 (Zuventus)'
);

-- line #2869
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FALCINOR 50 (Southsourne)',
	'Artesunate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FALCINOR 50 (Southsourne)'
);

-- line #2870
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FALCIPURE 60 (STERLING PH.)',
	'Artesunate',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FALCIPURE 60 (STERLING PH.)'
);

-- line #2871
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FALCIQUIN 50 (Saga Lab)',
	'Artesunate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FALCIQUIN 50 (Saga Lab)'
);

-- line #2872
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FALCIQUIT 50 (ADDPLUS)',
	'Artesunate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FALCIQUIT 50 (ADDPLUS)'
);

-- line #2873
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FALCITROL 60 (AGIO PH.)',
	'Artesunate',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg(+THE PACK CONTAIN 1ML AMP. OF SOD. BICARB.5 W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FALCITROL 60 (AGIO PH.)'
);

-- line #2874
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FALCIZED 50 (Zota)',
	'Artesunate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FALCIZED 50 (Zota)'
);

-- line #2875
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FALCYGUARD 60 (BIOSENA)',
	'Artesunate',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FALCYGUARD 60 (BIOSENA)'
);

-- line #2876
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FALCYNATE 60 (Samarth)',
	'Artesunate',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FALCYNATE 60 (Samarth)'
);

-- line #2877
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FALCYNATE-QRS 50 (Skymax)',
	'Artesunate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FALCYNATE-QRS 50 (Skymax)'
);

-- line #2878
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FALCYNATE 50 (Skymax)',
	'Artesunate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FALCYNATE 50 (Skymax)'
);

-- line #2879
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FALCY PLUS 50 (Baroque)',
	'Artesunate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FALCY PLUS 50 (Baroque)'
);

-- line #2880
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FALSU 60 (Votary Lab)',
	'Artesunate',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FALSU 60 (Votary Lab)'
);

-- line #2881
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FALSUN 60 (CH.Bhagat)',
	'Artesunate',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FALSUN 60 (CH.Bhagat)'
);

-- line #2882
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FALTEEM 50 (Neuron Ph.)',
	'Artesunate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FALTEEM 50 (Neuron Ph.)'
);

-- line #2883
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FM - 60 (Emcure)',
	'Artesunate',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FM - 60 (Emcure)'
);

-- line #2884
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'F-QUIT 50 (J.P.LIFE)',
	'Artesunate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'F-QUIT 50 (J.P.LIFE)'
);

-- line #2885
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATE 50 (VENSAT)',
	'Artesunate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATE 50 (VENSAT)'
);

-- line #2886
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GERINATE 60 (GERRYSUN PH.)',
	'Artesunate',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg(STERILI)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GERINATE 60 (GERRYSUN PH.)'
);

-- line #2887
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDINATE 60 (Indica)',
	'Artesunate',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDINATE 60 (Indica)'
);

-- line #2888
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDINATE 50 (Indica)',
	'Artesunate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDINATE 50 (Indica)'
);

-- line #2889
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEONATE DRY 50 (LEOLIFE)',
	'Artesunate',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEONATE DRY 50 (LEOLIFE)'
);

-- line #2890
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYSUNATE 60 (LYKA LABS)',
	'Artesunate',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYSUNATE 60 (LYKA LABS)'
);

-- line #2891
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYSUNATE 50 (LYKA LABS)',
	'Artesunate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYSUNATE 50 (LYKA LABS)'
);

-- line #2892
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALACURE AT 100 (Patson)',
	'Artesunate',
	'F. TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALACURE AT 100 (Patson)'
);

-- line #2893
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALACURE 60 (Patson)',
	'Artesunate',
	'AT INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALACURE 60 (Patson)'
);

-- line #2894
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALACURE 50 (Patson)',
	'Artesunate',
	'AT TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALACURE 50 (Patson)'
);

-- line #2895
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALANTE 60 (F D C)',
	'Artesunate',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg(+1AMP. NAHCO3 5'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALANTE 60 (F D C)'
);

-- line #2896
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALANTE 50 (F D C)',
	'Artesunate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALANTE 50 (F D C)'
);

-- line #2897
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALATRIT-S 60 (Piramal Hc.)',
	'Artesunate',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg (I.M. / I.V.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALATRIT-S 60 (Piramal Hc.)'
);

-- line #2898
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALATRIT-S 50 (Piramal Hc.)',
	'Artesunate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALATRIT-S 50 (Piramal Hc.)'
);

-- line #2899
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALICURE 50 (HELIOS)',
	'Artesunate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALICURE 50 (HELIOS)'
);

-- line #2900
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALNATE 50 (FDC(SELECT))',
	'Artesunate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg(3.5SOD. BICARB.'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALNATE 50 (FDC(SELECT))'
);

-- line #2901
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALNATE 50 (FDC(SELECT))',
	'Artesunate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALNATE 50 (FDC(SELECT))'
);

-- line #2902
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALOCIDE 60 (Torrent)',
	'Artesunate',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALOCIDE 60 (Torrent)'
);

-- line #2903
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALOCIDE 50 (Torrent)',
	'Artesunate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALOCIDE 50 (Torrent)'
);

-- line #2904
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MARTIS 50 (MADHAV BIO.)',
	'Artesunate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MARTIS 50 (MADHAV BIO.)'
);

-- line #2905
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MATCH-AR 60 (LIFESTAR)',
	'Artesunate',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg (PACK OF 1ML AMP. OF SOD. BICARB.+5ML SOD. CHL.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MATCH-AR 60 (LIFESTAR)'
);

-- line #2906
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MATCH-AR 50 (LIFESTAR)',
	'Artesunate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MATCH-AR 50 (LIFESTAR)'
);

-- line #2907
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAXINATE 60 (BIOMAX BIO.)',
	'Artesunate',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAXINATE 60 (BIOMAX BIO.)'
);

-- line #2908
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAXINATE 50 (Biomax Lab)',
	'Artesunate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAXINATE 50 (Biomax Lab)'
);

-- line #2909
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONONATE 60 (Leo)',
	'Artesunate',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONONATE 60 (Leo)'
);

-- line #2910
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONONATE 50 (Leo)',
	'Artesunate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONONATE 50 (Leo)'
);

-- line #2911
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'N ART 50 (NEMI PH.)',
	'Artesunate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'N ART 50 (NEMI PH.)'
);

-- line #2912
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NISUNATE 50 (NEISS)',
	'Artesunate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NISUNATE 50 (NEISS)'
);

-- line #2913
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Artesunate', u'always_empty': u'', u'form': u'VIAL', u'brand': u'NISUNATE', u'strength_3': u'', u'company': u'NEISS', u'unit': u''}

-- line #2914
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOMAL 60 (Indi Ph.)',
	'Artesunate',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOMAL 60 (Indi Ph.)'
);

-- line #2915
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOMAL 50 (Indi Ph.)',
	'Artesunate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOMAL 50 (Indi Ph.)'
);

-- line #2916
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORATE 50 (NORTECH REM.)',
	'Artesunate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORATE 50 (NORTECH REM.)'
);

-- line #2917
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXART 60 (AXYZEN LIFE)',
	'Artesunate',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXART 60 (AXYZEN LIFE)'
);

-- line #2918
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXART 50 (AXYZEN LIFE)',
	'Artesunate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXART 50 (AXYZEN LIFE)'
);

-- line #2919
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYRALFIN-A 60 (Lupin)',
	'Artesunate',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYRALFIN-A 60 (Lupin)'
);

-- line #2920
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYRALFIN-A 50 (Lupin)',
	'Artesunate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYRALFIN-A 50 (Lupin)'
);

-- line #2921
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REONATE 60 (RISHAB(OROCHEM))',
	'Artesunate',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REONATE 60 (RISHAB(OROCHEM))'
);

-- line #2922
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'ARTIFICIAL SALIVA', u'always_empty': u'', u'form': u'SUPPLEMENT', u'brand': u'AQWET SALIVA', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #2923
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLA-C 500 (AIMCO PH.)',
	'Ascorbic Acid',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLA-C 500 (AIMCO PH.)'
);

-- line #2924
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AQUASOL-C 75 (Lifeon)',
	'Ascorbic Acid',
	'DPS',
	gm.nullify_empty_string('75')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AQUASOL-C 75 (Lifeon)'
);

-- line #2925
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CECON 100 (Pfizer)',
	'Ascorbic Acid',
	'DPS',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CECON 100 (Pfizer)'
);

-- line #2926
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELIN CHW 500 (GSK)',
	'Ascorbic Acid',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELIN CHW 500 (GSK)'
);

-- line #2927
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELIN 100 (Gsk)',
	'Ascorbic Acid',
	'DPS',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELIN 100 (Gsk)'
);

-- line #2928
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELIN 500 (Gsk)',
	'Ascorbic Acid',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELIN 500 (Gsk)'
);

-- line #2929
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELL-C 100 (Nicholas)',
	'Ascorbic Acid',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELL-C 100 (Nicholas)'
);

-- line #2930
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELL-C 500 (Nicholas)',
	'Ascorbic Acid',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELL-C 500 (Nicholas)'
);

-- line #2931
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHEWCEE 500 (Wyeth)',
	'Ascorbic Acid',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg(338'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHEWCEE 500 (Wyeth)'
);

-- line #2932
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHEWCY 100 (SUNSIGN PH.)',
	'Ascorbic Acid',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg(+450'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHEWCY 100 (SUNSIGN PH.)'
);

-- line #2933
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHEWCY 500 (SUNSIGN PH.)',
	'Ascorbic Acid',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg(0.45G SOD.ASCORBATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHEWCY 500 (SUNSIGN PH.)'
);

-- line #2934
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITRAVITE 500 (Pharmed)',
	'Ascorbic Acid',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg(0.45G SOD.ASCORBATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITRAVITE 500 (Pharmed)'
);

-- line #2935
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-VIT 150 (Cipla)',
	'Ascorbic Acid',
	'CHEW TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg (394'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-VIT 150 (Cipla)'
);

-- line #2936
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FRUTCEE 110 (Sai Mirra)',
	'ASCORBIC ACID',
	'DPS',
	gm.nullify_empty_string('110')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FRUTCEE 110 (Sai Mirra)'
);

-- line #2937
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FRUTCEE 375 (MEDREICH SAI.)',
	'Ascorbic Acid',
	'TAB',
	gm.nullify_empty_string('375')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FRUTCEE 375 (MEDREICH SAI.)'
);

-- line #2938
-- ignoring line: field [strength_1] not numeric: >>>100(450<<<
-- {u'list_of_values_of_unknown_fields': [u' mg(ZINC CITRATE)', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100(450', u'strength_2': u'', u'substance': u'Ascorbic Acid', u'always_empty': u'', u'form': u'TAB', u'brand': u'KISSCEE CHW', u'strength_3': u'', u'company': u'MODHIKE', u'unit': u'mg SOD.ASCORBATE)'}

-- line #2939
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIMCEE 100 (Nicholas)',
	'Ascorbic Acid',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg (450'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIMCEE 100 (Nicholas)'
);

-- line #2940
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINCEE CHW 100 (Piramal Hc.)',
	'Ascorbic Acid',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'450'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINCEE CHW 100 (Piramal Hc.)'
);

-- line #2941
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REDOXON 500 (Nicholas)',
	'Ascorbic Acid',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REDOXON 500 (Nicholas)'
);

-- line #2942
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'1 UP 18 (N.I.)',
	'Aspartame',
	'PELLETS',
	gm.nullify_empty_string('18')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '1 UP 18 (N.I.)'
);

-- line #2943
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASPASWEET 18 (Intas)',
	'Aspartame',
	'TAB',
	gm.nullify_empty_string('18')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASPASWEET 18 (Intas)'
);

-- line #2944
-- ignoring line: field [strength_1] not numeric: >>>#NAME?<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'#NAME?', u'strength_2': u'', u'substance': u'Aspartame', u'always_empty': u'', u'form': u'SAC', u'brand': u'EQUAL', u'strength_3': u'', u'company': u'Rpg Life', u'unit': u'SILICON DIOXIDE'}

-- line #2945
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Aspartame', u'always_empty': u'', u'form': u'SPOONFUL', u'brand': u'EQUAL', u'strength_3': u'', u'company': u'Rpg Life', u'unit': u''}

-- line #2946
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Aspartame', u'always_empty': u'', u'form': u'TAB', u'brand': u'EQUAL', u'strength_3': u'', u'company': u'Rpg Life', u'unit': u''}

-- line #2947
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROXY 18 (Idpl)',
	'Aspartame',
	'TAB',
	gm.nullify_empty_string('18')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROXY 18 (Idpl)'
);

-- line #2948
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACETYL SALICYLIC ACID 50 (German R.)',
	'Aspirin',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACETYL SALICYLIC ACID 50 (German R.)'
);

-- line #2949
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTISPRIN 150 (Alkem)',
	'Aspirin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTISPRIN 150 (Alkem)'
);

-- line #2950
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTISPRIN 75 (Alkem)',
	'Aspirin',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTISPRIN 75 (Alkem)'
);

-- line #2951
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPYRIN 150 (Lincoln)',
	'Aspirin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPYRIN 150 (Lincoln)'
);

-- line #2952
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPYRIN 75 (Lincoln)',
	'Aspirin',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPYRIN 75 (Lincoln)'
);

-- line #2953
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASA 50 (German R.)',
	'Aspirin',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASA 50 (German R.)'
);

-- line #2954
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASA 75 (German R.)',
	'Aspirin',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASA 75 (German R.)'
);

-- line #2955
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASA 50 (ZYDUS MEDICA)',
	'Aspirin',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASA 50 (ZYDUS MEDICA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASA 75 (ZYDUS MEDICA)',
	'Aspirin',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASA 75 (ZYDUS MEDICA)'
);

-- line #2956
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASCAD 150 (Cardicare)',
	'Aspirin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg(DR)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASCAD 150 (Cardicare)'
);

-- line #2957
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASCAD 75 (Cardicare)',
	'Aspirin',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg(DR)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASCAD 75 (Cardicare)'
);

-- line #2958
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASICOM 75 (Comed)',
	'Aspirin',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASICOM 75 (Comed)'
);

-- line #2959
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASPENT 60 (Ranbaxy Cv)',
	'Aspirin',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASPENT 60 (Ranbaxy Cv)'
);

-- line #2960
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASPICOT 80 (Concept)',
	'Aspirin',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASPICOT 80 (Concept)'
);

-- line #2961
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASPIN 100 (Cipla)',
	'ASPIRIN',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASPIN 100 (Cipla)'
);

-- line #2962
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASPITEC 50 (NOVARTIS)',
	'Aspirin',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASPITEC 50 (NOVARTIS)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASPITEC 150 (NOVARTIS)',
	'Aspirin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASPITEC 150 (NOVARTIS)'
);

-- line #2963
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRIN 150 (Brawn Lab)',
	'Aspirin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRIN 150 (Brawn Lab)'
);

-- line #2964
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRIN 75 (Brawn Lab)',
	'Aspirin',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRIN 75 (Brawn Lab)'
);

-- line #2965
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARESPRIN 150 (Olcare)',
	'Aspirin',
	'CR TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARESPRIN 150 (Olcare)'
);

-- line #2966
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COLSPRIN 100 (RECKITT B.)',
	'ASPIRIN',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COLSPRIN 100 (RECKITT B.)'
);

-- line #2967
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COTASIPRIN 150 (Natco Ph.)',
	'Aspirin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COTASIPRIN 150 (Natco Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COTASIPRIN 325 (Natco Ph.)',
	'Aspirin',
	'TAB',
	gm.nullify_empty_string('325')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COTASIPRIN 325 (Natco Ph.)'
);

-- line #2968
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COTASPRIN 50 (Natco Ph.)',
	'Aspirin',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COTASPRIN 50 (Natco Ph.)'
);

-- line #2969
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COVASA 50 (Camlin)',
	'ASPIRIN',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COVASA 50 (Camlin)'
);

-- line #2970
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CV-SPRIN 150 (Cadila Ph.)',
	'Aspirin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CV-SPRIN 150 (Cadila Ph.)'
);

-- line #2971
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CV-SPRIN 75 (Cadila Ph.)',
	'Aspirin',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CV-SPRIN 75 (Cadila Ph.)'
);

-- line #2972
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50', u'strength_2': u'', u'substance': u'Aspirin', u'always_empty': u'', u'form': u'', u'brand': u'DELAYED RELEASE ASPIRIN', u'strength_3': u'', u'company': u'German R.', u'unit': u'mg'}

-- line #2973
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DELISPRIN 150 (Otsira)',
	'Aspirin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DELISPRIN 150 (Otsira)'
);

-- line #2974
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DELISPRIN 75 (Otsira)',
	'Aspirin',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DELISPRIN 75 (Otsira)'
);

-- line #2975
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DISPERSIBLE ASPIRIN 75 (Astrazeneca)',
	'Aspirin',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DISPERSIBLE ASPIRIN 75 (Astrazeneca)'
);

-- line #2976
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ECOSPRIN 150 (U S V)',
	'Aspirin',
	'EC TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ECOSPRIN 150 (U S V)'
);

-- line #2977
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ECOSPRIN 325 (U S V)',
	'Aspirin',
	'EC TAB',
	gm.nullify_empty_string('325')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ECOSPRIN 325 (U S V)'
);

-- line #2978
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ECOSPRIN 75 (U S V)',
	'Aspirin',
	'EC TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ECOSPRIN 75 (U S V)'
);

-- line #2979
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'E-PRIN 150 (Elder)',
	'Aspirin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg(D.R.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'E-PRIN 150 (Elder)'
);

-- line #2980
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'E-PRIN 325 (Elder)',
	'Aspirin',
	'TAB',
	gm.nullify_empty_string('325')::numeric,
	'mg(D.R.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'E-PRIN 325 (Elder)'
);

-- line #2981
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'E-PRIN 75 (Elder)',
	'Aspirin',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'E-PRIN 75 (Elder)'
);

-- line #2982
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRA 162.5 (EAST WEST)',
	'Aspirin',
	'TAB',
	gm.nullify_empty_string('162.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRA 162.5 (EAST WEST)'
);

-- line #2983
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRA 81 (EAST WEST)',
	'Aspirin',
	'TAB',
	gm.nullify_empty_string('81')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRA 81 (EAST WEST)'
);

-- line #2984
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INSPRIN 75 (AVINASH)',
	'Aspirin',
	'ER TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INSPRIN 75 (AVINASH)'
);

-- line #2985
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LDA 75 (Astrazeneca)',
	'Aspirin',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LDA 75 (Astrazeneca)'
);

-- line #2986
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINZI 300 (Neon)',
	'Aspirin',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINZI 300 (Neon)'
);

-- line #2987
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LODOSPRIN 75 (Astrazeneca)',
	'ASPIRIN',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LODOSPRIN 75 (Astrazeneca)'
);

-- line #2988
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOPRIN 162.5 (Unisearch)',
	'Aspirin',
	'DS TAB',
	gm.nullify_empty_string('162.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOPRIN 162.5 (Unisearch)'
);

-- line #2989
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOPRIN 75 (Unisearch)',
	'Aspirin',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOPRIN 75 (Unisearch)'
);

-- line #2990
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75', u'strength_2': u'', u'substance': u'Aspirin', u'always_empty': u'', u'form': u'', u'brand': u'LOW DOSE ASPIRIN', u'strength_3': u'', u'company': u'Astrazeneca', u'unit': u'mg'}

-- line #2991
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOSPIRIN 150 (Orchid Hc.)',
	'Aspirin',
	'ER TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOSPIRIN 150 (Orchid Hc.)'
);

-- line #2992
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOSPIRIN 50 (Orchid Hc.)',
	'Aspirin',
	'ER TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOSPIRIN 50 (Orchid Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOSPIRIN 75 (Orchid Hc.)',
	'Aspirin',
	'ER TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOSPIRIN 75 (Orchid Hc.)'
);

-- line #2993
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOSPIRIN 100 (Orchid Hc.)',
	'Aspirin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOSPIRIN 100 (Orchid Hc.)'
);

-- line #2994
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOSPIRIN 325 (Orchid Hc.)',
	'Aspirin',
	'TAB',
	gm.nullify_empty_string('325')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOSPIRIN 325 (Orchid Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOSPIRIN 400 (Orchid Hc.)',
	'Aspirin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOSPIRIN 400 (Orchid Hc.)'
);

-- line #2995
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOSPRIN 50 (Mano)',
	'Aspirin',
	'ER TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOSPRIN 50 (Mano)'
);

-- line #2996
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOSPRIN 75 (Mano)',
	'Aspirin',
	'ER TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOSPRIN 75 (Mano)'
);

-- line #2997
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOSPRIN 100 (Mano)',
	'Aspirin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOSPRIN 100 (Mano)'
);

-- line #2998
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOSPRIN 150 (Mano)',
	'Aspirin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOSPRIN 150 (Mano)'
);

-- line #2999
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOSPRIN 325 (Mano)',
	'Aspirin',
	'TAB',
	gm.nullify_empty_string('325')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOSPRIN 325 (Mano)'
);

-- line #3000
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOSPRIN 400 (Mano)',
	'Aspirin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOSPRIN 400 (Mano)'
);

-- line #3001
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAZORAL 75 (Cfl Ph.)',
	'Aspirin',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAZORAL 75 (Cfl Ph.)'
);

-- line #3002
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUSPRIN 100 (Emcure)',
	'Aspirin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUSPRIN 100 (Emcure)'
);

-- line #3003
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUSPRIN 75 (Emcure)',
	'Aspirin',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUSPRIN 75 (Emcure)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUSPRIN 150 (Emcure)',
	'Aspirin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUSPRIN 150 (Emcure)'
);

-- line #3004
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OD-PRIN 162.5 (Ordain Hc.)',
	'Aspirin',
	'TAB',
	gm.nullify_empty_string('162.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OD-PRIN 162.5 (Ordain Hc.)'
);

-- line #3005
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPTAZ-75 75 (SHREYA)',
	'Aspirin',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPTAZ-75 75 (SHREYA)'
);

-- line #3006
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OTASPIRIN 500 (Natco Ph.)',
	'Aspirin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OTASPIRIN 500 (Natco Ph.)'
);

-- line #3007
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OTASPIRIN 50 (Natco Ph.)',
	'Aspirin',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OTASPIRIN 50 (Natco Ph.)'
);

-- line #3008
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POLYKAA 75 (Troikaa)',
	'Aspirin',
	'KIT-B TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POLYKAA 75 (Troikaa)'
);

-- line #3009
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIN 81 (Ordain Hc.)',
	'Aspirin',
	'TAB',
	gm.nullify_empty_string('81')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIN 81 (Ordain Hc.)'
);

-- line #3010
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROSPRIN 100 (Reliance)',
	'Aspirin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROSPRIN 100 (Reliance)'
);

-- line #3011
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROSPRIN 150 (Reliance)',
	'Aspirin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROSPRIN 150 (Reliance)'
);

-- line #3012
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROSPRIN 50 (Reliance)',
	'Aspirin',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROSPRIN 50 (Reliance)'
);

-- line #3013
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORTIFY 40 (Universal)',
	'ASTAXANTHIN COMPLEX',
	'SG CAP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORTIFY 40 (Universal)'
);

-- line #3014
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACEMIZ 5 (Lupin)',
	'Astemizole',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACEMIZ 5 (Lupin)'
);

-- line #3015
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACEMIZ 10 (Lupin)',
	'Astemizole',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACEMIZ 10 (Lupin)'
);

-- line #3016
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACIPAX 10 (Wyeth)',
	'Astemizole',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACIPAX 10 (Wyeth)'
);

-- line #3017
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALERZOLE 5 (Themis)',
	'Astemizole',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALERZOLE 5 (Themis)'
);

-- line #3018
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALERZOLE 10 (Themis)',
	'Astemizole',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALERZOLE 10 (Themis)'
);

-- line #3019
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALESTOL 10 (Indoco Rem.)',
	'Astemizole',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALESTOL 10 (Indoco Rem.)'
);

-- line #3020
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASTELONG 5 (Torrent)',
	'Astemizole',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASTELONG 5 (Torrent)'
);

-- line #3021
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASTELONG 10 (Torrent)',
	'Astemizole',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASTELONG 10 (Torrent)'
);

-- line #3022
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASTEM 10 (Medley)',
	'Astemizole',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASTEM 10 (Medley)'
);

-- line #3023
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAMSTEM 10 (Camlin)',
	'Astemizole',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAMSTEM 10 (Camlin)'
);

-- line #3024
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HISMANAL 1 (Ethnor)',
	'Astemizole',
	'SYR',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HISMANAL 1 (Ethnor)'
);

-- line #3025
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HISMANAL 10 (Ethnor)',
	'Astemizole',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HISMANAL 10 (Ethnor)'
);

-- line #3026
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HISTALONG -J 5 (Dr.Reddy''S)',
	'Astemizole',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HISTALONG -J 5 (Dr.Reddy''S)'
);

-- line #3027
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HISTALONG 10 (Dr.Reddy''S)',
	'Astemizole',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HISTALONG 10 (Dr.Reddy''S)'
);

-- line #3028
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HISTEESE 5 (Micro Nova)',
	'Astemizole',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HISTEESE 5 (Micro Nova)'
);

-- line #3029
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HISTEESE 10 (Micro Nova)',
	'Astemizole',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HISTEESE 10 (Micro Nova)'
);

-- line #3030
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MINASTEM 10 (Glenmark)',
	'Astemizole',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MINASTEM 10 (Glenmark)'
);

-- line #3031
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLMIZ 10 (Olcare)',
	'Astemizole',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLMIZ 10 (Olcare)'
);

-- line #3032
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERIONE 10 (Merind)',
	'Astemizole',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERIONE 10 (Merind)'
);

-- line #3033
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATAVIR 300 (Cipla)',
	'ATAZANAVIR',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATAVIR 300 (Cipla)'
);

-- line #3034
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATAZOR 100 (EMCURE)',
	'ATAZANAVIR',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATAZOR 100 (EMCURE)'
);

-- line #3035
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATAZOR 150 (EMCURE)',
	'ATAZANAVIR',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATAZOR 150 (EMCURE)'
);

-- line #3036
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATAZOR 200 (EMCURE)',
	'ATAZANAVIR',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'300'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATAZOR 200 (EMCURE)'
);

-- line #3037
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATAZOR-R 100 (Emcure)',
	'ATAZANAVIR',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATAZOR-R 100 (Emcure)'
);

-- line #3038
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTINOL 50 (Bipl(Radico Lab))',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTINOL 50 (Bipl(Radico Lab))'
);

-- line #3039
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADBETA 12.5 (Zuventus)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADBETA 12.5 (Zuventus)'
);

-- line #3040
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADBETA 25 (Zuventus)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADBETA 25 (Zuventus)'
);

-- line #3041
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AGLOTEN 50 (Aglowmed)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AGLOTEN 50 (Aglowmed)'
);

-- line #3042
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALINOR 100 (VHB(CRONUS))',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALINOR 100 (VHB(CRONUS))'
);

-- line #3043
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALINOR 25 (VHB(CRONUS))',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALINOR 25 (VHB(CRONUS))'
);

-- line #3044
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALINOR 50 (VHB(CRONUS))',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALINOR 50 (VHB(CRONUS))'
);

-- line #3045
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALOTEN 100 (Claris L.)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALOTEN 100 (Claris L.)'
);

-- line #3046
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALOTEN 50 (Claris L.)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALOTEN 50 (Claris L.)'
);

-- line #3047
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALTOL 100 (Indoco Rem.)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALTOL 100 (Indoco Rem.)'
);

-- line #3048
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALTOL 25 (Indoco Rem.)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALTOL 25 (Indoco Rem.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALTOL 50 (Indoco Rem.)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALTOL 50 (Indoco Rem.)'
);

-- line #3049
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANGITOL 100 (Ind-Swift)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANGITOL 100 (Ind-Swift)'
);

-- line #3050
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANGITOL 25 (Ind-Swift)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANGITOL 25 (Ind-Swift)'
);

-- line #3051
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANGITOL 50 (Ind-Swift)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANGITOL 50 (Ind-Swift)'
);

-- line #3052
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANOL 25 (PSYCOREM)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANOL 25 (PSYCOREM)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANOL 50 (PSYCOREM)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANOL 50 (PSYCOREM)'
);

-- line #3053
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANTELOL 50 (Baroque)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANTELOL 50 (Baroque)'
);

-- line #3054
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANTIPRESS 100 (Saga Lab)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANTIPRESS 100 (Saga Lab)'
);

-- line #3055
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANTIPRESS 50 (Saga Lab)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANTIPRESS 50 (Saga Lab)'
);

-- line #3056
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARTEN 100 (Arbro Ph.)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARTEN 100 (Arbro Ph.)'
);

-- line #3057
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARTEN 50 (Arbro Ph.)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARTEN 50 (Arbro Ph.)'
);

-- line #3058
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATBETA 50 (SHRRISHTI HC.)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATBETA 50 (SHRRISHTI HC.)'
);

-- line #3059
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATCARDIL 100 (Sun)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATCARDIL 100 (Sun)'
);

-- line #3060
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATCARDIL 50 (Sun)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATCARDIL 50 (Sun)'
);

-- line #3061
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATCOM 25 (Comed)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATCOM 25 (Comed)'
);

-- line #3062
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATCOM 50 (Comed)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATCOM 50 (Comed)'
);

-- line #3063
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATECARD 100 (Dabur Ph.)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATECARD 100 (Dabur Ph.)'
);

-- line #3064
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATECARD 25 (Dabur Ph.)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATECARD 25 (Dabur Ph.)'
);

-- line #3065
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATECARD 50 (Dabur Ph.)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATECARD 50 (Dabur Ph.)'
);

-- line #3066
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATECOR 100 (Win-Medicare)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATECOR 100 (Win-Medicare)'
);

-- line #3067
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATECOR 50 (Win-Medicare)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATECOR 50 (Win-Medicare)'
);

-- line #3068
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATEKIND 50 (Mankind)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATEKIND 50 (Mankind)'
);

-- line #3069
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATELAND 25 (L & V PH.)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATELAND 25 (L & V PH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATELAND 50 (L & V PH.)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATELAND 50 (L & V PH.)'
);

-- line #3070
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATELOL 100 (Themis)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATELOL 100 (Themis)'
);

-- line #3071
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATELOL 25 (Themis)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATELOL 25 (Themis)'
);

-- line #3072
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATELOL 50 (Themis)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATELOL 50 (Themis)'
);

-- line #3073
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATEMARC 50 (Marc Lab)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATEMARC 50 (Marc Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATEMARC 100 (Marc Lab)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATEMARC 100 (Marc Lab)'
);

-- line #3074
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATENEX 100 (Zydus Cadila)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATENEX 100 (Zydus Cadila)'
);

-- line #3075
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATENEX 25 (Zydus Cadila)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATENEX 25 (Zydus Cadila)'
);

-- line #3076
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATENEX 50 (Zydus Cadila)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATENEX 50 (Zydus Cadila)'
);

-- line #3077
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATENIJ 100 (Sunij)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATENIJ 100 (Sunij)'
);

-- line #3078
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATENIJ 25 (Sunij)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATENIJ 25 (Sunij)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATENIJ 50 (Sunij)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATENIJ 50 (Sunij)'
);

-- line #3079
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATENOLOL 100 (Nicholas)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATENOLOL 100 (Nicholas)'
);

-- line #3080
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATENOLOL 50 (Nicholas)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATENOLOL 50 (Nicholas)'
);

-- line #3081
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATENOVA 100 (Lupin)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATENOVA 100 (Lupin)'
);

-- line #3082
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATENOVA 25 (Lupin)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATENOVA 25 (Lupin)'
);

-- line #3083
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATENOVA 50 (Lupin)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATENOVA 50 (Lupin)'
);

-- line #3084
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATEN 100 (Zydus Cadila)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATEN 100 (Zydus Cadila)'
);

-- line #3085
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATEN 25 (Zydus Cadila)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATEN 25 (Zydus Cadila)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATEN 50 (Zydus Cadila)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATEN 50 (Zydus Cadila)'
);

-- line #3086
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATEN 75 (Zydus Cadila)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATEN 75 (Zydus Cadila)'
);

-- line #3087
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATEPRES 50 (Cardicare)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATEPRES 50 (Cardicare)'
);

-- line #3088
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATMOST 50 (Torrent)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATMOST 50 (Torrent)'
);

-- line #3089
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'25', u'strength_2': u'', u'substance': u'Atenolol', u'always_empty': u'', u'form': u'', u'brand': u'ATMOST', u'strength_3': u'', u'company': u'Torrent', u'unit': u'mg'}

-- line #3090
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATOL 100 (EAST WEST)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATOL 100 (EAST WEST)'
);

-- line #3091
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATOL 25 (EAST WEST)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATOL 25 (EAST WEST)'
);

-- line #3092
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATOL 50 (EAST WEST)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATOL 50 (EAST WEST)'
);

-- line #3093
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATOP 50 (Finecure)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATOP 50 (Finecure)'
);

-- line #3094
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATORMIN 100 (P C INDIA)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATORMIN 100 (P C INDIA)'
);

-- line #3095
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATORMIN 25 (P C INDIA)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATORMIN 25 (P C INDIA)'
);

-- line #3096
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATORMIN 50 (P C INDIA)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATORMIN 50 (P C INDIA)'
);

-- line #3097
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATPARK 100 (Pfizer)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATPARK 100 (Pfizer)'
);

-- line #3098
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATPARK 25 (Pfizer)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATPARK 25 (Pfizer)'
);

-- line #3099
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATPARK 50 (Pfizer)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATPARK 50 (Pfizer)'
);

-- line #3100
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATPIC 25 (Systopic)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg (S-ATENOLOL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATPIC 25 (Systopic)'
);

-- line #3101
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'(S-ATENOLOL)', u'strength_2': u'', u'substance': u'Atenolol', u'always_empty': u'', u'form': u'TAB', u'brand': u'ATPURE', u'strength_3': u'', u'company': u'Emcure', u'unit': u''}

-- line #3102
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATZEE 50 (Zee Lab)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATZEE 50 (Zee Lab)'
);

-- line #3103
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXYNOL 50 (AXYZEN LIFE)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXYNOL 50 (AXYZEN LIFE)'
);

-- line #3104
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'B-BLOC 50 (WISCON)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'B-BLOC 50 (WISCON)'
);

-- line #3105
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BEETAN 50 (HAMPS BIO.)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BEETAN 50 (HAMPS BIO.)'
);

-- line #3106
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENOL 50 (Indica)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENOL 50 (Indica)'
);

-- line #3107
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETADURE 100 (Brown & B.)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETADURE 100 (Brown & B.)'
);

-- line #3108
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETADURE 50 (Brown & B.)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETADURE 50 (Brown & B.)'
);

-- line #3109
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETANOL 50 (Unichem)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETANOL 50 (Unichem)'
);

-- line #3110
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETA 100 (Stadmed)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETA 100 (Stadmed)'
);

-- line #3111
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETA 25 (Stadmed)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETA 25 (Stadmed)'
);

-- line #3112
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETA 50 (Stadmed)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETA 50 (Stadmed)'
);

-- line #3113
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETEN 12.5 (Svizera)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETEN 12.5 (Svizera)'
);

-- line #3114
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETEN 25 (Svizera)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETEN 25 (Svizera)'
);

-- line #3115
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETEN 50 (Svizera)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETEN 50 (Svizera)'
);

-- line #3116
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETEN 12.5 (SVIZERE HC.)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETEN 12.5 (SVIZERE HC.)'
);

-- line #3117
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETEN 25 (SVIZERE HC.)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETEN 25 (SVIZERE HC.)'
);

-- line #3118
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIDUTEN 50 (GSK)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIDUTEN 50 (GSK)'
);

-- line #3119
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BP-ACT 25 (Active Hc.)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BP-ACT 25 (Active Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BP-ACT 50 (Active Hc.)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BP-ACT 50 (Active Hc.)'
);

-- line #3120
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BPGARD 50 (Finecure)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BPGARD 50 (Finecure)'
);

-- line #3121
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BP-NOL 100 (Elder)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BP-NOL 100 (Elder)'
);

-- line #3122
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BP-NOL 25 (Elder)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BP-NOL 25 (Elder)'
);

-- line #3123
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BP-NOL 50 (Elder)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BP-NOL 50 (Elder)'
);

-- line #3124
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BP NORM 100 (Medley)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BP NORM 100 (Medley)'
);

-- line #3125
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BP NORM 25 (Medley)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BP NORM 25 (Medley)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BP NORM 50 (Medley)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BP NORM 50 (Medley)'
);

-- line #3126
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CADPRES 100 (Cadila Ph.)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CADPRES 100 (Cadila Ph.)'
);

-- line #3127
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CADPRES 25 (Cadila Ph.)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CADPRES 25 (Cadila Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CADPRES 50 (Cadila Ph.)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CADPRES 50 (Cadila Ph.)'
);

-- line #3128
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDATEN 5 (SG PH.)',
	'Atenolol',
	'AMP',
	gm.nullify_empty_string('5')::numeric,
	'mg/10ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDATEN 5 (SG PH.)'
);

-- line #3129
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDEN 100 (Intra Lab)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDEN 100 (Intra Lab)'
);

-- line #3130
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDEN 25 (Intra Lab)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDEN 25 (Intra Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDEN 50 (Intra Lab)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDEN 50 (Intra Lab)'
);

-- line #3131
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARTEN 100 (Olcare)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARTEN 100 (Olcare)'
);

-- line #3132
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARTEN 25 (Olcare)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARTEN 25 (Olcare)'
);

-- line #3133
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARTEN 50 (Olcare)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARTEN 50 (Olcare)'
);

-- line #3134
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CATENOL 100 (Zydus Med.)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CATENOL 100 (Zydus Med.)'
);

-- line #3135
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CATENOL 25 (Zydus Med.)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CATENOL 25 (Zydus Med.)'
);

-- line #3136
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CATENOL 50 (Zydus Med.)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CATENOL 50 (Zydus Med.)'
);

-- line #3137
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C CARD 50 (Chemo D.)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C CARD 50 (Chemo D.)'
);

-- line #3138
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORONOL 25 (SPPL)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORONOL 25 (SPPL)'
);

-- line #3139
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORONOL 50 (SPPL)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORONOL 50 (SPPL)'
);

-- line #3140
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-TOL 100 (Corona)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-TOL 100 (Corona)'
);

-- line #3141
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-TOL 50 (Corona)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-TOL 50 (Corona)'
);

-- line #3142
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILCARE 25 (Ind-Swift)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILCARE 25 (Ind-Swift)'
);

-- line #3143
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILCARE 50 (Ind-Swift)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILCARE 50 (Ind-Swift)'
);

-- line #3144
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMBETA 100 (Intas)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMBETA 100 (Intas)'
);

-- line #3145
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMBETA 25 (Intas)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMBETA 25 (Intas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMBETA 50 (Intas)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMBETA 50 (Intas)'
);

-- line #3146
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENEE 25 (Hal)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENEE 25 (Hal)'
);

-- line #3147
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENEE 50 (Hal)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENEE 50 (Hal)'
);

-- line #3148
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G-TEN 100 (GRANDIX)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G-TEN 100 (GRANDIX)'
);

-- line #3149
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G-TEN 25 (GRANDIX)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G-TEN 25 (GRANDIX)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G-TEN 50 (GRANDIX)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G-TEN 50 (GRANDIX)'
);

-- line #3150
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIBESOR 25 (Blue Cross)',
	'ATENOLOL',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIBESOR 25 (Blue Cross)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIBESOR 50 (Blue Cross)',
	'ATENOLOL',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIBESOR 50 (Blue Cross)'
);

-- line #3151
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIPRES 100 (Cipla)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIPRES 100 (Cipla)'
);

-- line #3152
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIPRES 25 (Cipla)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIPRES 25 (Cipla)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIPRES 50 (Cipla)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIPRES 50 (Cipla)'
);

-- line #3153
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYTEN 100 (Sain Med.)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYTEN 100 (Sain Med.)'
);

-- line #3154
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYTEN 25 (Sain Med.)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYTEN 25 (Sain Med.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYTEN 50 (Sain Med.)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYTEN 50 (Sain Med.)'
);

-- line #3155
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTALOL 100 (Intas)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTALOL 100 (Intas)'
);

-- line #3156
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTALOL 50 (Intas)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTALOL 50 (Intas)'
);

-- line #3157
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAKTEN 50 (Shalaks)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAKTEN 50 (Shalaks)'
);

-- line #3158
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LONET 25 (Alde Medi.)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LONET 25 (Alde Medi.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LONET 50 (Alde Medi.)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LONET 50 (Alde Medi.)'
);

-- line #3159
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LONOL 100 (XENON)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LONOL 100 (XENON)'
);

-- line #3160
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LONOL 25 (XENON)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LONOL 25 (XENON)'
);

-- line #3161
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LONOL 50 (XENON)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LONOL 50 (XENON)'
);

-- line #3162
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOTEN 100 (Mano)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOTEN 100 (Mano)'
);

-- line #3163
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOTEN 12.5 (Mano)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOTEN 12.5 (Mano)'
);

-- line #3164
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOTEN 25 (Mano)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOTEN 25 (Mano)'
);

-- line #3165
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOTEN 50 (Mano)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOTEN 50 (Mano)'
);

-- line #3166
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOTEN 75 (Mano)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOTEN 75 (Mano)'
);

-- line #3167
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOVATEN 50 (MOVA PH.)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOVATEN 50 (MOVA PH.)'
);

-- line #3168
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVATEN 100 (Ajanta Ph.)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVATEN 100 (Ajanta Ph.)'
);

-- line #3169
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVATEN 50 (Ajanta Ph.)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVATEN 50 (Ajanta Ph.)'
);

-- line #3170
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'O-BETA 100 (Intas)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'O-BETA 100 (Intas)'
);

-- line #3171
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'O-BETA 25 (Intas)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'O-BETA 25 (Intas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'O-BETA 50 (Intas)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'O-BETA 50 (Intas)'
);

-- line #3172
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODINOL 25 (Alembic)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODINOL 25 (Alembic)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODINOL 50 (Alembic)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODINOL 50 (Alembic)'
);

-- line #3173
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLATE 25 (Caplet Ind.)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLATE 25 (Caplet Ind.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLATE 50 (Caplet Ind.)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLATE 50 (Caplet Ind.)'
);

-- line #3174
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PDNOL 25 (Pharma Drugs)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PDNOL 25 (Pharma Drugs)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PDNOL 50 (Pharma Drugs)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PDNOL 50 (Pharma Drugs)'
);

-- line #3175
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERTENOL 100 (Kapl)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERTENOL 100 (Kapl)'
);

-- line #3176
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERTENOL 25 (Kapl)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERTENOL 25 (Kapl)'
);

-- line #3177
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERTENOL 50 (Kapl)',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERTENOL 50 (Kapl)'
);

-- line #3178
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRESTEN 25 (Intra(INVISION))',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRESTEN 25 (Intra(INVISION))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRESTEN 50 (Intra(INVISION))',
	'Atenolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRESTEN 50 (Intra(INVISION))'
);

-- line #3179
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATTENTROL10/18 10 (Sun)',
	'ATOMOXETINE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATTENTROL10/18 10 (Sun)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATTENTROL10/18 18 (Sun)',
	'ATOMOXETINE',
	'TAB',
	gm.nullify_empty_string('18')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATTENTROL10/18 18 (Sun)'
);

-- line #3180
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATTENTROL 10 (Sun)',
	'ATOMOXETINE',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATTENTROL 10 (Sun)'
);

-- line #3181
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATTENTROL 10 (Sun)',
	'ATOMOXETINE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATTENTROL 10 (Sun)'
);

-- line #3182
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATTENTROL 25 (Sun)',
	'ATOMOXETINE',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATTENTROL 25 (Sun)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATTENTROL 40 (Sun)',
	'ATOMOXETINE',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATTENTROL 40 (Sun)'
);

-- line #3183
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXEPTA 10 (Intas)',
	'ATOMOXETINE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXEPTA 10 (Intas)'
);

-- line #3184
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXEPTA 18 (Intas)',
	'ATOMOXETINE',
	'TAB',
	gm.nullify_empty_string('18')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXEPTA 18 (Intas)'
);

-- line #3185
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXEPTA 25 (Intas)',
	'ATOMOXETINE',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXEPTA 25 (Intas)'
);

-- line #3186
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXEPTA 40 (Intas)',
	'ATOMOXETINE',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXEPTA 40 (Intas)'
);

-- line #3187
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATOCARE 10 (SIGNOVA)',
	'ATORVA',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'20'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATOCARE 10 (SIGNOVA)'
);

-- line #3188
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALIP 10 (TALENT PH.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALIP 10 (TALENT PH.)'
);

-- line #3189
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALL STAT 10 (AEGIS)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALL STAT 10 (AEGIS)'
);

-- line #3190
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALNAVAS 10 (ALNA BIO.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALNAVAS 10 (ALNA BIO.)'
);

-- line #3191
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AOVA 10 (AAMORB(XEENA))',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AOVA 10 (AAMORB(XEENA))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AOVA 20 (AAMORB(XEENA))',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AOVA 20 (AAMORB(XEENA))'
);

-- line #3192
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AQUALIP 10 (AQUALIFE)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AQUALIP 10 (AQUALIFE)'
);

-- line #3193
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AREPRESS 10 (Organic Lab)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AREPRESS 10 (Organic Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AREPRESS 20 (Organic Lab)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AREPRESS 20 (Organic Lab)'
);

-- line #3194
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARPITOR CP 10 (Rpg Life)',
	'Atorvastatin',
	'FC TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARPITOR CP 10 (Rpg Life)'
);

-- line #3195
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARPITOR CP 20 (Rpg Life)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARPITOR CP 20 (Rpg Life)'
);

-- line #3196
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARPITOR 10 (Rpg Life)',
	'Atorvastatin',
	'FC TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARPITOR 10 (Rpg Life)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARPITOR 20 (Rpg Life)',
	'Atorvastatin',
	'FC TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARPITOR 20 (Rpg Life)'
);

-- line #3197
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASAT 10 (Sain Med.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASAT 10 (Sain Med.)'
);

-- line #3198
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASTIN 10 (Cardicare)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASTIN 10 (Cardicare)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASTIN 20 (Cardicare)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASTIN 20 (Cardicare)'
);

-- line #3199
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASTIN 40 (Cardicare)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASTIN 40 (Cardicare)'
);

-- line #3200
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASTIN 5 (Cardicare)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASTIN 5 (Cardicare)'
);

-- line #3201
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASTIN 80 (Micro Labs)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASTIN 80 (Micro Labs)'
);

-- line #3202
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASVASIN 5 (AS PHARMA)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASVASIN 5 (AS PHARMA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASVASIN 10 (AS PHARMA)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASVASIN 10 (AS PHARMA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASVASIN 20 (AS PHARMA)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASVASIN 20 (AS PHARMA)'
);

-- line #3203
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATAST 10 (ANTHUS)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'20'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATAST 10 (ANTHUS)'
);

-- line #3204
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATAVATIN 20 (Viva Labs.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATAVATIN 20 (Viva Labs.)'
);

-- line #3205
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATBA 10 (Aronex Life)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATBA 10 (Aronex Life)'
);

-- line #3206
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATCHOL 10 (Aristo)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATCHOL 10 (Aristo)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATCHOL 20 (Aristo)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATCHOL 20 (Aristo)'
);

-- line #3207
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATCHOL 40 (Aristo)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATCHOL 40 (Aristo)'
);

-- line #3208
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATHEART 10 (Franco I.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATHEART 10 (Franco I.)'
);

-- line #3209
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATHEROCHEK 10 (Indoco Rem.)',
	'Atorvastatin',
	'FC TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATHEROCHEK 10 (Indoco Rem.)'
);

-- line #3210
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATHOLD 10 (KPL LIFE)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATHOLD 10 (KPL LIFE)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATHOLD 20 (KPL LIFE)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATHOLD 20 (KPL LIFE)'
);

-- line #3211
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATIX 10 (Intra(INVISION))',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATIX 10 (Intra(INVISION))'
);

-- line #3212
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATOCARD 10 (ARCUS LABS)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATOCARD 10 (ARCUS LABS)'
);

-- line #3213
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATOCARD 20 (ARCUS LABS)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATOCARD 20 (ARCUS LABS)'
);

-- line #3214
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATOCARD 5 (ARCUS LABS)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATOCARD 5 (ARCUS LABS)'
);

-- line #3215
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATOCOR 10 (Dr.Reddy''S)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATOCOR 10 (Dr.Reddy''S)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATOCOR 20 (Dr.Reddy''S)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATOCOR 20 (Dr.Reddy''S)'
);

-- line #3216
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATOCOR 40 (Dr.Reddy''S)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATOCOR 40 (Dr.Reddy''S)'
);

-- line #3217
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATOCOR 5 (Dr.Reddy''S)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATOCOR 5 (Dr.Reddy''S)'
);

-- line #3218
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATOFAST 10 (Intra Lab)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATOFAST 10 (Intra Lab)'
);

-- line #3219
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATOFAST 20 (Intra Lab)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATOFAST 20 (Intra Lab)'
);

-- line #3220
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATONE 10 (ETHIX HC.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATONE 10 (ETHIX HC.)'
);

-- line #3221
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATOPIN 5 (Baroque)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATOPIN 5 (Baroque)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATOPIN 10 (Baroque)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATOPIN 10 (Baroque)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATOPIN 20 (Baroque)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATOPIN 20 (Baroque)'
);

-- line #3222
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10', u'strength_2': u'', u'substance': u'ATORVastatin', u'always_empty': u'', u'form': u'', u'brand': u'ATOPLUSE', u'strength_3': u'', u'company': u'HAMPS BIO', u'unit': u'mg'}

-- line #3223
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATORBEST 10 (CADILA(GENERIC))',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATORBEST 10 (CADILA(GENERIC))'
);

-- line #3224
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATORDIN 10 (Meridian)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATORDIN 10 (Meridian)'
);

-- line #3225
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATOREC 10 (Nucron Ph.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATOREC 10 (Nucron Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATOREC 20 (Nucron Ph.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATOREC 20 (Nucron Ph.)'
);

-- line #3226
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATOREC 40 (Nucron Ph.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATOREC 40 (Nucron Ph.)'
);

-- line #3227
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATOREC 5 (Nucron Ph.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATOREC 5 (Nucron Ph.)'
);

-- line #3228
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATOREM 10 (SAFE MED(MSN))',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATOREM 10 (SAFE MED(MSN))'
);

-- line #3229
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATOREM 20 (SAFE MED(MSN))',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATOREM 20 (SAFE MED(MSN))'
);

-- line #3230
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATORFIRST 10 (SINSAN PH.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATORFIRST 10 (SINSAN PH.)'
);

-- line #3231
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATORFIRST 20 (SINSAN PH.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATORFIRST 20 (SINSAN PH.)'
);

-- line #3232
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATORFIRST 40 (SINSAN PH.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATORFIRST 40 (SINSAN PH.)'
);

-- line #3233
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATORFIT-40 40 (Ajanta Ph.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATORFIT-40 40 (Ajanta Ph.)'
);

-- line #3234
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATORFIT 10 (Ajanta Ph.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATORFIT 10 (Ajanta Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATORFIT 20 (Ajanta Ph.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATORFIT 20 (Ajanta Ph.)'
);

-- line #3235
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATORFIT 5 (Ajanta Ph.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATORFIT 5 (Ajanta Ph.)'
);

-- line #3236
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATORIL 10 (Argus)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATORIL 10 (Argus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATORIL 20 (Argus)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATORIL 20 (Argus)'
);

-- line #3237
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATORIN 10 (Medley)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATORIN 10 (Medley)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATORIN 20 (Medley)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATORIN 20 (Medley)'
);

-- line #3238
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATORIN 10 (Medley)',
	'ATOrvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATORIN 10 (Medley)'
);

-- line #3239
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATORIN 20 (Medley)',
	'ATOrvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATORIN 20 (Medley)'
);

-- line #3240
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATORIN 40 (Medley)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATORIN 40 (Medley)'
);

-- line #3241
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATORIN 5 (Medley)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATORIN 5 (Medley)'
);

-- line #3242
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATORLAND 10 (L & V PH.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATORLAND 10 (L & V PH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATORLAND 20 (L & V PH.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATORLAND 20 (L & V PH.)'
);

-- line #3243
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATORLIP 10 (Cipla)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATORLIP 10 (Cipla)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATORLIP 20 (Cipla)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATORLIP 20 (Cipla)'
);

-- line #3244
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATORLIP 5 (Cipla)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATORLIP 5 (Cipla)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATORLIP 40 (Cipla)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATORLIP 40 (Cipla)'
);

-- line #3245
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATORMAC 10 (Macleods)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATORMAC 10 (Macleods)'
);

-- line #3246
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATORMAC 20 (Macleods)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATORMAC 20 (Macleods)'
);

-- line #3247
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATORMAC 40 (Macleods)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATORMAC 40 (Macleods)'
);

-- line #3248
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATORMAC 5 (Macleods)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATORMAC 5 (Macleods)'
);

-- line #3249
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATORNET 5 (AKESISS)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATORNET 5 (AKESISS)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATORNET 10 (AKESISS)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATORNET 10 (AKESISS)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATORNET 20 (AKESISS)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATORNET 20 (AKESISS)'
);

-- line #3250
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATOROLL 20 (Vhb)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATOROLL 20 (Vhb)'
);

-- line #3251
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATOROLL 5 (Vhb)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATOROLL 5 (Vhb)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATOROLL 10 (Vhb)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATOROLL 10 (Vhb)'
);

-- line #3252
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATORPIL 80 (Cipla)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATORPIL 80 (Cipla)'
);

-- line #3253
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATORSAVE 10 (ERIS LIFE)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATORSAVE 10 (ERIS LIFE)'
);

-- line #3254
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATORSAVE 20 (ERIS LIFE)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATORSAVE 20 (ERIS LIFE)'
);

-- line #3255
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATORSAVE 40 (ERIS LIFE)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATORSAVE 40 (ERIS LIFE)'
);

-- line #3256
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATORSAVE 80 (ERIS LIFE)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATORSAVE 80 (ERIS LIFE)'
);

-- line #3257
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATORSYN 10 (SYNAGE LC.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATORSYN 10 (SYNAGE LC.)'
);

-- line #3258
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATORTAG 10 (SMENTAG PH.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATORTAG 10 (SMENTAG PH.)'
);

-- line #3259
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATORTAG 20 (SMENTAG PH.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATORTAG 20 (SMENTAG PH.)'
);

-- line #3260
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATORTIN 10 (Panjon)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATORTIN 10 (Panjon)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATORTIN 20 (Panjon)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATORTIN 20 (Panjon)'
);

-- line #3261
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATORTUS 10 (CRATUS)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATORTUS 10 (CRATUS)'
);

-- line #3262
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATORVA 10 (Zydus Cadila)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATORVA 10 (Zydus Cadila)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATORVA 20 (Zydus Cadila)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATORVA 20 (Zydus Cadila)'
);

-- line #3263
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATORVA 5 (Zydus Cadila)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATORVA 5 (Zydus Cadila)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATORVA 40 (Zydus Cadila)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATORVA 40 (Zydus Cadila)'
);

-- line #3264
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATORVA 80 (Zydus Cadila)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATORVA 80 (Zydus Cadila)'
);

-- line #3265
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATORVIK 20 (ANVIK BIO.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATORVIK 20 (ANVIK BIO.)'
);

-- line #3266
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATOSAR 10 (SPPL)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATOSAR 10 (SPPL)'
);

-- line #3267
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATOSAR 20 (SPPL)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATOSAR 20 (SPPL)'
);

-- line #3268
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATOZIDE 5 (ESSWEIL)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATOZIDE 5 (ESSWEIL)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATOZIDE 10 (ESSWEIL)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATOZIDE 10 (ESSWEIL)'
);

-- line #3269
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATRIA 10 (Orion Life)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATRIA 10 (Orion Life)'
);

-- line #3270
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'80', u'strength_2': u'', u'substance': u'Atorvastatin', u'always_empty': u'', u'form': u'', u'brand': u'ATROFIT', u'strength_3': u'', u'company': u'Ajanta Ph.', u'unit': u'mg'}

-- line #3271
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATROLAR 10 (Lark Labs)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATROLAR 10 (Lark Labs)'
);

-- line #3272
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATROLET 10 (Caplet Ind.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATROLET 10 (Caplet Ind.)'
);

-- line #3273
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATRONA 10 (Sayona)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATRONA 10 (Sayona)'
);

-- line #3274
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATROSTAT 10 (Themis Med.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATROSTAT 10 (Themis Med.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATROSTAT 20 (Themis Med.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATROSTAT 20 (Themis Med.)'
);

-- line #3275
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATROZED 10 (Zota Ph.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATROZED 10 (Zota Ph.)'
);

-- line #3276
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATSTAT 10 (Ind-Swift)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATSTAT 10 (Ind-Swift)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATSTAT 20 (Ind-Swift)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATSTAT 20 (Ind-Swift)'
);

-- line #3277
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATTOR 10 (Biochem)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATTOR 10 (Biochem)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATTOR 20 (Biochem)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATTOR 20 (Biochem)'
);

-- line #3278
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATVALIP 10 (Chemo Bio.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATVALIP 10 (Chemo Bio.)'
);

-- line #3279
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATVAS 10 (Cadila Ph.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATVAS 10 (Cadila Ph.)'
);

-- line #3280
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Atorvastatin', u'always_empty': u'', u'form': u'', u'brand': u'ATVAST', u'strength_3': u'', u'company': u'NEO CC.', u'unit': u''}

-- line #3281
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATVATIN 10 (VIVA HC.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATVATIN 10 (VIVA HC.)'
);

-- line #3282
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATV 10 (Zee Lab)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATV 10 (Zee Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATV 20 (Zee Lab)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATV 20 (Zee Lab)'
);

-- line #3283
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVASCARE 5 (QCHECK)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVASCARE 5 (QCHECK)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVASCARE 10 (QCHECK)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVASCARE 10 (QCHECK)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVASCARE 20 (QCHECK)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVASCARE 20 (QCHECK)'
);

-- line #3284
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'80', u'strength_2': u'', u'substance': u'Atorvastatin', u'always_empty': u'', u'form': u'', u'brand': u'AVAS', u'strength_3': u'', u'company': u'Micro Labs', u'unit': u'mg'}

-- line #3285
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVAS 10 (Carsyon)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVAS 10 (Carsyon)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVAS 20 (Carsyon)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVAS 20 (Carsyon)'
);

-- line #3286
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVAS 40 (Carsyon)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVAS 40 (Carsyon)'
);

-- line #3287
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVAS 5 (Carsyon)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVAS 5 (Carsyon)'
);

-- line #3288
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVASTIN 10 (Mano)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVASTIN 10 (Mano)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVASTIN 20 (Mano)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVASTIN 20 (Mano)'
);

-- line #3289
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVASTIN 5 (Mano)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVASTIN 5 (Mano)'
);

-- line #3290
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVASTRAL 20 (MOVA PH.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVASTRAL 20 (MOVA PH.)'
);

-- line #3291
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVASTRAL 5 (MOVA PH.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVASTRAL 5 (MOVA PH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVASTRAL 10 (MOVA PH.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVASTRAL 10 (MOVA PH.)'
);

-- line #3292
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'A-VIN 10 (Bestochem)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'A-VIN 10 (Bestochem)'
);

-- line #3293
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVISTATIN 10 (AVINASH)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVISTATIN 10 (AVINASH)'
);

-- line #3294
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZERVA 10 (Intas)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZERVA 10 (Intas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZERVA 20 (Intas)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZERVA 20 (Intas)'
);

-- line #3295
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZERVA 40 (Intas)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZERVA 40 (Intas)'
);

-- line #3296
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZTOR 10 (Sun)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZTOR 10 (Sun)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZTOR 20 (Sun)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZTOR 20 (Sun)'
);

-- line #3297
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZTOR 20 (Sun)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZTOR 20 (Sun)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZTOR 40 (Sun)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZTOR 40 (Sun)'
);

-- line #3298
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZTRO 80 (Sun)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZTRO 80 (Sun)'
);

-- line #3299
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BAROSTATIN 10 (BARODA)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BAROSTATIN 10 (BARODA)'
);

-- line #3300
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAAT 10 (Piramal Hc.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAAT 10 (Piramal Hc.)'
);

-- line #3301
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAAT 20 (Piramal Hc.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAAT 20 (Piramal Hc.)'
);

-- line #3302
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAAT 40 (Piramal Hc.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAAT 40 (Piramal Hc.)'
);

-- line #3303
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARATO 10 (Saga Lab)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARATO 10 (Saga Lab)'
);

-- line #3304
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDIO 10 (Radix Bio.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDIO 10 (Radix Bio.)'
);

-- line #3305
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDISTAT 10 (Biological E.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDISTAT 10 (Biological E.)'
);

-- line #3306
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHOLECHEK 10 (Radius)',
	'ATORVASTATIN',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHOLECHEK 10 (Radius)'
);

-- line #3307
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHOLECHEK 20 (Radius)',
	'ATORVASTATIN',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHOLECHEK 20 (Radius)'
);

-- line #3308
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHOLESTAT 10 (Kopran)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHOLESTAT 10 (Kopran)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHOLESTAT 20 (Kopran)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHOLESTAT 20 (Kopran)'
);

-- line #3309
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIPOLIP 10 (Win-Medicare)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIPOLIP 10 (Win-Medicare)'
);

-- line #3310
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIPOLIP 20 (Win-Medicare)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIPOLIP 20 (Win-Medicare)'
);

-- line #3311
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DISPITOR 10 (LA RENON)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DISPITOR 10 (LA RENON)'
);

-- line #3312
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DISPITOR 20 (LA RENON)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DISPITOR 20 (LA RENON)'
);

-- line #3313
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYSLIP 10 (EAST WEST)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYSLIP 10 (EAST WEST)'
);

-- line #3314
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYSLIP 20 (EAST WEST)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYSLIP 20 (EAST WEST)'
);

-- line #3315
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYSLIP 5 (EAST WEST)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYSLIP 5 (EAST WEST)'
);

-- line #3316
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYSLIPTIN 20 (EAST WEST)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'40'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYSLIPTIN 20 (EAST WEST)'
);

-- line #3317
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYSLIPTIN 5 (EAST WEST)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'10'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYSLIPTIN 5 (EAST WEST)'
);

-- line #3318
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYSTATIN 10 (Dynamic)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYSTATIN 10 (Dynamic)'
);

-- line #3319
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40', u'strength_2': u'', u'substance': u'Atorvastatin', u'always_empty': u'', u'form': u'', u'brand': u'ECOTOR', u'strength_3': u'', u'company': u'ECON HC.', u'unit': u'mg'}

-- line #3320
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ECOTOR 10 (ECON HC.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ECOTOR 10 (ECON HC.)'
);

-- line #3321
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ECOTOR 20 (ECON HC.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ECOTOR 20 (ECON HC.)'
);

-- line #3322
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELVAS 10 (Captab)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELVAS 10 (Captab)'
);

-- line #3323
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELVAS 20 (Captab)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELVAS 20 (Captab)'
);

-- line #3324
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENTOR 10 (ENRICH PH.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENTOR 10 (ENRICH PH.)'
);

-- line #3325
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENTOR 20 (ENRICH PH.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENTOR 20 (ENRICH PH.)'
);

-- line #3326
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETERNEX 10 (DABUR PH.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETERNEX 10 (DABUR PH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETERNEX 20 (DABUR PH.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETERNEX 20 (DABUR PH.)'
);

-- line #3327
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETERNEX 40 (DABUR PH.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETERNEX 40 (DABUR PH.)'
);

-- line #3328
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATOVAS 10 (CMGBT)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATOVAS 10 (CMGBT)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATOVAS 20 (CMGBT)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATOVAS 20 (CMGBT)'
);

-- line #3329
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENLIP 10 (GENESIS)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENLIP 10 (GENESIS)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENLIP 20 (GENESIS)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENLIP 20 (GENESIS)'
);

-- line #3330
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENXVAST 10 (GENX)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENXVAST 10 (GENX)'
);

-- line #3331
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENXVAST 20 (GENX)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENXVAST 20 (GENX)'
);

-- line #3332
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENXVAST 5 (GENX)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENXVAST 5 (GENX)'
);

-- line #3333
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GOSTAT 10 (Badrivas)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GOSTAT 10 (Badrivas)'
);

-- line #3334
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JVASTOR 20 (Sanify)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JVASTOR 20 (Sanify)'
);

-- line #3335
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KLOFIT 10 (AXYZEN LIFE)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KLOFIT 10 (AXYZEN LIFE)'
);

-- line #3336
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LATIN 10 (Siomond)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LATIN 10 (Siomond)'
);

-- line #3337
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LDTOR 10 (Torrent)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LDTOR 10 (Torrent)'
);

-- line #3338
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LDTOR 20 (Torrent)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LDTOR 20 (Torrent)'
);

-- line #3339
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LDTOR 5 (Torrent)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LDTOR 5 (Torrent)'
);

-- line #3340
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEOVAS 10 (Phytochem)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEOVAS 10 (Phytochem)'
);

-- line #3341
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LESSKAA 10 (Troikaa)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LESSKAA 10 (Troikaa)'
);

-- line #3342
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LESSKAA 20 (Troikaa)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LESSKAA 20 (Troikaa)'
);

-- line #3343
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LESSTROL 10 (Troikaa)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LESSTROL 10 (Troikaa)'
);

-- line #3344
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LESSTROL 20 (Troikaa)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LESSTROL 20 (Troikaa)'
);

-- line #3345
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LESSTROL 5 (Troikaa)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LESSTROL 5 (Troikaa)'
);

-- line #3346
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LILO 10 (Gsk)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LILO 10 (Gsk)'
);

-- line #3347
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LILO 20 (Gsk)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LILO 20 (Gsk)'
);

-- line #3348
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'ATORVastatin', u'always_empty': u'', u'form': u'TAB', u'brand': u'LIPICALM', u'strength_3': u'', u'company': u'Votary Lab', u'unit': u''}

-- line #3349
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPICHEK 10 (Indi Ph.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPICHEK 10 (Indi Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPICHEK 20 (Indi Ph.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPICHEK 20 (Indi Ph.)'
);

-- line #3350
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPICON 10 (CONCERTINA)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPICON 10 (CONCERTINA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPICON 20 (CONCERTINA)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPICON 20 (CONCERTINA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPICON 30 (CONCERTINA)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPICON 30 (CONCERTINA)'
);

-- line #3351
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPICOR 20 (Intas)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPICOR 20 (Intas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPICOR 40 (Intas)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPICOR 40 (Intas)'
);

-- line #3352
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPICOR 5 (Intas)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPICOR 5 (Intas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPICOR 10 (Intas)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPICOR 10 (Intas)'
);

-- line #3353
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPICURE 10 (INTAS)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPICURE 10 (INTAS)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPICURE 20 (INTAS)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPICURE 20 (INTAS)'
);

-- line #3354
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPICURE 10 (Intas)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPICURE 10 (Intas)'
);

-- line #3355
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPICURE 40 (INTAS)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPICURE 40 (INTAS)'
);

-- line #3356
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPICURE 5 (INTAS)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPICURE 5 (INTAS)'
);

-- line #3357
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPICURE 80 (Intas)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPICURE 80 (Intas)'
);

-- line #3358
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPIDROP 10 (Sresan Ph.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPIDROP 10 (Sresan Ph.)'
);

-- line #3359
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPIGOAL 10 (Nicholas)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPIGOAL 10 (Nicholas)'
);

-- line #3360
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPIGOAL 20 (Nicholas)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPIGOAL 20 (Nicholas)'
);

-- line #3361
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPIKIND 10 (Mankind)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPIKIND 10 (Mankind)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPIKIND 20 (Mankind)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPIKIND 20 (Mankind)'
);

-- line #3362
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPILES 10 (Indchemie)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPILES 10 (Indchemie)'
);

-- line #3363
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPILES 20 (Indchemie)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPILES 20 (Indchemie)'
);

-- line #3364
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPINA 10 (WEST COAST)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPINA 10 (WEST COAST)'
);

-- line #3365
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPINA 20 (WEST COAST)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPINA 20 (WEST COAST)'
);

-- line #3366
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPIRA 10 (Emcure)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPIRA 10 (Emcure)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPIRA 20 (Emcure)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPIRA 20 (Emcure)'
);

-- line #3367
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPIRA 40 (Emcure)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPIRA 40 (Emcure)'
);

-- line #3368
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPIRA 5 (Emcure)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPIRA 5 (Emcure)'
);

-- line #3369
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPIROL 20 (TAJ PH.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPIROL 20 (TAJ PH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPIROL 40 (TAJ PH.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPIROL 40 (TAJ PH.)'
);

-- line #3370
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPIROL 5 (TAJ PH.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPIROL 5 (TAJ PH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPIROL 10 (TAJ PH.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPIROL 10 (TAJ PH.)'
);

-- line #3371
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPITAB-10 10 (HBC LIFESCIENCE)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPITAB-10 10 (HBC LIFESCIENCE)'
);

-- line #3372
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPITAB-20 20 (HBC LIFESCIENCE)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPITAB-20 20 (HBC LIFESCIENCE)'
);

-- line #3373
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPITAB-40 40 (HBC LIFESCIENCE)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPITAB-40 40 (HBC LIFESCIENCE)'
);

-- line #3374
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPITAB 10 (Meyer Org.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPITAB 10 (Meyer Org.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPITAB 20 (Meyer Org.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPITAB 20 (Meyer Org.)'
);

-- line #3375
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPIVAS-10 10 (Elder)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPIVAS-10 10 (Elder)'
);

-- line #3376
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPIVAS 20 (Elder)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPIVAS 20 (Elder)'
);

-- line #3377
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPOFIX 10 (Bal Ph.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPOFIX 10 (Bal Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPOFIX 20 (Bal Ph.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPOFIX 20 (Bal Ph.)'
);

-- line #3378
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPOFIX 5 (Bal Ph.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPOFIX 5 (Bal Ph.)'
);

-- line #3379
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPONORM 10 (Blue Cross)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPONORM 10 (Blue Cross)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPONORM 20 (Blue Cross)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPONORM 20 (Blue Cross)'
);

-- line #3380
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPONORM 40 (Blue Cross)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPONORM 40 (Blue Cross)'
);

-- line #3381
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPONORM 5 (Blue Cross)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPONORM 5 (Blue Cross)'
);

-- line #3382
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPOREST 10 (Centaur)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPOREST 10 (Centaur)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPOREST 20 (Centaur)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPOREST 20 (Centaur)'
);

-- line #3383
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPOZAC 10 (Torrent)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPOZAC 10 (Torrent)'
);

-- line #3384
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPOZAC 20 (Torrent)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPOZAC 20 (Torrent)'
);

-- line #3385
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPVAS 10 (Cipla)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPVAS 10 (Cipla)'
);

-- line #3386
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPVAS 20 (Cipla)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPVAS 20 (Cipla)'
);

-- line #3387
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPVAS 40 (Cipla)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPVAS 40 (Cipla)'
);

-- line #3388
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LLA 10 (Colinz Lab)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LLA 10 (Colinz Lab)'
);

-- line #3389
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOLIP-10 10 (Kamron)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOLIP-10 10 (Kamron)'
);

-- line #3390
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOLIP-5 5 (Kamron)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOLIP-5 5 (Kamron)'
);

-- line #3391
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOWER-A 10 (Panacea)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOWER-A 10 (Panacea)'
);

-- line #3392
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOWER-A 20 (Panacea)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOWER-A 20 (Panacea)'
);

-- line #3393
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACTOR 10 (Macleods)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACTOR 10 (Macleods)'
);

-- line #3394
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACTOR 20 (Macleods)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACTOR 20 (Macleods)'
);

-- line #3395
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACTOR 40 (MACLEODS)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACTOR 40 (MACLEODS)'
);

-- line #3396
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MINISTAT 10 (UNI OR.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MINISTAT 10 (UNI OR.)'
);

-- line #3397
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MODLIP 10 (Torrent)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MODLIP 10 (Torrent)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MODLIP 20 (Torrent)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MODLIP 20 (Torrent)'
);

-- line #3398
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MODLIP 40 (Torrent)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MODLIP 40 (Torrent)'
);

-- line #3399
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MODLIP 5 (Torrent)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MODLIP 5 (Torrent)'
);

-- line #3400
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MODLIP 80 (Torrent)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MODLIP 80 (Torrent)'
);

-- line #3401
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOTORVA 40 (USV CONDOR)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOTORVA 40 (USV CONDOR)'
);

-- line #3402
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOTORVA 5 (USV CONDOR)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOTORVA 5 (USV CONDOR)'
);

-- line #3403
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOTROVA 10 (U S V)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOTROVA 10 (U S V)'
);

-- line #3404
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOTROVA 20 (U S V)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOTROVA 20 (U S V)'
);

-- line #3405
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOTROVA 5 (U S V)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOTROVA 5 (U S V)'
);

-- line #3406
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOCLOG 10 (NEISS)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOCLOG 10 (NEISS)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOCLOG 20 (NEISS)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOCLOG 20 (NEISS)'
);

-- line #3407
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUSTAT 10 (Ordain Hc.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUSTAT 10 (Ordain Hc.)'
);

-- line #3408
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUSTAT 5 (Ordain Hc.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUSTAT 5 (Ordain Hc.)'
);

-- line #3409
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLTROVA 10 (Olcare)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLTROVA 10 (Olcare)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLTROVA 20 (Olcare)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLTROVA 20 (Olcare)'
);

-- line #3410
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLTROVA 40 (Olcare)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLTROVA 40 (Olcare)'
);

-- line #3411
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMNITOR 5 (CIPLA)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMNITOR 5 (CIPLA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMNITOR 10 (CIPLA)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMNITOR 10 (CIPLA)'
);

-- line #3412
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORVAS-10 10 (Systopic)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORVAS-10 10 (Systopic)'
);

-- line #3413
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORVAS-20 20 (Systopic)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORVAS-20 20 (Systopic)'
);

-- line #3414
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORVAS 5 (Systopic)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORVAS 5 (Systopic)'
);

-- line #3415
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORVASTIN 10 (Morepen)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORVASTIN 10 (Morepen)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORVASTIN 20 (Morepen)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORVASTIN 20 (Morepen)'
);

-- line #3416
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSTIN 10 (Osper)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSTIN 10 (Osper)'
);

-- line #3417
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OZOVAS 10 (Ozone Ph.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OZOVAS 10 (Ozone Ph.)'
);

-- line #3418
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OZOVAS 20 (Ozone Ph.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OZOVAS 20 (Ozone Ph.)'
);

-- line #3419
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OZOVAS 40 (Ozone Ph.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OZOVAS 40 (Ozone Ph.)'
);

-- line #3420
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PDVAS 10 (Pharma Drugs)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PDVAS 10 (Pharma Drugs)'
);

-- line #3421
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLEOSTIN 10 (Mano)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLEOSTIN 10 (Mano)'
);

-- line #3422
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLEOSTIN 20 (Mano)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLEOSTIN 20 (Mano)'
);

-- line #3423
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLEOSTIN 5 (Mano)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLEOSTIN 5 (Mano)'
);

-- line #3424
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLEOTOR 10 (Ipca)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLEOTOR 10 (Ipca)'
);

-- line #3425
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLEOTOR 20 (Ipca)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLEOTOR 20 (Ipca)'
);

-- line #3426
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLEOTOR 40 (Ipca)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLEOTOR 40 (Ipca)'
);

-- line #3427
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLEOTOR 5 (Ipca)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLEOTOR 5 (Ipca)'
);

-- line #3428
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POLYCARD 5 (Troikaa)',
	'Atorvastatin',
	'CAP',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POLYCARD 5 (Troikaa)'
);

-- line #3429
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QEST 10 (Ind-Swift)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QEST 10 (Ind-Swift)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QEST 20 (Ind-Swift)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QEST 20 (Ind-Swift)'
);

-- line #3430
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REDUSTAT 10 (RHINE BIO.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REDUSTAT 10 (RHINE BIO.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REDUSTAT 20 (RHINE BIO.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REDUSTAT 20 (RHINE BIO.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REDUSTAT 40 (RHINE BIO.)',
	'Atorvastatin',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REDUSTAT 40 (RHINE BIO.)'
);

-- line #3431
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACRIS 10 (Gland Ph.)',
	'Atracurium Besylate',
	'AMP',
	gm.nullify_empty_string('10')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACRIS 10 (Gland Ph.)'
);

-- line #3432
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACRIS 25 (Gland Ph.)',
	'Atracurium Besylate',
	'AMP',
	gm.nullify_empty_string('25')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACRIS 25 (Gland Ph.)'
);

-- line #3433
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALCURON 10 (ALEMBIC)',
	'Atracurium Besylate',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALCURON 10 (ALEMBIC)'
);

-- line #3434
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARIUM 25 (CELON(REVILON))',
	'Atracurium Besylate',
	'AMP',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARIUM 25 (CELON(REVILON))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARIUM 50 (CELON(REVILON))',
	'Atracurium Besylate',
	'AMP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARIUM 50 (CELON(REVILON))'
);

-- line #3435
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARTACIL 10 (Neon)',
	'Atracurium Besylate',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARTACIL 10 (Neon)'
);

-- line #3436
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARTACIL 50 (Neon)',
	'Atracurium Besylate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARTACIL 50 (Neon)'
);

-- line #3437
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARTACIL 10 (Neon)',
	'Atracurium Besylate',
	'VIAL',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARTACIL 10 (Neon)'
);

-- line #3438
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATCURIUM 25 (CH.Bhagat)',
	'Atracurium Besylate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATCURIUM 25 (CH.Bhagat)'
);

-- line #3439
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATRAGER 10 (German R.)',
	'Atracurium Besylate',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATRAGER 10 (German R.)'
);

-- line #3440
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATRELAX 10 (Nicholas)',
	'Atracurium Besylate',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATRELAX 10 (Nicholas)'
);

-- line #3441
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUMBLOK 100 (ZENOTECH LAB.)',
	'Atracurium Besylate',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/10ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUMBLOK 100 (ZENOTECH LAB.)'
);

-- line #3442
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUMBLOK 25 (ZENOTECH LAB.)',
	'Atracurium Besylate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/2.5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUMBLOK 25 (ZENOTECH LAB.)'
);

-- line #3443
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUMBLOK 50 (ZENOTECH LAB.)',
	'Atracurium Besylate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUMBLOK 50 (ZENOTECH LAB.)'
);

-- line #3444
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATP 0.6 (BIOMIICRON)',
	'Atropine',
	'AMP',
	gm.nullify_empty_string('0.6')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATP 0.6 (BIOMIICRON)'
);

-- line #3445
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Atropine', u'always_empty': u'', u'form': u'INJ', u'brand': u'ATRI', u'strength_3': u'', u'company': u'PREM PH.', u'unit': u''}

-- line #3446
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATROPINE SULPHATE 6 (Samarth)',
	'Atropine',
	'INJ',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATROPINE SULPHATE 6 (Samarth)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATROPINE SULPHATE 30 (Samarth)',
	'Atropine',
	'INJ',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATROPINE SULPHATE 30 (Samarth)'
);

-- line #3447
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATRO 1 (Intas)',
	'Atropine Sulph.',
	'DPS',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATRO 1 (Intas)'
);

-- line #3448
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATRONEX 0.6 (Indus)',
	'Atropine Sulph.',
	'INJ',
	gm.nullify_empty_string('0.6')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATRONEX 0.6 (Indus)'
);

-- line #3449
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATRO 1 (Intas)',
	'Atropine Sulph.',
	'OINT',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATRO 1 (Intas)'
);

-- line #3450
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATROPINE 1 (Andre)',
	'Atropine Sulph.',
	'EYE OINT',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATROPINE 1 (Andre)'
);

-- line #3451
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BELLPINO ATRIN 1 (Bell Ph.)',
	'Atropine Sulph.',
	'DPS',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BELLPINO ATRIN 1 (Bell Ph.)'
);

-- line #3452
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BELLPINO ATRIN 1 (Bell Ph.)',
	'Atropine Sulph.',
	'OINT',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BELLPINO ATRIN 1 (Bell Ph.)'
);

-- line #3453
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GOLDAR 3 (Zydus Cadila)',
	'Auranofin',
	'TAB',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GOLDAR 3 (Zydus Cadila)'
);

-- line #3454
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIDAURA 3 (Gsk)',
	'Auranofin',
	'TAB',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIDAURA 3 (Gsk)'
);

-- line #3455
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'TAB', u'brand': u'ABANA', u'strength_3': u'', u'company': u'Himalaya', u'unit': u''}

-- line #3456
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'CAP', u'brand': u'ABIOTIC', u'strength_3': u'', u'company': u'RND LAB', u'unit': u''}

-- line #3457
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'GRAN', u'brand': u'ACTIVAL', u'strength_3': u'', u'company': u'Fem care', u'unit': u''}

-- line #3458
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'OIL', u'brand': u'AD BABY', u'strength_3': u'', u'company': u'ZIMALAYA', u'unit': u''}

-- line #3459
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'CAP', u'brand': u'ADDYZOA', u'strength_3': u'', u'company': u'Charak', u'unit': u''}

-- line #3460
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALSAREX', u'strength_3': u'', u'company': u'Charak', u'unit': u''}

-- line #3461
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'OIL', u'brand': u'AMPUCARE', u'strength_3': u'', u'company': u'Venus Rem.', u'unit': u''}

-- line #3462
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'CAP', u'brand': u'ANAPROCT', u'strength_3': u'', u'company': u'Ind-Swift', u'unit': u''}

-- line #3463
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'TAB', u'brand': u'APTIVATE-OS', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #3464
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'SYR', u'brand': u'APTIVATE', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #3465
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'SYR', u'brand': u'APTIZOOOM', u'strength_3': u'', u'company': u'Charak', u'unit': u''}

-- line #3466
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'TAB', u'brand': u'ARJIN', u'strength_3': u'', u'company': u'Alarsin', u'unit': u''}

-- line #3467
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'CAP', u'brand': u'ARJUNIN', u'strength_3': u'', u'company': u'Charak', u'unit': u''}

-- line #3468
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'OINT', u'brand': u'ARSHONYT', u'strength_3': u'', u'company': u'Charak', u'unit': u''}

-- line #3469
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'TAB', u'brand': u'ARSHONYT', u'strength_3': u'', u'company': u'Charak', u'unit': u''}

-- line #3470
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'OINT', u'brand': u'ARTHRELLA', u'strength_3': u'', u'company': u'Charak', u'unit': u''}

-- line #3471
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'TAB', u'brand': u'ARTHRELLA', u'strength_3': u'', u'company': u'Charak', u'unit': u''}

-- line #3472
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'F. CAP', u'brand': u'ARTHRILL', u'strength_3': u'', u'company': u'Ind-Swift', u'unit': u''}

-- line #3473
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'', u'brand': u'ARTHRILL', u'strength_3': u'', u'company': u'Ind-Swift', u'unit': u''}

-- line #3474
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'CAP/SYR', u'brand': u'ASTHA-15', u'strength_3': u'', u'company': u'Dalmia Hc.', u'unit': u''}

-- line #3475
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'SYRUP', u'brand': u'ATTENTIO', u'strength_3': u'', u'company': u'Dalmia Hc.', u'unit': u''}

-- line #3476
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'TAB', u'brand': u'AYAPON', u'strength_3': u'', u'company': u'Alarsin', u'unit': u''}

-- line #3477
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'TAB', u'brand': u'BANGSHIL', u'strength_3': u'', u'company': u'Alarsin', u'unit': u''}

-- line #3478
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'OIL', u'brand': u'BESTOGESIC', u'strength_3': u'', u'company': u'Bestochem', u'unit': u''}

-- line #3479
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'DPS/LIQ', u'brand': u'BONNISAN', u'strength_3': u'', u'company': u'Himalaya', u'unit': u''}

-- line #3480
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'DPS', u'brand': u'BONNISPAZ', u'strength_3': u'', u'company': u'Himalaya', u'unit': u''}

-- line #3481
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'', u'brand': u'BRESOL', u'strength_3': u'', u'company': u'Himalaya', u'unit': u''}

-- line #3482
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'TAB', u'brand': u'BRESOL', u'strength_3': u'', u'company': u'Himalaya', u'unit': u''}

-- line #3483
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'TAB', u'brand': u'CALCURY', u'strength_3': u'', u'company': u'Charak', u'unit': u''}

-- line #3484
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'SYR', u'brand': u'CEBROTONE', u'strength_3': u'', u'company': u'Fem care', u'unit': u''}

-- line #3485
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'DPS', u'brand': u'CEPHAGRAINE NASAL', u'strength_3': u'', u'company': u'Charak', u'unit': u''}

-- line #3486
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'TAB', u'brand': u'CEPHAGRAINE', u'strength_3': u'', u'company': u'Charak', u'unit': u''}

-- line #3487
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'CRM', u'brand': u'CLARINA', u'strength_3': u'', u'company': u'Himalaya', u'unit': u''}

-- line #3488
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'', u'brand': u'COMFORT PAIN BALM', u'strength_3': u'', u'company': u'Cadila Ph.', u'unit': u''}

-- line #3489
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'TAB', u'brand': u'CONFIDO', u'strength_3': u'', u'company': u'Himalaya', u'unit': u''}

-- line #3490
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'SYR', u'brand': u'CYSTONE', u'strength_3': u'', u'company': u'Himalaya', u'unit': u''}

-- line #3491
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'TAB', u'brand': u'CYSTONE', u'strength_3': u'', u'company': u'Himalaya', u'unit': u''}

-- line #3492
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'CAP', u'brand': u'CYTOZEN', u'strength_3': u'', u'company': u'Charak', u'unit': u''}

-- line #3493
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'CAP', u'brand': u'DAASH', u'strength_3': u'', u'company': u'Themis Med.', u'unit': u''}

-- line #3494
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'CRM', u'brand': u'DEEPACT', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #3495
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'TAB', u'brand': u'DIABECON', u'strength_3': u'', u'company': u'Himalaya', u'unit': u''}

-- line #3496
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'', u'brand': u'DIAKOF LINCTUS', u'strength_3': u'', u'company': u'Himalaya', u'unit': u''}

-- line #3497
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'TAB', u'brand': u'DIAREX', u'strength_3': u'', u'company': u'Himalaya', u'unit': u''}

-- line #3498
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'CAP', u'brand': u'DISTONE', u'strength_3': u'', u'company': u'Ind-Swift', u'unit': u''}

-- line #3499
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'SYR', u'brand': u'DISTONE', u'strength_3': u'', u'company': u'Ind-Swift', u'unit': u''}

-- line #3500
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'SYR', u'brand': u'EAT EASE', u'strength_3': u'', u'company': u'Ranbaxy G.', u'unit': u''}

-- line #3501
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'SYR', u'brand': u'ENTROPS', u'strength_3': u'', u'company': u'J & J DeChane', u'unit': u''}

-- line #3502
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'LIQ', u'brand': u'ENTROSTAT', u'strength_3': u'', u'company': u'Dalmia Hc.', u'unit': u''}

-- line #3503
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'CAP', u'brand': u'EVANOVA', u'strength_3': u'', u'company': u'Charak', u'unit': u''}

-- line #3504
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'CAP', u'brand': u'EVECARE', u'strength_3': u'', u'company': u'Himalaya', u'unit': u''}

-- line #3505
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'SYR', u'brand': u'EVECARE', u'strength_3': u'', u'company': u'Himalaya', u'unit': u''}

-- line #3506
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'SYR', u'brand': u'EXTRAMMUNE', u'strength_3': u'', u'company': u'Charak', u'unit': u''}

-- line #3507
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'TAB', u'brand': u'EXTRAMMUNE', u'strength_3': u'', u'company': u'Charak', u'unit': u''}

-- line #3508
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'CAP', u'brand': u'FEMARELLE', u'strength_3': u'', u'company': u'Svizera', u'unit': u''}

-- line #3509
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'F. TAB', u'brand': u'FEMI', u'strength_3': u'', u'company': u'Charak', u'unit': u''}

-- line #3510
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'TAB', u'brand': u'FEMIPLEX', u'strength_3': u'', u'company': u'Charak', u'unit': u''}

-- line #3511
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'CAP', u'brand': u'FLUSH', u'strength_3': u'', u'company': u'RND LAB', u'unit': u''}

-- line #3512
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'SYR', u'brand': u'FLUSH', u'strength_3': u'', u'company': u'RND LAB', u'unit': u''}

-- line #3513
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'TAB', u'brand': u'FORTEGE', u'strength_3': u'', u'company': u'Alarsin', u'unit': u''}

-- line #3514
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'TAB', u'brand': u'FULL', u'strength_3': u'', u'company': u'Emcure', u'unit': u''}

-- line #3515
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'TAB', u'brand': u'G-32', u'strength_3': u'', u'company': u'Alarsin', u'unit': u''}

-- line #3516
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'TAB', u'brand': u'GALAKOL', u'strength_3': u'', u'company': u'Charak', u'unit': u''}

-- line #3517
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'TAB', u'brand': u'GARLILL', u'strength_3': u'', u'company': u'Charak', u'unit': u''}

-- line #3518
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'SYR', u'brand': u'GASEX', u'strength_3': u'', u'company': u'Himalaya', u'unit': u''}

-- line #3519
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'TAB', u'brand': u'GASEX', u'strength_3': u'', u'company': u'Himalaya', u'unit': u''}

-- line #3520
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'DPS', u'brand': u'GASTICA', u'strength_3': u'', u'company': u'Mankind', u'unit': u''}

-- line #3521
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'TAB', u'brand': u'GASTICA PLUS', u'strength_3': u'', u'company': u'Mankind', u'unit': u''}

-- line #3522
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'SYR', u'brand': u'GECITRAL', u'strength_3': u'', u'company': u'RND LAB', u'unit': u''}

-- line #3523
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'TAB/SYR', u'brand': u'GERIFORTE', u'strength_3': u'', u'company': u'Himalaya', u'unit': u''}

-- line #3524
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'CAP', u'brand': u'GGG', u'strength_3': u'', u'company': u'Sali Hc.', u'unit': u''}

-- line #3525
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'CAP', u'brand': u'GLOWSUN', u'strength_3': u'', u'company': u'Bestochem', u'unit': u''}

-- line #3526
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'TAB', u'brand': u'GLUDIBIT', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #3527
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'GEL', u'brand': u'GUM TONE', u'strength_3': u'', u'company': u'Charak', u'unit': u''}

-- line #3528
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'POW', u'brand': u'GUM TONE', u'strength_3': u'', u'company': u'Charak', u'unit': u''}

-- line #3529
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'LIQD', u'brand': u'GYNEDOL', u'strength_3': u'', u'company': u'Dwd', u'unit': u''}

-- line #3530
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'TAB', u'brand': u'GYNEDOL', u'strength_3': u'', u'company': u'Dwd', u'unit': u''}

-- line #3531
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'SYR', u'brand': u'GYNODEX', u'strength_3': u'', u'company': u'ZIMALAYA', u'unit': u''}

-- line #3532
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'SYR', u'brand': u'GYNOSET', u'strength_3': u'', u'company': u'SIGNOVA', u'unit': u''}

-- line #3533
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'SYR', u'brand': u'HALEEZY', u'strength_3': u'', u'company': u'Charak', u'unit': u''}

-- line #3534
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'GEL', u'brand': u'HEALPLUS', u'strength_3': u'', u'company': u'Sanat', u'unit': u''}

-- line #3535
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'SYR', u'brand': u'HEPACEF', u'strength_3': u'', u'company': u'Concept', u'unit': u''}

-- line #3536
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'TAB', u'brand': u'HEPACEF', u'strength_3': u'', u'company': u'Concept', u'unit': u''}

-- line #3537
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'TAB', u'brand': u'HEPATINIC', u'strength_3': u'', u'company': u"Dr.Reddy''S", u'unit': u''}

-- line #3538
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'OINT', u'brand': u'HERBINOL', u'strength_3': u'', u'company': u'Zydus Cadila', u'unit': u''}

-- line #3539
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'TAB', u'brand': u'HERBOHEP', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #3540
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'CAP', u'brand': u'HERBOLAX', u'strength_3': u'', u'company': u'Himalaya', u'unit': u''}

-- line #3541
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'TAB', u'brand': u'HERBOLAX', u'strength_3': u'', u'company': u'Himalaya', u'unit': u''}

-- line #3542
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'SYR', u'brand': u'HERR', u'strength_3': u'', u'company': u'RND LAB', u'unit': u''}

-- line #3543
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'SYR', u'brand': u'HIMCOCID', u'strength_3': u'', u'company': u'Himalaya', u'unit': u''}

-- line #3544
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'TAB', u'brand': u'HIMCOCID', u'strength_3': u'', u'company': u'Himalaya', u'unit': u''}

-- line #3545
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'GEL', u'brand': u'HIMCOLIN', u'strength_3': u'', u'company': u'Himalaya', u'unit': u''}

-- line #3546
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'CAP', u'brand': u'HIMCOSPAZ SOFT', u'strength_3': u'', u'company': u'Himalaya', u'unit': u''}

-- line #3547
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'TAB', u'brand': u'HIMPLASIA', u'strength_3': u'', u'company': u'Himalaya', u'unit': u''}

-- line #3548
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'SYR', u'brand': u'HONITUS', u'strength_3': u'', u'company': u'Dabur Ph.', u'unit': u''}

-- line #3549
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'TAB', u'brand': u'HYPONIDD', u'strength_3': u'', u'company': u'Charak', u'unit': u''}

-- line #3550
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'SYR', u'brand': u'IQMEM', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #3551
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'CAP', u'brand': u'JOINTIL', u'strength_3': u'', u'company': u'Sanat', u'unit': u''}

-- line #3552
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'OIL', u'brand': u'JOINTOP', u'strength_3': u'', u'company': u'INTRA(INVENTURE)', u'unit': u''}

-- line #3553
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'CAP', u'brand': u'KARNIM', u'strength_3': u'', u'company': u'Un.MEDIKIT', u'unit': u''}

-- line #3554
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'SYR', u'brand': u'KOFAREST-H', u'strength_3': u'', u'company': u'Centaur', u'unit': u''}

-- line #3555
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'LOZENGE', u'brand': u'KOFLET', u'strength_3': u'', u'company': u'Himalaya', u'unit': u''}

-- line #3556
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'SYR', u'brand': u'KOFLET', u'strength_3': u'', u'company': u'Himalaya', u'unit': u''}

-- line #3557
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'SYR', u'brand': u'KOFOL', u'strength_3': u'', u'company': u'Charak', u'unit': u''}

-- line #3558
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'TAB', u'brand': u'KOFOL', u'strength_3': u'', u'company': u'Charak', u'unit': u''}

-- line #3559
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'SYR', u'brand': u'LACTACRAT', u'strength_3': u'', u'company': u'CRATUS', u'unit': u''}

-- line #3560
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'CAP', u'brand': u'LAFORTE', u'strength_3': u'', u'company': u'Jenburkt', u'unit': u''}

-- line #3561
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'CAP', u'brand': u'LAVIRIL', u'strength_3': u'', u'company': u'Jenburkt', u'unit': u''}

-- line #3562
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'SYR', u'brand': u'LEUKO-G', u'strength_3': u'', u'company': u'ZIMALAYA', u'unit': u''}

-- line #3563
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'OIL', u'brand': u'LIMA', u'strength_3': u'', u'company': u'ZIMALAYA', u'unit': u''}

-- line #3564
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'DROP', u'brand': u'LIV-52', u'strength_3': u'', u'company': u'Himalaya', u'unit': u''}

-- line #3565
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'DS SYR', u'brand': u'LIV-52', u'strength_3': u'', u'company': u'Himalaya', u'unit': u''}

-- line #3566
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'DS TAB', u'brand': u'LIV-52', u'strength_3': u'', u'company': u'Himalaya', u'unit': u''}

-- line #3567
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'SYR', u'brand': u'LIV-52', u'strength_3': u'', u'company': u'Himalaya', u'unit': u''}

-- line #3568
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'TAB', u'brand': u'LIV-52', u'strength_3': u'', u'company': u'Himalaya', u'unit': u''}

-- line #3569
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'LIQ', u'brand': u'LI-VERVE', u'strength_3': u'', u'company': u'CRATUS', u'unit': u''}

-- line #3570
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'DPS', u'brand': u'LIVOMYN', u'strength_3': u'', u'company': u'Charak', u'unit': u''}

-- line #3571
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'SYR', u'brand': u'LIVOMYN', u'strength_3': u'', u'company': u'Charak', u'unit': u''}

-- line #3572
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'TAB', u'brand': u'LIVOMYN', u'strength_3': u'', u'company': u'Charak', u'unit': u''}

-- line #3573
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'SYR', u'brand': u'LIVOSIL-H', u'strength_3': u'', u'company': u'Centaur', u'unit': u''}

-- line #3574
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'TAB', u'brand': u'LUKOL', u'strength_3': u'', u'company': u'Himalaya', u'unit': u''}

-- line #3575
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'CAP', u'brand': u'LUKURE', u'strength_3': u'', u'company': u'Ttk Hc.', u'unit': u''}

-- line #3576
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'CAP', u'brand': u'LUNAREX', u'strength_3': u'', u'company': u'Charak', u'unit': u''}

-- line #3577
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'F. SYR', u'brand': u'M2-TONE', u'strength_3': u'', u'company': u'Charak', u'unit': u''}

-- line #3578
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'SYR', u'brand': u'M2-TONE', u'strength_3': u'', u'company': u'Charak', u'unit': u''}

-- line #3579
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'TAB', u'brand': u'M2-TONE', u'strength_3': u'', u'company': u'Charak', u'unit': u''}

-- line #3580
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'CAP', u'brand': u'MANIX', u'strength_3': u'', u'company': u'Wockhardt', u'unit': u''}

-- line #3581
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'CAP', u'brand': u'MANOLL', u'strength_3': u'', u'company': u'Charak', u'unit': u''}

-- line #3582
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'', u'brand': u'MANOLL MALT', u'strength_3': u'', u'company': u'Charak', u'unit': u''}

-- line #3583
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'SYR', u'brand': u'MANOLL', u'strength_3': u'', u'company': u'Charak', u'unit': u''}

-- line #3584
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'SYR', u'brand': u'MEMTONE', u'strength_3': u'', u'company': u'Aimil Ph.', u'unit': u''}

-- line #3585
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'TAB', u'brand': u'MENOSAN', u'strength_3': u'', u'company': u'Himalaya', u'unit': u''}

-- line #3586
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'DS SYR', u'brand': u'MENTAT', u'strength_3': u'', u'company': u'Himalaya', u'unit': u''}

-- line #3587
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'SYR', u'brand': u'MENTAT', u'strength_3': u'', u'company': u'Himalaya', u'unit': u''}

-- line #3588
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'TAB', u'brand': u'MENTAT', u'strength_3': u'', u'company': u'Himalaya', u'unit': u''}

-- line #3589
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'SYR', u'brand': u'MENTOFER', u'strength_3': u'', u'company': u'SIGNOVA', u'unit': u''}

-- line #3590
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'CAP', u'brand': u'MILANO', u'strength_3': u'', u'company': u'Geno Ph.', u'unit': u''}

-- line #3591
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'TAB', u'brand': u'MUSTONG', u'strength_3': u'', u'company': u'Ttk Hc.', u'unit': u''}

-- line #3592
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'TAB', u'brand': u'MYRON', u'strength_3': u'', u'company': u'Alarsin', u'unit': u''}

-- line #3593
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'LIQD', u'brand': u'NAPTIZER', u'strength_3': u'', u'company': u'BARODA', u'unit': u''}

-- line #3594
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'F. TAB', u'brand': u'NED', u'strength_3': u'', u'company': u'Charak', u'unit': u''}

-- line #3595
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'', u'brand': u'NEERI (1000)TAB', u'strength_3': u'', u'company': u'Aimil Ph.', u'unit': u''}

-- line #3596
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'SYR', u'brand': u'NEERI', u'strength_3': u'', u'company': u'Aimil Ph.', u'unit': u''}

-- line #3597
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'TAB', u'brand': u'NEERI', u'strength_3': u'', u'company': u'Aimil Ph.', u'unit': u''}

-- line #3598
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'TAB', u'brand': u'NEO(SILVER)', u'strength_3': u'', u'company': u'Charak', u'unit': u''}

-- line #3599
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'TAB', u'brand': u'NEVROMINE', u'strength_3': u'', u'company': u'Franco I.', u'unit': u''}

-- line #3600
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'DPS', u'brand': u'NEW LIVFIT', u'strength_3': u'', u'company': u'Dabur Ph.', u'unit': u''}

-- line #3601
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'SYR', u'brand': u'NEW LIVFIT', u'strength_3': u'', u'company': u'Dabur Ph.', u'unit': u''}

-- line #3602
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'TAB', u'brand': u'NEW LIVFIT', u'strength_3': u'', u'company': u'Dabur Ph.', u'unit': u''}

-- line #3603
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'SYR', u'brand': u'N-ZYME', u'strength_3': u'', u'company': u'ALLENGE', u'unit': u''}

-- line #3604
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'TAB', u'brand': u'OBENYL', u'strength_3': u'', u'company': u'Charak', u'unit': u''}

-- line #3605
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'SYR', u'brand': u'OJUS', u'strength_3': u'', u'company': u'Charak', u'unit': u''}

-- line #3606
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'TAB', u'brand': u'OJUS', u'strength_3': u'', u'company': u'Charak', u'unit': u''}

-- line #3607
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'DROP', u'brand': u'OLESAN COUGH', u'strength_3': u'', u'company': u'Ranbaxy G.', u'unit': u''}

-- line #3608
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'COUGH SYR', u'brand': u'OLESAN', u'strength_3': u'', u'company': u'Ranbaxy G.', u'unit': u''}

-- line #3609
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'GEL', u'brand': u'OLESAN', u'strength_3': u'', u'company': u'Ranbaxy G.', u'unit': u''}

-- line #3610
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'OIL', u'brand': u'OLESAN', u'strength_3': u'', u'company': u'Ranbaxy G.', u'unit': u''}

-- line #3611
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'CAP', u'brand': u'ONE ALL', u'strength_3': u'', u'company': u'Taurus Lab', u'unit': u''}

-- line #3612
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'POW', u'brand': u'ONE ALL', u'strength_3': u'', u'company': u'Taurus Lab', u'unit': u''}

-- line #3613
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'CAP', u'brand': u'ONE BE', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #3614
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'DPS', u'brand': u'OPHTHACARE', u'strength_3': u'', u'company': u'Himalaya', u'unit': u''}

-- line #3615
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'TAB', u'brand': u'OSTOLIFE', u'strength_3': u'', u'company': u'Charak', u'unit': u''}

-- line #3616
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'CAP', u'brand': u'OXITARD', u'strength_3': u'', u'company': u'Himalaya', u'unit': u''}

-- line #3617
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'DPS', u'brand': u'PAEDRITONE', u'strength_3': u'', u'company': u'Charak', u'unit': u''}

-- line #3618
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'F. TAB', u'brand': u'PALLRYWYN', u'strength_3': u'', u'company': u'Charak', u'unit': u''}

-- line #3619
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'OINT', u'brand': u'PIGMENTO', u'strength_3': u'', u'company': u'Charak', u'unit': u''}

-- line #3620
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'TAB', u'brand': u'PIGMENTO', u'strength_3': u'', u'company': u'Charak', u'unit': u''}

-- line #3621
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'TAB (1000)', u'brand': u'PILACT', u'strength_3': u'', u'company': u'Aimil Ph.', u'unit': u''}

-- line #3622
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'TAB', u'brand': u'PILACT', u'strength_3': u'', u'company': u'Aimil Ph.', u'unit': u''}

-- line #3623
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'OINT', u'brand': u'PILEX', u'strength_3': u'', u'company': u'Himalaya', u'unit': u''}

-- line #3624
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'TAB', u'brand': u'PILEX', u'strength_3': u'', u'company': u'Himalaya', u'unit': u''}

-- line #3625
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'CAP', u'brand': u'PMENSA', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #3626
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'SYR', u'brand': u'PMENSA', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #3627
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'F. CAP', u'brand': u'POSEX', u'strength_3': u'', u'company': u'Charak', u'unit': u''}

-- line #3628
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'LIQ', u'brand': u'PROSPAN', u'strength_3': u'', u'company': u'U S V', u'unit': u''}

-- line #3629
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'CAP', u'brand': u'PROSTINA', u'strength_3': u'', u'company': u"Dey''S", u'unit': u''}

-- line #3630
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'GEL', u'brand': u'PUREHANDS', u'strength_3': u'', u'company': u'Himalaya', u'unit': u''}

-- line #3631
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'TAB', u'brand': u'PURIM', u'strength_3': u'', u'company': u'Himalaya', u'unit': u''}

-- line #3632
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'CAP', u'brand': u'PURODIL', u'strength_3': u'', u'company': u'Aimil Ph.', u'unit': u''}

-- line #3633
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'SYR', u'brand': u'PURODIL', u'strength_3': u'', u'company': u'Aimil Ph.', u'unit': u''}

-- line #3634
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'CAP', u'brand': u'RAPKOSTAT', u'strength_3': u'', u'company': u'R.B.', u'unit': u''}

-- line #3635
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'GEL', u'brand': u'RAPKOSTAT', u'strength_3': u'', u'company': u'R.B.', u'unit': u''}

-- line #3636
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'SYR', u'brand': u'RAPPETITE', u'strength_3': u'', u'company': u'R.B.', u'unit': u''}

-- line #3637
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'CAP', u'brand': u'RAPTOLIV', u'strength_3': u'', u'company': u'R.B.', u'unit': u''}

-- line #3638
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'CAP', u'brand': u'RAPTONE', u'strength_3': u'', u'company': u'R.B.', u'unit': u''}

-- line #3639
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'LIQ', u'brand': u'RAPTONE', u'strength_3': u'', u'company': u'R.B.', u'unit': u''}

-- line #3640
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'F. TAB', u'brand': u'REGULAX', u'strength_3': u'', u'company': u'Charak', u'unit': u''}

-- line #3641
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'', u'brand': u'RELIVAC RUBEFACIENT', u'strength_3': u'', u'company': u'CRATUS', u'unit': u''}

-- line #3642
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'SYR', u'brand': u'RENALKA', u'strength_3': u'', u'company': u'Himalaya', u'unit': u''}

-- line #3643
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'TAB', u'brand': u'REOSTO', u'strength_3': u'', u'company': u'Himalaya', u'unit': u''}

-- line #3644
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'', u'brand': u'RESPICE', u'strength_3': u'', u'company': u'ZIMALAYA', u'unit': u''}

-- line #3645
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'SYR', u'brand': u'RESPIKID', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #3646
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'SYR', u'brand': u'RESPINOVA', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #3647
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'CAP', u'brand': u'REVIVIN', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #3648
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PREPARATION', u'always_empty': u'', u'form': u'CAP', u'brand': u'RIKABA', u'strength_3': u'', u'company': u'Centaur', u'unit': u''}

-- line #3649
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PRODUCT', u'always_empty': u'', u'form': u'CAP', u'brand': u'AFRODET PLUS', u'strength_3': u'', u'company': u'SOLUMIKS', u'unit': u''}

-- line #3650
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PRODUCT', u'always_empty': u'', u'form': u'CAP', u'brand': u'AFROL PLUS WITH GOLD', u'strength_3': u'', u'company': u'SOLUMIKS', u'unit': u''}

-- line #3651
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PRODUCT', u'always_empty': u'', u'form': u'CAP', u'brand': u'AOIM-Z', u'strength_3': u'', u'company': u'SOLUMIKS', u'unit': u''}

-- line #3652
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'AYURVEDIC PRODUCT', u'always_empty': u'', u'form': u'', u'brand': u'APPEGEST', u'strength_3': u'', u'company': u'BIRLA LIFE', u'unit': u''}

-- line #3653
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PRODUCT', u'always_empty': u'', u'form': u'TAB/SYR', u'brand': u'ASHOTONE', u'strength_3': u'', u'company': u'SOLUMIKS', u'unit': u''}

-- line #3654
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'AYURVEDIC PRODUCT', u'always_empty': u'', u'form': u'', u'brand': u'BRAHMATEJ', u'strength_3': u'', u'company': u'BIRLA LIFE', u'unit': u''}

-- line #3655
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'AYURVEDIC PRODUCT', u'always_empty': u'', u'form': u'', u'brand': u'DAZZLIN', u'strength_3': u'', u'company': u'BIRLA LIFE', u'unit': u''}

-- line #3656
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'AYURVEDIC PRODUCT', u'always_empty': u'', u'form': u'', u'brand': u'DHATRIKA', u'strength_3': u'', u'company': u'BIRLA LIFE', u'unit': u''}

-- line #3657
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PRODUCT', u'always_empty': u'', u'form': u'TAB/SYR', u'brand': u'DILAPSIN', u'strength_3': u'', u'company': u'SOLUMIKS', u'unit': u''}

-- line #3658
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PRODUCT', u'always_empty': u'', u'form': u'CAP', u'brand': u'EFIPLUS', u'strength_3': u'', u'company': u'SOLUMIKS', u'unit': u''}

-- line #3659
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PRODUCT', u'always_empty': u'', u'form': u'SYR', u'brand': u'ENTOSTAL', u'strength_3': u'', u'company': u'SOLUMIKS', u'unit': u''}

-- line #3660
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PRODUCT', u'always_empty': u'', u'form': u'TAB', u'brand': u'ENTOSTAL', u'strength_3': u'', u'company': u'SOLUMIKS', u'unit': u''}

-- line #3661
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PRODUCT', u'always_empty': u'', u'form': u'SYR', u'brand': u'ESPITONE', u'strength_3': u'', u'company': u'SOLUMIKS', u'unit': u''}

-- line #3662
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'AYURVEDIC PRODUCT', u'always_empty': u'', u'form': u'', u'brand': u'HEPATALL', u'strength_3': u'', u'company': u'BIRLA LIFE', u'unit': u''}

-- line #3663
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PRODUCT', u'always_empty': u'', u'form': u'SYR', u'brand': u'HONICOF', u'strength_3': u'', u'company': u'SOLUMIKS', u'unit': u''}

-- line #3664
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PRODUCT', u'always_empty': u'', u'form': u'TAB', u'brand': u'LUMITAL', u'strength_3': u'', u'company': u'SOLUMIKS', u'unit': u''}

-- line #3665
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PRODUCT', u'always_empty': u'', u'form': u'GRAN', u'brand': u'MAA LACT', u'strength_3': u'', u'company': u'SOLUMIKS', u'unit': u''}

-- line #3666
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PRODUCT', u'always_empty': u'', u'form': u'TAB', u'brand': u'MENOCRAMP', u'strength_3': u'', u'company': u'SOLUMIKS', u'unit': u''}

-- line #3667
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PRODUCT', u'always_empty': u'', u'form': u'TAB/SYR', u'brand': u'NIROCIL', u'strength_3': u'', u'company': u'SOLUMIKS', u'unit': u''}

-- line #3668
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PRODUCT', u'always_empty': u'', u'form': u'CAP', u'brand': u'PLANTACID', u'strength_3': u'', u'company': u'SOLUMIKS', u'unit': u''}

-- line #3669
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PRODUCT', u'always_empty': u'', u'form': u'SUS', u'brand': u'PLANTACID', u'strength_3': u'', u'company': u'SOLUMIKS', u'unit': u''}

-- line #3670
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'AYURVEDIC PRODUCT', u'always_empty': u'', u'form': u'', u'brand': u'PSORILIN', u'strength_3': u'', u'company': u'BIRLA LIFE', u'unit': u''}

-- line #3671
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PRODUCT', u'always_empty': u'', u'form': u'', u'brand': u'PYROFLEX LINIMENT/GEL', u'strength_3': u'', u'company': u'SOLUMIKS', u'unit': u''}

-- line #3672
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PRODUCT', u'always_empty': u'', u'form': u'SYR', u'brand': u'RADONA', u'strength_3': u'', u'company': u'SOLUMIKS', u'unit': u''}

-- line #3673
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'AYURVEDIC PRODUCT', u'always_empty': u'', u'form': u'TAB', u'brand': u'RADONA', u'strength_3': u'', u'company': u'SOLUMIKS', u'unit': u''}

-- line #3674
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'AYURVEDIC PRODUCT', u'always_empty': u'', u'form': u'', u'brand': u'REDUCID CHEWY', u'strength_3': u'', u'company': u'BIRLA LIFE', u'unit': u''}

-- line #3675
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'AYURVEDIC PRODUCT', u'always_empty': u'', u'form': u'', u'brand': u'REMENT', u'strength_3': u'', u'company': u'BIRLA LIFE', u'unit': u''}

-- line #3676
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZAP 50 (CH.Bhagat)',
	'Azathioprine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZAP 50 (CH.Bhagat)'
);

-- line #3677
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZATHIOPRINE 50 (Cytomed(Alkem))',
	'Azathioprine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZATHIOPRINE 50 (Cytomed(Alkem))'
);

-- line #3678
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIMUNE 50 (Sun)',
	'Azathioprine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIMUNE 50 (Sun)'
);

-- line #3679
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZOFIT 50 (Intas)',
	'Azathioprine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZOFIT 50 (Intas)'
);

-- line #3680
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZOPRINE 50 (Vhb)',
	'Azathioprine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZOPRINE 50 (Vhb)'
);

-- line #3681
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZOPRINE 50 (VHB)',
	'Azathioprine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZOPRINE 50 (VHB)'
);

-- line #3682
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZORAN 25 (Rpg Life)',
	'Azathioprine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZORAN 25 (Rpg Life)'
);

-- line #3683
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZORAN 50 (Rpg Life)',
	'Azathioprine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZORAN 50 (Rpg Life)'
);

-- line #3684
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMMUPRINE 50 (Csc Ph.)',
	'Azathioprine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMMUPRINE 50 (Csc Ph.)'
);

-- line #3685
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMURAN 50 (Gsk)',
	'Azathioprine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMURAN 50 (Gsk)'
);

-- line #3686
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMUZAT 50 (Elder)',
	'Azathioprine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMUZAT 50 (Elder)'
);

-- line #3687
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIDERM 10 (Micro Labs)',
	'Azelaic Acid',
	'CRM',
	gm.nullify_empty_string('10')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIDERM 10 (Micro Labs)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIDERM 20 (Micro Labs)',
	'Azelaic Acid',
	'CRM',
	gm.nullify_empty_string('20')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIDERM 20 (Micro Labs)'
);

-- line #3688
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARZEP 0.1 (RESPICARE(GERMAN R.))',
	'Azelastine',
	'NASAL SPRAY',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARZEP 0.1 (RESPICARE(GERMAN R.))'
);

-- line #3689
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZELAST 0.05 (Milmet)',
	'Azelastine',
	'DPS',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZELAST 0.05 (Milmet)'
);

-- line #3690
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZELAST 0.1 (Sun)',
	'Azelastine',
	'NASAL SPRAY',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZELAST 0.1 (Sun)'
);

-- line #3691
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZEP 0.14 (German R.)',
	'Azelastine',
	'NASAL SPRAY',
	gm.nullify_empty_string('0.14')::numeric,
	'mg(HCL)/SPRAY'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZEP 0.14 (German R.)'
);

-- line #3692
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCULAST 0.05 (Centaur)',
	'Azelastine',
	'EYE DPS',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCULAST 0.05 (Centaur)'
);

-- line #3693
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACE-AZ 250 (SHREE BALAJI PH.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACE-AZ 250 (SHREE BALAJI PH.)'
);

-- line #3694
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Azithromycin', u'always_empty': u'', u'form': u'TAB', u'brand': u'ACE-AZ', u'strength_3': u'', u'company': u'SHREE BALAJI PH.', u'unit': u''}

-- line #3695
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACEX 250 (ORION BIOTECH.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACEX 250 (ORION BIOTECH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACEX 500 (ORION BIOTECH.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACEX 500 (ORION BIOTECH.)'
);

-- line #3696
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTIMYCIN 500 (VENUS REM.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTIMYCIN 500 (VENUS REM.)'
);

-- line #3697
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500', u'strength_2': u'', u'substance': u'Azithromycin', u'always_empty': u'', u'form': u'', u'brand': u'ACTIMYCIN', u'strength_3': u'', u'company': u'VENUS REM.', u'unit': u'mg'}

-- line #3698
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AGM 250 (ORSAL PH.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AGM 250 (ORSAL PH.)'
);

-- line #3699
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AGM 500 (ORSAL PH.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AGM 500 (ORSAL PH.)'
);

-- line #3700
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AG 250 (AERO-CHEM)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AG 250 (AERO-CHEM)'
);

-- line #3701
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AG 500 (AERO-CHEM)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AG 500 (AERO-CHEM)'
);

-- line #3702
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AICIN 250 (SYKOCURE)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'500'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AICIN 250 (SYKOCURE)'
);

-- line #3703
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'A-JAR 1000 (WANDER)',
	'Azithromycin',
	'SYR',
	gm.nullify_empty_string('1000')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'A-JAR 1000 (WANDER)'
);

-- line #3704
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'A-JAR 250 (WANDER)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'A-JAR 250 (WANDER)'
);

-- line #3705
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'A-JAR 500 (WANDER)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'A-JAR 500 (WANDER)'
);

-- line #3706
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALICIN 200 (Orion Life)',
	'Azithromycin',
	'SYR',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALICIN 200 (Orion Life)'
);

-- line #3707
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALNEEVO 250 (LITTLE GREAVE)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALNEEVO 250 (LITTLE GREAVE)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALNEEVO 500 (LITTLE GREAVE)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALNEEVO 500 (LITTLE GREAVE)'
);

-- line #3708
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALROXAL 250 (Aldok Ph.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALROXAL 250 (Aldok Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALROXAL 500 (Aldok Ph.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALROXAL 500 (Aldok Ph.)'
);

-- line #3709
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZENTH 100 (AARON HC.)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZENTH 100 (AARON HC.)'
);

-- line #3710
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZENTH 250 (AARON HC.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZENTH 250 (AARON HC.)'
);

-- line #3711
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZENTH 500 (AARON HC.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZENTH 500 (AARON HC.)'
);

-- line #3712
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AN-250 250 (Patson)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AN-250 250 (Patson)'
);

-- line #3713
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AN-500 500 (Patson)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AN-500 500 (Patson)'
);

-- line #3714
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANZ 100 (ANAND HC.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANZ 100 (ANAND HC.)'
);

-- line #3715
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANZ 250 (ANAND HC.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANZ 250 (ANAND HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANZ 500 (ANAND HC.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANZ 500 (ANAND HC.)'
);

-- line #3716
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AQTHRAL 100 (Aquila)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AQTHRAL 100 (Aquila)'
);

-- line #3717
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AQTHRAL 100 (Aquila)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AQTHRAL 100 (Aquila)'
);

-- line #3718
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AQTHRAL 250 (Aquila)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AQTHRAL 250 (Aquila)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AQTHRAL 500 (Aquila)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AQTHRAL 500 (Aquila)'
);

-- line #3719
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARCIN 250 (Chemech)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARCIN 250 (Chemech)'
);

-- line #3720
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARMY-250 250 (TUNE PH.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARMY-250 250 (TUNE PH.)'
);

-- line #3721
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARMY-500 500 (TUNE PH.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARMY-500 500 (TUNE PH.)'
);

-- line #3722
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ART-250-T 250 (Serve Ph.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ART-250-T 250 (Serve Ph.)'
);

-- line #3723
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ART-500-T 500 (Serve Ph.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ART-500-T 500 (Serve Ph.)'
);

-- line #3724
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ART 100 (Serve Ph.)',
	'Azithromycin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ART 100 (Serve Ph.)'
);

-- line #3725
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARZ 100 (WILLOW)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARZ 100 (WILLOW)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARZ 200 (WILLOW)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARZ 200 (WILLOW)'
);

-- line #3726
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARZ 250 (WILLOW)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARZ 250 (WILLOW)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARZ 500 (WILLOW)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARZ 500 (WILLOW)'
);

-- line #3727
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATHROCIN 100 (AUM PH.)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATHROCIN 100 (AUM PH.)'
);

-- line #3728
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATHROCIN 200 (AUM PH.)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATHROCIN 200 (AUM PH.)'
);

-- line #3729
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATHROCIN 250 (AUM PH.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATHROCIN 250 (AUM PH.)'
);

-- line #3730
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATHROCIN 500 (AUM PH.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATHROCIN 500 (AUM PH.)'
);

-- line #3731
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATM 100 (Indoco Rem.)',
	'Azithromycin',
	'KID TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATM 100 (Indoco Rem.)'
);

-- line #3732
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATM 200 (Indoco Rem.)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATM 200 (Indoco Rem.)'
);

-- line #3733
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATM 250 (Indoco Rem.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATM 250 (Indoco Rem.)'
);

-- line #3734
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATM 500 (Indoco Rem.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATM 500 (Indoco Rem.)'
);

-- line #3735
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATM 100 (Indoco Rem.)',
	'Azithromycin',
	'XL',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATM 100 (Indoco Rem.)'
);

-- line #3736
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATM 200 (Indoco Rem.)',
	'Azithromycin',
	'XL',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATM 200 (Indoco Rem.)'
);

-- line #3737
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVINDO 100 (Cosme F.)',
	'Azithromycin',
	'READYMIX',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVINDO 100 (Cosme F.)'
);

-- line #3738
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVINDO 250 (Cosme F.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVINDO 250 (Cosme F.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVINDO 500 (Cosme F.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVINDO 500 (Cosme F.)'
);

-- line #3739
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVITLA 250 (Rowan Bio.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVITLA 250 (Rowan Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVITLA 500 (Rowan Bio.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVITLA 500 (Rowan Bio.)'
);

-- line #3740
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVZETH 250 (POSITIF(AFIVE))',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVZETH 250 (POSITIF(AFIVE))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVZETH 500 (POSITIF(AFIVE))',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVZETH 500 (POSITIF(AFIVE))'
);

-- line #3741
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXITHRO 500 (AXIS LIFE)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXITHRO 500 (AXIS LIFE)'
);

-- line #3742
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZ-1 250 (Kopran)',
	'Azithromycin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZ-1 250 (Kopran)'
);

-- line #3743
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZ3 100 (Albert D.)',
	'Azithromycin',
	'KID TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZ3 100 (Albert D.)'
);

-- line #3744
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZ3 20 (Albert D.)',
	'Azithromycin',
	'LIQ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZ3 20 (Albert D.)'
);

-- line #3745
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZ3 40 (Albert D.)',
	'Azithromycin',
	'LIQ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZ3 40 (Albert D.)'
);

-- line #3746
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZ3 250 (Albert D.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZ3 250 (Albert D.)'
);

-- line #3747
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZ3 500 (Albert D.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZ3 500 (Albert D.)'
);

-- line #3748
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZAD 100 (THEMIS MEDICARE)',
	'Azithromycin',
	'DT TABS',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZAD 100 (THEMIS MEDICARE)'
);

-- line #3749
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZAD 100 (Themis Med.)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZAD 100 (Themis Med.)'
);

-- line #3750
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZAD 200 (Themis Med.)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZAD 200 (Themis Med.)'
);

-- line #3751
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZAD 250 (Themis Med.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZAD 250 (Themis Med.)'
);

-- line #3752
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZAD 500 (Themis Med.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZAD 500 (Themis Med.)'
);

-- line #3753
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZAL 200 (Stallion)',
	'Azithromycin',
	'D.SYR',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZAL 200 (Stallion)'
);

-- line #3754
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZAL 250 (Stallion)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZAL 250 (Stallion)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZAL 500 (Stallion)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZAL 500 (Stallion)'
);

-- line #3755
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZARD 250 (PHARMATECH)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZARD 250 (PHARMATECH)'
);

-- line #3756
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZARD 500 (PHARMATECH)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZARD 500 (PHARMATECH)'
);

-- line #3757
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZAR 200 (Ochoa)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZAR 200 (Ochoa)'
);

-- line #3758
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Azithromycin', u'always_empty': u'', u'form': u'SUS', u'brand': u'AZAR', u'strength_3': u'', u'company': u'OCHOA LAB', u'unit': u''}

-- line #3759
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZAR 250 (Ochoa)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZAR 250 (Ochoa)'
);

-- line #3760
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZAUK 100 (AAMORB)',
	'Azithromycin',
	'SUSP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZAUK 100 (AAMORB)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZAUK 200 (AAMORB)',
	'Azithromycin',
	'SUSP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZAUK 200 (AAMORB)'
);

-- line #3761
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZAUK 250 (AAMORB)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZAUK 250 (AAMORB)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZAUK 500 (AAMORB)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZAUK 500 (AAMORB)'
);

-- line #3762
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZBACT 250 (GLOBELA PH.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZBACT 250 (GLOBELA PH.)'
);

-- line #3763
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZBACT 500 (GLOBELA PH.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZBACT 500 (GLOBELA PH.)'
);

-- line #3764
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZCRE 500 (Shalaks)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZCRE 500 (Shalaks)'
);

-- line #3765
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZEECA -500 500 (NIVCA)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZEECA -500 500 (NIVCA)'
);

-- line #3766
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Azithromycin', u'always_empty': u'', u'form': u'SUSP', u'brand': u'AZEECA', u'strength_3': u'', u'company': u'NIVCA', u'unit': u''}

-- line #3767
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZEECA 250 (NIVCA)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZEECA 250 (NIVCA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZEECA 500 (NIVCA)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZEECA 500 (NIVCA)'
);

-- line #3768
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZEECA - 250 (NIVCA)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZEECA - 250 (NIVCA)'
);

-- line #3769
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZEE 200 (Protec)',
	'Azithromycin',
	'D.SYR',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZEE 200 (Protec)'
);

-- line #3770
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZEE 100 (Protec)',
	'Azithromycin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZEE 100 (Protec)'
);

-- line #3771
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZEEMUNE 250 (Cipla)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZEEMUNE 250 (Cipla)'
);

-- line #3772
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZEEMUNE 500 (Cipla)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZEEMUNE 500 (Cipla)'
);

-- line #3773
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZEE 100 (Protec)',
	'Azithromycin',
	'SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZEE 100 (Protec)'
);

-- line #3774
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZEE 200 (Protec)',
	'Azithromycin',
	'SYR',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZEE 200 (Protec)'
);

-- line #3775
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Azithromycin', u'always_empty': u'', u'form': u'TAB', u'brand': u'AZEE', u'strength_3': u'', u'company': u'Protec', u'unit': u''}

-- line #3776
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZEE 250 (Protec)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZEE 250 (Protec)'
);

-- line #3777
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZEE 500 (Protec)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZEE 500 (Protec)'
);

-- line #3778
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZEE 500 (Protec)',
	'Azithromycin',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZEE 500 (Protec)'
);

-- line #3779
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZELOC 500 (Symbiotic)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZELOC 500 (Symbiotic)'
);

-- line #3780
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZEMO 1 (Sun)',
	'Azithromycin',
	'EYE DPS',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZEMO 1 (Sun)'
);

-- line #3781
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZEM 250 (UNISEARCH HC.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZEM 250 (UNISEARCH HC.)'
);

-- line #3782
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZEM 500 (UNISEARCH HC.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZEM 500 (UNISEARCH HC.)'
);

-- line #3783
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZEN-250 250 (ZENIVIA LS.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZEN-250 250 (ZENIVIA LS.)'
);

-- line #3784
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZENAS 200 (Morepen)',
	'Azithromycin',
	'SYP',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZENAS 200 (Morepen)'
);

-- line #3785
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZENAS 250 (Morepen)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZENAS 250 (Morepen)'
);

-- line #3786
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZENAS 500 (Morepen)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZENAS 500 (Morepen)'
);

-- line #3787
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZEN 250 (AXEN PH.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZEN 250 (AXEN PH.)'
);

-- line #3788
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZEN 500 (AXEN PH.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZEN 500 (AXEN PH.)'
);

-- line #3789
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZERIKA 500 (Elder)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZERIKA 500 (Elder)'
);

-- line #3790
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZERO REDIUSE 100 (AERO LIFE)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZERO REDIUSE 100 (AERO LIFE)'
);

-- line #3791
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZERO 500 (AERO LIFE)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZERO 500 (AERO LIFE)'
);

-- line #3792
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZERYTH-250 250 (ABLAZE HC)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZERYTH-250 250 (ABLAZE HC)'
);

-- line #3793
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZERYTH-KID 100 (ABLAZE HC)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZERYTH-KID 100 (ABLAZE HC)'
);

-- line #3794
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZERYTH 500 (ABLAZE HC)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZERYTH 500 (ABLAZE HC)'
);

-- line #3795
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZEST 100 (Zest Ph.)',
	'Azithromycin',
	'DT TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZEST 100 (Zest Ph.)'
);

-- line #3796
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZEST 100 (Zest Ph.)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZEST 100 (Zest Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZEST 200 (Zest Ph.)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZEST 200 (Zest Ph.)'
);

-- line #3797
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZEST 250 (Zest Ph.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZEST 250 (Zest Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZEST 500 (Zest Ph.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZEST 500 (Zest Ph.)'
);

-- line #3798
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZET 250 (Chemo D.)',
	'Azithromycin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZET 250 (Chemo D.)'
);

-- line #3799
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZETEN 250 (TENGEE)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZETEN 250 (TENGEE)'
);

-- line #3800
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZETEN 500 (TENGEE)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZETEN 500 (TENGEE)'
);

-- line #3801
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Azithromycin', u'always_empty': u'', u'form': u'SUS', u'brand': u'AZEZEN', u'strength_3': u'', u'company': u'BIOGEN PH.', u'unit': u''}

-- line #3802
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZEZEN 250 (BIOGEN PH.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZEZEN 250 (BIOGEN PH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZEZEN 500 (BIOGEN PH.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZEZEN 500 (BIOGEN PH.)'
);

-- line #3803
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZFORIN 250 (UNIKARE)',
	'Azithromycin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZFORIN 250 (UNIKARE)'
);

-- line #3804
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZFORIN 100 (Unichem)',
	'Azithromycin',
	'ORAL SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZFORIN 100 (Unichem)'
);

-- line #3805
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZFORIN 500 (Unichem)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZFORIN 500 (Unichem)'
);

-- line #3806
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIAGIO 100 (AGIO PH.)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIAGIO 100 (AGIO PH.)'
);

-- line #3807
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIAGIO 200 (AGIO PH.)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIAGIO 200 (AGIO PH.)'
);

-- line #3808
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIAGIO 1000 (AGIO PH.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIAGIO 1000 (AGIO PH.)'
);

-- line #3809
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIAGIO 250 (AGIO PH.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIAGIO 250 (AGIO PH.)'
);

-- line #3810
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIAGIO 500 (AGIO PH.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIAGIO 500 (AGIO PH.)'
);

-- line #3811
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIAR 250 (ARLOP PH.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIAR 250 (ARLOP PH.)'
);

-- line #3812
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIAR 500 (ARLOP PH.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIAR 500 (ARLOP PH.)'
);

-- line #3813
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIBACT 100 (Ipca)',
	'Azithromycin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIBACT 100 (Ipca)'
);

-- line #3814
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIBACT LR 100 (Ipca)',
	'Azithromycin',
	'READYMIX',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIBACT LR 100 (Ipca)'
);

-- line #3815
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIBACT LR 200 (Ipca)',
	'Azithromycin',
	'READYMIX',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIBACT LR 200 (Ipca)'
);

-- line #3816
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIBACT SI 500 (Ipca)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIBACT SI 500 (Ipca)'
);

-- line #3817
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2G', u'strength_2': u'', u'substance': u'Azithromycin', u'always_empty': u'', u'form': u'SR', u'brand': u'AZIBACT', u'strength_3': u'', u'company': u'Ipca', u'unit': u''}

-- line #3818
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIBACT 100 (Ipca)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIBACT 100 (Ipca)'
);

-- line #3819
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIBACT 200 (Ipca)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIBACT 200 (Ipca)'
);

-- line #3820
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIBACT 250 (Ipca)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIBACT 250 (Ipca)'
);

-- line #3821
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIBACT 500 (Ipca)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIBACT 500 (Ipca)'
);

-- line #3822
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500', u'strength_2': u'', u'substance': u'Azithromycin', u'always_empty': u'', u'form': u'', u'brand': u'AZIBA', u'strength_3': u'', u'company': u'EBAR HC.', u'unit': u'mg'}

-- line #3823
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIBER 100 (Calibar Ph.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIBER 100 (Calibar Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIBER 250 (Calibar Ph.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIBER 250 (Calibar Ph.)'
);

-- line #3824
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIBER 500 (Calibar Ph.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIBER 500 (Calibar Ph.)'
);

-- line #3825
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIBEST 100 (Blue Cross)',
	'Azithromycin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIBEST 100 (Blue Cross)'
);

-- line #3826
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIBEST 100 (Blue Cross)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIBEST 100 (Blue Cross)'
);

-- line #3827
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIBEST 200 (BLUE CROSS)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIBEST 200 (BLUE CROSS)'
);

-- line #3828
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIBEST 250 (Blue Cross)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIBEST 250 (Blue Cross)'
);

-- line #3829
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIBEST 500 (Blue Cross)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIBEST 500 (Blue Cross)'
);

-- line #3830
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIBIG 100 (Bestochem)',
	'Azithromycin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIBIG 100 (Bestochem)'
);

-- line #3831
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZI-BIG 100 (Bestochem)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZI-BIG 100 (Bestochem)'
);

-- line #3832
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIBIG 250 (Bestochem)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIBIG 250 (Bestochem)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIBIG 500 (Bestochem)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIBIG 500 (Bestochem)'
);

-- line #3833
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZI-BIG 250 (Bestochem)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZI-BIG 250 (Bestochem)'
);

-- line #3834
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZI-BIG 500 (Bestochem)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZI-BIG 500 (Bestochem)'
);

-- line #3835
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIBI 100 (SANCHEZ LAB.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIBI 100 (SANCHEZ LAB.)'
);

-- line #3836
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIBI 250 (SANCHEZ LAB.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIBI 250 (SANCHEZ LAB.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIBI 500 (SANCHEZ LAB.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIBI 500 (SANCHEZ LAB.)'
);

-- line #3837
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZICARE 100 (Olcare)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZICARE 100 (Olcare)'
);

-- line #3838
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZICARE 250 (Olcare)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZICARE 250 (Olcare)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZICARE 500 (Olcare)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZICARE 500 (Olcare)'
);

-- line #3839
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZICENT 250 (ASCENT REM.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZICENT 250 (ASCENT REM.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZICENT 500 (ASCENT REM.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZICENT 500 (ASCENT REM.)'
);

-- line #3840
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZICIN-500 500 (DYNAMIC LC.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZICIN-500 500 (DYNAMIC LC.)'
);

-- line #3841
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZICIN 250 (POSITIF(NUTRON))',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZICIN 250 (POSITIF(NUTRON))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZICIN 500 (POSITIF(NUTRON))',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZICIN 500 (POSITIF(NUTRON))'
);

-- line #3842
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZICIP 250 (Cipla)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZICIP 250 (Cipla)'
);

-- line #3843
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZICIP 500 (Cipla)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZICIP 500 (Cipla)'
);

-- line #3844
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZICLEN 100 (Biocin Hc.)',
	'Azithromycin',
	'D.SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZICLEN 100 (Biocin Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZICLEN 200 (Biocin Hc.)',
	'Azithromycin',
	'D.SYR',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZICLEN 200 (Biocin Hc.)'
);

-- line #3845
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZICLEN 100 (Biocin Hc.)',
	'Azithromycin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZICLEN 100 (Biocin Hc.)'
);

-- line #3846
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZICLEN 250 (Biocin Hc.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZICLEN 250 (Biocin Hc.)'
);

-- line #3847
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZICON 250 (Varun Life)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZICON 250 (Varun Life)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZICON 500 (Varun Life)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZICON 500 (Varun Life)'
);

-- line #3848
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Azithromycin', u'always_empty': u'', u'form': u'SUS/DS SUS', u'brand': u'AZICOR', u'strength_3': u'', u'company': u'WISCON', u'unit': u''}

-- line #3849
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZICOR 250 (WISCON)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZICOR 250 (WISCON)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZICOR 500 (WISCON)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZICOR 500 (WISCON)'
);

-- line #3850
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZICOX 250 (COXSWAIN HC.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZICOX 250 (COXSWAIN HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZICOX 500 (COXSWAIN HC.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZICOX 500 (COXSWAIN HC.)'
);

-- line #3851
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZICRAT 250 (CRATUS)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZICRAT 250 (CRATUS)'
);

-- line #3852
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZICRAT 500 (CRATUS)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZICRAT 500 (CRATUS)'
);

-- line #3853
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZICT 250 (Pulse Ph.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZICT 250 (Pulse Ph.)'
);

-- line #3854
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZICT 500 (Pulse Ph.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZICT 500 (Pulse Ph.)'
);

-- line #3855
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZICURE 250 (Secure)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZICURE 250 (Secure)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZICURE 500 (Secure)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZICURE 500 (Secure)'
);

-- line #3856
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZICYTE 200 (Lekar)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZICYTE 200 (Lekar)'
);

-- line #3857
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZICYTE 250 (Lekar)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZICYTE 250 (Lekar)'
);

-- line #3858
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZICYTE 500 (Lekar)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZICYTE 500 (Lekar)'
);

-- line #3859
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIDAC 500 (Ikon Rem)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIDAC 500 (Ikon Rem)'
);

-- line #3860
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIDARSH 250 (ROHVEESHPRA PH.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIDARSH 250 (ROHVEESHPRA PH.)'
);

-- line #3861
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIDARSH 500 (ROHVEESHPRA PH.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIDARSH 500 (ROHVEESHPRA PH.)'
);

-- line #3862
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIDAY 100 (Skymax LIFE)',
	'Azithromycin',
	'KID TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIDAY 100 (Skymax LIFE)'
);

-- line #3863
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250', u'strength_2': u'', u'substance': u'Azithromycin', u'always_empty': u'', u'form': u'', u'brand': u'AZIDAY', u'strength_3': u'', u'company': u'SKYMAX LIFE', u'unit': u'mg'}

-- line #3864
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIDAY 200 (Skymax)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIDAY 200 (Skymax)'
);

-- line #3865
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIDAY 500 (Skymax)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIDAY 500 (Skymax)'
);

-- line #3866
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZID 100 (Indi Ph.)',
	'Azithromycin',
	'D.SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZID 100 (Indi Ph.)'
);

-- line #3867
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZID 200 (Indi Ph.)',
	'Azithromycin',
	'D.SYR',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZID 200 (Indi Ph.)'
);

-- line #3868
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZID 100 (Indi Ph.)',
	'Azithromycin',
	'KID TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZID 100 (Indi Ph.)'
);

-- line #3869
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIDOC 250 (GEMASKO)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg/500'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIDOC 250 (GEMASKO)'
);

-- line #3870
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIDOL 100 (Idol Bio.)',
	'Azithromycin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIDOL 100 (Idol Bio.)'
);

-- line #3871
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIDOL 500 (Idol Bio.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIDOL 500 (Idol Bio.)'
);

-- line #3872
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIDRAW 250 (QCHECK)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIDRAW 250 (QCHECK)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIDRAW 500 (QCHECK)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIDRAW 500 (QCHECK)'
);

-- line #3873
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZID 250 (Indi Ph.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZID 250 (Indi Ph.)'
);

-- line #3874
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZID 500 (Indi Ph.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZID 500 (Indi Ph.)'
);

-- line #3875
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIDUTCH 250 (Dutch Rem.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIDUTCH 250 (Dutch Rem.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIDUTCH 500 (Dutch Rem.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIDUTCH 500 (Dutch Rem.)'
);

-- line #3876
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIFAM 250 (SIFAM PH.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIFAM 250 (SIFAM PH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIFAM 500 (SIFAM PH.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIFAM 500 (SIFAM PH.)'
);

-- line #3877
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIFAST 2 (Ipca)',
	'Azithromycin',
	'GEL',
	gm.nullify_empty_string('2')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIFAST 2 (Ipca)'
);

-- line #3878
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIFAST 250 (Ipca)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIFAST 250 (Ipca)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIFAST 500 (Ipca)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIFAST 500 (Ipca)'
);

-- line #3879
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIFA 500 (FIRST CHOICE)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIFA 500 (FIRST CHOICE)'
);

-- line #3880
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIFEM 250 (Fem care)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIFEM 250 (Fem care)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIFEM 500 (Fem care)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIFEM 500 (Fem care)'
);

-- line #3881
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIFINE 100 (Glenmark)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIFINE 100 (Glenmark)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIFINE 200 (Glenmark)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIFINE 200 (Glenmark)'
);

-- line #3882
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIFINE 250 (Glenmark)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIFINE 250 (Glenmark)'
);

-- line #3883
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIFINE 500 (Glenmark)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIFINE 500 (Glenmark)'
);

-- line #3884
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIFLOW 250 (XCEL LABS)',
	'AZIthromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIFLOW 250 (XCEL LABS)'
);

-- line #3885
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIFLOW 500 (XCEL LABS)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIFLOW 500 (XCEL LABS)'
);

-- line #3886
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIFOR-250 250 (FORAM BIO.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIFOR-250 250 (FORAM BIO.)'
);

-- line #3887
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIFOR-500 500 (FORAM BIO.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIFOR-500 500 (FORAM BIO.)'
);

-- line #3888
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIFST 100 (Ipca)',
	'Azithromycin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIFST 100 (Ipca)'
);

-- line #3889
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIFST 100 (Ipca)',
	'Azithromycin',
	'READYMIX',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIFST 100 (Ipca)'
);

-- line #3890
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIFST 200 (Ipca)',
	'Azithromycin',
	'READYMIX',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIFST 200 (Ipca)'
);

-- line #3891
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIGEN 500 (Regen Int.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIGEN 500 (Regen Int.)'
);

-- line #3892
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIGO 250 (Green Cross)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIGO 250 (Green Cross)'
);

-- line #3893
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIGRAM 250 (UNITED LIFE)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIGRAM 250 (UNITED LIFE)'
);

-- line #3894
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIGRAM 500 (UNITED LIFE)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIGRAM 500 (UNITED LIFE)'
);

-- line #3895
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIHEX-250 250 (HEXAL PH.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIHEX-250 250 (HEXAL PH.)'
);

-- line #3896
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIKAM 100 (Kamron)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/15ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIKAM 100 (Kamron)'
);

-- line #3897
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIKAM 250 (Kamron)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIKAM 250 (Kamron)'
);

-- line #3898
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIKAM 500 (Kamron)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIKAM 500 (Kamron)'
);

-- line #3899
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIKARE 250 (ANKARE)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIKARE 250 (ANKARE)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIKARE 500 (ANKARE)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIKARE 500 (ANKARE)'
);

-- line #3900
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZILAC-250 250 (EUTHERVA)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZILAC-250 250 (EUTHERVA)'
);

-- line #3901
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZILAC-500 500 (EUTHERVA)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZILAC-500 500 (EUTHERVA)'
);

-- line #3902
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZILAND 250 (L & V PH.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZILAND 250 (L & V PH.)'
);

-- line #3903
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZILAND 500 (L & V PH.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZILAND 500 (L & V PH.)'
);

-- line #3904
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZILEB 100 (Leben)',
	'Azithromycin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZILEB 100 (Leben)'
);

-- line #3905
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZILEB 100 (Leben)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZILEB 100 (Leben)'
);

-- line #3906
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZILEB 200 (Leben)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZILEB 200 (Leben)'
);

-- line #3907
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZILEB 250 (Leben)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZILEB 250 (Leben)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZILEB 500 (Leben)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZILEB 500 (Leben)'
);

-- line #3908
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZILIDE 100 (Micro Nova)',
	'Azithromycin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZILIDE 100 (Micro Nova)'
);

-- line #3909
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZILIDE 100 (Micro Nova)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZILIDE 100 (Micro Nova)'
);

-- line #3910
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZILIDE 200 (Micro Nova)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZILIDE 200 (Micro Nova)'
);

-- line #3911
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZILIDE 250 (Micro Nova)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZILIDE 250 (Micro Nova)'
);

-- line #3912
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZILIDE 500 (Micro Nova)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZILIDE 500 (Micro Nova)'
);

-- line #3913
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZILIFE 200 (AQUALIFE)',
	'Azithromycin',
	'SUSP',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZILIFE 200 (AQUALIFE)'
);

-- line #3914
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZILIFE 250 (AQUALIFE)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZILIFE 250 (AQUALIFE)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZILIFE 500 (AQUALIFE)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZILIFE 500 (AQUALIFE)'
);

-- line #3915
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZILLON 250 (SAILLON PH.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZILLON 250 (SAILLON PH.)'
);

-- line #3916
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZILLON 500 (SAILLON PH.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZILLON 500 (SAILLON PH.)'
);

-- line #3917
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZILONE 250 (ZYLONE HC.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZILONE 250 (ZYLONE HC.)'
);

-- line #3918
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZILOT 250 (Zealot Biotech)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZILOT 250 (Zealot Biotech)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZILOT 500 (Zealot Biotech)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZILOT 500 (Zealot Biotech)'
);

-- line #3919
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIL 100 (Lanark)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIL 100 (Lanark)'
);

-- line #3920
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIL 250 (Lanark)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIL 250 (Lanark)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIL 500 (Lanark)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIL 500 (Lanark)'
);

-- line #3921
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZILUP 100 (Lupin)',
	'Azithromycin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZILUP 100 (Lupin)'
);

-- line #3922
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZILUP 200 (Lupin)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZILUP 200 (Lupin)'
);

-- line #3923
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIMAC 100 (Interpharm)',
	'Azithromycin',
	'KID TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIMAC 100 (Interpharm)'
);

-- line #3924
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIMAC 200 (WISCON)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIMAC 200 (WISCON)'
);

-- line #3925
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIMAC 250 (Interpharm)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIMAC 250 (Interpharm)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIMAC 500 (Interpharm)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIMAC 500 (Interpharm)'
);

-- line #3926
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIMAC 250 (WISCON)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIMAC 250 (WISCON)'
);

-- line #3927
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIMAC 500 (WISCON)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIMAC 500 (WISCON)'
);

-- line #3928
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIMARS 250 (Mars Rem.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIMARS 250 (Mars Rem.)'
);

-- line #3929
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIMARS 500 (Mars Rem.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIMARS 500 (Mars Rem.)'
);

-- line #3930
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIMAX 100 (Cipla)',
	'Azithromycin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIMAX 100 (Cipla)'
);

-- line #3931
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIMAX 500 (Cipla)',
	'Azithromycin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIMAX 500 (Cipla)'
);

-- line #3932
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Azithromycin', u'always_empty': u'', u'form': u'SUS', u'brand': u'AZIMAX', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #3933
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIMAX 250 (CIPLA)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIMAX 250 (CIPLA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIMAX 500 (CIPLA)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIMAX 500 (CIPLA)'
);

-- line #3934
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIMED 500 (INNOMED HC.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIMED 500 (INNOMED HC.)'
);

-- line #3935
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIMER 100 (Mercury)',
	'Azithromycin',
	'KID TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIMER 100 (Mercury)'
);

-- line #3936
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Azithromycin', u'always_empty': u'', u'form': u'SUS', u'brand': u'AZIMER', u'strength_3': u'', u'company': u'Mercury', u'unit': u''}

-- line #3937
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIMER 250 (Mercury)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIMER 250 (Mercury)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIMER 500 (Mercury)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIMER 500 (Mercury)'
);

-- line #3938
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIMIST 250 (Parenteral)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIMIST 250 (Parenteral)'
);

-- line #3939
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIMIST 500 (Parenteral)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIMIST 500 (Parenteral)'
);

-- line #3940
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIMON 100 (Sterkem Ph.)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIMON 100 (Sterkem Ph.)'
);

-- line #3941
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Azithromycin', u'always_empty': u'', u'form': u'TAB', u'brand': u'AZIMON', u'strength_3': u'', u'company': u'Sterkem Ph.', u'unit': u''}

-- line #3942
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIMORE 250 (Mdc Ph.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIMORE 250 (Mdc Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIMORE 500 (Mdc Ph.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIMORE 500 (Mdc Ph.)'
);

-- line #3943
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIMO 100 (Zenon Hc.)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIMO 100 (Zenon Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIMO 200 (Zenon Hc.)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIMO 200 (Zenon Hc.)'
);

-- line #3944
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIMYCIN 250 (Arvind Lab.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIMYCIN 250 (Arvind Lab.)'
);

-- line #3945
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZINA 100 (Sayona)',
	'Azithromycin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZINA 100 (Sayona)'
);

-- line #3946
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZINA 250 (Sayona)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZINA 250 (Sayona)'
);

-- line #3947
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZINA 500 (Sayona)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZINA 500 (Sayona)'
);

-- line #3948
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Azithromycin', u'always_empty': u'', u'form': u'KID TAB', u'brand': u'AZINDICA', u'strength_3': u'', u'company': u'Indica', u'unit': u''}

-- line #3949
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZINDICA 250 (Indica)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZINDICA 250 (Indica)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZINDICA 500 (Indica)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZINDICA 500 (Indica)'
);

-- line #3950
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZINEN 500 (NENSHI HC.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZINEN 500 (NENSHI HC.)'
);

-- line #3951
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZINEW 100 (Dr.Arvind Shah''S)',
	'Azithromycin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZINEW 100 (Dr.Arvind Shah''S)'
);

-- line #3952
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZINEW 250 (Dr.Arvind Shah''S)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZINEW 250 (Dr.Arvind Shah''S)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZINEW 500 (Dr.Arvind Shah''S)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZINEW 500 (Dr.Arvind Shah''S)'
);

-- line #3953
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZINEX 100 (Aronex Life)',
	'Azithromycin',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZINEX 100 (Aronex Life)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZINEX 200 (Aronex Life)',
	'Azithromycin',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZINEX 200 (Aronex Life)'
);

-- line #3954
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZINEX 250 (Aronex Life)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZINEX 250 (Aronex Life)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZINEX 500 (Aronex Life)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZINEX 500 (Aronex Life)'
);

-- line #3955
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZINIDH 250 (NAVNIDHI LIFE)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZINIDH 250 (NAVNIDHI LIFE)'
);

-- line #3956
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZINIDH 500 (NAVNIDHI LIFE)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZINIDH 500 (NAVNIDHI LIFE)'
);

-- line #3957
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZINIJ 100 (SUNIJ PH.)',
	'Azithromycin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZINIJ 100 (SUNIJ PH.)'
);

-- line #3958
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZINIJ 250 (SUNIJ PH.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZINIJ 250 (SUNIJ PH.)'
);

-- line #3959
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZINIJ 500 (SUNIJ PH.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZINIJ 500 (SUNIJ PH.)'
);

-- line #3960
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2G', u'strength_2': u'', u'substance': u'Azithromycin', u'always_empty': u'', u'form': u'', u'brand': u'AZINIX SD', u'strength_3': u'', u'company': u'Khandelwal', u'unit': u''}

-- line #3961
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Azithromycin', u'always_empty': u'', u'form': u'', u'brand': u'AZINIX SDP', u'strength_3': u'', u'company': u'Khandelwal', u'unit': u''}

-- line #3962
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZINIX 100 (XENON(KHANDELWAL))',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZINIX 100 (XENON(KHANDELWAL))'
);

-- line #3963
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZINIX 200 (XENON(KHANDELWAL))',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZINIX 200 (XENON(KHANDELWAL))'
);

-- line #3964
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZINIX 250 (Khandelwal)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZINIX 250 (Khandelwal)'
);

-- line #3965
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZINIX 500 (Khandelwal)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZINIX 500 (Khandelwal)'
);

-- line #3966
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZINIX 250 (XENON(KHANDELWAL))',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZINIX 250 (XENON(KHANDELWAL))'
);

-- line #3967
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZINIX 500 (XENON(KHANDELWAL))',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZINIX 500 (XENON(KHANDELWAL))'
);

-- line #3968
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIN 250 (LEXMARK PH.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIN 250 (LEXMARK PH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIN 500 (LEXMARK PH.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIN 500 (LEXMARK PH.)'
);

-- line #3969
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZINTRA 100 (Intra Lab)',
	'Azithromycin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZINTRA 100 (Intra Lab)'
);

-- line #3970
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZINTRA 250 (Intra Lab)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZINTRA 250 (Intra Lab)'
);

-- line #3971
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZINTRA 500 (Intra Lab)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZINTRA 500 (Intra Lab)'
);

-- line #3972
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIOM 250 (Zenon Hc.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIOM 250 (Zenon Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIOM 500 (Zenon Hc.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIOM 500 (Zenon Hc.)'
);

-- line #3973
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZI-ONE 500 (ONE LIFECARE)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZI-ONE 500 (ONE LIFECARE)'
);

-- line #3974
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZION 250 (John Bio.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZION 250 (John Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZION 500 (John Bio.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZION 500 (John Bio.)'
);

-- line #3975
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIPAR 100 (MOLEKULE)',
	'Azithromycin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIPAR 100 (MOLEKULE)'
);

-- line #3976
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIPAR 100 (MOLEKULE)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIPAR 100 (MOLEKULE)'
);

-- line #3977
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIPAR 200 (MOLEKULE)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIPAR 200 (MOLEKULE)'
);

-- line #3978
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIPAR 250 (MOLEKULE)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIPAR 250 (MOLEKULE)'
);

-- line #3979
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIPAR 500 (MOLEKULE)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIPAR 500 (MOLEKULE)'
);

-- line #3980
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIPEN 500 (SAFE PH.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIPEN 500 (SAFE PH.)'
);

-- line #3981
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIPOS 100 (Aglowmed)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIPOS 100 (Aglowmed)'
);

-- line #3982
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIPOS 250 (Aglowmed)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIPOS 250 (Aglowmed)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIPOS 500 (Aglowmed)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIPOS 500 (Aglowmed)'
);

-- line #3983
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIPRO 100 (Cipla)',
	'Azithromycin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIPRO 100 (Cipla)'
);

-- line #3984
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2GM', u'strength_2': u'', u'substance': u'Azithromycin', u'always_empty': u'', u'form': u'', u'brand': u'AZIPRO GM ORAL', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #3985
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIPRO 500 (Cipla)',
	'Azithromycin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIPRO 500 (Cipla)'
);

-- line #3986
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100', u'strength_2': u'', u'substance': u'Azithromycin', u'always_empty': u'', u'form': u'', u'brand': u'AZIPRO REDIUSE', u'strength_3': u'', u'company': u'Cipla', u'unit': u'mg'}

-- line #3987
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200', u'strength_2': u'', u'substance': u'Azithromycin', u'always_empty': u'', u'form': u'', u'brand': u'AZIPRO REDIUSE', u'strength_3': u'', u'company': u'Cipla', u'unit': u'mg'}

-- line #3988
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIPRO 1000 (CIPLA)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIPRO 1000 (CIPLA)'
);

-- line #3989
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIPRO 250 (Cipla)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIPRO 250 (Cipla)'
);

-- line #3990
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIPRO 500 (Cipla)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIPRO 500 (Cipla)'
);

-- line #3991
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIRAM 200 (AUGMENT REM.)',
	'Azithromycin',
	'SUSP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIRAM 200 (AUGMENT REM.)'
);

-- line #3992
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIRAM 250 (AUGMENT REM.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIRAM 250 (AUGMENT REM.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIRAM 500 (AUGMENT REM.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIRAM 500 (AUGMENT REM.)'
);

-- line #3993
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIREL 200 (Relax Ph.)',
	'Azithromycin',
	'ORAL SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIREL 200 (Relax Ph.)'
);

-- line #3994
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIREL 250 (Relax Ph.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIREL 250 (Relax Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIREL 500 (Relax Ph.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIREL 500 (Relax Ph.)'
);

-- line #3995
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIRESP 100 (AZINE HC.)',
	'Azithromycin',
	'SUSP',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIRESP 100 (AZINE HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIRESP 200 (AZINE HC.)',
	'Azithromycin',
	'SUSP',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIRESP 200 (AZINE HC.)'
);

-- line #3996
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIRESP 250 (AZINE HC.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIRESP 250 (AZINE HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIRESP 500 (AZINE HC.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIRESP 500 (AZINE HC.)'
);

-- line #3997
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIREX 250 (Theo Ph.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIREX 250 (Theo Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIREX 500 (Theo Ph.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIREX 500 (Theo Ph.)'
);

-- line #3998
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIRICH 250 (ENRICH PH.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIRICH 250 (ENRICH PH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIRICH 500 (ENRICH PH.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIRICH 500 (ENRICH PH.)'
);

-- line #3999
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIRID 200 (Armour Rem.)',
	'Azithromycin',
	'SYR',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIRID 200 (Armour Rem.)'
);

-- line #4000
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIRID 250 (Armour Rem.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIRID 250 (Armour Rem.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIRID 500 (Armour Rem.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIRID 500 (Armour Rem.)'
);

-- line #4001
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIRIN 250 (ORIAN PH.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIRIN 250 (ORIAN PH.)'
);

-- line #4002
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIRIN 500 (ORIAN PH.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIRIN 500 (ORIAN PH.)'
);

-- line #4003
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Azithromycin', u'always_empty': u'', u'form': u'TAB', u'brand': u'AZIRIS-250', u'strength_3': u'', u'company': u'ARIES MEDI.', u'unit': u''}

-- line #4004
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIROM 100 (Rhombus)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIROM 100 (Rhombus)'
);

-- line #4005
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIROM 250 (Rhombus)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIROM 250 (Rhombus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIROM 500 (Rhombus)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIROM 500 (Rhombus)'
);

-- line #4006
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIRUN 500 (JARUN PH.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIRUN 500 (JARUN PH.)'
);

-- line #4007
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZISAFE 100 (UNI OR.)',
	'Azithromycin',
	'DT TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZISAFE 100 (UNI OR.)'
);

-- line #4008
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZISAFE 250 (UNI OR.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZISAFE 250 (UNI OR.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZISAFE 500 (UNI OR.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZISAFE 500 (UNI OR.)'
);

-- line #4009
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZISAL 100 (SALVO HC.)',
	'Azithromycin',
	'DT/500 TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZISAL 100 (SALVO HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZISAL 500 (SALVO HC.)',
	'Azithromycin',
	'DT/500 TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZISAL 500 (SALVO HC.)'
);

-- line #4010
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZISAL 100 (Salvo Hc.)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZISAL 100 (Salvo Hc.)'
);

-- line #4011
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZISAL 250 (Salvo Hc.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZISAL 250 (Salvo Hc.)'
);

-- line #4012
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZISARA 250 (Nicholas)',
	'Azithromycin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZISARA 250 (Nicholas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZISARA 500 (Nicholas)',
	'Azithromycin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZISARA 500 (Nicholas)'
);

-- line #4013
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZISEF 250 (HAMPS BIO)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZISEF 250 (HAMPS BIO)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZISEF 500 (HAMPS BIO)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZISEF 500 (HAMPS BIO)'
);

-- line #4014
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZISEF 500 (HAMPS BIO.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZISEF 500 (HAMPS BIO.)'
);

-- line #4015
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZISET 200 (Active Hc.)',
	'Azithromycin',
	'SUSP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZISET 200 (Active Hc.)'
);

-- line #4016
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZISET 250 (Active Hc.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZISET 250 (Active Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZISET 500 (Active Hc.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZISET 500 (Active Hc.)'
);

-- line #4017
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZISIS 100 (SYNOPSIS)',
	'Azithromycin',
	'KID TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZISIS 100 (SYNOPSIS)'
);

-- line #4018
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZISIS 250 (SYNOPSIS)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZISIS 250 (SYNOPSIS)'
);

-- line #4019
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZISIS 500 (SYNOPSIS)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZISIS 500 (SYNOPSIS)'
);

-- line #4020
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIS 100 (Taurus Lab)',
	'Azithromycin',
	'KID TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIS 100 (Taurus Lab)'
);

-- line #4021
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZISMI 500 (JIG PH.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZISMI 500 (JIG PH.)'
);

-- line #4022
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZISMITH 100 (Biosmith)',
	'Azithromycin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZISMITH 100 (Biosmith)'
);

-- line #4023
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZISMITH 250 (Biosmith)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZISMITH 250 (Biosmith)'
);

-- line #4024
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZISOL 250 (SOL DERMA)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZISOL 250 (SOL DERMA)'
);

-- line #4025
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZISOL 500 (SOL DERMA)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZISOL 500 (SOL DERMA)'
);

-- line #4026
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZISON 100 (DR. ALSON)',
	'Azithromycin',
	'SUSP',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZISON 100 (DR. ALSON)'
);

-- line #4027
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZISON 250 (DR. ALSON)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZISON 250 (DR. ALSON)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZISON 500 (DR. ALSON)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZISON 500 (DR. ALSON)'
);

-- line #4028
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZISPAN 100 (Votary Lab)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZISPAN 100 (Votary Lab)'
);

-- line #4029
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZISPAN 250 (Votary Lab)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZISPAN 250 (Votary Lab)'
);

-- line #4030
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZISPAN 500 (Votary Lab)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZISPAN 500 (Votary Lab)'
);

-- line #4031
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIS 200 (Sv Ph.)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIS 200 (Sv Ph.)'
);

-- line #4032
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIS 200 (Taurus Lab)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIS 200 (Taurus Lab)'
);

-- line #4033
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIS 100 (Sv Ph.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIS 100 (Sv Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIS 250 (Sv Ph.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIS 250 (Sv Ph.)'
);

-- line #4034
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIS 250 (Taurus Lab)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIS 250 (Taurus Lab)'
);

-- line #4035
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZISTART 200 (Rpg Life)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZISTART 200 (Rpg Life)'
);

-- line #4036
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZISTART 250 (Rpg Life)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZISTART 250 (Rpg Life)'
);

-- line #4037
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZISTART 500 (Rpg Life)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZISTART 500 (Rpg Life)'
);

-- line #4038
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZISTRA 500 (YASHTRA HEALTH)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZISTRA 500 (YASHTRA HEALTH)'
);

-- line #4039
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZISTREAM 250 (MEDISTREAM)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZISTREAM 250 (MEDISTREAM)'
);

-- line #4040
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZISTREAM 500 (MEDISTREAM)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZISTREAM 500 (MEDISTREAM)'
);

-- line #4041
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZISUPER 100 (Torrent)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZISUPER 100 (Torrent)'
);

-- line #4042
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZISUPER 200 (Torrent)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZISUPER 200 (Torrent)'
);

-- line #4043
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZISUPER 250 (Torrent)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZISUPER 250 (Torrent)'
);

-- line #4044
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZISUPER 500 (Torrent)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZISUPER 500 (Torrent)'
);

-- line #4045
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZISUR 250 (Surge Bio.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZISUR 250 (Surge Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZISUR 500 (Surge Bio.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZISUR 500 (Surge Bio.)'
);

-- line #4046
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZISWIFT 100 (Lupin)',
	'Azithromycin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZISWIFT 100 (Lupin)'
);

-- line #4047
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZISWIFT 100 (Lupin)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZISWIFT 100 (Lupin)'
);

-- line #4048
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZISWIFT 200 (Lupin)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZISWIFT 200 (Lupin)'
);

-- line #4049
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZISWIFT 250 (Lupin)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZISWIFT 250 (Lupin)'
);

-- line #4050
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZISWIFT 500 (Lupin)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZISWIFT 500 (Lupin)'
);

-- line #4051
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITAD 250 (ADVENTUS)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITAD 250 (ADVENTUS)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITAD 500 (ADVENTUS)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITAD 500 (ADVENTUS)'
);

-- line #4052
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITA 100 (Zota Ph.)',
	'Azithromycin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITA 100 (Zota Ph.)'
);

-- line #4053
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITAG 250 (SMENTAG PH.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITAG 250 (SMENTAG PH.)'
);

-- line #4054
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITAG 500 (SMENTAG PH.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITAG 500 (SMENTAG PH.)'
);

-- line #4055
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITA READY MIX 200 (Zota Ph.)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITA READY MIX 200 (Zota Ph.)'
);

-- line #4056
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITA 250 (Zota Ph.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITA 250 (Zota Ph.)'
);

-- line #4057
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITA 500 (Zota Ph.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITA 500 (Zota Ph.)'
);

-- line #4058
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITECH 250 (HBC LIFESCIENCE)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITECH 250 (HBC LIFESCIENCE)'
);

-- line #4059
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITECH 500 (HBC LIFESCIENCE)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITECH 500 (HBC LIFESCIENCE)'
);

-- line #4060
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITEC 250 (Tripada)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITEC 250 (Tripada)'
);

-- line #4061
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITEC 500 (Tripada)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITEC 500 (Tripada)'
);

-- line #4062
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITEC 250 (Tripada BIO.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITEC 250 (Tripada BIO.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITEC 500 (Tripada BIO.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITEC 500 (Tripada BIO.)'
);

-- line #4063
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITEC 250 (UNITED BIO.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITEC 250 (UNITED BIO.)'
);

-- line #4064
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITEC 500 (UNITED BIO.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITEC 500 (UNITED BIO.)'
);

-- line #4065
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITEN 250 (ACTON LIFE)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITEN 250 (ACTON LIFE)'
);

-- line #4066
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITEN 500 (ACTON LIFE)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITEN 500 (ACTON LIFE)'
);

-- line #4067
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITER 100 (GUJ. TE.)',
	'Azithromycin',
	'SUSP',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITER 100 (GUJ. TE.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITER 200 (GUJ. TE.)',
	'Azithromycin',
	'SUSP',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITER 200 (GUJ. TE.)'
);

-- line #4068
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITER 100 (GUJ. TE.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITER 100 (GUJ. TE.)'
);

-- line #4069
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITER 250 (GUJ. TE.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITER 250 (GUJ. TE.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITER 500 (GUJ. TE.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITER 500 (GUJ. TE.)'
);

-- line #4070
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Azithromycin', u'always_empty': u'', u'form': u'LIQ', u'brand': u'AZITH', u'strength_3': u'', u'company': u'Zee Lab', u'unit': u''}

-- line #4071
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITHOM 250 (Om Bio.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITHOM 250 (Om Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITHOM 500 (Om Bio.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITHOM 500 (Om Bio.)'
);

-- line #4072
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITHRAL 500 (Alembic)',
	'Azithromycin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITHRAL 500 (Alembic)'
);

-- line #4073
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Azithromycin', u'always_empty': u'', u'form': u'DPS', u'brand': u'AZITHRAL JUN', u'strength_3': u'', u'company': u'Alembic', u'unit': u''}

-- line #4074
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITHRAL 100 (Alembic)',
	'Azithromycin',
	'KT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITHRAL 100 (Alembic)'
);

-- line #4075
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITHRAL SI 500 (ALEMBIC)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITHRAL SI 500 (ALEMBIC)'
);

-- line #4076
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2G', u'strength_2': u'', u'substance': u'Azithromycin', u'always_empty': u'', u'form': u'', u'brand': u'AZITHRAL STAT', u'strength_3': u'', u'company': u'ALEMBIC', u'unit': u''}

-- line #4077
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITHRAL 100 (Alembic)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITHRAL 100 (Alembic)'
);

-- line #4078
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITHRAL 200 (Alembic)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITHRAL 200 (Alembic)'
);

-- line #4079
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITHRAL 250 (Alembic)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITHRAL 250 (Alembic)'
);

-- line #4080
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITHRAL 500 (Alembic)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITHRAL 500 (Alembic)'
);

-- line #4081
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITHRO 250 (Ind-Swift)',
	'Azithromycin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITHRO 250 (Ind-Swift)'
);

-- line #4082
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITHRO 200 (Ind-Swift)',
	'Azithromycin',
	'D.SYR',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITHRO 200 (Ind-Swift)'
);

-- line #4083
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITHRO 200 (Ind-Swift)',
	'Azithromycin',
	'REDIMIX',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITHRO 200 (Ind-Swift)'
);

-- line #4084
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITHRO 100 (Ind-Swift(SUPER SP.))',
	'Azithromycin',
	'REDIMIX',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITHRO 100 (Ind-Swift(SUPER SP.))'
);

-- line #4085
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITHRO 250 (Ind-Swift(SUPER SP.))',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITHRO 250 (Ind-Swift(SUPER SP.))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITHRO 500 (Ind-Swift(SUPER SP.))',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITHRO 500 (Ind-Swift(SUPER SP.))'
);

-- line #4086
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITH 250 (EAST WEST)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITH 250 (EAST WEST)'
);

-- line #4087
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITH 500 (EAST WEST)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITH 500 (EAST WEST)'
);

-- line #4088
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITH 100 (Zee Lab)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITH 100 (Zee Lab)'
);

-- line #4089
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITH 250 (Zee Lab)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITH 250 (Zee Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITH 500 (Zee Lab)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITH 500 (Zee Lab)'
);

-- line #4090
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITIDE 100 (Tidal Lab)',
	'Azithromycin',
	'DT TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITIDE 100 (Tidal Lab)'
);

-- line #4091
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITIDE 200 (Tidal Lab)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITIDE 200 (Tidal Lab)'
);

-- line #4092
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITOME 250 (EPITOME)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITOME 250 (EPITOME)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITOME 500 (EPITOME)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITOME 500 (EPITOME)'
);

-- line #4093
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITON 20 (Auroma Life)',
	'Azithromycin',
	'SYR',
	gm.nullify_empty_string('20')::numeric,
	'mg/1ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITON 20 (Auroma Life)'
);

-- line #4094
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITON 250 (Auroma Life)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITON 250 (Auroma Life)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITON 500 (Auroma Life)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITON 500 (Auroma Life)'
);

-- line #4095
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITOP 250 (VIVA LAB.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITOP 250 (VIVA LAB.)'
);

-- line #4096
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITOP 500 (VIVA LAB.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITOP 500 (VIVA LAB.)'
);

-- line #4097
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITOZ 100 (Atoz Ph.)',
	'Azithromycin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITOZ 100 (Atoz Ph.)'
);

-- line #4098
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITOZ 250 (Atoz Ph.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITOZ 250 (Atoz Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITOZ 500 (Atoz Ph.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITOZ 500 (Atoz Ph.)'
);

-- line #4099
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITRAC 200 (Intra(INVISION))',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITRAC 200 (Intra(INVISION))'
);

-- line #4100
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITRAC 100 (INVISION)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITRAC 100 (INVISION)'
);

-- line #4101
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITRAC 250 (INVISION)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITRAC 250 (INVISION)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITRAC 500 (INVISION)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITRAC 500 (INVISION)'
);

-- line #4102
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITRAS 100 (Biostrass)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITRAS 100 (Biostrass)'
);

-- line #4103
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITRAS 250 (Biostrass)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITRAS 250 (Biostrass)'
);

-- line #4104
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITRAS 500 (Biostrass)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITRAS 500 (Biostrass)'
);

-- line #4105
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITRIN 250 (PHARMATECH)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITRIN 250 (PHARMATECH)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITRIN 500 (PHARMATECH)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITRIN 500 (PHARMATECH)'
);

-- line #4106
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITRIX 250 (ERIS LIFE)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITRIX 250 (ERIS LIFE)'
);

-- line #4107
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITRIX 500 (ERIS LIFE)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITRIX 500 (ERIS LIFE)'
);

-- line #4108
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITROY 250 (Troikaa)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITROY 250 (Troikaa)'
);

-- line #4109
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITROY 500 (Troikaa)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITROY 500 (Troikaa)'
);

-- line #4110
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITSA 100 (AKESISS)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITSA 100 (AKESISS)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITSA 200 (AKESISS)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITSA 200 (AKESISS)'
);

-- line #4111
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITSA 100 (AKESISS)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITSA 100 (AKESISS)'
);

-- line #4112
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITSA 250 (AKESISS)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITSA 250 (AKESISS)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITSA 500 (AKESISS)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITSA 500 (AKESISS)'
);

-- line #4113
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITUS 50 (Zuventus)',
	'Azithromycin',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITUS 50 (Zuventus)'
);

-- line #4114
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITUS 250 (Zuventus)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITUS 250 (Zuventus)'
);

-- line #4115
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZITUS 500 (Zuventus)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZITUS 500 (Zuventus)'
);

-- line #4116
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIVAR 100 (Zota)',
	'Azithromycin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIVAR 100 (Zota)'
);

-- line #4117
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIVAR 250 (Zota)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIVAR 250 (Zota)'
);

-- line #4118
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIVAR 500 (Zota)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIVAR 500 (Zota)'
);

-- line #4119
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIVENT 100 (Aristo)',
	'Azithromycin',
	'MD TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIVENT 100 (Aristo)'
);

-- line #4120
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIVENT 100 (Aristo)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIVENT 100 (Aristo)'
);

-- line #4121
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIVENT 200 (Aristo)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIVENT 200 (Aristo)'
);

-- line #4122
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIVENT 250 (Aristo)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIVENT 250 (Aristo)'
);

-- line #4123
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIVENT 500 (Aristo)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIVENT 500 (Aristo)'
);

-- line #4124
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIWIN 100 (Bal Ph.)',
	'Azithromycin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIWIN 100 (Bal Ph.)'
);

-- line #4125
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIWIN 100 (Bal Ph.)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg (READYMIX)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIWIN 100 (Bal Ph.)'
);

-- line #4126
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIWIN 200 (Bal Ph.)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg (READYMIX)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIWIN 200 (Bal Ph.)'
);

-- line #4127
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIWIN 250 (Bal Ph.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIWIN 250 (Bal Ph.)'
);

-- line #4128
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIWIN 500 (Bal Ph.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIWIN 500 (Bal Ph.)'
);

-- line #4129
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIWIS 100 (Wisdom Ph.)',
	'Azithromycin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIWIS 100 (Wisdom Ph.)'
);

-- line #4130
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIWIS 100 (Wisdom Ph.)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIWIS 100 (Wisdom Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIWIS 200 (Wisdom Ph.)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIWIS 200 (Wisdom Ph.)'
);

-- line #4131
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIWIS 250 (Wisdom Ph.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIWIS 250 (Wisdom Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIWIS 500 (Wisdom Ph.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIWIS 500 (Wisdom Ph.)'
);

-- line #4132
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIWOK 100 (Wockhardt)',
	'Azithromycin',
	'KT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIWOK 100 (Wockhardt)'
);

-- line #4133
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIWOK 200 (Wockhardt)',
	'Azithromycin',
	'LIQ',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIWOK 200 (Wockhardt)'
);

-- line #4134
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2G', u'strength_2': u'', u'substance': u'Azithromycin', u'always_empty': u'', u'form': u'', u'brand': u'AZIWOK STAT', u'strength_3': u'', u'company': u'Wochardt', u'unit': u''}

-- line #4135
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIWOK 100 (Wockhardt)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIWOK 100 (Wockhardt)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIWOK 200 (Wockhardt)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIWOK 200 (Wockhardt)'
);

-- line #4136
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIWOK 200 (Wockhardt)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/2.5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIWOK 200 (Wockhardt)'
);

-- line #4137
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIWOK 250 (Wockhardt)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIWOK 250 (Wockhardt)'
);

-- line #4138
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIWOK 500 (Wockhardt)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIWOK 500 (Wockhardt)'
);

-- line #4139
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIX 100 (ALICON PH.)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIX 100 (ALICON PH.)'
);

-- line #4140
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIX 250 (ALICON PH.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIX 250 (ALICON PH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIX 500 (ALICON PH.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIX 500 (ALICON PH.)'
);

-- line #4141
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIZEN 250 (ZENECA DRUGS)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIZEN 250 (ZENECA DRUGS)'
);

-- line #4142
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZLA 200 (CANDOR BIO.)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZLA 200 (CANDOR BIO.)'
);

-- line #4143
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZLA 20 (CANDOR BIO.)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('20')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZLA 20 (CANDOR BIO.)'
);

-- line #4144
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZLA 250 (Candor Bio.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZLA 250 (Candor Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZLA 500 (Candor Bio.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZLA 500 (Candor Bio.)'
);

-- line #4145
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZMAG 100 (Magnus Bio.)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZMAG 100 (Magnus Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZMAG 200 (Magnus Bio.)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZMAG 200 (Magnus Bio.)'
);

-- line #4146
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZMIC 250 (EMAR)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZMIC 250 (EMAR)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZMIC 500 (EMAR)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZMIC 500 (EMAR)'
);

-- line #4147
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Azithromycin', u'always_empty': u'', u'form': u'TAB', u'brand': u'AZM', u'strength_3': u'', u'company': u'KORES F.', u'unit': u''}

-- line #4148
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZMYCIN 250 (ZEDR)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZMYCIN 250 (ZEDR)'
);

-- line #4149
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZNEE 100 (Gufic Bio.)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZNEE 100 (Gufic Bio.)'
);

-- line #4150
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZNEE 200 (Gufic Bio.)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZNEE 200 (Gufic Bio.)'
);

-- line #4151
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZNEE 250 (Gufic Bio.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZNEE 250 (Gufic Bio.)'
);

-- line #4152
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZNEE 500 (Gufic Bio.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZNEE 500 (Gufic Bio.)'
);

-- line #4153
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Azithromycin', u'always_empty': u'', u'form': u'OD INJ', u'brand': u'AZ', u'strength_3': u'', u'company': u'Gufic Bio.', u'unit': u''}

-- line #4154
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZOKING 100 (CHEMO HC.)',
	'Azithromycin',
	'KID TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZOKING 100 (CHEMO HC.)'
);

-- line #4155
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZOKING 250 (CHEMO HC.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZOKING 250 (CHEMO HC.)'
);

-- line #4156
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZOKING 500 (CHEMO HC.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZOKING 500 (CHEMO HC.)'
);

-- line #4157
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZOMARC 250 (Marc Lab)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZOMARC 250 (Marc Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZOMARC 500 (Marc Lab)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZOMARC 500 (Marc Lab)'
);

-- line #4158
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZOMAX 250 (MAX)',
	'Azithromycin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZOMAX 250 (MAX)'
);

-- line #4159
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZOM 200 (Finecure)',
	'Azithromycin',
	'D.SYR',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZOM 200 (Finecure)'
);

-- line #4160
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZOM 100 (Finecure)',
	'Azithromycin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZOM 100 (Finecure)'
);

-- line #4161
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZOM 250 (Finecure)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZOM 250 (Finecure)'
);

-- line #4162
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZOM 500 (Finecure)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZOM 500 (Finecure)'
);

-- line #4163
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZONIX 250 (PHENIX PH.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZONIX 250 (PHENIX PH.)'
);

-- line #4164
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZONIX 500 (PHENIX PH.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZONIX 500 (PHENIX PH.)'
);

-- line #4165
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZOO 100 (Group Ph.)',
	'Azithromycin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZOO 100 (Group Ph.)'
);

-- line #4166
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZOO 250 (Group Ph.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZOO 250 (Group Ph.)'
);

-- line #4167
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZOO 500 (Group Ph.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZOO 500 (Group Ph.)'
);

-- line #4168
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZO 250 (SHRI SWAMI)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZO 250 (SHRI SWAMI)'
);

-- line #4169
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZO 500 (SHRI SWAMI)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZO 500 (SHRI SWAMI)'
);

-- line #4170
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZOTIK 100 (U S V)',
	'Azithromycin',
	'READYMIX',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZOTIK 100 (U S V)'
);

-- line #4171
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZOTIK 200 (U S V)',
	'Azithromycin',
	'READYMIX',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZOTIK 200 (U S V)'
);

-- line #4172
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZRADE 250 (GLOWDERMA)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZRADE 250 (GLOWDERMA)'
);

-- line #4173
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZRADE 500 (GLOWDERMA)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZRADE 500 (GLOWDERMA)'
);

-- line #4174
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZRAS 100 (RASS HC.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZRAS 100 (RASS HC.)'
);

-- line #4175
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZRAS 250 (RASS HC.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZRAS 250 (RASS HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZRAS 500 (RASS HC.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZRAS 500 (RASS HC.)'
);

-- line #4176
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZRO 100 (NPIL HC.)',
	'Azithromycin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZRO 100 (NPIL HC.)'
);

-- line #4177
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZRO 100 (NPIL HC.)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZRO 100 (NPIL HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZRO 200 (NPIL HC.)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZRO 200 (NPIL HC.)'
);

-- line #4178
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZRO 200 (Nicholas)',
	'Azithromycin',
	'SYR',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZRO 200 (Nicholas)'
);

-- line #4179
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZRO 1000 (NPIL HC.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZRO 1000 (NPIL HC.)'
);

-- line #4180
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZRO 250 (NPIL HC.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZRO 250 (NPIL HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZRO 500 (NPIL HC.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZRO 500 (NPIL HC.)'
);

-- line #4181
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZTEL 500 (ARTEL LAB.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZTEL 500 (ARTEL LAB.)'
);

-- line #4182
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZTIN 100 (LAKSUN)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZTIN 100 (LAKSUN)'
);

-- line #4183
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZTIN 250 (LAKSUN)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZTIN 250 (LAKSUN)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZTIN 500 (LAKSUN)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZTIN 500 (LAKSUN)'
);

-- line #4184
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZTUS 100 (Emcure)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZTUS 100 (Emcure)'
);

-- line #4185
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZTUS 200 (Emcure)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZTUS 200 (Emcure)'
);

-- line #4186
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZTUS 250 (Emcure)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZTUS 250 (Emcure)'
);

-- line #4187
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZTUS 500 (Emcure)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZTUS 500 (Emcure)'
);

-- line #4188
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZUMA 500 (Fulford)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZUMA 500 (Fulford)'
);

-- line #4189
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZU 250 (VILBERRY HC.)',
	'Azithromycin',
	'OD TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZU 250 (VILBERRY HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZU 500 (VILBERRY HC.)',
	'Azithromycin',
	'OD TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZU 500 (VILBERRY HC.)'
);

-- line #4190
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZU 200 (VILBERRY HC.)',
	'Azithromycin',
	'ORAL SUSP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZU 200 (VILBERRY HC.)'
);

-- line #4191
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZURE 250 (Allure Rem.)',
	'Azithromycin',
	'CAP/TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZURE 250 (Allure Rem.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZURE 500 (Allure Rem.)',
	'Azithromycin',
	'CAP/TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZURE 500 (Allure Rem.)'
);

-- line #4192
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZURT 100 (N. V. LIFE)',
	'Azithromycin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZURT 100 (N. V. LIFE)'
);

-- line #4193
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZURT 250 (N. V. LIFE)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZURT 250 (N. V. LIFE)'
);

-- line #4194
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZURT 500 (N. V. LIFE)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZURT 500 (N. V. LIFE)'
);

-- line #4195
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZU 100 (VILBERRY HC.)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZU 100 (VILBERRY HC.)'
);

-- line #4196
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZU 200 (VILBERRY HC.)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZU 200 (VILBERRY HC.)'
);

-- line #4197
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZU 250 (VILBERRY HC.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZU 250 (VILBERRY HC.)'
);

-- line #4198
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZU 500 (VILBERRY HC.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZU 500 (VILBERRY HC.)'
);

-- line #4199
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZVIG 100 (MADHAV BIO.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZVIG 100 (MADHAV BIO.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZVIG 200 (MADHAV BIO.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZVIG 200 (MADHAV BIO.)'
);

-- line #4200
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZVIG 500 (MADHAV BIO.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZVIG 500 (MADHAV BIO.)'
);

-- line #4201
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200', u'strength_2': u'', u'substance': u'Azithromycin', u'always_empty': u'', u'form': u'', u'brand': u'AZYCIN', u'strength_3': u'', u'company': u'ALEXUS(SURYA)', u'unit': u'mg'}

-- line #4202
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZYCIN 250 (ALEXUS(SURYA))',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZYCIN 250 (ALEXUS(SURYA))'
);

-- line #4203
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZYCIN 500 (ALEXUS(SURYA))',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZYCIN 500 (ALEXUS(SURYA))'
);

-- line #4204
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZYLIN 100 (MARLINE BIO.)',
	'Azithromycin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZYLIN 100 (MARLINE BIO.)'
);

-- line #4205
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZYLIN 250 (MARLINE BIO.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZYLIN 250 (MARLINE BIO.)'
);

-- line #4206
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZYLIN 500 (MARLINE BIO.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZYLIN 500 (MARLINE BIO.)'
);

-- line #4207
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZYNOVA 250 (Bombay T.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZYNOVA 250 (Bombay T.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZYNOVA 500 (Bombay T.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZYNOVA 500 (Bombay T.)'
);

-- line #4208
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZYSAFE 100 (Overseas Hc.)',
	'Azithromycin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZYSAFE 100 (Overseas Hc.)'
);

-- line #4209
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Azithromycin', u'always_empty': u'', u'form': u'DT', u'brand': u'AZYSAFE', u'strength_3': u'', u'company': u'Overseas Hc.', u'unit': u''}

-- line #4210
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZYSAFE 250 (Overseas Hc.)',
	'Azithromycin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZYSAFE 250 (Overseas Hc.)'
);

-- line #4211
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZYSAFE 500 (Overseas Hc.)',
	'Azithromycin',
	'DT',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZYSAFE 500 (Overseas Hc.)'
);

-- line #4212
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZYXIN 100 (Centaur)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZYXIN 100 (Centaur)'
);

-- line #4213
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZYXIN 250 (Centaur)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZYXIN 250 (Centaur)'
);

-- line #4214
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZYXIN 500 (Centaur)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZYXIN 500 (Centaur)'
);

-- line #4215
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZZA 200 (Wintech)',
	'Azithromycin',
	'SUSP',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZZA 200 (Wintech)'
);

-- line #4216
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZZA 100 (Wintech)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZZA 100 (Wintech)'
);

-- line #4217
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZZA 250 (Wintech)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZZA 250 (Wintech)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZZA 500 (Wintech)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZZA 500 (Wintech)'
);

-- line #4218
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACTROCIN 100 (Nexus)',
	'Azithromycin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACTROCIN 100 (Nexus)'
);

-- line #4219
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACTROCIN 200 (Nexus)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACTROCIN 200 (Nexus)'
);

-- line #4220
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACTROCIN 1000 (Nexus)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACTROCIN 1000 (Nexus)'
);

-- line #4221
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACTROCIN 250 (Nexus)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACTROCIN 250 (Nexus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACTROCIN 500 (Nexus)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACTROCIN 500 (Nexus)'
);

-- line #4222
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BAZINCE 100 (SHINCE)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BAZINCE 100 (SHINCE)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BAZINCE 200 (SHINCE)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BAZINCE 200 (SHINCE)'
);

-- line #4223
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BAZINCE 100 (SHINCE)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BAZINCE 100 (SHINCE)'
);

-- line #4224
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BAZINCE 250 (SHINCE)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BAZINCE 250 (SHINCE)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BAZINCE 500 (SHINCE)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BAZINCE 500 (SHINCE)'
);

-- line #4225
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BAZI 250 (Biocare Rem.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BAZI 250 (Biocare Rem.)'
);

-- line #4226
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIO-AZ 250 (Biomax Lab)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIO-AZ 250 (Biomax Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIO-AZ 500 (Biomax Lab)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIO-AZ 500 (Biomax Lab)'
);

-- line #4227
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAZITHRO 100 (Cachet)',
	'Azithromycin',
	'SYRUP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAZITHRO 100 (Cachet)'
);

-- line #4228
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAZITHRO 200 (Cachet)',
	'Azithromycin',
	'SYRUP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAZITHRO 200 (Cachet)'
);

-- line #4229
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAZITHRO 250 (Cachet)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAZITHRO 250 (Cachet)'
);

-- line #4230
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAZITHRO 500 (Cachet)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAZITHRO 500 (Cachet)'
);

-- line #4231
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUMYCIN 250 (Curex)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUMYCIN 250 (Curex)'
);

-- line #4232
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUMYCIN 500 (Curex)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUMYCIN 500 (Curex)'
);

-- line #4233
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEFTOLIDE 100 (Themis Ph.)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEFTOLIDE 100 (Themis Ph.)'
);

-- line #4234
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEFTOLIDE 200 (Themis Ph.)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEFTOLIDE 200 (Themis Ph.)'
);

-- line #4235
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEFTOLIDE 250 (THEMIS)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEFTOLIDE 250 (THEMIS)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEFTOLIDE 500 (THEMIS)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEFTOLIDE 500 (THEMIS)'
);

-- line #4236
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEZITHRO 100 (Devi Form.)',
	'Azithromycin',
	'D.SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEZITHRO 100 (Devi Form.)'
);

-- line #4237
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEZITHRO 250 (Devi Form.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEZITHRO 250 (Devi Form.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEZITHRO 500 (Devi Form.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEZITHRO 500 (Devi Form.)'
);

-- line #4238
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIZITHRO-200 200 (Divine Life)',
	'Azithromycin',
	'SUSP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIZITHRO-200 200 (Divine Life)'
);

-- line #4239
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIZITHRO 250 (Divine Life)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIZITHRO 250 (Divine Life)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIZITHRO 500 (Divine Life)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIZITHRO 500 (Divine Life)'
);

-- line #4240
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELDERAZE 250 (Elder)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELDERAZE 250 (Elder)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELDERAZE 500 (Elder)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELDERAZE 500 (Elder)'
);

-- line #4241
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELETHRO 100 (ELEMENT PH.)',
	'Azithromycin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELETHRO 100 (ELEMENT PH.)'
);

-- line #4242
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100', u'strength_2': u'', u'substance': u'Azithromycin', u'always_empty': u'', u'form': u'', u'brand': u'ELGRAM DRYSYR', u'strength_3': u'', u'company': u'Captab', u'unit': u'mg/5ML'}

-- line #4243
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200', u'strength_2': u'', u'substance': u'Azithromycin', u'always_empty': u'', u'form': u'', u'brand': u'ELGRAM DRYSYR', u'strength_3': u'', u'company': u'Captab', u'unit': u'mg/5ML'}

-- line #4244
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELGRAM 250 (Captab)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELGRAM 250 (Captab)'
);

-- line #4245
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELGRAM 500 (Captab)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELGRAM 500 (Captab)'
);

-- line #4246
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELZEE 100 (Elder)',
	'Azithromycin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELZEE 100 (Elder)'
);

-- line #4247
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELZEE 100 (Elder)',
	'Azithromycin',
	'READYMIX',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELZEE 100 (Elder)'
);

-- line #4248
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELZEE 200 (Elder)',
	'Azithromycin',
	'READYMIX',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELZEE 200 (Elder)'
);

-- line #4249
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELZEE 250 (Elder)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELZEE 250 (Elder)'
);

-- line #4250
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELZEE 500 (Elder)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELZEE 500 (Elder)'
);

-- line #4251
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMTHRAL 250 (UMBILICAL PH.)',
	'Azithromycin',
	'KID TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMTHRAL 250 (UMBILICAL PH.)'
);

-- line #4252
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMTHRAL 250 (UMBILICAL PH.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMTHRAL 250 (UMBILICAL PH.)'
);

-- line #4253
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMTHRAL 500 (UMBILICAL PH.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMTHRAL 500 (UMBILICAL PH.)'
);

-- line #4254
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100', u'strength_2': u'', u'substance': u'Azithromycin', u'always_empty': u'', u'form': u'', u'brand': u'EMTHRAL', u'strength_3': u'', u'company': u'UMBILICAL PH.', u'unit': u'mg'}

-- line #4255
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200', u'strength_2': u'', u'substance': u'Azithromycin', u'always_empty': u'', u'form': u'', u'brand': u'EMTHRAL', u'strength_3': u'', u'company': u'UMBILICAL PH.', u'unit': u'mg'}

-- line #4256
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Azithromycin', u'always_empty': u'', u'form': u'TAB', u'brand': u'ERONET', u'strength_3': u'', u'company': u'National', u'unit': u''}

-- line #4257
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERTYCIN 100 (Nicholas)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERTYCIN 100 (Nicholas)'
);

-- line #4258
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERTYCIN 200 (Nicholas)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERTYCIN 200 (Nicholas)'
);

-- line #4259
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERTYCIN 250 (Nicholas)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERTYCIN 250 (Nicholas)'
);

-- line #4260
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERTYCIN 500 (Nicholas)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERTYCIN 500 (Nicholas)'
);

-- line #4261
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESZIT 500 (Ester Form.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESZIT 500 (Ester Form.)'
);

-- line #4262
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EZITHRO 250 (ECON HC.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EZITHRO 250 (ECON HC.)'
);

-- line #4263
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EZITHRO 500 (ECON HC.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EZITHRO 500 (ECON HC.)'
);

-- line #4264
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLAAG 200 (FLAMINGO PH.)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLAAG 200 (FLAMINGO PH.)'
);

-- line #4265
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLAAG 100 (FLAMINGO PH.)',
	'Azithromycin',
	'SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLAAG 100 (FLAMINGO PH.)'
);

-- line #4266
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLAAG 250 (FLAMINGO PH.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLAAG 250 (FLAMINGO PH.)'
);

-- line #4267
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLAAG 500 (FLAMINGO PH.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLAAG 500 (FLAMINGO PH.)'
);

-- line #4268
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLAGG 200 (FLAMINGO PH.)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLAGG 200 (FLAMINGO PH.)'
);

-- line #4269
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORIT 100 (Health Care)',
	'Azithromycin',
	'KID TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORIT 100 (Health Care)'
);

-- line #4270
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORIT 20 (Health Care)',
	'Azithromycin',
	'SUSP',
	gm.nullify_empty_string('20')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORIT 20 (Health Care)'
);

-- line #4271
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORIT 250 (Health Care)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORIT 250 (Health Care)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORIT 500 (Health Care)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORIT 500 (Health Care)'
);

-- line #4272
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GERITHRON 500 (GERRYSUN PH.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GERITHRON 500 (GERRYSUN PH.)'
);

-- line #4273
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GITRO 100 (PLUS INDIA)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GITRO 100 (PLUS INDIA)'
);

-- line #4274
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GITRO 500 (PLUS INDIA)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GITRO 500 (PLUS INDIA)'
);

-- line #4275
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GOTINEX 250 (Nexus)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GOTINEX 250 (Nexus)'
);

-- line #4276
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRAMAC 200 (INVISION(INFALIFE))',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRAMAC 200 (INVISION(INFALIFE))'
);

-- line #4277
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRAMAC 100 (INVISION(INFALIFE))',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRAMAC 100 (INVISION(INFALIFE))'
);

-- line #4278
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Azithromycin', u'always_empty': u'', u'form': u'D.SYR', u'brand': u'G-THRO', u'strength_3': u'', u'company': u'Globus', u'unit': u''}

-- line #4279
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G-THRO 250 (Globus)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G-THRO 250 (Globus)'
);

-- line #4280
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G-THRO 500 (Globus)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G-THRO 500 (Globus)'
);

-- line #4281
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ITHA 250 (ALNA BIO.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ITHA 250 (ALNA BIO.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ITHA 500 (ALNA BIO.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ITHA 500 (ALNA BIO.)'
);

-- line #4282
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'I-THRO 250 (ZUBIT)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'I-THRO 250 (ZUBIT)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'I-THRO 500 (ZUBIT)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'I-THRO 500 (ZUBIT)'
);

-- line #4283
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JOCIN 250 (D.R.John''S)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JOCIN 250 (D.R.John''S)'
);

-- line #4284
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JOCIN 500 (D.R.John''S)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JOCIN 500 (D.R.John''S)'
);

-- line #4285
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEZI 100 (Cadex Lab)',
	'Azithromycin',
	'D.SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEZI 100 (Cadex Lab)'
);

-- line #4286
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEZI 100 (Cadex Lab)',
	'Azithromycin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEZI 100 (Cadex Lab)'
);

-- line #4287
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEZI 250 (Cadex Lab)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEZI 250 (Cadex Lab)'
);

-- line #4288
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAZ 100 (GENX)',
	'Azithromycin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAZ 100 (GENX)'
);

-- line #4289
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100', u'strength_2': u'200', u'substance': u'Azithromycin', u'always_empty': u'', u'form': u'', u'brand': u'LAZ SYS', u'strength_3': u'', u'company': u'GENX', u'unit': u'mg/5ML'}

-- line #4290
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAZ 250 (GENX)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAZ 250 (GENX)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAZ 500 (GENX)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAZ 500 (GENX)'
);

-- line #4291
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Azithromycin', u'always_empty': u'', u'form': u'TAB', u'brand': u'LAZ', u'strength_3': u'', u'company': u'HETERO HC.', u'unit': u''}

-- line #4292
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100', u'strength_2': u'', u'substance': u'Azithromycin', u'always_empty': u'', u'form': u'', u'brand': u'LEMTHRO', u'strength_3': u'', u'company': u'LEMON PH.', u'unit': u'mg'}

-- line #4293
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200', u'strength_2': u'', u'substance': u'Azithromycin', u'always_empty': u'', u'form': u'', u'brand': u'LEMTHRO', u'strength_3': u'', u'company': u'LEMON PH.', u'unit': u'mg'}

-- line #4294
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEMTHRO 250 (LEMON PH.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEMTHRO 250 (LEMON PH.)'
);

-- line #4295
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEMTHRO 500 (LEMON PH.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEMTHRO 500 (LEMON PH.)'
);

-- line #4296
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LG-THRAL 250 (ANVIK BIO.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LG-THRAL 250 (ANVIK BIO.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LG-THRAL 500 (ANVIK BIO.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LG-THRAL 500 (ANVIK BIO.)'
);

-- line #4297
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOROMYCIN 250 (Novartis)',
	'Azithromycin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOROMYCIN 250 (Novartis)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOROMYCIN 500 (Novartis)',
	'Azithromycin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOROMYCIN 500 (Novartis)'
);

-- line #4298
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOROMYCIN 500 (Novartis)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOROMYCIN 500 (Novartis)'
);

-- line #4299
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'L-THRO 250 (Lexus)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'L-THRO 250 (Lexus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'L-THRO 500 (Lexus)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'L-THRO 500 (Lexus)'
);

-- line #4300
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUTHRO 250 (LUCIFER & H.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUTHRO 250 (LUCIFER & H.)'
);

-- line #4301
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUTHRO 500 (LUCIFER & H.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUTHRO 500 (LUCIFER & H.)'
);

-- line #4302
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250', u'strength_2': u'', u'substance': u'Azithromycin', u'always_empty': u'', u'form': u'', u'brand': u'MACROLIFE -', u'strength_3': u'', u'company': u'GEMLIFE PH.', u'unit': u'mg'}

-- line #4303
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500', u'strength_2': u'', u'substance': u'Azithromycin', u'always_empty': u'', u'form': u'', u'brand': u'MACROLIFE -', u'strength_3': u'', u'company': u'GEMLIFE PH.', u'unit': u'mg'}

-- line #4304
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACROSAFE 250 (SAFE MED(MSN))',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACROSAFE 250 (SAFE MED(MSN))'
);

-- line #4305
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACROSAFE 500 (SAFE MED(MSN))',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACROSAFE 500 (SAFE MED(MSN))'
);

-- line #4306
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACROTAR 250 (Torrent)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACROTAR 250 (Torrent)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACROTAR 500 (Torrent)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACROTAR 500 (Torrent)'
);

-- line #4307
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2G', u'strength_2': u'', u'substance': u'Azithromycin', u'always_empty': u'', u'form': u'', u'brand': u'MACROTOR STAT', u'strength_3': u'', u'company': u'Torrent', u'unit': u''}

-- line #4308
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACROTOR 100 (Torrent)',
	'Azithromycin',
	'SUSP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACROTOR 100 (Torrent)'
);

-- line #4309
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACROTOR 200 (Torrent)',
	'Azithromycin',
	'SUSP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACROTOR 200 (Torrent)'
);

-- line #4310
-- ignoring line: field [strength_2] not numeric: >>>500(DIHYDR.)<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': Decimal('250'), u'strength_2': u'500(DIHYDR.)', u'substance': u'Azithromycin', u'always_empty': u'', u'form': u'TAB', u'brand': u'MACROTOR', u'strength_3': u'', u'company': u'Torrent', u'unit': u'mg'}

-- line #4311
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACROZIP 250 (BIENSTAR)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACROZIP 250 (BIENSTAR)'
);

-- line #4312
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACROZIP 500 (BIENSTAR)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACROZIP 500 (BIENSTAR)'
);

-- line #4313
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACROZITH 250 (STEVELS)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACROZITH 250 (STEVELS)'
);

-- line #4314
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACROZITH 500 (STEVELS)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACROZITH 500 (STEVELS)'
);

-- line #4315
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACROZIT 250 (LA SERENA)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACROZIT 250 (LA SERENA)'
);

-- line #4316
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAZITH 250 (Globus)',
	'Azithromycin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAZITH 250 (Globus)'
);

-- line #4317
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILZI 100 (Shaimil)',
	'Azithromycin',
	'KID TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILZI 100 (Shaimil)'
);

-- line #4318
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILZI 250 (Shaimil)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILZI 250 (Shaimil)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILZI 500 (Shaimil)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILZI 500 (Shaimil)'
);

-- line #4319
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIOMYCIN 200 (Rekvina)',
	'Azithromycin',
	'SYR',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIOMYCIN 200 (Rekvina)'
);

-- line #4320
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIOMYCIN 100 (Rekvina)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIOMYCIN 100 (Rekvina)'
);

-- line #4321
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIOMYCIN 250 (Rekvina)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIOMYCIN 250 (Rekvina)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIOMYCIN 500 (Rekvina)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIOMYCIN 500 (Rekvina)'
);

-- line #4322
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MORZIT 100 (Dial Ph.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MORZIT 100 (Dial Ph.)'
);

-- line #4323
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MORZIT 250 (Dial Ph.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MORZIT 250 (Dial Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MORZIT 500 (Dial Ph.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MORZIT 500 (Dial Ph.)'
);

-- line #4324
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MORZIT 250 (Dial Ph.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MORZIT 250 (Dial Ph.)'
);

-- line #4325
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NANO 250 (KIVI LABS)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NANO 250 (KIVI LABS)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NANO 500 (KIVI LABS)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NANO 500 (KIVI LABS)'
);

-- line #4326
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NICY 250 (ALPHA TH.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NICY 250 (ALPHA TH.)'
);

-- line #4327
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NICY 500 (ALPHA TH.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NICY 500 (ALPHA TH.)'
);

-- line #4328
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIZITHRO 500 (NEISS)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIZITHRO 500 (NEISS)'
);

-- line #4329
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NTHROSIN 250 (NUMED LAB.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NTHROSIN 250 (NUMED LAB.)'
);

-- line #4330
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NTHROSIN 500 (NUMED LAB.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NTHROSIN 500 (NUMED LAB.)'
);

-- line #4331
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODIMAC 250 (Water Lilly)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODIMAC 250 (Water Lilly)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODIMAC 500 (Water Lilly)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODIMAC 500 (Water Lilly)'
);

-- line #4332
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPTITHROCIN 10 (Entod Ph.)',
	'Azithromycin',
	'EYE DPS',
	gm.nullify_empty_string('10')::numeric,
	'mg(ANHYDRT)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPTITHROCIN 10 (Entod Ph.)'
);

-- line #4333
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORTIZA 100 (Medopharm)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORTIZA 100 (Medopharm)'
);

-- line #4334
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORTIZA 200 (Medopharm)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORTIZA 200 (Medopharm)'
);

-- line #4335
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORTIZA 250 (Medopharm)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORTIZA 250 (Medopharm)'
);

-- line #4336
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORTIZA 500 (Medopharm)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORTIZA 500 (Medopharm)'
);

-- line #4337
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OZITH 100 (AXYZEN LIFE)',
	'Azithromycin',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OZITH 100 (AXYZEN LIFE)'
);

-- line #4338
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OZITH 250 (AXYZEN LIFE)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OZITH 250 (AXYZEN LIFE)'
);

-- line #4339
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OZITH 500 (AXYZEN LIFE)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OZITH 500 (AXYZEN LIFE)'
);

-- line #4340
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'O''ZITUFF 250 (OXYGEN PH.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'O''ZITUFF 250 (OXYGEN PH.)'
);

-- line #4341
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLUGCIN 250 (Samarth LIFE)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLUGCIN 250 (Samarth LIFE)'
);

-- line #4342
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLUGCIN 500 (Samarth LIFE)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLUGCIN 500 (Samarth LIFE)'
);

-- line #4343
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Azithromycin', u'always_empty': u'', u'form': u'D.SYR', u'brand': u'PRATHAM', u'strength_3': u'', u'company': u'Alkem', u'unit': u''}

-- line #4344
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2GM', u'strength_2': u'', u'substance': u'Azithromycin', u'always_empty': u'', u'form': u'TAB', u'brand': u'PRATHAM GM STAT', u'strength_3': u'', u'company': u'Alkem', u'unit': u''}

-- line #4345
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100', u'strength_2': u'', u'substance': u'Azithromycin', u'always_empty': u'', u'form': u'', u'brand': u'PRATHAM REDIUSE', u'strength_3': u'', u'company': u'ALKEM', u'unit': u'mg'}

-- line #4346
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200', u'strength_2': u'', u'substance': u'Azithromycin', u'always_empty': u'', u'form': u'', u'brand': u'PRATHAM REDIUSE', u'strength_3': u'', u'company': u'ALKEM', u'unit': u'mg'}

-- line #4347
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRATHAM 250 (Alkem)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRATHAM 250 (Alkem)'
);

-- line #4348
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRATHAM 500 (Alkem)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRATHAM 500 (Alkem)'
);

-- line #4349
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRAZITH 250 (PRISM LIFESCI.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRAZITH 250 (PRISM LIFESCI.)'
);

-- line #4350
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRAZITH 500 (PRISM LIFESCI.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRAZITH 500 (PRISM LIFESCI.)'
);

-- line #4351
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q-AZI 250 (PALSONS D.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q-AZI 250 (PALSONS D.)'
);

-- line #4352
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q-AZI 500 (PALSONS D.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q-AZI 500 (PALSONS D.)'
);

-- line #4353
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REMYCINE 200 (East India)',
	'Azithromycin',
	'SUSP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REMYCINE 200 (East India)'
);

-- line #4354
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REMYCINE 250 (East India)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REMYCINE 250 (East India)'
);

-- line #4355
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REMYCINE 500 (East India)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REMYCINE 500 (East India)'
);

-- line #4356
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESKIN 250 (J.P.LIFE)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESKIN 250 (J.P.LIFE)'
);

-- line #4357
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESKIN 500 (J.P.LIFE)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESKIN 500 (J.P.LIFE)'
);

-- line #4358
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REZI 250 (Runa Ph.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REZI 250 (Runa Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REZI 500 (Runa Ph.)',
	'Azithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REZI 500 (Runa Ph.)'
);

-- line #4359
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'2G', u'substance': u'AZTREONAM', u'always_empty': u'', u'form': u'', u'brand': u'AZACTAM G/2VIAL', u'strength_3': u'', u'company': u'BRISTOL MYERS', u'unit': u''}

-- line #4360
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZENAM 250 (Aristo)',
	'AZTREONAM',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZENAM 250 (Aristo)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZENAM 500 (Aristo)',
	'AZTREONAM',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZENAM 500 (Aristo)'
);

-- line #4361
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'AZTREONAM', u'always_empty': u'', u'form': u'VIAL', u'brand': u'AZENAM', u'strength_3': u'', u'company': u'Aristo', u'unit': u''}

-- line #4362
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2G', u'strength_2': u'', u'substance': u'AZTREONAM', u'always_empty': u'', u'form': u'VIAL', u'brand': u'AZENAM', u'strength_3': u'', u'company': u'Aristo', u'unit': u''}

-- line #4363
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1GM', u'strength_2': u'', u'substance': u'AZTREONAM', u'always_empty': u'', u'form': u'INJ', u'brand': u'AZOM', u'strength_3': u'', u'company': u'United Bio.', u'unit': u''}

-- line #4364
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'AZTREONAM', u'always_empty': u'', u'form': u'', u'brand': u'AZOTUM-1INJ', u'strength_3': u'', u'company': u'VENUS REM.', u'unit': u''}

-- line #4365
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2G', u'strength_2': u'', u'substance': u'AZTREONAM', u'always_empty': u'', u'form': u'', u'brand': u'AZOTUM-2INJ', u'strength_3': u'', u'company': u'VENUS REM.', u'unit': u''}

-- line #4366
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.5G', u'strength_2': u'', u'substance': u'AZTREONAM', u'always_empty': u'', u'form': u'VIAL', u'brand': u'AZTREO', u'strength_3': u'', u'company': u'Zydus Cadila', u'unit': u''}

-- line #4367
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'AZTREONAM', u'always_empty': u'', u'form': u'VIAL', u'brand': u'AZTREO', u'strength_3': u'', u'company': u'Zydus Cadila', u'unit': u''}

-- line #4368
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2G', u'strength_2': u'', u'substance': u'AZTREONAM', u'always_empty': u'', u'form': u'VIAL', u'brand': u'AZTREO', u'strength_3': u'', u'company': u'Zydus Cadila', u'unit': u''}

-- line #4369
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZTRONE 1000 (Neon)',
	'AZTREONAM',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg (ADDED L-ARGININE AS BUFFER)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZTRONE 1000 (Neon)'
);

-- line #4370
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZTRONE 2000 (Neon)',
	'AZTREONAM',
	'INJ',
	gm.nullify_empty_string('2000')::numeric,
	'mg (ADDED L-ARGININE AS BUFFER)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZTRONE 2000 (Neon)'
);

-- line #4371
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZTRONE 500 (Neon)',
	'AZTREONAM',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg (ADDED L-ARGININE AS BUFFER)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZTRONE 500 (Neon)'
);

-- line #4372
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'AZTREONAM', u'always_empty': u'', u'form': u'INJ', u'brand': u'REONAM', u'strength_3': u'', u'company': u'UNIMARK REM.', u'unit': u''}

-- line #4373
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3G', u'strength_2': u'', u'substance': u'AZTREONAM', u'always_empty': u'', u'form': u'INJ', u'brand': u'REONAM', u'strength_3': u'', u'company': u'UNIMARK REM.', u'unit': u''}

-- line #4374
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'BABY PRODUCTS', u'always_empty': u'', u'form': u'', u'brand': u'BABYCARE GIFT BASKET', u'strength_3': u'', u'company': u'Himalaya', u'unit': u''}

-- line #4375
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACLOF 20 (Intas)',
	'Baclofen',
	'OD TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACLOF 20 (Intas)'
);

-- line #4376
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACLOF 30 (Intas)',
	'Baclofen',
	'OD TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACLOF 30 (Intas)'
);

-- line #4377
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACLOF 10 (Intas)',
	'Baclofen',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACLOF 10 (Intas)'
);

-- line #4378
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACLOF 25 (Intas)',
	'Baclofen',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACLOF 25 (Intas)'
);

-- line #4379
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACMAX 10 (Biomax Lab)',
	'Baclofen',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACMAX 10 (Biomax Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACMAX 25 (Biomax Lab)',
	'Baclofen',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACMAX 25 (Biomax Lab)'
);

-- line #4380
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHINOFEN 10 (CH.Bhagat)',
	'Baclofen',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHINOFEN 10 (CH.Bhagat)'
);

-- line #4381
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIOFEN 500 (Sun)',
	'Baclofen',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIOFEN 500 (Sun)'
);

-- line #4382
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIOFEN 50 (Sun)',
	'Baclofen',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIOFEN 50 (Sun)'
);

-- line #4383
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIOFEN 10 (Sun)',
	'Baclofen',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIOFEN 10 (Sun)'
);

-- line #4384
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIOFEN 25 (Sun)',
	'Baclofen',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIOFEN 25 (Sun)'
);

-- line #4385
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIOFEN 50 (Sun)',
	'Baclofen',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIOFEN 50 (Sun)'
);

-- line #4386
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIOFEN 5 (Sun)',
	'Baclofen',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIOFEN 5 (Sun)'
);

-- line #4387
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIOFEN 20 (Sun)',
	'Baclofen',
	'XL CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIOFEN 20 (Sun)'
);

-- line #4388
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIOFEN 30 (Sun)',
	'Baclofen',
	'XL CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIOFEN 30 (Sun)'
);

-- line #4389
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIOFEN 40 (Sun)',
	'Baclofen',
	'XL CAP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIOFEN 40 (Sun)'
);

-- line #4390
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIORESAL 10 (Novartis)',
	'Baclofen',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIORESAL 10 (Novartis)'
);

-- line #4391
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIORESAL 25 (Novartis)',
	'Baclofen',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIORESAL 25 (Novartis)'
);

-- line #4392
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEUROFEN 10 (Vhb)',
	'Baclofen',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEUROFEN 10 (Vhb)'
);

-- line #4393
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RICLOFEN 10 (Samarth)',
	'Baclofen',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RICLOFEN 10 (Samarth)'
);

-- line #4394
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RICLOFEN 25 (Samarth)',
	'Baclofen',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RICLOFEN 25 (Samarth)'
);

-- line #4395
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROMIND 150 (Sysmed)',
	'BACOPA MONNIERA EXTRACT',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROMIND 150 (Sysmed)'
);

-- line #4396
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BALOFORCE 100 (Mankind)',
	'BALOFLOXACIN',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BALOFORCE 100 (Mankind)'
);

-- line #4397
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BALOFOX 100 (Piramal Hc.)',
	'BALOFLOXACIN',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BALOFOX 100 (Piramal Hc.)'
);

-- line #4398
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BALOMAC 100 (MACLEODS)',
	'BALOFLOXACIN',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BALOMAC 100 (MACLEODS)'
);

-- line #4399
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BALORAIN 100 (Torrent)',
	'BALOFLOXACIN',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BALORAIN 100 (Torrent)'
);

-- line #4400
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BALOTERO 100 (HETERO HC.)',
	'BALOFLOXACIN',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BALOTERO 100 (HETERO HC.)'
);

-- line #4401
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BALOXIN 100 (Alkem)',
	'BALOFLOXACIN',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BALOXIN 100 (Alkem)'
);

-- line #4402
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BALO-X 100 (Aristo)',
	'BALOFLOXACIN',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BALO-X 100 (Aristo)'
);

-- line #4403
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BAZOSTAR 100 (LASOR PH.)',
	'BALOFLOXACIN',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BAZOSTAR 100 (LASOR PH.)'
);

-- line #4404
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COLOREX 750 (Rexcel)',
	'BALSALAZIDE',
	'CAP',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COLOREX 750 (Rexcel)'
);

-- line #4405
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'BALSALAZIDE', u'always_empty': u'', u'form': u'SYR', u'brand': u'COLOREX', u'strength_3': u'', u'company': u'Rexcel', u'unit': u''}

-- line #4406
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTAZIDE 750 (Intas)',
	'BALSALAZIDE',
	'CAP',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTAZIDE 750 (Intas)'
);

-- line #4407
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ABEL 10 (Lupin)',
	'Bambuterol',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ABEL 10 (Lupin)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ABEL 20 (Lupin)',
	'Bambuterol',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ABEL 20 (Lupin)'
);

-- line #4408
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASTHAFREE 2 (Zuventus)',
	'Bambuterol',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASTHAFREE 2 (Zuventus)'
);

-- line #4409
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASTHAFREE 10 (Zuventus)',
	'Bambuterol',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASTHAFREE 10 (Zuventus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASTHAFREE 20 (Zuventus)',
	'Bambuterol',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASTHAFREE 20 (Zuventus)'
);

-- line #4410
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BAMBUDIL ORAL 1 (Cipla)',
	'Bambuterol',
	'SOL',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BAMBUDIL ORAL 1 (Cipla)'
);

-- line #4411
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BAMBUDIL 10 (Cipla)',
	'Bambuterol',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BAMBUDIL 10 (Cipla)'
);

-- line #4412
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BAMBUDIL 20 (Cipla)',
	'Bambuterol',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BAMBUDIL 20 (Cipla)'
);

-- line #4413
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BEMLO 1 (Emcure)',
	'Bambuterol',
	'SYR',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BEMLO 1 (Emcure)'
);

-- line #4414
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BEMLO 10 (Emcure)',
	'Bambuterol',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BEMLO 10 (Emcure)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BEMLO 20 (Emcure)',
	'Bambuterol',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BEMLO 20 (Emcure)'
);

-- line #4415
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETADAY 5 (Solares (Sun))',
	'Bambuterol',
	'LIQ',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETADAY 5 (Solares (Sun))'
);

-- line #4416
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETADAY 10 (Solares (Sun))',
	'Bambuterol',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETADAY 10 (Solares (Sun))'
);

-- line #4417
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETADAY 20 (Solares (Sun))',
	'Bambuterol',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETADAY 20 (Solares (Sun))'
);

-- line #4418
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COZABAL 750 (SUN)',
	'BASALAXIDE',
	'CAP',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COZABAL 750 (SUN)'
);

-- line #4419
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Bcg Vaccine', u'always_empty': u'', u'form': u'VIAL', u'brand': u'BCG', u'strength_3': u'', u'company': u'Aventis Pas.', u'unit': u''}

-- line #4420
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Bcg Vaccine', u'always_empty': u'', u'form': u'VIAL', u'brand': u'BCG', u'strength_3': u'', u'company': u'Serum Inst.', u'unit': u''}

-- line #4421
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Bcg Vaccine', u'always_empty': u'', u'form': u'INJ', u'brand': u'ONCO TICE', u'strength_3': u'', u'company': u'Infar', u'unit': u''}

-- line #4422
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENGLOBE 200 (Astrazeneca)',
	'Becampicillin Hcl.',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENGLOBE 200 (Astrazeneca)'
);

-- line #4423
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENGLOBE 400 (Astrazeneca)',
	'Becampicillin Hcl.',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENGLOBE 400 (Astrazeneca)'
);

-- line #4424
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BECLODERM 0.025 (INTERMED)',
	'BECLOMETASONE',
	'LOT',
	gm.nullify_empty_string('0.025')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BECLODERM 0.025 (INTERMED)'
);

-- line #4425
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50MCG', u'strength_2': u'DOSE', u'substance': u'Beclomethasone', u'always_empty': u'', u'form': u'', u'brand': u'BECLATE AQUANASE', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #4426
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BAYCORT 0.025 (Bayer)',
	'Beclomethasone Diprop.',
	'CRM',
	gm.nullify_empty_string('0.025')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BAYCORT 0.025 (Bayer)'
);

-- line #4427
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BECDERM 0.025 (Cipla)',
	'Beclomethasone Diprop.',
	'CRM',
	gm.nullify_empty_string('0.025')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BECDERM 0.025 (Cipla)'
);

-- line #4428
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BECLASONE 0.025 (Emcure)',
	'Beclomethasone Diprop.',
	'CRM',
	gm.nullify_empty_string('0.025')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BECLASONE 0.025 (Emcure)'
);

-- line #4429
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BECLATE 0.025 (Cipla)',
	'Beclomethasone Diprop.',
	'CRM',
	gm.nullify_empty_string('0.025')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BECLATE 0.025 (Cipla)'
);

-- line #4430
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200MCG', u'strength_2': u'250MCG', u'substance': u'Beclomethasone Diprop.', u'always_empty': u'', u'form': u'INHALER', u'brand': u'BECLATE', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #4431
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50MCG', u'strength_2': u'100MCG', u'substance': u'Beclomethasone Diprop.', u'always_empty': u'', u'form': u'INHALER', u'brand': u'BECLATE', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #4432
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50MCG', u'strength_2': u'', u'substance': u'Beclomethasone Diprop.', u'always_empty': u'', u'form': u'NASAL SPRAY', u'brand': u'BECLATE', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #4433
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100', u'strength_2': u'200', u'substance': u'Beclomethasone Diprop.', u'always_empty': u'', u'form': u'ROTACAPS', u'brand': u'BECLATE', u'strength_3': u'400;MCG', u'company': u'Cipla', u'unit': u''}

-- line #4434
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100', u'strength_2': u'200MCG', u'substance': u'Beclomethasone Diprop.', u'always_empty': u'', u'form': u'ROTACAPS', u'brand': u'BECLATE', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #4435
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'400MCG', u'strength_2': u'', u'substance': u'Beclomethasone Diprop.', u'always_empty': u'', u'form': u'ROTACAPS', u'brand': u'BECLATE', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #4436
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BECLODIP 0.025 (Camlin)',
	'Beclomethasone Diprop.',
	'CRM',
	gm.nullify_empty_string('0.025')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BECLODIP 0.025 (Camlin)'
);

-- line #4437
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BECLO 0.025 (Vilco)',
	'Beclomethasone Diprop.',
	'LOT',
	gm.nullify_empty_string('0.025')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BECLO 0.025 (Vilco)'
);

-- line #4438
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Beclomethasone Diprop.', u'always_empty': u'', u'form': u'CRM', u'brand': u'BECLOSAN', u'strength_3': u'', u'company': u'SANCHEZ LAB.', u'unit': u''}

-- line #4439
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250MCG', u'strength_2': u'', u'substance': u'Beclomethasone Diprop.', u'always_empty': u'', u'form': u'F. INH', u'brand': u'BECORIDE', u'strength_3': u'', u'company': u'Gsk', u'unit': u''}

-- line #4440
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50MCG', u'strength_2': u'100MCG', u'substance': u'Beclomethasone Diprop.', u'always_empty': u'', u'form': u'', u'brand': u'BECORIDE INH', u'strength_3': u'', u'company': u'Gsk', u'unit': u''}

-- line #4441
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50MCG', u'strength_2': u'1PUFF', u'substance': u'Beclomethasone Diprop.', u'always_empty': u'', u'form': u'', u'brand': u'BECORIDE JUNIOR MDI', u'strength_3': u'', u'company': u'GSK', u'unit': u''}

-- line #4442
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100MCG', u'strength_2': u'1PUFF', u'substance': u'Beclomethasone Diprop.', u'always_empty': u'', u'form': u'', u'brand': u'BECORIDE MDI', u'strength_3': u'', u'company': u'GSK', u'unit': u''}

-- line #4443
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BEKFORM 200 (Cipla)',
	'Beclomethasone Diprop.',
	'ROTACAPS',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BEKFORM 200 (Cipla)'
);

-- line #4444
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'400MCG', u'strength_2': u'', u'substance': u'Beclomethasone Diprop.', u'always_empty': u'', u'form': u'ROTACAPS', u'brand': u'BEKFORM', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #4445
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BELAR 0.025 (Comed)',
	'Beclomethasone Diprop.',
	'CRM',
	gm.nullify_empty_string('0.025')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BELAR 0.025 (Comed)'
);

-- line #4446
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BELONATE 0.025 (Gujarat Ph.)',
	'Beclomethasone Diprop.',
	'CRM',
	gm.nullify_empty_string('0.025')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BELONATE 0.025 (Gujarat Ph.)'
);

-- line #4447
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETA 0.05 (Micro Labs)',
	'Beclomethasone Diprop.',
	'GEL',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETA 0.05 (Micro Labs)'
);

-- line #4448
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100', u'strength_2': u'200;MCG(POW. INH.)', u'substance': u'Beclomethasone Diprop.', u'always_empty': u'', u'form': u'', u'brand': u'BEVENT EASECAPS', u'strength_3': u'', u'company': u'Kresp', u'unit': u''}

-- line #4449
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100MCG', u'strength_2': u'', u'substance': u'Beclomethasone Diprop.', u'always_empty': u'', u'form': u'INHALER', u'brand': u'BEVENT', u'strength_3': u'', u'company': u'Kresp', u'unit': u''}

-- line #4450
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250MCG', u'strength_2': u'', u'substance': u'Beclomethasone Diprop.', u'always_empty': u'', u'form': u'INHALER', u'brand': u'BEVENT', u'strength_3': u'', u'company': u'Kresp', u'unit': u''}

-- line #4451
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Beclomethasone Diprop.', u'always_empty': u'', u'form': u'CRM', u'brand': u'BICLO', u'strength_3': u'', u'company': u'Satyam', u'unit': u''}

-- line #4452
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORTISONE-BM 0.025 (PSYCOREM)',
	'Beclomethasone Diprop.',
	'CRM',
	gm.nullify_empty_string('0.025')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORTISONE-BM 0.025 (PSYCOREM)'
);

-- line #4453
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DERBEC 0.025 (Alkem)',
	'Beclomethasone Diprop.',
	'CRM',
	gm.nullify_empty_string('0.025')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DERBEC 0.025 (Alkem)'
);

-- line #4454
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIPROBEC 0.025 (Ranbaxy)',
	'Beclomethasone Diprop.',
	'CRM',
	gm.nullify_empty_string('0.025')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIPROBEC 0.025 (Ranbaxy)'
);

-- line #4455
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIPROBEC 0.025 (Croslands)',
	'Beclomethasone Diprop.',
	'LOT',
	gm.nullify_empty_string('0.025')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIPROBEC 0.025 (Croslands)'
);

-- line #4456
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIPROBEC-RD 0.0125 (Ranbaxy)',
	'Beclomethasone Diprop.',
	'CRM',
	gm.nullify_empty_string('0.0125')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIPROBEC-RD 0.0125 (Ranbaxy)'
);

-- line #4457
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIPROMILD 0.0125 (Somatico)',
	'Beclomethasone Diprop.',
	'CRM',
	gm.nullify_empty_string('0.0125')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIPROMILD 0.0125 (Somatico)'
);

-- line #4458
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ECONASE 0.05 (Gsk)',
	'Beclomethasone Diprop.',
	'NASAL SPRAY',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ECONASE 0.05 (Gsk)'
);

-- line #4459
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200MCG', u'strength_2': u'', u'substance': u'Beclomethasone Diprop.', u'always_empty': u'', u'form': u'ROTACAPS', u'brand': u'FULLFORM', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #4460
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'400MCG', u'strength_2': u'', u'substance': u'Beclomethasone Diprop.', u'always_empty': u'', u'form': u'ROTACAPS', u'brand': u'FULLFORM', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #4461
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLEONCO 15 (Vhb)',
	'Belomycin',
	'INJ',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLEONCO 15 (Vhb)'
);

-- line #4462
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OIL BLEO 30 (Khandelwal)',
	'Belomycin',
	'INJ',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OIL BLEO 30 (Khandelwal)'
);

-- line #4463
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2500IU.(SOL.)', u'strength_2': u'', u'substance': u'BEMIPARIN SODIUM', u'always_empty': u'', u'form': u'INJ', u'brand': u'HIBOR', u'strength_3': u'', u'company': u'Elder', u'unit': u''}

-- line #4464
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3500IU.(SOL.)', u'strength_2': u'', u'substance': u'BEMIPARIN SODIUM', u'always_empty': u'', u'form': u'INJ', u'brand': u'HIBOR', u'strength_3': u'', u'company': u'Elder', u'unit': u''}

-- line #4465
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU.(SOL.)', u'strength_2': u'', u'substance': u'BEMIPARIN SODIUM', u'always_empty': u'', u'form': u'INJ', u'brand': u'HIBOR', u'strength_3': u'', u'company': u'Elder', u'unit': u''}

-- line #4466
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'7500IU.(SOL.)', u'strength_2': u'', u'substance': u'BEMIPARIN SODIUM', u'always_empty': u'', u'form': u'INJ', u'brand': u'HIBOR', u'strength_3': u'', u'company': u'Elder', u'unit': u''}

-- line #4467
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENACE 10 (Novartis)',
	'Benazepril',
	'FC TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENACE 10 (Novartis)'
);

-- line #4468
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENACE 20 (Novartis)',
	'Benazepril',
	'FC TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENACE 20 (Novartis)'
);

-- line #4469
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENACE 5 (Novartis)',
	'Benazepril',
	'FC TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENACE 5 (Novartis)'
);

-- line #4470
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100', u'strength_2': u'', u'substance': u'BENDAMUSTINE HCL.', u'always_empty': u'', u'form': u'', u'brand': u'BEMUSTIN', u'strength_3': u'', u'company': u'Panacea', u'unit': u'mg'}

-- line #4471
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENDIT 100 (Natco Ph.)',
	'BENDAMUSTINE HCL.',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENDIT 100 (Natco Ph.)'
);

-- line #4472
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENZZ 100 (Intas)',
	'BENDAMUSTINE HCL.',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENZZ 100 (Intas)'
);

-- line #4473
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIMODE 100 (Emcure)',
	'BENDAMUSTINE HCL.',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIMODE 100 (Emcure)'
);

-- line #4474
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUSTIN 100 (Rpg Life)',
	'BENDAMUSTINE HCL.',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUSTIN 100 (Rpg Life)'
);

-- line #4475
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PURPLZ 100 (Dr. Reddy''S)',
	'BENDAMUSTINE HCL.',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PURPLZ 100 (Dr. Reddy''S)'
);

-- line #4476
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENALGIS 100 (Franco I.)',
	'BENFOTIAMINE',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENALGIS 100 (Franco I.)'
);

-- line #4477
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENFAGE 100 (Mano)',
	'BENFOTIAMINE',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENFAGE 100 (Mano)'
);

-- line #4478
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENFAGE 200 (Mano)',
	'BENFOTIAMINE',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENFAGE 200 (Mano)'
);

-- line #4479
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOTIA 150 (Bestochem)',
	'BENFOTIAMINE',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOTIA 150 (Bestochem)'
);

-- line #4480
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARITEC 4 (Stancare)',
	'Benidipine Hcl.',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARITEC 4 (Stancare)'
);

-- line #4481
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARITEC 8 (Stancare)',
	'Benidipine Hcl.',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARITEC 8 (Stancare)'
);

-- line #4482
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3', u'strength_2': u'', u'substance': u'Benzalkonium Chl.', u'always_empty': u'', u'form': u'', u'brand': u'BENZYL SEPTOL ACTIVE', u'strength_3': u'', u'company': u'MERIDIAN ENT.', u'unit': u'%(AQ BASE Q.S.)'}

-- line #4483
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ITEOL-H 4.5 (Astrazeneca)',
	'Benzalkonium Chl.',
	'SOL',
	gm.nullify_empty_string('4.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ITEOL-H 4.5 (Astrazeneca)'
);

-- line #4484
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPTREX 0.005 (ABBOTT)',
	'Benzalkonium Chl.',
	'EYE LOT',
	gm.nullify_empty_string('0.005')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPTREX 0.005 (ABBOTT)'
);

-- line #4485
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'4', u'strength_2': u'20', u'substance': u'Benzathine Penicillin', u'always_empty': u'', u'form': u'INJ', u'brand': u'FORTIFIED PROCAINE', u'strength_3': u'40;LACS U.', u'company': u'Hal', u'unit': u''}

-- line #4486
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'24LAC', u'strength_2': u'', u'substance': u'Benzathine Penicillin G', u'always_empty': u'', u'form': u'INJ LAC', u'brand': u'PENCOM', u'strength_3': u'', u'company': u'ALEMBIC', u'unit': u''}

-- line #4487
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'6LAC U', u'strength_2': u'12LAC U', u'substance': u'Benzathine Penicillin G', u'always_empty': u'', u'form': u'VIAL', u'brand': u'PENCOM', u'strength_3': u'', u'company': u'Alembic', u'unit': u''}

-- line #4488
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'12LAC U', u'strength_2': u'', u'substance': u'Benzathine Penicillin G', u'always_empty': u'', u'form': u'VIAL L', u'brand': u'PENIDURE', u'strength_3': u'', u'company': u'Wyeth', u'unit': u''}

-- line #4489
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'24LAC U', u'strength_2': u'', u'substance': u'Benzathine Penicillin G', u'always_empty': u'', u'form': u'VIAL L', u'brand': u'PENIDURE', u'strength_3': u'', u'company': u'Wyeth', u'unit': u''}

-- line #4490
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'6 LAC U', u'strength_2': u'', u'substance': u'Benzathine Penicillin G', u'always_empty': u'', u'form': u'VIAL L', u'brand': u'PENIDURE', u'strength_3': u'', u'company': u'Wyeth', u'unit': u''}

-- line #4491
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'6LAC U', u'strength_2': u'12LAC U', u'substance': u'Benzathine Penicillin', u'always_empty': u'', u'form': u'INJ', u'brand': u'LONGACILLIN', u'strength_3': u'', u'company': u'Hal', u'unit': u''}

-- line #4492
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'24 LAC U', u'strength_2': u'', u'substance': u'Benzathine Penicillin', u'always_empty': u'', u'form': u'INJ', u'brand': u'LONGACILLIN-L', u'strength_3': u'', u'company': u'Hal', u'unit': u''}

-- line #4493
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DENTEC 20 (Ravian)',
	'Benzocaine',
	'OINT',
	gm.nullify_empty_string('20')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DENTEC 20 (Ravian)'
);

-- line #4494
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAMDEW 7.5 (Shalaks)',
	'Benzocaine',
	'GEL',
	gm.nullify_empty_string('7.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAMDEW 7.5 (Shalaks)'
);

-- line #4495
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'28.35G', u'strength_2': u'', u'substance': u'Benzocaine', u'always_empty': u'', u'form': u'GEL', u'brand': u'MANDELAY', u'strength_3': u'', u'company': u'Morepen', u'unit': u''}

-- line #4496
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUCOPAIN 20 (Icpa)',
	'Benzocaine',
	'GEL',
	gm.nullify_empty_string('20')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUCOPAIN 20 (Icpa)'
);

-- line #4497
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENZ 100 (Lupin)',
	'BENZONATATE',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENZ 100 (Lupin)'
);

-- line #4498
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACNOX 2.5 (Dermocare)',
	'Benzoyl Peroxide',
	'GEL',
	gm.nullify_empty_string('2.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACNOX 2.5 (Dermocare)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACNOX 5 (Dermocare)',
	'Benzoyl Peroxide',
	'GEL',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACNOX 5 (Dermocare)'
);

-- line #4499
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTIBEN 2.5 (ADVIK)',
	'Benzoyl Peroxide',
	'GEL',
	gm.nullify_empty_string('2.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTIBEN 2.5 (ADVIK)'
);

-- line #4500
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTIBEN 5 (ADVIK)',
	'Benzoyl Peroxide',
	'GEL',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTIBEN 5 (ADVIK)'
);

-- line #4501
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACZEE 2.5 (OREVA DARMO.)',
	'Benzoyl Peroxide',
	'GEL',
	gm.nullify_empty_string('2.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACZEE 2.5 (OREVA DARMO.)'
);

-- line #4502
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACZEE 5 (OREVA DARMO.)',
	'Benzoyl Peroxide',
	'GEL',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACZEE 5 (OREVA DARMO.)'
);

-- line #4503
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACZEE 25 (Zee Lab)',
	'Benzoyl Peroxide',
	'GEL',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACZEE 25 (Zee Lab)'
);

-- line #4504
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENZAC AC 2.5 (Galderma)',
	'Benzoyl Peroxide',
	'GEL',
	gm.nullify_empty_string('2.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENZAC AC 2.5 (Galderma)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENZAC AC 5 (Galderma)',
	'Benzoyl Peroxide',
	'GEL',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENZAC AC 5 (Galderma)'
);

-- line #4505
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BREVOXYL 4 (STIEFEL)',
	'Benzoyl Peroxide',
	'CRMYWASH',
	gm.nullify_empty_string('4')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BREVOXYL 4 (STIEFEL)'
);

-- line #4506
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'4', u'strength_2': u'', u'substance': u'Benzoyl Peroxide', u'always_empty': u'', u'form': u'', u'brand': u'BREVOXYL FACE WASH', u'strength_3': u'', u'company': u'STIEFEL', u'unit': u'%'}

-- line #4507
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERIAC 2.5 (Cfl Ph.)',
	'Benzoyl Peroxide',
	'GEL',
	gm.nullify_empty_string('2.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERIAC 2.5 (Cfl Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERIAC 5 (Cfl Ph.)',
	'Benzoyl Peroxide',
	'GEL',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERIAC 5 (Cfl Ph.)'
);

-- line #4508
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Benzoyl Peroxide', u'always_empty': u'', u'form': u'GEL', u'brand': u'PERNEX-AC', u'strength_3': u'', u'company': u'Cosme Hc.', u'unit': u''}

-- line #4509
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERNOX-AC 2.5 (Cosme Hc.)',
	'Benzoyl Peroxide',
	'GEL',
	gm.nullify_empty_string('2.5')::numeric,
	'%(IN AQU.BSE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERNOX-AC 2.5 (Cosme Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERNOX-AC 5 (Cosme Hc.)',
	'Benzoyl Peroxide',
	'GEL',
	gm.nullify_empty_string('5')::numeric,
	'%(IN AQU.BSE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERNOX-AC 5 (Cosme Hc.)'
);

-- line #4510
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERNOX 2.5 (Cfl Ph.)',
	'Benzoyl Peroxide',
	'GEL',
	gm.nullify_empty_string('2.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERNOX 2.5 (Cfl Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERNOX 5 (Cfl Ph.)',
	'Benzoyl Peroxide',
	'GEL',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERNOX 5 (Cfl Ph.)'
);

-- line #4511
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEROBAR % 2.5 (Ajanta Ph.)',
	'Benzoyl Peroxide',
	'SOAP',
	gm.nullify_empty_string('2.5')::numeric,
	'%(TFM 60'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEROBAR % 2.5 (Ajanta Ph.)'
);

-- line #4512
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEROBAR % 5 (Ajanta Ph.)',
	'Benzoyl Peroxide',
	'SOAP',
	gm.nullify_empty_string('5')::numeric,
	'%(TFM 60'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEROBAR % 5 (Ajanta Ph.)'
);

-- line #4513
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2,5', u'strength_2': u'5', u'substance': u'Benzoyl Peroxide', u'always_empty': u'', u'form': u'', u'brand': u'PEROWASH', u'strength_3': u'', u'company': u'Ajanta Ph.', u'unit': u'%W/W'}

-- line #4514
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERSOL 2.5 (Wallace)',
	'Benzoyl Peroxide',
	'GEL',
	gm.nullify_empty_string('2.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERSOL 2.5 (Wallace)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERSOL 5 (Wallace)',
	'Benzoyl Peroxide',
	'GEL',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERSOL 5 (Wallace)'
);

-- line #4515
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DERMIN 25 (Bal Ph.)',
	'Benzyl Benzoate',
	'LOT',
	gm.nullify_empty_string('25')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DERMIN 25 (Bal Ph.)'
);

-- line #4516
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AKNEROXID 10 (Boots P.)',
	'Benzyl Peroxide',
	'GEL',
	gm.nullify_empty_string('10')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AKNEROXID 10 (Boots P.)'
);

-- line #4517
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AKNEROXID % 5 (Boots P.)',
	'Benzyl Peroxide',
	'GEL',
	gm.nullify_empty_string('5')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AKNEROXID % 5 (Boots P.)'
);

-- line #4518
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Benzyl Peroxide', u'always_empty': u'', u'form': u'GEL', u'brand': u'LAKBENZ', u'strength_3': u'', u'company': u'Shalaks', u'unit': u''}

-- line #4519
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'BERGENIA LIGULATA CRATEVA NURAVALA BOERHAVIA DIFFUSA ETC', u'always_empty': u'', u'form': u'', u'brand': u'RENOLITH', u'strength_3': u'', u'company': u'PINK HEALTH', u'unit': u''}

-- line #4520
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Beta Carotene', u'always_empty': u'', u'form': u'EC CAP', u'brand': u'BETA', u'strength_3': u'', u'company': u"D.R.John''S", u'unit': u''}

-- line #4521
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'WITH MICRO & MICRO NUTRIENTS', u'strength_2': u'', u'substance': u'Beta Carotene', u'always_empty': u'', u'form': u'EC PLUS CAP', u'brand': u'BETA', u'strength_3': u'', u'company': u"D.R.John''S", u'unit': u''}

-- line #4522
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'WITH VITAMINS', u'strength_2': u'', u'substance': u'Beta Carotene', u'always_empty': u'', u'form': u'SG CAP', u'brand': u'NOCOVIT', u'strength_3': u'', u'company': u'NEISS', u'unit': u''}

-- line #4523
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'WITH MULTIMINERALS AND MULTIVITAMINS', u'strength_2': u'', u'substance': u'BETA CAROTENE', u'always_empty': u'', u'form': u'CAP', u'brand': u'OXSULE', u'strength_3': u'', u'company': u'LEXUS', u'unit': u''}

-- line #4524
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BALANSE 8 (Cadila Ph.)',
	'Betahistine',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BALANSE 8 (Cadila Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BALANSE 16 (Cadila Ph.)',
	'Betahistine',
	'TAB',
	gm.nullify_empty_string('16')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BALANSE 16 (Cadila Ph.)'
);

-- line #4525
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BAROHIST 16 (Baroque)',
	'Betahistine',
	'TAB',
	gm.nullify_empty_string('16')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BAROHIST 16 (Baroque)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BAROHIST 24 (Baroque)',
	'Betahistine',
	'TAB',
	gm.nullify_empty_string('24')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BAROHIST 24 (Baroque)'
);

-- line #4526
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BAROHIST 8 (Baroque)',
	'Betahistine',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BAROHIST 8 (Baroque)'
);

-- line #4527
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETAHIST/FORTE 8 (Geno Ph.)',
	'Betahistine',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg(IN BETA CYCLODEXTRIN)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETAHIST/FORTE 8 (Geno Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETAHIST/FORTE 16 (Geno Ph.)',
	'Betahistine',
	'TAB',
	gm.nullify_empty_string('16')::numeric,
	'mg(IN BETA CYCLODEXTRIN)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETAHIST/FORTE 16 (Geno Ph.)'
);

-- line #4528
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETAVERT 24 (Sun)',
	'Betahistine',
	'OD TAB',
	gm.nullify_empty_string('24')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETAVERT 24 (Sun)'
);

-- line #4529
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETAVERT 16 (Sun)',
	'Betahistine',
	'TAB',
	gm.nullify_empty_string('16')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETAVERT 16 (Sun)'
);

-- line #4530
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETAVERT 24 (Sun)',
	'Betahistine',
	'TAB',
	gm.nullify_empty_string('24')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETAVERT 24 (Sun)'
);

-- line #4531
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETAVERT 8 (Sun)',
	'Betahistine',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETAVERT 8 (Sun)'
);

-- line #4532
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIXRO 8 (AAMORB(ST. MORISON))',
	'Betahistine',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIXRO 8 (AAMORB(ST. MORISON))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIXRO 16 (AAMORB(ST. MORISON))',
	'Betahistine',
	'TAB',
	gm.nullify_empty_string('16')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIXRO 16 (AAMORB(ST. MORISON))'
);

-- line #4533
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'B STIL 16 (Piramal Hc.)',
	'Betahistine',
	'TAB',
	gm.nullify_empty_string('16')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'B STIL 16 (Piramal Hc.)'
);

-- line #4534
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'B STIL 24 (Piramal Hc.)',
	'Betahistine',
	'TAB',
	gm.nullify_empty_string('24')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'B STIL 24 (Piramal Hc.)'
);

-- line #4535
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'B STIL 8 (Piramal Hc.)',
	'Betahistine',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'B STIL 8 (Piramal Hc.)'
);

-- line #4536
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CINAVER 25 (EAST WEST)',
	'Betahistine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CINAVER 25 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CINAVER 75 (EAST WEST)',
	'Betahistine',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CINAVER 75 (EAST WEST)'
);

-- line #4537
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVERT 16 (Meridian)',
	'Betahistine',
	'TAB',
	gm.nullify_empty_string('16')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVERT 16 (Meridian)'
);

-- line #4538
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVERT 8 (Meridian)',
	'Betahistine',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVERT 8 (Meridian)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVERT 16 (Meridian)',
	'Betahistine',
	'TAB',
	gm.nullify_empty_string('16')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVERT 16 (Meridian)'
);

-- line #4539
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVERT 8 (Meridian)',
	'Betahistine',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg(DI.HCL.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVERT 8 (Meridian)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVERT 16 (Meridian)',
	'Betahistine',
	'TAB',
	gm.nullify_empty_string('16')::numeric,
	'mg(DI.HCL.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVERT 16 (Meridian)'
);

-- line #4540
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVERT 8 (Meridian)',
	'Betahistine',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVERT 8 (Meridian)'
);

-- line #4541
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMVEX 16 (Alembic)',
	'Betahistine',
	'TAB',
	gm.nullify_empty_string('16')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMVEX 16 (Alembic)'
);

-- line #4542
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMVEX 8 (Alembic)',
	'Betahistine',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMVEX 8 (Alembic)'
);

-- line #4543
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FRIGO 16 (GLOBELA PH.)',
	'Betahistine',
	'TAB',
	gm.nullify_empty_string('16')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FRIGO 16 (GLOBELA PH.)'
);

-- line #4544
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FRIGO 8 (GLOBELA PH.)',
	'Betahistine',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FRIGO 8 (GLOBELA PH.)'
);

-- line #4545
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HISTAVERT 8 (Pulse Ph.)',
	'Betahistine',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HISTAVERT 8 (Pulse Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HISTAVERT 16 (Pulse Ph.)',
	'Betahistine',
	'TAB',
	gm.nullify_empty_string('16')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HISTAVERT 16 (Pulse Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HISTAVERT 24 (Pulse Ph.)',
	'Betahistine',
	'TAB',
	gm.nullify_empty_string('24')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HISTAVERT 24 (Pulse Ph.)'
);

-- line #4546
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HISTIGO 16 (MOLEKULE)',
	'Betahistine',
	'TAB',
	gm.nullify_empty_string('16')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HISTIGO 16 (MOLEKULE)'
);

-- line #4547
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HISTIGO 24 (MOLEKULE)',
	'Betahistine',
	'TAB',
	gm.nullify_empty_string('24')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HISTIGO 24 (MOLEKULE)'
);

-- line #4548
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HISTIGO 8 (MOLEKULE)',
	'Betahistine',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HISTIGO 8 (MOLEKULE)'
);

-- line #4549
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDIVERT PLUS 8 (Indilina Ph.)',
	'Betahistine',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg(DI.HCL.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDIVERT PLUS 8 (Indilina Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDIVERT PLUS 16 (Indilina Ph.)',
	'Betahistine',
	'TAB',
	gm.nullify_empty_string('16')::numeric,
	'mg(DI.HCL.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDIVERT PLUS 16 (Indilina Ph.)'
);

-- line #4550
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTRABET 8 (Intra Lab)',
	'Betahistine',
	'DT',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTRABET 8 (Intra Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTRABET 16 (Intra Lab)',
	'Betahistine',
	'DT',
	gm.nullify_empty_string('16')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTRABET 16 (Intra Lab)'
);

-- line #4551
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INVERT 8 (ANTHUS)',
	'Betahistine',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INVERT 8 (ANTHUS)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INVERT 16 (ANTHUS)',
	'Betahistine',
	'TAB',
	gm.nullify_empty_string('16')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INVERT 16 (ANTHUS)'
);

-- line #4552
-- ignoring line: field [strength_2] not numeric: >>>16L<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': Decimal('8'), u'strength_2': u'16L', u'substance': u'Betahistine', u'always_empty': u'', u'form': u'TAB', u'brand': u'MENEAS', u'strength_3': u'', u'company': u'Biomax Bio.', u'unit': u'mg'}

-- line #4553
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MENI-16 16 (F D C)',
	'Betahistine',
	'TAB',
	gm.nullify_empty_string('16')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MENI-16 16 (F D C)'
);

-- line #4554
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MENI-8 8 (F D C)',
	'Betahistine',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MENI-8 8 (F D C)'
);

-- line #4555
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MERSILON 12 (Unichem)',
	'Betahistine',
	'TAB',
	gm.nullify_empty_string('12')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MERSILON 12 (Unichem)'
);

-- line #4556
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MERSILON 6 (Unichem)',
	'Betahistine',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MERSILON 6 (Unichem)'
);

-- line #4557
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MS BETA 12 (Unichem)',
	'Betahistine',
	'TAB',
	gm.nullify_empty_string('12')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MS BETA 12 (Unichem)'
);

-- line #4558
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MS BETA 6 (Unichem)',
	'Betahistine',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MS BETA 6 (Unichem)'
);

-- line #4559
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEUVERT 16 (EAST WEST)',
	'Betahistine',
	'TAB',
	gm.nullify_empty_string('16')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEUVERT 16 (EAST WEST)'
);

-- line #4560
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEUVERT 24 (EAST WEST)',
	'Betahistine',
	'TAB',
	gm.nullify_empty_string('24')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEUVERT 24 (EAST WEST)'
);

-- line #4561
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEUVERT 8 (EAST WEST)',
	'Betahistine',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEUVERT 8 (EAST WEST)'
);

-- line #4562
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACZEE BETA 2 (OREVA DARMO.)',
	'BETAHYDROXY ACID',
	'LOT',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACZEE BETA 2 (OREVA DARMO.)'
);

-- line #4563
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTICARD 0.5 (Active Hc.)',
	'Betamethasone',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTICARD 0.5 (Active Hc.)'
);

-- line #4564
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALERKIM 1 (Kim Lab)',
	'Betamethasone',
	'F. TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALERKIM 1 (Kim Lab)'
);

-- line #4565
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALERKIM 4 (Kim Lab)',
	'Betamethasone',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALERKIM 4 (Kim Lab)'
);

-- line #4566
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALERKIM ORAL 0.5 (Kim Lab)',
	'Betamethasone',
	'DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALERKIM ORAL 0.5 (Kim Lab)'
);

-- line #4567
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALERKIM 0.5 (Kim Lab)',
	'Betamethasone',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALERKIM 0.5 (Kim Lab)'
);

-- line #4568
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BELAR-F 1 (Comed)',
	'Betamethasone',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BELAR-F 1 (Comed)'
);

-- line #4569
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BELAR 0.5 (Comed)',
	'Betamethasone',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BELAR 0.5 (Comed)'
);

-- line #4570
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENTESOL 1 (GSK)',
	'Betamethasone',
	'F. TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENTESOL 1 (GSK)'
);

-- line #4571
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETACORTRIL 1 (Pfizer)',
	'Betamethasone',
	'F. TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETACORTRIL 1 (Pfizer)'
);

-- line #4572
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETACORTRIL 0.5 (Pfizer)',
	'Betamethasone',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETACORTRIL 0.5 (Pfizer)'
);

-- line #4573
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETADERM 0.05 (Dermocare)',
	'Betamethasone',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETADERM 0.05 (Dermocare)'
);

-- line #4574
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETADERM RD 0.0125 (Dermocare)',
	'Betamethasone',
	'CRM',
	gm.nullify_empty_string('0.0125')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETADERM RD 0.0125 (Dermocare)'
);

-- line #4575
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETALAR 0.5 (Lark Labs)',
	'Betamethasone',
	'DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETALAR 0.5 (Lark Labs)'
);

-- line #4576
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETALAR 0.5 (Lark Labs)',
	'Betamethasone',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETALAR 0.5 (Lark Labs)'
);

-- line #4577
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETAMINE 1 (Unimarck)',
	'Betamethasone',
	'F. TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETAMINE 1 (Unimarck)'
);

-- line #4578
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETAMINE 0.5 (Unimarck)',
	'Betamethasone',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETAMINE 0.5 (Unimarck)'
);

-- line #4579
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'(SOD.PHOSPH.)', u'strength_2': u'', u'substance': u'Betamethasone', u'always_empty': u'', u'form': u'DPS', u'brand': u'BETASAN', u'strength_3': u'', u'company': u'SANCHEZ LAB.', u'unit': u''}

-- line #4580
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Betamethasone', u'always_empty': u'', u'form': u'INJ', u'brand': u'BETASAN', u'strength_3': u'', u'company': u'SANCHEZ LAB.', u'unit': u''}

-- line #4581
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETASAN 0.5 (SANCHEZ LAB.)',
	'Betamethasone',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg(PHOS.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETASAN 0.5 (SANCHEZ LAB.)'
);

-- line #4582
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETASONE 1 (Dial Ph.)',
	'Betamethasone',
	'F. TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETASONE 1 (Dial Ph.)'
);

-- line #4583
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETASONE 0.5 (Dial Ph.)',
	'Betamethasone',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETASONE 0.5 (Dial Ph.)'
);

-- line #4584
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETAWIN 0.5 (Bestochem)',
	'Betamethasone',
	'F. TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETAWIN 0.5 (Bestochem)'
);

-- line #4585
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETAWIN-S 0.5 (Bestochem)',
	'Betamethasone',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETAWIN-S 0.5 (Bestochem)'
);

-- line #4586
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETNECIP OVL 0.5 (Cipla)',
	'Betamethasone',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETNECIP OVL 0.5 (Cipla)'
);

-- line #4587
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETNECIP RND 0.5 (Cipla)',
	'Betamethasone',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETNECIP RND 0.5 (Cipla)'
);

-- line #4588
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETNECIP 0.5 (Cipla)',
	'Betamethasone',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETNECIP 0.5 (Cipla)'
);

-- line #4589
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETNECORT 0.5 (Cipla)',
	'Betamethasone',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg(PHOSPH.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETNECORT 0.5 (Cipla)'
);

-- line #4590
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETNELAN 1 (Gsk)',
	'Betamethasone',
	'F. TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETNELAN 1 (Gsk)'
);

-- line #4591
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETNELAN 0.5 (Gsk)',
	'Betamethasone',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETNELAN 0.5 (Gsk)'
);

-- line #4592
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETNESOL 0.1 (GSK)',
	'Betamethasone',
	'DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETNESOL 0.1 (GSK)'
);

-- line #4593
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETNESOL 0.5 (Gsk)',
	'Betamethasone',
	'DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETNESOL 0.5 (Gsk)'
);

-- line #4594
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETNESOL 1 (Gsk)',
	'Betamethasone',
	'FC/FORTE TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETNESOL 1 (Gsk)'
);

-- line #4595
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETNESOL 4 (Gsk)',
	'Betamethasone',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETNESOL 4 (Gsk)'
);

-- line #4596
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETNESOL 0.5 (Gsk)',
	'Betamethasone',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETNESOL 0.5 (Gsk)'
);

-- line #4597
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETSONE 1 (Medopharm)',
	'Betamethasone',
	'DS TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETSONE 1 (Medopharm)'
);

-- line #4598
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETSONE 4 (Medopharm)',
	'Betamethasone',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETSONE 4 (Medopharm)'
);

-- line #4599
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETSONE 0.5 (Medopharm)',
	'Betamethasone',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETSONE 0.5 (Medopharm)'
);

-- line #4600
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELESTONE 0.5 (Fulford)',
	'Betamethasone',
	'DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELESTONE 0.5 (Fulford)'
);

-- line #4601
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELESTONE 4 (Fulford)',
	'Betamethasone',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELESTONE 4 (Fulford)'
);

-- line #4602
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELESTONE 0.5 (Fulford)',
	'Betamethasone',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELESTONE 0.5 (Fulford)'
);

-- line #4603
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORTIBET 0.5 (Cambridge Hc.)',
	'Betamethasone',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORTIBET 0.5 (Cambridge Hc.)'
);

-- line #4604
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORTIFLAM-B 0.5 (Bennet Ph.)',
	'Betamethasone',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORTIFLAM-B 0.5 (Bennet Ph.)'
);

-- line #4605
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORTIHIST 0.5 (Inga)',
	'Betamethasone',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORTIHIST 0.5 (Inga)'
);

-- line #4606
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORTIL 0.5 (Micro Nova)',
	'Betamethasone',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORTIL 0.5 (Micro Nova)'
);

-- line #4607
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORTIL 1 (Micro Nova)',
	'Betamethasone',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORTIL 1 (Micro Nova)'
);

-- line #4608
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETAGEL 0.05 (Micro Labs)',
	'Betamethasone Diprop.',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETAGEL 0.05 (Micro Labs)'
);

-- line #4609
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETAGEL 0.05 (Micro Labs)',
	'Betamethasone Diprop.',
	'GEL',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETAGEL 0.05 (Micro Labs)'
);

-- line #4610
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETAMIL 0.05 (Merck)',
	'Betamethasone Diprop.',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETAMIL 0.05 (Merck)'
);

-- line #4611
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Betamethasone Diprop.', u'always_empty': u'', u'form': u'CRM', u'brand': u'BETASAN', u'strength_3': u'', u'company': u'SANCHEZ LAB.', u'unit': u''}

-- line #4612
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETSE 0.064 (Franklin)',
	'Betamethasone Diprop.',
	'CRM',
	gm.nullify_empty_string('0.064')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETSE 0.064 (Franklin)'
);

-- line #4613
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Betamethasone Diprop.', u'always_empty': u'', u'form': u'LOT', u'brand': u'BEZE', u'strength_3': u'', u'company': u'OREVA DARMO.', u'unit': u''}

-- line #4614
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORTIDERM 0.05 (Bal Ph.)',
	'Betamethasone Diprop.',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%W.W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORTIDERM 0.05 (Bal Ph.)'
);

-- line #4615
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIBEDERM 0.05 (Wanbury)',
	'Betamethasone Diprop.',
	'OINT',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIBEDERM 0.05 (Wanbury)'
);

-- line #4616
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIPLENE 0.64 (Fulford)',
	'Betamethasone Diprop.',
	'CRM',
	gm.nullify_empty_string('0.64')::numeric,
	'mg/G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIPLENE 0.64 (Fulford)'
);

-- line #4617
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIPNATE 0.05 (Karlin)',
	'Betamethasone Diprop.',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIPNATE 0.05 (Karlin)'
);

-- line #4618
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIPROVATE 0.05 (Croslands)',
	'Betamethasone Diprop.',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIPROVATE 0.05 (Croslands)'
);

-- line #4619
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIPROVATE 0.05 (Croslands)',
	'Betamethasone Diprop.',
	'LOT',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIPROVATE 0.05 (Croslands)'
);

-- line #4620
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIPROVATE-RD 0.0125 (Croslands)',
	'Betamethasone Diprop.',
	'CRM',
	gm.nullify_empty_string('0.0125')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIPROVATE-RD 0.0125 (Croslands)'
);

-- line #4621
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXEVATE 0.64 (Ochoa)',
	'Betamethasone Diprop.',
	'CRM',
	gm.nullify_empty_string('0.64')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXEVATE 0.64 (Ochoa)'
);

-- line #4622
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETO-B 0.05 (MED MANOR)',
	'Betamethasone Diprop.Ketoconazole',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'2'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETO-B 0.05 (MED MANOR)'
);

-- line #4623
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUPIDERM 0.05 (Lupin)',
	'Betamethasone Diprop.',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUPIDERM 0.05 (Lupin)'
);

-- line #4624
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLPROVATE 0.64 (Olcare)',
	'Betamethasone Diprop.',
	'CRM',
	gm.nullify_empty_string('0.64')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLPROVATE 0.64 (Olcare)'
);

-- line #4625
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLPROVATE 0.05 (Olcare)',
	'Betamethasone Diprop.',
	'LOT',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLPROVATE 0.05 (Olcare)'
);

-- line #4626
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Betamethasone', u'always_empty': u'', u'form': u'CRM', u'brand': u'GROBET', u'strength_3': u'', u'company': u'ADMIT', u'unit': u''}

-- line #4627
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Betamethasone', u'always_empty': u'', u'form': u'INJ', u'brand': u'M-VIT', u'strength_3': u'', u'company': u'SANCHEZ LAB.', u'unit': u''}

-- line #4628
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUCORT 0.5 (Mankind)',
	'Betamethasone',
	'DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUCORT 0.5 (Mankind)'
);

-- line #4629
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORBET 1 (Trio Rem.)',
	'Betamethasone',
	'F. TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORBET 1 (Trio Rem.)'
);

-- line #4630
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORBET 0.5 (Trio Rem.)',
	'Betamethasone',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORBET 0.5 (Trio Rem.)'
);

-- line #4631
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETNESOL 0.1 (Gsk)',
	'Betamethasone Sod.Phos.',
	'EYE OINT',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETNESOL 0.1 (Gsk)'
);

-- line #4632
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CATRISOL 0.5 (Raddison Hc.)',
	'Betamethasone Sod.Phos.',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CATRISOL 0.5 (Raddison Hc.)'
);

-- line #4633
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KARBET 0.5 (Medicot Plus)',
	'Betamethasone Sod.Phos.',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KARBET 0.5 (Medicot Plus)'
);

-- line #4634
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILBETA 0.1 (Milmet)',
	'Betamethasone Sod.Phos.',
	'DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILBETA 0.1 (Milmet)'
);

-- line #4635
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCUSONE 0.1 (Parenteral)',
	'Betamethasone Sod.Phos.',
	'DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCUSONE 0.1 (Parenteral)'
);

-- line #4636
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50GM', u'strength_2': u'', u'substance': u'Betamethasone Valerate', u'always_empty': u'', u'form': u'', u'brand': u'BETAFOAM', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #4637
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,1', u'strength_2': u'', u'substance': u'Betamethasone Valerate', u'always_empty': u'', u'form': u'FOAM', u'brand': u'BETAFOAM MOUSSE', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #4638
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETNOVATE 0.12 (Gsk)',
	'Betamethasone Valerate',
	'CRM',
	gm.nullify_empty_string('0.12')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETNOVATE 0.12 (Gsk)'
);

-- line #4639
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETNOVATE SCALP 0.12 (Gsk)',
	'Betamethasone Valerate',
	'LOT',
	gm.nullify_empty_string('0.12')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETNOVATE SCALP 0.12 (Gsk)'
);

-- line #4640
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUTOP-B 0.01 (COSME HEALTH)',
	'Betamethasone Valerate',
	'CRM',
	gm.nullify_empty_string('0.01')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUTOP-B 0.01 (COSME HEALTH)'
);

-- line #4641
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETAPRESS 0.5 (Micro V.)',
	'Betaxolol Hcl.',
	'EYE DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETAPRESS 0.5 (Micro V.)'
);

-- line #4642
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETHACOL 25 (SG PH.)',
	'Bethanechol Chloride',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETHACOL 25 (SG PH.)'
);

-- line #4643
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETHERAN 25 (Ranbaxy)',
	'Bethanechol Chloride',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETHERAN 25 (Ranbaxy)'
);

-- line #4644
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACPEE 25 (Intas)',
	'Bethanechol Chloride',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACPEE 25 (Intas)'
);

-- line #4645
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYOTONINE 25 (CH.Bhagat)',
	'Bethanechol Chloride',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYOTONINE 25 (CH.Bhagat)'
);

-- line #4646
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BEZALIP 400 (Nicholas)',
	'Bezafibrate',
	'SR TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BEZALIP 400 (Nicholas)'
);

-- line #4647
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BEZALIP 200 (Nicholas)',
	'Bezafibrate',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BEZALIP 200 (Nicholas)'
);

-- line #4648
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BEZA 400 (Otsira)',
	'Bezafibrate',
	'XL TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BEZA 400 (Otsira)'
);

-- line #4649
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLOBEZ 200 (Globus)',
	'Bezafibrate',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLOBEZ 200 (Globus)'
);

-- line #4650
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANDROBLOK 50 (SUN)',
	'BICALUTAMIDE',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANDROBLOK 50 (SUN)'
);

-- line #4651
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BICALUTAMIDE 50 (Khandelwal)',
	'BICALUTAMIDE',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BICALUTAMIDE 50 (Khandelwal)'
);

-- line #4652
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BICATERO 50 (HETERO HC.)',
	'BICALUTAMIDE',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BICATERO 50 (HETERO HC.)'
);

-- line #4653
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIPROSTA 50 (Cytomed(Alkem))',
	'BICALUTAMIDE',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIPROSTA 50 (Cytomed(Alkem))'
);

-- line #4654
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALUDAC 50 (Samarth)',
	'BICALUTAMIDE',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALUDAC 50 (Samarth)'
);

-- line #4655
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALUDEC 50 (Samarth)',
	'BICALUTAMIDE',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALUDEC 50 (Samarth)'
);

-- line #4656
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50', u'strength_2': u'', u'substance': u'BICALUTAMIDE', u'always_empty': u'', u'form': u'', u'brand': u'CALURAN CP', u'strength_3': u'', u'company': u'Ranbaxy', u'unit': u'mg'}

-- line #4657
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALUTIDE 50 (Cipla)',
	'BICALUTAMIDE',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALUTIDE 50 (Cipla)'
);

-- line #4658
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CASODEX 50 (Astrazeneca)',
	'BICALUTAMIDE',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CASODEX 50 (Astrazeneca)'
);

-- line #4659
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CESODEX 150 (Astrazeneca)',
	'BICALUTAMIDE',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CESODEX 150 (Astrazeneca)'
);

-- line #4660
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCOSPOR 1 (Bayer)',
	'Bifonazole',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCOSPOR 1 (Bayer)'
);

-- line #4661
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIMAT 0.3 (Ajanta Ph.)',
	'Bimatoprost',
	'INJ',
	gm.nullify_empty_string('0.3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIMAT 0.3 (Ajanta Ph.)'
);

-- line #4662
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIMAT 0.005 (ANVAXX)',
	'Bimatoprost',
	'LS',
	gm.nullify_empty_string('0.005')::numeric,
	'%W/V(0.1'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIMAT 0.005 (ANVAXX)'
);

-- line #4663
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Bimatoprost', u'always_empty': u'', u'form': u'EYE SOLN', u'brand': u'CAREPROST', u'strength_3': u'', u'company': u'SUN(AVESTA)', u'unit': u''}

-- line #4664
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTAPROST 0.3 (Intas)',
	'Bimatoprost',
	'EYE DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTAPROST 0.3 (Intas)'
);

-- line #4665
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5', u'strength_2': u'', u'substance': u'Bimatoprost', u'always_empty': u'', u'form': u'', u'brand': u'LUMIGAN', u'strength_3': u'', u'company': u'Allergan', u'unit': u'mg/ML(BENZALKONIUM CHL.)'}

-- line #4666
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10G', u'strength_2': u'', u'substance': u'BIOACTIVE COLLAGE PEPTIDES', u'always_empty': u'', u'form': u'SAC', u'brand': u'COLLAFEX', u'strength_3': u'', u'company': u'Universal', u'unit': u''}

-- line #4667
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVITIN-7 5 (Unimarck)',
	'BIOTIN',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVITIN-7 5 (Unimarck)'
);

-- line #4668
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXYTIN 5 (AXYZEN LIFE)',
	'BIOTIN',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXYTIN 5 (AXYZEN LIFE)'
);

-- line #4669
-- ignoring line: field [strength_1] not numeric: >>>WITH MULTIVITAMIN<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'WITH MULTIVITAMIN', u'strength_2': u'', u'substance': u'BIOTIN', u'always_empty': u'', u'form': u'TAB', u'brand': u'BGRO PLUS', u'strength_3': u'', u'company': u'OMNI LIFE', u'unit': u'MULTIMINERAL'}

-- line #4670
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIN 2.5 (LIVA HC.)',
	'BIOTIN',
	'DT',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIN 2.5 (LIVA HC.)'
);

-- line #4671
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIN 10 (LIVA HC.)',
	'BIOTIN',
	'F. TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIN 10 (LIVA HC.)'
);

-- line #4672
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOFOL 5 (Pharmed)',
	'BIOTIN',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOFOL 5 (Pharmed)'
);

-- line #4673
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOKARE 5 (KIVI LABS)',
	'BIOTIN',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOKARE 5 (KIVI LABS)'
);

-- line #4674
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOPECIA 5 (ALDERMAT PH.)',
	'BIOTIN',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOPECIA 5 (ALDERMAT PH.)'
);

-- line #4675
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOREK 5 (SUBHREK PH.)',
	'BIOTIN',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOREK 5 (SUBHREK PH.)'
);

-- line #4676
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOT-5 5 (Tripada BIO.)',
	'BIOTIN',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOT-5 5 (Tripada BIO.)'
);

-- line #4677
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOTIN 10 (ZYDUS(LIVA))',
	'BIOTIN',
	'F.',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOTIN 10 (ZYDUS(LIVA))'
);

-- line #4678
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOT 5 (Tripada)',
	'BIOTIN',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOT 5 (Tripada)'
);

-- line #4679
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BTN 2.5 (Liva Hc.)',
	'BIOTIN',
	'DT TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BTN 2.5 (Liva Hc.)'
);

-- line #4680
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BTN 10 (Liva Hc.)',
	'BIOTIN',
	'F. TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BTN 10 (Liva Hc.)'
);

-- line #4681
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'BIOTIN', u'always_empty': u'', u'form': u'LOT', u'brand': u'BTN', u'strength_3': u'', u'company': u'Liva Hc.', u'unit': u''}

-- line #4682
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BTN 5 (Liva Hc.)',
	'BIOTIN',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BTN 5 (Liva Hc.)'
);

-- line #4683
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'WITH CALCIUM PANTOTHENATE', u'strength_2': u'', u'substance': u'BIOTIN', u'always_empty': u'', u'form': u'', u'brand': u'BTN ULTRA', u'strength_3': u'', u'company': u'Liva Hc.', u'unit': u'ACETYLCYSTEINE & MINERALS'}

-- line #4684
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COSMETIN 5 (EAST WEST)',
	'biotin',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg/10'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COSMETIN 5 (EAST WEST)'
);

-- line #4685
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'WITH AMINO ACID', u'strength_2': u'', u'substance': u'BIOTIN', u'always_empty': u'', u'form': u'', u'brand': u'ESSVITAL', u'strength_3': u'', u'company': u'Ranbaxy', u'unit': u''}

-- line #4686
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESSVIT 5 (Ochoa)',
	'BIOTIN',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESSVIT 5 (Ochoa)'
);

-- line #4687
-- ignoring line: field [strength_1] not numeric: >>>WITH VIT.B5<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'WITH VIT.B5', u'strength_2': u'', u'substance': u'BIOTIN', u'always_empty': u'', u'form': u'F.', u'brand': u'EXTEND', u'strength_3': u'', u'company': u'KLM LAB.', u'unit': u'N-ACETYLCYSTEINE AND MINERALS'}

-- line #4688
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'WITH VIT. C', u'strength_2': u'', u'substance': u'BIOTIN', u'always_empty': u'', u'form': u'TAB', u'brand': u'HNS', u'strength_3': u'', u'company': u'HERBOTICS', u'unit': u''}

-- line #4689
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'H-VIT 5 (SYSTOPIC)',
	'BIOTIN',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'H-VIT 5 (SYSTOPIC)'
);

-- line #4690
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'WITH VIT. C. AND VITAMIN B. COMPLEX', u'strength_2': u'', u'substance': u'BIOTIN', u'always_empty': u'', u'form': u'TAB', u'brand': u'MANOVIT-C PLUS', u'strength_3': u'', u'company': u'Mano Ph.', u'unit': u''}

-- line #4691
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NISBIO 5 (John Bio.)',
	'BIOTIN',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NISBIO 5 (John Bio.)'
);

-- line #4692
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BAXATIVE 5 (Elder)',
	'Bisacodyl',
	'SUPP',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BAXATIVE 5 (Elder)'
);

-- line #4693
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BAXATIVE 5 (Elder)',
	'Bisacodyl',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BAXATIVE 5 (Elder)'
);

-- line #4694
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIDLAX-5 5 (GSK)',
	'Bisacodyl',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIDLAX-5 5 (GSK)'
);

-- line #4695
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BO LAX 5 (Cipla)',
	'Bisacodyl',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BO LAX 5 (Cipla)'
);

-- line #4696
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONLAX 5 (Bliss)',
	'Bisacodyl',
	'SUPPOS',
	gm.nullify_empty_string('5')::numeric,
	'mg/10'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONLAX 5 (Bliss)'
);

-- line #4697
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DULCOLAX 5 (German R.)',
	'Bisacodyl',
	'SUPPOS',
	gm.nullify_empty_string('5')::numeric,
	'mg/10'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DULCOLAX 5 (German R.)'
);

-- line #4698
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DULCOLAX 5 (German R.)',
	'Bisacodyl',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DULCOLAX 5 (German R.)'
);

-- line #4699
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GUDLAX 5 (Mankind)',
	'Bisacodyl',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GUDLAX 5 (Mankind)'
);

-- line #4700
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JULAX 5 (Shreya)',
	'Bisacodyl',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg/10'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JULAX 5 (Shreya)'
);

-- line #4701
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JUNIFREE-RDS 5 (Elder)',
	'Bisacodyl',
	'SUPP',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JUNIFREE-RDS 5 (Elder)'
);

-- line #4702
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAXIONE 10 (Theo Ph.)',
	'Bisacodyl',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAXIONE 10 (Theo Ph.)'
);

-- line #4703
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAXODYL 5 (Shalaks)',
	'Bisacodyl',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAXODYL 5 (Shalaks)'
);

-- line #4704
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BEBEDOL 10 (VHB(CRONUS))',
	'Bisoprolol',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BEBEDOL 10 (VHB(CRONUS))'
);

-- line #4705
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BEBEDOL 2.5 (VHB(CRONUS))',
	'Bisoprolol',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BEBEDOL 2.5 (VHB(CRONUS))'
);

-- line #4706
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BEBEDOL 5 (VHB(CRONUS))',
	'Bisoprolol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BEBEDOL 5 (VHB(CRONUS))'
);

-- line #4707
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BISBETA 5 (SHRRISHTI HC.)',
	'Bisoprolol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BISBETA 5 (SHRRISHTI HC.)'
);

-- line #4708
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BISELECT 2.5 (Intas)',
	'Bisoprolol',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BISELECT 2.5 (Intas)'
);

-- line #4709
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BISELECT 5 (Intas)',
	'Bisoprolol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BISELECT 5 (Intas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BISELECT 10 (Intas)',
	'Bisoprolol',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BISELECT 10 (Intas)'
);

-- line #4710
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BISOCAR 10 (Rusan Hc)',
	'Bisoprolol',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BISOCAR 10 (Rusan Hc)'
);

-- line #4711
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BISOCAR 2.5 (Rusan Hc)',
	'Bisoprolol',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BISOCAR 2.5 (Rusan Hc)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BISOCAR 5 (Rusan Hc)',
	'Bisoprolol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BISOCAR 5 (Rusan Hc)'
);

-- line #4712
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BISOD 2.5 (MEDREICH SAI.)',
	'Bisoprolol',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BISOD 2.5 (MEDREICH SAI.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BISOD 5 (MEDREICH SAI.)',
	'Bisoprolol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BISOD 5 (MEDREICH SAI.)'
);

-- line #4713
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIS 2.5 (SAI MIRRA)',
	'Bisoprolol',
	'OD TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIS 2.5 (SAI MIRRA)'
);

-- line #4714
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIS 5 (SAI MIRRA)',
	'Bisoprolol',
	'OD TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIS 5 (SAI MIRRA)'
);

-- line #4715
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CADROL 2.5 (TAJ PH.)',
	'Bisoprolol',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CADROL 2.5 (TAJ PH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CADROL 5 (TAJ PH.)',
	'Bisoprolol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CADROL 5 (TAJ PH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CADROL 10 (TAJ PH.)',
	'Bisoprolol',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CADROL 10 (TAJ PH.)'
);

-- line #4716
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONCOR COR 1.25 (Merck)',
	'Bisoprolol',
	'TAB',
	gm.nullify_empty_string('1.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONCOR COR 1.25 (Merck)'
);

-- line #4717
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONCOR 2.5 (Merck)',
	'Bisoprolol',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONCOR 2.5 (Merck)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONCOR 10 (Merck)',
	'Bisoprolol',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONCOR 10 (Merck)'
);

-- line #4718
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONCOR 5 (Merck)',
	'Bisoprolol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONCOR 5 (Merck)'
);

-- line #4719
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORBIS-H 2.5 (Unichem)',
	'Bisoprolol',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORBIS-H 2.5 (Unichem)'
);

-- line #4720
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORBIS 10 (Unisearch)',
	'Bisoprolol',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORBIS 10 (Unisearch)'
);

-- line #4721
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORBIS 2.5 (Unisearch)',
	'Bisoprolol',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORBIS 2.5 (Unisearch)'
);

-- line #4722
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORBIS 5 (Unisearch)',
	'Bisoprolol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORBIS 5 (Unisearch)'
);

-- line #4723
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIVACS 250 (Intas)',
	'BIVALIRUDIN',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIVACS 250 (Intas)'
);

-- line #4724
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIVASAVE 250 (Piramal Hc.)',
	'BIVALIRUDIN',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIVASAVE 250 (Piramal Hc.)'
);

-- line #4725
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOPACE 250 (Ranbaxy)',
	'BIVALIRUDIN',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOPACE 250 (Ranbaxy)'
);

-- line #4726
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GIOLOC 250 (USV(CELESTA))',
	'BIVALIRUDIN',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GIOLOC 250 (USV(CELESTA))'
);

-- line #4727
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUBIMAX 250 (Emcure)',
	'BIVALIRUDIN',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUBIMAX 250 (Emcure)'
);

-- line #4728
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'BIVALURIDIN', u'always_empty': u'', u'form': u'VIAL', u'brand': u'BIVAFLO', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #4729
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLEDMAX 15 (MAX)',
	'Bleomycin',
	'INJ',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLEDMAX 15 (MAX)'
);

-- line #4730
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'15U.', u'strength_2': u'', u'substance': u'Bleomycin', u'always_empty': u'', u'form': u'INJ', u'brand': u'BLEOCARE', u'strength_3': u'', u'company': u'Criticare', u'unit': u''}

-- line #4731
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'30U', u'strength_2': u'', u'substance': u'Bleomycin', u'always_empty': u'', u'form': u'INJ', u'brand': u'BLEOCARE', u'strength_3': u'', u'company': u'Criticare', u'unit': u''}

-- line #4732
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'15IU', u'strength_2': u'', u'substance': u'Bleomycin', u'always_empty': u'', u'form': u'INJ', u'brand': u'BLEOCEL', u'strength_3': u'', u'company': u'CELON(VIVILON)', u'unit': u''}

-- line #4733
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLEOCHEM 15 (Biochem)',
	'Bleomycin',
	'INJ',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLEOCHEM 15 (Biochem)'
);

-- line #4734
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLEOCIN 15 (Khandelwal)',
	'Bleomycin',
	'INJ',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLEOCIN 15 (Khandelwal)'
);

-- line #4735
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLEOCIP 15 (Cipla)',
	'Bleomycin',
	'INJ',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLEOCIP 15 (Cipla)'
);

-- line #4736
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1V&15U SOLVENT', u'strength_2': u'', u'substance': u'Bleomycin', u'always_empty': u'', u'form': u'INJ', u'brand': u'BLEOLEM', u'strength_3': u'', u'company': u'Lemery', u'unit': u''}

-- line #4737
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'15U.', u'strength_2': u'', u'substance': u'Bleomycin', u'always_empty': u'', u'form': u'INJ', u'brand': u'BLEONCO', u'strength_3': u'', u'company': u'VHB', u'unit': u''}

-- line #4738
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'15IU(SULPH)', u'strength_2': u'', u'substance': u'Bleomycin', u'always_empty': u'', u'form': u'INJ', u'brand': u'BLEOSTAR-S', u'strength_3': u'', u'company': u'CH.Bhagat', u'unit': u''}

-- line #4739
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'15 UNITS', u'strength_2': u'', u'substance': u'Bleomycin', u'always_empty': u'', u'form': u'INJ', u'brand': u'BLEOTEX', u'strength_3': u'', u'company': u'Cytomed(Alkem)', u'unit': u''}

-- line #4740
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Bleomycin', u'always_empty': u'', u'form': u'VIAL', u'brand': u'NAPROBLEO', u'strength_3': u'', u'company': u'MIRACALUS', u'unit': u''}

-- line #4741
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONCOBLEO 15 (Sun)',
	'Bleomycin',
	'INJ',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONCOBLEO 15 (Sun)'
);

-- line #4742
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'BOERHAVIA DIFFUSA CRATEVA NURVALA TRIBULUS TERRESTRIS ETC', u'always_empty': u'', u'form': u'', u'brand': u'OUTFLO', u'strength_3': u'', u'company': u'PINK HEALTH', u'unit': u''}

-- line #4743
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BAXIMIB 2 (Ranbaxy)',
	'BORTEZOMIB',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BAXIMIB 2 (Ranbaxy)'
);

-- line #4744
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BAXIMIB 3.5 (Ranbaxy)',
	'BORTEZOMIB',
	'INJ',
	gm.nullify_empty_string('3.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BAXIMIB 3.5 (Ranbaxy)'
);

-- line #4745
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BORTECAD 2 (Cadila Ph.)',
	'BORTEZOMIB',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BORTECAD 2 (Cadila Ph.)'
);

-- line #4746
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BORTENAT 2 (Natco Ph.)',
	'BORTEZOMIB',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BORTENAT 2 (Natco Ph.)'
);

-- line #4747
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BORTENAT 3.5 (Natco Ph.)',
	'BORTEZOMIB',
	'INJ',
	gm.nullify_empty_string('3.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BORTENAT 3.5 (Natco Ph.)'
);

-- line #4748
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BORVIZ 2 (Intas)',
	'BORTEZOMIB',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BORVIZ 2 (Intas)'
);

-- line #4749
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BORVIZ 3.5 (Intas)',
	'BORTEZOMIB',
	'INJ',
	gm.nullify_empty_string('3.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BORVIZ 3.5 (Intas)'
);

-- line #4750
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BOTEPAR 2 (Parenteral)',
	'BORTEZOMIB',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BOTEPAR 2 (Parenteral)'
);

-- line #4751
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORTEZ 2 (Zuventus)',
	'BORTEZOMIB',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORTEZ 2 (Zuventus)'
);

-- line #4752
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORTEZ 3.5 (Zuventus)',
	'BORTEZOMIB',
	'INJ',
	gm.nullify_empty_string('3.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORTEZ 3.5 (Zuventus)'
);

-- line #4753
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROTEOZ 2 (ZYDUS ONCO.)',
	'BORTEZOMIB',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROTEOZ 2 (ZYDUS ONCO.)'
);

-- line #4754
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BOZENA 125 (Cipla)',
	'BOSENTAN',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BOZENA 125 (Cipla)'
);

-- line #4755
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BOZENA 62.5 (Cipla)',
	'BOSENTAN',
	'TAB',
	gm.nullify_empty_string('62.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BOZENA 62.5 (Cipla)'
);

-- line #4756
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBRIM 0.15 (Alembic)',
	'Brimonidine Tartrate',
	'DPS',
	gm.nullify_empty_string('0.15')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBRIM 0.15 (Alembic)'
);

-- line #4757
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBRIM 0.1 (Alembic)',
	'Brimonidine Tartrate',
	'LS DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBRIM 0.1 (Alembic)'
);

-- line #4758
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALCON BRIMO OPHTH 0.15 (Alcon Lab)',
	'Brimonidine Tartrate',
	'SOL',
	gm.nullify_empty_string('0.15')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALCON BRIMO OPHTH 0.15 (Alcon Lab)'
);

-- line #4759
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPHAGAN 2 (Allergan)',
	'Brimonidine Tartrate',
	'DPS',
	gm.nullify_empty_string('2')::numeric,
	'mg(+POLIVINYL ALCOHOL'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPHAGAN 2 (Allergan)'
);

-- line #4760
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPHAGAN-P 0.15 (Allergan)',
	'Brimonidine Tartrate',
	'EYE DPS',
	gm.nullify_empty_string('0.15')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPHAGAN-P 0.15 (Allergan)'
);

-- line #4761
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1', u'strength_2': u'', u'substance': u'Brimonidine Tartrate', u'always_empty': u'', u'form': u'', u'brand': u'ALPHAGAN-Z', u'strength_3': u'', u'company': u'Allergan', u'unit': u'mg'}

-- line #4762
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRIMODIN 2 (Cipla)',
	'Brimonidine Tartrate',
	'EYE DPS',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRIMODIN 2 (Cipla)'
);

-- line #4763
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,2', u'strength_2': u'', u'substance': u'Brimonidine Tartrate', u'always_empty': u'', u'form': u'', u'brand': u'BRIMOPRESS', u'strength_3': u'', u'company': u'Centaur', u'unit': u'%'}

-- line #4764
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRIMOSUN 1.5 (Milmet)',
	'Brimonidine Tartrate',
	'EYE DPS',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRIMOSUN 1.5 (Milmet)'
);

-- line #4765
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRIMOSUN 0.1 (Sun)',
	'Brimonidine Tartrate',
	'LS SOL',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRIMOSUN 0.1 (Sun)'
);

-- line #4766
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLAUCOM 2 (Jawa Ph.)',
	'Brimonidine Tartrate',
	'EYE DPS',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLAUCOM 2 (Jawa Ph.)'
);

-- line #4767
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IOBRIM 0.2 (F D C)',
	'Brimonidine Tartrate',
	'EYE DPS',
	gm.nullify_empty_string('0.2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IOBRIM 0.2 (F D C)'
);

-- line #4768
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIMONID 0.15 (Micro V.)',
	'Brimonidine Tartrate',
	'EYE DPS',
	gm.nullify_empty_string('0.15')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIMONID 0.15 (Micro V.)'
);

-- line #4769
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BROMOZYME 200 (Aksigen Hosp.)',
	'BROMELAIN',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BROMOZYME 200 (Aksigen Hosp.)'
);

-- line #4770
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADBROM 1.035 (Entod Ph.)',
	'BROMFENAC SOD.',
	'EYE DPS',
	gm.nullify_empty_string('1.035')::numeric,
	'mg(BROMFENAC FREE ACID 0.9'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADBROM 1.035 (Entod Ph.)'
);

-- line #4771
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BFN 0.09 (Micro Labs)',
	'BROMFENAC SOD.',
	'EYE DROP',
	gm.nullify_empty_string('0.09')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BFN 0.09 (Micro Labs)'
);

-- line #4772
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,09', u'strength_2': u'', u'substance': u'BROMFENAC SOD.', u'always_empty': u'', u'form': u'', u'brand': u'BROMAID', u'strength_3': u'', u'company': u'Elder', u'unit': u'0.01'}

-- line #4773
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BROMENAC EYE 0.9 (LIFESTAR)',
	'BROMFENAC SOD.',
	'DROPS',
	gm.nullify_empty_string('0.9')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BROMENAC EYE 0.9 (LIFESTAR)'
);

-- line #4774
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BROM EYE 1.035 (Yash Ph.)',
	'BROMFENAC SOD.',
	'DROPS',
	gm.nullify_empty_string('1.035')::numeric,
	'mg(BROMFENAC FREE ACID 0.9'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BROM EYE 1.035 (Yash Ph.)'
);

-- line #4775
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BROMIFEN 0.09 (Optho Rem.)',
	'BROMFENAC SOD.',
	'EYE DPS',
	gm.nullify_empty_string('0.09')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BROMIFEN 0.09 (Optho Rem.)'
);

-- line #4776
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FACO 1.035 (SENSES)',
	'BROMFENAC SOD.',
	'DROPS',
	gm.nullify_empty_string('1.035')::numeric,
	'mg(BROMFENAC FREE ACID 0.9'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FACO 1.035 (SENSES)'
);

-- line #4777
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BISOLVON 4 (German R.)',
	'Bromhexine Hcl.',
	'EXP LIQ',
	gm.nullify_empty_string('4')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BISOLVON 4 (German R.)'
);

-- line #4778
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BISOLVON 8 (German R.)',
	'Bromhexine Hcl.',
	'EXP TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BISOLVON 8 (German R.)'
);

-- line #4779
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BROMEX 4 (Cipla)',
	'Bromhexine Hcl.',
	'SYR',
	gm.nullify_empty_string('4')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BROMEX 4 (Cipla)'
);

-- line #4780
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BROMEX 8 (Cipla)',
	'Bromhexine Hcl.',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BROMEX 8 (Cipla)'
);

-- line #4781
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BROMHEXINE 4 (Ipca)',
	'Bromhexine Hcl.',
	'SYR',
	gm.nullify_empty_string('4')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BROMHEXINE 4 (Ipca)'
);

-- line #4782
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BROMHEXINE 8 (Ipca)',
	'Bromhexine Hcl.',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BROMHEXINE 8 (Ipca)'
);

-- line #4783
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHESTON 4 (Cipla)',
	'Bromhexine Hcl.',
	'SYR',
	gm.nullify_empty_string('4')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHESTON 4 (Cipla)'
);

-- line #4784
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUKE 8 (Bipl(Radico Lab))',
	'Bromhexine',
	'SYR',
	gm.nullify_empty_string('8')::numeric,
	'mg/10ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUKE 8 (Bipl(Radico Lab))'
);

-- line #4785
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUKE 8 (Bipl(Radico Lab))',
	'Bromhexine',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUKE 8 (Bipl(Radico Lab))'
);

-- line #4786
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESPOTAB 4 (GSK)',
	'Bromhexine',
	'SYR',
	gm.nullify_empty_string('4')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESPOTAB 4 (GSK)'
);

-- line #4787
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESPOTAB 16 (GSK)',
	'Bromhexine',
	'TAB',
	gm.nullify_empty_string('16')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESPOTAB 16 (GSK)'
);

-- line #4788
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'B CRIP 1.25 (Solvay Ph.)',
	'Bromocriptine',
	'TAB',
	gm.nullify_empty_string('1.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'B CRIP 1.25 (Solvay Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'B CRIP 2.5 (Solvay Ph.)',
	'Bromocriptine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'B CRIP 2.5 (Solvay Ph.)'
);

-- line #4789
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'B CRIP 5 (Solvay Ph.)',
	'Bromocriptine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'B CRIP 5 (Solvay Ph.)'
);

-- line #4790
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'8', u'strength_2': u'', u'substance': u'Bromocriptine', u'always_empty': u'', u'form': u'', u'brand': u'BRAINSTAR', u'strength_3': u'', u'company': u'USV', u'unit': u'mg'}

-- line #4791
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRIPTIN 1.25 (Walter B.)',
	'Bromocriptine',
	'TAB',
	gm.nullify_empty_string('1.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRIPTIN 1.25 (Walter B.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRIPTIN 2.5 (Walter B.)',
	'Bromocriptine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRIPTIN 2.5 (Walter B.)'
);

-- line #4792
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BROMOGEN 1.25 (Uni-Sank.)',
	'Bromocriptine',
	'TAB',
	gm.nullify_empty_string('1.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BROMOGEN 1.25 (Uni-Sank.)'
);

-- line #4793
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BROMOGEN 2.5 (Uni-Sank.)',
	'Bromocriptine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BROMOGEN 2.5 (Uni-Sank.)'
);

-- line #4794
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BROMOREX 1.25 (Ar-Ex Labs.)',
	'Bromocriptine',
	'TAB',
	gm.nullify_empty_string('1.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BROMOREX 1.25 (Ar-Ex Labs.)'
);

-- line #4795
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BROMOREX 2.5 (Ar-Ex Labs.)',
	'Bromocriptine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BROMOREX 2.5 (Ar-Ex Labs.)'
);

-- line #4796
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BROMOTIN 1.435 (Rpg Life)',
	'Bromocriptine',
	'TAB',
	gm.nullify_empty_string('1.435')::numeric,
	'1.25'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BROMOTIN 1.435 (Rpg Life)'
);

-- line #4797
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BROMOTIN 2.87 (Rpg Life)',
	'Bromocriptine',
	'TAB',
	gm.nullify_empty_string('2.87')::numeric,
	'2.5'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BROMOTIN 2.87 (Rpg Life)'
);

-- line #4798
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BROM 1.25 (Inga)',
	'Bromocriptine',
	'TAB',
	gm.nullify_empty_string('1.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BROM 1.25 (Inga)'
);

-- line #4799
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BROM 2.5 (Inga)',
	'Bromocriptine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BROM 2.5 (Inga)'
);

-- line #4800
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CRIPTAL 1.25 (Helios Ph.)',
	'Bromocriptine',
	'TAB',
	gm.nullify_empty_string('1.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CRIPTAL 1.25 (Helios Ph.)'
);

-- line #4801
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CRIPTAL 2.5 (Helios Ph.)',
	'Bromocriptine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CRIPTAL 2.5 (Helios Ph.)'
);

-- line #4802
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DBRO 0.8 (SINSAN PH.)',
	'Bromocriptine',
	'TAB',
	gm.nullify_empty_string('0.8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DBRO 0.8 (SINSAN PH.)'
);

-- line #4803
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIACRIPTINE 0.8 (DELVIN)',
	'Bromocriptine',
	'TAB',
	gm.nullify_empty_string('0.8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIACRIPTINE 0.8 (DELVIN)'
);

-- line #4804
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENCRIPT 2.5 (Synapse)',
	'Bromocriptine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENCRIPT 2.5 (Synapse)'
);

-- line #4805
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENCRIPT 5 (Synapse)',
	'Bromocriptine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENCRIPT 5 (Synapse)'
);

-- line #4806
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,8', u'strength_2': u'', u'substance': u'Bromocriptine', u'always_empty': u'', u'form': u'', u'brand': u"LUPIN''S GLUCOMIND", u'strength_3': u'', u'company': u'Lupin', u'unit': u'mg'}

-- line #4807
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OVUCRIPT 1.25 (VHB)',
	'Bromocriptine',
	'TAB',
	gm.nullify_empty_string('1.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OVUCRIPT 1.25 (VHB)'
);

-- line #4808
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OVUCRIPT 2.5 (VHB)',
	'Bromocriptine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OVUCRIPT 2.5 (VHB)'
);

-- line #4809
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARLODEL 2.5 (Novartis)',
	'Bromocriptine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARLODEL 2.5 (Novartis)'
);

-- line #4810
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POLODYL 2.5 (CH.Bhagat)',
	'Bromocriptine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POLODYL 2.5 (CH.Bhagat)'
);

-- line #4811
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROCTINAL 1.25 (Gsk)',
	'Bromocriptine',
	'TAB',
	gm.nullify_empty_string('1.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROCTINAL 1.25 (Gsk)'
);

-- line #4812
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROCTINAL 2.5 (Gsk)',
	'Bromocriptine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROCTINAL 2.5 (Gsk)'
);

-- line #4813
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LONGIFENE 12 (Mankind)',
	'Buclizine Hcl.',
	'DS SYR',
	gm.nullify_empty_string('12')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LONGIFENE 12 (Mankind)'
);

-- line #4814
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LONGIFENE 50 (Mankind)',
	'Buclizine Hcl.',
	'DS TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LONGIFENE 50 (Mankind)'
);

-- line #4815
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LONGIFENE 6 (Ucb India)',
	'Buclizine Hcl.',
	'SYR',
	gm.nullify_empty_string('6')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LONGIFENE 6 (Ucb India)'
);

-- line #4816
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LONGIFENE 25 (Ucb India)',
	'Buclizine Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LONGIFENE 25 (Ucb India)'
);

-- line #4817
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100MCG', u'strength_2': u'', u'substance': u'Budesonide', u'always_empty': u'', u'form': u'CAP', u'brand': u'BUDATE', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #4818
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BUDATE-F 1 (Lupin)',
	'Budesonide',
	'RESP',
	gm.nullify_empty_string('1')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BUDATE-F 1 (Lupin)'
);

-- line #4819
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BUDATE 0.5 (Lupin)',
	'Budesonide',
	'RESP',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BUDATE 0.5 (Lupin)'
);

-- line #4820
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100MCG', u'strength_2': u'D.', u'substance': u'Budesonide', u'always_empty': u'', u'form': u'', u'brand': u'BUDECORT HFA INH', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #4821
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200MCG', u'strength_2': u'D.', u'substance': u'Budesonide', u'always_empty': u'', u'form': u'', u'brand': u'BUDECORT HFA INH', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #4822
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100MCG', u'strength_2': u'DOSE', u'substance': u'Budesonide', u'always_empty': u'', u'form': u'INHALER', u'brand': u'BUDECORT', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #4823
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200MCG', u'strength_2': u'DOSE', u'substance': u'Budesonide', u'always_empty': u'', u'form': u'INHALER', u'brand': u'BUDECORT', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #4824
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100MCG', u'strength_2': u'', u'substance': u'Budesonide', u'always_empty': u'', u'form': u'', u'brand': u'BUDECORT NEOHALER', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #4825
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200MCG', u'strength_2': u'', u'substance': u'Budesonide', u'always_empty': u'', u'form': u'', u'brand': u'BUDECORT NEOHALER', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #4826
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BUDECORT 0.25 (Cipla)',
	'Budesonide',
	'RES',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BUDECORT 0.25 (Cipla)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BUDECORT 0.5 (Cipla)',
	'Budesonide',
	'RES',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BUDECORT 0.5 (Cipla)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BUDECORT 1 (Cipla)',
	'Budesonide',
	'RES',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BUDECORT 1 (Cipla)'
);

-- line #4827
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100', u'strength_2': u'200', u'substance': u'Budesonide', u'always_empty': u'', u'form': u'ROTACAPS', u'brand': u'BUDECORT', u'strength_3': u'400;MCG', u'company': u'Cipla', u'unit': u''}

-- line #4828
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BUDEFEX 3 (Ranbaxy)',
	'Budesonide',
	'CR CAP',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BUDEFEX 3 (Ranbaxy)'
);

-- line #4829
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100MCG', u'strength_2': u'DOSE', u'substance': u'Budesonide', u'always_empty': u'', u'form': u'', u'brand': u'BUDENASE AQ', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #4830
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Budesonide', u'always_empty': u'', u'form': u'', u'brand': u'BUDEZ ENEMA', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #4831
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100', u'strength_2': u'200;MCG', u'substance': u'Budesonide', u'always_empty': u'', u'form': u'INHALER', u'brand': u'BUDEZ', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #4832
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BUDEZ 0.02 (Sun)',
	'Budesonide',
	'NASAL SPRAY',
	gm.nullify_empty_string('0.02')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BUDEZ 0.02 (Sun)'
);

-- line #4833
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100', u'strength_2': u'200MCG', u'substance': u'Budesonide', u'always_empty': u'', u'form': u'', u'brand': u'BUDVENT EASECAPS', u'strength_3': u'', u'company': u'Kresp', u'unit': u''}

-- line #4834
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'400MCG', u'strength_2': u'', u'substance': u'Budesonide', u'always_empty': u'', u'form': u'', u'brand': u'BUDVENT EASECAPS', u'strength_3': u'', u'company': u'Kresp', u'unit': u''}

-- line #4835
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100', u'strength_2': u'200MCG', u'substance': u'Budesonide', u'always_empty': u'', u'form': u'', u'brand': u'BUDVENT INH100/200', u'strength_3': u'', u'company': u'Kresp', u'unit': u''}

-- line #4836
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100MCG', u'strength_2': u'', u'substance': u'Budesonide', u'always_empty': u'', u'form': u'CAP', u'brand': u'BUNASE', u'strength_3': u'', u'company': u'Macleods', u'unit': u''}

-- line #4837
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200MCG', u'strength_2': u'', u'substance': u'Budesonide', u'always_empty': u'', u'form': u'CAP', u'brand': u'BUNASE', u'strength_3': u'', u'company': u'Macleods', u'unit': u''}

-- line #4838
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'400MCG', u'strength_2': u'', u'substance': u'Budesonide', u'always_empty': u'', u'form': u'CAP', u'brand': u'BUNASE', u'strength_3': u'', u'company': u'Macleods', u'unit': u''}

-- line #4839
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100MCG(ETHANOL 1.0', u'strength_2': u'', u'substance': u'Budesonide', u'always_empty': u'', u'form': u'', u'brand': u'BUNASE (INHALER)', u'strength_3': u'', u'company': u'Macleods', u'unit': u'%W/W)'}

-- line #4840
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200MCG(ETHANOL 1.0', u'strength_2': u'', u'substance': u'Budesonide', u'always_empty': u'', u'form': u'', u'brand': u'BUNASE (INHALER)', u'strength_3': u'', u'company': u'Macleods', u'unit': u'%W/W)'}

-- line #4841
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BUNASE 0.5 (Macleods)',
	'Budesonide',
	'RES',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BUNASE 0.5 (Macleods)'
);

-- line #4842
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BUNASE 1 (Macleods)',
	'Budesonide',
	'RESUPLES',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BUNASE 1 (Macleods)'
);

-- line #4843
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BUNIDE 3 (Natco Ph.)',
	'Budesonide',
	'CR CAP',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BUNIDE 3 (Natco Ph.)'
);

-- line #4844
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100MCG', u'strength_2': u'D.', u'substance': u'Budesonide', u'always_empty': u'', u'form': u'', u'brand': u'DERINIDE INH', u'strength_3': u'', u'company': u'German R.', u'unit': u''}

-- line #4845
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200MCG', u'strength_2': u'D.', u'substance': u'Budesonide', u'always_empty': u'', u'form': u'', u'brand': u'DERINIDE INH', u'strength_3': u'', u'company': u'German R.', u'unit': u''}

-- line #4846
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DERINIDE 0.5 (German R.)',
	'Budesonide',
	'RES',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DERINIDE 0.5 (German R.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DERINIDE 1 (German R.)',
	'Budesonide',
	'RES',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DERINIDE 1 (German R.)'
);

-- line #4847
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100MCG', u'strength_2': u'', u'substance': u'Budesonide', u'always_empty': u'', u'form': u'RESPICAPS', u'brand': u'DERINIDE', u'strength_3': u'', u'company': u'German R.', u'unit': u''}

-- line #4848
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200MCG', u'strength_2': u'', u'substance': u'Budesonide', u'always_empty': u'', u'form': u'RESPICAPS', u'brand': u'DERINIDE', u'strength_3': u'', u'company': u'German R.', u'unit': u''}

-- line #4849
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'400MCG', u'strength_2': u'', u'substance': u'Budesonide', u'always_empty': u'', u'form': u'RESPICAPS', u'brand': u'DERINIDE', u'strength_3': u'', u'company': u'German R.', u'unit': u''}

-- line #4850
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100MCG', u'strength_2': u'', u'substance': u'Budesonide', u'always_empty': u'', u'form': u'', u'brand': u'PULMICORT INH', u'strength_3': u'', u'company': u'Astrazeneca', u'unit': u''}

-- line #4851
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200MCG', u'strength_2': u'', u'substance': u'Budesonide', u'always_empty': u'', u'form': u'', u'brand': u'PULMICORT INH', u'strength_3': u'', u'company': u'Astrazeneca', u'unit': u''}

-- line #4852
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'400MCG', u'strength_2': u'', u'substance': u'Budesonide', u'always_empty': u'', u'form': u'', u'brand': u'PULMICORT INH', u'strength_3': u'', u'company': u'Astrazeneca', u'unit': u''}

-- line #4853
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PULMICORT 0.25 (Astrazeneca)',
	'Budesonide',
	'RESP',
	gm.nullify_empty_string('0.25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PULMICORT 0.25 (Astrazeneca)'
);

-- line #4854
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PULMICORT 0.5 (Astrazeneca)',
	'Budesonide',
	'RESP',
	gm.nullify_empty_string('0.5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PULMICORT 0.5 (Astrazeneca)'
);

-- line #4855
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'64MCG', u'strength_2': u'', u'substance': u'Budesonide', u'always_empty': u'', u'form': u'', u'brand': u'RHINOCORT AQUA', u'strength_3': u'', u'company': u'Astrazeneca', u'unit': u''}

-- line #4856
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50MCG', u'strength_2': u'DOSE', u'substance': u'Budesonide', u'always_empty': u'', u'form': u'NASAL SPRAY', u'brand': u'RHINOCORT', u'strength_3': u'', u'company': u'Astrazeneca', u'unit': u''}

-- line #4857
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50MCG', u'strength_2': u'1PUFF', u'substance': u'Budesonide', u'always_empty': u'', u'form': u'', u'brand': u'RHINOCORT SPY', u'strength_3': u'', u'company': u'Astrazeneca', u'unit': u''}

-- line #4858
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AABLAQUIN 25 (Piramal Hc.)',
	'Bulaquine',
	'CAP',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AABLAQUIN 25 (Piramal Hc.)'
);

-- line #4859
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANAWIN % 0.25 (Neon)',
	'Bupivacaine',
	'INJ',
	gm.nullify_empty_string('0.25')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANAWIN % 0.25 (Neon)'
);

-- line #4860
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANAWIN 5 (Neon)',
	'Bupivacaine',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANAWIN 5 (Neon)'
);

-- line #4861
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANAWIN 5 (Neon)',
	'Bupivacaine',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANAWIN 5 (Neon)'
);

-- line #4862
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Bupivacaine', u'always_empty': u'', u'form': u'INJ', u'brand': u'BUPITROY HEAVY', u'strength_3': u'', u'company': u'Troikaa', u'unit': u''}

-- line #4863
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,0025', u'strength_2': u'', u'substance': u'Bupivacaine', u'always_empty': u'', u'form': u'INJ', u'brand': u'BUPITROY', u'strength_3': u'', u'company': u'Troikaa', u'unit': u''}

-- line #4864
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,005', u'strength_2': u'', u'substance': u'Bupivacaine', u'always_empty': u'', u'form': u'INJ', u'brand': u'BUPITROY', u'strength_3': u'', u'company': u'Troikaa', u'unit': u''}

-- line #4865
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BUPIVACAINE % 0.25 (I C I)',
	'Bupivacaine',
	'INJ',
	gm.nullify_empty_string('0.25')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BUPIVACAINE % 0.25 (I C I)'
);

-- line #4866
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BUPIVACAINE % 0.5 (I C I)',
	'Bupivacaine',
	'INJ',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BUPIVACAINE % 0.5 (I C I)'
);

-- line #4867
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BUPIVAC 0.25 (CELON(REVILON))',
	'Bupivacaine',
	'VIAL',
	gm.nullify_empty_string('0.25')::numeric,
	'0.5'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BUPIVAC 0.25 (CELON(REVILON))'
);

-- line #4868
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BUPIVAN 0.25 (Globus)',
	'Bupivacaine',
	'INJ',
	gm.nullify_empty_string('0.25')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BUPIVAN 0.25 (Globus)'
);

-- line #4869
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BUPIVAN 0.5 (Globus)',
	'Bupivacaine',
	'INJ',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BUPIVAN 0.5 (Globus)'
);

-- line #4870
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BUPIVAN 0.25 (INCA(SUN))',
	'Bupivacaine',
	'INJ',
	gm.nullify_empty_string('0.25')::numeric,
	'0.5'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BUPIVAN 0.25 (INCA(SUN))'
);

-- line #4871
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BUPIVAN 0.5 (INCA(SUN))',
	'Bupivacaine',
	'INJ',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BUPIVAN 0.5 (INCA(SUN))'
);

-- line #4872
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LONGICAINE 0.5 (Csc Ph.)',
	'Bupivacaine',
	'INJ',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LONGICAINE 0.5 (Csc Ph.)'
);

-- line #4873
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MARCAIN (HYPERBARIC) % 1 (Nicholas)',
	'Bupivacaine',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MARCAIN (HYPERBARIC) % 1 (Nicholas)'
);

-- line #4874
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MARCAIN % 0.5 (Nicholas)',
	'Bupivacaine',
	'INJ',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MARCAIN % 0.5 (Nicholas)'
);

-- line #4875
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELICAINE HEAVY 5 (Bharat S.)',
	'Bupivacaine',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELICAINE HEAVY 5 (Bharat S.)'
);

-- line #4876
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELICAINE 0.5 (Bharat S.)',
	'Bupivacaine',
	'INJ',
	gm.nullify_empty_string('0.5')::numeric,
	'%/20ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELICAINE 0.5 (Bharat S.)'
);

-- line #4877
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REPIVACAIN 5 (Ind-Swift)',
	'Bupivacaine',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REPIVACAIN 5 (Ind-Swift)'
);

-- line #4878
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADDNOK 0.2 (Rusan Hc)',
	'Buprenorphine',
	'TAB',
	gm.nullify_empty_string('0.2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADDNOK 0.2 (Rusan Hc)'
);

-- line #4879
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENERGENCE 0.3 (Ind-Swift)',
	'Buprenorphine',
	'INJ',
	gm.nullify_empty_string('0.3')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENERGENCE 0.3 (Ind-Swift)'
);

-- line #4880
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BUNOGESIC 0.3 (Rusan Hc)',
	'Buprenorphine',
	'INJ',
	gm.nullify_empty_string('0.3')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BUNOGESIC 0.3 (Rusan Hc)'
);

-- line #4881
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BUPRIGESIC 0.3 (Neon)',
	'Buprenorphine',
	'AMP',
	gm.nullify_empty_string('0.3')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BUPRIGESIC 0.3 (Neon)'
);

-- line #4882
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BUPRINOR 0.3 (Astrazeneca)',
	'Buprenorphine',
	'INJ',
	gm.nullify_empty_string('0.3')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BUPRINOR 0.3 (Astrazeneca)'
);

-- line #4883
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLORPHIN 0.3 (Gland Ph.)',
	'Buprenorphine',
	'AMP1',
	gm.nullify_empty_string('0.3')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLORPHIN 0.3 (Gland Ph.)'
);

-- line #4884
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLORPHIN 0.3 (Gland Ph.)',
	'Buprenorphine',
	'AMP2',
	gm.nullify_empty_string('0.3')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLORPHIN 0.3 (Gland Ph.)'
);

-- line #4885
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'600 MCG', u'strength_2': u'', u'substance': u'Buprenorphine', u'always_empty': u'', u'form': u'INJ', u'brand': u'MORGESIC', u'strength_3': u'', u'company': u'Samarth', u'unit': u''}

-- line #4886
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOOPHIN 0.3 (Dynamic)',
	'Buprenorphine',
	'INJ',
	gm.nullify_empty_string('0.3')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOOPHIN 0.3 (Dynamic)'
);

-- line #4887
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORPHIGESIC 0.3 (Csc Ph.)',
	'Buprenorphine',
	'INJ',
	gm.nullify_empty_string('0.3')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORPHIGESIC 0.3 (Csc Ph.)'
);

-- line #4888
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORPHIN 0.3 (Unichem)',
	'Buprenorphine',
	'AMP',
	gm.nullify_empty_string('0.3')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORPHIN 0.3 (Unichem)'
);

-- line #4889
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENTOREL 0.3 (Khandelwal)',
	'Buprenorphine',
	'INJ',
	gm.nullify_empty_string('0.3')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENTOREL 0.3 (Khandelwal)'
);

-- line #4890
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BUPEP 150 (Cipla)',
	'BUPROPION HCL.',
	'SR TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BUPEP 150 (Cipla)'
);

-- line #4891
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BUPRON 150 (Sun)',
	'Bupropion Hcl.',
	'SR TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BUPRON 150 (Sun)'
);

-- line #4892
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NICOTEX 150 (Cipla)',
	'Bupropion Hcl.',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NICOTEX 150 (Cipla)'
);

-- line #4893
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BUSARLIN 1 (Intas)',
	'BUSARLIN PH. EUR',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'mg(+BENZYL ALCOHOL 10'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BUSARLIN 1 (Intas)'
);

-- line #4894
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BUSELIN 0.5 (Samarth)',
	'BUSERELIN',
	'INJ',
	gm.nullify_empty_string('0.5')::numeric,
	'mg/0.5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BUSELIN 0.5 (Samarth)'
);

-- line #4895
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BUSELIN 7 (Samarth)',
	'BUSERELIN',
	'INJ',
	gm.nullify_empty_string('7')::numeric,
	'mg/7ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BUSELIN 7 (Samarth)'
);

-- line #4896
-- ignoring line: field [strength_1] not numeric: >>>1(10<<<
-- {u'list_of_values_of_unknown_fields': [u' mg SOD. CHL.)', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1(10', u'strength_2': u'', u'substance': u'BUSERLIN', u'always_empty': u'', u'form': u'INJ', u'brand': u'BUSAG', u'strength_3': u'', u'company': u'German R.', u'unit': u'mg BENZYL ALCOHOL'}

-- line #4897
-- ignoring line: field [strength_1] not numeric: >>>1(10<<<
-- {u'list_of_values_of_unknown_fields': [u' mg SOD. CHL.)', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1(10', u'strength_2': u'', u'substance': u'BUSERLIN', u'always_empty': u'', u'form': u'INJ', u'brand': u'GUSAG', u'strength_3': u'', u'company': u'German R.', u'unit': u'mg BENZYL ALCOHOL'}

-- line #4898
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANXIPAR 10 (Torrent)',
	'Buspirone Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANXIPAR 10 (Torrent)'
);

-- line #4899
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANXIPAR 5 (Torrent)',
	'Buspirone Hcl.',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANXIPAR 5 (Torrent)'
);

-- line #4900
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BUSCALM 10 (Merind)',
	'Buspirone Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BUSCALM 10 (Merind)'
);

-- line #4901
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BUSCALM 5 (Merind)',
	'Buspirone Hcl.',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BUSCALM 5 (Merind)'
);

-- line #4902
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BUSIRON 10 (Tripada Hc.)',
	'Buspirone Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BUSIRON 10 (Tripada Hc.)'
);

-- line #4903
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BUSIRON 5 (Tripada Hc.)',
	'Buspirone Hcl.',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BUSIRON 5 (Tripada Hc.)'
);

-- line #4904
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BUSON 10 (Kramer)',
	'Buspirone Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BUSON 10 (Kramer)'
);

-- line #4905
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BUSON 5 (Kramer)',
	'Buspirone Hcl.',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BUSON 5 (Kramer)'
);

-- line #4906
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BUSPIDAC 10 (Zydus A.)',
	'Buspirone Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BUSPIDAC 10 (Zydus A.)'
);

-- line #4907
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BUSPIDAC 5 (Zydus A.)',
	'Buspirone Hcl.',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BUSPIDAC 5 (Zydus A.)'
);

-- line #4908
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BUSPIN 10 (Intas)',
	'Buspirone Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BUSPIN 10 (Intas)'
);

-- line #4909
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BUSPIN 5 (Intas)',
	'Buspirone Hcl.',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BUSPIN 5 (Intas)'
);

-- line #4910
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BUCELON 60 (CELON(VIVILON))',
	'Busulphan',
	'AMP',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BUCELON 60 (CELON(VIVILON))'
);

-- line #4911
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BUCELON 2 (CELON(VIVILON))',
	'Busulphan',
	'FC TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BUCELON 2 (CELON(VIVILON))'
);

-- line #4912
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BUSULFAN 2 (CH.Bhagat)',
	'Busulphan',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BUSULFAN 2 (CH.Bhagat)'
);

-- line #4913
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BUSUPHAN 2 (Elder)',
	'Busulphan',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BUSUPHAN 2 (Elder)'
);

-- line #4914
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYLEFAN 2 (Cadila Hc.)',
	'Busulphan',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYLEFAN 2 (Cadila Hc.)'
);

-- line #4915
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYLERAN 2 (Gsk)',
	'Busulphan',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYLERAN 2 (Gsk)'
);

-- line #4916
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYRAN 2 (Vhb)',
	'Busulphan',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYRAN 2 (Vhb)'
);

-- line #4917
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYSULFAN 2 (CH.Bhagat)',
	'Busulphan',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYSULFAN 2 (CH.Bhagat)'
);

-- line #4918
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BUTENASKIN 1 (Elder)',
	'Butenafine Hydrochloride',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BUTENASKIN 1 (Elder)'
);

-- line #4919
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BUTOP 1 (Cipla)',
	'Butenafine Hydrochloride',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BUTOP 1 (Cipla)'
);

-- line #4920
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXEBUTE 1 (Ochoa)',
	'Butenafine Hydrochloride',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXEBUTE 1 (Ochoa)'
);

-- line #4921
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FINTOP 1 (Gracewell)',
	'Butenafine Hydrochloride',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FINTOP 1 (Gracewell)'
);

-- line #4922
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BUTODOL 1 (Neon)',
	'Butorphanol Tartrate',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BUTODOL 1 (Neon)'
);

-- line #4923
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BUTODOL 2 (Neon)',
	'Butorphanol Tartrate',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BUTODOL 2 (Neon)'
);

-- line #4924
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BUTOLOL 1 (NEON)',
	'Butorphanol Tartrate',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BUTOLOL 1 (NEON)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BUTOLOL 2 (NEON)',
	'Butorphanol Tartrate',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BUTOLOL 2 (NEON)'
);

-- line #4925
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BUTRUM 1 (Aristo)',
	'Butorphanol Tartrate',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BUTRUM 1 (Aristo)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BUTRUM 2 (Aristo)',
	'Butorphanol Tartrate',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BUTRUM 2 (Aristo)'
);

-- line #4926
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BUTRUM-NS 10 (Aristo)',
	'Butorphanol Tartrate',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BUTRUM-NS 10 (Aristo)'
);

-- line #4927
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CABERCET 0.5 (Bharat S.)',
	'CABERGOLINE',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CABERCET 0.5 (Bharat S.)'
);

-- line #4928
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CABERLIN 0.25 (SUN)',
	'CABERGOLINE',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CABERLIN 0.25 (SUN)'
);

-- line #4929
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CABERLIN 0.5 (Sun)',
	'CABERGOLINE',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CABERLIN 0.5 (Sun)'
);

-- line #4930
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CABERLIN 1 (SUN)',
	'CABERGOLINE',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CABERLIN 1 (SUN)'
);

-- line #4931
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CABGOLIN 0.25 (SUN)',
	'CABERGOLINE',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CABGOLIN 0.25 (SUN)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CABGOLIN 0.5 (SUN)',
	'CABERGOLINE',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CABGOLIN 0.5 (SUN)'
);

-- line #4932
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CABGOLIN 0.5 (Sun)',
	'CABERGOLINE',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CABGOLIN 0.5 (Sun)'
);

-- line #4933
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CABGON-025 0.25 (Intas)',
	'CABERGOLINE',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CABGON-025 0.25 (Intas)'
);

-- line #4934
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CABGON-05 0.5 (Intas)',
	'CABERGOLINE',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CABGON-05 0.5 (Intas)'
);

-- line #4935
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CABLYN 0.5 (CELON)',
	'CABERGOLINE',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CABLYN 0.5 (CELON)'
);

-- line #4936
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CABRE 0.5 (Inga)',
	'CABERGOLINE',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CABRE 0.5 (Inga)'
);

-- line #4937
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAMFORTE 0.25 (Svizera)',
	'CABERGOLINE',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAMFORTE 0.25 (Svizera)'
);

-- line #4938
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAMFORTE 0.5 (Svizera)',
	'CABERGOLINE',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAMFORTE 0.5 (Svizera)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAMFORTE 1 (Svizera)',
	'CABERGOLINE',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAMFORTE 1 (Svizera)'
);

-- line #4939
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CB-LIN 0.5 (Serum Inst.)',
	'CABERGOLINE',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CB-LIN 0.5 (Serum Inst.)'
);

-- line #4940
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CB-LIN 0.25 (Serum Int.)',
	'CABERGOLINE',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CB-LIN 0.25 (Serum Int.)'
);

-- line #4941
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CB-LIN 1 (Serum Int.)',
	'CABERGOLINE',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CB-LIN 1 (Serum Int.)'
);

-- line #4942
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COLETTE 0.25 (CIPLA)',
	'CABERGOLINE',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COLETTE 0.25 (CIPLA)'
);

-- line #4943
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COLETTE 0.5 (CIPLA)',
	'CABERGOLINE',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COLETTE 0.5 (CIPLA)'
);

-- line #4944
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FILOGOL 0.5 (FOURRTS)',
	'CABERGOLINE',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FILOGOL 0.5 (FOURRTS)'
);

-- line #4945
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OVUCAB 0.5 (Vhb)',
	'CABERGOLINE',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OVUCAB 0.5 (Vhb)'
);

-- line #4946
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACIBAN 20 (Cadila Ph.)',
	'c',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACIBAN 20 (Cadila Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACIBAN 40 (Cadila Ph.)',
	'c',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACIBAN 40 (Cadila Ph.)'
);

-- line #4947
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAFIRATE 20 (Sun)',
	'Caffeine CITRATE',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAFIRATE 20 (Sun)'
);

-- line #4948
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAFIRATE ORAL 20 (Sun)',
	'Caffeine CITRATE',
	'SOL',
	gm.nullify_empty_string('20')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAFIRATE ORAL 20 (Sun)'
);

-- line #4949
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'Caffeine CITRATE', u'always_empty': u'', u'form': u'', u'brand': u'CAFIRATE', u'strength_3': u'', u'company': u'Sun', u'unit': u'mg/ML'}

-- line #4950
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTRACAL 8 (Intra Lab)',
	'Calamine',
	'LOT',
	gm.nullify_empty_string('8')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTRACAL 8 (Intra Lab)'
);

-- line #4951
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINIMOIST 8 (Palsons)',
	'Calamine',
	'LOT',
	gm.nullify_empty_string('8')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINIMOIST 8 (Palsons)'
);

-- line #4952
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50MCG', u'strength_2': u'G', u'substance': u'Calcipotriol', u'always_empty': u'', u'form': u'OINT', u'brand': u'DAIVONEX', u'strength_3': u'', u'company': u'Win-Medicare', u'unit': u''}

-- line #4953
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAIVONEX SCALP 0.005 (Win-Medicare)',
	'Calcipotriol',
	'SOL',
	gm.nullify_empty_string('0.005')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAIVONEX SCALP 0.005 (Win-Medicare)'
);

-- line #4954
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEXIMAR 0.005 (Shalaks)',
	'Calcipotriol',
	'OINT',
	gm.nullify_empty_string('0.005')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEXIMAR 0.005 (Shalaks)'
);

-- line #4955
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PASITREX 0.005 (Sun)',
	'Calcipotriol',
	'TAB',
	gm.nullify_empty_string('0.005')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PASITREX 0.005 (Sun)'
);

-- line #4956
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,005', u'strength_2': u'', u'substance': u'Calcipotriol', u'always_empty': u'', u'form': u'CRM', u'brand': u'PSORTEX', u'strength_3': u'', u'company': u'Liva Hc.', u'unit': u''}

-- line #4957
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Calcipotriol', u'always_empty': u'', u'form': u'OINT', u'brand': u'PSOTRIOL', u'strength_3': u'', u'company': u'Sysmed', u'unit': u''}

-- line #4958
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50', u'strength_2': u'100;IU.', u'substance': u'Calcitonin', u'always_empty': u'', u'form': u'INJ', u'brand': u'BIOCALCIN', u'strength_3': u'', u'company': u'United Bio.', u'unit': u''}

-- line #4959
-- ignoring line: field [strength_1] not numeric: >>>2200IU.(SALMON)+BENZALKONIUM CHLORIDE O.O1<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2200IU.(SALMON)+BENZALKONIUM CHLORIDE O.O1', u'strength_2': u'', u'substance': u'Calcitonin', u'always_empty': u'', u'form': u'NASAL SPRAY', u'brand': u'BONSPARK', u'strength_3': u'', u'company': u'GLENMARK', u'unit': u'%W/V'}

-- line #4960
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Calcitonin', u'always_empty': u'', u'form': u'NASAL SPRAY', u'brand': u'CALCINASE', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #4961
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Calcitonin', u'always_empty': u'', u'form': u'', u'brand': u'CALCITONIN', u'strength_3': u'', u'company': u'ZYDUS SYNO.', u'unit': u''}

-- line #4962
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100IU.', u'strength_2': u'ML', u'substance': u'Calcitonin', u'always_empty': u'', u'form': u'AMP', u'brand': u'CALSYNAR', u'strength_3': u'', u'company': u'Nicholas', u'unit': u''}

-- line #4963
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2200IU.(SALMON)', u'strength_2': u'', u'substance': u'Calcitonin', u'always_empty': u'', u'form': u'NASAL SPRAY', u'brand': u'MIACALCIC', u'strength_3': u'', u'company': u'Novartis', u'unit': u''}

-- line #4964
-- ignoring line: field [strength_1] not numeric: >>>2200IU(SALMON)+(0.01<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2200IU(SALMON)+(0.01', u'strength_2': u'', u'substance': u'Calcitonin', u'always_empty': u'', u'form': u'SPRAY', u'brand': u'OSTEOROL', u'strength_3': u'', u'company': u'Ranbaxy', u'unit': u'%W/VBENZALKONIUM CHL.)'}

-- line #4965
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Calcitonin', u'always_empty': u'', u'form': u'SPRAY', u'brand': u'OSTOSPRAY-N', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #4966
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.25MCG', u'strength_2': u'', u'substance': u'Calcitriol', u'always_empty': u'', u'form': u'CAP', u'brand': u'ACTIVE-D', u'strength_3': u'', u'company': u'STEADFAST MEDI.', u'unit': u''}

-- line #4967
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.25MCG', u'strength_2': u'', u'substance': u'Calcitriol', u'always_empty': u'', u'form': u'CAP', u'brand': u'ARISTROL', u'strength_3': u'', u'company': u'Otsira', u'unit': u''}

-- line #4968
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.25MCG(1.25HYDROXY VIT.D3)', u'strength_2': u'', u'substance': u'Calcitriol', u'always_empty': u'', u'form': u'CAP', u'brand': u'BIO-D3 SOFGEL', u'strength_3': u'', u'company': u'Macleods', u'unit': u''}

-- line #4969
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1MCG', u'strength_2': u'ML', u'substance': u'Calcitriol', u'always_empty': u'', u'form': u'INJ', u'brand': u'CALCIBEST', u'strength_3': u'', u'company': u'Bestochem', u'unit': u''}

-- line #4970
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.25MCG', u'strength_2': u'', u'substance': u'Calcitriol', u'always_empty': u'', u'form': u'CAP', u'brand': u'CALOSTO', u'strength_3': u'', u'company': u'Nicholas', u'unit': u''}

-- line #4971
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.25MCG', u'strength_2': u'', u'substance': u'Calcitriol', u'always_empty': u'', u'form': u'CAP', u'brand': u'CALTROL', u'strength_3': u'', u'company': u'Orchid Hc.', u'unit': u''}

-- line #4972
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1MCG', u'strength_2': u'', u'substance': u'Calcitriol', u'always_empty': u'', u'form': u'INJ', u'brand': u'CELOL', u'strength_3': u'', u'company': u'Emcure', u'unit': u''}

-- line #4973
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.25MCG', u'strength_2': u'', u'substance': u'Calcitriol', u'always_empty': u'', u'form': u'CAP', u'brand': u'GEMCAL-C', u'strength_3': u'', u'company': u'Bergen', u'unit': u''}

-- line #4974
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.25MCG', u'strength_2': u'', u'substance': u'Calcitriol', u'always_empty': u'', u'form': u'CAP', u'brand': u'LARETOL', u'strength_3': u'', u'company': u'LA RENON', u'unit': u''}

-- line #4975
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1MCG', u'strength_2': u'ML', u'substance': u'Calcitriol', u'always_empty': u'', u'form': u'INJ', u'brand': u'LARETOL', u'strength_3': u'', u'company': u'LA RENON', u'unit': u''}

-- line #4976
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.25MCG', u'strength_2': u'', u'substance': u'Calcitriol', u'always_empty': u'', u'form': u'CAP', u'brand': u'NEPH-CELOL', u'strength_3': u'', u'company': u'Emcure', u'unit': u''}

-- line #4977
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1MCG', u'strength_2': u'', u'substance': u'Calcitriol', u'always_empty': u'', u'form': u'INJ', u'brand': u'NEPH-CELOL', u'strength_3': u'', u'company': u'Emcure', u'unit': u''}

-- line #4978
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.25MCG', u'strength_2': u'', u'substance': u'Calcitriol', u'always_empty': u'', u'form': u'CAP', u'brand': u'NEPHCLA', u'strength_3': u'', u'company': u'Ipca', u'unit': u''}

-- line #4979
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.25MCG', u'strength_2': u'', u'substance': u'Calcitriol', u'always_empty': u'', u'form': u'CAP', u'brand': u'OSTRIOL', u'strength_3': u'', u'company': u'Otsira', u'unit': u''}

-- line #4980
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.25MCG', u'strength_2': u'', u'substance': u'Calcitriol', u'always_empty': u'', u'form': u'CAP', u'brand': u'PT-PRESS', u'strength_3': u'', u'company': u'Unisearch', u'unit': u''}

-- line #4981
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1MCG', u'strength_2': u'', u'substance': u'Calcitriol', u'always_empty': u'', u'form': u'INJ', u'brand': u'RENATRIOL MCG', u'strength_3': u'', u'company': u'Ajanta Ph.', u'unit': u''}

-- line #4982
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALSICON 667 (Emcure)',
	'Calcium Acetate',
	'TAB',
	gm.nullify_empty_string('667')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALSICON 667 (Emcure)'
);

-- line #4983
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYPOPHOS 667 (Samarth)',
	'Calcium Acetate',
	'TAB',
	gm.nullify_empty_string('667')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYPOPHOS 667 (Samarth)'
);

-- line #4984
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANUM 667 (LA RENON)',
	'Calcium Acetate',
	'TAB',
	gm.nullify_empty_string('667')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANUM 667 (LA RENON)'
);

-- line #4985
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHOSBI 667 (Ipca)',
	'Calcium Acetate',
	'TAB',
	gm.nullify_empty_string('667')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHOSBI 667 (Ipca)'
);

-- line #4986
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHOSFORID 667 (Sun)',
	'Calcium Acetate',
	'TAB',
	gm.nullify_empty_string('667')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHOSFORID 667 (Sun)'
);

-- line #4987
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHOSTAT 667 (Zydus Cadila)',
	'Calcium Acetate',
	'TAB',
	gm.nullify_empty_string('667')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHOSTAT 667 (Zydus Cadila)'
);

-- line #4988
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RENAPHOS 667 (Rpg Life)',
	'Calcium Acetate',
	'TAB',
	gm.nullify_empty_string('667')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RENAPHOS 667 (Rpg Life)'
);

-- line #4989
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Calcium Carbonate', u'always_empty': u'', u'form': u'TAB', u'brand': u'ACICAL', u'strength_3': u'', u'company': u'WEST COAST', u'unit': u''}

-- line #4990
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Calcium Carbonate', u'always_empty': u'', u'form': u'CHEW TAB', u'brand': u'ASTROCAL', u'strength_3': u'', u'company': u'YASHTRA HEALTH', u'unit': u''}

-- line #4991
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.25GM', u'strength_2': u'5ML', u'substance': u'Calcium Carbonate', u'always_empty': u'', u'form': u'SYR', u'brand': u'BONYCAL', u'strength_3': u'', u'company': u'TAJ PH.', u'unit': u''}

-- line #4992
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BONYCAL 2.5 (TAJ PH.)',
	'Calcium Carbonate',
	'SYR',
	gm.nullify_empty_string('2.5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BONYCAL 2.5 (TAJ PH.)'
);

-- line #4993
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BONYCAL 250 (TAJ PH.)',
	'Calcium Carbonate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'500'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BONYCAL 250 (TAJ PH.)'
);

-- line #4994
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALCICIP 625 (Cipla)',
	'Calcium Carbonate',
	'TAB',
	gm.nullify_empty_string('625')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALCICIP 625 (Cipla)'
);

-- line #4995
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALCIUM SANDOZ 625 (Novartis)',
	'Calcium Carbonate',
	'TAB',
	gm.nullify_empty_string('625')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALCIUM SANDOZ 625 (Novartis)'
);

-- line #4996
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALIBON-Z 250 (Intra Lab)',
	'Calcium Carbonate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALIBON-Z 250 (Intra Lab)'
);

-- line #4997
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAL SHELL 625 (Drakt Int.)',
	'Calcium Carbonate',
	'TAB',
	gm.nullify_empty_string('625')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAL SHELL 625 (Drakt Int.)'
);

-- line #4998
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'CORAL GRAINS', u'strength_2': u'', u'substance': u'Calcium Carbonate', u'always_empty': u'', u'form': u'TAB', u'brand': u'CORCIUM', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #4999
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FACTOCAL 625 (Wanbury)',
	'Calcium Carbonate',
	'TAB',
	gm.nullify_empty_string('625')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FACTOCAL 625 (Wanbury)'
);

-- line #5000
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'WITH ACTIVATED DIMETHICONE', u'strength_2': u'', u'substance': u'Calcium Carbonate', u'always_empty': u'', u'form': u'TAB', u'brand': u'GASBIT', u'strength_3': u'', u'company': u'WEST COAST', u'unit': u''}

-- line #5001
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KARECAL 625 (Orchid Hc.)',
	'Calcium Carbonate',
	'TAB',
	gm.nullify_empty_string('625')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KARECAL 625 (Orchid Hc.)'
);

-- line #5002
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANUM-C-500 1250 (LA RENON)',
	'Calcium Carbonate',
	'TAB',
	gm.nullify_empty_string('1250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANUM-C-500 1250 (LA RENON)'
);

-- line #5003
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILTAB 250 (MEDREICH SAI.)',
	'Calcium Carbonate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILTAB 250 (MEDREICH SAI.)'
);

-- line #5004
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSCAL 500 (Osper)',
	'Calcium Carbonate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSCAL 500 (Osper)'
);

-- line #5005
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NELCIUM 10 (Neon)',
	'CALCIUM CHLORIDE',
	'AMP',
	gm.nullify_empty_string('10')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NELCIUM 10 (Neon)'
);

-- line #5006
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CABISYL 500 (Rusan Hc)',
	'CALCIUM DOBESILATE',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CABISYL 500 (Rusan Hc)'
);

-- line #5007
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALCIDOB 500 (CHEMO HC.)',
	'CALCIUM DOBESILATE',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALCIDOB 500 (CHEMO HC.)'
);

-- line #5008
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALDOB 500 (Comed)',
	'CALCIUM DOBESILATE',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALDOB 500 (Comed)'
);

-- line #5009
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COCALATE 500 (VHB(CRONUS))',
	'CALCIUM DOBESILATE',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COCALATE 500 (VHB(CRONUS))'
);

-- line #5010
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DBS 500 (Zee Lab)',
	'CALCIUM DOBESILATE',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DBS 500 (Zee Lab)'
);

-- line #5011
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOBAID 500 (Pharma Drugs)',
	'CALCIUM DOBESILATE',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOBAID 500 (Pharma Drugs)'
);

-- line #5012
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOBESIL 500 (Ochoa)',
	'CALCIUM DOBESILATE',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOBESIL 500 (Ochoa)'
);

-- line #5013
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOBESIL 0.5 (Ochoa)',
	'CALCIUM DOBESILATE',
	'OINT',
	gm.nullify_empty_string('0.5')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOBESIL 0.5 (Ochoa)'
);

-- line #5014
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOBESIL 0.5 (Ranbaxy)',
	'CALCIUM DOBESILATE',
	'OINT',
	gm.nullify_empty_string('0.5')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOBESIL 0.5 (Ranbaxy)'
);

-- line #5015
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOBEST 500 (Wallace)',
	'CALCIUM DOBESILATE',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOBEST 500 (Wallace)'
);

-- line #5016
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOBICAL 500 (Espira Life)',
	'CALCIUM DOBESILATE',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOBICAL 500 (Espira Life)'
);

-- line #5017
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOBILET 500 (Otsira)',
	'CALCIUM DOBESILATE',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOBILET 500 (Otsira)'
);

-- line #5018
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOBIUM 500 (Mano)',
	'CALCIUM DOBESILATE',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOBIUM 500 (Mano)'
);

-- line #5019
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOBUHEAL 500 (Healthcare)',
	'CALCIUM DOBESILATE',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOBUHEAL 500 (Healthcare)'
);

-- line #5020
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOSIL 500 (BIOMEDICA)',
	'CALCIUM DOBESILATE',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg(MONOHYDRT.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOSIL 500 (BIOMEDICA)'
);

-- line #5021
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'CALCIUM DOBESILATE', u'always_empty': u'', u'form': u'CAP', u'brand': u'DOVAS', u'strength_3': u'', u'company': u'Sunways', u'unit': u''}

-- line #5022
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXIUM 500 (Dr.Reddy''S)',
	'CALCIUM DOBESILATE',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXIUM 500 (Dr.Reddy''S)'
);

-- line #5023
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EFLO 500 (Winsome Lab)',
	'CALCIUM DOBESILATE',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EFLO 500 (Winsome Lab)'
);

-- line #5024
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOBIUM 500 (Orchid Hc.)',
	'CALCIUM DOBESILATE',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOBIUM 500 (Orchid Hc.)'
);

-- line #5025
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSIL 500 (Ozone Ph.)',
	'CALCIUM DOBESILATE',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSIL 500 (Ozone Ph.)'
);

-- line #5026
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RHYTHM 500 (Skymax)',
	'CALCIUM DOBESILATE',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RHYTHM 500 (Skymax)'
);

-- line #5027
-- ignoring line: field [strength_1] not numeric: >>>(10<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'(10', u'strength_2': u'', u'substance': u'Calcium Glubionate', u'always_empty': u'', u'form': u'INJ', u'brand': u'CALCIUM-SANDOZ', u'strength_3': u'', u'company': u'Novartis', u'unit': u'%)0.137.5G/ML'}

-- line #5028
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'740', u'strength_2': u'', u'substance': u'CALCIUM OROTATE', u'always_empty': u'', u'form': u'', u'brand': u'CALORTE', u'strength_3': u'', u'company': u'CH.Bhagat', u'unit': u'mg'}

-- line #5029
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALSLOT 740 (Ranbaxy)',
	'CALCIUM OROTATE',
	'TAB',
	gm.nullify_empty_string('740')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALSLOT 740 (Ranbaxy)'
);

-- line #5030
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'92,5', u'strength_2': u'', u'substance': u'CALCIUM OROTATE', u'always_empty': u'', u'form': u'', u'brand': u'CDENSE GEMS', u'strength_3': u'', u'company': u'Wanbury', u'unit': u'mg'}

-- line #5031
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CDENSE 740 (Wanbury)',
	'CALCIUM OROTATE',
	'TAB',
	gm.nullify_empty_string('740')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CDENSE 740 (Wanbury)'
);

-- line #5032
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-DIRECT 740 (F D C)',
	'CALCIUM OROTATE',
	'TAB',
	gm.nullify_empty_string('740')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-DIRECT 740 (F D C)'
);

-- line #5033
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OROTATE 740 (AKESISS)',
	'CALCIUM OROTATE',
	'TAB',
	gm.nullify_empty_string('740')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OROTATE 740 (AKESISS)'
);

-- line #5034
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALCIUM PANTOTHENATE 50 (Svizera)',
	'CALCIUM PANTOTHENATE',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALCIUM PANTOTHENATE 50 (Svizera)'
);

-- line #5035
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-PANT 100 (Chem+Med)',
	'CALCIUM PANTOTHENATE',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-PANT 100 (Chem+Med)'
);

-- line #5036
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALBIN 667 (Claris L.)',
	'Calcium Phosphate',
	'TAB',
	gm.nullify_empty_string('667')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALBIN 667 (Claris L.)'
);

-- line #5037
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALIBS 625 (Ranbaxy)',
	'CALCIUM POLYCARBOPHIL',
	'TAB',
	gm.nullify_empty_string('625')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALIBS 625 (Ranbaxy)'
);

-- line #5038
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIBOTAB 625 (Torrent)',
	'CALCIUM POLYCARBOPHIL',
	'TAB',
	gm.nullify_empty_string('625')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIBOTAB 625 (Torrent)'
);

-- line #5039
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORMOSYS 625 (Indchemie)',
	'CALCIUM POLYCARBOPHIL',
	'TAB',
	gm.nullify_empty_string('625')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORMOSYS 625 (Indchemie)'
);

-- line #5040
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'300G', u'strength_2': u'', u'substance': u'CALCIUM POLYSTRENE SULPHONATE', u'always_empty': u'', u'form': u'RESONIUM JAR', u'brand': u'CALCIUM', u'strength_3': u'', u'company': u'Sanofi Aventis', u'unit': u''}

-- line #5041
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALCIUM RESONIUM 15 (Sanofi Aventis)',
	'CALCIUM POLYSTRENE SULPHONATE',
	'POW',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALCIUM RESONIUM 15 (Sanofi Aventis)'
);

-- line #5042
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'15G', u'strength_2': u'', u'substance': u'CALCIUM POLYSTRENE SULPHONATE', u'always_empty': u'', u'form': u'', u'brand': u'KALICEPT', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #5043
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'CALCIUM POLYSTRENE SULPHONATE', u'always_empty': u'', u'form': u'POW', u'brand': u'KAPSTAT', u'strength_3': u'', u'company': u'Claris L.', u'unit': u''}

-- line #5044
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'15G', u'strength_2': u'', u'substance': u'CALCIUM POLYSTRENE SULPHONATE', u'always_empty': u'', u'form': u'SAC', u'brand': u'K-BAIT', u'strength_3': u'', u'company': u'Panacea', u'unit': u''}

-- line #5045
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'15G', u'strength_2': u'', u'substance': u'CALCIUM POLYSTRENE SULPHONATE', u'always_empty': u'', u'form': u'SAC', u'brand': u'KCHEK', u'strength_3': u'', u'company': u'LA RENON', u'unit': u''}

-- line #5046
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'CALCIUM POLYSTRENE SULPHONATE', u'always_empty': u'', u'form': u'POUCH', u'brand': u'PEBIND', u'strength_3': u'', u'company': u'Emcure', u'unit': u''}

-- line #5047
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLAXENNA 11.5 (Gsk)',
	'Calcium Salts',
	'TAB',
	gm.nullify_empty_string('11.5')::numeric,
	'mg(SENNOCID B)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLAXENNA 11.5 (Gsk)'
);

-- line #5048
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAXTON 11.5 (Inga)',
	'Calcium Salts',
	'TAB',
	gm.nullify_empty_string('11.5')::numeric,
	'mg(SENNOCID B)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAXTON 11.5 (Inga)'
);

-- line #5049
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAMOPAN 100 (Sun)',
	'CAMOSTAT',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAMOPAN 100 (Sun)'
);

-- line #5050
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANAFORTAN 20 (Khandelwal)',
	'Camylofin Dihydrochloride',
	'DPS',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANAFORTAN 20 (Khandelwal)'
);

-- line #5051
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANAFORTAN 25 (Khandelwal)',
	'Camylofin Dihydrochloride',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANAFORTAN 25 (Khandelwal)'
);

-- line #5052
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANAFORTAN 25 (Khandelwal)',
	'Camylofin Dihydrochloride',
	'V',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANAFORTAN 25 (Khandelwal)'
);

-- line #5053
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANDESTAN 4 (Medley)',
	'Candesartan',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANDESTAN 4 (Medley)'
);

-- line #5054
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANDESTAN 8 (Medley)',
	'Candesartan',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANDESTAN 8 (Medley)'
);

-- line #5055
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANDEZ 4 (Ind-Swift)',
	'Candesartan',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANDEZ 4 (Ind-Swift)'
);

-- line #5056
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANDEZ 8 (Ind-Swift)',
	'Candesartan',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANDEZ 8 (Ind-Swift)'
);

-- line #5057
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILSAVE 4 (Nucron Ph.)',
	'Candesartan',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILSAVE 4 (Nucron Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILSAVE 8 (Nucron Ph.)',
	'Candesartan',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILSAVE 8 (Nucron Ph.)'
);

-- line #5058
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IPSITA 16 (Bal Ph.)',
	'Candesartan',
	'TAB',
	gm.nullify_empty_string('16')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IPSITA 16 (Bal Ph.)'
);

-- line #5059
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IPSITA 4 (Bal Ph.)',
	'Candesartan',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IPSITA 4 (Bal Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IPSITA 8 (Bal Ph.)',
	'Candesartan',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IPSITA 8 (Bal Ph.)'
);

-- line #5060
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALCIT 500 (Biochem)',
	'CAPECITABINE',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALCIT 500 (Biochem)'
);

-- line #5061
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAPCITA 500 (Wockhardt)',
	'CAPECITABINE',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAPCITA 500 (Wockhardt)'
);

-- line #5062
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAPECAD 500 (Cadila Ph.)',
	'CAPECITABINE',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAPECAD 500 (Cadila Ph.)'
);

-- line #5063
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAPECITAPER 500 (Parenteral)',
	'CAPECITABINE',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAPECITAPER 500 (Parenteral)'
);

-- line #5064
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAPETA 500 (Cytomed(Alkem))',
	'CAPECITABINE',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAPETA 500 (Cytomed(Alkem))'
);

-- line #5065
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAPETERO 500 (HETERO HC.)',
	'CAPECITABINE',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAPETERO 500 (HETERO HC.)'
);

-- line #5066
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAPIIBINE 150 (Dr.Reddy''S)',
	'CAPECITABINE',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAPIIBINE 150 (Dr.Reddy''S)'
);

-- line #5067
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAPIIBINE 500 (Dr.Reddy''S)',
	'CAPECITABINE',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAPIIBINE 500 (Dr.Reddy''S)'
);

-- line #5068
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAPNAT 500 (Natco Ph.)',
	'CAPECITABINE',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAPNAT 500 (Natco Ph.)'
);

-- line #5069
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'CAPECITABINE', u'always_empty': u'', u'form': u'TAB', u'brand': u'CAPSY', u'strength_3': u'', u'company': u'Intas', u'unit': u''}

-- line #5070
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAPTABIN 500 (Shantha Bio.)',
	'CAPECITABINE',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAPTABIN 500 (Shantha Bio.)'
);

-- line #5071
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAPXCEL 500 (Khandelwal)',
	'CAPECITABINE',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAPXCEL 500 (Khandelwal)'
);

-- line #5072
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAPROCAP 500 (MIRACALUS)',
	'CAPECITABINE',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAPROCAP 500 (MIRACALUS)'
);

-- line #5073
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROFIVE 500 (UTTARA BIO.)',
	'CAPECITABINE',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROFIVE 500 (UTTARA BIO.)'
);

-- line #5074
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Capreomycin', u'always_empty': u'', u'form': u'INJ', u'brand': u'CAPREOMYCIN', u'strength_3': u'', u'company': u'Sanjivani', u'unit': u''}

-- line #5075
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.5G', u'strength_2': u'', u'substance': u'Capreomycin', u'always_empty': u'', u'form': u'INJ', u'brand': u'KAPOCIN', u'strength_3': u'', u'company': u'Macleods', u'unit': u''}

-- line #5076
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.75G', u'strength_2': u'', u'substance': u'Capreomycin', u'always_empty': u'', u'form': u'INJ', u'brand': u'KAPOCIN', u'strength_3': u'', u'company': u'Macleods', u'unit': u''}

-- line #5077
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Capreomycin', u'always_empty': u'', u'form': u'INJ', u'brand': u'KAPOCIN', u'strength_3': u'', u'company': u'Macleods', u'unit': u''}

-- line #5078
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAPSAIN-P % 0.025 (Sun)',
	'Capsaicin',
	'CRM',
	gm.nullify_empty_string('0.025')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAPSAIN-P % 0.025 (Sun)'
);

-- line #5079
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAPSAIN-P % 0.075 (Sun)',
	'Capsaicin',
	'CRM',
	gm.nullify_empty_string('0.075')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAPSAIN-P % 0.075 (Sun)'
);

-- line #5080
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACETEN 12.5 (Wockhardt)',
	'Captopril',
	'TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACETEN 12.5 (Wockhardt)'
);

-- line #5081
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACETEN 25 (Wockhardt)',
	'Captopril',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACETEN 25 (Wockhardt)'
);

-- line #5082
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANGIOPRIL 25 (Torrent)',
	'Captopril',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANGIOPRIL 25 (Torrent)'
);

-- line #5083
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAPOTRIL 12.5 (Lupin)',
	'Captopril',
	'TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAPOTRIL 12.5 (Lupin)'
);

-- line #5084
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAPOTRIL 25 (Lupin)',
	'Captopril',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAPOTRIL 25 (Lupin)'
);

-- line #5085
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INHIBACE 25 (Dolphin)',
	'Captopril',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INHIBACE 25 (Dolphin)'
);

-- line #5086
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'CARBACHOL', u'always_empty': u'', u'form': u'EYE DPS', u'brand': u'BIO-CHOL', u'strength_3': u'', u'company': u'Bio-Tech Opth.', u'unit': u''}

-- line #5087
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'CARBACHOL', u'always_empty': u'', u'form': u'INJ', u'brand': u'CARBADOL', u'strength_3': u'', u'company': u'Sunways', u'unit': u''}

-- line #5088
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACETOL 200 (Pil)',
	'Carbamazepine',
	'CR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACETOL 200 (Pil)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACETOL 400 (Pil)',
	'Carbamazepine',
	'CR TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACETOL 400 (Pil)'
);

-- line #5089
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACETOL 100 (Pil)',
	'Carbamazepine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACETOL 100 (Pil)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACETOL 200 (Pil)',
	'Carbamazepine',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACETOL 200 (Pil)'
);

-- line #5090
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANTILEP 200 (PSYCOREM)',
	'Carbamazepine',
	'CR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANTILEP 200 (PSYCOREM)'
);

-- line #5091
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANTILEP 300 (PSYCOREM)',
	'Carbamazepine',
	'CR TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANTILEP 300 (PSYCOREM)'
);

-- line #5092
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANTILEP 400 (PSYCOREM)',
	'Carbamazepine',
	'CR TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANTILEP 400 (PSYCOREM)'
);

-- line #5093
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANTILEP 100 (PSYCOREM)',
	'Carbamazepine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANTILEP 100 (PSYCOREM)'
);

-- line #5094
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANTILEP 200 (PSYCOREM)',
	'Carbamazepine',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANTILEP 200 (PSYCOREM)'
);

-- line #5095
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARBACONTIN 200 (Modi Mundi)',
	'Carbamazepine',
	'CR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARBACONTIN 200 (Modi Mundi)'
);

-- line #5096
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARBACONTIN 300 (Modi Mundi)',
	'Carbamazepine',
	'CR TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARBACONTIN 300 (Modi Mundi)'
);

-- line #5097
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARBACONTIN 400 (Modi Mundi)',
	'Carbamazepine',
	'CR TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARBACONTIN 400 (Modi Mundi)'
);

-- line #5098
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARBADAC 200 (Cadila Hc.)',
	'Carbamazepine',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARBADAC 200 (Cadila Hc.)'
);

-- line #5099
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARBAFEN 100 (Theo Ph.)',
	'Carbamazepine',
	'SR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARBAFEN 100 (Theo Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARBAFEN 200 (Theo Ph.)',
	'Carbamazepine',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARBAFEN 200 (Theo Ph.)'
);

-- line #5100
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARBAFEN 400 (Theo Ph.)',
	'Carbamazepine',
	'SR TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARBAFEN 400 (Theo Ph.)'
);

-- line #5101
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARBAPA 200 (Olcare)',
	'Carbamazepine',
	'CR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARBAPA 200 (Olcare)'
);

-- line #5102
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARBATOL 200 (Torrent)',
	'Carbamazepine',
	'CR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARBATOL 200 (Torrent)'
);

-- line #5103
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARBATOL 300 (TORRENT)',
	'Carbamazepine',
	'CR TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARBATOL 300 (TORRENT)'
);

-- line #5104
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARBATOL 400 (Torrent)',
	'Carbamazepine',
	'CR TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARBATOL 400 (Torrent)'
);

-- line #5105
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARBATOL 100 (Torrent)',
	'Carbamazepine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARBATOL 100 (Torrent)'
);

-- line #5106
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARBATOL 200 (Torrent)',
	'Carbamazepine',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARBATOL 200 (Torrent)'
);

-- line #5107
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARBDAC 200 (Zydus A.)',
	'Carbamazepine',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARBDAC 200 (Zydus A.)'
);

-- line #5108
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARBIN 200 (Rkg)',
	'Carbamazepine',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg S.R.'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARBIN 200 (Rkg)'
);

-- line #5109
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARIZINE 200 (EAST WEST)',
	'Carbamazepine',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARIZINE 200 (EAST WEST)'
);

-- line #5110
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARMAZ 100 (Sun)',
	'Carbamazepine',
	'TAB/KID',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARMAZ 100 (Sun)'
);

-- line #5111
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARMAZ 200 (Sun)',
	'Carbamazepine',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARMAZ 200 (Sun)'
);

-- line #5112
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARMEG 100 (N.A.)',
	'Carbamazepine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARMEG 100 (N.A.)'
);

-- line #5113
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARMEG 200 (N.A.)',
	'Carbamazepine',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARMEG 200 (N.A.)'
);

-- line #5114
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARZ 200 (MEDISYS)',
	'Carbamazepine',
	'CR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARZ 200 (MEDISYS)'
);

-- line #5115
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARZEP 100 (Taurus Lab)',
	'Carbamazepine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARZEP 100 (Taurus Lab)'
);

-- line #5116
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARZEP 200 (Taurus Lab)',
	'Carbamazepine',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARZEP 200 (Taurus Lab)'
);

-- line #5117
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARZEP 400 (Taurus Lab)',
	'Carbamazepine',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARZEP 400 (Taurus Lab)'
);

-- line #5118
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARZINE 200 (EAST WEST)',
	'Carbamazepine',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARZINE 200 (EAST WEST)'
);

-- line #5119
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIZETOL 200 (Cipla)',
	'Carbamazepine',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIZETOL 200 (Cipla)'
);

-- line #5120
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-LEP 200 (Pifer Ph.)',
	'Carbamazepine',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-LEP 200 (Pifer Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-LEP 300 (Pifer Ph.)',
	'Carbamazepine',
	'SR TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-LEP 300 (Pifer Ph.)'
);

-- line #5121
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-LEP 400 (Pifer Ph.)',
	'Carbamazepine',
	'SR TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-LEP 400 (Pifer Ph.)'
);

-- line #5122
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-LEP 100 (Pifer Ph.)',
	'Carbamazepine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-LEP 100 (Pifer Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-LEP 200 (Pifer Ph.)',
	'Carbamazepine',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-LEP 200 (Pifer Ph.)'
);

-- line #5123
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPILEP 200 (TASMED)',
	'Carbamazepine',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPILEP 200 (TASMED)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPILEP 200 (TASMED)',
	'Carbamazepine',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPILEP 200 (TASMED)'
);

-- line #5124
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPINIL 100 (Themis)',
	'Carbamazepine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'200'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPINIL 100 (Themis)'
);

-- line #5125
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPIX 200 (BARODA)',
	'Carbamazepine',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPIX 200 (BARODA)'
);

-- line #5126
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOBIGONE 20 (Marc Lab)',
	'Carbamazepine',
	'SYR',
	gm.nullify_empty_string('20')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOBIGONE 20 (Marc Lab)'
);

-- line #5127
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOBIGONE 100 (Marc Lab)',
	'Carbamazepine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOBIGONE 100 (Marc Lab)'
);

-- line #5128
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOBIGONE 200 (Marc Lab)',
	'Carbamazepine',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOBIGONE 200 (Marc Lab)'
);

-- line #5129
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOBIGONE 400 (Marc Lab)',
	'Carbamazepine',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOBIGONE 400 (Marc Lab)'
);

-- line #5130
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEXITROL 100 (Healthgaurd)',
	'Carbamazepine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEXITROL 100 (Healthgaurd)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEXITROL 200 (Healthgaurd)',
	'Carbamazepine',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEXITROL 200 (Healthgaurd)'
);

-- line #5131
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOCARB 200 (Orchid Hc.)',
	'Carbamazepine',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOCARB 200 (Orchid Hc.)'
);

-- line #5132
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAZETOL 100 (Piramal Hc.)',
	'Carbamazepine',
	'CHEWTAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAZETOL 100 (Piramal Hc.)'
);

-- line #5133
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAZETOL 200 (Piramal Hc.)',
	'Carbamazepine',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAZETOL 200 (Piramal Hc.)'
);

-- line #5134
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAZETOL 300 (Piramal Hc.)',
	'Carbamazepine',
	'SR TAB',
	gm.nullify_empty_string('300')::numeric,
	'400'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAZETOL 300 (Piramal Hc.)'
);

-- line #5135
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAZETOL 100 (Piramal Hc.)',
	'Carbamazepine',
	'SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg/5 ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAZETOL 100 (Piramal Hc.)'
);

-- line #5136
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAZETOL 100 (Piramal Hc.)',
	'Carbamazepine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAZETOL 100 (Piramal Hc.)'
);

-- line #5137
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAZETOL 200 (Piramal Hc.)',
	'Carbamazepine',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAZETOL 200 (Piramal Hc.)'
);

-- line #5138
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAZETOL 400 (Piramal Hc.)',
	'Carbamazepine',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAZETOL 400 (Piramal Hc.)'
);

-- line #5139
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'M CARB 100 (Medopharm)',
	'Carbamazepine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'M CARB 100 (Medopharm)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'M CARB 200 (Medopharm)',
	'Carbamazepine',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'M CARB 200 (Medopharm)'
);

-- line #5140
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEZAPINE 200 (OREVA DARMO.)',
	'Carbamazepine',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEZAPINE 200 (OREVA DARMO.)'
);

-- line #5141
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEZAPIN 200 (LA DRUG)',
	'Carbamazepine',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEZAPIN 200 (LA DRUG)'
);

-- line #5142
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEZAPIN 200 (LA DRUG)',
	'Carbamazepine',
	'XR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEZAPIN 200 (LA DRUG)'
);

-- line #5143
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEZAPIN 400 (LA DRUG)',
	'Carbamazepine',
	'XR TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEZAPIN 400 (LA DRUG)'
);

-- line #5144
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEZARIL 100 (Reliance)',
	'Carbamazepine',
	'KID TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEZARIL 100 (Reliance)'
);

-- line #5145
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEZARIL 200 (Reliance)',
	'Carbamazepine',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEZARIL 200 (Reliance)'
);

-- line #5146
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEZARIL 400 (Reliance)',
	'Carbamazepine',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEZARIL 400 (Reliance)'
);

-- line #5147
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RBA-400 400 (ROSE LABS)',
	'Carbamazepine',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RBA-400 400 (ROSE LABS)'
);

-- line #5148
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Carbenicillin Disod.', u'always_empty': u'', u'form': u'INJ', u'brand': u'CARBELIN', u'strength_3': u'', u'company': u'HETERO HC.', u'unit': u''}

-- line #5149
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5G', u'strength_2': u'', u'substance': u'Carbenicillin Disod.', u'always_empty': u'', u'form': u'INJ', u'brand': u'CARBELIN', u'strength_3': u'', u'company': u'HETERO HC.', u'unit': u''}

-- line #5150
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANTI THYROX 10 (Macleods)',
	'Carbimazole',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANTI THYROX 10 (Macleods)'
);

-- line #5151
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANTI-THYROX 20 (Macleods)',
	'Carbimazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANTI-THYROX 20 (Macleods)'
);

-- line #5152
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANTI-THYROX 5 (Macleods)',
	'Carbimazole',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANTI-THYROX 5 (Macleods)'
);

-- line #5153
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEO-MERCAZOLE 10 (Nicholas)',
	'Carbimazole',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEO-MERCAZOLE 10 (Nicholas)'
);

-- line #5154
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEO-MERCAZOLE 20 (Nicholas)',
	'Carbimazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEO-MERCAZOLE 20 (Nicholas)'
);

-- line #5155
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEO-MERCAZOLE 5 (Nicholas)',
	'Carbimazole',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEO-MERCAZOLE 5 (Nicholas)'
);

-- line #5156
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUCODYNE 150 (Elder)',
	'Carbocisteine',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUCODYNE 150 (Elder)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUCODYNE 375 (Elder)',
	'Carbocisteine',
	'CAP',
	gm.nullify_empty_string('375')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUCODYNE 375 (Elder)'
);

-- line #5157
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUCODYNE 150 (Elder)',
	'Carbocisteine',
	'SYR',
	gm.nullify_empty_string('150')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUCODYNE 150 (Elder)'
);

-- line #5158
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUCODYNE 250 (Elder)',
	'Carbocisteine',
	'SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUCODYNE 250 (Elder)'
);

-- line #5159
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'CARBONYL IRON', u'always_empty': u'', u'form': u'CAP', u'brand': u'ENIRON-C', u'strength_3': u'', u'company': u'J.P.LIFE', u'unit': u''}

-- line #5160
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EVAGLOW 50 (Evacare)',
	'CARBONYL IRON',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EVAGLOW 50 (Evacare)'
);

-- line #5161
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERISAN-S 20 (Intra(INVISION))',
	'CARBONYL IRON',
	'AMP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERISAN-S 20 (Intra(INVISION))'
);

-- line #5162
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FESAFE 50 (RND LAB)',
	'CARBONYL IRON',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FESAFE 50 (RND LAB)'
);

-- line #5163
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FESAFE 100 (RND LAB)',
	'CARBONYL IRON',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FESAFE 100 (RND LAB)'
);

-- line #5164
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HB FAST 50 (Biological E.)',
	'CARBONYL IRON',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HB FAST 50 (Biological E.)'
);

-- line #5165
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'CARBONYL IRON', u'always_empty': u'', u'form': u'CAP', u'brand': u'HEMOGAIN', u'strength_3': u'', u'company': u'GENETIC PH.', u'unit': u''}

-- line #5166
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMFERON 50 (Shreya)',
	'CARBONYL IRON',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMFERON 50 (Shreya)'
);

-- line #5167
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OROFER 10 (Emcure)',
	'CARBONYL IRON',
	'XT DPS',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OROFER 10 (Emcure)'
);

-- line #5168
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOCARB 150 (Biochem)',
	'CARBOPLATIN',
	'V',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOCARB 150 (Biochem)'
);

-- line #5169
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOCARB 450 (Biochem)',
	'CARBOPLATIN',
	'V',
	gm.nullify_empty_string('450')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOCARB 450 (Biochem)'
);

-- line #5170
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLASTOCARB 150 (Lemery)',
	'Carboplatin',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLASTOCARB 150 (Lemery)'
);

-- line #5171
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLASTOCARB 450 (Lemery)',
	'Carboplatin',
	'INJ',
	gm.nullify_empty_string('450')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLASTOCARB 450 (Lemery)'
);

-- line #5172
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLASTOPLATIN 150 (CH.Bhagat)',
	'Carboplatin',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/15ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLASTOPLATIN 150 (CH.Bhagat)'
);

-- line #5173
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLASTOPLATIN 450 (CH.Bhagat)',
	'Carboplatin',
	'INJ',
	gm.nullify_empty_string('450')::numeric,
	'mg/45ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLASTOPLATIN 450 (CH.Bhagat)'
);

-- line #5174
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARBIN 150 (AMRONCO)',
	'CARBOPLATIN',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARBIN 150 (AMRONCO)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARBIN 450 (AMRONCO)',
	'CARBOPLATIN',
	'INJ',
	gm.nullify_empty_string('450')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARBIN 450 (AMRONCO)'
);

-- line #5175
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARBOKEM 150 (Cytomed(Alkem))',
	'CARBOPLATIN',
	'VIAL',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARBOKEM 150 (Cytomed(Alkem))'
);

-- line #5176
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARBOKEM 450 (Cytomed(Alkem))',
	'CARBOPLATIN',
	'VIAL',
	gm.nullify_empty_string('450')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARBOKEM 450 (Cytomed(Alkem))'
);

-- line #5177
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARBOPA 150 (Intas)',
	'Carboplatin',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARBOPA 150 (Intas)'
);

-- line #5178
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARBOPA 450 (Intas)',
	'Carboplatin',
	'INJ',
	gm.nullify_empty_string('450')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARBOPA 450 (Intas)'
);

-- line #5179
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARBOPLAN 150 (Natco Ph.)',
	'Carboplatin',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARBOPLAN 150 (Natco Ph.)'
);

-- line #5180
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARBOPLATIN 10 (DR. REDDY''S)',
	'CARBOPLATIN',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg(100'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARBOPLATIN 10 (DR. REDDY''S)'
);

-- line #5181
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARBOPLATIN 150 (Pharmacia)',
	'Carboplatin',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/15ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARBOPLATIN 150 (Pharmacia)'
);

-- line #5182
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARBOPLATIN 450 (Pharmacia)',
	'Carboplatin',
	'INJ',
	gm.nullify_empty_string('450')::numeric,
	'mg/45ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARBOPLATIN 450 (Pharmacia)'
);

-- line #5183
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARBOTEEN 150 (VHB)',
	'Carboplatin',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/15ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARBOTEEN 150 (VHB)'
);

-- line #5184
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARBOTEEN 450 (VHB)',
	'Carboplatin',
	'INJ',
	gm.nullify_empty_string('450')::numeric,
	'mg/45ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARBOTEEN 450 (VHB)'
);

-- line #5185
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARBOTINAL 150 (Vhb)',
	'Carboplatin',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARBOTINAL 150 (Vhb)'
);

-- line #5186
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARBOTINAL 450 (Vhb)',
	'Carboplatin',
	'INJ',
	gm.nullify_empty_string('450')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARBOTINAL 450 (Vhb)'
);

-- line #5187
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELCARB 150 (CELON(VIVILON))',
	'CARBOPLATIN',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'450'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELCARB 150 (CELON(VIVILON))'
);

-- line #5188
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYTOCARB 150 (Cipla)',
	'Carboplatin',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYTOCARB 150 (Cipla)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYTOCARB 450 (Cipla)',
	'Carboplatin',
	'INJ',
	gm.nullify_empty_string('450')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYTOCARB 450 (Cipla)'
);

-- line #5189
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUCARB 150 (Samarth)',
	'CARBOPLATIN',
	'V',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUCARB 150 (Samarth)'
);

-- line #5190
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUCARB 450 (Samarth)',
	'CARBOPLATIN',
	'V',
	gm.nullify_empty_string('450')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUCARB 450 (Samarth)'
);

-- line #5191
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KARPLAT 10 (Cadila Ph.)',
	'Carboplatin',
	'VIAL',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KARPLAT 10 (Cadila Ph.)'
);

-- line #5192
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEMOCARB 150 (Dabur Ph.)',
	'Carboplatin',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEMOCARB 150 (Dabur Ph.)'
);

-- line #5193
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEMOCARB 450 (Dabur Ph.)',
	'Carboplatin',
	'INJ',
	gm.nullify_empty_string('450')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEMOCARB 450 (Dabur Ph.)'
);

-- line #5194
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAPROPLAT 150 (MIRACALUS)',
	'CARBOPLATIN',
	'VIAL',
	gm.nullify_empty_string('150')::numeric,
	'450'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAPROPLAT 150 (MIRACALUS)'
);

-- line #5195
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOCARB 150 (Biological E.)',
	'Carboplatin',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOCARB 150 (Biological E.)'
);

-- line #5196
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOCARB 450 (Biological E.)',
	'Carboplatin',
	'INJ',
	gm.nullify_empty_string('450')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOCARB 450 (Biological E.)'
);

-- line #5197
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOPLATIN 150 (Oncomed)',
	'Carboplatin',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOPLATIN 150 (Oncomed)'
);

-- line #5198
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONCOCARBIN AQ 150 (Sun)',
	'Carboplatin',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONCOCARBIN AQ 150 (Sun)'
);

-- line #5199
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARAPLATIN 150 (BRISTOL MYERS)',
	'CARBOPLATIN',
	'VIAL',
	gm.nullify_empty_string('150')::numeric,
	'mg/15ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARAPLATIN 150 (BRISTOL MYERS)'
);

-- line #5200
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARAPLATIN 450 (BRISTOL MYERS)',
	'CARBOPLATIN',
	'VIAL',
	gm.nullify_empty_string('450')::numeric,
	'mg/45ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARAPLATIN 450 (BRISTOL MYERS)'
);

-- line #5201
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'125MCG', u'strength_2': u'', u'substance': u'Carboprost Tromethamine', u'always_empty': u'', u'form': u'INJ', u'brand': u'CABOPROST', u'strength_3': u'', u'company': u'Neon', u'unit': u''}

-- line #5202
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250MCG', u'strength_2': u'ML', u'substance': u'Carboprost Tromethamine', u'always_empty': u'', u'form': u'INJ', u'brand': u'CABOPROST', u'strength_3': u'', u'company': u'Neon', u'unit': u''}

-- line #5203
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250MCG', u'strength_2': u'', u'substance': u'Carboprost Tromethamine', u'always_empty': u'', u'form': u'INJ', u'brand': u'DEVIPROST', u'strength_3': u'', u'company': u"Dr.Reddy''S", u'unit': u''}

-- line #5204
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'125MCG', u'strength_2': u'0.5ML', u'substance': u'Carboprost Tromethamine', u'always_empty': u'', u'form': u'INJ', u'brand': u'EVACARB', u'strength_3': u'', u'company': u'CELON', u'unit': u''}

-- line #5205
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'125MCG', u'strength_2': u'', u'substance': u'Carboprost Tromethamine', u'always_empty': u'', u'form': u'INJ', u'brand': u'GYNEPROST', u'strength_3': u'', u'company': u'German R.', u'unit': u''}

-- line #5206
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250MCG', u'strength_2': u'', u'substance': u'Carboprost Tromethamine', u'always_empty': u'', u'form': u'INJ', u'brand': u'GYNEPROST', u'strength_3': u'', u'company': u'German R.', u'unit': u''}

-- line #5207
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'125MCG', u'strength_2': u'', u'substance': u'Carboprost Tromethamine', u'always_empty': u'', u'form': u'INJ', u'brand': u'PROSTODIN', u'strength_3': u'', u'company': u'Astrazeneca', u'unit': u''}

-- line #5208
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250MCG', u'strength_2': u'', u'substance': u'Carboprost Tromethamine', u'always_empty': u'', u'form': u'INJ', u'brand': u'PROSTODIN', u'strength_3': u'', u'company': u'Astrazeneca', u'unit': u''}

-- line #5209
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'60IU.', u'strength_2': u'ML', u'substance': u'Carboxymethyl Cellulose', u'always_empty': u'', u'form': u'INJ', u'brand': u'ACTON PROLONGATUM', u'strength_3': u'', u'company': u'Ferring Ph.', u'unit': u''}

-- line #5210
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADD TEARS 0.5 (Cipla)',
	'Carboxymethyl Cellulose',
	'EYE DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADD TEARS 0.5 (Cipla)'
);

-- line #5211
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Carboxymethyl Cellulose', u'always_empty': u'', u'form': u'', u'brand': u'ADFRESH TEARS', u'strength_3': u'', u'company': u'ADVENTUS', u'unit': u''}

-- line #5212
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AFTEE 0.5 (Ind-Swift)',
	'Carboxymethyl Cellulose',
	'DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AFTEE 0.5 (Ind-Swift)'
);

-- line #5213
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CCS 0.5 (Optho Rem.)',
	'Carboxymethyl Cellulose',
	'EYE DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CCS 0.5 (Optho Rem.)'
);

-- line #5214
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1', u'strength_2': u'', u'substance': u'Carboxymethyl Cellulose', u'always_empty': u'', u'form': u'', u'brand': u'CELLUVISC UNIMS', u'strength_3': u'', u'company': u'Allergan', u'unit': u'%'}

-- line #5215
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CMCGEL 1 (Jawa Ph.)',
	'Carboxymethyl Cellulose',
	'EYE DPS',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CMCGEL 1 (Jawa Ph.)'
);

-- line #5216
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'E-SALIVA 1 (Entod Ph.)',
	'Carboxymethyl Cellulose',
	'SPRAY',
	gm.nullify_empty_string('1')::numeric,
	'%W/V(SOD.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'E-SALIVA 1 (Entod Ph.)'
);

-- line #5217
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FRESH 0.5 (VISION PH.)',
	'Carboxymethyl Cellulose',
	'DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FRESH 0.5 (VISION PH.)'
);

-- line #5218
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FRESHIL 0.5 (RHYTHM PH.)',
	'Carboxymethyl Cellulose',
	'EYE DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FRESHIL 0.5 (RHYTHM PH.)'
);

-- line #5219
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Carboxymethyl Cellulose', u'always_empty': u'', u'form': u'DPS', u'brand': u'GLYTEARS', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #5220
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'I-MAX 0.5 (NIVCA)',
	'Carboxymethyl Cellulose',
	'DROPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'I-MAX 0.5 (NIVCA)'
);

-- line #5221
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'I-MAX 0.5 (NIVCA)',
	'Carboxymethyl Cellulose',
	'DROPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'I-MAX 0.5 (NIVCA)'
);

-- line #5222
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ITEARS 0.5 (IVA REM.)',
	'Carboxymethyl Cellulose',
	'EYE DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ITEARS 0.5 (IVA REM.)'
);

-- line #5223
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JUST TEARS 0.5 (SUNWAYS)',
	'Carboxymethyl Cellulose',
	'DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JUST TEARS 0.5 (SUNWAYS)'
);

-- line #5224
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JUST TEARS 0.3 (Sunways)',
	'Carboxymethyl Cellulose',
	'OINT',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JUST TEARS 0.3 (Sunways)'
);

-- line #5225
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUBREX 0.5 (Micro Labs)',
	'Carboxymethyl Cellulose',
	'DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUBREX 0.5 (Micro Labs)'
);

-- line #5226
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDITEARS 0.5 (MEDITRINA PH.)',
	'Carboxymethyl Cellulose',
	'EYE DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDITEARS 0.5 (MEDITRINA PH.)'
);

-- line #5227
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Carboxymethyl Cellulose', u'always_empty': u'', u'form': u'E/E DPS', u'brand': u'NISTEAR', u'strength_3': u'', u'company': u'NEISS', u'unit': u''}

-- line #5228
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REAL GEL 1 (DREAM PH.)',
	'Carboxymethyl Cellulose',
	'EYE DPS',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REAL GEL 1 (DREAM PH.)'
);

-- line #5229
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,5', u'strength_2': u'', u'substance': u'Carboxymethyl Cellulose', u'always_empty': u'', u'form': u'', u'brand': u'REAL TEARS', u'strength_3': u'', u'company': u'DREAM PH.', u'unit': u'%'}

-- line #5230
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REFRESH 1 (Allergan)',
	'Carboxymethyl Cellulose',
	'LIQUIGEL DPS',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REFRESH 1 (Allergan)'
);

-- line #5231
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,5', u'strength_2': u'', u'substance': u'Carboxymethyl Cellulose', u'always_empty': u'', u'form': u'', u'brand': u'REFRESH TEARS', u'strength_3': u'', u'company': u'Allergan', u'unit': u'%'}

-- line #5232
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REKOOL 0.5 (REXUS HC.)',
	'Carboxymethyl Cellulose',
	'EYE DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REKOOL 0.5 (REXUS HC.)'
);

-- line #5233
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELIF 0.5 (Allergan)',
	'Carboxymethyl Cellulose',
	'DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELIF 0.5 (Allergan)'
);

-- line #5234
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1', u'strength_2': u'', u'substance': u'Carboxymethyl Cellulose', u'always_empty': u'', u'form': u'', u'brand': u'RICHGEL TEARS', u'strength_3': u'', u'company': u'Sun', u'unit': u'%'}

-- line #5235
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Cardioplegia', u'always_empty': u'', u'form': u'INJ', u'brand': u'KP-EGIOCARD', u'strength_3': u'', u'company': u'Vhb', u'unit': u''}

-- line #5236
-- ignoring line: empty field [strength_1]
-- {u'list_of_values_of_unknown_fields': [u'PROCAINE 272.8 ', u' mg;20ML', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'', u'strength_2': u'', u'substance': u'Cardioplegia', u'always_empty': u'', u'form': u'AMP', u'brand': u'KP-PLEGIA', u'strength_3': u'', u'company': u'Vhb', u'unit': u'mg 3.25G'}

-- line #5237
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Cardioplegia', u'always_empty': u'', u'form': u'SOL', u'brand': u'PLEGIOCARD', u'strength_3': u'', u'company': u'Samarth', u'unit': u''}

-- line #5238
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARISOMA 350 (Wallace)',
	'Carisoprodol',
	'TAB',
	gm.nullify_empty_string('350')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARISOMA 350 (Wallace)'
);

-- line #5239
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CADMOS 12.5 (VHB(CRONUS))',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CADMOS 12.5 (VHB(CRONUS))'
);

-- line #5240
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CADMOS 25 (VHB(CRONUS))',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CADMOS 25 (VHB(CRONUS))'
);

-- line #5241
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CADMOS 3.125 (VHB(CRONUS))',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('3.125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CADMOS 3.125 (VHB(CRONUS))'
);

-- line #5242
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CADMOS 6.25 (VHB(CRONUS))',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('6.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CADMOS 6.25 (VHB(CRONUS))'
);

-- line #5243
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARCA 10 (Intas)',
	'Carvedilol',
	'CR TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARCA 10 (Intas)'
);

-- line #5244
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARCA 20 (Intas)',
	'Carvedilol',
	'CR TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARCA 20 (Intas)'
);

-- line #5245
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARCA 40 (Intas)',
	'Carvedilol',
	'CR TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARCA 40 (Intas)'
);

-- line #5246
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARCA 80 (Intas)',
	'Carvedilol',
	'CR TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARCA 80 (Intas)'
);

-- line #5247
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARCA 12.5 (Intas)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARCA 12.5 (Intas)'
);

-- line #5248
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARCA 25 (Intas)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARCA 25 (Intas)'
);

-- line #5249
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARCA 3.125 (Intas)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('3.125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARCA 3.125 (Intas)'
);

-- line #5250
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARCA 6.25 (Intas)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('6.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARCA 6.25 (Intas)'
);

-- line #5251
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDIPURE 12.5 (Mankind)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDIPURE 12.5 (Mankind)'
);

-- line #5252
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDIPURE 3.125 (Mankind)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('3.125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDIPURE 3.125 (Mankind)'
);

-- line #5253
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDIPURE 6.25 (Mankind)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('6.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDIPURE 6.25 (Mankind)'
);

-- line #5254
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDIVAS 10 (Sun)',
	'Carvedilol',
	'CR CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDIVAS 10 (Sun)'
);

-- line #5255
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDIVAS 20 (Sun)',
	'Carvedilol',
	'CR CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDIVAS 20 (Sun)'
);

-- line #5256
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDIVAS 40 (Sun)',
	'Carvedilol',
	'CR CAP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDIVAS 40 (Sun)'
);

-- line #5257
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDIVAS 12.5 (Sun)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDIVAS 12.5 (Sun)'
);

-- line #5258
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDIVAS 25 (Sun)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDIVAS 25 (Sun)'
);

-- line #5259
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDIVAS 3.125 (Sun)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('3.125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDIVAS 3.125 (Sun)'
);

-- line #5260
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDIVAS 6.25 (Sun)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('6.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDIVAS 6.25 (Sun)'
);

-- line #5261
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARELOL 12.5 (Cipla)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARELOL 12.5 (Cipla)'
);

-- line #5262
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARELOL 3.125 (Cipla)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('3.125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARELOL 3.125 (Cipla)'
);

-- line #5263
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARELOL 6.25 (Cipla)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('6.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARELOL 6.25 (Cipla)'
);

-- line #5264
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARLOC 12.5 (Cipla)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARLOC 12.5 (Cipla)'
);

-- line #5265
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARLOC 25 (Cipla)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARLOC 25 (Cipla)'
);

-- line #5266
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARLOC 3.125 (Cipla)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('3.125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARLOC 3.125 (Cipla)'
);

-- line #5267
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARLOC 6.25 (Cipla)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('6.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARLOC 6.25 (Cipla)'
);

-- line #5268
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARTAB 12.5 (Rpg Life)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARTAB 12.5 (Rpg Life)'
);

-- line #5269
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARTAB 25 (Rpg Life)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARTAB 25 (Rpg Life)'
);

-- line #5270
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARTAB 3.125 (Rpg Life)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('3.125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARTAB 3.125 (Rpg Life)'
);

-- line #5271
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARTAB 6.25 (Rpg Life)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('6.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARTAB 6.25 (Rpg Life)'
);

-- line #5272
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARVAS 12.5 (Medley)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARVAS 12.5 (Medley)'
);

-- line #5273
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARVAS 25 (Medley)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARVAS 25 (Medley)'
);

-- line #5274
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARVAS 3.125 (Medley)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('3.125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARVAS 3.125 (Medley)'
);

-- line #5275
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARVAS 6.25 (Medley)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('6.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARVAS 6.25 (Medley)'
);

-- line #5276
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARVEDIL 12.5 (Alkem)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARVEDIL 12.5 (Alkem)'
);

-- line #5277
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARVEDIL 25 (Alkem)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARVEDIL 25 (Alkem)'
);

-- line #5278
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARVEDIL 3.125 (Alkem)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('3.125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARVEDIL 3.125 (Alkem)'
);

-- line #5279
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARVEDIL 6.25 (Alkem)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('6.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARVEDIL 6.25 (Alkem)'
);

-- line #5280
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARVEL P/F 6.25 (Taurus Lab)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('6.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARVEL P/F 6.25 (Taurus Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARVEL P/F 12.5 (Taurus Lab)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARVEL P/F 12.5 (Taurus Lab)'
);

-- line #5281
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARVEL 3.125 (Taurus Lab)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('3.125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARVEL 3.125 (Taurus Lab)'
);

-- line #5282
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARVETREND 12.5 (Piramal Hc.)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARVETREND 12.5 (Piramal Hc.)'
);

-- line #5283
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARVETREND 25 (Piramal Hc.)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARVETREND 25 (Piramal Hc.)'
);

-- line #5284
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARVETREND 3.125 (Piramal Hc.)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('3.125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARVETREND 3.125 (Piramal Hc.)'
);

-- line #5285
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARVETREND 6.25 (Piramal Hc.)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('6.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARVETREND 6.25 (Piramal Hc.)'
);

-- line #5286
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10', u'strength_2': u'', u'substance': u'Carvedilol', u'always_empty': u'', u'form': u'', u'brand': u'CARVIFLO', u'strength_3': u'', u'company': u'Ajanta Ph.', u'unit': u'mg'}

-- line #5287
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'Carvedilol', u'always_empty': u'', u'form': u'', u'brand': u'CARVIFLO', u'strength_3': u'', u'company': u'Ajanta Ph.', u'unit': u'mg'}

-- line #5288
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40', u'strength_2': u'', u'substance': u'Carvedilol', u'always_empty': u'', u'form': u'', u'brand': u'CARVIFLO', u'strength_3': u'', u'company': u'Ajanta Ph.', u'unit': u'mg'}

-- line #5289
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARVIL 12.5 (Zydus cnd)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARVIL 12.5 (Zydus cnd)'
);

-- line #5290
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARVIL 25 (Zydus cnd)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARVIL 25 (Zydus cnd)'
);

-- line #5291
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARVIL 3.125 (Zydus cnd)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('3.125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARVIL 3.125 (Zydus cnd)'
);

-- line #5292
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARVIL 6.25 (Zydus cnd)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('6.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARVIL 6.25 (Zydus cnd)'
);

-- line #5293
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARVIMED 12.5 (Comed)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARVIMED 12.5 (Comed)'
);

-- line #5294
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARVIMED 3.125 (Comed)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('3.125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARVIMED 3.125 (Comed)'
);

-- line #5295
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARVIPRESS 12.5 (Cardicare)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARVIPRESS 12.5 (Cardicare)'
);

-- line #5296
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARVIPRESS 25 (Cardicare)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARVIPRESS 25 (Cardicare)'
);

-- line #5297
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARVIPRESS 3.125 (Cardicare)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('3.125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARVIPRESS 3.125 (Cardicare)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARVIPRESS 6.25 (Cardicare)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('6.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARVIPRESS 6.25 (Cardicare)'
);

-- line #5298
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARVISTAR 12.5 (Lupin)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARVISTAR 12.5 (Lupin)'
);

-- line #5299
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARVISTAR 3.125 (Lupin)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('3.125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARVISTAR 3.125 (Lupin)'
);

-- line #5300
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARVISTAR 6.25 (Lupin)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('6.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARVISTAR 6.25 (Lupin)'
);

-- line #5301
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARVIZEST 12.5 (Emcure)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARVIZEST 12.5 (Emcure)'
);

-- line #5302
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARVIZEST 3.125 (Emcure)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('3.125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARVIZEST 3.125 (Emcure)'
);

-- line #5303
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARZEC 12.5 (Gsk)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARZEC 12.5 (Gsk)'
);

-- line #5304
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARZEC 3.125 (Gsk)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('3.125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARZEC 3.125 (Gsk)'
);

-- line #5305
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARZEC 6.25 (Gsk)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('6.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARZEC 6.25 (Gsk)'
);

-- line #5306
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CASLOT 12.5 (Ranbaxy Cv)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CASLOT 12.5 (Ranbaxy Cv)'
);

-- line #5307
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CASLOT 25 (Ranbaxy Cv)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CASLOT 25 (Ranbaxy Cv)'
);

-- line #5308
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CASLOT 3.125 (Ranbaxy Cv)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('3.125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CASLOT 3.125 (Ranbaxy Cv)'
);

-- line #5309
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CASLOT 6.25 (Ranbaxy Cv)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('6.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CASLOT 6.25 (Ranbaxy Cv)'
);

-- line #5310
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAVE 3.12 (WEST COAST)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('3.12')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAVE 3.12 (WEST COAST)'
);

-- line #5311
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAVE 6.25 (WEST COAST)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('6.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAVE 6.25 (WEST COAST)'
);

-- line #5312
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEVAS 12.5 (Cadila Ph.)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEVAS 12.5 (Cadila Ph.)'
);

-- line #5313
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEVAS 3.125 (Cadila Ph.)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('3.125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEVAS 3.125 (Cadila Ph.)'
);

-- line #5314
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONPRES 12.5 (Torrent)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONPRES 12.5 (Torrent)'
);

-- line #5315
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONPRES 3.125 (Torrent)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('3.125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONPRES 3.125 (Torrent)'
);

-- line #5316
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONPRES 6.25 (Torrent)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('6.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONPRES 6.25 (Torrent)'
);

-- line #5317
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CVL 3.125 (Themis Med.)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('3.125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CVL 3.125 (Themis Med.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CVL 12.5 (Themis Med.)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CVL 12.5 (Themis Med.)'
);

-- line #5318
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CVL 6.25 (Themis Med.)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('6.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CVL 6.25 (Themis Med.)'
);

-- line #5319
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORICAR 12.5 (Piramal Hc.)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORICAR 12.5 (Piramal Hc.)'
);

-- line #5320
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORICAR 25 (Piramal Hc.)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORICAR 25 (Piramal Hc.)'
);

-- line #5321
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORICAR 3.125 (Piramal Hc.)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('3.125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORICAR 3.125 (Piramal Hc.)'
);

-- line #5322
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORICAR 6.25 (Piramal Hc.)',
	'Carvedilol',
	'TAB',
	gm.nullify_empty_string('6.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORICAR 6.25 (Piramal Hc.)'
);

-- line #5323
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5G', u'strength_2': u'ML', u'substance': u'CASPOFUNGIN', u'always_empty': u'', u'form': u'INJ', u'brand': u'CANCIDAS', u'strength_3': u'', u'company': u'MSD', u'unit': u''}

-- line #5324
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CATALIN 0.005 (Allergan)',
	'CATALIN',
	'SOLV',
	gm.nullify_empty_string('0.005')::numeric,
	'%(I-HYDROXY-5-OXO-5H-PYRIDO(3-2A)PHENOXAZINE 3 CARBOXYLIC ACID)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CATALIN 0.005 (Allergan)'
);

-- line #5325
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CATALIN 0.75 (Allergan)',
	'CATALIN',
	'TAB',
	gm.nullify_empty_string('0.75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CATALIN 0.75 (Allergan)'
);

-- line #5326
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTICLOR 125 (Active Hc.)',
	'Cefaclor',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTICLOR 125 (Active Hc.)'
);

-- line #5327
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALCLOR 250 (Taurus Lab)',
	'Cefaclor',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALCLOR 250 (Taurus Lab)'
);

-- line #5328
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALCLOR 125 (Taurus Lab)',
	'Cefaclor',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALCLOR 125 (Taurus Lab)'
);

-- line #5329
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALFACLOR 250 (Alpha Lab)',
	'Cefaclor',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALFACLOR 250 (Alpha Lab)'
);

-- line #5330
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALFACLOR 250 (Alpha Lab)',
	'Cefaclor',
	'D.SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALFACLOR 250 (Alpha Lab)'
);

-- line #5331
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50', u'strength_2': u'', u'substance': u'Cefaclor', u'always_empty': u'', u'form': u'', u'brand': u'ARTICLOR DSP', u'strength_3': u'', u'company': u'ICARUS', u'unit': u'mg/ML'}

-- line #5332
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'125', u'strength_2': u'', u'substance': u'Cefaclor', u'always_empty': u'', u'form': u'', u'brand': u'ARTICLOR D SRY', u'strength_3': u'', u'company': u'ICARUS', u'unit': u'mg/5ML'}

-- line #5333
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARTICLOR 125 (ICARUS)',
	'Cefaclor',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARTICLOR 125 (ICARUS)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARTICLOR 250 (ICARUS)',
	'Cefaclor',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARTICLOR 250 (ICARUS)'
);

-- line #5334
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C CLOR 125 (Shalman)',
	'Cefaclor',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C CLOR 125 (Shalman)'
);

-- line #5335
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C CLOR 125 (Shalman)',
	'Cefaclor',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C CLOR 125 (Shalman)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C CLOR 250 (Shalman)',
	'Cefaclor',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C CLOR 250 (Shalman)'
);

-- line #5336
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'15G', u'strength_2': u'30ML', u'substance': u'Cefaclor', u'always_empty': u'', u'form': u'SUS', u'brand': u'CECEL', u'strength_3': u'', u'company': u'Zee Lab', u'unit': u''}

-- line #5337
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CECLOR 250 (Arvind Lab.)',
	'Cefaclor',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CECLOR 250 (Arvind Lab.)'
);

-- line #5338
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Cefaclor', u'always_empty': u'', u'form': u'D.SYR', u'brand': u'CEFGOL', u'strength_3': u'', u'company': u'Parenteral', u'unit': u''}

-- line #5339
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFLOR 250 (Finecure)',
	'Cefaclor',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFLOR 250 (Finecure)'
);

-- line #5340
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFLOR 125 (Finecure)',
	'Cefaclor',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFLOR 125 (Finecure)'
);

-- line #5341
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEKLOR 250 (Solitaire)',
	'Cefaclor',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEKLOR 250 (Solitaire)'
);

-- line #5342
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOROCEF 125 (Genix Ph.)',
	'Cefaclor',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOROCEF 125 (Genix Ph.)'
);

-- line #5343
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COLORS 125 (Mefro Ph.)',
	'Cefaclor',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COLORS 125 (Mefro Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COLORS 250 (Mefro Ph.)',
	'Cefaclor',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COLORS 250 (Mefro Ph.)'
);

-- line #5344
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLOR 250 (Divine)',
	'Cefaclor',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLOR 250 (Divine)'
);

-- line #5345
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLOR 125 (Divine)',
	'Cefaclor',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLOR 125 (Divine)'
);

-- line #5346
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DISTACLOR 250 (Eli Lilly)',
	'Cefaclor',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DISTACLOR 250 (Eli Lilly)'
);

-- line #5347
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DISTACLOR 500 (Eli Lilly)',
	'Cefaclor',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DISTACLOR 500 (Eli Lilly)'
);

-- line #5348
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DISTACLOR 375 (Eli Lilly)',
	'Cefaclor',
	'CD TAB',
	gm.nullify_empty_string('375')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DISTACLOR 375 (Eli Lilly)'
);

-- line #5349
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DISTACLOR 750 (Eli Lilly)',
	'Cefaclor',
	'CD TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DISTACLOR 750 (Eli Lilly)'
);

-- line #5350
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DISTACLOR 50 (Eli Lilly)',
	'Cefaclor',
	'DPS',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DISTACLOR 50 (Eli Lilly)'
);

-- line #5351
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DISTACLOR 125 (Eli Lilly)',
	'Cefaclor',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DISTACLOR 125 (Eli Lilly)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DISTACLOR 250 (Eli Lilly)',
	'Cefaclor',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DISTACLOR 250 (Eli Lilly)'
);

-- line #5352
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DISTACLOR 125 (Eli Lilly)',
	'Cefaclor',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DISTACLOR 125 (Eli Lilly)'
);

-- line #5353
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DISTACLOR 187 (Eli Lilly)',
	'Cefaclor',
	'SUS',
	gm.nullify_empty_string('187')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DISTACLOR 187 (Eli Lilly)'
);

-- line #5354
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUCLOR 250 (Morepen)',
	'Cefaclor',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUCLOR 250 (Morepen)'
);

-- line #5355
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUCLOR 500 (Morepen)',
	'Cefaclor',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUCLOR 500 (Morepen)'
);

-- line #5356
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUCLOR 125 (Morepen)',
	'Cefaclor',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUCLOR 125 (Morepen)'
);

-- line #5357
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUCLOR 187 (Morepen)',
	'Cefaclor',
	'KT',
	gm.nullify_empty_string('187')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUCLOR 187 (Morepen)'
);

-- line #5358
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ECLOR 375 (Lupin)',
	'Cefaclor',
	'LA TAB',
	gm.nullify_empty_string('375')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ECLOR 375 (Lupin)'
);

-- line #5359
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ECLOR PREMIX 125 (Lupin)',
	'Cefaclor',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ECLOR PREMIX 125 (Lupin)'
);

-- line #5360
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALCLOR 250 (Hal)',
	'Cefaclor',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALCLOR 250 (Hal)'
);

-- line #5361
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALOCEF 250 (Otsira)',
	'Cefaclor',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALOCEF 250 (Otsira)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALOCEF 500 (Otsira)',
	'Cefaclor',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALOCEF 500 (Otsira)'
);

-- line #5362
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALOCEF 125 (Otsira)',
	'Cefaclor',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALOCEF 125 (Otsira)'
);

-- line #5363
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALOCEF 187 (Otsira)',
	'Cefaclor',
	'D.SYR',
	gm.nullify_empty_string('187')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALOCEF 187 (Otsira)'
);

-- line #5364
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALOCEF PAED 50 (Otsira)',
	'Cefaclor',
	'DPS',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALOCEF PAED 50 (Otsira)'
);

-- line #5365
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFLOR 250 (Ranbaxy)',
	'Cefaclor',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFLOR 250 (Ranbaxy)'
);

-- line #5366
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFLOR 50 (Ranbaxy)',
	'Cefaclor',
	'DPS',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFLOR 50 (Ranbaxy)'
);

-- line #5367
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFLOR 187 (Ranbaxy)',
	'Cefaclor',
	'D.SYR',
	gm.nullify_empty_string('187')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFLOR 187 (Ranbaxy)'
);

-- line #5368
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFLOR 125 (Ranbaxy)',
	'Cefaclor',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFLOR 125 (Ranbaxy)'
);

-- line #5369
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFLOR 250 (Ranbaxy)',
	'Cefaclor',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFLOR 250 (Ranbaxy)'
);

-- line #5370
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFLOR 125 (Ranbaxy)',
	'Cefaclor',
	'GRAN',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFLOR 125 (Ranbaxy)'
);

-- line #5371
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFLOR 375 (Ranbaxy)',
	'Cefaclor',
	'MR TAB',
	gm.nullify_empty_string('375')::numeric,
	'mg(M.R.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFLOR 375 (Ranbaxy)'
);

-- line #5372
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFLOR 750 (Ranbaxy)',
	'Cefaclor',
	'MR TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFLOR 750 (Ranbaxy)'
);

-- line #5373
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFLOR 125 (Ranbaxy)',
	'Cefaclor',
	'REDIMIX SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFLOR 125 (Ranbaxy)'
);

-- line #5374
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFMAX 125 (Biomax Lab)',
	'Cefaclor',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFMAX 125 (Biomax Lab)'
);

-- line #5375
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KIDORIN 125 (Parenteral)',
	'Cefaclor',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KIDORIN 125 (Parenteral)'
);

-- line #5376
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACLOR 250 (Meridian)',
	'Cefaclor',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACLOR 250 (Meridian)'
);

-- line #5377
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RADICLOR 250 (Radicura)',
	'Cefaclor',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RADICLOR 250 (Radicura)'
);

-- line #5378
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESCLOR-D 125 (Cure Quick)',
	'Cefaclor',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESCLOR-D 125 (Cure Quick)'
);

-- line #5379
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACER 125 (Mefro Ph.)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACER 125 (Mefro Ph.)'
);

-- line #5380
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACER 250 (Mefro Ph.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACER 250 (Mefro Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACER 500 (Mefro Ph.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACER 500 (Mefro Ph.)'
);

-- line #5381
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTIDROX 125 (Active Hc.)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTIDROX 125 (Active Hc.)'
);

-- line #5382
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTIDROX 250 (Active Hc.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTIDROX 250 (Active Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTIDROX 500 (Active Hc.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTIDROX 500 (Active Hc.)'
);

-- line #5383
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACUDROX 125 (Macleods)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACUDROX 125 (Macleods)'
);

-- line #5384
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACUDROX 250 (Macleods)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACUDROX 250 (Macleods)'
);

-- line #5385
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACUDROX 500 (Macleods)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACUDROX 500 (Macleods)'
);

-- line #5386
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADROX 125 (Admac Ph.)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADROX 125 (Admac Ph.)'
);

-- line #5387
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADROX 250 (Admac Ph.)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADROX 250 (Admac Ph.)'
);

-- line #5388
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADROX 500 (Admac Ph.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADROX 500 (Admac Ph.)'
);

-- line #5389
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AFFYCEF 125 (AFFY)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AFFYCEF 125 (AFFY)'
);

-- line #5390
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AFFYCEF 250 (AFFY)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AFFYCEF 250 (AFFY)'
);

-- line #5391
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AFFYCEF 500 (AFFY)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AFFYCEF 500 (AFFY)'
);

-- line #5392
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANICEF 125 (Anikem Lab.)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANICEF 125 (Anikem Lab.)'
);

-- line #5393
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANICEF 250 (Anikem Lab.)',
	'Cefadroxil',
	'DT/500TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANICEF 250 (Anikem Lab.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANICEF 500 (Anikem Lab.)',
	'Cefadroxil',
	'DT/500TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANICEF 500 (Anikem Lab.)'
);

-- line #5394
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANICEF 125 (Anikem Lab.)',
	'Cefadroxil',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANICEF 125 (Anikem Lab.)'
);

-- line #5395
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APDIL 250 (Ajanta Ph.)',
	'CEFADROXIL',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APDIL 250 (Ajanta Ph.)'
);

-- line #5396
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APDIL REDIUSE 125 (Ajanta Ph.)',
	'CEFADROXIL',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APDIL REDIUSE 125 (Ajanta Ph.)'
);

-- line #5397
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APDIL 500 (Ajanta Ph.)',
	'CEFADROXIL',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APDIL 500 (Ajanta Ph.)'
);

-- line #5398
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AQDROX 125 (Aquila)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AQDROX 125 (Aquila)'
);

-- line #5399
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AQDROX 125 (Aquila)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AQDROX 125 (Aquila)'
);

-- line #5400
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AQDROX 250 (Aquila)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AQDROX 250 (Aquila)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AQDROX 500 (Aquila)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AQDROX 500 (Aquila)'
);

-- line #5401
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AQDROX 500 (Aquila)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AQDROX 500 (Aquila)'
);

-- line #5402
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AROXIL 125 (Acme Ph)',
	'Cefadroxil',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AROXIL 125 (Acme Ph)'
);

-- line #5403
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AROXIL 250 (Acme Ph)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AROXIL 250 (Acme Ph)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AROXIL 500 (Acme Ph)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AROXIL 500 (Acme Ph)'
);

-- line #5404
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATDROX 125 (Atoz Ph.)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATDROX 125 (Atoz Ph.)'
);

-- line #5405
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATDROX 125 (Atoz Ph.)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATDROX 125 (Atoz Ph.)'
);

-- line #5406
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATDROX 250 (Atoz Ph.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATDROX 250 (Atoz Ph.)'
);

-- line #5407
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATDROX 500 (Atoz Ph.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATDROX 500 (Atoz Ph.)'
);

-- line #5408
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXIS 250 (Sierra)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXIS 250 (Sierra)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXIS 500 (Sierra)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXIS 500 (Sierra)'
);

-- line #5409
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACTOXIL 125 (Graf Lab.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACTOXIL 125 (Graf Lab.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACTOXIL 250 (Graf Lab.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACTOXIL 250 (Graf Lab.)'
);

-- line #5410
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACTOXIL 500 (Graf Lab.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACTOXIL 500 (Graf Lab.)'
);

-- line #5411
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BD 500 (Kopran)',
	'Cefadroxil',
	'LB CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg( WITH LACTOBACILLUS)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BD 500 (Kopran)'
);

-- line #5412
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BD 250 (Kopran)',
	'Cefadroxil',
	'LB SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg/5'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BD 250 (Kopran)'
);

-- line #5413
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'B-DRIL 125 (Biocin Hc.)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'B-DRIL 125 (Biocin Hc.)'
);

-- line #5414
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'B-DRIL 250 (Biocin Hc.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'B-DRIL 250 (Biocin Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'B-DRIL 500 (Biocin Hc.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'B-DRIL 500 (Biocin Hc.)'
);

-- line #5415
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BICEF 125 (Micro Nova)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BICEF 125 (Micro Nova)'
);

-- line #5416
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BICEF 250 (Micro Nova)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BICEF 250 (Micro Nova)'
);

-- line #5417
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BICEF 500 (Micro Nova)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BICEF 500 (Micro Nova)'
);

-- line #5418
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BICEF 125 (Micro Nova)',
	'Cefadroxil',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BICEF 125 (Micro Nova)'
);

-- line #5419
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BICEF 250 (Micro Nova)',
	'Cefadroxil',
	'SUS',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BICEF 250 (Micro Nova)'
);

-- line #5420
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BID 500 (Kopran)',
	'Cefadroxil',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BID 500 (Kopran)'
);

-- line #5421
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIDEL 125 (VERITAZ)',
	'Cefadroxil',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIDEL 125 (VERITAZ)'
);

-- line #5422
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIDEL 125 (VERITAZ)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIDEL 125 (VERITAZ)'
);

-- line #5423
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIDEL 250 (VERITAZ)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIDEL 250 (VERITAZ)'
);

-- line #5424
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIDEL 500 (VERITAZ)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIDEL 500 (VERITAZ)'
);

-- line #5425
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BID 125 (Kopran)',
	'Cefadroxil',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BID 125 (Kopran)'
);

-- line #5426
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BID 250 (Kopran)',
	'Cefadroxil',
	'KT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BID 250 (Kopran)'
);

-- line #5427
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIDOXIL 125 (Calyx Rem.)',
	'Cefadroxil',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIDOXIL 125 (Calyx Rem.)'
);

-- line #5428
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIDOXIL 250 (Calyx Rem.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIDOXIL 250 (Calyx Rem.)'
);

-- line #5429
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIDROX 250 (Brussels)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIDROX 250 (Brussels)'
);

-- line #5430
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIDROX 125 (Brussels)',
	'Cefadroxil',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIDROX 125 (Brussels)'
);

-- line #5431
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIDROX 250 (Brussels)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIDROX 250 (Brussels)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIDROX 500 (Brussels)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIDROX 500 (Brussels)'
);

-- line #5432
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BID 250 (Kopran)',
	'Cefadroxil',
	'SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BID 250 (Kopran)'
);

-- line #5433
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLUDROX 500 (Blue Cross)',
	'Cefadroxil',
	'CAP/TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLUDROX 500 (Blue Cross)'
);

-- line #5434
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLUDROX 100 (Blue Cross)',
	'Cefadroxil',
	'DPS',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLUDROX 100 (Blue Cross)'
);

-- line #5435
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLUDROX 125 (Blue Cross)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLUDROX 125 (Blue Cross)'
);

-- line #5436
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLUDROX 125 (Blue Cross)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLUDROX 125 (Blue Cross)'
);

-- line #5437
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLUDROX 250 (Blue Cross)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLUDROX 250 (Blue Cross)'
);

-- line #5438
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLUDROX-P 100 (BLUE CROSS(GOLD CROSS))',
	'Cefadroxil',
	'DPS',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLUDROX-P 100 (BLUE CROSS(GOLD CROSS))'
);

-- line #5439
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLUDROX-P 125 (BLUE CROSS(GOLD CROSS))',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLUDROX-P 125 (BLUE CROSS(GOLD CROSS))'
);

-- line #5440
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLUDROX-P 125 (BLUE CROSS(GOLD CROSS))',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLUDROX-P 125 (BLUE CROSS(GOLD CROSS))'
);

-- line #5441
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLUDROX 250 (Blue Cross)',
	'Cefadroxil',
	'SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg;5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLUDROX 250 (Blue Cross)'
);

-- line #5442
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BONAXIL-D 125 (Medico)',
	'Cefadroxil',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BONAXIL-D 125 (Medico)'
);

-- line #5443
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BONAXIL 250 (Medico)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BONAXIL 250 (Medico)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BONAXIL 500 (Medico)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BONAXIL 500 (Medico)'
);

-- line #5444
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BROTZU 125 (Dey''S)',
	'CEFADROXIL',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BROTZU 125 (Dey''S)'
);

-- line #5445
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BROTZU 250 (Dey''S)',
	'CEFADROXIL',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BROTZU 250 (Dey''S)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BROTZU 500 (Dey''S)',
	'CEFADROXIL',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BROTZU 500 (Dey''S)'
);

-- line #5446
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAREDROX 125 (Intra Lab)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAREDROX 125 (Intra Lab)'
);

-- line #5447
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAREDROX 250 (Intra Lab)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAREDROX 250 (Intra Lab)'
);

-- line #5448
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAREDROX 500 (Intra Lab)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAREDROX 500 (Intra Lab)'
);

-- line #5449
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-DROX 250 (Corona)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-DROX 250 (Corona)'
);

-- line #5450
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-DROX 500 (Corona)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-DROX 500 (Corona)'
);

-- line #5451
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CDSTAN 125 (Stanford)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CDSTAN 125 (Stanford)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CDSTAN 250 (Stanford)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CDSTAN 250 (Stanford)'
);

-- line #5452
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CDSTAN 500 (Stanford)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CDSTAN 500 (Stanford)'
);

-- line #5453
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CDX 125 (Zorex Ph.)',
	'Cefadroxil',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CDX 125 (Zorex Ph.)'
);

-- line #5454
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CDX 250 (Zorex Ph.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CDX 250 (Zorex Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CDX 500 (Zorex Ph.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CDX 500 (Zorex Ph.)'
);

-- line #5455
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEDIL 125 (BACTOLAC)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEDIL 125 (BACTOLAC)'
);

-- line #5456
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEDIL 250 (BACTOLAC)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEDIL 250 (BACTOLAC)'
);

-- line #5457
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEDIL 125 (BACTOLAC)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEDIL 125 (BACTOLAC)'
);

-- line #5458
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEDIL 500 (BACTOLAC)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEDIL 500 (BACTOLAC)'
);

-- line #5459
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEDOL 125 (Olcare)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEDOL 125 (Olcare)'
);

-- line #5460
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEDOL 250 (Olcare)',
	'Cefadroxil',
	'KT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEDOL 250 (Olcare)'
);

-- line #5461
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEDOL 500 (Olcare)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEDOL 500 (Olcare)'
);

-- line #5462
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEDOXIL 500 (Monokem)',
	'Cefadroxil',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEDOXIL 500 (Monokem)'
);

-- line #5463
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEDOXIL 250 (Monokem)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEDOXIL 250 (Monokem)'
);

-- line #5464
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEDOXIL 250 (Monokem)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEDOXIL 250 (Monokem)'
);

-- line #5465
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEDRIL 250 (Stallion)',
	'Cefadroxil',
	'DS D.SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEDRIL 250 (Stallion)'
);

-- line #5466
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEDRIL 125 (Stallion)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEDRIL 125 (Stallion)'
);

-- line #5467
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEDRIL 250 (Stallion)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEDRIL 250 (Stallion)'
);

-- line #5468
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEDRIL 500 (Stallion)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEDRIL 500 (Stallion)'
);

-- line #5469
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEDRO 125 (Rekvina)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEDRO 125 (Rekvina)'
);

-- line #5470
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEDRO 250 (Rekvina)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEDRO 250 (Rekvina)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEDRO 500 (Rekvina)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEDRO 500 (Rekvina)'
);

-- line #5471
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEDROX 125 (Citadel)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEDROX 125 (Citadel)'
);

-- line #5472
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEDROX 250 (VERITAZ)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEDROX 250 (VERITAZ)'
);

-- line #5473
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEDROXIN 125 (Claris L.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEDROXIN 125 (Claris L.)'
);

-- line #5474
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEDROXIN 250 (Claris L.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEDROXIN 250 (Claris L.)'
);

-- line #5475
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEDROXIN 500 (Claris L.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEDROXIN 500 (Claris L.)'
);

-- line #5476
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEDROX 125 (EAST WEST)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEDROX 125 (EAST WEST)'
);

-- line #5477
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEDROX 500 (VERITAZ)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEDROX 500 (VERITAZ)'
);

-- line #5478
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFABID 100 (Life Line)',
	'Cefadroxil',
	'DPS',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFABID 100 (Life Line)'
);

-- line #5479
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFABID 125 (Life Line)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFABID 125 (Life Line)'
);

-- line #5480
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFABID 250 (Indica)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFABID 250 (Indica)'
);

-- line #5481
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFABID 250 (Life Line)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFABID 250 (Life Line)'
);

-- line #5482
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFABID 125 (Indica)',
	'Cefadroxil',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFABID 125 (Indica)'
);

-- line #5483
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFABID 500 (Indica)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFABID 500 (Indica)'
);

-- line #5484
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFABID 125 (Life Line)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFABID 125 (Life Line)'
);

-- line #5485
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFABID 500 (Life Line)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFABID 500 (Life Line)'
);

-- line #5486
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'125RNG', u'strength_2': u'', u'substance': u'Cefadroxil', u'always_empty': u'', u'form': u'TAB', u'brand': u'CEFACURE', u'strength_3': u'', u'company': u'Unicure', u'unit': u''}

-- line #5487
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFACURE 250 (Unicure)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFACURE 250 (Unicure)'
);

-- line #5488
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFADAUR 100 (Protec)',
	'Cefadroxil',
	'DPS',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFADAUR 100 (Protec)'
);

-- line #5489
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFADRISH 250 (Maneesh)',
	'Cefadroxil',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFADRISH 250 (Maneesh)'
);

-- line #5490
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFADRISH 125 (Maneesh)',
	'Cefadroxil',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFADRISH 125 (Maneesh)'
);

-- line #5491
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFADRISH 500 (Maneesh)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFADRISH 500 (Maneesh)'
);

-- line #5492
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFADROX 500 (Aristo)',
	'Cefadroxil',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFADROX 500 (Aristo)'
);

-- line #5493
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFADROX 250 (Aristo)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFADROX 250 (Aristo)'
);

-- line #5494
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFADROX 125 (Aristo)',
	'Cefadroxil',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFADROX 125 (Aristo)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFADROX 250 (Aristo)',
	'Cefadroxil',
	'KID TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFADROX 250 (Aristo)'
);

-- line #5495
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFADROX 125 (Aristo)',
	'Cefadroxil',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFADROX 125 (Aristo)'
);

-- line #5496
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFADROX 500 (Aristo)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFADROX 500 (Aristo)'
);

-- line #5497
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFADUR 125 (Protec)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFADUR 125 (Protec)'
);

-- line #5498
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFADUR 250 (Protec)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFADUR 250 (Protec)'
);

-- line #5499
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFADUR REDIUSE 100 (Protec)',
	'Cefadroxil',
	'DPS',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFADUR REDIUSE 100 (Protec)'
);

-- line #5500
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFADUR REDIUSE 125 (Protec)',
	'Cefadroxil',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFADUR REDIUSE 125 (Protec)'
);

-- line #5501
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFADUR REDIUSE 250 (Protec)',
	'Cefadroxil',
	'SUS',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFADUR REDIUSE 250 (Protec)'
);

-- line #5502
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFADUR 125 (Protec)',
	'Cefadroxil',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFADUR 125 (Protec)'
);

-- line #5503
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFADUR 250 (Protec)',
	'Cefadroxil',
	'SUS',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFADUR 250 (Protec)'
);

-- line #5504
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFADUR 500 (Protec)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFADUR 500 (Protec)'
);

-- line #5505
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFALOBID 250 (TALENT LAB.)',
	'Cefadroxil',
	'DT/F DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFALOBID 250 (TALENT LAB.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFALOBID 500 (TALENT LAB.)',
	'Cefadroxil',
	'DT/F DT',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFALOBID 500 (TALENT LAB.)'
);

-- line #5506
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFALOBID 125 (TALENT LAB.)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFALOBID 125 (TALENT LAB.)'
);

-- line #5507
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFALOBID 250 (TALENT LAB.)',
	'Cefadroxil',
	'F. D.SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFALOBID 250 (TALENT LAB.)'
);

-- line #5508
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAR 250 (ARLOP PH.)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAR 250 (ARLOP PH.)'
);

-- line #5509
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAR 500 (ARLOP PH.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAR 500 (ARLOP PH.)'
);

-- line #5510
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFASAL 500 (Salvo Hc.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFASAL 500 (Salvo Hc.)'
);

-- line #5511
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFASTAR 125 (Mankind)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFASTAR 125 (Mankind)'
);

-- line #5512
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFASTAR 250 (Mankind)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFASTAR 250 (Mankind)'
);

-- line #5513
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFASTAR 500 (Mankind)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFASTAR 500 (Mankind)'
);

-- line #5514
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFATAUR 500 (Taurus Lab)',
	'Cefadroxil',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFATAUR 500 (Taurus Lab)'
);

-- line #5515
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFATAUR 125 (Taurus Lab)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFATAUR 125 (Taurus Lab)'
);

-- line #5516
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFATAUR 125 (Taurus Lab)',
	'Cefadroxil',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFATAUR 125 (Taurus Lab)'
);

-- line #5517
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFATAUR 250 (Taurus Lab)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFATAUR 250 (Taurus Lab)'
);

-- line #5518
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFCARE 250 (Wanbury)',
	'Cefadroxil',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFCARE 250 (Wanbury)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFCARE 500 (Wanbury)',
	'Cefadroxil',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFCARE 500 (Wanbury)'
);

-- line #5519
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFCARE 250 (Wanbury)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFCARE 250 (Wanbury)'
);

-- line #5520
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFCARE 125 (Wanbury)',
	'Cefadroxil',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFCARE 125 (Wanbury)'
);

-- line #5521
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFDIL 500 (Indu D.)',
	'Cefadroxil',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFDIL 500 (Indu D.)'
);

-- line #5522
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFDIL KID 125 (Indu D.)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFDIL KID 125 (Indu D.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFDIL KID 250 (Indu D.)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFDIL KID 250 (Indu D.)'
);

-- line #5523
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFDOX 500 (MILMET)',
	'Cefadroxil',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFDOX 500 (MILMET)'
);

-- line #5524
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFDOX 125 (MILMET)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFDOX 125 (MILMET)'
);

-- line #5525
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFDOX 125 (MILMET)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFDOX 125 (MILMET)'
);

-- line #5526
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFDOX 250 (MILMET)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFDOX 250 (MILMET)'
);

-- line #5527
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFDRONAT 125 (Natco Ph.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg(ANHYDR.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFDRONAT 125 (Natco Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFDRONAT 250 (Natco Ph.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg(ANHYDR.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFDRONAT 250 (Natco Ph.)'
);

-- line #5528
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFDRONAT 500 (Natco Ph.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg(ANHYDR.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFDRONAT 500 (Natco Ph.)'
);

-- line #5529
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFMAC 500 (Mcneil Ph.)',
	'Cefadroxil',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFMAC 500 (Mcneil Ph.)'
);

-- line #5530
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFNOR 125 (Norris Med.)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFNOR 125 (Norris Med.)'
);

-- line #5531
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFNOR 125 (Norris Med.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFNOR 125 (Norris Med.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFNOR 250 (Norris Med.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFNOR 250 (Norris Med.)'
);

-- line #5532
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFNOR 500 (Norris Med.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFNOR 500 (Norris Med.)'
);

-- line #5533
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFODRIL 500 (Pharma synth)',
	'Cefadroxil',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFODRIL 500 (Pharma synth)'
);

-- line #5534
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFODRIL 125 (Pharma synth)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFODRIL 125 (Pharma synth)'
);

-- line #5535
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFORAL 250 (Southsourne)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFORAL 250 (Southsourne)'
);

-- line #5536
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFORAL 500 (Southsourne)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFORAL 500 (Southsourne)'
);

-- line #5537
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOXID 100 (Bergen)',
	'Cefadroxil',
	'DPS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOXID 100 (Bergen)'
);

-- line #5538
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOXID 125 (Bergen)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOXID 125 (Bergen)'
);

-- line #5539
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOXID 250 (Bergen)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOXID 250 (Bergen)'
);

-- line #5540
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOXID 125 (Bergen)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOXID 125 (Bergen)'
);

-- line #5541
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOXID 250 (Bergen)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOXID 250 (Bergen)'
);

-- line #5542
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOXID 500 (Bergen)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOXID 500 (Bergen)'
);

-- line #5543
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOXIL-500 500 (Dynamic)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOXIL-500 500 (Dynamic)'
);

-- line #5544
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOXIL 125 (Bal Ph.)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOXIL 125 (Bal Ph.)'
);

-- line #5545
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOXIL 250 (Bal Ph.)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOXIL 250 (Bal Ph.)'
);

-- line #5546
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOXIL 125 (Bal Ph.)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOXIL 125 (Bal Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOXIL 250 (Bal Ph.)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOXIL 250 (Bal Ph.)'
);

-- line #5547
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOXIL 125 (Dynamic)',
	'Cefadroxil',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOXIL 125 (Dynamic)'
);

-- line #5548
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOXIL 125 (Dynamic)',
	'Cefadroxil',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOXIL 125 (Dynamic)'
);

-- line #5549
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOXIL-P 250 (Dynamic)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOXIL-P 250 (Dynamic)'
);

-- line #5550
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOXIL 125 (Dynamic)',
	'Cefadroxil',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOXIL 125 (Dynamic)'
);

-- line #5551
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOXIL 500 (Bal Ph.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOXIL 500 (Bal Ph.)'
);

-- line #5552
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTEK 125 (Zetek Ph.)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTEK 125 (Zetek Ph.)'
);

-- line #5553
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTEK 250 (Zetek Ph.)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTEK 250 (Zetek Ph.)'
);

-- line #5554
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTEK 500 (Zetek Ph.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTEK 500 (Zetek Ph.)'
);

-- line #5555
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTIC 250 (Yash Ph.)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTIC 250 (Yash Ph.)'
);

-- line #5556
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTIC 500 (Yash Ph.)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTIC 500 (Yash Ph.)'
);

-- line #5557
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTIC 125 (Yash Ph.)',
	'Cefadroxil',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTIC 125 (Yash Ph.)'
);

-- line #5558
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFWIN 125 (Ikon Rem)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFWIN 125 (Ikon Rem)'
);

-- line #5559
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFWIN 125 (Ikon Rem)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFWIN 125 (Ikon Rem)'
);

-- line #5560
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFWIN 250 (Ikon Rem)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFWIN 250 (Ikon Rem)'
);

-- line #5561
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFWIN 500 (Ikon Rem)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFWIN 500 (Ikon Rem)'
);

-- line #5562
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFWIN-P 100 (Ikon Rem)',
	'Cefadroxil',
	'DPS',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFWIN-P 100 (Ikon Rem)'
);

-- line #5563
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFZIL 125 (Lanark)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFZIL 125 (Lanark)'
);

-- line #5564
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFZIL 250 (Lanark)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFZIL 250 (Lanark)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFZIL 500 (Lanark)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFZIL 500 (Lanark)'
);

-- line #5565
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CENROXIL 125 (AIMCO PH.)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CENROXIL 125 (AIMCO PH.)'
);

-- line #5566
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CENROXIL 250 (AIMCO PH.)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CENROXIL 250 (AIMCO PH.)'
);

-- line #5567
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CENROXIL 125 (AIMCO PH.)',
	'Cefadroxil',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CENROXIL 125 (AIMCO PH.)'
);

-- line #5568
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CENROXIL 500 (AIMCO PH.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CENROXIL 500 (AIMCO PH.)'
);

-- line #5569
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEROXIL 125 (Medizone)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEROXIL 125 (Medizone)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEROXIL 500 (Medizone)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEROXIL 500 (Medizone)'
);

-- line #5570
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CERYL 250 (Cosmic Ph.)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CERYL 250 (Cosmic Ph.)'
);

-- line #5571
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CERYL 125 (Cosmic Ph.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CERYL 125 (Cosmic Ph.)'
);

-- line #5572
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CERYL 250 (Cosmic Ph.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CERYL 250 (Cosmic Ph.)'
);

-- line #5573
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CERYL 500 (Cosmic Ph.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CERYL 500 (Cosmic Ph.)'
);

-- line #5574
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETRON 125 (Cosme Hc.)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETRON 125 (Cosme Hc.)'
);

-- line #5575
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETRON 250 (Cosme Hc.)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETRON 250 (Cosme Hc.)'
);

-- line #5576
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETRON 500 (Cosme Hc.)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETRON 500 (Cosme Hc.)'
);

-- line #5577
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEXIL 125 (Franklin)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEXIL 125 (Franklin)'
);

-- line #5578
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEXIL 250 (Franklin)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEXIL 250 (Franklin)'
);

-- line #5579
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEXIL 125 (Leben)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEXIL 125 (Leben)'
);

-- line #5580
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEXIL 250 (Leben)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEXIL 250 (Leben)'
);

-- line #5581
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEXIL 250 (Franklin)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEXIL 250 (Franklin)'
);

-- line #5582
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEXIL 250 (Leben)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEXIL 250 (Leben)'
);

-- line #5583
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEXIL 125 (Leben)',
	'Cefadroxil',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEXIL 125 (Leben)'
);

-- line #5584
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEXIL 125 (Franklin)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEXIL 125 (Franklin)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEXIL 500 (Franklin)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEXIL 500 (Franklin)'
);

-- line #5585
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEXIL 500 (Leben)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEXIL 500 (Leben)'
);

-- line #5586
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIMDROX 250 (Dcm Lab)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIMDROX 250 (Dcm Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIMDROX 500 (Dcm Lab)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIMDROX 500 (Dcm Lab)'
);

-- line #5587
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CODROXIL 125 (Comed)',
	'Cefadroxil',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CODROXIL 125 (Comed)'
);

-- line #5588
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CODROXIL 1000 (Comed Chem.)',
	'Cefadroxil',
	'OD TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CODROXIL 1000 (Comed Chem.)'
);

-- line #5589
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CODROXIL 125 (Comed)',
	'Cefadroxil',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CODROXIL 125 (Comed)'
);

-- line #5590
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CODROXIL 250 (Comed)',
	'Cefadroxil',
	'SUS',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CODROXIL 250 (Comed)'
);

-- line #5591
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CODROXIL 250 (Comed)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CODROXIL 250 (Comed)'
);

-- line #5592
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CODROXIL 500 (Comed)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CODROXIL 500 (Comed)'
);

-- line #5593
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COSDROX 125 (Cosme Hc.)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COSDROX 125 (Cosme Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COSDROX 250 (Cosme Hc.)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COSDROX 250 (Cosme Hc.)'
);

-- line #5594
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COSDROX 500 (Cosme Hc.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COSDROX 500 (Cosme Hc.)'
);

-- line #5595
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COXIL 250 (Gcm Lab.)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COXIL 250 (Gcm Lab.)'
);

-- line #5596
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COXIL 500 (Gcm Lab.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COXIL 500 (Gcm Lab.)'
);

-- line #5597
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUDROX 250 (Elfin Ph.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUDROX 250 (Elfin Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUDROX 500 (Elfin Ph.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUDROX 500 (Elfin Ph.)'
);

-- line #5598
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYDROXIL 125 (Kentreck)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYDROXIL 125 (Kentreck)'
);

-- line #5599
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYDROXIL 250 (Kentreck)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYDROXIL 250 (Kentreck)'
);

-- line #5600
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYDROXIL 125 (Kentreck)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYDROXIL 125 (Kentreck)'
);

-- line #5601
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYDROXIL 250 (Kentreck)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYDROXIL 250 (Kentreck)'
);

-- line #5602
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYDROXIL 500 (Kentreck)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYDROXIL 500 (Kentreck)'
);

-- line #5603
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYDROX 250 (Calibar Ph.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYDROX 250 (Calibar Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYDROX 500 (Calibar Ph.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYDROX 500 (Calibar Ph.)'
);

-- line #5604
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYNOXIL 125 (Varun Life)',
	'Cefadroxil',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYNOXIL 125 (Varun Life)'
);

-- line #5605
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYNOXIL 125 (Varun Life)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYNOXIL 125 (Varun Life)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYNOXIL 250 (Varun Life)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYNOXIL 250 (Varun Life)'
);

-- line #5606
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYNOXIL 500 (Varun Life)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYNOXIL 500 (Varun Life)'
);

-- line #5607
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAX 125 (Dwd)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAX 125 (Dwd)'
);

-- line #5608
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAX 250 (Dwd)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAX 250 (Dwd)'
);

-- line #5609
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAX 125 (Dwd)',
	'Cefadroxil',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAX 125 (Dwd)'
);

-- line #5610
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAX 500 (Dwd)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAX 500 (Dwd)'
);

-- line #5611
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DELCEF 250 (SHREYA)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DELCEF 250 (SHREYA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DELCEF 500 (SHREYA)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DELCEF 500 (SHREYA)'
);

-- line #5612
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICEF 125 (Allure Rem.)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICEF 125 (Allure Rem.)'
);

-- line #5613
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICEF 250 (Allure Rem.)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICEF 250 (Allure Rem.)'
);

-- line #5614
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICEF 500 (Allure Rem.)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICEF 500 (Allure Rem.)'
);

-- line #5615
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROCIF 500 (Inj.Capta)',
	'Cefadroxil',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROCIF 500 (Inj.Capta)'
);

-- line #5616
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROCIF-D 125 (Inj.Capta)',
	'Cefadroxil',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROCIF-D 125 (Inj.Capta)'
);

-- line #5617
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROCIF 125 (Inj.Capta)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROCIF 125 (Inj.Capta)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROCIF 250 (Inj.Capta)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROCIF 250 (Inj.Capta)'
);

-- line #5618
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROFA 125 (VENSAT)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROFA 125 (VENSAT)'
);

-- line #5619
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROFA 250 (VENSAT)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROFA 250 (VENSAT)'
);

-- line #5620
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROFA 500 (VENSAT)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROFA 500 (VENSAT)'
);

-- line #5621
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROSEC-D 125 (Secure)',
	'Cefadroxil',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROSEC-D 125 (Secure)'
);

-- line #5622
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROSEC 125 (Secure)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg(ANHYD.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROSEC 125 (Secure)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROSEC 250 (Secure)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg(ANHYD.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROSEC 250 (Secure)'
);

-- line #5623
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROSEC 500 (Secure)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg(ANHYD.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROSEC 500 (Secure)'
);

-- line #5624
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROSOFT 250 (Soft Ph.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROSOFT 250 (Soft Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROSOFT 500 (Soft Ph.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROSOFT 500 (Soft Ph.)'
);

-- line #5625
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROXAL 250 (Arvind Lab.)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROXAL 250 (Arvind Lab.)'
);

-- line #5626
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROXAL 125 (Arvind Lab.)',
	'Cefadroxil',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROXAL 125 (Arvind Lab.)'
);

-- line #5627
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROXAL 125 (Arvind Lab.)',
	'Cefadroxil',
	'ORAL SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg;5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROXAL 125 (Arvind Lab.)'
);

-- line #5628
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROXAL 500 (Arvind Lab.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROXAL 500 (Arvind Lab.)'
);

-- line #5629
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROXBIT 250 (Cubit Hc.)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROXBIT 250 (Cubit Hc.)'
);

-- line #5630
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROXBIT 500 (Cubit Hc.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROXBIT 500 (Cubit Hc.)'
);

-- line #5631
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROXEL 125 (Esken)',
	'Cefadroxil',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROXEL 125 (Esken)'
);

-- line #5632
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROXEL 250 (Esken)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROXEL 250 (Esken)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROXEL 500 (Esken)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROXEL 500 (Esken)'
);

-- line #5633
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROXIB 125 (Aabtac Life)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROXIB 125 (Aabtac Life)'
);

-- line #5634
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROXIBID 250 (Hal)',
	'Cefadroxil',
	'KT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROXIBID 250 (Hal)'
);

-- line #5635
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROXIBID 500 (Hal)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROXIBID 500 (Hal)'
);

-- line #5636
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROXIB 250 (Aabtac Life)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROXIB 250 (Aabtac Life)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROXIB 500 (Aabtac Life)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROXIB 500 (Aabtac Life)'
);

-- line #5637
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROXIKAA 250 (Troikaa)',
	'Cefadroxil',
	'DT TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROXIKAA 250 (Troikaa)'
);

-- line #5638
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROXIKAA 500 (Troikaa)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROXIKAA 500 (Troikaa)'
);

-- line #5639
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROXILITE 125 (Elite Ph.)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROXILITE 125 (Elite Ph.)'
);

-- line #5640
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROXILITE 250 (Elite Ph.)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROXILITE 250 (Elite Ph.)'
);

-- line #5641
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROXILITE 500 (Elite Ph.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROXILITE 500 (Elite Ph.)'
);

-- line #5642
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROXIMIL 125 (Shaimil)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROXIMIL 125 (Shaimil)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROXIMIL 250 (Shaimil)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROXIMIL 250 (Shaimil)'
);

-- line #5643
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROXIMIL 500 (Shaimil)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROXIMIL 500 (Shaimil)'
);

-- line #5644
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROXITECH 125 (PHARMATECH)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROXITECH 125 (PHARMATECH)'
);

-- line #5645
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROXITECH 125 (PHARMATECH)',
	'Cefadroxil',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROXITECH 125 (PHARMATECH)'
);

-- line #5646
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROXITECH 250 (PHARMATECH)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROXITECH 250 (PHARMATECH)'
);

-- line #5647
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROXITECH 500 (PHARMATECH)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROXITECH 500 (PHARMATECH)'
);

-- line #5648
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROXTER 500 (ASTER PH.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROXTER 500 (ASTER PH.)'
);

-- line #5649
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROXUS 250 (Lexus)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROXUS 250 (Lexus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROXUS 500 (Lexus)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROXUS 500 (Lexus)'
);

-- line #5650
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROXYCAD 125 (Zydus Cadila)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROXYCAD 125 (Zydus Cadila)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROXYCAD 250 (Zydus Cadila)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROXYCAD 250 (Zydus Cadila)'
);

-- line #5651
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROXYCAD 500 (Zydus Cadila)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROXYCAD 500 (Zydus Cadila)'
);

-- line #5652
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROXYCEPH 500 (Orchid Hc.)',
	'Cefadroxil',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROXYCEPH 500 (Orchid Hc.)'
);

-- line #5653
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROXYCEPH 125 (Orchid Hc.)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROXYCEPH 125 (Orchid Hc.)'
);

-- line #5654
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROXYCEPH 250 (Orchid Hc.)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROXYCEPH 250 (Orchid Hc.)'
);

-- line #5655
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROXYKON 250 (Konark Bio.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROXYKON 250 (Konark Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROXYKON 500 (Konark Bio.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROXYKON 500 (Konark Bio.)'
);

-- line #5656
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROXYLAN 250 (Lan Ph.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROXYLAN 250 (Lan Ph.)'
);

-- line #5657
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROXYLAN 500 (Lan Ph.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROXYLAN 500 (Lan Ph.)'
);

-- line #5658
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROXYLA 250 (Jarson Ph.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROXYLA 250 (Jarson Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROXYLA 500 (Jarson Ph.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROXYLA 500 (Jarson Ph.)'
);

-- line #5659
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROXYL 125 (Torrent)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROXYL 125 (Torrent)'
);

-- line #5660
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROXYL 250 (Torrent)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROXYL 250 (Torrent)'
);

-- line #5661
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'125', u'strength_2': u'', u'substance': u'Cefadroxil', u'always_empty': u'', u'form': u'', u'brand': u'DROXYL INSTAUSE', u'strength_3': u'', u'company': u'Torrent', u'unit': u'mg'}

-- line #5662
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250', u'strength_2': u'', u'substance': u'Cefadroxil', u'always_empty': u'', u'form': u'', u'brand': u'DROXYL INSTAUSE', u'strength_3': u'', u'company': u'Torrent', u'unit': u'mg'}

-- line #5663
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROXYL 250 (Torrent)',
	'Cefadroxil',
	'SUS',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROXYL 250 (Torrent)'
);

-- line #5664
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROXYL 500 (Torrent)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROXYL 500 (Torrent)'
);

-- line #5665
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROXYMET 125 (Metrix Hc.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROXYMET 125 (Metrix Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROXYMET 500 (Metrix Hc.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROXYMET 500 (Metrix Hc.)'
);

-- line #5666
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROZIL 125 (Zee Lab)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROZIL 125 (Zee Lab)'
);

-- line #5667
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROZIL 250 (Zee Lab)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROZIL 250 (Zee Lab)'
);

-- line #5668
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROZIL 500 (Zee Lab)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROZIL 500 (Zee Lab)'
);

-- line #5669
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EDOXIL-D 125 (Eden Hc.)',
	'Cefadroxil',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EDOXIL-D 125 (Eden Hc.)'
);

-- line #5670
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EDOXIL 250 (Eden Hc.)',
	'Cefadroxil',
	'DT/500 TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EDOXIL 250 (Eden Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EDOXIL 500 (Eden Hc.)',
	'Cefadroxil',
	'DT/500 TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EDOXIL 500 (Eden Hc.)'
);

-- line #5671
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EDROXIL 100 (Ethilex Hc.)',
	'Cefadroxil',
	'DPS',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EDROXIL 100 (Ethilex Hc.)'
);

-- line #5672
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EDROXIL 125 (Ethilex Hc.)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EDROXIL 125 (Ethilex Hc.)'
);

-- line #5673
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EDROXIL 125 (Ethilex Hc.)',
	'Cefadroxil',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EDROXIL 125 (Ethilex Hc.)'
);

-- line #5674
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EDROXIL 250 (Ethilex Hc.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EDROXIL 250 (Ethilex Hc.)'
);

-- line #5675
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EDROXIL 500 (Ethilex Hc.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EDROXIL 500 (Ethilex Hc.)'
);

-- line #5676
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELDROXIL 125 (Elysium)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELDROXIL 125 (Elysium)'
);

-- line #5677
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELDROXIL 250 (Elysium)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELDROXIL 250 (Elysium)'
);

-- line #5678
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELDROXIL 250 (Elysium)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELDROXIL 250 (Elysium)'
);

-- line #5679
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELDROXIL 500 (Elysium)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELDROXIL 500 (Elysium)'
);

-- line #5680
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELIMINATE 125 (Zydus)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELIMINATE 125 (Zydus)'
);

-- line #5681
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELIMINATE 250 (Zydus)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELIMINATE 250 (Zydus)'
);

-- line #5682
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELIMINATE 125 (Zydus)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELIMINATE 125 (Zydus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELIMINATE 250 (Zydus)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELIMINATE 250 (Zydus)'
);

-- line #5683
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250', u'strength_2': u'', u'substance': u'Cefadroxil', u'always_empty': u'', u'form': u'', u'brand': u'ENACXIL', u'strength_3': u'', u'company': u'SHINCE PH.', u'unit': u'mg'}

-- line #5684
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500', u'strength_2': u'', u'substance': u'Cefadroxil', u'always_empty': u'', u'form': u'', u'brand': u'ENACXIL', u'strength_3': u'', u'company': u'SHINCE PH.', u'unit': u'mg'}

-- line #5685
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENOCEF 125 (Zenon Hc.)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENOCEF 125 (Zenon Hc.)'
);

-- line #5686
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENOCEF 250 (Zenon Hc.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENOCEF 250 (Zenon Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENOCEF 500 (Zenon Hc.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENOCEF 500 (Zenon Hc.)'
);

-- line #5687
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUDROX 125 (Euphoric)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUDROX 125 (Euphoric)'
);

-- line #5688
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUDROX 250 (Euphoric)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUDROX 250 (Euphoric)'
);

-- line #5689
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUDROX 500 (Euphoric)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUDROX 500 (Euphoric)'
);

-- line #5690
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FADROX 250 (Uniroyal)',
	'Cefadroxil',
	'DT/500 TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FADROX 250 (Uniroyal)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FADROX 500 (Uniroyal)',
	'Cefadroxil',
	'DT/500 TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FADROX 500 (Uniroyal)'
);

-- line #5691
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FADROXYL 250 (Dial Ph.)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FADROXYL 250 (Dial Ph.)'
);

-- line #5692
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FADROXYL 250 (Dial Ph.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FADROXYL 250 (Dial Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FADROXYL 500 (Dial Ph.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FADROXYL 500 (Dial Ph.)'
);

-- line #5693
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAXIL-D 125 (Lancer)',
	'Cefadroxil',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAXIL-D 125 (Lancer)'
);

-- line #5694
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAXIL 125 (Serve Ph.)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAXIL 125 (Serve Ph.)'
);

-- line #5695
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAXIL 250 (Serve Ph.)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAXIL 250 (Serve Ph.)'
);

-- line #5696
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAXIL 125 (Serve Ph.)',
	'Cefadroxil',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAXIL 125 (Serve Ph.)'
);

-- line #5697
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAXIL 125 (Lancer)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAXIL 125 (Lancer)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAXIL 250 (Lancer)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAXIL 250 (Lancer)'
);

-- line #5698
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAXIL 500 (Lancer)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAXIL 500 (Lancer)'
);

-- line #5699
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAXIL 500 (Serve Ph.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAXIL 500 (Serve Ph.)'
);

-- line #5700
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEXIL 125 (Lancer)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg(ANHY.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEXIL 125 (Lancer)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEXIL 250 (Lancer)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg(ANHY.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEXIL 250 (Lancer)'
);

-- line #5701
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEXIL 500 (Lancer)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg(ANHY.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEXIL 500 (Lancer)'
);

-- line #5702
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FROLIC 125 (Shinto Org.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FROLIC 125 (Shinto Org.)'
);

-- line #5703
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FROLIC 250 (Shinto Org.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FROLIC 250 (Shinto Org.)'
);

-- line #5704
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FROLIC 500 (Shinto Org.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FROLIC 500 (Shinto Org.)'
);

-- line #5705
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GIGACEF 125 (Aglowmed)',
	'Cefadroxil',
	'CAP',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GIGACEF 125 (Aglowmed)'
);

-- line #5706
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GIGACEF 250 (Aglowmed)',
	'Cefadroxil',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GIGACEF 250 (Aglowmed)'
);

-- line #5707
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GIGACEF 500 (Aglowmed)',
	'Cefadroxil',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GIGACEF 500 (Aglowmed)'
);

-- line #5708
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GIGACEF 125 (Aglowmed)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GIGACEF 125 (Aglowmed)'
);

-- line #5709
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GIGACEF-P 125 (Aglowmed)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'250'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GIGACEF-P 125 (Aglowmed)'
);

-- line #5710
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GIGACEF 500 (Aglowmed)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GIGACEF 500 (Aglowmed)'
);

-- line #5711
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIDROX 125 (Hygeia Ph.)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIDROX 125 (Hygeia Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIDROX 250 (Hygeia Ph.)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIDROX 250 (Hygeia Ph.)'
);

-- line #5712
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIDROX 500 (Hygeia Ph.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIDROX 500 (Hygeia Ph.)'
);

-- line #5713
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HINDROX 500 (Chemo D.)',
	'Cefadroxil',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HINDROX 500 (Chemo D.)'
);

-- line #5714
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HINDROX 125 (Chemo D.)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HINDROX 125 (Chemo D.)'
);

-- line #5715
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HINDROX 250 (Chemo D.)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HINDROX 250 (Chemo D.)'
);

-- line #5716
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYDROX 500 (Winsome Lab)',
	'Cefadroxil',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYDROX 500 (Winsome Lab)'
);

-- line #5717
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYDROX 125 (Winsome Lab)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYDROX 125 (Winsome Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYDROX 250 (Winsome Lab)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYDROX 250 (Winsome Lab)'
);

-- line #5718
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INOROX 125 (Lenit Ph.)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INOROX 125 (Lenit Ph.)'
);

-- line #5719
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INOROX 250 (Lenit Ph.)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INOROX 250 (Lenit Ph.)'
);

-- line #5720
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INOROX 500 (Lenit Ph.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INOROX 500 (Lenit Ph.)'
);

-- line #5721
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JYODOX 125 (Biocin Gen.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JYODOX 125 (Biocin Gen.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JYODOX 250 (Biocin Gen.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JYODOX 250 (Biocin Gen.)'
);

-- line #5722
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JYODOX 500 (Biocin Gen.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JYODOX 500 (Biocin Gen.)'
);

-- line #5723
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEDRIL 125 (Cadex Lab)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEDRIL 125 (Cadex Lab)'
);

-- line #5724
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEDRIL 250 (Cadex Lab)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEDRIL 250 (Cadex Lab)'
);

-- line #5725
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEDRIL 500 (Cadex Lab)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEDRIL 500 (Cadex Lab)'
);

-- line #5726
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEECEF 125 (Kee Ph.)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEECEF 125 (Kee Ph.)'
);

-- line #5727
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEECEF 250 (Kee Ph.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEECEF 250 (Kee Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEECEF 500 (Kee Ph.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEECEF 500 (Kee Ph.)'
);

-- line #5728
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFDIL 125 (Ajanta Ph.)',
	'Cefadroxil',
	'DT/250 TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFDIL 125 (Ajanta Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFDIL 250 (Ajanta Ph.)',
	'Cefadroxil',
	'DT/250 TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFDIL 250 (Ajanta Ph.)'
);

-- line #5729
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFDIL 500 (Ajanta Ph.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFDIL 500 (Ajanta Ph.)'
);

-- line #5730
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFDROXIL 125 (Regent)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFDROXIL 125 (Regent)'
);

-- line #5731
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFDROXIL 125 (Regent)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFDROXIL 125 (Regent)'
);

-- line #5732
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFDROXIL 250 (Regent)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFDROXIL 250 (Regent)'
);

-- line #5733
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFDROXIL 500 (Regent)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFDROXIL 500 (Regent)'
);

-- line #5734
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFEXYL 500 (TWILIGHT LIT.)',
	'Cefadroxil',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFEXYL 500 (TWILIGHT LIT.)'
);

-- line #5735
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFEXYL 125 (TWILIGHT LIT.)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFEXYL 125 (TWILIGHT LIT.)'
);

-- line #5736
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFEXYL 125 (TWILIGHT LIT.)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFEXYL 125 (TWILIGHT LIT.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFEXYL 250 (TWILIGHT LIT.)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFEXYL 250 (TWILIGHT LIT.)'
);

-- line #5737
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFLOXIN 500 (Rextar)',
	'Cefadroxil',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFLOXIN 500 (Rextar)'
);

-- line #5738
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFLOXIN 125 (Rextar)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFLOXIN 125 (Rextar)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFLOXIN 250 (Rextar)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFLOXIN 250 (Rextar)'
);

-- line #5739
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFLOXIN 125 (Rextar)',
	'Cefadroxil',
	'REDIMIX',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFLOXIN 125 (Rextar)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFLOXIN 250 (Rextar)',
	'Cefadroxil',
	'REDIMIX',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFLOXIN 250 (Rextar)'
);

-- line #5740
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFLOXIN 125 (Rextar)',
	'Cefadroxil',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFLOXIN 125 (Rextar)'
);

-- line #5741
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFZEN 125 (Indchemie)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFZEN 125 (Indchemie)'
);

-- line #5742
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFZEN 250 (Indchemie)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFZEN 250 (Indchemie)'
);

-- line #5743
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFZEN 500 (Indchemie)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFZEN 500 (Indchemie)'
);

-- line #5744
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KIDOXYL 100 (Rhombus)',
	'Cefadroxil',
	'DPS',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KIDOXYL 100 (Rhombus)'
);

-- line #5745
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KIDOXYL 125 (Rhombus)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KIDOXYL 125 (Rhombus)'
);

-- line #5746
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KIDOXYL 250 (Rhombus)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KIDOXYL 250 (Rhombus)'
);

-- line #5747
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KIDOXYL 125 (Rhombus)',
	'Cefadroxil',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KIDOXYL 125 (Rhombus)'
);

-- line #5748
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KIDOXYL 250 (Rhombus)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KIDOXYL 250 (Rhombus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KIDOXYL 500 (Rhombus)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KIDOXYL 500 (Rhombus)'
);

-- line #5749
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KIDROX 100 (Cadila New.)',
	'Cefadroxil',
	'DPS',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KIDROX 100 (Cadila New.)'
);

-- line #5750
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KIDROX 125 (Cadila New.)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KIDROX 125 (Cadila New.)'
);

-- line #5751
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KIDROX 250 (Cadila New.)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KIDROX 250 (Cadila New.)'
);

-- line #5752
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KIDROX 125 (Cadila New.)',
	'Cefadroxil',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KIDROX 125 (Cadila New.)'
);

-- line #5753
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KIDROX 250 (Cadila New.)',
	'Cefadroxil',
	'SUS',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KIDROX 250 (Cadila New.)'
);

-- line #5754
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KIMDROX 125 (Kim Lab)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KIMDROX 125 (Kim Lab)'
);

-- line #5755
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KIMDROX 250 (Kim Lab)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KIMDROX 250 (Kim Lab)'
);

-- line #5756
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KIMDROX 500 (Kim Lab)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KIMDROX 500 (Kim Lab)'
);

-- line #5757
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KODROX 125 (Beckcem)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KODROX 125 (Beckcem)'
);

-- line #5758
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KODROX 125 (Beckcem)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KODROX 125 (Beckcem)'
);

-- line #5759
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KODROX 250 (Beckcem)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KODROX 250 (Beckcem)'
);

-- line #5760
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KODROX 500 (Beckcem)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KODROX 500 (Beckcem)'
);

-- line #5761
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LACTOCEF 125 (Irm Ph.)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LACTOCEF 125 (Irm Ph.)'
);

-- line #5762
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LACTOCEF 125 (Irm Ph.)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LACTOCEF 125 (Irm Ph.)'
);

-- line #5763
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LACTOCEF 250 (Irm Ph.)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LACTOCEF 250 (Irm Ph.)'
);

-- line #5764
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LACTOCEF 500 (Irm Ph.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LACTOCEF 500 (Irm Ph.)'
);

-- line #5765
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LACTODROX 250 (Siesta)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LACTODROX 250 (Siesta)'
);

-- line #5766
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LACTODROX 500 (Siesta)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LACTODROX 500 (Siesta)'
);

-- line #5767
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LADROX 125 (Logos)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LADROX 125 (Logos)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LADROX 250 (Logos)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LADROX 250 (Logos)'
);

-- line #5768
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LADROX 500 (Logos)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LADROX 500 (Logos)'
);

-- line #5769
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LB DROX 125 (Laborate)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LB DROX 125 (Laborate)'
);

-- line #5770
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LB DROX 125 (Laborate)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LB DROX 125 (Laborate)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LB DROX 250 (Laborate)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LB DROX 250 (Laborate)'
);

-- line #5771
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LB DROX 500 (Laborate)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LB DROX 500 (Laborate)'
);

-- line #5772
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LC DROX 250 (Mars Rem.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LC DROX 250 (Mars Rem.)'
);

-- line #5773
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIFODROXIL 125 (Life Line)',
	'Cefadroxil',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIFODROXIL 125 (Life Line)'
);

-- line #5774
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIFODROXIL 250 (Life Line)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIFODROXIL 250 (Life Line)'
);

-- line #5775
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIFODROXIL 500 (Life Line)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIFODROXIL 500 (Life Line)'
);

-- line #5776
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYDROXIL 500 (HETERO HC.)',
	'Cefadroxil',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYDROXIL 500 (HETERO HC.)'
);

-- line #5777
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYDROXIL 250 (HETERO HC.)',
	'Cefadroxil',
	'KT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYDROXIL 250 (HETERO HC.)'
);

-- line #5778
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYDROXIL 125 (HETERO HC.)',
	'Cefadroxil',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYDROXIL 125 (HETERO HC.)'
);

-- line #5779
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALODROX 250 (Malody Hc.)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALODROX 250 (Malody Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALODROX 500 (Malody Hc.)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALODROX 500 (Malody Hc.)'
);

-- line #5780
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOXYL 125 (Maan)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOXYL 125 (Maan)'
);

-- line #5781
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOXYL 125 (Maan)',
	'Cefadroxil',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOXYL 125 (Maan)'
);

-- line #5782
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOXYL 250 (Maan)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOXYL 250 (Maan)'
);

-- line #5783
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOXYL 500 (Maan)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOXYL 500 (Maan)'
);

-- line #5784
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAPRADROX 250 (Mapra)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAPRADROX 250 (Mapra)'
);

-- line #5785
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAPRADROX 125 (Mapra)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAPRADROX 125 (Mapra)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAPRADROX 250 (Mapra)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAPRADROX 250 (Mapra)'
);

-- line #5786
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAPRADROX 500 (Mapra)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAPRADROX 500 (Mapra)'
);

-- line #5787
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAXCEF -F 250 (Maxcure)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAXCEF -F 250 (Maxcure)'
);

-- line #5788
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAXCEF 125 (Maxcure)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAXCEF 125 (Maxcure)'
);

-- line #5789
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'M-DROX 500 (Mercury Hc.)',
	'Cefadroxil',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'M-DROX 500 (Mercury Hc.)'
);

-- line #5790
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'M-DROX 125 (Mercury Hc.)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'M-DROX 125 (Mercury Hc.)'
);

-- line #5791
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'M-DROX 250 (Mercury Hc.)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'M-DROX 250 (Mercury Hc.)'
);

-- line #5792
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MECEF 125 (Merit Org.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MECEF 125 (Merit Org.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MECEF 250 (Merit Org.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MECEF 250 (Merit Org.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MECEF 500 (Merit Org.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MECEF 500 (Merit Org.)'
);

-- line #5793
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGADROX 125 (Skymax)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGADROX 125 (Skymax)'
);

-- line #5794
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGADROX 250 (Skymax)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGADROX 250 (Skymax)'
);

-- line #5795
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGADROX 250 (Maneesh)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGADROX 250 (Maneesh)'
);

-- line #5796
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGADROX 500 (Maneesh)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGADROX 500 (Maneesh)'
);

-- line #5797
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGADROX 500 (Skymax)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGADROX 500 (Skymax)'
);

-- line #5798
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEROX 250 (Medo Chem)',
	'Cefadroxil',
	'KID TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEROX 250 (Medo Chem)'
);

-- line #5799
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MODCEF 500 (Nicholas)',
	'Cefadroxil',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MODCEF 500 (Nicholas)'
);

-- line #5800
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MODCEF KT/250 125 (Nicholas)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MODCEF KT/250 125 (Nicholas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MODCEF KT/250 250 (Nicholas)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MODCEF KT/250 250 (Nicholas)'
);

-- line #5801
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONODROX 125 (Profic)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONODROX 125 (Profic)'
);

-- line #5802
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONODROX 250 (Profic)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONODROX 250 (Profic)'
);

-- line #5803
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONODROX 500 (Profic)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONODROX 500 (Profic)'
);

-- line #5804
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYDROX 250 (Radix Bio.)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYDROX 250 (Radix Bio.)'
);

-- line #5805
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEODROX 125 (Cipla)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEODROX 125 (Cipla)'
);

-- line #5806
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEODROX 250 (Cipla)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEODROX 250 (Cipla)'
);

-- line #5807
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEODROX 500 (Cipla)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEODROX 500 (Cipla)'
);

-- line #5808
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEPHLEX 125 (Neo Ph.)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEPHLEX 125 (Neo Ph.)'
);

-- line #5809
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEPHLEX 250 (Neo Ph.)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEPHLEX 250 (Neo Ph.)'
);

-- line #5810
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NESDROX 500 (Nestor)',
	'Cefadroxil',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NESDROX 500 (Nestor)'
);

-- line #5811
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NESDROX 125 (Nestor)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NESDROX 125 (Nestor)'
);

-- line #5812
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NESDROX 250 (Nestor)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NESDROX 250 (Nestor)'
);

-- line #5813
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NESDROX 125 (Nestor)',
	'Cefadroxil',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NESDROX 125 (Nestor)'
);

-- line #5814
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIOXYL 125 (Nibin Ph.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIOXYL 125 (Nibin Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIOXYL 250 (Nibin Ph.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIOXYL 250 (Nibin Ph.)'
);

-- line #5815
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIOXYL 500 (Nibin Ph.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIOXYL 500 (Nibin Ph.)'
);

-- line #5816
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVADROXIL 50 (Genova)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVADROXIL 50 (Genova)'
);

-- line #5817
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVADROXIL 125 (Genova)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVADROXIL 125 (Genova)'
);

-- line #5818
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVADROXIL 250 (Genova)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVADROXIL 250 (Genova)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVADROXIL 500 (Genova)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVADROXIL 500 (Genova)'
);

-- line #5819
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCOCEF 125 (Ochoa)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCOCEF 125 (Ochoa)'
);

-- line #5820
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCOCEF 250 (Ochoa)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCOCEF 250 (Ochoa)'
);

-- line #5821
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCOCEF 250 (Ochoa)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCOCEF 250 (Ochoa)'
);

-- line #5822
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCOCEF 500 (Ochoa)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCOCEF 500 (Ochoa)'
);

-- line #5823
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCOCEF 125 (Ochoa)',
	'Cefadroxil',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCOCEF 125 (Ochoa)'
);

-- line #5824
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODOXIL 250 (Lupin)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODOXIL 250 (Lupin)'
);

-- line #5825
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODOXIL 125 (Lupin)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODOXIL 125 (Lupin)'
);

-- line #5826
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODOXIL 250 (Lupin)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODOXIL 250 (Lupin)'
);

-- line #5827
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Cefadroxil', u'always_empty': u'', u'form': u'KID TAB', u'brand': u'ODOXIL', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #5828
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODOXIL 1000 (Lupin)',
	'Cefadroxil',
	'OD TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODOXIL 1000 (Lupin)'
);

-- line #5829
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250', u'strength_2': u'', u'substance': u'Cefadroxil', u'always_empty': u'', u'form': u'', u'brand': u'ODOXIL PREMIX DS-SYR', u'strength_3': u'', u'company': u'Lupin', u'unit': u'mg/5ML'}

-- line #5830
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODOXIL PREMIX 125 (Lupin)',
	'Cefadroxil',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODOXIL PREMIX 125 (Lupin)'
);

-- line #5831
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODOXIL 125 (Lupin)',
	'Cefadroxil',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODOXIL 125 (Lupin)'
);

-- line #5832
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODOXIL 250 (Lupin)',
	'Cefadroxil',
	'SUS',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODOXIL 250 (Lupin)'
);

-- line #5833
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODOXIL 500 (Lupin)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODOXIL 500 (Lupin)'
);

-- line #5834
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODUR 250 (Vivid Lab)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODUR 250 (Vivid Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODUR 500 (Vivid Lab)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODUR 500 (Vivid Lab)'
);

-- line #5835
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMIDROX 500 (Osper)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMIDROX 500 (Osper)'
);

-- line #5836
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORDAF 250 (Water Lilly)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORDAF 250 (Water Lilly)'
);

-- line #5837
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORDAF 500 (Water Lilly)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORDAF 500 (Water Lilly)'
);

-- line #5838
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORTOS 125 (Medicamen)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORTOS 125 (Medicamen)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORTOS 250 (Medicamen)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORTOS 250 (Medicamen)'
);

-- line #5839
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORTOS 500 (Medicamen)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORTOS 500 (Medicamen)'
);

-- line #5840
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Cefadroxil', u'always_empty': u'', u'form': u'D.SYR', u'brand': u'ORYDOXIL', u'strength_3': u'', u'company': u'Jrs Oryx.', u'unit': u''}

-- line #5841
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORYDOXIL 250 (Jrs Oryx.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORYDOXIL 250 (Jrs Oryx.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORYDOXIL 500 (Jrs Oryx.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORYDOXIL 500 (Jrs Oryx.)'
);

-- line #5842
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANDROX 125 (Kwik Hc.)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANDROX 125 (Kwik Hc.)'
);

-- line #5843
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANDROX 250 (Kwik Hc.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANDROX 250 (Kwik Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANDROX 500 (Kwik Hc.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANDROX 500 (Kwik Hc.)'
);

-- line #5844
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAROXIL 250 (Parasol)',
	'Cefadroxil',
	'DT/TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAROXIL 250 (Parasol)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAROXIL 500 (Parasol)',
	'Cefadroxil',
	'DT/TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAROXIL 500 (Parasol)'
);

-- line #5845
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAXYL 250 (Royal Lab)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAXYL 250 (Royal Lab)'
);

-- line #5846
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAXYL 250 (Royal Lab)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAXYL 250 (Royal Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAXYL 500 (Royal Lab)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAXYL 500 (Royal Lab)'
);

-- line #5847
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PD-ROXIL 500 (Parenteral)',
	'Cefadroxil',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PD-ROXIL 500 (Parenteral)'
);

-- line #5848
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PD-ROXIL 125 (Parenteral)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PD-ROXIL 125 (Parenteral)'
);

-- line #5849
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PD-ROXIL 250 (Parenteral)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PD-ROXIL 250 (Parenteral)'
);

-- line #5850
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENDROX 125 (intas)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENDROX 125 (intas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENDROX 250 (intas)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENDROX 250 (intas)'
);

-- line #5851
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENDROX 250 (Makers)',
	'Cefadroxil',
	'KT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENDROX 250 (Makers)'
);

-- line #5852
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENDROX 500 (intas)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENDROX 500 (intas)'
);

-- line #5853
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENDROX 500 (Makers)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENDROX 500 (Makers)'
);

-- line #5854
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENOXYL 250 (SAFE PH.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENOXYL 250 (SAFE PH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENOXYL 500 (SAFE PH.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENOXYL 500 (SAFE PH.)'
);

-- line #5855
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREXIL 125 (National)',
	'Cefadroxil',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREXIL 125 (National)'
);

-- line #5856
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREXIL 250 (National)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREXIL 250 (National)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREXIL 500 (National)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREXIL 500 (National)'
);

-- line #5857
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRODROX 125 (Perk Ph.)',
	'Cefadroxil',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRODROX 125 (Perk Ph.)'
);

-- line #5858
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRODROX 125 (Perk Ph.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRODROX 125 (Perk Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRODROX 250 (Perk Ph.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRODROX 250 (Perk Ph.)'
);

-- line #5859
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRODROX 500 (Perk Ph.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRODROX 500 (Perk Ph.)'
);

-- line #5860
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PUREDROX 250 (Maneesh)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PUREDROX 250 (Maneesh)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PUREDROX 500 (Maneesh)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PUREDROX 500 (Maneesh)'
);

-- line #5861
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYCEFF 125 (Pifer Ph.)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYCEFF 125 (Pifer Ph.)'
);

-- line #5862
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYCEFF 250 (Pifer Ph.)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYCEFF 250 (Pifer Ph.)'
);

-- line #5863
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYCEFF 125 (Pifer Ph.)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYCEFF 125 (Pifer Ph.)'
);

-- line #5864
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYCEFF 250 (Pifer Ph.)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYCEFF 250 (Pifer Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYCEFF 500 (Pifer Ph.)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYCEFF 500 (Pifer Ph.)'
);

-- line #5865
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QCEPH 500 (Emcure)',
	'Cefadroxil',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QCEPH 500 (Emcure)'
);

-- line #5866
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QCEPH 125 (Emcure)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QCEPH 125 (Emcure)'
);

-- line #5867
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QCEPH 250 (Emcure)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QCEPH 250 (Emcure)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QCEPH 500 (Emcure)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QCEPH 500 (Emcure)'
);

-- line #5868
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q CIDROX 250 (Que Ph.)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q CIDROX 250 (Que Ph.)'
);

-- line #5869
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q CIDROX 125 (Que Ph.)',
	'Cefadroxil',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q CIDROX 125 (Que Ph.)'
);

-- line #5870
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q CIDROX 500 (Que Ph.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q CIDROX 500 (Que Ph.)'
);

-- line #5871
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAPIDROX 250 (Biostrass)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAPIDROX 250 (Biostrass)'
);

-- line #5872
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAPIDROX 125 (Biostrass)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAPIDROX 125 (Biostrass)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAPIDROX 250 (Biostrass)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAPIDROX 250 (Biostrass)'
);

-- line #5873
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAPIDROX 500 (Biostrass)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAPIDROX 500 (Biostrass)'
);

-- line #5874
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAPIDROX 125 (Stanmark)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAPIDROX 125 (Stanmark)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAPIDROX 250 (Stanmark)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAPIDROX 250 (Stanmark)'
);

-- line #5875
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAPIDROX 500 (Stanmark)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAPIDROX 500 (Stanmark)'
);

-- line #5876
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELADROX 500 (Relax Ph.)',
	'Cefadroxil',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELADROX 500 (Relax Ph.)'
);

-- line #5877
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELADROX 125 (Relax Ph.)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELADROX 125 (Relax Ph.)'
);

-- line #5878
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELADROX 250 (Relax Ph.)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELADROX 250 (Relax Ph.)'
);

-- line #5879
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELADROX 125 (Relax Ph.)',
	'Cefadroxil',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELADROX 125 (Relax Ph.)'
);

-- line #5880
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REXIL 125 (Runa Ph.)',
	'Cefadroxil',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REXIL 125 (Runa Ph.)'
);

-- line #5881
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REXIL 250 (Runa Ph.)',
	'Cefadroxil',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REXIL 250 (Runa Ph.)'
);

-- line #5882
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REXIL 500 (Runa Ph.)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REXIL 500 (Runa Ph.)'
);

-- line #5883
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIDROX 125 (Reliance)',
	'Cefadroxil',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIDROX 125 (Reliance)'
);

-- line #5884
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIDROX 250 (Reliance)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIDROX 250 (Reliance)'
);

-- line #5885
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIDROX 500 (Reliance)',
	'Cefadroxil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIDROX 500 (Reliance)'
);

-- line #5886
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefazolin', u'always_empty': u'', u'form': u'INJ', u'brand': u'ALCIZON', u'strength_3': u'', u'company': u'Alembic', u'unit': u''}

-- line #5887
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALCIZON 250 (Alembic)',
	'Cefazolin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALCIZON 250 (Alembic)'
);

-- line #5888
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALCIZON 500 (Alembic)',
	'Cefazolin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALCIZON 500 (Alembic)'
);

-- line #5889
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZOLIN 500 (Biochem)',
	'Cefazolin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZOLIN 500 (Biochem)'
);

-- line #5890
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefazolin', u'always_empty': u'', u'form': u'VIAL', u'brand': u'AZOLIN', u'strength_3': u'', u'company': u'Biochem', u'unit': u''}

-- line #5891
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFADIN 125 (Neon)',
	'Cefazolin',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFADIN 125 (Neon)'
);

-- line #5892
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefazolin', u'always_empty': u'', u'form': u'INJ', u'brand': u'CEFADIN', u'strength_3': u'', u'company': u'Neon', u'unit': u''}

-- line #5893
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFADIN 250 (Neon)',
	'Cefazolin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFADIN 250 (Neon)'
);

-- line #5894
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFADIN 500 (Neon)',
	'Cefazolin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFADIN 500 (Neon)'
);

-- line #5895
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefazolin', u'always_empty': u'', u'form': u'INJ', u'brand': u'CEFAMEZIN', u'strength_3': u'', u'company': u'Shreya', u'unit': u''}

-- line #5896
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAMEZIN 250 (Shreya)',
	'Cefazolin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAMEZIN 250 (Shreya)'
);

-- line #5897
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAMEZIN 500 (Shreya)',
	'Cefazolin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAMEZIN 500 (Shreya)'
);

-- line #5898
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefazolin', u'always_empty': u'', u'form': u'INJ', u'brand': u'CEZOLIN', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #5899
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEZOLIN 250 (Lupin)',
	'Cefazolin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEZOLIN 250 (Lupin)'
);

-- line #5900
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEZOLIN 500 (Lupin)',
	'Cefazolin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEZOLIN 500 (Lupin)'
);

-- line #5901
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefazolin', u'always_empty': u'', u'form': u'INJ', u'brand': u'CIPRID', u'strength_3': u'', u'company': u'Neon', u'unit': u''}

-- line #5902
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPRID 250 (Neon)',
	'Cefazolin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPRID 250 (Neon)'
);

-- line #5903
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPRID 500 (Neon)',
	'Cefazolin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPRID 500 (Neon)'
);

-- line #5904
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYZOLIN 500 (HETERO HC.)',
	'Cefazolin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYZOLIN 500 (HETERO HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYZOLIN 1000 (HETERO HC.)',
	'Cefazolin',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYZOLIN 1000 (HETERO HC.)'
);

-- line #5905
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefazolin', u'always_empty': u'', u'form': u'VIAL', u'brand': u'ORIZOLIN', u'strength_3': u'', u'company': u'Zydus A.', u'unit': u''}

-- line #5906
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORIZOLIN 125 (Zydus A.)',
	'Cefazolin',
	'V',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORIZOLIN 125 (Zydus A.)'
);

-- line #5907
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORIZOLIN 250 (Zydus A.)',
	'Cefazolin',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORIZOLIN 250 (Zydus A.)'
);

-- line #5908
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORIZOLIN 500 (Zydus A.)',
	'Cefazolin',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORIZOLIN 500 (Zydus A.)'
);

-- line #5909
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefazolin', u'always_empty': u'', u'form': u'INJ', u'brand': u'OZOLIN', u'strength_3': u'', u'company': u'Osper', u'unit': u''}

-- line #5910
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OZOLIN 250 (Osper)',
	'Cefazolin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'500'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OZOLIN 250 (Osper)'
);

-- line #5911
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefazolin', u'always_empty': u'', u'form': u'INJ', u'brand': u'PRILEX', u'strength_3': u'', u'company': u'Hal', u'unit': u''}

-- line #5912
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRILEX 500 (Hal)',
	'Cefazolin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRILEX 500 (Hal)'
);

-- line #5913
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefazolin', u'always_empty': u'', u'form': u'V', u'brand': u'REFLIN', u'strength_3': u'', u'company': u'Ranbaxy', u'unit': u''}

-- line #5914
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REFLIN 250 (Ranbaxy)',
	'Cefazolin',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REFLIN 250 (Ranbaxy)'
);

-- line #5915
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REFLIN 500 (Ranbaxy)',
	'Cefazolin',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REFLIN 500 (Ranbaxy)'
);

-- line #5916
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADCEF 300 (Torrent)',
	'Cefdinir',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADCEF 300 (Torrent)'
);

-- line #5917
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADCEF 125 (Torrent)',
	'Cefdinir',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADCEF 125 (Torrent)'
);

-- line #5918
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'125', u'strength_2': u'', u'substance': u'Cefdinir', u'always_empty': u'', u'form': u'', u'brand': u'ADCEF INSTAUSE', u'strength_3': u'', u'company': u'TORRENT(PRIMA)', u'unit': u'mg/5ML'}

-- line #5919
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADCEF 125 (Torrent)',
	'Cefdinir',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADCEF 125 (Torrent)'
);

-- line #5920
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADINIR 300 (VENSAT)',
	'Cefdinir',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADINIR 300 (VENSAT)'
);

-- line #5921
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALDINIR 300 (Alembic)',
	'Cefdinir',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALDINIR 300 (Alembic)'
);

-- line #5922
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALDINIR 125 (Alembic)',
	'Cefdinir',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALDINIR 125 (Alembic)'
);

-- line #5923
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENIR 300 (Baroque)',
	'Cefdinir',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENIR 300 (Baroque)'
);

-- line #5924
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENIR 125 (Baroque)',
	'Cefdinir',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENIR 125 (Baroque)'
);

-- line #5925
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOCEF 300 (BIOCHEM)',
	'Cefdinir',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOCEF 300 (BIOCHEM)'
);

-- line #5926
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOCEF 125 (BIOCHEM)',
	'Cefdinir',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOCEF 125 (BIOCHEM)'
);

-- line #5927
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Cefdinir', u'always_empty': u'', u'form': u'SYR', u'brand': u'BIOKEF', u'strength_3': u'', u'company': u'Biochem', u'unit': u''}

-- line #5928
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEDNIR 300 (Nicholas)',
	'Cefdinir',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEDNIR 300 (Nicholas)'
);

-- line #5929
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFCAS 300 (CASCA)',
	'Cefdinir',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFCAS 300 (CASCA)'
);

-- line #5930
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFCY 125 (Solitaire)',
	'Cefdinir',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFCY 125 (Solitaire)'
);

-- line #5931
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFDIEL 300 (Ranbaxy)',
	'Cefdinir',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFDIEL 300 (Ranbaxy)'
);

-- line #5932
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFDIEL 125 (Ranbaxy)',
	'Cefdinir',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFDIEL 125 (Ranbaxy)'
);

-- line #5933
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFDIEL 125 (Ranbaxy)',
	'Cefdinir',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFDIEL 125 (Ranbaxy)'
);

-- line #5934
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFDIEL 250 (Ranbaxy)',
	'Cefdinir',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFDIEL 250 (Ranbaxy)'
);

-- line #5935
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefdinir', u'always_empty': u'', u'form': u'INJ', u'brand': u'CEFDIEL-I', u'strength_3': u'', u'company': u'Ranbaxy', u'unit': u''}

-- line #5936
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFDIEL-I 500 (Ranbaxy)',
	'Cefdinir',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFDIEL-I 500 (Ranbaxy)'
);

-- line #5937
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFDIEL 125 (Ranbaxy)',
	'Cefdinir',
	'REDIMIX',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFDIEL 125 (Ranbaxy)'
);

-- line #5938
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFDIEL 250 (Ranbaxy)',
	'Cefdinir',
	'SUS',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFDIEL 250 (Ranbaxy)'
);

-- line #5939
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFDIEL 125 (Ranbaxy)',
	'Cefdinir',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFDIEL 125 (Ranbaxy)'
);

-- line #5940
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFDIEL 300 (Ranbaxy)',
	'Cefdinir',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFDIEL 300 (Ranbaxy)'
);

-- line #5941
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFDIPAR 300 (Parenteral)',
	'Cefdinir',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFDIPAR 300 (Parenteral)'
);

-- line #5942
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFDNIR 300 (Nicholas)',
	'Cefdinir',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFDNIR 300 (Nicholas)'
);

-- line #5943
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFFIPAR 125 (Parenteral)',
	'Cefdinir',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFFIPAR 125 (Parenteral)'
);

-- line #5944
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IDINIR 125 (INVISION)',
	'Cefdinir',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IDINIR 125 (INVISION)'
);

-- line #5945
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IDINIR 300 (Intra(INVISION))',
	'Cefdinir',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IDINIR 300 (Intra(INVISION))'
);

-- line #5946
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFDURE 300 (Sanat)',
	'Cefdinir',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFDURE 300 (Sanat)'
);

-- line #5947
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFNIR 300 (Glenmark)',
	'Cefdinir',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFNIR 300 (Glenmark)'
);

-- line #5948
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFNIR 125 (Glenmark)',
	'Cefdinir',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFNIR 125 (Glenmark)'
);

-- line #5949
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAXICEF-O 300 (Aristo)',
	'Cefdinir',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAXICEF-O 300 (Aristo)'
);

-- line #5950
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAXICEF-O 125 (Aristo)',
	'Cefdinir',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAXICEF-O 125 (Aristo)'
);

-- line #5951
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCEPH 300 (Zuventus)',
	'Cefdinir',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCEPH 300 (Zuventus)'
);

-- line #5952
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCEPH 125 (Zuventus)',
	'Cefdinir',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCEPH 125 (Zuventus)'
);

-- line #5953
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROXECEF 30 (AUREUS)',
	'Cefdinir',
	'DT',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROXECEF 30 (AUREUS)'
);

-- line #5954
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROXECEF 50 (AUREUS)',
	'Cefdinir',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROXECEF 50 (AUREUS)'
);

-- line #5955
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALTORAN 200 (ALEMBIC)',
	'CEFDITOREN',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALTORAN 200 (ALEMBIC)'
);

-- line #5956
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFDICARE 200 (Meyer Org.)',
	'CEFDITOREN',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFDICARE 200 (Meyer Org.)'
);

-- line #5957
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFDITAS 200 (Intas)',
	'CEFDITOREN',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFDITAS 200 (Intas)'
);

-- line #5958
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFDITRAN 50 (Stancare)',
	'CEFDITOREN',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFDITRAN 50 (Stancare)'
);

-- line #5959
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFDITRAN 200 (Ranbaxy)',
	'CEFDITOREN',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFDITRAN 200 (Ranbaxy)'
);

-- line #5960
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTORIN 200 (Cipla)',
	'CEFDITOREN',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTORIN 200 (Cipla)'
);

-- line #5961
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROFEXECEF 400 (AUREUS)',
	'CEFDITOREN',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROFEXECEF 400 (AUREUS)'
);

-- line #5962
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROXECEF 200 (Ajanta Ph.)',
	'CEFDITOREN',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROXECEF 200 (Ajanta Ph.)'
);

-- line #5963
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefepime', u'always_empty': u'', u'form': u'VIAL', u'brand': u'ADPIME', u'strength_3': u'', u'company': u'Admac Ph.', u'unit': u''}

-- line #5964
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADPIME 250 (Admac Ph.)',
	'Cefepime',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADPIME 250 (Admac Ph.)'
);

-- line #5965
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'CEFEPIME', u'always_empty': u'', u'form': u'INJ', u'brand': u'BIOPIME', u'strength_3': u'', u'company': u'Biochem', u'unit': u''}

-- line #5966
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOPIME 250 (BIOCHEM)',
	'CEFEPIME',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOPIME 250 (BIOCHEM)'
);

-- line #5967
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOPIME 500 (Biochem)',
	'CEFEPIME',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOPIME 500 (Biochem)'
);

-- line #5968
-- ignoring line: field [strength_1] not numeric: >>>1G<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'250', u'substance': u'Cefepime', u'always_empty': u'', u'form': u'VIAL', u'brand': u'CADPIME', u'strength_3': u'', u'company': u'ADMAC(CADMA)', u'unit': u'mg'}

-- line #5969
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefepime', u'always_empty': u'', u'form': u'INJ', u'brand': u'CEFICAD', u'strength_3': u'', u'company': u'Cadila Ph.', u'unit': u''}

-- line #5970
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFICAD 500 (Cadila Ph.)',
	'Cefepime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFICAD 500 (Cadila Ph.)'
);

-- line #5971
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefepime', u'always_empty': u'', u'form': u'INJ', u'brand': u'CEFI-IV', u'strength_3': u'', u'company': u'Piramal Hc.', u'unit': u''}

-- line #5972
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFPIME 1000 (Global Med.)',
	'Cefepime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFPIME 1000 (Global Med.)'
);

-- line #5973
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFPIME 500 (Global Med.)',
	'Cefepime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFPIME 500 (Global Med.)'
);

-- line #5974
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFUDIX 1000 (Neon)',
	'Cefepime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFUDIX 1000 (Neon)'
);

-- line #5975
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFUDIX 500 (Neon)',
	'Cefepime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFUDIX 500 (Neon)'
);

-- line #5976
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefepime', u'always_empty': u'', u'form': u'INJ', u'brand': u'CELRIM', u'strength_3': u'', u'company': u'Biocon', u'unit': u''}

-- line #5977
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'CEFEPIME', u'always_empty': u'', u'form': u'VIAL', u'brand': u'CEPIME', u'strength_3': u'', u'company': u'Alembic', u'unit': u''}

-- line #5978
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPIME 250 (Alembic)',
	'CEFEPIME',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPIME 250 (Alembic)'
);

-- line #5979
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPIME 500 (Alembic)',
	'CEFEPIME',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPIME 500 (Alembic)'
);

-- line #5980
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefepime', u'always_empty': u'', u'form': u'VIAL', u'brand': u'CHASE', u'strength_3': u'', u'company': u'SHRESHTHA', u'unit': u''}

-- line #5981
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHASE 250 (SHRESHTHA)',
	'Cefepime',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHASE 250 (SHRESHTHA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHASE 500 (SHRESHTHA)',
	'Cefepime',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHASE 500 (SHRESHTHA)'
);

-- line #5982
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefepime', u'always_empty': u'', u'form': u'INJ', u'brand': u'C-PIME', u'strength_3': u'', u'company': u'Osper', u'unit': u''}

-- line #5983
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-PIME 250 (Osper)',
	'Cefepime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-PIME 250 (Osper)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-PIME 500 (Osper)',
	'Cefepime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-PIME 500 (Osper)'
);

-- line #5984
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMIPIME GM 1000 (Dominion)',
	'Cefepime',
	'VIAL',
	gm.nullify_empty_string('1000')::numeric,
	'mg(STERILE MODURE OF CEFEPIME HCL AND L-ARGININE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMIPIME GM 1000 (Dominion)'
);

-- line #5985
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMIPIME 250 (Dominion)',
	'Cefepime',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg(STERILE MODURE OF CEFEPIME HCL AND L-ARGININE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMIPIME 250 (Dominion)'
);

-- line #5986
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMIPIME 500 (Dominion)',
	'Cefepime',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg(STERILE MODURE OF CEFEPIME HCL AND L-ARGININE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMIPIME 500 (Dominion)'
);

-- line #5987
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EFEPIME 500 (MEDISYS)',
	'Cefepime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EFEPIME 500 (MEDISYS)'
);

-- line #5988
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefepime', u'always_empty': u'', u'form': u'INJ', u'brand': u'FORPAR', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #5989
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2G', u'strength_2': u'', u'substance': u'Cefepime', u'always_empty': u'', u'form': u'INJ', u'brand': u'FORPAR', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #5990
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORPAR 500 (Cipla)',
	'Cefepime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORPAR 500 (Cipla)'
);

-- line #5991
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'CEFEPIME', u'always_empty': u'', u'form': u'INJ', u'brand': u'INPIME', u'strength_3': u'', u'company': u'Profic', u'unit': u''}

-- line #5992
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INPIME 500 (Profic)',
	'CEFEPIME',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INPIME 500 (Profic)'
);

-- line #5993
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'CEFEPIME', u'always_empty': u'', u'form': u'VIAL', u'brand': u'IVIPIME', u'strength_3': u'', u'company': u'Vhb', u'unit': u''}

-- line #5994
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IVIPIME 500 (Vhb)',
	'CEFEPIME',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IVIPIME 500 (Vhb)'
);

-- line #5995
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2G', u'strength_2': u'', u'substance': u'Cefepime', u'always_empty': u'', u'form': u'INJ', u'brand': u'KEFAGE', u'strength_3': u'', u'company': u'Indchemie', u'unit': u''}

-- line #5996
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFAGE 500 (Indchemie)',
	'Cefepime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFAGE 500 (Indchemie)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFAGE 1000 (Indchemie)',
	'Cefepime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFAGE 1000 (Indchemie)'
);

-- line #5997
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G(ST.MIXTURE OF CEFEPIME HCL. AND L-ARGININE)', u'strength_2': u'', u'substance': u'Cefepime', u'always_empty': u'', u'form': u'VIAL', u'brand': u'KEPIME', u'strength_3': u'', u'company': u'HETERO HC.', u'unit': u''}

-- line #5998
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KINGCEF 1000 (Shreya)',
	'Cefepime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KINGCEF 1000 (Shreya)'
);

-- line #5999
-- ignoring line: field [strength_1] not numeric: >>>1G<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'250', u'substance': u'Cefepime', u'always_empty': u'', u'form': u'VIAL', u'brand': u'LEEPIME', u'strength_3': u'', u'company': u'ADMAC (LEE BENZ)', u'unit': u'mg'}

-- line #6000
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefepime', u'always_empty': u'', u'form': u'INJ', u'brand': u'MAGNOVA', u'strength_3': u'', u'company': u'LUPIN', u'unit': u''}

-- line #6001
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAGNOVA 500 (LUPIN)',
	'Cefepime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAGNOVA 500 (LUPIN)'
);

-- line #6002
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAPIME 1000 (Mapra)',
	'Cefepime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAPIME 1000 (Mapra)'
);

-- line #6003
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAPIME 250 (Mapra)',
	'Cefepime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAPIME 250 (Mapra)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAPIME 500 (Mapra)',
	'Cefepime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAPIME 500 (Mapra)'
);

-- line #6004
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAXICEF 500 (Aristo)',
	'CEFEPIME',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAXICEF 500 (Aristo)'
);

-- line #6005
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'CEFEPIME', u'always_empty': u'', u'form': u'VIAL', u'brand': u'MAXICEF', u'strength_3': u'', u'company': u'Aristo', u'unit': u''}

-- line #6006
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAXICEF 250 (Aristo)',
	'CEFEPIME',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAXICEF 250 (Aristo)'
);

-- line #6007
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefepime', u'always_empty': u'', u'form': u'VIAL', u'brand': u'MAXIPIME', u'strength_3': u'', u'company': u'BRISTOL MYERS', u'unit': u''}

-- line #6008
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAXOPIME 1000 (Parenteral)',
	'CEFEPIME',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAXOPIME 1000 (Parenteral)'
);

-- line #6009
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAXOPIME 500 (Parenteral)',
	'CEFEPIME',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAXOPIME 500 (Parenteral)'
);

-- line #6010
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGAPIME 250 (Alkem)',
	'Cefepime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGAPIME 250 (Alkem)'
);

-- line #6011
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGAPIME 500 (Alkem)',
	'Cefepime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGAPIME 500 (Alkem)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGAPIME 1000 (Alkem)',
	'Cefepime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGAPIME 1000 (Alkem)'
);

-- line #6012
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'CEFEPIME', u'always_empty': u'', u'form': u'INJ', u'brand': u'MICROPIME-G', u'strength_3': u'', u'company': u'MICRO LABS', u'unit': u''}

-- line #6013
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICROPIME 500 (MICRO LABS)',
	'CEFEPIME',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICROPIME 500 (MICRO LABS)'
);

-- line #6014
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITIPIME 1000 (Nitin Ph.)',
	'Cefepime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITIPIME 1000 (Nitin Ph.)'
);

-- line #6015
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefepime', u'always_empty': u'', u'form': u'INJ', u'brand': u'NOVAPIME', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #6016
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVAPIME 250 (Lupin)',
	'Cefepime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVAPIME 250 (Lupin)'
);

-- line #6017
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2G', u'strength_2': u'', u'substance': u'Cefepime', u'always_empty': u'', u'form': u'INJ', u'brand': u'NOVAPIME', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #6018
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVAPIME 500 (Lupin)',
	'Cefepime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVAPIME 500 (Lupin)'
);

-- line #6019
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefepime', u'always_empty': u'', u'form': u'INJ', u'brand': u'ORPIME', u'strength_3': u'', u'company': u'Orchid Hc.', u'unit': u''}

-- line #6020
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'CEFEPIME', u'always_empty': u'', u'form': u'INJ', u'brand': u'OXIROME', u'strength_3': u'', u'company': u'AXYZEN LIFE', u'unit': u''}

-- line #6021
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefepime', u'always_empty': u'', u'form': u'INJ', u'brand': u'PATRIAT', u'strength_3': u'', u'company': u'Ikon Rem', u'unit': u''}

-- line #6022
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIMACEF 250 (Intra Lab)',
	'Cefepime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIMACEF 250 (Intra Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIMACEF 500 (Intra Lab)',
	'Cefepime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIMACEF 500 (Intra Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIMACEF 1000 (Intra Lab)',
	'Cefepime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIMACEF 1000 (Intra Lab)'
);

-- line #6023
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'CEFEPIME', u'always_empty': u'', u'form': u'INJ', u'brand': u'PRYME', u'strength_3': u'', u'company': u'Cfl Ph.', u'unit': u''}

-- line #6024
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRYME 500 (Cfl Ph.)',
	'CEFEPIME',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRYME 500 (Cfl Ph.)'
);

-- line #6025
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefepime', u'always_empty': u'', u'form': u'VIAL', u'brand': u'RADIPIME', u'strength_3': u'', u'company': u'Radicura', u'unit': u''}

-- line #6026
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALTAMET 250 (Alembic)',
	'CEFETAMET PIVOXIL HCI.',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALTAMET 250 (Alembic)'
);

-- line #6027
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALTAMET 500 (Alembic)',
	'CEFETAMET PIVOXIL HCI.',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALTAMET 500 (Alembic)'
);

-- line #6028
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'CEFETAMET PIVOXIL HCI.', u'always_empty': u'', u'form': u'D.SYR', u'brand': u'CEPIME-O', u'strength_3': u'', u'company': u'Alembic', u'unit': u''}

-- line #6029
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPIME-O 100 (Alembic)',
	'CEFETAMET PIVOXIL HCI.',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPIME-O 100 (Alembic)'
);

-- line #6030
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPIME-O 200 (Alembic)',
	'CEFETAMET PIVOXIL HCI.',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPIME-O 200 (Alembic)'
);

-- line #6031
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPIME-O 250 (Alembic)',
	'CEFETAMET PIVOXIL HCI.',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPIME-O 250 (Alembic)'
);

-- line #6032
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPIME-O 500 (Alembic)',
	'CEFETAMET PIVOXIL HCI.',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPIME-O 500 (Alembic)'
);

-- line #6033
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'H-ROM 250 (ROSE LABS)',
	'CEFETAMET PIVOXIL HCI.',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'H-ROM 250 (ROSE LABS)'
);

-- line #6034
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KUZET 250 (HETERO HC.)',
	'CEFETAMET PIVOXIL HCI.',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KUZET 250 (HETERO HC.)'
);

-- line #6035
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KUZET 500 (HETERO HC.)',
	'CEFETAMET PIVOXIL HCI.',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KUZET 500 (HETERO HC.)'
);

-- line #6036
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRYZM 250 (UNICHEM)',
	'CEFETAMET PIVOXIL HCI.',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRYZM 250 (UNICHEM)'
);

-- line #6037
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRYZM 500 (UNICHEM)',
	'CEFETAMET PIVOXIL HCI.',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRYZM 500 (UNICHEM)'
);

-- line #6038
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RECOCEF 250 (Zydus Cadila)',
	'CEFETAMET',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RECOCEF 250 (Zydus Cadila)'
);

-- line #6039
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RECOCEF 500 (Zydus Cadila)',
	'CEFETAMET',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RECOCEF 500 (Zydus Cadila)'
);

-- line #6040
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'3A-XIM 200 (3A PHARMA.)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '3A-XIM 200 (3A PHARMA.)'
);

-- line #6041
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AB-CEF 100 (Bestochem)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AB-CEF 100 (Bestochem)'
);

-- line #6042
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ABCEF 100 (BESTOCHEM)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ABCEF 100 (BESTOCHEM)'
);

-- line #6043
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ABCEF 200 (BESTOCHEM)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ABCEF 200 (BESTOCHEM)'
);

-- line #6044
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AB-CEF 200 (Bestochem)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AB-CEF 200 (Bestochem)'
);

-- line #6045
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AC-FIX 100 (ABLAZE HC)',
	'Cefixime',
	'DT TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AC-FIX 100 (ABLAZE HC)'
);

-- line #6046
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AC-FIX 50 (ABLAZE HC)',
	'Cefixime',
	'DT TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AC-FIX 50 (ABLAZE HC)'
);

-- line #6047
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AC-FIX 200 (ABLAZE HC)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AC-FIX 200 (ABLAZE HC)'
);

-- line #6048
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACUFIX 100 (Macleods)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACUFIX 100 (Macleods)'
);

-- line #6049
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACUFIX 200 (Macleods)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACUFIX 200 (Macleods)'
);

-- line #6050
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACUFIX 50 (Macleods)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACUFIX 50 (Macleods)'
);

-- line #6051
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACUFIX 50 (Macleods)',
	'Cefixime',
	'ORAL SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACUFIX 50 (Macleods)'
);

-- line #6052
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACXIM 200 (APPLEDENT ORAL)',
	'CEFIxime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACXIM 200 (APPLEDENT ORAL)'
);

-- line #6053
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADDFIX 200 (ADDPLUS)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADDFIX 200 (ADDPLUS)'
);

-- line #6054
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AEROCEF 50 (AERO LIFE)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AEROCEF 50 (AERO LIFE)'
);

-- line #6055
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AEROCEF 100 (AERO LIFE)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AEROCEF 100 (AERO LIFE)'
);

-- line #6056
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AEROCEF 200 (AERO LIFE)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AEROCEF 200 (AERO LIFE)'
);

-- line #6057
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'12G', u'strength_2': u'30ML', u'substance': u'Cefixime', u'always_empty': u'', u'form': u'SUSP', u'brand': u'AFIXIM', u'strength_3': u'', u'company': u'ACTO', u'unit': u''}

-- line #6058
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AFIXIM 100 (ACTO)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AFIXIM 100 (ACTO)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AFIXIM 200 (ACTO)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AFIXIM 200 (ACTO)'
);

-- line #6059
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AFIX 200 (Alpic Bio.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AFIX 200 (Alpic Bio.)'
);

-- line #6060
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AFIX 50 (Alpic Bio.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AFIX 50 (Alpic Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AFIX 100 (Alpic Bio.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AFIX 100 (Alpic Bio.)'
);

-- line #6061
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALCEFT-O 200 (Alcare Lab.)',
	'Cefixime',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALCEFT-O 200 (Alcare Lab.)'
);

-- line #6062
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALCEFT-O 50 (Alcare Lab.)',
	'Cefixime',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALCEFT-O 50 (Alcare Lab.)'
);

-- line #6063
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALFI 100 (ACTON LIFE)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALFI 100 (ACTON LIFE)'
);

-- line #6064
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALFI 200 (ACTON LIFE)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALFI 200 (ACTON LIFE)'
);

-- line #6065
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALMOCEF 50 (GUJ. TE.)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALMOCEF 50 (GUJ. TE.)'
);

-- line #6066
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALMOCEF 100 (GUJ. TE.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'200'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALMOCEF 100 (GUJ. TE.)'
);

-- line #6067
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALMOCEF 50 (GUJ. TE.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALMOCEF 50 (GUJ. TE.)'
);

-- line #6068
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANAFIX 200 (ANABIOSIS)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANAFIX 200 (ANABIOSIS)'
);

-- line #6069
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANCEF-O 50 (Shrinivas)',
	'CEFIXIME',
	'D.SYRUP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANCEF-O 50 (Shrinivas)'
);

-- line #6070
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANCEF-O 100 (Shrinivas)',
	'CEFIXIME',
	'DT TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANCEF-O 100 (Shrinivas)'
);

-- line #6071
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AQCEF 200 (Aquila)',
	'Cefixime',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AQCEF 200 (Aquila)'
);

-- line #6072
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AQCEF 100 (Aquila)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AQCEF 100 (Aquila)'
);

-- line #6073
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARCEF 200 (Armour Rem.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARCEF 200 (Armour Rem.)'
);

-- line #6074
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'CEFIXIME', u'always_empty': u'', u'form': u'TAB', u'brand': u'ARICEF', u'strength_3': u'', u'company': u'ARIES MEDI.', u'unit': u''}

-- line #6075
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AROFIX 50 (ARLOP PH.)',
	'Cefixime',
	'D.SYRUP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AROFIX 50 (ARLOP PH.)'
);

-- line #6076
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AROFIX 200 (ARLOP PH.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AROFIX 200 (ARLOP PH.)'
);

-- line #6077
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AROXIM 50 (Aronex Life)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AROXIM 50 (Aronex Life)'
);

-- line #6078
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AROXIM 50 (Aronex Life)',
	'Cefixime',
	'DT TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AROXIM 50 (Aronex Life)'
);

-- line #6079
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AROXIM 100 (Aronex Life)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AROXIM 100 (Aronex Life)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AROXIM 200 (Aronex Life)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AROXIM 200 (Aronex Life)'
);

-- line #6080
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASERT 100 (Piramal Hc.)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASERT 100 (Piramal Hc.)'
);

-- line #6081
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASERT 200 (Piramal Hc.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASERT 200 (Piramal Hc.)'
);

-- line #6082
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Cefixime', u'always_empty': u'', u'form': u'D.SYR', u'brand': u'ASIFIN', u'strength_3': u'', u'company': u'Mefro Ph.', u'unit': u''}

-- line #6083
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASIFIN 100 (Mefro Ph.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASIFIN 100 (Mefro Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASIFIN 200 (Mefro Ph.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASIFIN 200 (Mefro Ph.)'
);

-- line #6084
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATOCEF 50 (Atoz Ph.)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATOCEF 50 (Atoz Ph.)'
);

-- line #6085
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATOCEF 100 (Atoz Ph.)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATOCEF 100 (Atoz Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATOCEF 200 (Atoz Ph.)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATOCEF 200 (Atoz Ph.)'
);

-- line #6086
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVCIF 50 (POSITIF(AFIVE))',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVCIF 50 (POSITIF(AFIVE))'
);

-- line #6087
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVCIF 100 (POSITIF(AFIVE))',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'200'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVCIF 100 (POSITIF(AFIVE))'
);

-- line #6088
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXICLAV 200 (AXIS LIFE)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXICLAV 200 (AXIS LIFE)'
);

-- line #6089
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXIM 10 (Kee Ph.)',
	'Cefixime',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXIM 10 (Kee Ph.)'
);

-- line #6090
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXIM 2 (Kee Ph.)',
	'Cefixime',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg.'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXIM 2 (Kee Ph.)'
);

-- line #6091
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXIM-O 200 (Kee Ph.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXIM-O 200 (Kee Ph.)'
);

-- line #6092
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXIM 100 (Lanark)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXIM 100 (Lanark)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXIM 200 (Lanark)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXIM 200 (Lanark)'
);

-- line #6093
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXIOM-OR 15 (Panjon)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('15')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXIOM-OR 15 (Panjon)'
);

-- line #6094
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXIOM-OR 100 (Panjon)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXIOM-OR 100 (Panjon)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXIOM-OR 200 (Panjon)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXIOM-OR 200 (Panjon)'
);

-- line #6095
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Cefixime', u'always_empty': u'', u'form': u'D.SYR', u'brand': u'AXYCEF', u'strength_3': u'', u'company': u'AXYZEN LIFE', u'unit': u''}

-- line #6096
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXYCEF 100 (AXYZEN LIFE)',
	'CEFIxime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXYCEF 100 (AXYZEN LIFE)'
);

-- line #6097
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXYCEF 200 (AXYZEN LIFE)',
	'CEFIxime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXYCEF 200 (AXYZEN LIFE)'
);

-- line #6098
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACSTAN 200 (AVIS LIFE)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACSTAN 200 (AVIS LIFE)'
);

-- line #6099
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BELFIX 50 (BLUBELL)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BELFIX 50 (BLUBELL)'
);

-- line #6100
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BELFIX 100 (BLUBELL)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'200'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BELFIX 100 (BLUBELL)'
);

-- line #6101
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENIXIM 50 (Baroque)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENIXIM 50 (Baroque)'
);

-- line #6102
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIENZE 200 (BIENSTAR)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIENZE 200 (BIENSTAR)'
);

-- line #6103
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIGXIME-O 50 (Helax Hc.)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIGXIME-O 50 (Helax Hc.)'
);

-- line #6104
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIGXIME 200 (Helax Hc.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIGXIME 200 (Helax Hc.)'
);

-- line #6105
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BILACTAM 100 (Cosme F.)',
	'Cefixime',
	'KID TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BILACTAM 100 (Cosme F.)'
);

-- line #6106
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIME 200 (ROSE LABS)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIME 200 (ROSE LABS)'
);

-- line #6107
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOFIX 200 (BIOGENESIS)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOFIX 200 (BIOGENESIS)'
);

-- line #6108
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOTAX-O 200 (Biochem)',
	'Cefixime',
	'CD TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOTAX-O 200 (Biochem)'
);

-- line #6109
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOTAX-O 50 (Biochem)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOTAX-O 50 (Biochem)'
);

-- line #6110
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOTAX-O 100 (Biochem)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOTAX-O 100 (Biochem)'
);

-- line #6111
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOTAX-O 50 (Biochem)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOTAX-O 50 (Biochem)'
);

-- line #6112
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOTAX-O 200 (Biochem)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOTAX-O 200 (Biochem)'
);

-- line #6113
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOXIME 100 (Biosmith)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOXIME 100 (Biosmith)'
);

-- line #6114
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOXIME 200 (Biosmith)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOXIME 200 (Biosmith)'
);

-- line #6115
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOXIM 100 (SANCHEZ LAB.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOXIM 100 (SANCHEZ LAB.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOXIM 200 (SANCHEZ LAB.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOXIM 200 (SANCHEZ LAB.)'
);

-- line #6116
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIXIGARD 100 (Biomax Lab)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIXIGARD 100 (Biomax Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIXIGARD 200 (Biomax Lab)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIXIGARD 200 (Biomax Lab)'
);

-- line #6117
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLUECEF-100 100 (BLUE WINGS)',
	'CEFIxime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLUECEF-100 100 (BLUE WINGS)'
);

-- line #6118
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLUECEF-200 200 (BLUE WINGS)',
	'CEFIxime',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLUECEF-200 200 (BLUE WINGS)'
);

-- line #6119
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BROCEF 200 (BIO-SWITZ)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BROCEF 200 (BIO-SWITZ)'
);

-- line #6120
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRUFIX 50 (Brawn Lab)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRUFIX 50 (Brawn Lab)'
);

-- line #6121
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRUFIX 200 (Brawn Lab)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRUFIX 200 (Brawn Lab)'
);

-- line #6122
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CACEFIX 5 (CAPIC LAB.)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CACEFIX 5 (CAPIC LAB.)'
);

-- line #6123
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARE 200 (SAACHI PH.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARE 200 (SAACHI PH.)'
);

-- line #6124
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CASXIM 100 (CASCA)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CASXIM 100 (CASCA)'
);

-- line #6125
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CASXIM 200 (CASCA)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CASXIM 200 (CASCA)'
);

-- line #6126
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEBAY 50 (Leben)',
	'Cefixime',
	'D.SYRUP',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEBAY 50 (Leben)'
);

-- line #6127
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEBAY 100 (Leben)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEBAY 100 (Leben)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEBAY 200 (Leben)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEBAY 200 (Leben)'
);

-- line #6128
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEBAY 50 (Leben)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEBAY 50 (Leben)'
);

-- line #6129
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEBAY 100 (Leben)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEBAY 100 (Leben)'
);

-- line #6130
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEBAY 50 (Leben)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEBAY 50 (Leben)'
);

-- line #6131
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEDRO 50 (Rekvina)',
	'Cefixime',
	'CF D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEDRO 50 (Rekvina)'
);

-- line #6132
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEDRO 100 (Rekvina)',
	'Cefixime',
	'CF TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEDRO 100 (Rekvina)'
);

-- line #6133
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEDRO 200 (Rekvina)',
	'Cefixime',
	'CF TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEDRO 200 (Rekvina)'
);

-- line #6134
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50', u'strength_2': u'', u'substance': u'CEFIXIME', u'always_empty': u'', u'form': u'', u'brand': u'CEEFIX D/S', u'strength_3': u'', u'company': u'Symbiosis Lab.', u'unit': u'mg/5ML'}

-- line #6135
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEEFIX 50 (Symbiosis Lab.)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEEFIX 50 (Symbiosis Lab.)'
);

-- line #6136
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEEMI 200 (Winsome Lab)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEEMI 200 (Winsome Lab)'
);

-- line #6137
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEEMI 50 (Winsome Lab)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEEMI 50 (Winsome Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEEMI 100 (Winsome Lab)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEEMI 100 (Winsome Lab)'
);

-- line #6138
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEEPIX 100 (Symbiosis Lab.)',
	'CEFIXIME',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEEPIX 100 (Symbiosis Lab.)'
);

-- line #6139
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200', u'strength_2': u'', u'substance': u'CEFIXIME', u'always_empty': u'', u'form': u'', u'brand': u'CEEPIX', u'strength_3': u'', u'company': u'Symbiosis Lab.', u'unit': u'mg'}

-- line #6140
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFADEN-O 50 (Eden Hc.)',
	'Cefixime',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFADEN-O 50 (Eden Hc.)'
);

-- line #6141
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFADEN-O 100 (Eden Hc.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFADEN-O 100 (Eden Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFADEN-O 200 (Eden Hc.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFADEN-O 200 (Eden Hc.)'
);

-- line #6142
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAL-O 100 (Mercury)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAL-O 100 (Mercury)'
);

-- line #6143
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAL-O 50 (Mercury)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAL-O 50 (Mercury)'
);

-- line #6144
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAL-O 100 (Mercury)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAL-O 100 (Mercury)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAL-O 200 (Mercury)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAL-O 200 (Mercury)'
);

-- line #6145
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAMAX 200 (Mercury Hc.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAMAX 200 (Mercury Hc.)'
);

-- line #6146
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAN 50 (Norris Med.)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAN 50 (Norris Med.)'
);

-- line #6147
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAN 200 (Norris Med.)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAN 200 (Norris Med.)'
);

-- line #6148
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAN 50 (Norris Med.)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAN 50 (Norris Med.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAN 100 (Norris Med.)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAN 100 (Norris Med.)'
);

-- line #6149
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFBID 200 (Sbeed Hc.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFBID 200 (Sbeed Hc.)'
);

-- line #6150
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFCON 200 (CONCERTINA)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFCON 200 (CONCERTINA)'
);

-- line #6151
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFCO 100 (Dynamic)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFCO 100 (Dynamic)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFCO 200 (Dynamic)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFCO 200 (Dynamic)'
);

-- line #6152
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFEX 50 (TALENT LAB.)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFEX 50 (TALENT LAB.)'
);

-- line #6153
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFEX 100 (TALENT LAB.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFEX 100 (TALENT LAB.)'
);

-- line #6154
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFEX 200 (TALENT LAB.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFEX 200 (TALENT LAB.)'
);

-- line #6155
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFEXY 50 (NEISS)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFEXY 50 (NEISS)'
);

-- line #6156
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFEXY 100 (NEISS)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFEXY 100 (NEISS)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFEXY 200 (NEISS)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFEXY 200 (NEISS)'
);

-- line #6157
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFFITER 200 (LACTARE PH.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFFITER 200 (LACTARE PH.)'
);

-- line #6158
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFGI-100 100 (AGISTA PH.)',
	'CEFIxime',
	'DT TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFGI-100 100 (AGISTA PH.)'
);

-- line #6159
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFGI-200 200 (AGISTA PH.)',
	'CEFIxime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFGI-200 200 (AGISTA PH.)'
);

-- line #6160
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFHEAL 100 (MEDHEAL PH.)',
	'CEFIxime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFHEAL 100 (MEDHEAL PH.)'
);

-- line #6161
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFHEAL 200 (MEDHEAL PH.)',
	'CEFIxime',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFHEAL 200 (MEDHEAL PH.)'
);

-- line #6162
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'30ML', u'strength_2': u'', u'substance': u'Cefixime', u'always_empty': u'', u'form': u'D.SYR', u'brand': u'CEFIACE', u'strength_3': u'', u'company': u'ACE LAB.', u'unit': u''}

-- line #6163
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFIACE 200 (ACE LAB.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFIACE 200 (ACE LAB.)'
);

-- line #6164
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFIANTE-KID 50 (CORE GESTRA)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFIANTE-KID 50 (CORE GESTRA)'
);

-- line #6165
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFIANTE 100 (CORE GESTRA)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'200'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFIANTE 100 (CORE GESTRA)'
);

-- line #6166
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFIA 100 (POSITIF(NUTRON))',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFIA 100 (POSITIF(NUTRON))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFIA 200 (POSITIF(NUTRON))',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFIA 200 (POSITIF(NUTRON))'
);

-- line #6167
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFIBEER 200 (ABEER PH.)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFIBEER 200 (ABEER PH.)'
);

-- line #6168
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFICACY 50 (Dallas Ph.)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFICACY 50 (Dallas Ph.)'
);

-- line #6169
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFICACY 100 (Dallas Ph.)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFICACY 100 (Dallas Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFICACY 200 (Dallas Ph.)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFICACY 200 (Dallas Ph.)'
);

-- line #6170
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFICAD-O 50 (Cadila)',
	'Cefixime',
	'D.SYRUP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFICAD-O 50 (Cadila)'
);

-- line #6171
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFICAD --O 200 (Cadila)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFICAD --O 200 (Cadila)'
);

-- line #6172
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFICAD-O 100 (Cadila)',
	'Cefixime',
	'DT TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFICAD-O 100 (Cadila)'
);

-- line #6173
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFICAN 200 (CAN HC.)',
	'CEFIxime',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFICAN 200 (CAN HC.)'
);

-- line #6174
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Cefixime', u'always_empty': u'', u'form': u'TAB', u'brand': u'CEFICA', u'strength_3': u'', u'company': u'NIVCA', u'unit': u''}

-- line #6175
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFICIN 100 (FLAMINGO PH.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFICIN 100 (FLAMINGO PH.)'
);

-- line #6176
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFICIN 200 (FLAMINGO PH.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFICIN 200 (FLAMINGO PH.)'
);

-- line #6177
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFICON 100 (Skymax)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFICON 100 (Skymax)'
);

-- line #6178
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFICON 200 (Skymax)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFICON 200 (Skymax)'
);

-- line #6179
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFICRAT 50 (CRATUS)',
	'Cefixime',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFICRAT 50 (CRATUS)'
);

-- line #6180
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFICRAT 100 (CRATUS)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFICRAT 100 (CRATUS)'
);

-- line #6181
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFICRAT 200 (CRATUS)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFICRAT 200 (CRATUS)'
);

-- line #6182
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFICUTE 200 (VIDACARE PH.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFICUTE 200 (VIDACARE PH.)'
);

-- line #6183
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFID-200 200 (DYNAMIC LC.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFID-200 200 (DYNAMIC LC.)'
);

-- line #6184
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFIDOC 50 (Hema Lab.)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFIDOC 50 (Hema Lab.)'
);

-- line #6185
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFIDOC 100 (Hema Lab.)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFIDOC 100 (Hema Lab.)'
);

-- line #6186
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFIDOC 200 (Hema Lab.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFIDOC 200 (Hema Lab.)'
);

-- line #6187
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFI 50 (Khandelwal)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFI 50 (Khandelwal)'
);

-- line #6188
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFIGARD 100 (VANGUARD)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFIGARD 100 (VANGUARD)'
);

-- line #6189
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFIGARD 200 (VANGUARD)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFIGARD 200 (VANGUARD)'
);

-- line #6190
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Cefixime', u'always_empty': u'', u'form': u'SYR', u'brand': u'CEFIGARD', u'strength_3': u'', u'company': u'VANGUARD', u'unit': u''}

-- line #6191
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFIGO 50 (LEO)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFIGO 50 (LEO)'
);

-- line #6192
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFIGO 100 (LEO)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFIGO 100 (LEO)'
);

-- line #6193
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFIGO 200 (LEO)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFIGO 200 (LEO)'
);

-- line #6194
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFIGO 50 (LEO)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFIGO 50 (LEO)'
);

-- line #6195
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFIGRAM 200 (UNITED LIFE)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFIGRAM 200 (UNITED LIFE)'
);

-- line #6196
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFIHEX 200 (HEXAL PH.)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFIHEX 200 (HEXAL PH.)'
);

-- line #6197
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Cefixime', u'always_empty': u'', u'form': u'INJ', u'brand': u'CEFI IV', u'strength_3': u'', u'company': u'Khandelwal', u'unit': u''}

-- line #6198
-- ignoring line: field [strength_1] not numeric: >>>1G<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'500', u'substance': u'Cefixime', u'always_empty': u'', u'form': u'VIAL', u'brand': u'CEFI-IV', u'strength_3': u'', u'company': u'Khandelwal', u'unit': u'mg'}

-- line #6199
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFIKAA 100 (Troikaa)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFIKAA 100 (Troikaa)'
);

-- line #6200
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFIKAA 200 (Troikaa)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFIKAA 200 (Troikaa)'
);

-- line #6201
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFILOT 200 (Zealot Biotech)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFILOT 200 (Zealot Biotech)'
);

-- line #6202
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFIMAX 100 (WELLMAX)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFIMAX 100 (WELLMAX)'
);

-- line #6203
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFIMAX 200 (WELLMAX)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFIMAX 200 (WELLMAX)'
);

-- line #6204
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFIM 100 (G.Nine Form.)',
	'Cefixime',
	'DT TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFIM 100 (G.Nine Form.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFIM 200 (G.Nine Form.)',
	'Cefixime',
	'DT TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFIM 200 (G.Nine Form.)'
);

-- line #6205
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFIMED 100 (Meridian)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFIMED 100 (Meridian)'
);

-- line #6206
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFIMED 200 (Meridian)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFIMED 200 (Meridian)'
);

-- line #6207
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFIME 100 (Uniroyal)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFIME 100 (Uniroyal)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFIME 200 (Uniroyal)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFIME 200 (Uniroyal)'
);

-- line #6208
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFIMIN 200 (PHARMIN)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFIMIN 200 (PHARMIN)'
);

-- line #6209
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFIMO 50 (PHARMATECH)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFIMO 50 (PHARMATECH)'
);

-- line #6210
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFINAR 100 (Zydus Cadila)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFINAR 100 (Zydus Cadila)'
);

-- line #6211
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFINAR 200 (Zydus Cadila)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFINAR 200 (Zydus Cadila)'
);

-- line #6212
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Cefixime', u'always_empty': u'', u'form': u'SYR', u'brand': u'CEFIND-D', u'strength_3': u'', u'company': u'Indu D.', u'unit': u''}

-- line #6213
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFIND 100 (Indu D.)',
	'Cefixime',
	'DT/ TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFIND 100 (Indu D.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFIND 200 (Indu D.)',
	'Cefixime',
	'DT/ TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFIND 200 (Indu D.)'
);

-- line #6214
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFINE-D 50 (Finecure)',
	'Cefixime',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFINE-D 50 (Finecure)'
);

-- line #6215
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFINE 100 (Finecure)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFINE 100 (Finecure)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFINE 200 (Finecure)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFINE 200 (Finecure)'
);

-- line #6216
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFINIDH 100 (NAVNIDHI LIFE)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFINIDH 100 (NAVNIDHI LIFE)'
);

-- line #6217
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFINIDH 200 (NAVNIDHI LIFE)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFINIDH 200 (NAVNIDHI LIFE)'
);

-- line #6218
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFINIX 100 (PHENIX PH.)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFINIX 100 (PHENIX PH.)'
);

-- line #6219
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFINIX 200 (PHENIX PH.)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFINIX 200 (PHENIX PH.)'
);

-- line #6220
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFINOZ 100 (INNOWAYZ PH.)',
	'CEFIxime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFINOZ 100 (INNOWAYZ PH.)'
);

-- line #6221
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFINOZ 200 (INNOWAYZ PH.)',
	'CEFIxime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFINOZ 200 (INNOWAYZ PH.)'
);

-- line #6222
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFI 400 (Khandelwal)',
	'Cefixime',
	'OD TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg(E.R.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFI 400 (Khandelwal)'
);

-- line #6223
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFI 50 (Piramal Hc.)',
	'Cefixime',
	'READYMIX',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFI 50 (Piramal Hc.)'
);

-- line #6224
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Cefixime', u'always_empty': u'', u'form': u'SYR', u'brand': u'CEFIRICH', u'strength_3': u'', u'company': u'Goodrich', u'unit': u''}

-- line #6225
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFIRICH 200 (Goodrich)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFIRICH 200 (Goodrich)'
);

-- line #6226
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFI 100 (Khandelwal)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFI 100 (Khandelwal)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFI 200 (Khandelwal)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFI 200 (Khandelwal)'
);

-- line #6227
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFI 100 (Khandelwal)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFI 100 (Khandelwal)'
);

-- line #6228
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFI 400 (Khandelwal)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFI 400 (Khandelwal)'
);

-- line #6229
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFI 50 (Khandelwal)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFI 50 (Khandelwal)'
);

-- line #6230
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFITAB 200 (SMENTAG PH.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFITAB 200 (SMENTAG PH.)'
);

-- line #6231
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFITAX 200 (Vega Lab)',
	'Cefixime',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFITAX 200 (Vega Lab)'
);

-- line #6232
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFITAX 50 (Vega Lab)',
	'Cefixime',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFITAX 50 (Vega Lab)'
);

-- line #6233
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFIT 50 (Cubit Hc.)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFIT 50 (Cubit Hc.)'
);

-- line #6234
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFIT 100 (Cubit Hc.)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFIT 100 (Cubit Hc.)'
);

-- line #6235
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFIT 200 (Cubit Hc.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFIT 200 (Cubit Hc.)'
);

-- line #6236
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFIVENT 100 (Atrimed Ph.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFIVENT 100 (Atrimed Ph.)'
);

-- line #6237
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFIVENT 200 (Atrimed Ph.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFIVENT 200 (Atrimed Ph.)'
);

-- line #6238
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFIWOK 100 (Wockhardt)',
	'Cefixime',
	'DT TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFIWOK 100 (Wockhardt)'
);

-- line #6239
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFIWOK 200 (Wockhardt)',
	'Cefixime',
	'DT TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFIWOK 200 (Wockhardt)'
);

-- line #6240
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFIWOK 50 (Wockhardt)',
	'Cefixime',
	'REDIMIX',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFIWOK 50 (Wockhardt)'
);

-- line #6241
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFIXAIN 100 (Sain Med.)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFIXAIN 100 (Sain Med.)'
);

-- line #6242
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFIXAIN 200 (Sain Med.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFIXAIN 200 (Sain Med.)'
);

-- line #6243
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFIX 50 (CIPLA)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFIX 50 (CIPLA)'
);

-- line #6244
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFIX 100 (CIPLA)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFIX 100 (CIPLA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFIX 200 (CIPLA)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFIX 200 (CIPLA)'
);

-- line #6245
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFIX 100 (Active Hc.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFIX 100 (Active Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFIX 200 (Active Hc.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFIX 200 (Active Hc.)'
);

-- line #6246
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100', u'strength_2': u'', u'substance': u'Cefixime', u'always_empty': u'', u'form': u'', u'brand': u'CEFIZI', u'strength_3': u'', u'company': u'AASHRAY', u'unit': u'mg'}

-- line #6247
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFIZI 200 (AASHRAY)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFIZI 200 (AASHRAY)'
);

-- line #6248
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFKO 200 (GEMASKO)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFKO 200 (GEMASKO)'
);

-- line #6249
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFKO 50 (GEMASKO)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFKO 50 (GEMASKO)'
);

-- line #6250
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFLA 100 (LA SERENA)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFLA 100 (LA SERENA)'
);

-- line #6251
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFLAND 100 (L & V PH.)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFLAND 100 (L & V PH.)'
);

-- line #6252
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFLAND 200 (L & V PH.)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFLAND 200 (L & V PH.)'
);

-- line #6253
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFLAND 50 (L & V PH.)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFLAND 50 (L & V PH.)'
);

-- line #6254
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFLUV 50 (Wisdom Ph.)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFLUV 50 (Wisdom Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFLUV 100 (Wisdom Ph.)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFLUV 100 (Wisdom Ph.)'
);

-- line #6255
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFLUV 50 (Wisdom Ph.)',
	'Cefixime',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFLUV 50 (Wisdom Ph.)'
);

-- line #6256
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFLUV 200 (Wisdom Ph.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFLUV 200 (Wisdom Ph.)'
);

-- line #6257
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFMA 100 (Medoz Ph.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFMA 100 (Medoz Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFMA 200 (Medoz Ph.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFMA 200 (Medoz Ph.)'
);

-- line #6258
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFMOST 100 (Torrent)',
	'CEFIXIme',
	'DT TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFMOST 100 (Torrent)'
);

-- line #6259
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFMOST 50 (Torrent)',
	'CEFIXIme',
	'DT TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFMOST 50 (Torrent)'
);

-- line #6260
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50', u'strength_2': u'', u'substance': u'Cefixime', u'always_empty': u'', u'form': u'', u'brand': u'CEFMOST INSTA-USE', u'strength_3': u'', u'company': u'Torrent', u'unit': u'mg'}

-- line #6261
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFMOST 200 (Torrent)',
	'CEFIXIme',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFMOST 200 (Torrent)'
);

-- line #6262
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFNIJ 100 (Sunij)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFNIJ 100 (Sunij)'
);

-- line #6263
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFNIJ 50 (Sunij)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFNIJ 50 (Sunij)'
);

-- line #6264
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFNIJ 200 (Sunij)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFNIJ 200 (Sunij)'
);

-- line #6265
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOCEF-0 100 (CENTAUR PH.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOCEF-0 100 (CENTAUR PH.)'
);

-- line #6266
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOCEF-0 200 (CENTAUR PH.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOCEF-0 200 (CENTAUR PH.)'
);

-- line #6267
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOCEF-0 50 (CENTAUR PH.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOCEF-0 50 (CENTAUR PH.)'
);

-- line #6268
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOCEF 100 (Centaur)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOCEF 100 (Centaur)'
);

-- line #6269
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOCEF 200 (Centaur)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOCEF 200 (Centaur)'
);

-- line #6270
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOLIN 50 (Stallion)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOLIN 50 (Stallion)'
);

-- line #6271
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOLIN 100 (Stallion)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOLIN 100 (Stallion)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOLIN 200 (Stallion)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOLIN 200 (Stallion)'
);

-- line #6272
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOMARC-O 100 (Marc Lab)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOMARC-O 100 (Marc Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOMARC-O 200 (Marc Lab)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOMARC-O 200 (Marc Lab)'
);

-- line #6273
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOMARC-O 50 (Marc Lab)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOMARC-O 50 (Marc Lab)'
);

-- line #6274
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFORGE 200 (FORGE PH.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFORGE 200 (FORGE PH.)'
);

-- line #6275
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFO 50 (Medley)',
	'Cefixime',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFO 50 (Medley)'
);

-- line #6276
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOX 50 (Health Care)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOX 50 (Health Care)'
);

-- line #6277
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOX-O 100 (Jackson)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOX-O 100 (Jackson)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOX-O 200 (Jackson)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOX-O 200 (Jackson)'
);

-- line #6278
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOX 100 (Health Care)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOX 100 (Health Care)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOX 200 (Health Care)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOX 200 (Health Care)'
);

-- line #6279
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOX 50 (Health Care)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOX 50 (Health Care)'
);

-- line #6280
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFPAR 200 (Parasol)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFPAR 200 (Parasol)'
);

-- line #6281
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEF-P 50 (Patson)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEF-P 50 (Patson)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEF-P 100 (Patson)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEF-P 100 (Patson)'
);

-- line #6282
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEF-P 200 (Patson)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEF-P 200 (Patson)'
);

-- line #6283
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFREE 100 (AUGMENT REM.)',
	'Cefixime',
	'DT TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFREE 100 (AUGMENT REM.)'
);

-- line #6284
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFREE 200 (AUGMENT REM.)',
	'Cefixime',
	'DT TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFREE 200 (AUGMENT REM.)'
);

-- line #6285
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFRUB 50 (Chemo D.)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFRUB 50 (Chemo D.)'
);

-- line #6286
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFRUB 200 (Chemo D.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFRUB 200 (Chemo D.)'
);

-- line #6287
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFSAN 200 (TUTTSAN PH.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFSAN 200 (TUTTSAN PH.)'
);

-- line #6288
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFSPAN 100 (Gsk)',
	'Cefixime',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFSPAN 100 (Gsk)'
);

-- line #6289
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFSPAN 200 (Gsk)',
	'Cefixime',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFSPAN 200 (Gsk)'
);

-- line #6290
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFSPAN 100 (Gsk)',
	'Cefixime',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFSPAN 100 (Gsk)'
);

-- line #6291
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFSTAT 100 (Kaiser Ph.)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFSTAT 100 (Kaiser Ph.)'
);

-- line #6292
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFSTAT 200 (Kaiser Ph.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFSTAT 200 (Kaiser Ph.)'
);

-- line #6293
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTAS 50 (Intas)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTAS 50 (Intas)'
);

-- line #6294
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTAS 100 (Intas)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTAS 100 (Intas)'
);

-- line #6295
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTAS 200 (Intas)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTAS 200 (Intas)'
);

-- line #6296
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTAS 400 (Intas)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTAS 400 (Intas)'
);

-- line #6297
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTIWIN 100 (Parenteral)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTIWIN 100 (Parenteral)'
);

-- line #6298
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTIWIN 200 (Parenteral)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTIWIN 200 (Parenteral)'
);

-- line #6299
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Cefixime', u'always_empty': u'', u'form': u'DT TAB', u'brand': u'CEFTUS', u'strength_3': u'', u'company': u'DEXTUS LC.', u'unit': u''}

-- line #6300
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Cefixime', u'always_empty': u'', u'form': u'TAB', u'brand': u'CEFTUS', u'strength_3': u'', u'company': u'DEXTUS LC.', u'unit': u''}

-- line #6301
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFUP 100 (Sanat)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFUP 100 (Sanat)'
);

-- line #6302
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFUP 200 (Sanat)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFUP 200 (Sanat)'
);

-- line #6303
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'12G', u'strength_2': u'30ML', u'substance': u'Cefixime', u'always_empty': u'', u'form': u'D.SYR', u'brand': u'CEFWOM', u'strength_3': u'', u'company': u'WOMB LAB.', u'unit': u''}

-- line #6304
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFWOM 200 (WOMB LAB.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFWOM 200 (WOMB LAB.)'
);

-- line #6305
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFXI-O 50 (SINKHAI)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFXI-O 50 (SINKHAI)'
);

-- line #6306
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFXI-O 50 (SINKHAI)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFXI-O 50 (SINKHAI)'
);

-- line #6307
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFYGEN 200 (BIOGEN PH.)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFYGEN 200 (BIOGEN PH.)'
);

-- line #6308
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFZIM 200 (ARCUS LABS)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFZIM 200 (ARCUS LABS)'
);

-- line #6309
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEIM-D 125 (Jrs Oryx.)',
	'Cefixime',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEIM-D 125 (Jrs Oryx.)'
);

-- line #6310
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEIM 200 (Jrs Oryx.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEIM 200 (Jrs Oryx.)'
);

-- line #6311
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELECT 200 (GALLICA PH.)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELECT 200 (GALLICA PH.)'
);

-- line #6312
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELITOL 50 (Elder)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELITOL 50 (Elder)'
);

-- line #6313
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELITOL 50 (Elder)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELITOL 50 (Elder)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELITOL 100 (Elder)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELITOL 100 (Elder)'
);

-- line #6314
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEMAXIN 50 (MOLEKULE)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEMAXIN 50 (MOLEKULE)'
);

-- line #6315
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEMAXIN 50 (MOLEKULE)',
	'CEFIxime',
	'DT TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEMAXIN 50 (MOLEKULE)'
);

-- line #6316
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEMAXIN 100 (MOLEKULE)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEMAXIN 100 (MOLEKULE)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEMAXIN 200 (MOLEKULE)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEMAXIN 200 (MOLEKULE)'
);

-- line #6317
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEMAX-O 100 (Wanbury)',
	'Cefixime',
	'DT/200 TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEMAX-O 100 (Wanbury)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEMAX-O 200 (Wanbury)',
	'Cefixime',
	'DT/200 TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEMAX-O 200 (Wanbury)'
);

-- line #6318
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEMAX-O 50 (Wanbury)',
	'Cefixime',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEMAX-O 50 (Wanbury)'
);

-- line #6319
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEME 100 (Ritz Ph.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEME 100 (Ritz Ph.)'
);

-- line #6320
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEME 200 (Ritz Ph.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEME 200 (Ritz Ph.)'
);

-- line #6321
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEO 100 (Prisma Hc.)',
	'Cefixime',
	'DT/200TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEO 100 (Prisma Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEO 200 (Prisma Hc.)',
	'Cefixime',
	'DT/200TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEO 200 (Prisma Hc.)'
);

-- line #6322
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200', u'strength_2': u'', u'substance': u'Cefixime', u'always_empty': u'', u'form': u'', u'brand': u'CEVICIM-200', u'strength_3': u'', u'company': u'SHINCE PH.', u'unit': u'mg'}

-- line #6323
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEVICIM 50 (SHINCE)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEVICIM 50 (SHINCE)'
);

-- line #6324
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEVICIM 50 (SHINCE PH.)',
	'CEFIxime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEVICIM 50 (SHINCE PH.)'
);

-- line #6325
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEVICIM 50 (SHINCE)',
	'Cefixime',
	'DT TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEVICIM 50 (SHINCE)'
);

-- line #6326
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEVICIM 100 (SHINCE)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEVICIM 100 (SHINCE)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEVICIM 200 (SHINCE)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEVICIM 200 (SHINCE)'
);

-- line #6327
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEXIM 100 (D.R.John''S)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEXIM 100 (D.R.John''S)'
);

-- line #6328
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEZEN 100 (Zenith Hc.)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEZEN 100 (Zenith Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEZEN 200 (Zenith Hc.)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEZEN 200 (Zenith Hc.)'
);

-- line #6329
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CF-100/200 100 (Allure Rem.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CF-100/200 100 (Allure Rem.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CF-100/200 200 (Allure Rem.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CF-100/200 200 (Allure Rem.)'
);

-- line #6330
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-FIX 50 (Corona)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-FIX 50 (Corona)'
);

-- line #6331
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-FIX 100 (Corona)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-FIX 100 (Corona)'
);

-- line #6332
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-FIX 200 (Corona)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-FIX 200 (Corona)'
);

-- line #6333
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CFM 200 (EAST WEST)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CFM 200 (EAST WEST)'
);

-- line #6334
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CFM 50 (EAST WEST)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CFM 50 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CFM 100 (EAST WEST)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CFM 100 (EAST WEST)'
);

-- line #6335
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CFX 50 (Skymax)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CFX 50 (Skymax)'
);

-- line #6336
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CFX 100 (SKYMAX LIFE)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CFX 100 (SKYMAX LIFE)'
);

-- line #6337
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CFX 100 (SHRI SWAMI)',
	'Cefixime',
	'DT TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CFX 100 (SHRI SWAMI)'
);

-- line #6338
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Cefixime', u'always_empty': u'', u'form': u'SYR', u'brand': u'CF-XIM', u'strength_3': u'', u'company': u'Indica', u'unit': u''}

-- line #6339
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CF-XIM 200 (Indica)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CF-XIM 200 (Indica)'
);

-- line #6340
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CFX-KID 50 (SKYMAX LIFE)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CFX-KID 50 (SKYMAX LIFE)'
);

-- line #6341
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CFX 100 (Pulse Ph.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CFX 100 (Pulse Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CFX 200 (Pulse Ph.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CFX 200 (Pulse Ph.)'
);

-- line #6342
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CFX 200 (SHRI SWAMI)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CFX 200 (SHRI SWAMI)'
);

-- line #6343
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CFX 200 (Skymax)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CFX 200 (Skymax)'
);

-- line #6344
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHEF 50 (Salvo Hc.)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHEF 50 (Salvo Hc.)'
);

-- line #6345
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHEF 100 (SALVO HC.)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHEF 100 (SALVO HC.)'
);

-- line #6346
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHEF 200 (Salvo Hc.)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHEF 200 (Salvo Hc.)'
);

-- line #6347
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'CEfixime', u'always_empty': u'', u'form': u'SYP', u'brand': u'CIFANSH DRY', u'strength_3': u'', u'company': u'CIVANSH LIFESCI.', u'unit': u''}

-- line #6348
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIFANSH 100 (CIVANSH LIFESCI.)',
	'CEfixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIFANSH 100 (CIVANSH LIFESCI.)'
);

-- line #6349
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIFANSH 200 (CIVANSH LIFESCI.)',
	'CEfixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIFANSH 200 (CIVANSH LIFESCI.)'
);

-- line #6350
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIFGEN 200 (GENESIS)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIFGEN 200 (GENESIS)'
);

-- line #6351
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIFINEX 200 (Nexus)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIFINEX 200 (Nexus)'
);

-- line #6352
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIFIVAR 50 (ZOTA)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIFIVAR 50 (ZOTA)'
);

-- line #6353
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIFIXIL 100 (HEXIL LIFE)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIFIXIL 100 (HEXIL LIFE)'
);

-- line #6354
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIFOTREX 200 (Biocare Rem.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIFOTREX 200 (Biocare Rem.)'
);

-- line #6355
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIXER 50 (AERO-CHEM)',
	'Cefixime',
	'DS',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIXER 50 (AERO-CHEM)'
);

-- line #6356
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIXER 100 (AERO-CHEM)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIXER 100 (AERO-CHEM)'
);

-- line #6357
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIXER 200 (AERO-CHEM)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIXER 200 (AERO-CHEM)'
);

-- line #6358
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIXIME 200 (Arvind Lab.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIXIME 200 (Arvind Lab.)'
);

-- line #6359
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLAFERON-O 200 (Sanofi Aventis)',
	'Cefixime',
	'SUSP',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLAFERON-O 200 (Sanofi Aventis)'
);

-- line #6360
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLAFERON-O 200 (Sanofi Aventis)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLAFERON-O 200 (Sanofi Aventis)'
);

-- line #6361
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLAFORAN-O 50 (Aventis)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLAFORAN-O 50 (Aventis)'
);

-- line #6362
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLAFORAN OT 200 (Aventis)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLAFORAN OT 200 (Aventis)'
);

-- line #6363
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLEARCEF 100 (Glister Hc.)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLEARCEF 100 (Glister Hc.)'
);

-- line #6364
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLEARCEF 200 (Glister Hc.)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLEARCEF 200 (Glister Hc.)'
);

-- line #6365
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLEONN 200 (D & D PH.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLEONN 200 (D & D PH.)'
);

-- line #6366
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-MAX 50 (PARAMOUNT HC.)',
	'Cefixime',
	'D.SYRUP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-MAX 50 (PARAMOUNT HC.)'
);

-- line #6367
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-MAX 200 (PARAMOUNT HC.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-MAX 200 (PARAMOUNT HC.)'
);

-- line #6368
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-TAX-O 25 (Zuventus)',
	'Cefixime',
	'DPS',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-TAX-O 25 (Zuventus)'
);

-- line #6369
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-TAX-O 50 (Zuventus)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-TAX-O 50 (Zuventus)'
);

-- line #6370
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-TAX-O 100 (Zuventus)',
	'Cefixime',
	'F. D.SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-TAX-O 100 (Zuventus)'
);

-- line #6371
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-TAX-O 200 (Zuventus)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-TAX-O 200 (Zuventus)'
);

-- line #6372
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-TAX-O 50 (Zuventus)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'100'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-TAX-O 50 (Zuventus)'
);

-- line #6373
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-TAX-P 50 (Emcure)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-TAX-P 50 (Emcure)'
);

-- line #6374
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-TAX 400 (Zuventus)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-TAX 400 (Zuventus)'
);

-- line #6375
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-TAX -T 100 (Emcure)',
	'Cefixime',
	'KT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-TAX -T 100 (Emcure)'
);

-- line #6376
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-TAX-T 100 (Emcure)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-TAX-T 100 (Emcure)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-TAX-T 200 (Emcure)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-TAX-T 200 (Emcure)'
);

-- line #6377
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-TAX -T 100 (Emcure)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-TAX -T 100 (Emcure)'
);

-- line #6378
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-TAX -T 200 (Emcure)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-TAX -T 200 (Emcure)'
);

-- line #6379
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUFIX 50 (Curex)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUFIX 50 (Curex)'
);

-- line #6380
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAFIXIM 200 (DAVIDSON BROCKS)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAFIXIM 200 (DAVIDSON BROCKS)'
);

-- line #6381
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEFENDER 100 (Skymax)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEFENDER 100 (Skymax)'
);

-- line #6382
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEFENDER 200 (Skymax)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEFENDER 200 (Skymax)'
);

-- line #6383
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DELBI 50 (VERITAZ)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DELBI 50 (VERITAZ)'
);

-- line #6384
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DELBI 200 (VERITAZ)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DELBI 200 (VERITAZ)'
);

-- line #6385
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DESATAX-O 100 (SHREYA)',
	'Cefixime',
	'DT/TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DESATAX-O 100 (SHREYA)'
);

-- line #6386
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DESATAX-O 200 (SHREYA)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DESATAX-O 200 (SHREYA)'
);

-- line #6387
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEXIM-O 50 (Jarson Ph.)',
	'Cefixime',
	'KID TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEXIM-O 50 (Jarson Ph.)'
);

-- line #6388
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEXIM-O 100 (Jarson Ph.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEXIM-O 100 (Jarson Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEXIM-O 200 (Jarson Ph.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEXIM-O 200 (Jarson Ph.)'
);

-- line #6389
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ECEF 200 (ECON HC.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ECEF 200 (ECON HC.)'
);

-- line #6390
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EFELAC 100 (Jenburkt)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EFELAC 100 (Jenburkt)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EFELAC 200 (Jenburkt)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EFELAC 200 (Jenburkt)'
);

-- line #6391
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'E-FIX 50 (MARLINE BIO.)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'E-FIX 50 (MARLINE BIO.)'
);

-- line #6392
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EFOXIM 200 (Reliance)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EFOXIM 200 (Reliance)'
);

-- line #6393
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELCEF 50 (Elfin Ph.)',
	'Cefixime',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELCEF 50 (Elfin Ph.)'
);

-- line #6394
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELFI 50 (Elder)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELFI 50 (Elder)'
);

-- line #6395
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELFI 100 (Elder)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELFI 100 (Elder)'
);

-- line #6396
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELFI 200 (Elder)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELFI 200 (Elder)'
);

-- line #6397
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELFI 50 (Elder)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELFI 50 (Elder)'
);

-- line #6398
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELXIME 200 (ROSE LABS)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELXIME 200 (ROSE LABS)'
);

-- line #6399
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESFIX 50 (RASS HC.)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESFIX 50 (RASS HC.)'
);

-- line #6400
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESFIX 200 (RASS HC.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESFIX 200 (RASS HC.)'
);

-- line #6401
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESFIX 50 (RASS HC.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESFIX 50 (RASS HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESFIX 100 (RASS HC.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESFIX 100 (RASS HC.)'
);

-- line #6402
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXCEF 100 (Ind-Swift)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXCEF 100 (Ind-Swift)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXCEF 200 (Ind-Swift)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXCEF 200 (Ind-Swift)'
);

-- line #6403
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXCEF 50 (Ind-Swift)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXCEF 50 (Ind-Swift)'
);

-- line #6404
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXIM 100 (Lanark)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXIM 100 (Lanark)'
);

-- line #6405
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXIM 200 (Lanark)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXIM 200 (Lanark)'
);

-- line #6406
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXIN 50 (EOAN PH.)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXIN 50 (EOAN PH.)'
);

-- line #6407
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXTACEF 50 (Blue Cross)',
	'Cefixime',
	'DPS',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXTACEF 50 (Blue Cross)'
);

-- line #6408
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXTACEF 50 (Blue Cross)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXTACEF 50 (Blue Cross)'
);

-- line #6409
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXTACEF 100 (Blue Cross)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXTACEF 100 (Blue Cross)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXTACEF 200 (Blue Cross)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXTACEF 200 (Blue Cross)'
);

-- line #6410
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXTACEF 50 (Blue Cross)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXTACEF 50 (Blue Cross)'
);

-- line #6411
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXTACEF-P 50 (Blue Cross)',
	'Cefixime',
	'SYP',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXTACEF-P 50 (Blue Cross)'
);

-- line #6412
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAX 200 (Secure)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAX 200 (Secure)'
);

-- line #6413
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEMCEF 200 (Fem care)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEMCEF 200 (Fem care)'
);

-- line #6414
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEVORIT 50 (Indoco Rem.)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEVORIT 50 (Indoco Rem.)'
);

-- line #6415
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEVORIT 100 (Indoco Rem.)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEVORIT 100 (Indoco Rem.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEVORIT 200 (Indoco Rem.)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEVORIT 200 (Indoco Rem.)'
);

-- line #6416
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEVORIT 50 (Indoco Rem.)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEVORIT 50 (Indoco Rem.)'
);

-- line #6417
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEXIM 50 (Admac Ph.)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEXIM 50 (Admac Ph.)'
);

-- line #6418
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEXIM 100 (Admac Ph.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEXIM 100 (Admac Ph.)'
);

-- line #6419
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEXIM 200 (Admac Ph.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEXIM 200 (Admac Ph.)'
);

-- line #6420
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIMIAL 50 (CHEMO HC.)',
	'CEFIxime',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIMIAL 50 (CHEMO HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIMIAL 100 (CHEMO HC.)',
	'CEFIxime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIMIAL 100 (CHEMO HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIMIAL 200 (CHEMO HC.)',
	'CEFIxime',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIMIAL 200 (CHEMO HC.)'
);

-- line #6421
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIMI 200 (MEDICO HEALTH)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIMI 200 (MEDICO HEALTH)'
);

-- line #6422
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FINCH 200 (Chemo Bio.)',
	'Cefixime',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FINCH 200 (Chemo Bio.)'
);

-- line #6423
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FINCH 50 (Chemo Bio.)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FINCH 50 (Chemo Bio.)'
);

-- line #6424
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FINCH 100 (Chemo Bio.)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FINCH 100 (Chemo Bio.)'
);

-- line #6425
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FINFIX 200 (FINE BIO-SC.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FINFIX 200 (FINE BIO-SC.)'
);

-- line #6426
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIXAL 100 (Shalman)',
	'Cefixime',
	'DT/200 TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIXAL 100 (Shalman)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIXAL 200 (Shalman)',
	'Cefixime',
	'DT/200 TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIXAL 200 (Shalman)'
);

-- line #6427
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIXCEF 50 (LAKSUN)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIXCEF 50 (LAKSUN)'
);

-- line #6428
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIXCEF 200 (LAKSUN)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIXCEF 200 (LAKSUN)'
);

-- line #6429
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIXCEF 50 (LAKSUN)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIXCEF 50 (LAKSUN)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIXCEF 100 (LAKSUN)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIXCEF 100 (LAKSUN)'
);

-- line #6430
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIXCEF 100 (LUCIFER & H.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIXCEF 100 (LUCIFER & H.)'
);

-- line #6431
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIXEN 100 (ESKEN)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIXEN 100 (ESKEN)'
);

-- line #6432
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIXEN 200 (ESKEN)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIXEN 200 (ESKEN)'
);

-- line #6433
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIXICAN 200 (Ikon Rem)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIXICAN 200 (Ikon Rem)'
);

-- line #6434
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIXI 100 (Cadex Lab)',
	'Cefixime',
	'DT/200 TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIXI 100 (Cadex Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIXI 200 (Cadex Lab)',
	'Cefixime',
	'DT/200 TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIXI 200 (Cadex Lab)'
);

-- line #6435
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIXIMO-D 15 (Unicure)',
	'Cefixime',
	'SYR',
	gm.nullify_empty_string('15')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIXIMO-D 15 (Unicure)'
);

-- line #6436
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIXIMO 200 (Unicure)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIXIMO 200 (Unicure)'
);

-- line #6437
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIXIM 15 (NUCLEUS LAB.)',
	'Cefixime',
	'SYR',
	gm.nullify_empty_string('15')::numeric,
	'mg/30ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIXIM 15 (NUCLEUS LAB.)'
);

-- line #6438
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIXI-O 50 (Cadex Lab)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIXI-O 50 (Cadex Lab)'
);

-- line #6439
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIXIRON 50 (Ronak Lab.)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIXIRON 50 (Ronak Lab.)'
);

-- line #6440
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIXIRON 100 (Ronak Lab.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIXIRON 100 (Ronak Lab.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIXIRON 200 (Ronak Lab.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIXIRON 200 (Ronak Lab.)'
);

-- line #6441
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIXIZEN 50 (CITIZEN LAB.)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIXIZEN 50 (CITIZEN LAB.)'
);

-- line #6442
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIXIZEN 200 (CITIZEN LAB.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIXIZEN 200 (CITIZEN LAB.)'
);

-- line #6443
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIXMAN 100 (Maneesh Hc.)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIXMAN 100 (Maneesh Hc.)'
);

-- line #6444
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIXMAN 200 (Maneesh Hc.)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIXMAN 200 (Maneesh Hc.)'
);

-- line #6445
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIXSPOR 50 (INVISION(INFALIFE))',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIXSPOR 50 (INVISION(INFALIFE))'
);

-- line #6446
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIXSPOR 100 (INVISION(INFALIFE))',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIXSPOR 100 (INVISION(INFALIFE))'
);

-- line #6447
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIXX 100 (Unichem)',
	'Cefixime',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIXX 100 (Unichem)'
);

-- line #6448
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIXX 200 (Unichem)',
	'Cefixime',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIXX 200 (Unichem)'
);

-- line #6449
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIXX 50 (Unichem)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIXX 50 (Unichem)'
);

-- line #6450
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIXX 100 (Unichem)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIXX 100 (Unichem)'
);

-- line #6451
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIXXI-O 200 (R.B.REM.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIXXI-O 200 (R.B.REM.)'
);

-- line #6452
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOXIT 50 (Bantom)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOXIT 50 (Bantom)'
);

-- line #6453
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOXIT 100 (Bantom)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOXIT 100 (Bantom)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOXIT 200 (Bantom)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOXIT 200 (Bantom)'
);

-- line #6454
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENFIX 50 (Genova)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENFIX 50 (Genova)'
);

-- line #6455
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENFIX 100 (Genova)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENFIX 100 (Genova)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENFIX 200 (Genova)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENFIX 200 (Genova)'
);

-- line #6456
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRAMOCEF-O 50 (Micro Labs)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRAMOCEF-O 50 (Micro Labs)'
);

-- line #6457
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRAMOCEF-O 400 (MICRO LAB.)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRAMOCEF-O 400 (MICRO LAB.)'
);

-- line #6458
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRAMOCEF-O 100 (Micro Labs)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRAMOCEF-O 100 (Micro Labs)'
);

-- line #6459
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRAMOCEF-O 200 (Micro Labs)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRAMOCEF-O 200 (Micro Labs)'
);

-- line #6460
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRAMOCEF-O 50 (Micro Labs)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRAMOCEF-O 50 (Micro Labs)'
);

-- line #6461
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G-XIME 100 (Graf Lab.)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G-XIME 100 (Graf Lab.)'
);

-- line #6462
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G-XIME 200 (Graf Lab.)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G-XIME 200 (Graf Lab.)'
);

-- line #6463
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HELCEF 200 (HELIUM HC.)',
	'Cefixime',
	'DT TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HELCEF 200 (HELIUM HC.)'
);

-- line #6464
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Cefixime', u'always_empty': u'', u'form': u'DPS', u'brand': u'HIFEN', u'strength_3': u'', u'company': u'HETERO HC.', u'unit': u''}

-- line #6465
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIFEN 50 (HETERO HC.)',
	'Cefixime',
	'DS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIFEN 50 (HETERO HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIFEN 100 (HETERO HC.)',
	'Cefixime',
	'DS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIFEN 100 (HETERO HC.)'
);

-- line #6466
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIFEN 100 (HETERO HC.)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIFEN 100 (HETERO HC.)'
);

-- line #6467
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYSEF 50 (FIRST HORIZON)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYSEF 50 (FIRST HORIZON)'
);

-- line #6468
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYSEF 100 (First Horizon)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYSEF 100 (First Horizon)'
);

-- line #6469
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYSEF 200 (First Horizon)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYSEF 200 (First Horizon)'
);

-- line #6470
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INCEF 50 (Intra Lab)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INCEF 50 (Intra Lab)'
);

-- line #6471
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INCEF 100 (Intra Lab)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INCEF 100 (Intra Lab)'
);

-- line #6472
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INCEF 200 (Intra Lab)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INCEF 200 (Intra Lab)'
);

-- line #6473
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INCEF 50 (Intra Lab)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INCEF 50 (Intra Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INCEF 200 (Intra Lab)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INCEF 200 (Intra Lab)'
);

-- line #6474
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INCEF 200 (INVIIVO HC.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INCEF 200 (INVIIVO HC.)'
);

-- line #6475
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDCEF 50 (Ind-Swift)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDCEF 50 (Ind-Swift)'
);

-- line #6476
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDCEF 100 (Ind-Swift)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDCEF 100 (Ind-Swift)'
);

-- line #6477
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDCEF 200 (Ind-Swift)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDCEF 200 (Ind-Swift)'
);

-- line #6478
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDCEF 50 (Ind-Swift)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDCEF 50 (Ind-Swift)'
);

-- line #6479
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JETEX 100 (Pfizer)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JETEX 100 (Pfizer)'
);

-- line #6480
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JETEX 200 (Pfizer)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JETEX 200 (Pfizer)'
);

-- line #6481
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JIDOX-C 200 (D.R.John''S)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'125'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JIDOX-C 200 (D.R.John''S)'
);

-- line #6482
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JIDOX 200 (D.R.John''S)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JIDOX 200 (D.R.John''S)'
);

-- line #6483
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JIDOX 100 (D.R.John''S)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JIDOX 100 (D.R.John''S)'
);

-- line #6484
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JIDOX 200 (D.R.John''S)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JIDOX 200 (D.R.John''S)'
);

-- line #6485
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JIFON 100 (D.R.John''S)',
	'CEFIXIME',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JIFON 100 (D.R.John''S)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JIFON 200 (D.R.John''S)',
	'CEFIXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JIFON 200 (D.R.John''S)'
);

-- line #6486
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JUCEF 100 (Jollen Med.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JUCEF 100 (Jollen Med.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JUCEF 200 (Jollen Med.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JUCEF 200 (Jollen Med.)'
);

-- line #6487
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KAFIXIME 100 (Kaptab)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KAFIXIME 100 (Kaptab)'
);

-- line #6488
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KAFIXIME 200 (Kaptab)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KAFIXIME 200 (Kaptab)'
);

-- line #6489
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KAFIXIME 50 (Kaptab)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KAFIXIME 50 (Kaptab)'
);

-- line #6490
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KAMICEF 50 (KAMSONS PH.)',
	'Cefixime',
	'SUSP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KAMICEF 50 (KAMSONS PH.)'
);

-- line #6491
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KAMICEF 200 (KAMSONS PH.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KAMICEF 200 (KAMSONS PH.)'
);

-- line #6492
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KAPDOX 100 (Novagen Ph.)',
	'Cefixime',
	'CL TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KAPDOX 100 (Novagen Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KAPDOX 200 (Novagen Ph.)',
	'Cefixime',
	'CL TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KAPDOX 200 (Novagen Ph.)'
);

-- line #6493
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KCEF 50 (KPL LIFE)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KCEF 50 (KPL LIFE)'
);

-- line #6494
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFIX 200 (ETHIX HC.)',
	'Cefixime',
	'F. TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFIX 200 (ETHIX HC.)'
);

-- line #6495
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFIX 100 (ETHIX HC.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFIX 100 (ETHIX HC.)'
);

-- line #6496
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFOTAX-O 100 (Grandix)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFOTAX-O 100 (Grandix)'
);

-- line #6497
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFOTAX-O 50 (Grandix)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFOTAX-O 50 (Grandix)'
);

-- line #6498
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFOTAX-O 100 (Grandix)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFOTAX-O 100 (Grandix)'
);

-- line #6499
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFOTAX-O 200 (Grandix)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFOTAX-O 200 (Grandix)'
);

-- line #6500
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETBID 50 (Water Lilly)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETBID 50 (Water Lilly)'
);

-- line #6501
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETBID 100 (Water Lilly)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETBID 100 (Water Lilly)'
);

-- line #6502
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETBID 200 (Water Lilly)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETBID 200 (Water Lilly)'
);

-- line #6503
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KINECEF 100 (Kinedex Hc.)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KINECEF 100 (Kinedex Hc.)'
);

-- line #6504
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KIXIM 100 (Brooks Ph.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KIXIM 100 (Brooks Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KIXIM 200 (Brooks Ph.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KIXIM 200 (Brooks Ph.)'
);

-- line #6505
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAXIM-100 100 (L.B. PH.)',
	'CEFIXIME',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAXIM-100 100 (L.B. PH.)'
);

-- line #6506
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAXIM 50 (Biocin Hc.)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAXIM 50 (Biocin Hc.)'
);

-- line #6507
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Cefixime', u'always_empty': u'', u'form': u'D.SYR', u'brand': u'LAXIMO', u'strength_3': u'', u'company': u'Lexus', u'unit': u''}

-- line #6508
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAXIMO 200 (Lexus)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAXIMO 200 (Lexus)'
);

-- line #6509
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAXIM 100 (Biocin Hc.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAXIM 100 (Biocin Hc.)'
);

-- line #6510
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAXIM 200 (Biocin Hc.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAXIM 200 (Biocin Hc.)'
);

-- line #6511
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'L-CEF 50 (Captab)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'L-CEF 50 (Captab)'
);

-- line #6512
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LCEF 100 (Dr.Arvind Shah''S)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LCEF 100 (Dr.Arvind Shah''S)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LCEF 200 (Dr.Arvind Shah''S)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LCEF 200 (Dr.Arvind Shah''S)'
);

-- line #6513
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEMCEF 100 (LEMON PH.)',
	'Cefixime',
	'DT TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEMCEF 100 (LEMON PH.)'
);

-- line #6514
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEMCEF 200 (LEMON PH.)',
	'Cefixime',
	'DT TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEMCEF 200 (LEMON PH.)'
);

-- line #6515
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Cefixime', u'always_empty': u'', u'form': u'SYP', u'brand': u'LEMCEFF', u'strength_3': u'', u'company': u'LEMON PH.', u'unit': u''}

-- line #6516
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LETIX 50 (ADLEY PHARMA.)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LETIX 50 (ADLEY PHARMA.)'
);

-- line #6517
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LETIX 100 (ADLEY PHARMA.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LETIX 100 (ADLEY PHARMA.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LETIX 200 (ADLEY PHARMA.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LETIX 200 (ADLEY PHARMA.)'
);

-- line #6518
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Cefixime', u'always_empty': u'', u'form': u'D.SYR', u'brand': u'LEXIME', u'strength_3': u'', u'company': u'Lexus', u'unit': u''}

-- line #6519
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEXIME 100 (Cosmas Ph.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEXIME 100 (Cosmas Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEXIME 200 (Cosmas Ph.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEXIME 200 (Cosmas Ph.)'
);

-- line #6520
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEXIME 200 (Lexus)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEXIME 200 (Lexus)'
);

-- line #6521
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Cefixime', u'always_empty': u'', u'form': u'SUS', u'brand': u'LUFIX', u'strength_3': u'', u'company': u'LUSTRE', u'unit': u''}

-- line #6522
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUFIX 100 (LUSTRE)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUFIX 100 (LUSTRE)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUFIX 200 (LUSTRE)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUFIX 200 (LUSTRE)'
);

-- line #6523
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYCEFT-O 50 (HETERO HC.)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYCEFT-O 50 (HETERO HC.)'
);

-- line #6524
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYCEFT-O 200 (HETERO HC.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYCEFT-O 200 (HETERO HC.)'
);

-- line #6525
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYOXIM 50 (Lypho Med)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYOXIM 50 (Lypho Med)'
);

-- line #6526
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYOXIM 100 (Lypho Med)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYOXIM 100 (Lypho Med)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYOXIM 200 (Lypho Med)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYOXIM 200 (Lypho Med)'
);

-- line #6527
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAGNEXIM 50 (Magnus Bio.)',
	'Cefixime',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAGNEXIM 50 (Magnus Bio.)'
);

-- line #6528
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Cefixime', u'always_empty': u'', u'form': u'DPS', u'brand': u'MAHACEF', u'strength_3': u'', u'company': u'Discovery M.', u'unit': u''}

-- line #6529
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5G', u'strength_2': u'10ML(ANHYD.)', u'substance': u'Cefixime', u'always_empty': u'', u'form': u'DPS', u'brand': u'MAHACEF', u'strength_3': u'', u'company': u'Mankind', u'unit': u''}

-- line #6530
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAHACEF 50 (Discovery M.)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAHACEF 50 (Discovery M.)'
);

-- line #6531
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAHACEF 200 (Discovery M.)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAHACEF 200 (Discovery M.)'
);

-- line #6532
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAHACEF 50 (Discovery M.)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAHACEF 50 (Discovery M.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAHACEF 100 (Discovery M.)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAHACEF 100 (Discovery M.)'
);

-- line #6533
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAXICEF 50 (Biomax Lab)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAXICEF 50 (Biomax Lab)'
);

-- line #6534
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAXICEF 100 (Biomax Lab)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAXICEF 100 (Biomax Lab)'
);

-- line #6535
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAXICEF 200 (Biomax Lab)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAXICEF 200 (Biomax Lab)'
);

-- line #6536
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAXI-D 50 (Dial Ph.)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAXI-D 50 (Dial Ph.)'
);

-- line #6537
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAXI-D 200 (Dial Ph.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAXI-D 200 (Dial Ph.)'
);

-- line #6538
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MCEF 200 (MATRIX LIFE)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MCEF 200 (MATRIX LIFE)'
);

-- line #6539
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MERYCEF-100 100 (ALEXUS(SURYA))',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MERYCEF-100 100 (ALEXUS(SURYA))'
);

-- line #6540
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MERYCEF-200 200 (ALEXUS(SURYA))',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MERYCEF-200 200 (ALEXUS(SURYA))'
);

-- line #6541
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEXI 200 (ALPHA TH.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEXI 200 (ALPHA TH.)'
);

-- line #6542
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICFOX 50 (Alde Medi.)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/1ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICFOX 50 (Alde Medi.)'
);

-- line #6543
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICFOX 100 (Alde Medi.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICFOX 100 (Alde Medi.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICFOX 200 (Alde Medi.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICFOX 200 (Alde Medi.)'
);

-- line #6544
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILFIXIME 200 (Shaimil)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILFIXIME 200 (Shaimil)'
);

-- line #6545
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILFIXIME 50 (Shaimil)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILFIXIME 50 (Shaimil)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILFIXIME 100 (Shaimil)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILFIXIME 100 (Shaimil)'
);

-- line #6546
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILIXIM 100 (Glenmark)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILIXIM 100 (Glenmark)'
);

-- line #6547
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILIXIM-D 50 (Glenmark)',
	'Cefixime',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILIXIM-D 50 (Glenmark)'
);

-- line #6548
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILIXIM 100 (Glenmark)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILIXIM 100 (Glenmark)'
);

-- line #6549
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILIXIM 50 (Glenmark)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILIXIM 50 (Glenmark)'
);

-- line #6550
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILIXIM 200 (Glenmark)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILIXIM 200 (Glenmark)'
);

-- line #6551
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MTEF 125 (Kwik Hc.)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MTEF 125 (Kwik Hc.)'
);

-- line #6552
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MTEF 100 (Kwik Hc.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MTEF 100 (Kwik Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MTEF 200 (Kwik Hc.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MTEF 200 (Kwik Hc.)'
);

-- line #6553
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUCIFI 100 (Cyper Ph.)',
	'Cefixime',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUCIFI 100 (Cyper Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUCIFI 200 (Cyper Ph.)',
	'Cefixime',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUCIFI 200 (Cyper Ph.)'
);

-- line #6554
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUCIFI 400 (Cyper Ph.)',
	'Cefixime',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUCIFI 400 (Cyper Ph.)'
);

-- line #6555
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCEF-O 50 (Solitaire)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCEF-O 50 (Solitaire)'
);

-- line #6556
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYTAX-O 50 (Radix Bio.)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYTAX-O 50 (Radix Bio.)'
);

-- line #6557
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYTAX-O 200 (Radix Bio.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYTAX-O 200 (Radix Bio.)'
);

-- line #6558
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAFI 50 (Runa Ph.)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAFI 50 (Runa Ph.)'
);

-- line #6559
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAFI 100 (Runa Ph.)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAFI 100 (Runa Ph.)'
);

-- line #6560
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAFI 200 (Runa Ph.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAFI 200 (Runa Ph.)'
);

-- line #6561
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'N-CEF 50 (National)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'N-CEF 50 (National)'
);

-- line #6562
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'N-CEF 200 (National)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'N-CEF 200 (National)'
);

-- line #6563
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEXIM 50 (Kentreck)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEXIM 50 (Kentreck)'
);

-- line #6564
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEXIM 50 (Kentreck)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEXIM 50 (Kentreck)'
);

-- line #6565
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEXIM 50 (Kentreck)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEXIM 50 (Kentreck)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEXIM 200 (Kentreck)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEXIM 200 (Kentreck)'
);

-- line #6566
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Cefixime', u'always_empty': u'', u'form': u'D.SYR', u'brand': u'NITAXIM-O', u'strength_3': u'', u'company': u'Nitin Ph.', u'unit': u''}

-- line #6567
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITAXIM-O 100 (Nitin Ph.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITAXIM-O 100 (Nitin Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITAXIM-O 200 (Nitin Ph.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITAXIM-O 200 (Nitin Ph.)'
);

-- line #6568
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIZOCEF 50 (USP LIFE)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIZOCEF 50 (USP LIFE)'
);

-- line #6569
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORCEF-D 50 (NORTECH REM.)',
	'Cefixime',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORCEF-D 50 (NORTECH REM.)'
);

-- line #6570
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORCEF 200 (NORTECH REM.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORCEF 200 (NORTECH REM.)'
);

-- line #6571
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVACEF 50 (Saga Lab)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVACEF 50 (Saga Lab)'
);

-- line #6572
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVACEF 200 (Saga Lab)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVACEF 200 (Saga Lab)'
);

-- line #6573
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVACEF 50 (Saga Lab)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVACEF 50 (Saga Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVACEF 100 (Saga Lab)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVACEF 100 (Saga Lab)'
);

-- line #6574
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVAFEX 50 (Radicura)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVAFEX 50 (Radicura)'
);

-- line #6575
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVAFEX 100 (Radicura)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVAFEX 100 (Radicura)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVAFEX 200 (Radicura)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVAFEX 200 (Radicura)'
);

-- line #6576
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUCLEAR 50 (Zenon Hc.)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUCLEAR 50 (Zenon Hc.)'
);

-- line #6577
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUCLEAR 50 (Zenon Hc.)',
	'Cefixime',
	'DT TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUCLEAR 50 (Zenon Hc.)'
);

-- line #6578
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUCLEAR 100 (Zenon Hc.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUCLEAR 100 (Zenon Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUCLEAR 200 (Zenon Hc.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUCLEAR 200 (Zenon Hc.)'
);

-- line #6579
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUROCEF 100 (Neuron Ph.)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUROCEF 100 (Neuron Ph.)'
);

-- line #6580
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUROCEF 200 (Neuron Ph.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUROCEF 200 (Neuron Ph.)'
);

-- line #6581
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'N-XIME 200 (NENSHI HC.)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'N-XIME 200 (NENSHI HC.)'
);

-- line #6582
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OBFIX 200 (Obzone Ph.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OBFIX 200 (Obzone Ph.)'
);

-- line #6583
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OBICEF 200 (GYNOB PH.)',
	'CEFIxime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OBICEF 200 (GYNOB PH.)'
);

-- line #6584
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCEF 50 (Osper)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCEF 50 (Osper)'
);

-- line #6585
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCEF 100 (Osper)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCEF 100 (Osper)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCEF 200 (Osper)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCEF 200 (Osper)'
);

-- line #6586
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODCEF 200 (Apex Form.)',
	'Cefixime',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg(TRIHYDR.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODCEF 200 (Apex Form.)'
);

-- line #6587
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODICEF 200 (Galpha)',
	'Cefixime',
	'CV TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODICEF 200 (Galpha)'
);

-- line #6588
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODICEF-O 200 (Galpha)',
	'Cefixime',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODICEF-O 200 (Galpha)'
);

-- line #6589
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODICEF-O 100 (Galpha)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODICEF-O 100 (Galpha)'
);

-- line #6590
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODICEF-O 50 (Galpha)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODICEF-O 50 (Galpha)'
);

-- line #6591
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOMIX 50 (ORION BIOTECH.)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOMIX 50 (ORION BIOTECH.)'
);

-- line #6592
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOMIX 50 (ORION BIOTECH.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOMIX 50 (ORION BIOTECH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOMIX 100 (ORION BIOTECH.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOMIX 100 (ORION BIOTECH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOMIX 200 (ORION BIOTECH.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOMIX 200 (ORION BIOTECH.)'
);

-- line #6593
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLCEFONE 50 (Olcare)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLCEFONE 50 (Olcare)'
);

-- line #6594
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLCEFONE 50 (Olcare)',
	'Cefixime',
	'DT/100 TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLCEFONE 50 (Olcare)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLCEFONE 100 (Olcare)',
	'Cefixime',
	'DT/100 TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLCEFONE 100 (Olcare)'
);

-- line #6595
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLCEFONE 200 (Olcare)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLCEFONE 200 (Olcare)'
);

-- line #6596
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLCEFONE-T 100 (Olcare)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLCEFONE-T 100 (Olcare)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLCEFONE-T 200 (Olcare)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLCEFONE-T 200 (Olcare)'
);

-- line #6597
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50', u'strength_2': u'100', u'substance': u'Cefixime', u'always_empty': u'', u'form': u'', u'brand': u'OMNATAX-O BIOTAB', u'strength_3': u'', u'company': u'Nicholas', u'unit': u'mg'}

-- line #6598
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMNATAX-O 50 (Nicholas)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMNATAX-O 50 (Nicholas)'
);

-- line #6599
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMNATAX-O 100 (Nicholas)',
	'Cefixime',
	'DT/200 TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMNATAX-O 100 (Nicholas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMNATAX-O 200 (Nicholas)',
	'Cefixime',
	'DT/200 TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMNATAX-O 200 (Nicholas)'
);

-- line #6600
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMNICEF-O 100 (Otsira)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMNICEF-O 100 (Otsira)'
);

-- line #6601
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMNICEF-O 200 (Otsira)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMNICEF-O 200 (Otsira)'
);

-- line #6602
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONICEF 200 (ACE LAB.)',
	'CEFIxime',
	'LB TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONICEF 200 (ACE LAB.)'
);

-- line #6603
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'O-POWERCEF 50 (Wockhardt)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'O-POWERCEF 50 (Wockhardt)'
);

-- line #6604
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'O-POWERCEF 100 (Wockhardt)',
	'Cefixime',
	'DT/TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'O-POWERCEF 100 (Wockhardt)'
);

-- line #6605
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'O-POWERCEF 200 (Wockhardt)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'O-POWERCEF 200 (Wockhardt)'
);

-- line #6606
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORAXIM-D 50 (Lark Labs)',
	'Cefixime',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORAXIM-D 50 (Lark Labs)'
);

-- line #6607
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORAXIM -F 200 (Lark Labs)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORAXIM -F 200 (Lark Labs)'
);

-- line #6608
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORAXIM 100 (Lark Labs)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORAXIM 100 (Lark Labs)'
);

-- line #6609
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORCEF 50 (RISHAB(KUREKEMI))',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORCEF 50 (RISHAB(KUREKEMI))'
);

-- line #6610
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORCEF 100 (RISHAB(KUREKEMI))',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORCEF 100 (RISHAB(KUREKEMI))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORCEF 200 (RISHAB(KUREKEMI))',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORCEF 200 (RISHAB(KUREKEMI))'
);

-- line #6611
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORFIX 100 (Orchid Hc.)',
	'Cefixime',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORFIX 100 (Orchid Hc.)'
);

-- line #6612
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORFIX 200 (Orchid Hc.)',
	'Cefixime',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORFIX 200 (Orchid Hc.)'
);

-- line #6613
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORFIX 100 (Orchid Hc.)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORFIX 100 (Orchid Hc.)'
);

-- line #6614
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORIFIX 100 (ORIAN PH.)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORIFIX 100 (ORIAN PH.)'
);

-- line #6615
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORIFIX 200 (ORIAN PH.)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORIFIX 200 (ORIAN PH.)'
);

-- line #6616
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORITAXIM-O 100 (Cadila)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORITAXIM-O 100 (Cadila)'
);

-- line #6617
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORITAXIM-O 200 (Cadila)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORITAXIM-O 200 (Cadila)'
);

-- line #6618
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORITAXIM-O 50 (Cadila)',
	'Cefixime',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORITAXIM-O 50 (Cadila)'
);

-- line #6619
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OROCEF 100 (COXSWAIN HC.)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OROCEF 100 (COXSWAIN HC.)'
);

-- line #6620
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OROCEF 200 (COXSWAIN HC.)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OROCEF 200 (COXSWAIN HC.)'
);

-- line #6621
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OROCEF 50 (COXSWAIN HC.)',
	'Cefixime',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OROCEF 50 (COXSWAIN HC.)'
);

-- line #6622
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORTAX 200 (Medo Chem)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORTAX 200 (Medo Chem)'
);

-- line #6623
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXIM 50 (Orison Ph.)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXIM 50 (Orison Ph.)'
);

-- line #6624
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXIM 200 (Orison Ph.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXIM 200 (Orison Ph.)'
);

-- line #6625
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANCEF-O 50 (Aglowmed)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANCEF-O 50 (Aglowmed)'
);

-- line #6626
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANCEF-O 100 (Aglowmed)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANCEF-O 100 (Aglowmed)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANCEF-O 200 (Aglowmed)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANCEF-O 200 (Aglowmed)'
);

-- line #6627
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEDIXIM 50 (Biological E.)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEDIXIM 50 (Biological E.)'
);

-- line #6628
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEDIXIM 100 (Biological E.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEDIXIM 100 (Biological E.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEDIXIM 200 (Biological E.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEDIXIM 200 (Biological E.)'
);

-- line #6629
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEDIXIM 400 (Biological E.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEDIXIM 400 (Biological E.)'
);

-- line #6630
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Cefixime', u'always_empty': u'', u'form': u'D.SYR', u'brand': u'PENIXIME', u'strength_3': u'', u'company': u'SAFE PH.', u'unit': u''}

-- line #6631
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENIXIME 200 (SAFE PH.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENIXIME 200 (SAFE PH.)'
);

-- line #6632
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEXIM 50 (Pifer Ph.)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEXIM 50 (Pifer Ph.)'
);

-- line #6633
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEXIM 100 (Pifer Ph.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEXIM 100 (Pifer Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEXIM 200 (Pifer Ph.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEXIM 200 (Pifer Ph.)'
);

-- line #6634
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLUGFIX 100 (Samarth Life)',
	'CEFIXIME',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLUGFIX 100 (Samarth Life)'
);

-- line #6635
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLUGFIX 200 (Samarth Life)',
	'CEFIXIME',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLUGFIX 200 (Samarth Life)'
);

-- line #6636
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLUGFIX 50 (Samarth Life)',
	'CEFIXIME',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLUGFIX 50 (Samarth Life)'
);

-- line #6637
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLUGFIX 50 (Samarth LIFE)',
	'Cefixime',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLUGFIX 50 (Samarth LIFE)'
);

-- line #6638
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROCEF 100 (Semsun Ph.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROCEF 100 (Semsun Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROCEF 200 (Semsun Ph.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROCEF 200 (Semsun Ph.)'
);

-- line #6639
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROXIM 200 (Vivid Lab)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROXIM 200 (Vivid Lab)'
);

-- line #6640
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROXIT 100 (SKYMAX LIFE)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROXIT 100 (SKYMAX LIFE)'
);

-- line #6641
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYXY-200 200 (BIOKIND HC.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYXY-200 200 (BIOKIND HC.)'
);

-- line #6642
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Cefixime', u'always_empty': u'', u'form': u'SYP', u'brand': u'PYXY DRY', u'strength_3': u'', u'company': u'BIOKIND HC.', u'unit': u''}

-- line #6643
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYXY 100 (BIOKIND HC.)',
	'Cefixime',
	'DT TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYXY 100 (BIOKIND HC.)'
);

-- line #6644
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAINFIX-50 50 (RAINVIS PH.)',
	'Cefixime',
	'D.SYRUP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAINFIX-50 50 (RAINVIS PH.)'
);

-- line #6645
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAINFIX 200 (RAINVIS PH.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAINFIX 200 (RAINVIS PH.)'
);

-- line #6646
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAXIM 100 (Zydus Cadila)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAXIM 100 (Zydus Cadila)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAXIM 200 (Zydus Cadila)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAXIM 200 (Zydus Cadila)'
);

-- line #6647
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REDICATE50 50 (Dr. Reddy''S)',
	'Cefixime',
	'DS',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REDICATE50 50 (Dr. Reddy''S)'
);

-- line #6648
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REFIX 50 (SHRESHTHA)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REFIX 50 (SHRESHTHA)'
);

-- line #6649
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REFIX 100 (SHRESHTHA)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REFIX 100 (SHRESHTHA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REFIX 200 (SHRESHTHA)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REFIX 200 (SHRESHTHA)'
);

-- line #6650
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELIXIME 50 (Relax Ph.)',
	'Cefixime',
	'ORAL SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELIXIME 50 (Relax Ph.)'
);

-- line #6651
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELIXIME 100 (Relax Ph.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELIXIME 100 (Relax Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELIXIME 200 (Relax Ph.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELIXIME 200 (Relax Ph.)'
);

-- line #6652
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REXIM 200 (Replica)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REXIM 200 (Replica)'
);

-- line #6653
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RHOXIM 50 (Rhombus)',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RHOXIM 50 (Rhombus)'
);

-- line #6654
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RHOXIM 100 (Rhombus)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RHOXIM 100 (Rhombus)'
);

-- line #6655
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RHOXIM 50 (Rhombus)',
	'Cefixime',
	'KID TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RHOXIM 50 (Rhombus)'
);

-- line #6656
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RHOXIM 200 (Rhombus)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RHOXIM 200 (Rhombus)'
);

-- line #6657
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Cefixime', u'always_empty': u'', u'form': u'SYR', u'brand': u'RHOXIN-D', u'strength_3': u'', u'company': u'Rhombus', u'unit': u''}

-- line #6658
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RHOXIN 100 (Rhombus)',
	'Cefixime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RHOXIN 100 (Rhombus)'
);

-- line #6659
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RHOX 200 (Rhombus)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RHOX 200 (Rhombus)'
);

-- line #6660
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RICIME 50 (RISHAB(OROCHEM))',
	'Cefixime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RICIME 50 (RISHAB(OROCHEM))'
);

-- line #6661
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RICIME-L 100 (RISHAB(OROCHEM))',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RICIME-L 100 (RISHAB(OROCHEM))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RICIME-L 200 (RISHAB(OROCHEM))',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RICIME-L 200 (RISHAB(OROCHEM))'
);

-- line #6662
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIOCEF-200 200 (RIYA REM.)',
	'Cefixime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIOCEF-200 200 (RIYA REM.)'
);

-- line #6663
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOZONE 1000 (Biosmith)',
	'Cefoperazone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOZONE 1000 (Biosmith)'
);

-- line #6664
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefoperazone', u'always_empty': u'', u'form': u'INJ', u'brand': u'BURNCEF', u'strength_3': u'', u'company': u'Kepsee', u'unit': u''}

-- line #6665
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefoperazone', u'always_empty': u'', u'form': u'INJ', u'brand': u'CEFAKING', u'strength_3': u'', u'company': u'Bennet Ph.', u'unit': u''}

-- line #6666
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAKING 250 (Bennet Ph.)',
	'Cefoperazone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAKING 250 (Bennet Ph.)'
);

-- line #6667
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAONE 250 (Mefro Ph.)',
	'Cefoperazone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAONE 250 (Mefro Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAONE 1000 (Mefro Ph.)',
	'Cefoperazone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAONE 1000 (Mefro Ph.)'
);

-- line #6668
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefoperazone', u'always_empty': u'', u'form': u'INJ', u'brand': u'CEFAZONE', u'strength_3': u'', u'company': u'Jackson', u'unit': u''}

-- line #6669
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFINA 250 (Intra Lab)',
	'Cefoperazone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFINA 250 (Intra Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFINA 1000 (Intra Lab)',
	'Cefoperazone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFINA 1000 (Intra Lab)'
);

-- line #6670
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFNEX 250 (Nexus)',
	'Cefoperazone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFNEX 250 (Nexus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFNEX 1000 (Nexus)',
	'Cefoperazone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFNEX 1000 (Nexus)'
);

-- line #6671
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2G', u'strength_2': u'', u'substance': u'Cefoperazone', u'always_empty': u'', u'form': u'INJ', u'brand': u'CEFNEX', u'strength_3': u'', u'company': u'Nexus', u'unit': u''}

-- line #6672
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefoperazone', u'always_empty': u'', u'form': u'V', u'brand': u'CEFOMYCIN', u'strength_3': u'', u'company': u'Zydus Cadila', u'unit': u''}

-- line #6673
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2G', u'strength_2': u'', u'substance': u'Cefoperazone', u'always_empty': u'', u'form': u'V', u'brand': u'CEFOMYCIN', u'strength_3': u'', u'company': u'Zydus Cadila', u'unit': u''}

-- line #6674
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefoperazone', u'always_empty': u'', u'form': u'INJ', u'brand': u'CEFONE', u'strength_3': u'', u'company': u'Admac Ph.', u'unit': u''}

-- line #6675
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFONE 250 (Admac Ph.)',
	'Cefoperazone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFONE 250 (Admac Ph.)'
);

-- line #6676
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOPAN 250 (Taurus Lab)',
	'Cefoperazone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOPAN 250 (Taurus Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOPAN 1000 (Taurus Lab)',
	'Cefoperazone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOPAN 1000 (Taurus Lab)'
);

-- line #6677
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefoperazone', u'always_empty': u'', u'form': u'INJ', u'brand': u'CEFOPERACIN', u'strength_3': u'', u'company': u'Pfiscar Ind.', u'unit': u''}

-- line #6678
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOROM 250 (Rhombus)',
	'Cefoperazone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOROM 250 (Rhombus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOROM 500 (Rhombus)',
	'Cefoperazone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOROM 500 (Rhombus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOROM 1000 (Rhombus)',
	'Cefoperazone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOROM 1000 (Rhombus)'
);

-- line #6679
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefoperazone', u'always_empty': u'', u'form': u'INJ', u'brand': u'CEFOZONE', u'strength_3': u'', u'company': u'Csc Ph.', u'unit': u''}

-- line #6680
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.5G', u'strength_2': u'', u'substance': u'Cefoperazone', u'always_empty': u'', u'form': u'V', u'brand': u'CEFPAR', u'strength_3': u'', u'company': u'Kapl', u'unit': u''}

-- line #6681
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefoperazone', u'always_empty': u'', u'form': u'V', u'brand': u'CEFPAR', u'strength_3': u'', u'company': u'Kapl', u'unit': u''}

-- line #6682
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFROSE 1000 (SANCHEZ LAB.)',
	'Cefoperazone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFROSE 1000 (SANCHEZ LAB.)'
);

-- line #6683
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefoperazone', u'always_empty': u'', u'form': u'INJ', u'brand': u'CEFU', u'strength_3': u'', u'company': u'Sanjeevani Bio.', u'unit': u''}

-- line #6684
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefoperazone', u'always_empty': u'', u'form': u'V', u'brand': u'CEPRAZO', u'strength_3': u'', u'company': u'Global Med.', u'unit': u''}

-- line #6685
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPRAZO 250 (Global Med.)',
	'Cefoperazone',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPRAZO 250 (Global Med.)'
);

-- line #6686
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefoperazone', u'always_empty': u'', u'form': u'INJ', u'brand': u'CERIZONE', u'strength_3': u'', u'company': u'Phytochem', u'unit': u''}

-- line #6687
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUCEF 250 (Cubit Hc.)',
	'Cefoperazone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUCEF 250 (Cubit Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUCEF 1000 (Cubit Hc.)',
	'Cefoperazone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUCEF 1000 (Cubit Hc.)'
);

-- line #6688
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DALCEFA 250 (Dallas Ph.)',
	'Cefoperazone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DALCEFA 250 (Dallas Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DALCEFA 1000 (Dallas Ph.)',
	'Cefoperazone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DALCEFA 1000 (Dallas Ph.)'
);

-- line #6689
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefoperazone', u'always_empty': u'', u'form': u'INJ', u'brand': u'DUBACT', u'strength_3': u'', u'company': u'Armour Rem.', u'unit': u''}

-- line #6690
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefoperazone', u'always_empty': u'', u'form': u'V', u'brand': u'DURAZONE', u'strength_3': u'', u'company': u'Ophthal R.', u'unit': u''}

-- line #6691
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DURAZONE 250 (Ophthal R.)',
	'Cefoperazone',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DURAZONE 250 (Ophthal R.)'
);

-- line #6692
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefoperazone', u'always_empty': u'', u'form': u'VIAL', u'brand': u'ERIZON', u'strength_3': u'', u'company': u'Intracin', u'unit': u''}

-- line #6693
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERIZON 500 (Intracin)',
	'Cefoperazone',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERIZON 500 (Intracin)'
);

-- line #6694
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FINCEF 1000 (Finesse Ph.)',
	'Cefoperazone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FINCEF 1000 (Finesse Ph.)'
);

-- line #6695
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FINCEF 250 (Finesse Ph.)',
	'Cefoperazone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FINCEF 250 (Finesse Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FINCEF 500 (Finesse Ph.)',
	'Cefoperazone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FINCEF 500 (Finesse Ph.)'
);

-- line #6696
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FRONE 250 (Zee Lab)',
	'Cefoperazone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/1000'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FRONE 250 (Zee Lab)'
);

-- line #6697
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefoperazone', u'always_empty': u'', u'form': u'INJ', u'brand': u'FUZONE', u'strength_3': u'', u'company': u'N.K.Ph.', u'unit': u''}

-- line #6698
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUZONE 250 (N.K.Ph.)',
	'Cefoperazone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUZONE 250 (N.K.Ph.)'
);

-- line #6699
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefoperazone', u'always_empty': u'', u'form': u'VIAL', u'brand': u'FUZOSUL', u'strength_3': u'', u'company': u'N.K.Ph.', u'unit': u''}

-- line #6700
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2G', u'strength_2': u'', u'substance': u'Cefoperazone', u'always_empty': u'', u'form': u'VIAL', u'brand': u'FUZOSUL', u'strength_3': u'', u'company': u'N.K.Ph.', u'unit': u''}

-- line #6701
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INFICIN 250 (Brooks Ph.)',
	'Cefoperazone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INFICIN 250 (Brooks Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INFICIN 1000 (Brooks Ph.)',
	'Cefoperazone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INFICIN 1000 (Brooks Ph.)'
);

-- line #6702
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefoperazone', u'always_empty': u'', u'form': u'INJ', u'brand': u'KEPHAZON', u'strength_3': u'', u'company': u'United Bio.', u'unit': u''}

-- line #6703
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEXONE 1000 (Cadex Lab)',
	'Cefoperazone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEXONE 1000 (Cadex Lab)'
);

-- line #6704
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefoperazone', u'always_empty': u'', u'form': u'V', u'brand': u'LORIZON', u'strength_3': u'', u'company': u'Dolphin', u'unit': u''}

-- line #6705
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2G', u'strength_2': u'', u'substance': u'Cefoperazone', u'always_empty': u'', u'form': u'V', u'brand': u'LORIZON', u'strength_3': u'', u'company': u'Dolphin', u'unit': u''}

-- line #6706
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORIZON 500 (Dolphin)',
	'Cefoperazone',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORIZON 500 (Dolphin)'
);

-- line #6707
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefoperazone', u'always_empty': u'', u'form': u'V', u'brand': u'MAGNAMYCIN', u'strength_3': u'', u'company': u'Pfizer', u'unit': u''}

-- line #6708
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAGNAMYCIN 250 (Pfizer)',
	'Cefoperazone',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAGNAMYCIN 250 (Pfizer)'
);

-- line #6709
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2G', u'strength_2': u'', u'substance': u'Cefoperazone', u'always_empty': u'', u'form': u'V', u'brand': u'MAGNAMYCIN', u'strength_3': u'', u'company': u'Pfizer', u'unit': u''}

-- line #6710
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAGNAZONE 1000 (Ikon Rem)',
	'Cefoperazone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAGNAZONE 1000 (Ikon Rem)'
);

-- line #6711
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefoperazone', u'always_empty': u'', u'form': u'INJ', u'brand': u'MALOZONE', u'strength_3': u'', u'company': u'Malody Hc.', u'unit': u''}

-- line #6712
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefoperazone', u'always_empty': u'', u'form': u'V', u'brand': u'MEGACEF', u'strength_3': u'', u'company': u'Biological E.', u'unit': u''}

-- line #6713
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGAZONE 250 (TALENT LAB.)',
	'Cefoperazone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGAZONE 250 (TALENT LAB.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGAZONE 1000 (TALENT LAB.)',
	'Cefoperazone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGAZONE 1000 (TALENT LAB.)'
);

-- line #6714
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefoperazone', u'always_empty': u'', u'form': u'V', u'brand': u'MULTIMYCIN', u'strength_3': u'', u'company': u'Redson', u'unit': u''}

-- line #6715
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MULTIMYCIN 250 (Redson)',
	'Cefoperazone',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MULTIMYCIN 250 (Redson)'
);

-- line #6716
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYOZONE 250 (Biocin Hc.)',
	'Cefoperazone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYOZONE 250 (Biocin Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYOZONE 1000 (Biocin Hc.)',
	'Cefoperazone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYOZONE 1000 (Biocin Hc.)'
);

-- line #6717
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefoperazone', u'always_empty': u'', u'form': u'V', u'brand': u'MYTICEF', u'strength_3': u'', u'company': u'Panacea', u'unit': u''}

-- line #6718
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYTICEF 250 (Panacea)',
	'Cefoperazone',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYTICEF 250 (Panacea)'
);

-- line #6719
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2G', u'strength_2': u'', u'substance': u'Cefoperazone', u'always_empty': u'', u'form': u'V', u'brand': u'MYTICEF', u'strength_3': u'', u'company': u'Panacea', u'unit': u''}

-- line #6720
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYTICEF 500 (Panacea)',
	'Cefoperazone',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYTICEF 500 (Panacea)'
);

-- line #6721
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEFAPARA 250 (Nitin Ph.)',
	'Cefoperazone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEFAPARA 250 (Nitin Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEFAPARA 1000 (Nitin Ph.)',
	'Cefoperazone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEFAPARA 1000 (Nitin Ph.)'
);

-- line #6722
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefoperazone', u'always_empty': u'', u'form': u'INJ', u'brand': u'NEGAPLUS', u'strength_3': u'', u'company': u'Orchid Hc.', u'unit': u''}

-- line #6723
-- ignoring line: field [strength_1] not numeric: >>>1G<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefoperazone', u'always_empty': u'', u'form': u'VIAL', u'brand': u'NOVACIP', u'strength_3': u'', u'company': u'Radicura', u'unit': u'250'}

-- line #6724
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefoperazone', u'always_empty': u'', u'form': u'INJ', u'brand': u'NUPERAZONE', u'strength_3': u'', u'company': u'CH.Bhagat', u'unit': u''}

-- line #6725
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPRAZ 500 (Dynamic)',
	'Cefoperazone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPRAZ 500 (Dynamic)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPRAZ 1000 (Dynamic)',
	'Cefoperazone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPRAZ 1000 (Dynamic)'
);

-- line #6726
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefoperazone', u'always_empty': u'', u'form': u'INJ', u'brand': u'OZONE', u'strength_3': u'', u'company': u'Solitaire', u'unit': u''}

-- line #6727
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefoperazone', u'always_empty': u'', u'form': u'VIAL', u'brand': u'PERONIS', u'strength_3': u'', u'company': u'NEISS', u'unit': u''}

-- line #6728
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefoperazone', u'always_empty': u'', u'form': u'INJ', u'brand': u'PIRAZONE', u'strength_3': u'', u'company': u'PREM PH.', u'unit': u''}

-- line #6729
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefoperazone', u'always_empty': u'', u'form': u'V', u'brand': u'PURECEF', u'strength_3': u'', u'company': u'Samarth', u'unit': u''}

-- line #6730
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BID 125 (Merck)',
	'CEFOROXIME',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BID 125 (Merck)'
);

-- line #6731
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BID 250 (Merck)',
	'CEFOROXIME',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BID 250 (Merck)'
);

-- line #6732
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BID 500 (Merck)',
	'CEFOROXIME',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BID 500 (Merck)'
);

-- line #6733
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1GM', u'strength_2': u'', u'substance': u'Cefotaxime', u'always_empty': u'', u'form': u'DS INJ', u'brand': u'AMCIL-T', u'strength_3': u'', u'company': u'Perk Ph.', u'unit': u''}

-- line #6734
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMCIL-T 250 (Perk Ph.)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMCIL-T 250 (Perk Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMCIL-T 500 (Perk Ph.)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMCIL-T 500 (Perk Ph.)'
);

-- line #6735
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANITOX 1000 (Phytochem)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANITOX 1000 (Phytochem)'
);

-- line #6736
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANITOX 250 (Phytochem)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANITOX 250 (Phytochem)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANITOX 500 (Phytochem)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANITOX 500 (Phytochem)'
);

-- line #6737
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVICEF 125 (Admac Ph.)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVICEF 125 (Admac Ph.)'
);

-- line #6738
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefotaxime', u'always_empty': u'', u'form': u'INJ', u'brand': u'AVICEF', u'strength_3': u'', u'company': u'Admac Ph.', u'unit': u''}

-- line #6739
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVICEF 250 (Admac Ph.)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVICEF 250 (Admac Ph.)'
);

-- line #6740
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVICEF 500 (Admac Ph.)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVICEF 500 (Admac Ph.)'
);

-- line #6741
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXIM 250 (Kee Ph.)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/1G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXIM 250 (Kee Ph.)'
);

-- line #6742
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefotaxime', u'always_empty': u'', u'form': u'INJ', u'brand': u'AXIOM', u'strength_3': u'', u'company': u'Panjon', u'unit': u''}

-- line #6743
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BESTAX 125 (Biological E.)',
	'Cefotaxime',
	'V',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BESTAX 125 (Biological E.)'
);

-- line #6744
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefotaxime', u'always_empty': u'', u'form': u'V', u'brand': u'BESTAX', u'strength_3': u'', u'company': u'Biological E.', u'unit': u''}

-- line #6745
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BESTAX 250 (Biological E.)',
	'Cefotaxime',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BESTAX 250 (Biological E.)'
);

-- line #6746
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BESTAX 500 (Biological E.)',
	'Cefotaxime',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BESTAX 500 (Biological E.)'
);

-- line #6747
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOTAX 125 (Biochem)',
	'Cefotaxime',
	'V',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOTAX 125 (Biochem)'
);

-- line #6748
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefotaxime', u'always_empty': u'', u'form': u'V', u'brand': u'BIOTAX', u'strength_3': u'', u'company': u'Biochem', u'unit': u''}

-- line #6749
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOTAX 250 (Biochem)',
	'Cefotaxime',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOTAX 250 (Biochem)'
);

-- line #6750
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOTAX 500 (Biochem)',
	'Cefotaxime',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOTAX 500 (Biochem)'
);

-- line #6751
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefotaxime', u'always_empty': u'', u'form': u'TM INJ', u'brand': u'BLUCEF', u'strength_3': u'', u'company': u'Blue Cross', u'unit': u''}

-- line #6752
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLUCEF 250 (Blue Cross)',
	'Cefotaxime',
	'TM INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLUCEF 250 (Blue Cross)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLUCEF 500 (Blue Cross)',
	'Cefotaxime',
	'TM INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLUCEF 500 (Blue Cross)'
);

-- line #6753
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLUTAX 125 (Blue Cross)',
	'Cefotaxime',
	'V',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLUTAX 125 (Blue Cross)'
);

-- line #6754
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefotaxime', u'always_empty': u'', u'form': u'V', u'brand': u'BLUTAX', u'strength_3': u'', u'company': u'Blue Cross', u'unit': u''}

-- line #6755
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLUTAX 250 (Blue Cross)',
	'Cefotaxime',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLUTAX 250 (Blue Cross)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLUTAX 500 (Blue Cross)',
	'Cefotaxime',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLUTAX 500 (Blue Cross)'
);

-- line #6756
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefotaxime', u'always_empty': u'', u'form': u'INJ', u'brand': u'CEFADEN', u'strength_3': u'', u'company': u'Eden Hc.', u'unit': u''}

-- line #6757
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFADEN 250 (Eden Hc.)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFADEN 250 (Eden Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFADEN 500 (Eden Hc.)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFADEN 500 (Eden Hc.)'
);

-- line #6758
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFANTRAL 125 (Lupin)',
	'Cefotaxime',
	'V',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFANTRAL 125 (Lupin)'
);

-- line #6759
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefotaxime', u'always_empty': u'', u'form': u'V', u'brand': u'CEFANTRAL', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #6760
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFANTRAL 250 (Lupin)',
	'Cefotaxime',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFANTRAL 250 (Lupin)'
);

-- line #6761
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFANTRAL 500 (Lupin)',
	'Cefotaxime',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFANTRAL 500 (Lupin)'
);

-- line #6762
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFLIN 125 (Lincoln)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFLIN 125 (Lincoln)'
);

-- line #6763
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefotaxime', u'always_empty': u'', u'form': u'INJ', u'brand': u'CEFLIN', u'strength_3': u'', u'company': u'Lincoln', u'unit': u''}

-- line #6764
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFLIN 250 (Lincoln)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFLIN 250 (Lincoln)'
);

-- line #6765
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFLIN 500 (Lincoln)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFLIN 500 (Lincoln)'
);

-- line #6766
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOKIL 125 (Global Med.)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOKIL 125 (Global Med.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOKIL 250 (Global Med.)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOKIL 250 (Global Med.)'
);

-- line #6767
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOKIL 500 (Global Med.)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOKIL 500 (Global Med.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOKIL 1000 (Global Med.)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOKIL 1000 (Global Med.)'
);

-- line #6768
-- ignoring line: empty field [company]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'125', u'strength_2': u'', u'substance': u'Cefotaxime', u'always_empty': u'', u'form': u'V', u'brand': u'CEFORED', u'strength_3': u'', u'company': u'', u'unit': u'mg'}

-- line #6769
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefotaxime', u'always_empty': u'', u'form': u'V', u'brand': u'CEFORED', u'strength_3': u'', u'company': u'Redson', u'unit': u''}

-- line #6770
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFORED 250 (Redson)',
	'Cefotaxime',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFORED 250 (Redson)'
);

-- line #6771
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFORED 500 (Redson)',
	'Cefotaxime',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFORED 500 (Redson)'
);

-- line #6772
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFORMARC 125 (Marc Lab)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFORMARC 125 (Marc Lab)'
);

-- line #6773
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefotaxime', u'always_empty': u'', u'form': u'INJ', u'brand': u'CEFORMARC', u'strength_3': u'', u'company': u'Marc Lab', u'unit': u''}

-- line #6774
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFORMARC 250 (Marc Lab)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFORMARC 250 (Marc Lab)'
);

-- line #6775
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2G', u'strength_2': u'', u'substance': u'Cefotaxime', u'always_empty': u'', u'form': u'INJ', u'brand': u'CEFORMARC', u'strength_3': u'', u'company': u'Marc Lab', u'unit': u''}

-- line #6776
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFORMARC 500 (Marc Lab)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFORMARC 500 (Marc Lab)'
);

-- line #6777
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefotaxime', u'always_empty': u'', u'form': u'V', u'brand': u'CEFOTAXIME', u'strength_3': u'', u'company': u'Dopson Ph.', u'unit': u''}

-- line #6778
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOTAXIME 250 (Dopson Ph.)',
	'Cefotaxime',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOTAXIME 250 (Dopson Ph.)'
);

-- line #6779
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOTAXIME 500 (Dopson Ph.)',
	'Cefotaxime',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOTAXIME 500 (Dopson Ph.)'
);

-- line #6780
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOTIM 1000 (Zydus Cadila(Mm))',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOTIM 1000 (Zydus Cadila(Mm))'
);

-- line #6781
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOTIM 250 (Zydus Cadila(Mm))',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOTIM 250 (Zydus Cadila(Mm))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOTIM 500 (Zydus Cadila(Mm))',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOTIM 500 (Zydus Cadila(Mm))'
);

-- line #6782
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOX 1000 (Jackson)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOX 1000 (Jackson)'
);

-- line #6783
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOX 250 (Jackson)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOX 250 (Jackson)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOX 500 (Jackson)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOX 500 (Jackson)'
);

-- line #6784
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTAX 125 (Adison Lab)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTAX 125 (Adison Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTAX 250 (Adison Lab)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTAX 250 (Adison Lab)'
);

-- line #6785
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTAX 500 (Adison Lab)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTAX 500 (Adison Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTAX 1000 (Adison Lab)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTAX 1000 (Adison Lab)'
);

-- line #6786
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefotaxime', u'always_empty': u'', u'form': u'V', u'brand': u'CEFTAX NPPA', u'strength_3': u'', u'company': u'Csc Ph.', u'unit': u''}

-- line #6787
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CENTAX 125 (Intracin)',
	'Cefotaxime',
	'VIAL',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CENTAX 125 (Intracin)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CENTAX 250 (Intracin)',
	'Cefotaxime',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CENTAX 250 (Intracin)'
);

-- line #6788
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CENTAX 500 (Intracin)',
	'Cefotaxime',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CENTAX 500 (Intracin)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CENTAX 1000 (Intracin)',
	'Cefotaxime',
	'VIAL',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CENTAX 1000 (Intracin)'
);

-- line #6789
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefotaxime', u'always_empty': u'', u'form': u'INJ', u'brand': u'CETEXIM', u'strength_3': u'', u'company': u'Secure', u'unit': u''}

-- line #6790
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETEXIM 250 (Secure)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETEXIM 250 (Secure)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETEXIM 500 (Secure)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETEXIM 500 (Secure)'
);

-- line #6791
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIFA 250 (Monokem)',
	'Cefotaxime',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIFA 250 (Monokem)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIFA 1000 (Monokem)',
	'Cefotaxime',
	'VIAL',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIFA 1000 (Monokem)'
);

-- line #6792
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefotaxime', u'always_empty': u'', u'form': u'V', u'brand': u'CLAFORAN', u'strength_3': u'', u'company': u'Sanofi Aventis', u'unit': u''}

-- line #6793
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLAFORAN 250 (Sanofi Aventis)',
	'Cefotaxime',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLAFORAN 250 (Sanofi Aventis)'
);

-- line #6794
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLAFORAN 500 (Sanofi Aventis)',
	'Cefotaxime',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLAFORAN 500 (Sanofi Aventis)'
);

-- line #6795
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COTAX 125 (Dynamic)',
	'Cefotaxime',
	'V',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COTAX 125 (Dynamic)'
);

-- line #6796
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefotaxime', u'always_empty': u'', u'form': u'V', u'brand': u'COTAX', u'strength_3': u'', u'company': u'Dynamic', u'unit': u''}

-- line #6797
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COTAX 250 (Dynamic)',
	'Cefotaxime',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COTAX 250 (Dynamic)'
);

-- line #6798
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COTAX 500 (Dynamic)',
	'Cefotaxime',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COTAX 500 (Dynamic)'
);

-- line #6799
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-TAX 125 (Emcure)',
	'Cefotaxime',
	'V',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-TAX 125 (Emcure)'
);

-- line #6800
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.5G', u'strength_2': u'', u'substance': u'Cefotaxime', u'always_empty': u'', u'form': u'V', u'brand': u'C-TAX', u'strength_3': u'', u'company': u'Emcure', u'unit': u''}

-- line #6801
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefotaxime', u'always_empty': u'', u'form': u'V', u'brand': u'C-TAX', u'strength_3': u'', u'company': u'Emcure', u'unit': u''}

-- line #6802
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-TAX 250 (Emcure)',
	'Cefotaxime',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-TAX 250 (Emcure)'
);

-- line #6803
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-TAX 500 (Emcure)',
	'Cefotaxime',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-TAX 500 (Emcure)'
);

-- line #6804
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CT 1000 (Goodluck Ph.)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CT 1000 (Goodluck Ph.)'
);

-- line #6805
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CT 250 (Goodluck Ph.)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CT 250 (Goodluck Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CT 500 (Goodluck Ph.)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CT 500 (Goodluck Ph.)'
);

-- line #6806
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefotaxime', u'always_empty': u'', u'form': u'V', u'brand': u'DESATAX', u'strength_3': u'', u'company': u'SHREYA', u'unit': u''}

-- line #6807
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DESATAX 250 (SHREYA)',
	'Cefotaxime',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DESATAX 250 (SHREYA)'
);

-- line #6808
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DESATAX 500 (SHREYA)',
	'Cefotaxime',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DESATAX 500 (SHREYA)'
);

-- line #6809
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Cefotaxime', u'always_empty': u'', u'form': u'INJ', u'brand': u'DIVITAXIME', u'strength_3': u'', u'company': u'DIVINE LAB.', u'unit': u''}

-- line #6810
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EFOTAX 125 (Reliance)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EFOTAX 125 (Reliance)'
);

-- line #6811
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefotaxime', u'always_empty': u'', u'form': u'INJ', u'brand': u'EFOTAX', u'strength_3': u'', u'company': u'Reliance', u'unit': u''}

-- line #6812
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EFOTAX 250 (Reliance)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EFOTAX 250 (Reliance)'
);

-- line #6813
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EFOTAX 500 (Reliance)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EFOTAX 500 (Reliance)'
);

-- line #6814
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELTAX 250 (Elysium)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/1G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELTAX 250 (Elysium)'
);

-- line #6815
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefotaxime', u'always_empty': u'', u'form': u'V', u'brand': u'ERATAX', u'strength_3': u'', u'company': u'Brawn Lab', u'unit': u''}

-- line #6816
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERATAX 250 (Brawn Lab)',
	'Cefotaxime',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERATAX 250 (Brawn Lab)'
);

-- line #6817
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERATAX 500 (Brawn Lab)',
	'Cefotaxime',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERATAX 500 (Brawn Lab)'
);

-- line #6818
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EVACEF 125 (Neon)',
	'Cefotaxime',
	'V',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EVACEF 125 (Neon)'
);

-- line #6819
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefotaxime', u'always_empty': u'', u'form': u'V', u'brand': u'EVACEF', u'strength_3': u'', u'company': u'Neon', u'unit': u''}

-- line #6820
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EVACEF 250 (Neon)',
	'Cefotaxime',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EVACEF 250 (Neon)'
);

-- line #6821
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EVACEF 500 (Neon)',
	'Cefotaxime',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EVACEF 500 (Neon)'
);

-- line #6822
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefotaxime', u'always_empty': u'', u'form': u'V', u'brand': u'FAXIM', u'strength_3': u'', u'company': u'Chemech', u'unit': u''}

-- line #6823
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAXIM 250 (Chemech)',
	'Cefotaxime',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAXIM 250 (Chemech)'
);

-- line #6824
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAXTIME 250 (SALVO HC.)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/1GM'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAXTIME 250 (SALVO HC.)'
);

-- line #6825
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAXTIME 500 (SALVO HC.)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAXTIME 500 (SALVO HC.)'
);

-- line #6826
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FINTAXIM 1000 (Finesse Ph.)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FINTAXIM 1000 (Finesse Ph.)'
);

-- line #6827
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FINTAXIM 250 (Finesse Ph.)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FINTAXIM 250 (Finesse Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FINTAXIM 500 (Finesse Ph.)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FINTAXIM 500 (Finesse Ph.)'
);

-- line #6828
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefotaxime', u'always_empty': u'', u'form': u'INJ', u'brand': u'FLAMOTAX', u'strength_3': u'', u'company': u'FLAMINGO PH.', u'unit': u''}

-- line #6829
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefotaxime', u'always_empty': u'', u'form': u'V', u'brand': u'FOTIME', u'strength_3': u'', u'company': u'Maan', u'unit': u''}

-- line #6830
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOTIME 250 (Maan)',
	'Cefotaxime',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOTIME 250 (Maan)'
);

-- line #6831
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOTIME 500 (Maan)',
	'Cefotaxime',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOTIME 500 (Maan)'
);

-- line #6832
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefotaxime', u'always_empty': u'', u'form': u'INJ', u'brand': u'GRATAX', u'strength_3': u'', u'company': u'Graf Lab.', u'unit': u''}

-- line #6833
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRATAX 250 (Graf Lab.)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRATAX 250 (Graf Lab.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRATAX 500 (Graf Lab.)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRATAX 500 (Graf Lab.)'
);

-- line #6834
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1GM', u'strength_2': u'', u'substance': u'Cefotaxime', u'always_empty': u'', u'form': u'INJ', u'brand': u'GREATAX', u'strength_3': u'', u'company': u'Brooks Ph.', u'unit': u''}

-- line #6835
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefotaxime', u'always_empty': u'', u'form': u'V', u'brand': u'HALTAX', u'strength_3': u'', u'company': u'Hal', u'unit': u''}

-- line #6836
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALTAX 250 (Hal)',
	'Cefotaxime',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALTAX 250 (Hal)'
);

-- line #6837
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALTAX 500 (Hal)',
	'Cefotaxime',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALTAX 500 (Hal)'
);

-- line #6838
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefotaxime', u'always_empty': u'', u'form': u'INJ', u'brand': u'INTAX', u'strength_3': u'', u'company': u'Intra Lab', u'unit': u''}

-- line #6839
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTAX 250 (Intra Lab)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTAX 250 (Intra Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTAX 500 (Intra Lab)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTAX 500 (Intra Lab)'
);

-- line #6840
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IVITAX 1000 (VHB)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IVITAX 1000 (VHB)'
);

-- line #6841
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IVITAX 125 (VHB)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IVITAX 125 (VHB)'
);

-- line #6842
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IVITAX 250 (VHB)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IVITAX 250 (VHB)'
);

-- line #6843
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IVITAX 500 (VHB)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IVITAX 500 (VHB)'
);

-- line #6844
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefotaxime', u'always_empty': u'', u'form': u'V', u'brand': u'LYFORAN', u'strength_3': u'', u'company': u'HETERO HC.', u'unit': u''}

-- line #6845
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYFORAN 250 (HETERO HC.)',
	'Cefotaxime',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYFORAN 250 (HETERO HC.)'
);

-- line #6846
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefotaxime', u'always_empty': u'', u'form': u'INJ', u'brand': u'MILTAX', u'strength_3': u'', u'company': u'Shaimil', u'unit': u''}

-- line #6847
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILTAX 250 (Shaimil)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILTAX 250 (Shaimil)'
);

-- line #6848
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefotaxime', u'always_empty': u'', u'form': u'INJ', u'brand': u'MUTAX', u'strength_3': u'', u'company': u'CH.Bhagat', u'unit': u''}

-- line #6849
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUTAX 250 (CH.Bhagat)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUTAX 250 (CH.Bhagat)'
);

-- line #6850
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUTAX 500 (CH.Bhagat)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUTAX 500 (CH.Bhagat)'
);

-- line #6851
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYTAX 1000 (Solitaire)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYTAX 1000 (Solitaire)'
);

-- line #6852
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYTAX 250 (Solitaire)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYTAX 250 (Solitaire)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYTAX 500 (Solitaire)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYTAX 500 (Solitaire)'
);

-- line #6853
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NACXIME 500 (Nac Int.)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NACXIME 500 (Nac Int.)'
);

-- line #6854
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NATOCEF 1000 (Pfiscar Ind.)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NATOCEF 1000 (Pfiscar Ind.)'
);

-- line #6855
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NATOCEF 250 (Pfiscar Ind.)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NATOCEF 250 (Pfiscar Ind.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NATOCEF 500 (Pfiscar Ind.)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NATOCEF 500 (Pfiscar Ind.)'
);

-- line #6856
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefotaxime', u'always_empty': u'', u'form': u'V', u'brand': u'NEPOTAX', u'strength_3': u'', u'company': u'Ttk Hc.', u'unit': u''}

-- line #6857
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEPOTAX 250 (Ttk Hc.)',
	'Cefotaxime',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEPOTAX 250 (Ttk Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEPOTAX 500 (Ttk Hc.)',
	'Cefotaxime',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEPOTAX 500 (Ttk Hc.)'
);

-- line #6858
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NILSTAT 125 (Uni-Sank.)',
	'Cefotaxime',
	'V',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NILSTAT 125 (Uni-Sank.)'
);

-- line #6859
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefotaxime', u'always_empty': u'', u'form': u'V', u'brand': u'NILSTAT', u'strength_3': u'', u'company': u'Uni-Sank.', u'unit': u''}

-- line #6860
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NILSTAT 250 (Uni-Sank.)',
	'Cefotaxime',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NILSTAT 250 (Uni-Sank.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NILSTAT 500 (Uni-Sank.)',
	'Cefotaxime',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NILSTAT 500 (Uni-Sank.)'
);

-- line #6861
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITAXIN 1000 (Nitin Ph.)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITAXIN 1000 (Nitin Ph.)'
);

-- line #6862
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITAXIN 250 (Nitin Ph.)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITAXIN 250 (Nitin Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITAXIN 500 (Nitin Ph.)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITAXIN 500 (Nitin Ph.)'
);

-- line #6863
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefotaxime', u'always_empty': u'', u'form': u'V', u'brand': u'NOVATAX', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #6864
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVATAX 250 (Cipla)',
	'Cefotaxime',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVATAX 250 (Cipla)'
);

-- line #6865
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVATAX 500 (Cipla)',
	'Cefotaxime',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVATAX 500 (Cipla)'
);

-- line #6866
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUTAXIN 1000 (Aglowmed)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUTAXIN 1000 (Aglowmed)'
);

-- line #6867
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUTAXIN 125 (Aglowmed)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUTAXIN 125 (Aglowmed)'
);

-- line #6868
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUTAXIN 250 (Aglowmed)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUTAXIN 250 (Aglowmed)'
);

-- line #6869
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUTAXIN 500 (Aglowmed)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUTAXIN 500 (Aglowmed)'
);

-- line #6870
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUTAXIN 125 (Aglowmed)',
	'Cefotaxime',
	'V',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUTAXIN 125 (Aglowmed)'
);

-- line #6871
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefotaxime', u'always_empty': u'', u'form': u'V', u'brand': u'NUTAXIN', u'strength_3': u'', u'company': u'Aglowmed', u'unit': u''}

-- line #6872
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUTAXIN 250 (Aglowmed)',
	'Cefotaxime',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUTAXIN 250 (Aglowmed)'
);

-- line #6873
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUTAXIN 500 (Aglowmed)',
	'Cefotaxime',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUTAXIN 500 (Aglowmed)'
);

-- line #6874
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMINAX 125 (Mapra)',
	'Cefotaxime',
	'V',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMINAX 125 (Mapra)'
);

-- line #6875
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefotaxime', u'always_empty': u'', u'form': u'V', u'brand': u'OMINAX', u'strength_3': u'', u'company': u'Mapra', u'unit': u''}

-- line #6876
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMINAX 250 (Mapra)',
	'Cefotaxime',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMINAX 250 (Mapra)'
);

-- line #6877
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMINAX 500 (Mapra)',
	'Cefotaxime',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMINAX 500 (Mapra)'
);

-- line #6878
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefotaxime', u'always_empty': u'', u'form': u'V', u'brand': u'OMNATAX', u'strength_3': u'', u'company': u'Nicholas', u'unit': u''}

-- line #6879
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMNATAX 250 (Nicholas)',
	'Cefotaxime',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMNATAX 250 (Nicholas)'
);

-- line #6880
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMNATAX 500 (Nicholas)',
	'Cefotaxime',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMNATAX 500 (Nicholas)'
);

-- line #6881
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMNICEF 125 (Aristo)',
	'Cefotaxime',
	'V',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMNICEF 125 (Aristo)'
);

-- line #6882
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefotaxime', u'always_empty': u'', u'form': u'V', u'brand': u'OMNICEF', u'strength_3': u'', u'company': u'Aristo', u'unit': u''}

-- line #6883
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMNICEF 250 (Aristo)',
	'Cefotaxime',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMNICEF 250 (Aristo)'
);

-- line #6884
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMNICEF 500 (Aristo)',
	'Cefotaxime',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMNICEF 500 (Aristo)'
);

-- line #6885
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMTAX 1000 (Om Bio.)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMTAX 1000 (Om Bio.)'
);

-- line #6886
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMTAX 250 (Om Bio.)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMTAX 250 (Om Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMTAX 500 (Om Bio.)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMTAX 500 (Om Bio.)'
);

-- line #6887
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORILAC 250 (Ophthal R.)',
	'Cefotaxime',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORILAC 250 (Ophthal R.)'
);

-- line #6888
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORILAC 125 (Ophthal R.)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORILAC 125 (Ophthal R.)'
);

-- line #6889
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefotaxime', u'always_empty': u'', u'form': u'INJ', u'brand': u'ORILAC', u'strength_3': u'', u'company': u'Ophthal R.', u'unit': u''}

-- line #6890
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORILAC 250 (Ophthal R.)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORILAC 250 (Ophthal R.)'
);

-- line #6891
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORILAC 500 (Ophthal R.)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORILAC 500 (Ophthal R.)'
);

-- line #6892
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefotaxime', u'always_empty': u'', u'form': u'V', u'brand': u'ORITAXIM', u'strength_3': u'', u'company': u'Cadila (G.)', u'unit': u''}

-- line #6893
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORITAXIM 250 (Cadila (G.))',
	'Cefotaxime',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORITAXIM 250 (Cadila (G.))'
);

-- line #6894
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORITAXIM 500 (Cadila (G.))',
	'Cefotaxime',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORITAXIM 500 (Cadila (G.))'
);

-- line #6895
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSOTAX 125 (Osper)',
	'Cefotaxime',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg/250'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSOTAX 125 (Osper)'
);

-- line #6896
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefotaxime', u'always_empty': u'', u'form': u'TAB', u'brand': u'OSOTAX', u'strength_3': u'', u'company': u'Osper', u'unit': u''}

-- line #6897
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSOTAX 500 (Osper)',
	'Cefotaxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSOTAX 500 (Osper)'
);

-- line #6898
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefotaxime', u'always_empty': u'', u'form': u'INJ', u'brand': u'OTAX', u'strength_3': u'', u'company': u'Oscar Rem.', u'unit': u''}

-- line #6899
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OTAX 250 (Oscar Rem.)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OTAX 250 (Oscar Rem.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OTAX 500 (Oscar Rem.)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OTAX 500 (Oscar Rem.)'
);

-- line #6900
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefotaxime', u'always_empty': u'', u'form': u'INJ', u'brand': u'POSTOP', u'strength_3': u'', u'company': u'Medispan', u'unit': u''}

-- line #6901
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POSTOP 250 (Medispan)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POSTOP 250 (Medispan)'
);

-- line #6902
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROCEF 1000 (Prohealth)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROCEF 1000 (Prohealth)'
);

-- line #6903
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROCEF 250 (Prohealth)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROCEF 250 (Prohealth)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROCEF 500 (Prohealth)',
	'Cefotaxime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROCEF 500 (Prohealth)'
);

-- line #6904
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefpirome', u'always_empty': u'', u'form': u'INJ', u'brand': u'ALLARD', u'strength_3': u'', u'company': u'Ikon Rem', u'unit': u''}

-- line #6905
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefpirome', u'always_empty': u'', u'form': u'VIAL', u'brand': u'BACIROM', u'strength_3': u'', u'company': u'Aristo', u'unit': u''}

-- line #6906
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACIROM 250 (Aristo)',
	'Cefpirome',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACIROM 250 (Aristo)'
);

-- line #6907
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACIROM 500 (Aristo)',
	'Cefpirome',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACIROM 500 (Aristo)'
);

-- line #6908
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefpirome', u'always_empty': u'', u'form': u'INJ', u'brand': u'CEF-4', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #6909
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFIM IV 250 (TALENT LAB.)',
	'Cefpirome',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/1G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFIM IV 250 (TALENT LAB.)'
);

-- line #6910
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOR 500 (United Bio.)',
	'Cefpirome',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOR 500 (United Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOR 1000 (United Bio.)',
	'Cefpirome',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOR 1000 (United Bio.)'
);

-- line #6911
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefpirome', u'always_empty': u'', u'form': u'INJ', u'brand': u'CEFORTH', u'strength_3': u'', u'company': u'Biochem', u'unit': u''}

-- line #6912
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefpirome', u'always_empty': u'', u'form': u'INJ', u'brand': u'CEFPH', u'strength_3': u'', u'company': u'Sanjivani', u'unit': u''}

-- line #6913
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefpirome', u'always_empty': u'', u'form': u'V', u'brand': u'CEFROM', u'strength_3': u'', u'company': u'Sanofi Aventis', u'unit': u''}

-- line #6914
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefpirome', u'always_empty': u'', u'form': u'INJ', u'brand': u'CEPIROM', u'strength_3': u'', u'company': u'Orchid Hc.', u'unit': u''}

-- line #6915
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIFY 1000 (Phytochem)',
	'Cefpirome',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIFY 1000 (Phytochem)'
);

-- line #6916
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefpirome', u'always_empty': u'', u'form': u'INJ', u'brand': u'C-ROME', u'strength_3': u'', u'company': u'Mapra', u'unit': u''}

-- line #6917
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-ROME 250 (Mapra)',
	'Cefpirome',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-ROME 250 (Mapra)'
);

-- line #6918
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORGEN 250 (Alkem)',
	'Cefpirome',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORGEN 250 (Alkem)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORGEN 500 (Alkem)',
	'Cefpirome',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORGEN 500 (Alkem)'
);

-- line #6919
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefpirome', u'always_empty': u'', u'form': u'VIAL', u'brand': u'FORGEN', u'strength_3': u'', u'company': u'Alkem', u'unit': u''}

-- line #6920
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefpirome', u'always_empty': u'', u'form': u'', u'brand': u'GENPIROME', u'strength_3': u'', u'company': u'Biocon', u'unit': u''}

-- line #6921
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIPIROM 1000 (Redson)',
	'Cefpirome',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIPIROM 1000 (Redson)'
);

-- line #6922
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefpirome', u'always_empty': u'', u'form': u'VIAL', u'brand': u'IVIROME', u'strength_3': u'', u'company': u'Vhb', u'unit': u''}

-- line #6923
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefpirome', u'always_empty': u'', u'form': u'INJ', u'brand': u'NEOPIROME', u'strength_3': u'', u'company': u'NEON', u'unit': u''}

-- line #6924
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEXTGEN 1000 (Pfiscar Ind.)',
	'Cefpirome',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEXTGEN 1000 (Pfiscar Ind.)'
);

-- line #6925
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefpirome', u'always_empty': u'', u'form': u'VIAL', u'brand': u'NISPIROME', u'strength_3': u'', u'company': u'NEISS', u'unit': u''}

-- line #6926
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITPIROME 1000 (Nitin Ph.)',
	'Cefpirome',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITPIROME 1000 (Nitin Ph.)'
);

-- line #6927
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefpirome', u'always_empty': u'', u'form': u'INJ', u'brand': u'OMNIROM', u'strength_3': u'', u'company': u'CIPLA', u'unit': u''}

-- line #6928
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefpirome', u'always_empty': u'', u'form': u'INJ', u'brand': u'OPIROM', u'strength_3': u'', u'company': u'Osper', u'unit': u''}

-- line #6929
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPIROM 250 (Osper)',
	'Cefpirome',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/500'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPIROM 250 (Osper)'
);

-- line #6930
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefpirome', u'always_empty': u'', u'form': u'INJ', u'brand': u'PRADO', u'strength_3': u'', u'company': u'INNOVATIVE', u'unit': u''}

-- line #6931
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'P-ROM 1000 (Global Med.)',
	'Cefpirome',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'P-ROM 1000 (Global Med.)'
);

-- line #6932
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'P-ROM 250 (Global Med.)',
	'Cefpirome',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'P-ROM 250 (Global Med.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'P-ROM 500 (Global Med.)',
	'Cefpirome',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'P-ROM 500 (Global Med.)'
);

-- line #6933
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REFZIL 1000 (Stancare)',
	'Cefpirome',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REFZIL 1000 (Stancare)'
);

-- line #6934
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REFZIL 500 (Stancare)',
	'Cefpirome',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REFZIL 500 (Stancare)'
);

-- line #6935
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AKPOD 50 (AKESISS)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AKPOD 50 (AKESISS)'
);

-- line #6936
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AKPOD 100 (AKESISS)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AKPOD 100 (AKESISS)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AKPOD 200 (AKESISS)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AKPOD 200 (AKESISS)'
);

-- line #6937
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALCEPID KID 50 (CORE GESTRA)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALCEPID KID 50 (CORE GESTRA)'
);

-- line #6938
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALCEPID 200 (CORE GESTRA)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALCEPID 200 (CORE GESTRA)'
);

-- line #6939
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANDROXIL 200 (Symbiosis Lab.)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANDROXIL 200 (Symbiosis Lab.)'
);

-- line #6940
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AQDOXIM 50 (Aquila)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AQDOXIM 50 (Aquila)'
);

-- line #6941
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AQDOXIM 100 (Aquila)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AQDOXIM 100 (Aquila)'
);

-- line #6942
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AQDOXIM 200 (Aquila)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AQDOXIM 200 (Aquila)'
);

-- line #6943
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AQDOXIM 50 (Aquila)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AQDOXIM 50 (Aquila)'
);

-- line #6944
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARODOX 50 (Aronex Life)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARODOX 50 (Aronex Life)'
);

-- line #6945
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARODOX 50 (Aronex Life)',
	'CEFPODOXIME',
	'DT TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARODOX 50 (Aronex Life)'
);

-- line #6946
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARODOX 100 (Aronex Life)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARODOX 100 (Aronex Life)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARODOX 200 (Aronex Life)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARODOX 200 (Aronex Life)'
);

-- line #6947
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATACK 50 (Olcare)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATACK 50 (Olcare)'
);

-- line #6948
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATACK 100 (Olcare)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATACK 100 (Olcare)'
);

-- line #6949
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATACK 200 (Olcare)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATACK 200 (Olcare)'
);

-- line #6950
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATACK 50 (Olcare)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATACK 50 (Olcare)'
);

-- line #6951
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'CEFPODOXIME', u'always_empty': u'', u'form': u'VIAL', u'brand': u'ATACK', u'strength_3': u'', u'company': u'Olcare', u'unit': u''}

-- line #6952
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATACK 250 (Olcare)',
	'CEFPODOXIME',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATACK 250 (Olcare)'
);

-- line #6953
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVICEF-O 50 (UNI-SANKYO)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVICEF-O 50 (UNI-SANKYO)'
);

-- line #6954
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVICEF-O 100 (Admac Ph.)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVICEF-O 100 (Admac Ph.)'
);

-- line #6955
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVICEF-O 50 (Admac Ph.)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVICEF-O 50 (Admac Ph.)'
);

-- line #6956
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACTOGARD 100 (Indoco Rem.)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACTOGARD 100 (Indoco Rem.)'
);

-- line #6957
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACTOGARD 200 (Indoco Rem.)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACTOGARD 200 (Indoco Rem.)'
);

-- line #6958
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BANIN 50 (UNI-SANKYO)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BANIN 50 (UNI-SANKYO)'
);

-- line #6959
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BANIN 100 (UNI-SANKYO)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BANIN 100 (UNI-SANKYO)'
);

-- line #6960
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BANIN 200 (UNI-SANKYO)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BANIN 200 (UNI-SANKYO)'
);

-- line #6961
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BAROXIME 50 (BARODA)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BAROXIME 50 (BARODA)'
);

-- line #6962
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BAROXIME 200 (BARODA)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BAROXIME 200 (BARODA)'
);

-- line #6963
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BAROXIME 50 (BARODA)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BAROXIME 50 (BARODA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BAROXIME 100 (BARODA)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BAROXIME 100 (BARODA)'
);

-- line #6964
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BELPRO 50 (BLUBELL)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BELPRO 50 (BLUBELL)'
);

-- line #6965
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BELPRO 100 (BLUBELL)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BELPRO 100 (BLUBELL)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BELPRO 200 (BLUBELL)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BELPRO 200 (BLUBELL)'
);

-- line #6966
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLUEFOX-100 100 (BLUE WINGS)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLUEFOX-100 100 (BLUE WINGS)'
);

-- line #6967
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLUEFOX-200 200 (BLUE WINGS)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLUEFOX-200 200 (BLUE WINGS)'
);

-- line #6968
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100', u'strength_2': u'', u'substance': u'CEFPODOXIME', u'always_empty': u'', u'form': u'', u'brand': u'CACEF', u'strength_3': u'', u'company': u'Cachet', u'unit': u'mg'}

-- line #6969
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200', u'strength_2': u'', u'substance': u'CEFPODOXIME', u'always_empty': u'', u'form': u'', u'brand': u'CACEF', u'strength_3': u'', u'company': u'Cachet', u'unit': u'mg'}

-- line #6970
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CACEF 50 (Cachet)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CACEF 50 (Cachet)'
);

-- line #6971
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAFAGE-O 100 (ALLENGE)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAFAGE-O 100 (ALLENGE)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAFAGE-O 200 (ALLENGE)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAFAGE-O 200 (ALLENGE)'
);

-- line #6972
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAFAGE-O 50 (ALLENGE)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAFAGE-O 50 (ALLENGE)'
);

-- line #6973
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAFAGE 50 (ALLENGE)',
	'CEFPODOXIME',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAFAGE 50 (ALLENGE)'
);

-- line #6974
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANISS-100 100 (CHEMO HC.)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANISS-100 100 (CHEMO HC.)'
);

-- line #6975
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANISS-200 200 (CHEMO HC.)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANISS-200 200 (CHEMO HC.)'
);

-- line #6976
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CASPOD 100 (CASCA)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CASPOD 100 (CASCA)'
);

-- line #6977
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CASPOD 200 (CASCA)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CASPOD 200 (CASCA)'
);

-- line #6978
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CCL 100 (Indi Ph.)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CCL 100 (Indi Ph.)'
);

-- line #6979
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CCL 50 (Indi Ph.)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CCL 50 (Indi Ph.)'
);

-- line #6980
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CDM 100 (L & V PH.)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CDM 100 (L & V PH.)'
);

-- line #6981
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CDM 200 (L & V PH.)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CDM 200 (L & V PH.)'
);

-- line #6982
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-DOX 50 (SHINCE)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-DOX 50 (SHINCE)'
);

-- line #6983
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-DOX 100 (SHINCE)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-DOX 100 (SHINCE)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-DOX 200 (SHINCE)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-DOX 200 (SHINCE)'
);

-- line #6984
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200', u'strength_2': u'', u'substance': u'CEFPODOXIME', u'always_empty': u'', u'form': u'', u'brand': u'CEDO-200', u'strength_3': u'', u'company': u'PARAMOUNT HC.', u'unit': u'mg'}

-- line #6985
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEDO 50 (PARAMOUNT HC.)',
	'Cefpodoxime',
	'D.SYRUP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEDO 50 (PARAMOUNT HC.)'
);

-- line #6986
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEDON 50 (Blue Cross)',
	'CEFPODOXIME',
	'DPS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEDON 50 (Blue Cross)'
);

-- line #6987
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEDON 50 (Blue Cross)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEDON 50 (Blue Cross)'
);

-- line #6988
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEDON-P 50 (Blue Cross)',
	'CEFPODOXIME',
	'DPS',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEDON-P 50 (Blue Cross)'
);

-- line #6989
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEDON 100 (Blue Cross)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEDON 100 (Blue Cross)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEDON 200 (Blue Cross)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEDON 200 (Blue Cross)'
);

-- line #6990
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEDON 50 (Blue Cross)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEDON 50 (Blue Cross)'
);

-- line #6991
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEDOXIME 50 (AKUM(ALCARE))',
	'CEFPODOXIME',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEDOXIME 50 (AKUM(ALCARE))'
);

-- line #6992
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAKIND-P 50 (Mankind)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAKIND-P 50 (Mankind)'
);

-- line #6993
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAKIND-P 50 (Mankind)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAKIND-P 50 (Mankind)'
);

-- line #6994
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFANTIB 100 (Group Ph.)',
	'Cefpodoxime',
	'D.SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFANTIB 100 (Group Ph.)'
);

-- line #6995
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFA-Q 50 (Que Ph.)',
	'CEFPODOXIME',
	'D.SYRUP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFA-Q 50 (Que Ph.)'
);

-- line #6996
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFA-Q 100 (Que Ph.)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFA-Q 100 (Que Ph.)'
);

-- line #6997
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFA-Q 200 (Que Ph.)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFA-Q 200 (Que Ph.)'
);

-- line #6998
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFARUN 100 (JARUN PH.)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFARUN 100 (JARUN PH.)'
);

-- line #6999
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFARUN 200 (JARUN PH.)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFARUN 200 (JARUN PH.)'
);

-- line #7000
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFBIL 100 (VILBERRY HC.)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFBIL 100 (VILBERRY HC.)'
);

-- line #7001
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFBIL 50 (VILBERRY HC.)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFBIL 50 (VILBERRY HC.)'
);

-- line #7002
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFBIL 100 (VILBERRY HC.)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFBIL 100 (VILBERRY HC.)'
);

-- line #7003
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFBIL 200 (VILBERRY HC.)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFBIL 200 (VILBERRY HC.)'
);

-- line #7004
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFDOLIFE 200 (LIFE STYLE)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFDOLIFE 200 (LIFE STYLE)'
);

-- line #7005
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFDOXIM DRY 50 (Royal)',
	'CEFPODOXIME',
	'SYP',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFDOXIM DRY 50 (Royal)'
);

-- line #7006
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFDOXIM 100 (Royal Lab)',
	'Cefpodoxime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFDOXIM 100 (Royal Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFDOXIM 200 (Royal Lab)',
	'Cefpodoxime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFDOXIM 200 (Royal Lab)'
);

-- line #7007
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFECTIVE 100 (Merck)',
	'Cefpodoxime',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFECTIVE 100 (Merck)'
);

-- line #7008
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFECTIVE 50 (Merck)',
	'Cefpodoxime',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFECTIVE 50 (Merck)'
);

-- line #7009
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFECTIVE 100 (Merck)',
	'Cefpodoxime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFECTIVE 100 (Merck)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFECTIVE 200 (Merck)',
	'Cefpodoxime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFECTIVE 200 (Merck)'
);

-- line #7010
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'CEFPODOXIME', u'always_empty': u'', u'form': u'D.SYR', u'brand': u'CEFGEM', u'strength_3': u'', u'company': u'GEMLIFE PH.', u'unit': u''}

-- line #7011
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFGEM 100 (GEMLIFE PH.)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFGEM 100 (GEMLIFE PH.)'
);

-- line #7012
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFGEM 200 (GEMLIFE PH.)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFGEM 200 (GEMLIFE PH.)'
);

-- line #7013
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFGEM 50 (GEMLIFE PH.)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFGEM 50 (GEMLIFE PH.)'
);

-- line #7014
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFGOL 100 (Parenteral)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFGOL 100 (Parenteral)'
);

-- line #7015
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFGOL 200 (Parenteral)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFGOL 200 (Parenteral)'
);

-- line #7016
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFGOL 50 (Parenteral)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFGOL 50 (Parenteral)'
);

-- line #7017
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFISA 100 (Pharmed)',
	'CEFPODOXIME',
	'CV TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFISA 100 (Pharmed)'
);

-- line #7018
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFISA 200 (Pharmed)',
	'CEFPODOXIME',
	'CV TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFISA 200 (Pharmed)'
);

-- line #7019
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFMAG 100 (Magnus Bio.)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFMAG 100 (Magnus Bio.)'
);

-- line #7020
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFMAG 200 (Magnus Bio.)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFMAG 200 (Magnus Bio.)'
);

-- line #7021
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFMAX 200 (Max Life)',
	'Cefpodoxime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFMAX 200 (Max Life)'
);

-- line #7022
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFO-3 50 (Neuron Ph.)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFO-3 50 (Neuron Ph.)'
);

-- line #7023
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFO-3 100 (Neuron Ph.)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFO-3 100 (Neuron Ph.)'
);

-- line #7024
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOACT 50 (Active Hc.)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOACT 50 (Active Hc.)'
);

-- line #7025
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOACT 100 (Active Hc.)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOACT 100 (Active Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOACT 200 (Active Hc.)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOACT 200 (Active Hc.)'
);

-- line #7026
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOACT 50 (Active Hc.)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOACT 50 (Active Hc.)'
);

-- line #7027
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOBIT 50 (Cubit Hc.)',
	'Cefpodoxime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOBIT 50 (Cubit Hc.)'
);

-- line #7028
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOBIT 100 (Cubit Hc.)',
	'Cefpodoxime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOBIT 100 (Cubit Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOBIT 200 (Cubit Hc.)',
	'Cefpodoxime',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOBIT 200 (Cubit Hc.)'
);

-- line #7029
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFODIME 100 (Medley)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFODIME 100 (Medley)'
);

-- line #7030
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFODIME 50 (Medley)',
	'CEFPODOXIME',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFODIME 50 (Medley)'
);

-- line #7031
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFODIME 200 (Medley)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFODIME 200 (Medley)'
);

-- line #7032
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFODOL-100 100 (DOLPHIN PH.)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFODOL-100 100 (DOLPHIN PH.)'
);

-- line #7033
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFODOX 50 (Bipl(Radico Lab))',
	'Cefpodoxime',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFODOX 50 (Bipl(Radico Lab))'
);

-- line #7034
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFODOX 100 (Bipl(Radico Lab))',
	'Cefpodoxime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFODOX 100 (Bipl(Radico Lab))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFODOX 200 (Bipl(Radico Lab))',
	'Cefpodoxime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFODOX 200 (Bipl(Radico Lab))'
);

-- line #7035
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOGRAM 50 (J.P.LIFE)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOGRAM 50 (J.P.LIFE)'
);

-- line #7036
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOGRAM 200 (J.P.LIFE)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOGRAM 200 (J.P.LIFE)'
);

-- line #7037
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOPROX 50 (CIPLA)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOPROX 50 (CIPLA)'
);

-- line #7038
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOPROX 50 (Cipla)',
	'CEFPODOXIME',
	'DT TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOPROX 50 (Cipla)'
);

-- line #7039
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOPROX 100 (Cipla)',
	'Cefpodoxime',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOPROX 100 (Cipla)'
);

-- line #7040
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOPROX 50 (Cipla)',
	'Cefpodoxime',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOPROX 50 (Cipla)'
);

-- line #7041
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOPROX 100 (Cipla)',
	'Cefpodoxime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOPROX 100 (Cipla)'
);

-- line #7042
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOPROX 200 (Cipla)',
	'Cefpodoxime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOPROX 200 (Cipla)'
);

-- line #7043
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFORIL 50 (SYNOPSIS)',
	'Cefpodoxime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFORIL 50 (SYNOPSIS)'
);

-- line #7044
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOTIL 50 (TENGEE)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOTIL 50 (TENGEE)'
);

-- line #7045
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOTIL 50 (TENGEE)',
	'CEFPODOXIME',
	'KID TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOTIL 50 (TENGEE)'
);

-- line #7046
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOTIL 100 (TENGEE)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOTIL 100 (TENGEE)'
);

-- line #7047
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOTIL 200 (TENGEE)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOTIL 200 (TENGEE)'
);

-- line #7048
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFPIUM 200 (HELIUM HC.)',
	'CEFPODOXIME',
	'DT TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFPIUM 200 (HELIUM HC.)'
);

-- line #7049
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFPODEM 100 (Croslands)',
	'Cefpodoxime',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFPODEM 100 (Croslands)'
);

-- line #7050
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFPODEM 100 (Stancare)',
	'Cefpodoxime',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFPODEM 100 (Stancare)'
);

-- line #7051
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFPODEM 200 (Croslands)',
	'Cefpodoxime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFPODEM 200 (Croslands)'
);

-- line #7052
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFPODEM 100 (Stancare)',
	'Cefpodoxime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFPODEM 100 (Stancare)'
);

-- line #7053
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFPODEM 200 (Stancare)',
	'Cefpodoxime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFPODEM 200 (Stancare)'
);

-- line #7054
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFPO 100 (Finecure)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFPO 100 (Finecure)'
);

-- line #7055
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFPOGARD 100 (Candor Bio.)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFPOGARD 100 (Candor Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFPOGARD 200 (Candor Bio.)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFPOGARD 200 (Candor Bio.)'
);

-- line #7056
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFPOLAR 100 (Lark Labs)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFPOLAR 100 (Lark Labs)'
);

-- line #7057
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFPOLAR 100 (Lark Labs)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFPOLAR 100 (Lark Labs)'
);

-- line #7058
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFPOLAR 200 (Lark Labs)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFPOLAR 200 (Lark Labs)'
);

-- line #7059
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFPO 100 (Finecure)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFPO 100 (Finecure)'
);

-- line #7060
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFPO 200 (Finecure)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFPO 200 (Finecure)'
);

-- line #7061
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFPOTIN 100 (SALVO HC.)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFPOTIN 100 (SALVO HC.)'
);

-- line #7062
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFPOTIN 200 (SALVO HC.)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFPOTIN 200 (SALVO HC.)'
);

-- line #7063
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFSTRONG 50 (Cipla)',
	'CEFPODOXIME',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFSTRONG 50 (Cipla)'
);

-- line #7064
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFSTRONG 200 (Cipla)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFSTRONG 200 (Cipla)'
);

-- line #7065
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTILS 100 (SHRESHTHA)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTILS 100 (SHRESHTHA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTILS 200 (SHRESHTHA)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTILS 200 (SHRESHTHA)'
);

-- line #7066
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTISA 50 (Pharmed)',
	'CEFPODOXIME',
	'CV TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTISA 50 (Pharmed)'
);

-- line #7067
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTISA 100 (Pharmed)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTISA 100 (Pharmed)'
);

-- line #7068
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTISA 50 (Pharmed)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTISA 50 (Pharmed)'
);

-- line #7069
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTISA 50 (Pharmed)',
	'CEFPODOXIME',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTISA 50 (Pharmed)'
);

-- line #7070
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTISA 200 (Pharmed)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTISA 200 (Pharmed)'
);

-- line #7071
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTIS 100 (Pharmed)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTIS 100 (Pharmed)'
);

-- line #7072
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTIS 50 (Pharmed)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTIS 50 (Pharmed)'
);

-- line #7073
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTIS 50 (Pharmed)',
	'CEFPODOXIME',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTIS 50 (Pharmed)'
);

-- line #7074
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTIS 200 (Pharmed)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTIS 200 (Pharmed)'
);

-- line #7075
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTOP 100 (VENSAT)',
	'CEFPODOXIME',
	'DT TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTOP 100 (VENSAT)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTOP 200 (VENSAT)',
	'CEFPODOXIME',
	'DT TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTOP 200 (VENSAT)'
);

-- line #7076
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTOP 50 (VENSAT)',
	'CEFPODOXIME',
	'DT TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTOP 50 (VENSAT)'
);

-- line #7077
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTRU 100 (TRUMAC)',
	'CEFPODOXIME',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTRU 100 (TRUMAC)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTRU 200 (TRUMAC)',
	'CEFPODOXIME',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTRU 200 (TRUMAC)'
);

-- line #7078
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTRU 50 (TRUMAC)',
	'CEFPODOXIME',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTRU 50 (TRUMAC)'
);

-- line #7079
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTRU 50 (TRUMAC)',
	'CEFPODOXIME',
	'DT TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTRU 50 (TRUMAC)'
);

-- line #7080
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFWAR 50 (Leben)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFWAR 50 (Leben)'
);

-- line #7081
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFWAR 100 (Leben)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFWAR 100 (Leben)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFWAR 200 (Leben)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFWAR 200 (Leben)'
);

-- line #7082
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPFOR 50 (Health Care)',
	'Cefpodoxime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPFOR 50 (Health Care)'
);

-- line #7083
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPFOR 50 (Health Care)',
	'Cefpodoxime',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPFOR 50 (Health Care)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPFOR 100 (Health Care)',
	'Cefpodoxime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPFOR 100 (Health Care)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPFOR 200 (Health Care)',
	'Cefpodoxime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPFOR 200 (Health Care)'
);

-- line #7084
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPIME-O 50 (ALEMBIC)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPIME-O 50 (ALEMBIC)'
);

-- line #7085
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPOCARE 200 (VIDACARE PH.)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPOCARE 200 (VIDACARE PH.)'
);

-- line #7086
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPOCOR 100 (Croslands)',
	'Cefpodoxime',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPOCOR 100 (Croslands)'
);

-- line #7087
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPOCOR 50 (Croslands)',
	'Cefpodoxime',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPOCOR 50 (Croslands)'
);

-- line #7088
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPOCOR 100 (Croslands)',
	'Cefpodoxime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPOCOR 100 (Croslands)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPOCOR 200 (Croslands)',
	'Cefpodoxime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPOCOR 200 (Croslands)'
);

-- line #7089
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPODEM 50 (Stancare)',
	'Cefpodoxime',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPODEM 50 (Stancare)'
);

-- line #7090
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPODEM 100 (Stancare)',
	'Cefpodoxime',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPODEM 100 (Stancare)'
);

-- line #7091
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPODEM 50 (Stancare)',
	'Cefpodoxime',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPODEM 50 (Stancare)'
);

-- line #7092
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPODEM 100 (Stancare)',
	'Cefpodoxime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPODEM 100 (Stancare)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPODEM 200 (Stancare)',
	'Cefpodoxime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPODEM 200 (Stancare)'
);

-- line #7093
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPOD-N 100 (NEMI PH.)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPOD-N 100 (NEMI PH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPOD-N 200 (NEMI PH.)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPOD-N 200 (NEMI PH.)'
);

-- line #7094
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPODOM 200 (Dominion)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPODOM 200 (Dominion)'
);

-- line #7095
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPODOX 100 (PHARMATECH)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPODOX 100 (PHARMATECH)'
);

-- line #7096
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPODOX 200 (PHARMATECH)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPODOX 200 (PHARMATECH)'
);

-- line #7097
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPOMAX 50 (Biomax Lab)',
	'Cefpodoxime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPOMAX 50 (Biomax Lab)'
);

-- line #7098
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPORSE 50 (ROSE LABS)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPORSE 50 (ROSE LABS)'
);

-- line #7099
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPOSTER 100 (ASTER PH.)',
	'CEFPODOXIME',
	'DT TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPOSTER 100 (ASTER PH.)'
);

-- line #7100
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPOSTER 200 (ASTER PH.)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPOSTER 200 (ASTER PH.)'
);

-- line #7101
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPOTEC 100 (ICON DRUGS)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPOTEC 100 (ICON DRUGS)'
);

-- line #7102
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'CEFPODOXIME', u'always_empty': u'', u'form': u'SYR', u'brand': u'CEPOTEC', u'strength_3': u'', u'company': u'ICON DRUGS', u'unit': u''}

-- line #7103
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPOTEC 200 (ICON DRUGS)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPOTEC 200 (ICON DRUGS)'
);

-- line #7104
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPOTIL 18 (Orchid Hc.)',
	'Cefpodoxime',
	'D.SYR',
	gm.nullify_empty_string('18')::numeric,
	'mg/30ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPOTIL 18 (Orchid Hc.)'
);

-- line #7105
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPOTIL 100 (Orchid Hc.)',
	'Cefpodoxime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPOTIL 100 (Orchid Hc.)'
);

-- line #7106
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPOTIL 200 (Orchid Hc.)',
	'Cefpodoxime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPOTIL 200 (Orchid Hc.)'
);

-- line #7107
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPOTUF 100 (VANGUARD)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPOTUF 100 (VANGUARD)'
);

-- line #7108
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPOTUF 200 (VANGUARD)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPOTUF 200 (VANGUARD)'
);

-- line #7109
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPOTUS 50 (ICARUS)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPOTUS 50 (ICARUS)'
);

-- line #7110
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPOTUS 100 (ICARUS)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPOTUS 100 (ICARUS)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPOTUS 200 (ICARUS)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPOTUS 200 (ICARUS)'
);

-- line #7111
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPOTUS 50 (ICARUS)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPOTUS 50 (ICARUS)'
);

-- line #7112
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPOXIM 50 (SYNTRO HC.)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPOXIM 50 (SYNTRO HC.)'
);

-- line #7113
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPOXIM 100 (SYNTRO HC.)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPOXIM 100 (SYNTRO HC.)'
);

-- line #7114
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPOXIM 200 (SYNTRO HC.)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPOXIM 200 (SYNTRO HC.)'
);

-- line #7115
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPROSE 200 (ROSE LABS)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPROSE 200 (ROSE LABS)'
);

-- line #7116
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CFDX 100 (Zorex Ph.)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CFDX 100 (Zorex Ph.)'
);

-- line #7117
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CFDX 200 (Zorex Ph.)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CFDX 200 (Zorex Ph.)'
);

-- line #7118
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIFOMAX 200 (AXIS LIFE)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIFOMAX 200 (AXIS LIFE)'
);

-- line #7119
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPONA 100 (Sayona)',
	'Cefpodoxime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPONA 100 (Sayona)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPONA 200 (Sayona)',
	'Cefpodoxime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPONA 200 (Sayona)'
);

-- line #7120
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPOTOZ 50 (Atoz Ph.)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPOTOZ 50 (Atoz Ph.)'
);

-- line #7121
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPOZED 50 (Zota Ph.)',
	'Cefpodoxime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPOZED 50 (Zota Ph.)'
);

-- line #7122
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPOZED 50 (Zota Ph.)',
	'Cefpodoxime',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPOZED 50 (Zota Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPOZED 100 (Zota Ph.)',
	'Cefpodoxime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPOZED 100 (Zota Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPOZED 200 (Zota Ph.)',
	'Cefpodoxime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPOZED 200 (Zota Ph.)'
);

-- line #7123
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLIO-100 100 (WANDER)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLIO-100 100 (WANDER)'
);

-- line #7124
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLIO-200 200 (WANDER)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLIO-200 200 (WANDER)'
);

-- line #7125
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50', u'strength_2': u'', u'substance': u'CEFPODOXIME', u'always_empty': u'', u'form': u'', u'brand': u'CLIO-50SYR', u'strength_3': u'', u'company': u'WANDER', u'unit': u'mg/5ML'}

-- line #7126
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CODIMOL 100 (GUJ. TE.)',
	'CEFPODOXIME',
	'SUSP',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CODIMOL 100 (GUJ. TE.)'
);

-- line #7127
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CODIMOL 50 (GUJ. TE.)',
	'CEFPODOXIME',
	'SUSP',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CODIMOL 50 (GUJ. TE.)'
);

-- line #7128
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CODIMOL 100 (GUJ. TE.)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CODIMOL 100 (GUJ. TE.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CODIMOL 200 (GUJ. TE.)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CODIMOL 200 (GUJ. TE.)'
);

-- line #7129
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CODIMOL 50 (GUJ. TE.)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CODIMOL 50 (GUJ. TE.)'
);

-- line #7130
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUMIN 100 (D.R.John''S)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'200'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUMIN 100 (D.R.John''S)'
);

-- line #7131
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUPAL 100 (D.R.John''S)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUPAL 100 (D.R.John''S)'
);

-- line #7132
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUPAL 100 (D.R.John''S)',
	'CEFPODOXIME',
	'DT TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUPAL 100 (D.R.John''S)'
);

-- line #7133
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUPAL 200 (D.R.John''S)',
	'CEFPODOXIME',
	'DT TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUPAL 200 (D.R.John''S)'
);

-- line #7134
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUPAL 200 (D.R.John''S)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUPAL 200 (D.R.John''S)'
);

-- line #7135
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECEF 100 (Lupin)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECEF 100 (Lupin)'
);

-- line #7136
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECEF 200 (Lupin)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECEF 200 (Lupin)'
);

-- line #7137
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIOXIM-50 50 (Divine Life)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIOXIM-50 50 (Divine Life)'
);

-- line #7138
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIOXIM 100 (Divine Life)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIOXIM 100 (Divine Life)'
);

-- line #7139
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIOXIM 50 (Divine Life)',
	'CEFPODOXIME',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIOXIM 50 (Divine Life)'
);

-- line #7140
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXCEF 100 (Lupin)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXCEF 100 (Lupin)'
);

-- line #7141
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXCEF 50 (Lupin)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXCEF 50 (Lupin)'
);

-- line #7142
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXCEF 100 (Lupin)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXCEF 100 (Lupin)'
);

-- line #7143
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXCEF 50 (Lupin)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXCEF 50 (Lupin)'
);

-- line #7144
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXCEF 100 (Lupin)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXCEF 100 (Lupin)'
);

-- line #7145
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXCEF 200 (Lupin)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXCEF 200 (Lupin)'
);

-- line #7146
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXINIS 50 (NEISS)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXINIS 50 (NEISS)'
);

-- line #7147
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXINIS 100 (NEISS)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXINIS 100 (NEISS)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXINIS 200 (NEISS)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXINIS 200 (NEISS)'
);

-- line #7148
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50', u'strength_2': u'', u'substance': u'CEFPODOXIME', u'always_empty': u'', u'form': u'', u'brand': u'DS CEPODOM', u'strength_3': u'', u'company': u'Dominion', u'unit': u'mg'}

-- line #7149
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EDOXIM 50 (AZINE HC.)',
	'CEFPODOXIME',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EDOXIM 50 (AZINE HC.)'
);

-- line #7150
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EDOXIM 100 (AZINE HC.)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EDOXIM 100 (AZINE HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EDOXIM 200 (AZINE HC.)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EDOXIM 200 (AZINE HC.)'
);

-- line #7151
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EDOXIM 50 (AZINE HC.)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EDOXIM 50 (AZINE HC.)'
);

-- line #7152
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EDRIGARD 200 (CONDOR(EDRIC))',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EDRIGARD 200 (CONDOR(EDRIC))'
);

-- line #7153
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EFIBACT 100 (MOLEKULE)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EFIBACT 100 (MOLEKULE)'
);

-- line #7154
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EFIBACT 50 (MOLEKULE)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EFIBACT 50 (MOLEKULE)'
);

-- line #7155
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EFIBACT 100 (MOLEKULE)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EFIBACT 100 (MOLEKULE)'
);

-- line #7156
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EFIBACT 200 (MOLEKULE)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EFIBACT 200 (MOLEKULE)'
);

-- line #7157
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EFIBACT 50 (MOLEKULE)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EFIBACT 50 (MOLEKULE)'
);

-- line #7158
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELPOD 50 (Elder)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELPOD 50 (Elder)'
);

-- line #7159
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELPOD 100 (Elder)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELPOD 100 (Elder)'
);

-- line #7160
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELPOD 200 (Elder)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELPOD 200 (Elder)'
);

-- line #7161
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELPOD 50 (Elder)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELPOD 50 (Elder)'
);

-- line #7162
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMPROX 50 (EMAR)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMPROX 50 (EMAR)'
);

-- line #7163
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMPROX 100 (EMAR)',
	'CEFPODOXIME',
	'DT TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMPROX 100 (EMAR)'
);

-- line #7164
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMPROX 200 (EMAR)',
	'CEFPODOXIME',
	'FC TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMPROX 200 (EMAR)'
);

-- line #7165
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPODOX 50 (NITIN)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPODOX 50 (NITIN)'
);

-- line #7166
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPODOX 100 (Nitin Ph.)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPODOX 100 (Nitin Ph.)'
);

-- line #7167
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPODOX 50 (Nitin Ph.)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPODOX 50 (Nitin Ph.)'
);

-- line #7168
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPODOX 200 (NITIN)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPODOX 200 (NITIN)'
);

-- line #7169
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPODOX 50 (NITIN)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPODOX 50 (NITIN)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPODOX 100 (NITIN)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPODOX 100 (NITIN)'
);

-- line #7170
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPODOX 200 (Nitin Ph.)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPODOX 200 (Nitin Ph.)'
);

-- line #7171
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXPODOX 50 (Ind-Swift)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXPODOX 50 (Ind-Swift)'
);

-- line #7172
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXPODOX 100 (Ind-Swift)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXPODOX 100 (Ind-Swift)'
);

-- line #7173
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXPODOX 200 (Ind-Swift)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXPODOX 200 (Ind-Swift)'
);

-- line #7174
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FINECEF 100 (Nicholas)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FINECEF 100 (Nicholas)'
);

-- line #7175
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FINECEF 100 (PIRAMAL HC.)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FINECEF 100 (PIRAMAL HC.)'
);

-- line #7176
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FINECEF 50 (PIRAMAL HC.)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FINECEF 50 (PIRAMAL HC.)'
);

-- line #7177
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FINECEF 100 (PIRAMAL HC.)',
	'CEFPODOXIME',
	'SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FINECEF 100 (PIRAMAL HC.)'
);

-- line #7178
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FINECEF 50 (PIRAMAL HC.)',
	'CEFPODOXIME',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FINECEF 50 (PIRAMAL HC.)'
);

-- line #7179
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FINECEF 200 (PIRAMAL HC.)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FINECEF 200 (PIRAMAL HC.)'
);

-- line #7180
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIXTAN 50 (LITTLE GREAVE)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIXTAN 50 (LITTLE GREAVE)'
);

-- line #7181
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIXTAN 100 (LITTLE GREAVE)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIXTAN 100 (LITTLE GREAVE)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIXTAN 200 (LITTLE GREAVE)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIXTAN 200 (LITTLE GREAVE)'
);

-- line #7182
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FODOX 200 (BLUE WINGS)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FODOX 200 (BLUE WINGS)'
);

-- line #7183
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLOUP 100 (Ipca)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLOUP 100 (Ipca)'
);

-- line #7184
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOX 50 (John Bio.)',
	'Cefpodoxime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOX 50 (John Bio.)'
);

-- line #7185
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FYPODOX 100 (Phytochem)',
	'Cefpodoxime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FYPODOX 100 (Phytochem)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FYPODOX 200 (Phytochem)',
	'Cefpodoxime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FYPODOX 200 (Phytochem)'
);

-- line #7186
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GCEF 200 (Goodrich)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GCEF 200 (Goodrich)'
);

-- line #7187
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GETWELL 50 (AUM PH.)',
	'CEFPODOXIME',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GETWELL 50 (AUM PH.)'
);

-- line #7188
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GUDCEF 50 (LIFESTAR)',
	'CEFPODOXIME',
	'DS DPS',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GUDCEF 50 (LIFESTAR)'
);

-- line #7189
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GUDCEF 50 (LIFESTAR)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GUDCEF 50 (LIFESTAR)'
);

-- line #7190
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GUDCEF 100 (LIFESTAR)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GUDCEF 100 (LIFESTAR)'
);

-- line #7191
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GUDCEF 50 (LIFESTAR)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GUDCEF 50 (LIFESTAR)'
);

-- line #7192
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GUDCEF 200 (LIFESTAR)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GUDCEF 200 (LIFESTAR)'
);

-- line #7193
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIGHSAFE-O 50 (Dr.Arvind Shah''S)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIGHSAFE-O 50 (Dr.Arvind Shah''S)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIGHSAFE-O 100 (Dr.Arvind Shah''S)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIGHSAFE-O 100 (Dr.Arvind Shah''S)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIGHSAFE-O 200 (Dr.Arvind Shah''S)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIGHSAFE-O 200 (Dr.Arvind Shah''S)'
);

-- line #7194
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIPODOX 50 (RISHAB(OROCHEM))',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIPODOX 50 (RISHAB(OROCHEM))'
);

-- line #7195
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIPODOX 200 (RISHAB(OROCHEM))',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIPODOX 200 (RISHAB(OROCHEM))'
);

-- line #7196
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIPODOX 50 (RISHAB(OROCHEM))',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIPODOX 50 (RISHAB(OROCHEM))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIPODOX 100 (RISHAB(OROCHEM))',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIPODOX 100 (RISHAB(OROCHEM))'
);

-- line #7197
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYCEF 50 (Grandix)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYCEF 50 (Grandix)'
);

-- line #7198
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYCEF 100 (Grandix)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYCEF 100 (Grandix)'
);

-- line #7199
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200', u'strength_2': u'', u'substance': u'CEFPODOXIME', u'always_empty': u'', u'form': u'', u'brand': u'HYCEF', u'strength_3': u'', u'company': u'Grandix', u'unit': u'mg'}

-- line #7200
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYPODEX 50 (First Horizon)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYPODEX 50 (First Horizon)'
);

-- line #7201
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200', u'strength_2': u'', u'substance': u'CEFPODOXIME', u'always_empty': u'', u'form': u'', u'brand': u'HYPODEX', u'strength_3': u'', u'company': u'First Horizon', u'unit': u'mg'}

-- line #7202
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200', u'strength_2': u'', u'substance': u'CEFPODOXIME', u'always_empty': u'', u'form': u'', u'brand': u'INNOPOD', u'strength_3': u'', u'company': u'INNOVA LIFESCI.', u'unit': u'mg'}

-- line #7203
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INPODOX 100 (Indica)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INPODOX 100 (Indica)'
);

-- line #7204
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INXOP 200 (INVIIVO HC.)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INXOP 200 (INVIIVO HC.)'
);

-- line #7205
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IPOD 50 (Intra(INVISION))',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IPOD 50 (Intra(INVISION))'
);

-- line #7206
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IPODEX 50 (Intra Lab)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IPODEX 50 (Intra Lab)'
);

-- line #7207
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IPODEX 100 (Intra Lab)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IPODEX 100 (Intra Lab)'
);

-- line #7208
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IPODEX 200 (Intra Lab)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IPODEX 200 (Intra Lab)'
);

-- line #7209
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IPODEX 50 (Intra Lab)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IPODEX 50 (Intra Lab)'
);

-- line #7210
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IPOD-KID 50 (INVISION)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IPOD-KID 50 (INVISION)'
);

-- line #7211
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IPOD 100 (INVISION)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IPOD 100 (INVISION)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IPOD 200 (INVISION)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IPOD 200 (INVISION)'
);

-- line #7212
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'I POD 100 (Leo Form.)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'I POD 100 (Leo Form.)'
);

-- line #7213
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'I POD 200 (Leo Form.)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'I POD 200 (Leo Form.)'
);

-- line #7214
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KAPDOX 50 (Novagen Ph.)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KAPDOX 50 (Novagen Ph.)'
);

-- line #7215
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KAPDOX 100 (Novagen Ph.)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KAPDOX 100 (Novagen Ph.)'
);

-- line #7216
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KAPDOX 200 (Novagen Ph.)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KAPDOX 200 (Novagen Ph.)'
);

-- line #7217
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KAPDOX 50 (Novagen Ph.)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KAPDOX 50 (Novagen Ph.)'
);

-- line #7218
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFMAX 50 (Indchemie)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFMAX 50 (Indchemie)'
);

-- line #7219
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFMAX 200 (Indchemie)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFMAX 200 (Indchemie)'
);

-- line #7220
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFPOD 100 (INTEGRACE)',
	'CEFPODOXIME',
	'DT TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFPOD 100 (INTEGRACE)'
);

-- line #7221
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFPOD ORANGE 50 (INTEGRACE (GLENMARK))',
	'CEFPODOXIME',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFPOD ORANGE 50 (INTEGRACE (GLENMARK))'
);

-- line #7222
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'CEFPODOXIME', u'always_empty': u'', u'form': u'SUS', u'brand': u'KEFPOD', u'strength_3': u'', u'company': u'Glenmark', u'unit': u''}

-- line #7223
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFPOD 200 (Glenmark)',
	'Cefpodoxime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFPOD 200 (Glenmark)'
);

-- line #7224
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFPOD 50 (Glenmark)',
	'Cefpodoxime',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFPOD 50 (Glenmark)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFPOD 100 (Glenmark)',
	'Cefpodoxime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFPOD 100 (Glenmark)'
);

-- line #7225
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEXEF-O 50 (Cadex Lab)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEXEF-O 50 (Cadex Lab)'
);

-- line #7226
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEXEF-O 50 (Cadex Lab)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEXEF-O 50 (Cadex Lab)'
);

-- line #7227
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEXEF-O 100 (Cadex Lab)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEXEF-O 100 (Cadex Lab)'
);

-- line #7228
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEXEF-O 200 (Cadex Lab)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEXEF-O 200 (Cadex Lab)'
);

-- line #7229
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KINDCEF 50 (Radix Bio.)',
	'Cefpodoxime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KINDCEF 50 (Radix Bio.)'
);

-- line #7230
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KINDCEFF 100 (SOLITAIRE(RADIX))',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KINDCEFF 100 (SOLITAIRE(RADIX))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KINDCEFF 200 (SOLITAIRE(RADIX))',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KINDCEFF 200 (SOLITAIRE(RADIX))'
);

-- line #7231
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KINDCEFF 50 (SOLITAIRE(RADIX))',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KINDCEFF 50 (SOLITAIRE(RADIX))'
);

-- line #7232
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KUDOX 50 (RISHAB(KUREKEMI))',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KUDOX 50 (RISHAB(KUREKEMI))'
);

-- line #7233
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KUDOX 100 (RISHAB(KUREKEMI))',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KUDOX 100 (RISHAB(KUREKEMI))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KUDOX 200 (RISHAB(KUREKEMI))',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KUDOX 200 (RISHAB(KUREKEMI))'
);

-- line #7234
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAVICEF 100 (DAVIDSON BROCKS)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAVICEF 100 (DAVIDSON BROCKS)'
);

-- line #7235
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'L-DOXIME 100 (LA SERENA)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'L-DOXIME 100 (LA SERENA)'
);

-- line #7236
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACCEF-O 50 (Admac (CADMA))',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACCEF-O 50 (Admac (CADMA))'
);

-- line #7237
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACPOD 25 (Macleods)',
	'CEFPODOXIME',
	'DPS',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACPOD 25 (Macleods)'
);

-- line #7238
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACPOD 100 (Macleods)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACPOD 100 (Macleods)'
);

-- line #7239
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACPOD 50 (Macleods)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACPOD 50 (Macleods)'
);

-- line #7240
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACPOD 100 (Macleods)',
	'CEFPODOXIME',
	'SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACPOD 100 (Macleods)'
);

-- line #7241
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACPOD 50 (Macleods)',
	'CEFPODOXIME',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACPOD 50 (Macleods)'
);

-- line #7242
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACPOD 200 (Macleods)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACPOD 200 (Macleods)'
);

-- line #7243
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MARKODOXIM 200 (MEDIMARK)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MARKODOXIM 200 (MEDIMARK)'
);

-- line #7244
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGACEF 50 (Biological E.)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGACEF 50 (Biological E.)'
);

-- line #7245
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGACEF 100 (Biological)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGACEF 100 (Biological)'
);

-- line #7246
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGACEF 200 (Biological)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGACEF 200 (Biological)'
);

-- line #7247
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEPODO 200 (GLOBUS)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEPODO 200 (GLOBUS)'
);

-- line #7248
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METOXIM 100 (Sandoz)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METOXIM 100 (Sandoz)'
);

-- line #7249
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METOXIM 50 (NOVARTIS(SANDOZ))',
	'CEFPODOXIME',
	'DT TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METOXIM 50 (NOVARTIS(SANDOZ))'
);

-- line #7250
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METOXIM 100 (Sandoz)',
	'Cefpodoxime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METOXIM 100 (Sandoz)'
);

-- line #7251
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METOXIM 200 (Sandoz)',
	'Cefpodoxime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METOXIM 200 (Sandoz)'
);

-- line #7252
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICROCEF 50 (Micro Nova)',
	'Cefpodoxime',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICROCEF 50 (Micro Nova)'
);

-- line #7253
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICROCEF 100 (Micro Nova)',
	'Cefpodoxime',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICROCEF 100 (Micro Nova)'
);

-- line #7254
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICROCEF 50 (Micro Nova)',
	'Cefpodoxime',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICROCEF 50 (Micro Nova)'
);

-- line #7255
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICROCEF 100 (Micro Nova)',
	'Cefpodoxime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICROCEF 100 (Micro Nova)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICROCEF 200 (Micro Nova)',
	'Cefpodoxime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICROCEF 200 (Micro Nova)'
);

-- line #7256
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICROCEF 200 (Micro Nova)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICROCEF 200 (Micro Nova)'
);

-- line #7257
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOCEF-O 100 (Aristo)',
	'Cefpodoxime',
	'D.SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOCEF-O 100 (Aristo)'
);

-- line #7258
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOCEF-O 50 (Aristo)',
	'Cefpodoxime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOCEF-O 50 (Aristo)'
);

-- line #7259
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOCEF-O 50 (Aristo)',
	'Cefpodoxime',
	'KT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOCEF-O 50 (Aristo)'
);

-- line #7260
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOCEF-O 100 (Aristo)',
	'Cefpodoxime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOCEF-O 100 (Aristo)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOCEF-O 200 (Aristo)',
	'Cefpodoxime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOCEF-O 200 (Aristo)'
);

-- line #7261
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOTAX-O 200 (Biochem)',
	'Cefpodoxime',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOTAX-O 200 (Biochem)'
);

-- line #7262
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOTAX-O 100 (Biochem)',
	'Cefpodoxime',
	'D.SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOTAX-O 100 (Biochem)'
);

-- line #7263
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOTAX-O 50 (Biochem)',
	'Cefpodoxime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOTAX-O 50 (Biochem)'
);

-- line #7264
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOTAX-O 100 (Biochem)',
	'Cefpodoxime',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOTAX-O 100 (Biochem)'
);

-- line #7265
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOTAX-O 100 (Biochem)',
	'Cefpodoxime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOTAX-O 100 (Biochem)'
);

-- line #7266
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'M-POD 50 (Medopharm)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'M-POD 50 (Medopharm)'
);

-- line #7267
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'M-POD 50 (Medopharm)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'M-POD 50 (Medopharm)'
);

-- line #7268
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'M-POD 100 (Medopharm)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'M-POD 100 (Medopharm)'
);

-- line #7269
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'M-POD 200 (Medopharm)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'M-POD 200 (Medopharm)'
);

-- line #7270
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUCOCEF-O 100 (ETHIX HC.)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUCOCEF-O 100 (ETHIX HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUCOCEF-O 200 (ETHIX HC.)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUCOCEF-O 200 (ETHIX HC.)'
);

-- line #7271
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEXTIL 100 (Nexus)',
	'Cefpodoxime',
	'D.SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEXTIL 100 (Nexus)'
);

-- line #7272
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEXTIL 50 (Nexus)',
	'Cefpodoxime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEXTIL 50 (Nexus)'
);

-- line #7273
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIKOUNTER 50 (MERIDIAN ENT.)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIKOUNTER 50 (MERIDIAN ENT.)'
);

-- line #7274
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIPOD 200 (John Bio.)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIPOD 200 (John Bio.)'
);

-- line #7275
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIPOD 50 (JOHN BIO.)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIPOD 50 (JOHN BIO.)'
);

-- line #7276
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIPP 50 (ST.MORRISON)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIPP 50 (ST.MORRISON)'
);

-- line #7277
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIPP 100 (ST.MORRISON)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIPP 100 (ST.MORRISON)'
);

-- line #7278
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIPP 200 (ST.MORRISON)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIPP 200 (ST.MORRISON)'
);

-- line #7279
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIZODOX 100 (USP LIFE)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIZODOX 100 (USP LIFE)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIZODOX 200 (USP LIFE)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIZODOX 200 (USP LIFE)'
);

-- line #7280
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOLIA 50 (Shinto BIOTEC)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOLIA 50 (Shinto BIOTEC)'
);

-- line #7281
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOLIA 200 (Shinto BIOTEC)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOLIA 200 (Shinto BIOTEC)'
);

-- line #7282
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUDOXIM 50 (Zenon Hc.)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUDOXIM 50 (Zenon Hc.)'
);

-- line #7283
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUDOXIM 50 (Zenon Hc.)',
	'CEFPODOXIME',
	'DT TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUDOXIM 50 (Zenon Hc.)'
);

-- line #7284
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUDOXIM 100 (Zenon Hc.)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUDOXIM 100 (Zenon Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUDOXIM 200 (Zenon Hc.)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUDOXIM 200 (Zenon Hc.)'
);

-- line #7285
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUPOD 100 (Nicholas)',
	'CEFPODOXIME',
	'CV DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUPOD 100 (Nicholas)'
);

-- line #7286
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUPOD 200 (Nicholas)',
	'CEFPODOXIME',
	'CV TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUPOD 200 (Nicholas)'
);

-- line #7287
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUPOD -D 100 (NICHOLAS ZIV.)',
	'CEFPODOXIME',
	'SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUPOD -D 100 (NICHOLAS ZIV.)'
);

-- line #7288
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUPOD -D 50 (NICHOLAS ZIV.)',
	'CEFPODOXIME',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUPOD -D 50 (NICHOLAS ZIV.)'
);

-- line #7289
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUPOD 100 (NICHOLAS ZIV.)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUPOD 100 (NICHOLAS ZIV.)'
);

-- line #7290
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUPOD 50 (NICHOLAS ZIV.)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUPOD 50 (NICHOLAS ZIV.)'
);

-- line #7291
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUPOD 200 (NICHOLAS ZIV.)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUPOD 200 (NICHOLAS ZIV.)'
);

-- line #7292
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMNACEFPO 50 (Nicholas)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMNACEFPO 50 (Nicholas)'
);

-- line #7293
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMNACEFPO -D 100 (Piramal Hc.)',
	'CEFPODOXIME',
	'SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMNACEFPO -D 100 (Piramal Hc.)'
);

-- line #7294
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMNACEFPO 100 (Nicholas)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMNACEFPO 100 (Nicholas)'
);

-- line #7295
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMNACEFPO 50 (Nicholas)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMNACEFPO 50 (Nicholas)'
);

-- line #7296
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMNACEFPO 200 (Piramal Hc.)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMNACEFPO 200 (Piramal Hc.)'
);

-- line #7297
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPOX 25 (GENX PH.)',
	'Cefpodoxime',
	'DROPS',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPOX 25 (GENX PH.)'
);

-- line #7298
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPOX 100 (GENX)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPOX 100 (GENX)'
);

-- line #7299
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPOX 50 (GENX)',
	'Cefpodoxime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPOX 50 (GENX)'
);

-- line #7300
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPOX 50 (Genx Ph.)',
	'CEFPODOXIME',
	'DT TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPOX 50 (Genx Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPOX 100 (Genx Ph.)',
	'CEFPODOXIME',
	'DT TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPOX 100 (Genx Ph.)'
);

-- line #7301
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPOX 200 (Genx Ph.)',
	'CEFPODOXIME',
	'FC TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPOX 200 (Genx Ph.)'
);

-- line #7302
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORGACEF 100 (Tnt Life)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg(PROXETIL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORGACEF 100 (Tnt Life)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORGACEF 200 (Tnt Life)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg(PROXETIL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORGACEF 200 (Tnt Life)'
);

-- line #7303
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORIPOD 50 (ORION BIOTECH.)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORIPOD 50 (ORION BIOTECH.)'
);

-- line #7304
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORIPOD 50 (ORION BIOTECH.)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORIPOD 50 (ORION BIOTECH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORIPOD 100 (ORION BIOTECH.)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORIPOD 100 (ORION BIOTECH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORIPOD 200 (ORION BIOTECH.)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORIPOD 200 (ORION BIOTECH.)'
);

-- line #7305
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXIPOD 25 (Indoco Rem.)',
	'CEFPODOXIME',
	'DPS',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXIPOD 25 (Indoco Rem.)'
);

-- line #7306
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXIPOD 100 (Indoco Rem.)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXIPOD 100 (Indoco Rem.)'
);

-- line #7307
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXIPOD 50 (Indoco Rem.)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXIPOD 50 (Indoco Rem.)'
);

-- line #7308
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXIPOD 100 (Indoco Rem.)',
	'CEFPODOXIME',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXIPOD 100 (Indoco Rem.)'
);

-- line #7309
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXIPOD 50 (Indoco Rem.)',
	'CEFPODOXIME',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXIPOD 50 (Indoco Rem.)'
);

-- line #7310
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXIPOD 200 (Indoco Rem.)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXIPOD 200 (Indoco Rem.)'
);

-- line #7311
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANDOX 50 (Aglowmed)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANDOX 50 (Aglowmed)'
);

-- line #7312
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANDOX 200 (Aglowmed)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANDOX 200 (Aglowmed)'
);

-- line #7313
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PECEF 100 (DR. REDDY''S)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PECEF 100 (DR. REDDY''S)'
);

-- line #7314
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PECEF 50 (DR. REDDY''S)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PECEF 50 (DR. REDDY''S)'
);

-- line #7315
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PECEF 100 (DR. REDDY''S)',
	'CEFPODOXIME',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PECEF 100 (DR. REDDY''S)'
);

-- line #7316
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PECEF 50 (DR. REDDY''S)',
	'CEFPODOXIME',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PECEF 50 (DR. REDDY''S)'
);

-- line #7317
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PECEF 200 (Dr.Reddy''S)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PECEF 200 (Dr.Reddy''S)'
);

-- line #7318
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'P-FIXIM 50 (Svizera)',
	'CEFPODOXIME',
	'D.SYRUP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'P-FIXIM 50 (Svizera)'
);

-- line #7319
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLUGDOX 100 (Samarth LIFE)',
	'CEFPODOXIME',
	'SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLUGDOX 100 (Samarth LIFE)'
);

-- line #7320
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLUGDOX 50 (Samarth LIFE)',
	'CEFPODOXIME',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLUGDOX 50 (Samarth LIFE)'
);

-- line #7321
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLUGDOX 200 (Samarth LIFE)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLUGDOX 200 (Samarth LIFE)'
);

-- line #7322
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PODCEF 100 (Galpha)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PODCEF 100 (Galpha)'
);

-- line #7323
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PODCEF 50 (Galpha)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PODCEF 50 (Galpha)'
);

-- line #7324
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PODCEF 100 (Galpha)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PODCEF 100 (Galpha)'
);

-- line #7325
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PODCEF 50 (Galpha)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PODCEF 50 (Galpha)'
);

-- line #7326
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PODCEF 200 (Galpha)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PODCEF 200 (Galpha)'
);

-- line #7327
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PODMAN 50 (Maneesh Hc.)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PODMAN 50 (Maneesh Hc.)'
);

-- line #7328
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PODMAN 100 (Maneesh Hc.)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PODMAN 100 (Maneesh Hc.)'
);

-- line #7329
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PODMAN 200 (Maneesh Hc.)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PODMAN 200 (Maneesh Hc.)'
);

-- line #7330
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PODOBACT 100 (Troikaa)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PODOBACT 100 (Troikaa)'
);

-- line #7331
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PODOBACT 200 (Troikaa)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PODOBACT 200 (Troikaa)'
);

-- line #7332
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PODOCEF 200 (Biochem)',
	'CEFPODOXIME',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PODOCEF 200 (Biochem)'
);

-- line #7333
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PODOCEF 100 (Biochem)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PODOCEF 100 (Biochem)'
);

-- line #7334
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PODOCEF 50 (Biochem)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PODOCEF 50 (Biochem)'
);

-- line #7335
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PODOCEF 100 (Biochem)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PODOCEF 100 (Biochem)'
);

-- line #7336
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PODO 50 (Overseas Hc.)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PODO 50 (Overseas Hc.)'
);

-- line #7337
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PODO 100 (OVERSEAS MED.)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PODO 100 (OVERSEAS MED.)'
);

-- line #7338
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PODO 50 (OVERSEAS MED.)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PODO 50 (OVERSEAS MED.)'
);

-- line #7339
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PODOM 50 (EPITOME)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PODOM 50 (EPITOME)'
);

-- line #7340
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PODOM 100 (EPITOME)',
	'CEFPODOXIME',
	'DT TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PODOM 100 (EPITOME)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PODOM 200 (EPITOME)',
	'CEFPODOXIME',
	'DT TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PODOM 200 (EPITOME)'
);

-- line #7341
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PODOM-KID 50 (EPITOME)',
	'CEFPODOXIME',
	'DT TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PODOM-KID 50 (EPITOME)'
);

-- line #7342
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PODO 200 (OVERSEAS MED.)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PODO 200 (OVERSEAS MED.)'
);

-- line #7343
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PODOTAG 200 (SMENTAG PH.)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PODOTAG 200 (SMENTAG PH.)'
);

-- line #7344
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PODOX 50 (Ordain Hc.)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PODOX 50 (Ordain Hc.)'
);

-- line #7345
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PODOX 50 (Ordain Hc.)',
	'CEFPODOXIME',
	'KID TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PODOX 50 (Ordain Hc.)'
);

-- line #7346
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PODOX 100 (Ordain Hc.)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PODOX 100 (Ordain Hc.)'
);

-- line #7347
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PODOX 200 (Ordain Hc.)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PODOX 200 (Ordain Hc.)'
);

-- line #7348
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PODOZEN 50 (CITIZEN LAB.)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PODOZEN 50 (CITIZEN LAB.)'
);

-- line #7349
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PODOZEN 200 (CITIZEN LAB.)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PODOZEN 200 (CITIZEN LAB.)'
);

-- line #7350
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POLARES-100 DRY 100 (Zuventus)',
	'CEFPODOXIME',
	'SYP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POLARES-100 DRY 100 (Zuventus)'
);

-- line #7351
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POLARES-100 100 (Zuventus)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POLARES-100 100 (Zuventus)'
);

-- line #7352
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POLARES-200 200 (Zuventus)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POLARES-200 200 (Zuventus)'
);

-- line #7353
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POLARES-50 50 (Zuventus)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POLARES-50 50 (Zuventus)'
);

-- line #7354
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POLARES 25 (Zuventus)',
	'CEFPODOXIME',
	'DROPS',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POLARES 25 (Zuventus)'
);

-- line #7355
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POLARES 50 (ZUVISTA)',
	'CEFPODOXIME',
	'SUSP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POLARES 50 (ZUVISTA)'
);

-- line #7356
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POLYPOD 25 (Macleods)',
	'CEFPODOXIME',
	'DPS',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POLYPOD 25 (Macleods)'
);

-- line #7357
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POLYPOD 50 (Macleods)',
	'CEFPODOXIME',
	'DS',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POLYPOD 50 (Macleods)'
);

-- line #7358
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POLYPOD 100 (Macleods)',
	'CEFPODOXIME',
	'DT TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POLYPOD 100 (Macleods)'
);

-- line #7359
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POLYPOD 200 (Macleods)',
	'CEFPODOXIME',
	'DT TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POLYPOD 200 (Macleods)'
);

-- line #7360
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POLYPOD 50 (Macleods)',
	'CEFPODOXIME',
	'DT TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POLYPOD 50 (Macleods)'
);

-- line #7361
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POROD 50 (POSITIF(AFIVE))',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POROD 50 (POSITIF(AFIVE))'
);

-- line #7362
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POROD 100 (POSITIF(AFIVE))',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POROD 100 (POSITIF(AFIVE))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POROD 200 (POSITIF(AFIVE))',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POROD 200 (POSITIF(AFIVE))'
);

-- line #7363
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POXESTAL 100 (Stallion)',
	'Cefpodoxime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POXESTAL 100 (Stallion)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POXESTAL 200 (Stallion)',
	'Cefpodoxime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POXESTAL 200 (Stallion)'
);

-- line #7364
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRODOX 50 (Gufic Bio.)',
	'CEFPODOXIME',
	'DT TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRODOX 50 (Gufic Bio.)'
);

-- line #7365
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRODOXIME 200 (Universal)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRODOXIME 200 (Universal)'
);

-- line #7366
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROXIND 50 (Indu D.)',
	'Cefpodoxime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROXIND 50 (Indu D.)'
);

-- line #7367
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROXIND 200 (Indu D.)',
	'Cefpodoxime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROXIND 200 (Indu D.)'
);

-- line #7368
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROXIT 50 (Skymax)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROXIT 50 (Skymax)'
);

-- line #7369
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROXIT 50 (SKYMAX LIFE)',
	'CEFPODOXIME',
	'KID TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROXIT 50 (SKYMAX LIFE)'
);

-- line #7370
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROXIT 200 (Skymax)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROXIT 200 (Skymax)'
);

-- line #7371
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROXTL 50 (VERITAZ)',
	'Cefpodoxime',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROXTL 50 (VERITAZ)'
);

-- line #7372
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROXTL 100 (VERITAZ)',
	'Cefpodoxime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROXTL 100 (VERITAZ)'
);

-- line #7373
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROXTL 200 (VERITAZ)',
	'Cefpodoxime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROXTL 200 (VERITAZ)'
);

-- line #7374
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYFO 100 (BIOKIND HC.)',
	'CEFPODOXIME',
	'DT TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYFO 100 (BIOKIND HC.)'
);

-- line #7375
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYRICEP 50 (PSYCOREM)',
	'CEFPODOXIME',
	'DT TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYRICEP 50 (PSYCOREM)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYRICEP 100 (PSYCOREM)',
	'CEFPODOXIME',
	'DT TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYRICEP 100 (PSYCOREM)'
);

-- line #7376
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYRICEP 200 (PSYCOREM)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYRICEP 200 (PSYCOREM)'
);

-- line #7377
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUCEF 100 (Baroque)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUCEF 100 (Baroque)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUCEF 200 (Baroque)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUCEF 200 (Baroque)'
);

-- line #7378
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUCEF 50 (Baroque)',
	'CEFPODOXIME',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUCEF 50 (Baroque)'
);

-- line #7379
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAPOD 50 (RASS HC.)',
	'CEFPODOXIME',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAPOD 50 (RASS HC.)'
);

-- line #7380
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAPOD 100 (RASS HC.)',
	'CEFPODOXIME',
	'DT TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAPOD 100 (RASS HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAPOD 200 (RASS HC.)',
	'CEFPODOXIME',
	'DT TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAPOD 200 (RASS HC.)'
);

-- line #7381
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAPOD 50 (RASS HC.)',
	'CEFPODOXIME',
	'DT TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAPOD 50 (RASS HC.)'
);

-- line #7382
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REPIDOX 200 (Replica)',
	'CEFPODOXIME',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REPIDOX 200 (Replica)'
);

-- line #7383
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250', u'strength_2': u'', u'substance': u'CEFPROZIL', u'always_empty': u'', u'form': u'TAB', u'brand': u'3-CEF', u'strength_3': u'', u'company': u'ALKEM', u'unit': u''}

-- line #7384
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500', u'strength_2': u'', u'substance': u'CEFPROZIL', u'always_empty': u'', u'form': u'TAB', u'brand': u'3-CEF', u'strength_3': u'', u'company': u'ALKEM', u'unit': u''}

-- line #7385
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORPROZIL 250 (Orchid Hc.)',
	'CEFPROZIL',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORPROZIL 250 (Orchid Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORPROZIL 500 (Orchid Hc.)',
	'CEFPROZIL',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORPROZIL 500 (Orchid Hc.)'
);

-- line #7386
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'3A-TAZ 1000 (3A PHARMA.)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '3A-TAZ 1000 (3A PHARMA.)'
);

-- line #7387
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'3A-TAZ 250 (3A PHARMA.)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '3A-TAZ 250 (3A PHARMA.)'
);

-- line #7388
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTAZ 1000 (Acme Ph)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTAZ 1000 (Acme Ph)'
);

-- line #7389
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AFZID 1000 (Alpha Arom.)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AFZID 1000 (Alpha Arom.)'
);

-- line #7390
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AFZID 250 (Alpha Arom.)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AFZID 250 (Alpha Arom.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AFZID 500 (Alpha Arom.)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AFZID 500 (Alpha Arom.)'
);

-- line #7391
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZED 250 (Aust Ind.)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZED 250 (Aust Ind.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZED 1000 (Aust Ind.)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZED 1000 (Aust Ind.)'
);

-- line #7392
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMCEFT 1000 (HEALTH BIO.)',
	'Ceftazidime',
	'TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMCEFT 1000 (HEALTH BIO.)'
);

-- line #7393
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMCEFT 250 (HEALTH BIO.)',
	'Ceftazidime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMCEFT 250 (HEALTH BIO.)'
);

-- line #7394
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZID 250 (Admac Ph.)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZID 250 (Admac Ph.)'
);

-- line #7395
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZID 500 (Admac Ph.)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg/1G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZID 500 (Admac Ph.)'
);

-- line #7396
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACNIL 250 (Shinto Org.)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACNIL 250 (Shinto Org.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACNIL 1000 (Shinto Org.)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACNIL 1000 (Shinto Org.)'
);

-- line #7397
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftazidime', u'always_empty': u'', u'form': u'INJ', u'brand': u'BECTOZID', u'strength_3': u'', u'company': u'Cadila (GENSTAR)', u'unit': u''}

-- line #7398
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftazidime', u'always_empty': u'', u'form': u'INJ', u'brand': u'BETASYS', u'strength_3': u'', u'company': u'SYSTACARE', u'unit': u''}

-- line #7399
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOCEFT 1000 (Biocare Rem.)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg(PENTAHYDRT.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOCEFT 1000 (Biocare Rem.)'
);

-- line #7400
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftazidime', u'always_empty': u'', u'form': u'INJ', u'brand': u'CADZID', u'strength_3': u'', u'company': u'Admac (CADMA)', u'unit': u''}

-- line #7401
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CADZID 250 (Admac (CADMA))',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CADZID 250 (Admac (CADMA))'
);

-- line #7402
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFATIL 1000 (Discovery M.)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFATIL 1000 (Discovery M.)'
);

-- line #7403
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFATIL 250 (Mefro Ph.)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFATIL 250 (Mefro Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFATIL 500 (Mefro Ph.)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFATIL 500 (Mefro Ph.)'
);

-- line #7404
-- ignoring line: field [strength_1] not numeric: >>>1G(+118<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G(+118', u'strength_2': u'', u'substance': u'Ceftazidime', u'always_empty': u'', u'form': u'V', u'brand': u'CEFAZID', u'strength_3': u'', u'company': u'Biochem', u'unit': u'mg SOD.CARB.)'}

-- line #7405
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAZID 250 (Biochem)',
	'Ceftazidime',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg(+29.5/59.00 SOD.CARB.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAZID 250 (Biochem)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAZID 500 (Biochem)',
	'Ceftazidime',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg(+29.5/59.00 SOD.CARB.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAZID 500 (Biochem)'
);

-- line #7406
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1GM', u'strength_2': u'', u'substance': u'Ceftazidime', u'always_empty': u'', u'form': u'INJ', u'brand': u'CEFCURE', u'strength_3': u'', u'company': u'Cure Quick', u'unit': u''}

-- line #7407
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFDINA 1000 (Sayona)',
	'Ceftazidime',
	'VIAL',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFDINA 1000 (Sayona)'
);

-- line #7408
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFDINE 1000 (Parasol)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFDINE 1000 (Parasol)'
);

-- line #7409
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFDINE 250 (Parasol)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFDINE 250 (Parasol)'
);

-- line #7410
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftazidime', u'always_empty': u'', u'form': u'INJ', u'brand': u'CEFDIN', u'strength_3': u'', u'company': u'Marc Lab', u'unit': u''}

-- line #7411
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFDIN 250 (Marc Lab)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFDIN 250 (Marc Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFDIN 500 (Marc Lab)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFDIN 500 (Marc Lab)'
);

-- line #7412
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFEST 1000 (Obzone Ph.)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFEST 1000 (Obzone Ph.)'
);

-- line #7413
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFNON 250 (Zenon Hc.)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFNON 250 (Zenon Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFNON 1000 (Zenon Hc.)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFNON 1000 (Zenon Hc.)'
);

-- line #7414
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOT 250 (Intracin)',
	'Ceftazidime',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOT 250 (Intracin)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOT 1000 (Intracin)',
	'Ceftazidime',
	'VIAL',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOT 1000 (Intracin)'
);

-- line #7415
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFPEN 250 (Eg Ph.)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFPEN 250 (Eg Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFPEN 1000 (Eg Ph.)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFPEN 1000 (Eg Ph.)'
);

-- line #7416
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTABIT 1000 (Cubit Hc.)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTABIT 1000 (Cubit Hc.)'
);

-- line #7417
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTA 250 (Apex Form.)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/1G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTA 250 (Apex Form.)'
);

-- line #7418
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTALUCK 250 (Goodluck Ph.)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTALUCK 250 (Goodluck Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTALUCK 1000 (Goodluck Ph.)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTALUCK 1000 (Goodluck Ph.)'
);

-- line #7419
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1GM', u'strength_2': u'', u'substance': u'Ceftazidime', u'always_empty': u'', u'form': u'INJ', u'brand': u'CEFTAROL', u'strength_3': u'', u'company': u'Royal', u'unit': u''}

-- line #7420
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTASTAR 250 (WISCON)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTASTAR 250 (WISCON)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTASTAR 1000 (WISCON)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTASTAR 1000 (WISCON)'
);

-- line #7421
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftazidime', u'always_empty': u'', u'form': u'V', u'brand': u'CEFTAZIDIME', u'strength_3': u'', u'company': u'Dopson Ph.', u'unit': u''}

-- line #7422
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTAZIDIME 250 (Dopson Ph.)',
	'Ceftazidime',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTAZIDIME 250 (Dopson Ph.)'
);

-- line #7423
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTAZIDIME 500 (Dopson Ph.)',
	'Ceftazidime',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTAZIDIME 500 (Dopson Ph.)'
);

-- line #7424
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTAZID 125 (Redson)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTAZID 125 (Redson)'
);

-- line #7425
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTAZID 250 (Redson)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTAZID 250 (Redson)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTAZID 1000 (Redson)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTAZID 1000 (Redson)'
);

-- line #7426
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftazidime', u'always_empty': u'', u'form': u'V', u'brand': u'CEFTAZID', u'strength_3': u'', u'company': u'Dopson Ph.', u'unit': u''}

-- line #7427
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTAZID 250 (Dopson Ph.)',
	'Ceftazidime',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTAZID 250 (Dopson Ph.)'
);

-- line #7428
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTAZID 500 (Dopson Ph.)',
	'Ceftazidime',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTAZID 500 (Dopson Ph.)'
);

-- line #7429
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftazidime', u'always_empty': u'', u'form': u'INJ', u'brand': u'CEFTID', u'strength_3': u'', u'company': u'Csc Ph.', u'unit': u''}

-- line #7430
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftazidime', u'always_empty': u'', u'form': u'V', u'brand': u'CEFTIDIN', u'strength_3': u'', u'company': u'HETERO HC.', u'unit': u''}

-- line #7431
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTIDIN 250 (HETERO HC.)',
	'Ceftazidime',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTIDIN 250 (HETERO HC.)'
);

-- line #7432
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTOZ 250 (Medoz Ph.)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTOZ 250 (Medoz Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTOZ 1000 (Medoz Ph.)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTOZ 1000 (Medoz Ph.)'
);

-- line #7433
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftazidime', u'always_empty': u'', u'form': u'V', u'brand': u'CEFUTAUR', u'strength_3': u'', u'company': u'Taurus Lab', u'unit': u''}

-- line #7434
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFUTAUR 250 (Taurus Lab)',
	'Ceftazidime',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFUTAUR 250 (Taurus Lab)'
);

-- line #7435
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G(+DILUENT)', u'strength_2': u'', u'substance': u'Ceftazidime', u'always_empty': u'', u'form': u'INJ', u'brand': u'CEFZIDIME', u'strength_3': u'', u'company': u'CH.Bhagat', u'unit': u''}

-- line #7436
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFZIDIME 250 (CH.Bhagat)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFZIDIME 250 (CH.Bhagat)'
);

-- line #7437
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFZIDIME 500 (CH.Bhagat)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFZIDIME 500 (CH.Bhagat)'
);

-- line #7438
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFZID 1000 (Elfin Ph.)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFZID 1000 (Elfin Ph.)'
);

-- line #7439
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFZID 250 (Ind-Swift)',
	'Ceftazidime',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFZID 250 (Ind-Swift)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFZID 1000 (Ind-Swift)',
	'Ceftazidime',
	'VIAL',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFZID 1000 (Ind-Swift)'
);

-- line #7440
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftazidime', u'always_empty': u'', u'form': u'INJ', u'brand': u'CEFZY', u'strength_3': u'', u'company': u'Zee Lab', u'unit': u''}

-- line #7441
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFZY 250 (Zee Lab)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFZY 250 (Zee Lab)'
);

-- line #7442
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftazidime', u'always_empty': u'', u'form': u'INJ', u'brand': u'CETAZID', u'strength_3': u'', u'company': u'HAMPS BIO', u'unit': u''}

-- line #7443
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftazidime', u'always_empty': u'', u'form': u'INJ', u'brand': u'CUZID', u'strength_3': u'', u'company': u'Curex', u'unit': u''}

-- line #7444
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftazidime', u'always_empty': u'', u'form': u'V', u'brand': u'C-ZID', u'strength_3': u'', u'company': u'Emcure', u'unit': u''}

-- line #7445
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-ZID 250 (Emcure)',
	'Ceftazidime',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-ZID 250 (Emcure)'
);

-- line #7446
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-ZID 500 (Emcure)',
	'Ceftazidime',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-ZID 500 (Emcure)'
);

-- line #7447
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMIZIDE GM 1000 (Dominion)',
	'Ceftazidime',
	'VIAL',
	gm.nullify_empty_string('1000')::numeric,
	'mg(A BLEND OF CEFTAZIDIME PENTAHYDRATE AND STERILE SODIUM CARBONATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMIZIDE GM 1000 (Dominion)'
);

-- line #7448
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMIZIDE 250 (Dominion)',
	'Ceftazidime',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg(A BLEND OF CEFTAZIDIME PENTAHYDRATE AND STERILE SODIUM CARBONATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMIZIDE 250 (Dominion)'
);

-- line #7449
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftazidime', u'always_empty': u'', u'form': u'INJ', u'brand': u'DYZID', u'strength_3': u'', u'company': u'Dynamic', u'unit': u''}

-- line #7450
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYZID 250 (Dynamic)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYZID 250 (Dynamic)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYZID 500 (Dynamic)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYZID 500 (Dynamic)'
);

-- line #7451
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftazidime', u'always_empty': u'', u'form': u'VIAL', u'brand': u'ECOZID', u'strength_3': u'', u'company': u'FLAMINGO PH.', u'unit': u''}

-- line #7452
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EFDIM 1000 (AXYZEN LIFE)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EFDIM 1000 (AXYZEN LIFE)'
);

-- line #7453
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EFDIM 250 (AXYZEN LIFE)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EFDIM 250 (AXYZEN LIFE)'
);

-- line #7454
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1GM', u'strength_2': u'', u'substance': u'Ceftazidime', u'always_empty': u'', u'form': u'INJ', u'brand': u'EFZID-1000', u'strength_3': u'', u'company': u'Biocin Hc.', u'unit': u''}

-- line #7455
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERAZIDE 250 (Brawn Lab)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERAZIDE 250 (Brawn Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERAZIDE 1000 (Brawn Lab)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERAZIDE 1000 (Brawn Lab)'
);

-- line #7456
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESDIME 250 (Swayam Hc.)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESDIME 250 (Swayam Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESDIME 1000 (Swayam Hc.)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESDIME 1000 (Swayam Hc.)'
);

-- line #7457
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftazidime', u'always_empty': u'', u'form': u'V', u'brand': u'EUTUM', u'strength_3': u'', u'company': u'Euphoric', u'unit': u''}

-- line #7458
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUTUM 250 (Euphoric)',
	'Ceftazidime',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUTUM 250 (Euphoric)'
);

-- line #7459
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAZID 250 (Finesse Ph.)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAZID 250 (Finesse Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAZID 1000 (Finesse Ph.)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAZID 1000 (Finesse Ph.)'
);

-- line #7460
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftazidime', u'always_empty': u'', u'form': u'INJ', u'brand': u'FECTIM', u'strength_3': u'', u'company': u'TRUMAC', u'unit': u''}

-- line #7461
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FODIDIME 1000 (Forgo Ph.)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FODIDIME 1000 (Forgo Ph.)'
);

-- line #7462
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1GM', u'strength_2': u'', u'substance': u'Ceftazidime', u'always_empty': u'', u'form': u'INJ', u'brand': u'FORAXX', u'strength_3': u'', u'company': u'Medicorp', u'unit': u''}

-- line #7463
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftazidime', u'always_empty': u'', u'form': u'V', u'brand': u'FORTACEF', u'strength_3': u'', u'company': u'Troikaa', u'unit': u''}

-- line #7464
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORTACEF 250 (Troikaa)',
	'Ceftazidime',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORTACEF 250 (Troikaa)'
);

-- line #7465
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORTACEF 500 (Troikaa)',
	'Ceftazidime',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORTACEF 500 (Troikaa)'
);

-- line #7466
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1', u'strength_2': u'2;G', u'substance': u'Ceftazidime', u'always_empty': u'', u'form': u'', u'brand': u'FORTUM G/2V', u'strength_3': u'', u'company': u'Gsk', u'unit': u''}

-- line #7467
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORTUM 250 (Gsk)',
	'Ceftazidime',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORTUM 250 (Gsk)'
);

-- line #7468
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORTUM 500 (Gsk)',
	'Ceftazidime',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORTUM 500 (Gsk)'
);

-- line #7469
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1', u'strength_2': u'2;G', u'substance': u'Ceftazidime', u'always_empty': u'', u'form': u'INJ', u'brand': u'FORZID', u'strength_3': u'', u'company': u'United Bio.', u'unit': u''}

-- line #7470
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftazidime', u'always_empty': u'', u'form': u'INJ', u'brand': u'FOTARAN', u'strength_3': u'', u'company': u'Vhb', u'unit': u''}

-- line #7471
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOTARAN 250 (Vhb)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOTARAN 250 (Vhb)'
);

-- line #7472
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOTARAN 500 (Vhb)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOTARAN 500 (Vhb)'
);

-- line #7473
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftazidime', u'always_empty': u'', u'form': u'INJ', u'brand': u'GLIFEST', u'strength_3': u'', u'company': u'NEISS', u'unit': u''}

-- line #7474
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYCEF 1000 (SANCHEZ LAB.)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYCEF 1000 (SANCHEZ LAB.)'
);

-- line #7475
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYDIME 250 (Brooks Ph.)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYDIME 250 (Brooks Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYDIME 1000 (Brooks Ph.)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYDIME 1000 (Brooks Ph.)'
);

-- line #7476
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IZIDIME 250 (Izen Ph.)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IZIDIME 250 (Izen Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IZIDIME 1000 (Izen Ph.)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IZIDIME 1000 (Izen Ph.)'
);

-- line #7477
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IZID 250 (Intra Lab)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IZID 250 (Intra Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IZID 1000 (Intra Lab)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IZID 1000 (Intra Lab)'
);

-- line #7478
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JINTUM 250 (Om Bio.)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JINTUM 250 (Om Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JINTUM 1000 (Om Bio.)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JINTUM 1000 (Om Bio.)'
);

-- line #7479
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEMZID 250 (Chemo D.)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEMZID 250 (Chemo D.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEMZID 1000 (Chemo D.)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEMZID 1000 (Chemo D.)'
);

-- line #7480
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LARZID 250 (Malar Hc.)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LARZID 250 (Malar Hc.)'
);

-- line #7481
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LARZID 500 (Malar Hc.)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LARZID 500 (Malar Hc.)'
);

-- line #7482
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUCEDIME 1000 (STAUNCH)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUCEDIME 1000 (STAUNCH)'
);

-- line #7483
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUCEDIME 2000 (STAUNCH)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('2000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUCEDIME 2000 (STAUNCH)'
);

-- line #7484
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftazidime', u'always_empty': u'', u'form': u'INJ', u'brand': u'MAGNAZIDE', u'strength_3': u'', u'company': u'Ikon Rem', u'unit': u''}

-- line #7485
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAGNAZIDE 250 (Ikon Rem)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAGNAZIDE 250 (Ikon Rem)'
);

-- line #7486
-- ignoring line: field [strength_1] not numeric: >>>1G<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'250', u'substance': u'Ceftazidime', u'always_empty': u'', u'form': u'VIAL', u'brand': u'MANZID', u'strength_3': u'', u'company': u'ADMAC(LEE BENZ)', u'unit': u'mg'}

-- line #7487
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftazidime', u'always_empty': u'', u'form': u'', u'brand': u'MEEZAT', u'strength_3': u'', u'company': u'Biocon', u'unit': u''}

-- line #7488
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGAZID 125 (Mapra)',
	'Ceftazidime',
	'V',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGAZID 125 (Mapra)'
);

-- line #7489
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftazidime', u'always_empty': u'', u'form': u'V', u'brand': u'MEGAZID', u'strength_3': u'', u'company': u'Mapra', u'unit': u''}

-- line #7490
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGAZID 250 (Mapra)',
	'Ceftazidime',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGAZID 250 (Mapra)'
);

-- line #7491
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYZID 250 (Solitaire)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYZID 250 (Solitaire)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYZID 1000 (Solitaire)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYZID 1000 (Solitaire)'
);

-- line #7492
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NATADIME 1000 (Pfiscar Ind.)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg(PENTAHYDRT.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NATADIME 1000 (Pfiscar Ind.)'
);

-- line #7493
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NECEFT 250 (Nitin Ph.)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NECEFT 250 (Nitin Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NECEFT 1000 (Nitin Ph.)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NECEFT 1000 (Nitin Ph.)'
);

-- line #7494
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEPOCEF 250 (Ttk Hc.)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEPOCEF 250 (Ttk Hc.)'
);

-- line #7495
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftazidime', u'always_empty': u'', u'form': u'V', u'brand': u'NEPOCEF', u'strength_3': u'', u'company': u'Ttk Hc.', u'unit': u''}

-- line #7496
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NICZID 250 (Phytochem)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NICZID 250 (Phytochem)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NICZID 1000 (Phytochem)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NICZID 1000 (Phytochem)'
);

-- line #7497
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftazidime', u'always_empty': u'', u'form': u'VIAL', u'brand': u'NKCEFTA', u'strength_3': u'', u'company': u'N.K.Ph.', u'unit': u''}

-- line #7498
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NKCEFTA 250 (N.K.Ph.)',
	'Ceftazidime',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NKCEFTA 250 (N.K.Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NKCEFTA 500 (N.K.Ph.)',
	'Ceftazidime',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NKCEFTA 500 (N.K.Ph.)'
);

-- line #7499
-- ignoring line: field [strength_1] not numeric: >>>1G<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'250', u'substance': u'Ceftazidime', u'always_empty': u'', u'form': u'VIAL', u'brand': u'NOVAZIDIM', u'strength_3': u'', u'company': u'Radicura', u'unit': u'mg'}

-- line #7500
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFTAZID 250 (Siomond)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFTAZID 250 (Siomond)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFTAZID 1000 (Siomond)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFTAZID 1000 (Siomond)'
);

-- line #7501
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFTAZID 500 (Siomond)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFTAZID 500 (Siomond)'
);

-- line #7502
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftazidime', u'always_empty': u'', u'form': u'INJ', u'brand': u'OMNAZIDE', u'strength_3': u'', u'company': u'INNOVATIVE', u'unit': u''}

-- line #7503
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMNAZIDE 250 (INNOVATIVE)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMNAZIDE 250 (INNOVATIVE)'
);

-- line #7504
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftazidime', u'always_empty': u'', u'form': u'INJ', u'brand': u'ORZID', u'strength_3': u'', u'company': u'Orchid Hc.', u'unit': u''}

-- line #7505
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORZID 250 (Orchid Hc.)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORZID 250 (Orchid Hc.)'
);

-- line #7506
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftazidime', u'always_empty': u'', u'form': u'INJ', u'brand': u'OSZID', u'strength_3': u'', u'company': u'Osper', u'unit': u''}

-- line #7507
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSZID 250 (Osper)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/500'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSZID 250 (Osper)'
);

-- line #7508
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OZID 1000 (Oscar Rem.)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OZID 1000 (Oscar Rem.)'
);

-- line #7509
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OZID 250 (Oscar Rem.)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OZID 250 (Oscar Rem.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OZID 500 (Oscar Rem.)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OZID 500 (Oscar Rem.)'
);

-- line #7510
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROCEFTA 250 (Prohealth)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROCEFTA 250 (Prohealth)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROCEFTA 1000 (Prohealth)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROCEFTA 1000 (Prohealth)'
);

-- line #7511
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROCEFTA 500 (Prohealth)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROCEFTA 500 (Prohealth)'
);

-- line #7512
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftazidime', u'always_empty': u'', u'form': u'INJ', u'brand': u'PSEODOCEF', u'strength_3': u'', u'company': u'Shreya', u'unit': u''}

-- line #7513
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftazidime', u'always_empty': u'', u'form': u'INJ', u'brand': u'PSEUDOCEF', u'strength_3': u'', u'company': u'Shreya', u'unit': u''}

-- line #7514
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESCUCEF 250 (Biomax Lab)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESCUCEF 250 (Biomax Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESCUCEF 1000 (Biomax Lab)',
	'Ceftazidime',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESCUCEF 1000 (Biomax Lab)'
);

-- line #7515
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROCADAX 400 (Fulford)',
	'Ceftibuten',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROCADAX 400 (Fulford)'
);

-- line #7516
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROCADAX 90 (Fulford)',
	'Ceftibuten',
	'POW',
	gm.nullify_empty_string('90')::numeric,
	'mg/5ML(AFTER RECONST.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROCADAX 90 (Fulford)'
);

-- line #7517
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftizoxime', u'always_empty': u'', u'form': u'V', u'brand': u'CEFIZOX', u'strength_3': u'', u'company': u'Gsk', u'unit': u''}

-- line #7518
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFIZOX 250 (Gsk)',
	'Ceftizoxime',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'500'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFIZOX 250 (Gsk)'
);

-- line #7519
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELDCEF 250 (Elder)',
	'Ceftizoxime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELDCEF 250 (Elder)'
);

-- line #7520
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftizoxime', u'always_empty': u'', u'form': u'V', u'brand': u'ELDCEF', u'strength_3': u'', u'company': u'Elder', u'unit': u''}

-- line #7521
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftizoxime', u'always_empty': u'', u'form': u'V', u'brand': u'EPOCELIN', u'strength_3': u'', u'company': u'Shreya', u'unit': u''}

-- line #7522
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AACEF 250 (Alpic Bio.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AACEF 250 (Alpic Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AACEF 500 (Alpic Bio.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AACEF 500 (Alpic Bio.)'
);

-- line #7523
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'AARTICEF', u'strength_3': u'', u'company': u'Alpic Rem.', u'unit': u''}

-- line #7524
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AARTICEF 250 (Alpic Rem.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AARTICEF 250 (Alpic Rem.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AARTICEF 500 (Alpic Rem.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AARTICEF 500 (Alpic Rem.)'
);

-- line #7525
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACCUZON 125 (Macleods)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACCUZON 125 (Macleods)'
);

-- line #7526
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'ACCUZON', u'strength_3': u'', u'company': u'Macleods', u'unit': u''}

-- line #7527
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACCUZON 250 (Macleods)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACCUZON 250 (Macleods)'
);

-- line #7528
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'ACCUZON', u'strength_3': u'', u'company': u'Macleods', u'unit': u''}

-- line #7529
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACCUZON 500 (Macleods)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACCUZON 500 (Macleods)'
);

-- line #7530
-- ignoring line: field [strength_1] not numeric: >>>1G<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'250', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'ACTICEF G/250', u'strength_3': u'', u'company': u'Active Hc.', u'unit': u'mg'}

-- line #7531
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AFZONE 125 (Admac Ph.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AFZONE 125 (Admac Ph.)'
);

-- line #7532
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'AFZONE', u'strength_3': u'', u'company': u'Admac Ph.', u'unit': u''}

-- line #7533
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AFZONE 250 (Admac Ph.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AFZONE 250 (Admac Ph.)'
);

-- line #7534
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'AFZONE', u'strength_3': u'', u'company': u'Admac Ph.', u'unit': u''}

-- line #7535
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AFZONE 500 (Admac Ph.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AFZONE 500 (Admac Ph.)'
);

-- line #7536
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMCEF 250 (AMRIT)',
	'Ceftriaxone',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMCEF 250 (AMRIT)'
);

-- line #7537
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AON 250 (Aust Ind.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AON 250 (Aust Ind.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AON 1000 (Aust Ind.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AON 1000 (Aust Ind.)'
);

-- line #7538
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APECEF 1000 (Apex Form.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APECEF 1000 (Apex Form.)'
);

-- line #7539
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APECEF 250 (Apex Form.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APECEF 250 (Apex Form.)'
);

-- line #7540
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APECEF 500 (Apex Form.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APECEF 500 (Apex Form.)'
);

-- line #7541
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARICEF 1000 (ARCUS LABS)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARICEF 1000 (ARCUS LABS)'
);

-- line #7542
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AROCEF 1000 (Alpha Arom.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AROCEF 1000 (Alpha Arom.)'
);

-- line #7543
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AROCEF 250 (Alpha Arom.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AROCEF 250 (Alpha Arom.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AROCEF 500 (Alpha Arom.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AROCEF 500 (Alpha Arom.)'
);

-- line #7544
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASTRACEF 1000 (YASHTRA HEALTH)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASTRACEF 1000 (YASHTRA HEALTH)'
);

-- line #7545
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXE 1000 (Cataliq)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXE 1000 (Cataliq)'
);

-- line #7546
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXE 250 (Cataliq)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXE 250 (Cataliq)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXE 500 (Cataliq)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXE 500 (Cataliq)'
);

-- line #7547
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXONE 125 (Cadila Ph.)',
	'Ceftriaxone',
	'V',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXONE 125 (Cadila Ph.)'
);

-- line #7548
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'V', u'brand': u'AXONE', u'strength_3': u'', u'company': u'Cadila Ph.', u'unit': u''}

-- line #7549
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXONE 250 (Cadila Ph.)',
	'Ceftriaxone',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXONE 250 (Cadila Ph.)'
);

-- line #7550
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXYCEF 1000 (AXYZEN LIFE)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXYCEF 1000 (AXYZEN LIFE)'
);

-- line #7551
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXYCEF 250 (AXYZEN LIFE)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXYCEF 250 (AXYZEN LIFE)'
);

-- line #7552
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXYCEF 500 (AXYZEN LIFE)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXYCEF 500 (AXYZEN LIFE)'
);

-- line #7553
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BECEF 125 (Alkem)',
	'Ceftriaxone',
	'V',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BECEF 125 (Alkem)'
);

-- line #7554
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'V', u'brand': u'BECEF', u'strength_3': u'', u'company': u'Alkem', u'unit': u''}

-- line #7555
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BECEF 250 (Alkem)',
	'Ceftriaxone',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BECEF 250 (Alkem)'
);

-- line #7556
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BECEF 500 (Alkem)',
	'Ceftriaxone',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BECEF 500 (Alkem)'
);

-- line #7557
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOXONE 1000 (Biosmith)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOXONE 1000 (Biosmith)'
);

-- line #7558
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOXONE 250 (Biosmith)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOXONE 250 (Biosmith)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOXONE 500 (Biosmith)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOXONE 500 (Biosmith)'
);

-- line #7559
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'BLUEZONE', u'strength_3': u'', u'company': u'BLUE WINGS', u'unit': u''}

-- line #7560
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'BROADCEF', u'strength_3': u'', u'company': u'Sanjivani', u'unit': u''}

-- line #7561
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BROADCEF 250 (Sanjivani)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BROADCEF 250 (Sanjivani)'
);

-- line #7562
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-31 GM 1 (SYNER MED.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-31 GM 1 (SYNER MED.)'
);

-- line #7563
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'CADICEFT', u'strength_3': u'', u'company': u'Zydus Cadila', u'unit': u''}

-- line #7564
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'CADIZONE', u'strength_3': u'', u'company': u'Admac (CADMA)', u'unit': u''}

-- line #7565
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CADIZONE 250 (Admac (CADMA))',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CADIZONE 250 (Admac (CADMA))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CADIZONE 500 (Admac (CADMA))',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CADIZONE 500 (Admac (CADMA))'
);

-- line #7566
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'V', u'brand': u'CAFZONE', u'strength_3': u'', u'company': u'Ind-Swift', u'unit': u''}

-- line #7567
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAFZONE 250 (Ind-Swift)',
	'Ceftriaxone',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAFZONE 250 (Ind-Swift)'
);

-- line #7568
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALICEF 1000 (Calibar Ph.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALICEF 1000 (Calibar Ph.)'
);

-- line #7569
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'CB-ZONE', u'strength_3': u'', u'company': u'CH.Bhagat', u'unit': u''}

-- line #7570
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'CEBAY-TRX', u'strength_3': u'', u'company': u'Leben', u'unit': u''}

-- line #7571
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEBAY-TRX 250 (Leben)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEBAY-TRX 250 (Leben)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEBAY-TRX 500 (Leben)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEBAY-TRX 500 (Leben)'
);

-- line #7572
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEEMI 250 (Winsome Lab)',
	'Ceftriaxone',
	'CX INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEEMI 250 (Winsome Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEEMI 1000 (Winsome Lab)',
	'Ceftriaxone',
	'CX INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEEMI 1000 (Winsome Lab)'
);

-- line #7573
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAB 1000 (Aabtac Life)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAB 1000 (Aabtac Life)'
);

-- line #7574
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAB 250 (Aabtac Life)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAB 250 (Aabtac Life)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAB 500 (Aabtac Life)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAB 500 (Aabtac Life)'
);

-- line #7575
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFADAY 250 (TALENT LAB.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFADAY 250 (TALENT LAB.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFADAY 1000 (TALENT LAB.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFADAY 1000 (TALENT LAB.)'
);

-- line #7576
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFADAY 500 (TALENT LAB.)',
	'Ceftriaxone',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFADAY 500 (TALENT LAB.)'
);

-- line #7577
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAL 250 (Mercury)',
	'Ceftriaxone',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAL 250 (Mercury)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAL 1000 (Mercury)',
	'Ceftriaxone',
	'VIAL',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAL 1000 (Mercury)'
);

-- line #7578
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'CEFAMED', u'strength_3': u'', u'company': u'Meridian', u'unit': u''}

-- line #7579
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAMED 250 (Meridian)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAMED 250 (Meridian)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAMED 500 (Meridian)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAMED 500 (Meridian)'
);

-- line #7580
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAST 125 (Bergen)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAST 125 (Bergen)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAST 250 (Bergen)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAST 250 (Bergen)'
);

-- line #7581
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAST 500 (Bergen)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg/1G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAST 500 (Bergen)'
);

-- line #7582
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAXONE 125 (Lupin)',
	'Ceftriaxone',
	'V',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAXONE 125 (Lupin)'
);

-- line #7583
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'V', u'brand': u'CEFAXONE', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #7584
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAXONE 250 (Lupin)',
	'Ceftriaxone',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAXONE 250 (Lupin)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAXONE 500 (Lupin)',
	'Ceftriaxone',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAXONE 500 (Lupin)'
);

-- line #7585
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFBACT 1000 (Cipla)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFBACT 1000 (Cipla)'
);

-- line #7586
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFBACT 250 (Cipla)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFBACT 250 (Cipla)'
);

-- line #7587
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFBACT 500 (Cipla)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFBACT 500 (Cipla)'
);

-- line #7588
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFCON 250 (Briskon)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFCON 250 (Briskon)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFCON 1000 (Briskon)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFCON 1000 (Briskon)'
);

-- line #7589
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'V', u'brand': u'CEFERA', u'strength_3': u'', u'company': u'Shreya', u'unit': u''}

-- line #7590
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFERA 250 (Shreya)',
	'Ceftriaxone',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFERA 250 (Shreya)'
);

-- line #7591
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFERA 500 (Shreya)',
	'Ceftriaxone',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFERA 500 (Shreya)'
);

-- line #7592
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFEZONE 125 (Intas)',
	'Ceftriaxone',
	'VIAL',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFEZONE 125 (Intas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFEZONE 250 (Intas)',
	'Ceftriaxone',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFEZONE 250 (Intas)'
);

-- line #7593
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'VIAL', u'brand': u'CEFEZONE', u'strength_3': u'', u'company': u'Intas', u'unit': u''}

-- line #7594
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFEZONE 500 (Intas)',
	'Ceftriaxone',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFEZONE 500 (Intas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFEZONE 1000 (Intas)',
	'Ceftriaxone',
	'VIAL',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFEZONE 1000 (Intas)'
);

-- line #7595
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'CEFLIFE', u'strength_3': u'', u'company': u'SHAILSTAR LIFE', u'unit': u''}

-- line #7596
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'CEFMAC', u'strength_3': u'', u'company': u'Ikon Rem', u'unit': u''}

-- line #7597
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFMIL 1000 (Shaimil)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFMIL 1000 (Shaimil)'
);

-- line #7598
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFMIL 250 (Shaimil)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFMIL 250 (Shaimil)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFMIL 500 (Shaimil)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFMIL 500 (Shaimil)'
);

-- line #7599
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOAT 250 (Atoz Ph.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOAT 250 (Atoz Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOAT 1000 (Atoz Ph.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOAT 1000 (Atoz Ph.)'
);

-- line #7600
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'V', u'brand': u'CEFOCEF', u'strength_3': u'', u'company': u'Centaur', u'unit': u''}

-- line #7601
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOCEF 250 (Centaur)',
	'Ceftriaxone',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOCEF 250 (Centaur)'
);

-- line #7602
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'CEFOGRAM', u'strength_3': u'', u'company': u'Orchid Hc.', u'unit': u''}

-- line #7603
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOGRAM 250 (Orchid Hc.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOGRAM 250 (Orchid Hc.)'
);

-- line #7604
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOGRAM 500 (Orchid Hc.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOGRAM 500 (Orchid Hc.)'
);

-- line #7605
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFON 125 (Zee Lab)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFON 125 (Zee Lab)'
);

-- line #7606
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'CEFON', u'strength_3': u'', u'company': u'Zee Lab', u'unit': u''}

-- line #7607
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFON 250 (Zee Lab)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFON 250 (Zee Lab)'
);

-- line #7608
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFON 500 (Zee Lab)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFON 500 (Zee Lab)'
);

-- line #7609
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFRIN 1000 (Siomond)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFRIN 1000 (Siomond)'
);

-- line #7610
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFRIN 250 (Siomond)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFRIN 250 (Siomond)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFRIN 500 (Siomond)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFRIN 500 (Siomond)'
);

-- line #7611
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFRITZ 1000 (Ritz Ph.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFRITZ 1000 (Ritz Ph.)'
);

-- line #7612
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFRITZ 250 (Ritz Ph.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFRITZ 250 (Ritz Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFRITZ 500 (Ritz Ph.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFRITZ 500 (Ritz Ph.)'
);

-- line #7613
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.5G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'CEFROX', u'strength_3': u'', u'company': u'CH.Bhagat', u'unit': u''}

-- line #7614
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFSET 250 (Wintech)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFSET 250 (Wintech)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFSET 1000 (Wintech)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFSET 1000 (Wintech)'
);

-- line #7615
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'VIAL', u'brand': u'CEFS', u'strength_3': u'', u'company': u'SHRESHTHA', u'unit': u''}

-- line #7616
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFS 250 (SHRESHTHA)',
	'Ceftriaxone',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFS 250 (SHRESHTHA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFS 500 (SHRESHTHA)',
	'Ceftriaxone',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFS 500 (SHRESHTHA)'
);

-- line #7617
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'CEFTIFORCE', u'strength_3': u'', u'company': u'Mankind', u'unit': u''}

-- line #7618
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'CEFTIFORCE', u'strength_3': u'', u'company': u'Mankind', u'unit': u''}

-- line #7619
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'CEFTOCID', u'strength_3': u'', u'company': u'Marc Lab', u'unit': u''}

-- line #7620
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTOCID 250 (Marc Lab)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTOCID 250 (Marc Lab)'
);

-- line #7621
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTOCID 500 (Marc Lab)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTOCID 500 (Marc Lab)'
);

-- line #7622
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTOX 1000 (Eg Ph.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTOX 1000 (Eg Ph.)'
);

-- line #7623
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTOX 250 (Eg Ph.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTOX 250 (Eg Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTOX 500 (Eg Ph.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTOX 500 (Eg Ph.)'
);

-- line #7624
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTRAX 125 (VERITAZ)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTRAX 125 (VERITAZ)'
);

-- line #7625
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'CEFTRAX', u'strength_3': u'', u'company': u'VERITAZ', u'unit': u''}

-- line #7626
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTRAX 250 (VERITAZ)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTRAX 250 (VERITAZ)'
);

-- line #7627
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTRAX 500 (VERITAZ)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTRAX 500 (VERITAZ)'
);

-- line #7628
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'V', u'brand': u'CEFTRIAN', u'strength_3': u'', u'company': u'Taurus Lab', u'unit': u''}

-- line #7629
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTRIAN 250 (Taurus Lab)',
	'Ceftriaxone',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTRIAN 250 (Taurus Lab)'
);

-- line #7630
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTRIAN 500 (Taurus Lab)',
	'Ceftriaxone',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTRIAN 500 (Taurus Lab)'
);

-- line #7631
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTRIASAFE 1000 (Kepsee)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTRIASAFE 1000 (Kepsee)'
);

-- line #7632
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTRIASAFE 250 (Kepsee)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTRIASAFE 250 (Kepsee)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTRIASAFE 500 (Kepsee)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTRIASAFE 500 (Kepsee)'
);

-- line #7633
-- ignoring line: field [strength_1] not numeric: >>>1G<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'250', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'VIAL', u'brand': u'CEFTRICA G/250', u'strength_3': u'', u'company': u'MOLEKULE', u'unit': u'mg'}

-- line #7634
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'CEFTRIL', u'strength_3': u'', u'company': u'TABLETS I.', u'unit': u''}

-- line #7635
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'CEFTRINA', u'strength_3': u'', u'company': u'CITIZEN LAB.', u'unit': u''}

-- line #7636
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTRINA 250 (CITIZEN LAB.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTRINA 250 (CITIZEN LAB.)'
);

-- line #7637
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTRION 1000 (Claris L.)',
	'Ceftriaxone',
	'VIAL',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTRION 1000 (Claris L.)'
);

-- line #7638
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTRION 250 (Claris L.)',
	'Ceftriaxone',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTRION 250 (Claris L.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTRION 500 (Claris L.)',
	'Ceftriaxone',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTRION 500 (Claris L.)'
);

-- line #7639
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'CEFTRISONE', u'strength_3': u'', u'company': u'AKUM(PLETHICO)', u'unit': u''}

-- line #7640
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTRISONE 250 (AKUM(PLETHICO))',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTRISONE 250 (AKUM(PLETHICO))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTRISONE 500 (AKUM(PLETHICO))',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTRISONE 500 (AKUM(PLETHICO))'
);

-- line #7641
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTRON 1000 (Inga)',
	'Ceftriaxone',
	'VIAL',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTRON 1000 (Inga)'
);

-- line #7642
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTRON 125 (Inga)',
	'Ceftriaxone',
	'VIAL',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTRON 125 (Inga)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTRON 250 (Inga)',
	'Ceftriaxone',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTRON 250 (Inga)'
);

-- line #7643
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEF 125 (Eden Hc.)',
	'Ceftriaxone',
	'V',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEF 125 (Eden Hc.)'
);

-- line #7644
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'V', u'brand': u'CEF', u'strength_3': u'', u'company': u'Eden Hc.', u'unit': u''}

-- line #7645
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEF 250 (Eden Hc.)',
	'Ceftriaxone',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEF 250 (Eden Hc.)'
);

-- line #7646
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEF 500 (Eden Hc.)',
	'Ceftriaxone',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEF 500 (Eden Hc.)'
);

-- line #7647
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFXI 125 (Medley)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFXI 125 (Medley)'
);

-- line #7648
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'CEFXI', u'strength_3': u'', u'company': u'Medley', u'unit': u''}

-- line #7649
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFXI 250 (Medley)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFXI 250 (Medley)'
);

-- line #7650
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFXI 500 (Medley)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFXI 500 (Medley)'
);

-- line #7651
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFXONE GM 1000 (SMITH LIFE)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFXONE GM 1000 (SMITH LIFE)'
);

-- line #7652
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEMAX 125 (Wanbury)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEMAX 125 (Wanbury)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEMAX 250 (Wanbury)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEMAX 250 (Wanbury)'
);

-- line #7653
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEMAX 500 (Wanbury)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEMAX 500 (Wanbury)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEMAX 1000 (Wanbury)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEMAX 1000 (Wanbury)'
);

-- line #7654
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPTRADIN 125 (TAJ PH.)',
	'Ceftriaxone',
	'VIAL',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPTRADIN 125 (TAJ PH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPTRADIN 250 (TAJ PH.)',
	'Ceftriaxone',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPTRADIN 250 (TAJ PH.)'
);

-- line #7655
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1', u'strength_2': u'2;G', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'VIAL', u'brand': u'CEPTRADIN', u'strength_3': u'', u'company': u'TAJ PH.', u'unit': u''}

-- line #7656
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CESAFE 1000 (Guj.Terce)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CESAFE 1000 (Guj.Terce)'
);

-- line #7657
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'CESAFE', u'strength_3': u'', u'company': u'Guj.Terce', u'unit': u''}

-- line #7658
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CESAFE 250 (Guj.Terce)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CESAFE 250 (Guj.Terce)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CESAFE 500 (Guj.Terce)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CESAFE 500 (Guj.Terce)'
);

-- line #7659
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'CETAZONE', u'strength_3': u'', u'company': u'Ajanta Ph.', u'unit': u''}

-- line #7660
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETAZONE 250 (Ajanta Ph.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETAZONE 250 (Ajanta Ph.)'
);

-- line #7661
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETMEX 250 (Goodluck Ph.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETMEX 250 (Goodluck Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETMEX 1000 (Goodluck Ph.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETMEX 1000 (Goodluck Ph.)'
);

-- line #7662
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETREX 1000 (Parasol)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETREX 1000 (Parasol)'
);

-- line #7663
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETREX 250 (Parasol)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETREX 250 (Parasol)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETREX 500 (Parasol)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETREX 500 (Parasol)'
);

-- line #7664
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.5G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'CETRIAX', u'strength_3': u'', u'company': u'Kapl', u'unit': u''}

-- line #7665
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'V', u'brand': u'CETRIAX', u'strength_3': u'', u'company': u'Kapl', u'unit': u''}

-- line #7666
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETRIAX 250 (Kapl)',
	'Ceftriaxone',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETRIAX 250 (Kapl)'
);

-- line #7667
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'CETRIAZONE', u'strength_3': u'', u'company': u'Csc Ph.', u'unit': u''}

-- line #7668
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETZONE 125 (GRACE)',
	'Ceftriaxone',
	'VIAL',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETZONE 125 (GRACE)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETZONE 250 (GRACE)',
	'Ceftriaxone',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETZONE 250 (GRACE)'
);

-- line #7669
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETZONE 500 (GRACE)',
	'Ceftriaxone',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETZONE 500 (GRACE)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETZONE 1000 (GRACE)',
	'Ceftriaxone',
	'VIAL',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETZONE 1000 (GRACE)'
);

-- line #7670
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'CEZONE', u'strength_3': u'', u'company': u'CH.Bhagat', u'unit': u''}

-- line #7671
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEZONE 250 (CH.Bhagat)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEZONE 250 (CH.Bhagat)'
);

-- line #7672
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEZONE 500 (CH.Bhagat)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEZONE 500 (CH.Bhagat)'
);

-- line #7673
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'C-FAX', u'strength_3': u'', u'company': u'Divine', u'unit': u''}

-- line #7674
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-FAX 250 (Divine)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-FAX 250 (Divine)'
);

-- line #7675
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHUNCIF 1000 (Medizone)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHUNCIF 1000 (Medizone)'
);

-- line #7676
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'CIFORION', u'strength_3': u'', u'company': u'ORION BIOTECH.', u'unit': u''}

-- line #7677
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIFORION 250 (ORION BIOTECH.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIFORION 250 (ORION BIOTECH.)'
);

-- line #7678
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIFORION 500 (Orion Life)',
	'Ceftriaxone',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIFORION 500 (Orion Life)'
);

-- line #7679
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'CIPLACEF', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #7680
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPLACEF 250 (Cipla)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPLACEF 250 (Cipla)'
);

-- line #7681
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPLACEF 500 (Cipla)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPLACEF 500 (Cipla)'
);

-- line #7682
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITREX 1000 (PARASOL)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITREX 1000 (PARASOL)'
);

-- line #7683
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'V', u'brand': u'COMTRIX', u'strength_3': u'', u'company': u'Comed', u'unit': u''}

-- line #7684
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COMTRIX 250 (Comed)',
	'Ceftriaxone',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COMTRIX 250 (Comed)'
);

-- line #7685
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COMTRIX 500 (Comed)',
	'Ceftriaxone',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COMTRIX 500 (Comed)'
);

-- line #7686
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONCEFT 250 (Dial Ph.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONCEFT 250 (Dial Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONCEFT 1000 (Dial Ph.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONCEFT 1000 (Dial Ph.)'
);

-- line #7687
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'CORCEF', u'strength_3': u'', u'company': u'Corona', u'unit': u''}

-- line #7688
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORCEF 250 (Corona)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORCEF 250 (Corona)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORCEF 500 (Corona)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORCEF 500 (Corona)'
);

-- line #7689
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CRUZONE 1000 (Aronex Life)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CRUZONE 1000 (Aronex Life)'
);

-- line #7690
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CRUZONE 250 (Aronex Life)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CRUZONE 250 (Aronex Life)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CRUZONE 500 (Aronex Life)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CRUZONE 500 (Aronex Life)'
);

-- line #7691
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'C-TECH', u'strength_3': u'', u'company': u'Malar Hc.', u'unit': u''}

-- line #7692
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-TECH 250 (Malar Hc.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-TECH 250 (Malar Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-TECH 500 (Malar Hc.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-TECH 500 (Malar Hc.)'
);

-- line #7693
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1', u'strength_2': u'2;G', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'', u'brand': u'C-TRI G/2V', u'strength_3': u'', u'company': u'Zuventus', u'unit': u''}

-- line #7694
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-TRI 125 (Zuventus)',
	'Ceftriaxone',
	'V',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-TRI 125 (Zuventus)'
);

-- line #7695
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-TRI 250 (Zuventus)',
	'Ceftriaxone',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-TRI 250 (Zuventus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-TRI 500 (Zuventus)',
	'Ceftriaxone',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-TRI 500 (Zuventus)'
);

-- line #7696
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'', u'brand': u'CTX GM', u'strength_3': u'', u'company': u'SHINCE PH.', u'unit': u'mg'}

-- line #7697
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'V', u'brand': u'CT-XONE', u'strength_3': u'', u'company': u'SUN', u'unit': u''}

-- line #7698
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CT-XONE 250 (SUN)',
	'Ceftriaxone',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CT-XONE 250 (SUN)'
);

-- line #7699
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CTX 125 (SHINCE)',
	'Ceftriaxone',
	'VIAL',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CTX 125 (SHINCE)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CTX 250 (SHINCE)',
	'Ceftriaxone',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CTX 250 (SHINCE)'
);

-- line #7700
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CTX 500 (SHINCE)',
	'Ceftriaxone',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CTX 500 (SHINCE)'
);

-- line #7701
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'VIAL', u'brand': u'CUCEF', u'strength_3': u'', u'company': u'Curex', u'unit': u''}

-- line #7702
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUCEF 250 (Curex)',
	'Ceftriaxone',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUCEF 250 (Curex)'
);

-- line #7703
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUCEF 500 (Curex)',
	'Ceftriaxone',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUCEF 500 (Curex)'
);

-- line #7704
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'CURECEF', u'strength_3': u'', u'company': u'Cure Quick', u'unit': u''}

-- line #7705
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CURECEF 250 (Cure Quick)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CURECEF 250 (Cure Quick)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CURECEF 500 (Cure Quick)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CURECEF 500 (Cure Quick)'
);

-- line #7706
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'', u'brand': u'CURETRIAX GM', u'strength_3': u'', u'company': u'SAFE CURE', u'unit': u''}

-- line #7707
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'CUXONE', u'strength_3': u'', u'company': u'Cubit Hc.', u'unit': u''}

-- line #7708
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUXONE 250 (Cubit Hc.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUXONE 250 (Cubit Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUXONE 500 (Cubit Hc.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUXONE 500 (Cubit Hc.)'
);

-- line #7709
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'CX-ONE', u'strength_3': u'', u'company': u'HANBURYS', u'unit': u''}

-- line #7710
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1', u'strength_2': u'2;G', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'', u'brand': u'DALTRIX G/2INJ', u'strength_3': u'', u'company': u'Dallas Ph.', u'unit': u''}

-- line #7711
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DALTRIX 250 (Dallas Ph.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DALTRIX 250 (Dallas Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DALTRIX 500 (Dallas Ph.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DALTRIX 500 (Dallas Ph.)'
);

-- line #7712
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'D-CEF', u'strength_3': u'', u'company': u'Dwd', u'unit': u''}

-- line #7713
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'D-CEF 250 (Dwd)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'D-CEF 250 (Dwd)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'D-CEF 500 (Dwd)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'D-CEF 500 (Dwd)'
);

-- line #7714
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'VIAL', u'brand': u'D-CEF', u'strength_3': u'', u'company': u'Dwd', u'unit': u''}

-- line #7715
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'D-CEF 250 (Dwd)',
	'Ceftriaxone',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'D-CEF 250 (Dwd)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'D-CEF 500 (Dwd)',
	'Ceftriaxone',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'D-CEF 500 (Dwd)'
);

-- line #7716
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEFTRIX 250 (Devi Form.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEFTRIX 250 (Devi Form.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEFTRIX 1000 (Devi Form.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEFTRIX 1000 (Devi Form.)'
);

-- line #7717
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'DEWCEF', u'strength_3': u'', u'company': u'HALEDEW', u'unit': u''}

-- line #7718
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'E-CEF 125 (Lupin)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'E-CEF 125 (Lupin)'
);

-- line #7719
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'E-CEF', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #7720
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'E-CEF 250 (Lupin)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'E-CEF 250 (Lupin)'
);

-- line #7721
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'E-CEF 500 (Lupin)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'E-CEF 500 (Lupin)'
);

-- line #7722
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'E-CEF', u'strength_3': u'', u'company': u'MARLINE BIO.', u'unit': u''}

-- line #7723
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'E-CEF 250 (MARLINE BIO.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'E-CEF 250 (MARLINE BIO.)'
);

-- line #7724
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'EFECTAL', u'strength_3': u'', u'company': u'Neon', u'unit': u''}

-- line #7725
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EFECTAL 250 (Neon)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EFECTAL 250 (Neon)'
);

-- line #7726
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EFOCEFT 1000 (Reliance)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EFOCEFT 1000 (Reliance)'
);

-- line #7727
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EFOCEFT 250 (Reliance)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EFOCEFT 250 (Reliance)'
);

-- line #7728
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EFOCEFT 500 (Reliance)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EFOCEFT 500 (Reliance)'
);

-- line #7729
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'EFTRAX', u'strength_3': u'', u'company': u'Dynamic', u'unit': u''}

-- line #7730
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EFTRAX 250 (Dynamic)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EFTRAX 250 (Dynamic)'
);

-- line #7731
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'V', u'brand': u'EKCEF', u'strength_3': u'', u'company': u'Euphoric', u'unit': u''}

-- line #7732
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EKCEF 250 (Euphoric)',
	'Ceftriaxone',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EKCEF 250 (Euphoric)'
);

-- line #7733
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EKCEF 500 (Euphoric)',
	'Ceftriaxone',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EKCEF 500 (Euphoric)'
);

-- line #7734
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELZONE 250 (Elysium)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELZONE 250 (Elysium)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELZONE 1000 (Elysium)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELZONE 1000 (Elysium)'
);

-- line #7735
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMTRIAXONE 250 (Embiotic Lab.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMTRIAXONE 250 (Embiotic Lab.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMTRIAXONE 1000 (Embiotic Lab.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMTRIAXONE 1000 (Embiotic Lab.)'
);

-- line #7736
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'EMTRI', u'strength_3': u'', u'company': u'Captab', u'unit': u''}

-- line #7737
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENCEF 250 (Kentreck)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENCEF 250 (Kentreck)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENCEF 1000 (Kentreck)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENCEF 1000 (Kentreck)'
);

-- line #7738
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENZONE 1000 (National)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENZONE 1000 (National)'
);

-- line #7739
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'ENZONE', u'strength_3': u'', u'company': u'NORTECH REM.', u'unit': u''}

-- line #7740
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENZONE 250 (NORTECH REM.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENZONE 250 (NORTECH REM.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENZONE 500 (NORTECH REM.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENZONE 500 (NORTECH REM.)'
);

-- line #7741
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'ERACEF', u'strength_3': u'', u'company': u'Brawn Lab', u'unit': u''}

-- line #7742
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERACEF 250 (Brawn Lab)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERACEF 250 (Brawn Lab)'
);

-- line #7743
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERACEF 500 (Brawn Lab)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERACEF 500 (Brawn Lab)'
);

-- line #7744
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESTRIN 125 (Swayam Hc.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESTRIN 125 (Swayam Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESTRIN 250 (Swayam Hc.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESTRIN 250 (Swayam Hc.)'
);

-- line #7745
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESTRIN 500 (Swayam Hc.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESTRIN 500 (Swayam Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESTRIN 1000 (Swayam Hc.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESTRIN 1000 (Swayam Hc.)'
);

-- line #7746
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXTACEF-I 125 (Blue Cross)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXTACEF-I 125 (Blue Cross)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXTACEF-I 250 (Blue Cross)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXTACEF-I 250 (Blue Cross)'
);

-- line #7747
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'EXTACEF-I', u'strength_3': u'', u'company': u'Blue Cross', u'unit': u''}

-- line #7748
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXTACEF-I 500 (Blue Cross)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXTACEF-I 500 (Blue Cross)'
);

-- line #7749
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIAXONE 1000 (Finesse Ph.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIAXONE 1000 (Finesse Ph.)'
);

-- line #7750
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIAXONE 250 (Finesse Ph.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIAXONE 250 (Finesse Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIAXONE 500 (Finesse Ph.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIAXONE 500 (Finesse Ph.)'
);

-- line #7751
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'FINECEF', u'strength_3': u'', u'company': u'Piramal Hc.', u'unit': u''}

-- line #7752
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FINECEF 250 (Piramal Hc.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FINECEF 250 (Piramal Hc.)'
);

-- line #7753
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FINECEF 500 (Piramal Hc.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FINECEF 500 (Piramal Hc.)'
);

-- line #7754
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'FINETRIAX', u'strength_3': u'', u'company': u'Finecure', u'unit': u''}

-- line #7755
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FINETRIAX 250 (Finecure)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FINETRIAX 250 (Finecure)'
);

-- line #7756
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FINETRIAX 500 (Finecure)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FINETRIAX 500 (Finecure)'
);

-- line #7757
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FINTRAX 1000 (Chemo Bio.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FINTRAX 1000 (Chemo Bio.)'
);

-- line #7758
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIXON 125 (Lanark)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIXON 125 (Lanark)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIXON 250 (Lanark)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIXON 250 (Lanark)'
);

-- line #7759
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIXON 500 (Lanark)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIXON 500 (Lanark)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIXON 1000 (Lanark)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIXON 1000 (Lanark)'
);

-- line #7760
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'GEMINATE', u'strength_3': u'', u'company': u'GENESIS', u'unit': u''}

-- line #7761
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'VIAL', u'brand': u'GLEN', u'strength_3': u'', u'company': u'RASS HC.', u'unit': u''}

-- line #7762
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLEN 250 (RASS HC.)',
	'Ceftriaxone',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLEN 250 (RASS HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLEN 500 (RASS HC.)',
	'Ceftriaxone',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLEN 500 (RASS HC.)'
);

-- line #7763
-- ignoring line: field [strength_1] not numeric: >>>1G<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'250', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'GLICEF G/250', u'strength_3': u'', u'company': u'NEISS', u'unit': u'mg'}

-- line #7764
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'GRACEF', u'strength_3': u'', u'company': u'Graf Lab.', u'unit': u''}

-- line #7765
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRACEF 250 (Graf Lab.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRACEF 250 (Graf Lab.)'
);

-- line #7766
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRACEF 500 (Graf Lab.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRACEF 500 (Graf Lab.)'
);

-- line #7767
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRACIDE 1000 (Jackson)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRACIDE 1000 (Jackson)'
);

-- line #7768
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRACIDE 250 (Jackson)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRACIDE 250 (Jackson)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRACIDE 500 (Jackson)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRACIDE 500 (Jackson)'
);

-- line #7769
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'V', u'brand': u'GRAMOCEF', u'strength_3': u'', u'company': u'Micro Labs', u'unit': u''}

-- line #7770
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRAMOCEF 250 (Micro Labs)',
	'Ceftriaxone',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRAMOCEF 250 (Micro Labs)'
);

-- line #7771
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'GROSAFE', u'strength_3': u'', u'company': u'GERRYSUN PH.', u'unit': u''}

-- line #7772
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'V', u'brand': u'GUTENCEF', u'strength_3': u'', u'company': u'Merck', u'unit': u''}

-- line #7773
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GUTENCEF 250 (Merck)',
	'Ceftriaxone',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GUTENCEF 250 (Merck)'
);

-- line #7774
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HANUCEF 250 (Ravian)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HANUCEF 250 (Ravian)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HANUCEF 1000 (Ravian)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HANUCEF 1000 (Ravian)'
);

-- line #7775
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HAXONE 250 (Hal)',
	'Ceftriaxone',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HAXONE 250 (Hal)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HAXONE 1000 (Hal)',
	'Ceftriaxone',
	'VIAL',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HAXONE 1000 (Hal)'
);

-- line #7776
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1GM', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'HG-CEF', u'strength_3': u'', u'company': u'Healthgaurd', u'unit': u''}

-- line #7777
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'V', u'brand': u'HICEF', u'strength_3': u'', u'company': u'Samarth', u'unit': u''}

-- line #7778
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'HIGHSAFE', u'strength_3': u'', u'company': u"Dr.Arvind Shah''S", u'unit': u''}

-- line #7779
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'I-CEF 250 (Izen Ph.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'I-CEF 250 (Izen Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'I-CEF 500 (Izen Ph.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'I-CEF 500 (Izen Ph.)'
);

-- line #7780
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'I-CEF 1000 (Izen Ph.)',
	'Ceftriaxone',
	'V',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'I-CEF 1000 (Izen Ph.)'
);

-- line #7781
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IFYTROX 1000 (Sanify)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IFYTROX 1000 (Sanify)'
);

-- line #7782
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IFYTROX 125 (Sanify)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IFYTROX 125 (Sanify)'
);

-- line #7783
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IFYTROX 250 (Sanify)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IFYTROX 250 (Sanify)'
);

-- line #7784
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IFYTROX 500 (Sanify)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IFYTROX 500 (Sanify)'
);

-- line #7785
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMMUNOX 1000 (VENUS REM.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMMUNOX 1000 (VENUS REM.)'
);

-- line #7786
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMMUNOX 250 (VENUS REM.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMMUNOX 250 (VENUS REM.)'
);

-- line #7787
-- ignoring line: field [strength_1] not numeric: >>>2G<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2G', u'strength_2': u'125', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'INCEF G/125', u'strength_3': u'', u'company': u'Intra Lab', u'unit': u'mg'}

-- line #7788
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INCEF 1000 (Intra Lab)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INCEF 1000 (Intra Lab)'
);

-- line #7789
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INCEF 250 (Intra Lab)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INCEF 250 (Intra Lab)'
);

-- line #7790
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INCEF 500 (Intra Lab)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INCEF 500 (Intra Lab)'
);

-- line #7791
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'I-TAX 1000 (Sanjeevani Bio.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'I-TAX 1000 (Sanjeevani Bio.)'
);

-- line #7792
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'I-TAX 250 (Sanjeevani Bio.)',
	'Ceftriaxone',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'I-TAX 250 (Sanjeevani Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'I-TAX 500 (Sanjeevani Bio.)',
	'Ceftriaxone',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'I-TAX 500 (Sanjeevani Bio.)'
);

-- line #7793
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'I-TONE 125 (Sanjivani)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'I-TONE 125 (Sanjivani)'
);

-- line #7794
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'I-TONE', u'strength_3': u'', u'company': u'Sanjivani', u'unit': u''}

-- line #7795
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'I-TONE 250 (Sanjivani)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'I-TONE 250 (Sanjivani)'
);

-- line #7796
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'I-TONE', u'strength_3': u'', u'company': u'Sanjivani', u'unit': u''}

-- line #7797
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'I-TONE 500 (Sanjivani)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'I-TONE 500 (Sanjivani)'
);

-- line #7798
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'VIAL', u'brand': u'IVIXONE', u'strength_3': u'', u'company': u'Vhb', u'unit': u''}

-- line #7799
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IVIXONE 250 (Vhb)',
	'Ceftriaxone',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IVIXONE 250 (Vhb)'
);

-- line #7800
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'VIAL', u'brand': u'IVIXONE', u'strength_3': u'', u'company': u'Vhb', u'unit': u''}

-- line #7801
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'JYOCEF', u'strength_3': u'', u'company': u'Biocin Gen.', u'unit': u''}

-- line #7802
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JYOCEF 250 (Biocin Gen.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JYOCEF 250 (Biocin Gen.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JYOCEF 500 (Biocin Gen.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JYOCEF 500 (Biocin Gen.)'
);

-- line #7803
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'VIAL', u'brand': u'KAFI', u'strength_3': u'', u'company': u'VENSAT', u'unit': u''}

-- line #7804
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KAFI 250 (VENSAT)',
	'Ceftriaxone',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KAFI 250 (VENSAT)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KAFI 500 (VENSAT)',
	'Ceftriaxone',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KAFI 500 (VENSAT)'
);

-- line #7805
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KAMICEF IV 1000 (KAMSONS PH.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KAMICEF IV 1000 (KAMSONS PH.)'
);

-- line #7806
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KAYCIDE 250 (Khushal Ph.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KAYCIDE 250 (Khushal Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KAYCIDE 1000 (Khushal Ph.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KAYCIDE 1000 (Khushal Ph.)'
);

-- line #7807
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KCEF 1000 (N.I.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KCEF 1000 (N.I.)'
);

-- line #7808
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFOTAX 1000 (GRANDIX)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFOTAX 1000 (GRANDIX)'
);

-- line #7809
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFOTAX 2000 (GRANDIX)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('2000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFOTAX 2000 (GRANDIX)'
);

-- line #7810
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFOTAX 250 (GRANDIX)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFOTAX 250 (GRANDIX)'
);

-- line #7811
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFOTEX 500 (Grandix)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFOTEX 500 (Grandix)'
);

-- line #7812
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFTAC 250 (PHARMATECH)',
	'Ceftriaxone',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFTAC 250 (PHARMATECH)'
);

-- line #7813
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFTAC 500 (PHARMATECH)',
	'Ceftriaxone',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFTAC 500 (PHARMATECH)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFTAC 1000 (PHARMATECH)',
	'Ceftriaxone',
	'VIAL',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFTAC 1000 (PHARMATECH)'
);

-- line #7814
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFTRA 125 (Ipca)',
	'Ceftriaxone',
	'VIAL',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFTRA 125 (Ipca)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFTRA 250 (Ipca)',
	'Ceftriaxone',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFTRA 250 (Ipca)'
);

-- line #7815
-- ignoring line: field [strength_1] not numeric: >>>1G<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'500', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'VIAL', u'brand': u'KEFTRA', u'strength_3': u'', u'company': u'Ipca', u'unit': u'mg'}

-- line #7816
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFTRA 500 (Ipca)',
	'Ceftriaxone',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFTRA 500 (Ipca)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFTRA 1000 (Ipca)',
	'Ceftriaxone',
	'VIAL',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFTRA 1000 (Ipca)'
);

-- line #7817
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEMTRAX 250 (Chemo Bio.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEMTRAX 250 (Chemo Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEMTRAX 1000 (Chemo Bio.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEMTRAX 1000 (Chemo Bio.)'
);

-- line #7818
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'KEXEF', u'strength_3': u'', u'company': u'Cadex Lab', u'unit': u''}

-- line #7819
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEXEF 250 (Cadex Lab)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEXEF 250 (Cadex Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEXEF 500 (Cadex Lab)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEXEF 500 (Cadex Lab)'
);

-- line #7820
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEXONE 1000 (Medispan)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEXONE 1000 (Medispan)'
);

-- line #7821
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEXONE 250 (Medispan)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEXONE 250 (Medispan)'
);

-- line #7822
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ G', u'brand': u'KOCEF', u'strength_3': u'', u'company': u'Kopran', u'unit': u''}

-- line #7823
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KOCEF 250 (Kopran)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KOCEF 250 (Kopran)'
);

-- line #7824
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KOCEF 500 (Kopran)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KOCEF 500 (Kopran)'
);

-- line #7825
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAXEF 125 (Biocin Hc.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAXEF 125 (Biocin Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAXEF 250 (Biocin Hc.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAXEF 250 (Biocin Hc.)'
);

-- line #7826
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAXEF 500 (Biocin Hc.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAXEF 500 (Biocin Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAXEF 1000 (Biocin Hc.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAXEF 1000 (Biocin Hc.)'
);

-- line #7827
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'LEXCEF', u'strength_3': u'', u'company': u'LEXMARK PH.', u'unit': u''}

-- line #7828
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'VIAL', u'brand': u'LISEL', u'strength_3': u'', u'company': u'MADHAV BIO.', u'unit': u''}

-- line #7829
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LISEL 250 (MADHAV BIO.)',
	'Ceftriaxone',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LISEL 250 (MADHAV BIO.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LISEL 500 (MADHAV BIO.)',
	'Ceftriaxone',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LISEL 500 (MADHAV BIO.)'
);

-- line #7830
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'LUCETUM', u'strength_3': u'', u'company': u'STAUNCH', u'unit': u''}

-- line #7831
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'LUCETUM', u'strength_3': u'', u'company': u'STAUNCH', u'unit': u''}

-- line #7832
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYCEFT 125 (HETERO HC.)',
	'Ceftriaxone',
	'V',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYCEFT 125 (HETERO HC.)'
);

-- line #7833
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'V', u'brand': u'LYCEFT', u'strength_3': u'', u'company': u'HETERO HC.', u'unit': u''}

-- line #7834
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYCEFT 250 (HETERO HC.)',
	'Ceftriaxone',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYCEFT 250 (HETERO HC.)'
);

-- line #7835
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYCEFT 500 (HETERO HC.)',
	'Ceftriaxone',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYCEFT 500 (HETERO HC.)'
);

-- line #7836
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'MACZONE', u'strength_3': u'', u'company': u'Macleods', u'unit': u''}

-- line #7837
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACZONE 250 (Macleods)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACZONE 250 (Macleods)'
);

-- line #7838
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACZONE 500 (Macleods)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACZONE 500 (Macleods)'
);

-- line #7839
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAGTRAX 250 (Magnus Bio.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/1000'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAGTRAX 250 (Magnus Bio.)'
);

-- line #7840
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'MAHACEF', u'strength_3': u'', u'company': u'Discovery M.', u'unit': u''}

-- line #7841
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAHACEF 250 (Discovery M.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAHACEF 250 (Discovery M.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAHACEF 500 (Discovery M.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAHACEF 500 (Discovery M.)'
);

-- line #7842
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MARCEF 250 (Mark Rem.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MARCEF 250 (Mark Rem.)'
);

-- line #7843
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'VIAL', u'brand': u'MARCEF', u'strength_3': u'', u'company': u'Mark Rem.', u'unit': u''}

-- line #7844
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAXONE 1000 (Meridian)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAXONE 1000 (Meridian)'
);

-- line #7845
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAXONE 250 (Meridian)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAXONE 250 (Meridian)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAXONE 500 (Meridian)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAXONE 500 (Meridian)'
);

-- line #7846
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'MEDOXONE', u'strength_3': u'', u'company': u'Medopharm', u'unit': u''}

-- line #7847
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDOXONE 250 (Medopharm)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDOXONE 250 (Medopharm)'
);

-- line #7848
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGAZONE 1000 (Solitaire)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGAZONE 1000 (Solitaire)'
);

-- line #7849
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGAZONE 250 (Solitaire)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGAZONE 250 (Solitaire)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGAZONE 500 (Solitaire)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGAZONE 500 (Solitaire)'
);

-- line #7850
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOCEF 1000 (MORISON PH.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOCEF 1000 (MORISON PH.)'
);

-- line #7851
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'VIAL', u'brand': u'MOCEF', u'strength_3': u'', u'company': u'AAMORB(ST. MORISON)', u'unit': u''}

-- line #7852
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOCEF 250 (AAMORB(ST. MORISON))',
	'Ceftriaxone',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg/500'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOCEF 250 (AAMORB(ST. MORISON))'
);

-- line #7853
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'125', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'', u'brand': u'MONOCEF IV', u'strength_3': u'', u'company': u'Aristo', u'unit': u'mg'}

-- line #7854
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'', u'brand': u'MONOCEF IV', u'strength_3': u'', u'company': u'Aristo', u'unit': u'mg'}

-- line #7855
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'', u'brand': u'MONOCEF IV', u'strength_3': u'', u'company': u'Aristo', u'unit': u'mg'}

-- line #7856
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'', u'brand': u'MONOCEF IV G', u'strength_3': u'', u'company': u'Aristo', u'unit': u''}

-- line #7857
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'', u'brand': u'MONOCEF IV G', u'strength_3': u'', u'company': u'Aristo', u'unit': u''}

-- line #7858
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOTAX 125 (Biochem)',
	'Ceftriaxone',
	'V',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOTAX 125 (Biochem)'
);

-- line #7859
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'V', u'brand': u'MONOTAX', u'strength_3': u'', u'company': u'Biochem', u'unit': u''}

-- line #7860
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOTAX 250 (Biochem)',
	'Ceftriaxone',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOTAX 250 (Biochem)'
);

-- line #7861
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'V', u'brand': u'MONOTAX', u'strength_3': u'', u'company': u'Biochem', u'unit': u''}

-- line #7862
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOTAX 500 (Biochem)',
	'Ceftriaxone',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOTAX 500 (Biochem)'
);

-- line #7863
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOSEF 1000 (Charmos Bio.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOSEF 1000 (Charmos Bio.)'
);

-- line #7864
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOSEF 250 (Charmos Bio.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOSEF 250 (Charmos Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOSEF 500 (Charmos Bio.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOSEF 500 (Charmos Bio.)'
);

-- line #7865
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1GM', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'MP-CEFT', u'strength_3': u'', u'company': u'Medicorp', u'unit': u''}

-- line #7866
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'M-TRAX 1000 (Mercury Hc.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'M-TRAX 1000 (Mercury Hc.)'
);

-- line #7867
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NACXONE 125 (Nac Int.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NACXONE 125 (Nac Int.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NACXONE 250 (Nac Int.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NACXONE 250 (Nac Int.)'
);

-- line #7868
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NACXONE 500 (Nac Int.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NACXONE 500 (Nac Int.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NACXONE 1000 (Nac Int.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NACXONE 1000 (Nac Int.)'
);

-- line #7869
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NATAXONE 1000 (Pfiscar Ind.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NATAXONE 1000 (Pfiscar Ind.)'
);

-- line #7870
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NATAXONE 250 (Pfiscar Ind.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NATAXONE 250 (Pfiscar Ind.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NATAXONE 500 (Pfiscar Ind.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NATAXONE 500 (Pfiscar Ind.)'
);

-- line #7871
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEFZON 1000 (Nitin Ph.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEFZON 1000 (Nitin Ph.)'
);

-- line #7872
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEFZON 250 (Nitin Ph.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEFZON 250 (Nitin Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEFZON 500 (Nitin Ph.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEFZON 500 (Nitin Ph.)'
);

-- line #7873
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEXCEF 125 (Nexus)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEXCEF 125 (Nexus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEXCEF 250 (Nexus)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEXCEF 250 (Nexus)'
);

-- line #7874
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEXCEF 500 (Nexus)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEXCEF 500 (Nexus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEXCEF 1000 (Nexus)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEXCEF 1000 (Nexus)'
);

-- line #7875
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'VIAL', u'brand': u'NEXEF-O', u'strength_3': u'', u'company': u'INVISION', u'unit': u''}

-- line #7876
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEXEF-O 250 (INVISION)',
	'Ceftriaxone',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEXEF-O 250 (INVISION)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEXEF-O 500 (INVISION)',
	'Ceftriaxone',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEXEF-O 500 (INVISION)'
);

-- line #7877
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NICZONE 1000 (Phytochem)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NICZONE 1000 (Phytochem)'
);

-- line #7878
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NICZONE 250 (Phytochem)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NICZONE 250 (Phytochem)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NICZONE 500 (Phytochem)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NICZONE 500 (Phytochem)'
);

-- line #7879
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIZOTRAX 250 (USP LIFE)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/1000'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIZOTRAX 250 (USP LIFE)'
);

-- line #7880
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORCEF 250 (NORTECH REM.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/1G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORCEF 250 (NORTECH REM.)'
);

-- line #7881
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'NOSOCARE', u'strength_3': u'', u'company': u'COXSWAIN HC.', u'unit': u''}

-- line #7882
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'V', u'brand': u'NOSOCEF', u'strength_3': u'', u'company': u'Merind', u'unit': u''}

-- line #7883
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOSOCEF 250 (Merind)',
	'Ceftriaxone',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOSOCEF 250 (Merind)'
);

-- line #7884
-- ignoring line: field [strength_1] not numeric: >>>1G<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'VIAL', u'brand': u'NOVACEFT G/500', u'strength_3': u'', u'company': u'Radicura', u'unit': u'500'}

-- line #7885
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVACEFT 125 (Radicura)',
	'Ceftriaxone',
	'VIAL',
	gm.nullify_empty_string('125')::numeric,
	'250'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVACEFT 125 (Radicura)'
);

-- line #7886
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVATRAX 250 (Novagen Ph.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVATRAX 250 (Novagen Ph.)'
);

-- line #7887
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVATRAX 500 (Novagen Ph.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVATRAX 500 (Novagen Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVATRAX 1000 (Novagen Ph.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVATRAX 1000 (Novagen Ph.)'
);

-- line #7888
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NU AXIOM 250 (Panjon)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NU AXIOM 250 (Panjon)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NU AXIOM 1000 (Panjon)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NU AXIOM 1000 (Panjon)'
);

-- line #7889
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'OCEF', u'strength_3': u'', u'company': u'Osper', u'unit': u''}

-- line #7890
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODICEF 2000 (Galapha)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('2000')::numeric,
	'mg(SOD)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODICEF 2000 (Galapha)'
);

-- line #7891
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODICEF 125 (Galpha)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODICEF 125 (Galpha)'
);

-- line #7892
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'ODICEF', u'strength_3': u'', u'company': u'Galpha', u'unit': u''}

-- line #7893
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODICEF 250 (Galpha)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODICEF 250 (Galpha)'
);

-- line #7894
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODICEF 500 (Galpha)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODICEF 500 (Galpha)'
);

-- line #7895
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFRAMAX 125 (Ranbaxy)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFRAMAX 125 (Ranbaxy)'
);

-- line #7896
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'OFRAMAX', u'strength_3': u'', u'company': u'Ranbaxy', u'unit': u''}

-- line #7897
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFRAMAX 500 (Ranbaxy)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFRAMAX 500 (Ranbaxy)'
);

-- line #7898
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'V', u'brand': u'OFRAMAX', u'strength_3': u'', u'company': u'Ranbaxy', u'unit': u''}

-- line #7899
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFRAMAX 250 (Ranbaxy)',
	'Ceftriaxone',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFRAMAX 250 (Ranbaxy)'
);

-- line #7900
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLCEFONE 1000 (Olcare)',
	'CEFTRIAXONE',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLCEFONE 1000 (Olcare)'
);

-- line #7901
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLCEFONE 250 (Olcare)',
	'CEFTRIAXONE',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLCEFONE 250 (Olcare)'
);

-- line #7902
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'OMISAFE', u'strength_3': u'', u'company': u'INNOVATIVE', u'unit': u''}

-- line #7903
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMISAFE 250 (INNOVATIVE)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMISAFE 250 (INNOVATIVE)'
);

-- line #7904
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'', u'brand': u'OMNA ONE', u'strength_3': u'', u'company': u'Nicholas', u'unit': u'mg'}

-- line #7905
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'', u'brand': u'OMNA ONE', u'strength_3': u'', u'company': u'Nicholas', u'unit': u'mg'}

-- line #7906
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONCEFT 125 (Adison Lab)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONCEFT 125 (Adison Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONCEFT 250 (Adison Lab)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONCEFT 250 (Adison Lab)'
);

-- line #7907
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONCEFT 500 (Adison Lab)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONCEFT 500 (Adison Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONCEFT 1000 (Adison Lab)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONCEFT 1000 (Adison Lab)'
);

-- line #7908
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'VIAL', u'brand': u'ONCEF', u'strength_3': u'', u'company': u'PLUS INDIA', u'unit': u''}

-- line #7909
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONCEF 250 (PLUS INDIA)',
	'Ceftriaxone',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONCEF 250 (PLUS INDIA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONCEF 500 (PLUS INDIA)',
	'Ceftriaxone',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONCEF 500 (PLUS INDIA)'
);

-- line #7910
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'ONECEF', u'strength_3': u'', u'company': u'UNIMARK REM.', u'unit': u''}

-- line #7911
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONECEF 250 (UNIMARK REM.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONECEF 250 (UNIMARK REM.)'
);

-- line #7912
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'V', u'brand': u'ORICEFT', u'strength_3': u'', u'company': u'Ophthal R.', u'unit': u''}

-- line #7913
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORICEFT 250 (Ophthal R.)',
	'Ceftriaxone',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORICEFT 250 (Ophthal R.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORICEFT 500 (Ophthal R.)',
	'Ceftriaxone',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORICEFT 500 (Ophthal R.)'
);

-- line #7914
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OVYCEF 1000 (Zedip Form.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OVYCEF 1000 (Zedip Form.)'
);

-- line #7915
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OVYCEF 250 (Zedip Form.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OVYCEF 250 (Zedip Form.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OVYCEF 500 (Zedip Form.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OVYCEF 500 (Zedip Form.)'
);

-- line #7916
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXY 250 (D.R.John''S)',
	'Ceftriaxone',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXY 250 (D.R.John''S)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXY 500 (D.R.John''S)',
	'Ceftriaxone',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXY 500 (D.R.John''S)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXY 1000 (D.R.John''S)',
	'Ceftriaxone',
	'VIAL',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXY 1000 (D.R.John''S)'
);

-- line #7917
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANCEF 125 (Aglowmed)',
	'Ceftriaxone',
	'V',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANCEF 125 (Aglowmed)'
);

-- line #7918
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'V', u'brand': u'PANCEF', u'strength_3': u'', u'company': u'Aglowmed', u'unit': u''}

-- line #7919
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANCEF 250 (Aglowmed)',
	'Ceftriaxone',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANCEF 250 (Aglowmed)'
);

-- line #7920
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANCEF 500 (Aglowmed)',
	'Ceftriaxone',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANCEF 500 (Aglowmed)'
);

-- line #7921
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARCEF 250 (EAST WEST)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/1000'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARCEF 250 (EAST WEST)'
);

-- line #7922
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'PFITRAX', u'strength_3': u'', u'company': u'ANVIK BIO.', u'unit': u''}

-- line #7923
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PFITRAX 250 (ANVIK BIO.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PFITRAX 250 (ANVIK BIO.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PFITRAX 500 (ANVIK BIO.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PFITRAX 500 (ANVIK BIO.)'
);

-- line #7924
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POLYCEF 250 (Brooks Ph.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POLYCEF 250 (Brooks Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POLYCEF 1000 (Brooks Ph.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POLYCEF 1000 (Brooks Ph.)'
);

-- line #7925
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POWERCEF 125 (Wockhardt)',
	'Ceftriaxone',
	'V',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POWERCEF 125 (Wockhardt)'
);

-- line #7926
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'V', u'brand': u'POWERCEF', u'strength_3': u'', u'company': u'Wockhardt', u'unit': u''}

-- line #7927
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POWERCEF 250 (Wockhardt)',
	'Ceftriaxone',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POWERCEF 250 (Wockhardt)'
);

-- line #7928
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POWERCEF 500 (Wockhardt)',
	'Ceftriaxone',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POWERCEF 500 (Wockhardt)'
);

-- line #7929
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'POWERZIP', u'strength_3': u'', u'company': u'SYNTRO HC.', u'unit': u''}

-- line #7930
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POWERZIP 250 (SYNTRO HC.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POWERZIP 250 (SYNTRO HC.)'
);

-- line #7931
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POWERZIP 500 (SYNTRO HC.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POWERZIP 500 (SYNTRO HC.)'
);

-- line #7932
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROXONE 1000 (Prohealth)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROXONE 1000 (Prohealth)'
);

-- line #7933
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROXONE 250 (Prohealth)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROXONE 250 (Prohealth)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROXONE 500 (Prohealth)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROXONE 500 (Prohealth)'
);

-- line #7934
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'QUIX', u'strength_3': u'', u'company': u'Que Ph.', u'unit': u''}

-- line #7935
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RENICEFT 1000 (REXUS HC.)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RENICEFT 1000 (REXUS HC.)'
);

-- line #7936
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1GM', u'strength_2': u'', u'substance': u'Ceftriaxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'RIAXOL', u'strength_3': u'', u'company': u'Royal', u'unit': u''}

-- line #7937
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIAXOL 250 (Royal)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIAXOL 250 (Royal)'
);

-- line #7938
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIAXOL 500 (Royal)',
	'Ceftriaxone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIAXOL 500 (Royal)'
);

-- line #7939
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'3A-CEF ALU 250 (3A PHARMA.)',
	'Cefuroxime',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '3A-CEF ALU 250 (3A PHARMA.)'
);

-- line #7940
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'3A-CEF ALU 500 (3A PHARMA.)',
	'Cefuroxime',
	'DT',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '3A-CEF ALU 500 (3A PHARMA.)'
);

-- line #7941
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'3A-CEF 500 (3A PHARMA.)',
	'Cefuroxime',
	'DT',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '3A-CEF 500 (3A PHARMA.)'
);

-- line #7942
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AAXIM 250 (Oscar Rem.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AAXIM 250 (Oscar Rem.)'
);

-- line #7943
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AAXIM 500 (Oscar Rem.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AAXIM 500 (Oscar Rem.)'
);

-- line #7944
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTUM 125 (ALICON PH.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTUM 125 (ALICON PH.)'
);

-- line #7945
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTUM 250 (ALICON PH.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTUM 250 (ALICON PH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTUM 500 (ALICON PH.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTUM 500 (ALICON PH.)'
);

-- line #7946
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADEXIM 125 (Admac Ph.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADEXIM 125 (Admac Ph.)'
);

-- line #7947
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADEXIM 250 (Admac Ph.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADEXIM 250 (Admac Ph.)'
);

-- line #7948
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADEXIM 500 (Admac Ph.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADEXIM 500 (Admac Ph.)'
);

-- line #7949
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AKSICEF 250 (Aksigen Hosp.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AKSICEF 250 (Aksigen Hosp.)'
);

-- line #7950
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AKSICEF 500 (Aksigen Hosp.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AKSICEF 500 (Aksigen Hosp.)'
);

-- line #7951
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.5G', u'strength_2': u'', u'substance': u'Cefuroxime', u'always_empty': u'', u'form': u'INJ', u'brand': u'ALLSEF', u'strength_3': u'', u'company': u'HAMPS BIO.', u'unit': u''}

-- line #7952
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALLSEF 750 (HAMPS BIO.)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALLSEF 750 (HAMPS BIO.)'
);

-- line #7953
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALLSEF 750 (HAMPS BIO)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg/1.5G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALLSEF 750 (HAMPS BIO)'
);

-- line #7954
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALLSEF 250 (HAMPS BIO)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALLSEF 250 (HAMPS BIO)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALLSEF 500 (HAMPS BIO)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALLSEF 500 (HAMPS BIO)'
);

-- line #7955
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.5G', u'strength_2': u'', u'substance': u'Cefuroxime', u'always_empty': u'', u'form': u'INJ', u'brand': u'ALTACEF', u'strength_3': u'', u'company': u'Glenmark', u'unit': u''}

-- line #7956
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALTACEF 250 (Glenmark)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALTACEF 250 (Glenmark)'
);

-- line #7957
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALTACEF 750 (Glenmark)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALTACEF 750 (Glenmark)'
);

-- line #7958
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALTACEF 500 (Glenmark)',
	'Cefuroxime',
	'OD TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALTACEF 500 (Glenmark)'
);

-- line #7959
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALTACEF 125 (Glenmark)',
	'Cefuroxime',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALTACEF 125 (Glenmark)'
);

-- line #7960
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALTACEF 125 (Glenmark)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALTACEF 125 (Glenmark)'
);

-- line #7961
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALTACEF 250 (Glenmark)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALTACEF 250 (Glenmark)'
);

-- line #7962
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALTACEF 500 (Glenmark)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALTACEF 500 (Glenmark)'
);

-- line #7963
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALTUM 250 (DR. ALSON)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALTUM 250 (DR. ALSON)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALTUM 500 (DR. ALSON)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALTUM 500 (DR. ALSON)'
);

-- line #7964
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AQTUM 125 (Aquila)',
	'Cefuroxime',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AQTUM 125 (Aquila)'
);

-- line #7965
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AQTUM 250 (Aquila)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AQTUM 250 (Aquila)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AQTUM 500 (Aquila)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AQTUM 500 (Aquila)'
);

-- line #7966
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AUROCEF 250 (Auroma Life)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AUROCEF 250 (Auroma Life)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AUROCEF 500 (Auroma Life)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AUROCEF 500 (Auroma Life)'
);

-- line #7967
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXACEF 125 (MEDREICH SAI.)',
	'Cefuroxime',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXACEF 125 (MEDREICH SAI.)'
);

-- line #7968
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXACEF 750 (MEDREICH SAI.)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXACEF 750 (MEDREICH SAI.)'
);

-- line #7969
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXACEF 250 (MEDREICH SAI.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXACEF 250 (MEDREICH SAI.)'
);

-- line #7970
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXACEF 500 (MEDREICH SAI.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXACEF 500 (MEDREICH SAI.)'
);

-- line #7971
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXEPTIL 250 (EMAR)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXEPTIL 250 (EMAR)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXEPTIL 500 (EMAR)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXEPTIL 500 (EMAR)'
);

-- line #7972
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXETIM 250 (Indu D.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg(AXETIL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXETIM 250 (Indu D.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXETIM 500 (Indu D.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg(AXETIL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXETIM 500 (Indu D.)'
);

-- line #7973
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXIFUR 125 (VERITAZ)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg(SOD)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXIFUR 125 (VERITAZ)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXIFUR 250 (VERITAZ)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg(SOD)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXIFUR 250 (VERITAZ)'
);

-- line #7974
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXIOM 250 (Biocin Gen.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXIOM 250 (Biocin Gen.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXIOM 500 (Biocin Gen.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXIOM 500 (Biocin Gen.)'
);

-- line #7975
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXITUF-KID 125 (Chemo Bio.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXITUF-KID 125 (Chemo Bio.)'
);

-- line #7976
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXITUF 250 (Chemo Bio.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXITUF 250 (Chemo Bio.)'
);

-- line #7977
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXITUF 500 (Chemo Bio.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXITUF 500 (Chemo Bio.)'
);

-- line #7978
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXTL 125 (VERITAZ)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXTL 125 (VERITAZ)'
);

-- line #7979
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXTL 250 (VERITAZ)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXTL 250 (VERITAZ)'
);

-- line #7980
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXTL 500 (VERITAZ)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXTL 500 (VERITAZ)'
);

-- line #7981
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACTICEF 750 (NEON)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACTICEF 750 (NEON)'
);

-- line #7982
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACTICEF 250 (NEON)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACTICEF 250 (NEON)'
);

-- line #7983
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACTICEF 500 (NEON)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACTICEF 500 (NEON)'
);

-- line #7984
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BAROCEF 500 (BARODA)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BAROCEF 500 (BARODA)'
);

-- line #7985
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENCEF 750 (INNOVATIVE)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENCEF 750 (INNOVATIVE)'
);

-- line #7986
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIGCEF 125 (Bestochem)',
	'Cefuroxime',
	'DT/250 TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIGCEF 125 (Bestochem)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIGCEF 250 (Bestochem)',
	'Cefuroxime',
	'DT/250 TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIGCEF 250 (Bestochem)'
);

-- line #7987
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.5G', u'strength_2': u'ML(IV', u'substance': u'Cefuroxime', u'always_empty': u'', u'form': u'INJ', u'brand': u'BIGCEF', u'strength_3': u'IM)', u'company': u'Bestochem', u'unit': u''}

-- line #7988
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIGCEF 750 (Bestochem)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIGCEF 750 (Bestochem)'
);

-- line #7989
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIGCEF 500 (Bestochem)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIGCEF 500 (Bestochem)'
);

-- line #7990
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOCEF 250 (SANCHEZ LAB.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOCEF 250 (SANCHEZ LAB.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOCEF 500 (SANCHEZ LAB.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOCEF 500 (SANCHEZ LAB.)'
);

-- line #7991
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOXIME 500 (Biocare Rem.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOXIME 500 (Biocare Rem.)'
);

-- line #7992
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIXIM-F 500 (Dynamic)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIXIM-F 500 (Dynamic)'
);

-- line #7993
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIXIM-K 125 (Dynamic)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIXIM-K 125 (Dynamic)'
);

-- line #7994
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIXIM-P 250 (Dynamic)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIXIM-P 250 (Dynamic)'
);

-- line #7995
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CASCEF 250 (CASCA)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CASCEF 250 (CASCA)'
);

-- line #7996
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CASCEF 500 (CASCA)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CASCEF 500 (CASCA)'
);

-- line #7997
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CDEF-AX 125 (WISCON)',
	'Cefuroxime',
	'SYRUP',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CDEF-AX 125 (WISCON)'
);

-- line #7998
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEBOX 125 (EAST WEST)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEBOX 125 (EAST WEST)'
);

-- line #7999
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEBOX 250 (EAST WEST)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEBOX 250 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEBOX 500 (EAST WEST)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEBOX 500 (EAST WEST)'
);

-- line #8000
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAC 125 (Nac Int.)',
	'Cefuroxime',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAC 125 (Nac Int.)'
);

-- line #8001
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFACT 750 (Royal)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFACT 750 (Royal)'
);

-- line #8002
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFACT 250 (Royal Lab)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFACT 250 (Royal Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFACT 500 (Royal Lab)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFACT 500 (Royal Lab)'
);

-- line #8003
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAGE 750 (Medoz Ph.)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAGE 750 (Medoz Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAGE 1500 (Medoz Ph.)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('1500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAGE 1500 (Medoz Ph.)'
);

-- line #8004
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAGE 250 (Medoz Ph.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAGE 250 (Medoz Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAGE 500 (Medoz Ph.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAGE 500 (Medoz Ph.)'
);

-- line #8005
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAKIND 125 (Mankind)',
	'Cefuroxime',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAKIND 125 (Mankind)'
);

-- line #8006
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAKIND 125 (Mankind)',
	'Cefuroxime',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAKIND 125 (Mankind)'
);

-- line #8007
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAKIND 250 (Mankind)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAKIND 250 (Mankind)'
);

-- line #8008
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAKIND 500 (Mankind)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAKIND 500 (Mankind)'
);

-- line #8009
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAM 250 (ADLEY PHARMA.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAM 250 (ADLEY PHARMA.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAM 500 (ADLEY PHARMA.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAM 500 (ADLEY PHARMA.)'
);

-- line #8010
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAM 750 (ADLEY PHARMA.)',
	'Cefuroxime',
	'VIAL',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAM 750 (ADLEY PHARMA.)'
);

-- line #8011
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFASYN 750 (Cipla)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFASYN 750 (Cipla)'
);

-- line #8012
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFASYN 250 (Cipla)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFASYN 250 (Cipla)'
);

-- line #8013
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFASYN 500 (Cipla)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFASYN 500 (Cipla)'
);

-- line #8014
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAXAL 500 (Arvind Lab.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAXAL 500 (Arvind Lab.)'
);

-- line #8015
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAXIL 125 (Lark Labs)',
	'Cefuroxime',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAXIL 125 (Lark Labs)'
);

-- line #8016
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAXIL 125 (Lark Labs)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAXIL 125 (Lark Labs)'
);

-- line #8017
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAXIL 250 (Lark Labs)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAXIL 250 (Lark Labs)'
);

-- line #8018
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAXIL 500 (Lark Labs)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAXIL 500 (Lark Labs)'
);

-- line #8019
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.5G', u'strength_2': u'', u'substance': u'Cefuroxime', u'always_empty': u'', u'form': u'', u'brand': u'CEFBET GM', u'strength_3': u'', u'company': u'ZYPHARS PH.', u'unit': u''}

-- line #8020
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250', u'strength_2': u'', u'substance': u'Cefuroxime', u'always_empty': u'', u'form': u'', u'brand': u'CEFBET', u'strength_3': u'', u'company': u'ZYPHARS PH.', u'unit': u'mg'}

-- line #8021
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500', u'strength_2': u'', u'substance': u'Cefuroxime', u'always_empty': u'', u'form': u'', u'brand': u'CEFBET', u'strength_3': u'', u'company': u'ZYPHARS PH.', u'unit': u'mg'}

-- line #8022
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'750', u'strength_2': u'', u'substance': u'Cefuroxime', u'always_empty': u'', u'form': u'', u'brand': u'CEFBET', u'strength_3': u'', u'company': u'ZYPHARS PH.', u'unit': u'mg'}

-- line #8023
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFEXL 250 (Active Hc.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFEXL 250 (Active Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFEXL 500 (Active Hc.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFEXL 500 (Active Hc.)'
);

-- line #8024
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFISEPT 125 (CHEMO HC.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFISEPT 125 (CHEMO HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFISEPT 250 (CHEMO HC.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFISEPT 250 (CHEMO HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFISEPT 500 (CHEMO HC.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFISEPT 500 (CHEMO HC.)'
);

-- line #8025
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFIYA 250 (KAVYA HC.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFIYA 250 (KAVYA HC.)'
);

-- line #8026
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.5G', u'strength_2': u'', u'substance': u'Cefuroxime', u'always_empty': u'', u'form': u'INJ', u'brand': u'CEFKING', u'strength_3': u'', u'company': u'Maneesh', u'unit': u''}

-- line #8027
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFKING 750 (Maneesh)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFKING 750 (Maneesh)'
);

-- line #8028
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFKING 250 (Maneesh)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg(AXETIL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFKING 250 (Maneesh)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFKING 750 (Maneesh)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg(AXETIL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFKING 750 (Maneesh)'
);

-- line #8029
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.5G', u'strength_2': u'', u'substance': u'Cefuroxime', u'always_empty': u'', u'form': u'INJ', u'brand': u'CEFLET', u'strength_3': u'', u'company': u'Ikon Rem', u'unit': u''}

-- line #8030
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFLET 750 (Ikon Rem)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFLET 750 (Ikon Rem)'
);

-- line #8031
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFLET 500 (Ikon Rem)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFLET 500 (Ikon Rem)'
);

-- line #8032
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFNEXT 500 (Cerspin)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFNEXT 500 (Cerspin)'
);

-- line #8033
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOB 250 (TRUMAC)',
	'Cefuroxime',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOB 250 (TRUMAC)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOB 500 (TRUMAC)',
	'Cefuroxime',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOB 500 (TRUMAC)'
);

-- line #8034
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOGEN 250 (Irm Ph.)',
	'Cefuroxime',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOGEN 250 (Irm Ph.)'
);

-- line #8035
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOGEN 750 (Irm Ph.)',
	'Cefuroxime',
	'V',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOGEN 750 (Irm Ph.)'
);

-- line #8036
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOPRIM 750 (United Bio.)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOPRIM 750 (United Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOPRIM 1500 (United Bio.)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('1500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOPRIM 1500 (United Bio.)'
);

-- line #8037
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOPRIM 250 (United Bio.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOPRIM 250 (United Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOPRIM 500 (United Bio.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOPRIM 500 (United Bio.)'
);

-- line #8038
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFORIM 250 (HETERO HC.)',
	'Cefuroxime',
	'TAB/750 INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFORIM 250 (HETERO HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFORIM 750 (HETERO HC.)',
	'Cefuroxime',
	'TAB/750 INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFORIM 750 (HETERO HC.)'
);

-- line #8039
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFORIM 500 (HETERO HC.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFORIM 500 (HETERO HC.)'
);

-- line #8040
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOS 1500 (Osper)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('1500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOS 1500 (Osper)'
);

-- line #8041
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOS 250 (Osper)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOS 250 (Osper)'
);

-- line #8042
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOS 750 (Osper)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOS 750 (Osper)'
);

-- line #8043
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOS 500 (Osper)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOS 500 (Osper)'
);

-- line #8044
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOXIM 125 (Biochem)',
	'Cefuroxime',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOXIM 125 (Biochem)'
);

-- line #8045
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOXIM 750 (Biochem)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOXIM 750 (Biochem)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOXIM 1500 (Biochem)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('1500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOXIM 1500 (Biochem)'
);

-- line #8046
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOXIM 250 (Biochem)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOXIM 250 (Biochem)'
);

-- line #8047
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOXIM 500 (Biochem)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOXIM 500 (Biochem)'
);

-- line #8048
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFPIL 500 (Pil)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFPIL 500 (Pil)'
);

-- line #8049
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFROX 750 (Marc Lab)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFROX 750 (Marc Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFROX 1500 (Marc Lab)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('1500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFROX 1500 (Marc Lab)'
);

-- line #8050
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFROX 125 (Marc Lab)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFROX 125 (Marc Lab)'
);

-- line #8051
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFROX 250 (Marc Lab)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFROX 250 (Marc Lab)'
);

-- line #8052
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFROX 500 (Marc Lab)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFROX 500 (Marc Lab)'
);

-- line #8053
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFROX 125 (Sain Med.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFROX 125 (Sain Med.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFROX 250 (Sain Med.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFROX 250 (Sain Med.)'
);

-- line #8054
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFROX 500 (Sain Med.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFROX 500 (Sain Med.)'
);

-- line #8055
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFSAFE 250 (Khandelwal)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFSAFE 250 (Khandelwal)'
);

-- line #8056
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFSAFE 500 (Khandelwal)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFSAFE 500 (Khandelwal)'
);

-- line #8057
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEF 250 (Sienna Form.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg(AXETIL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEF 250 (Sienna Form.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEF 500 (Sienna Form.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg(AXETIL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEF 500 (Sienna Form.)'
);

-- line #8058
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTAB 250 (Sienna Form.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTAB 250 (Sienna Form.)'
);

-- line #8059
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTAB 500 (Sienna Form.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTAB 500 (Sienna Form.)'
);

-- line #8060
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTADOM-250 250 (Dominion)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTADOM-250 250 (Dominion)'
);

-- line #8061
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTADOM-500 500 (Dominion)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTADOM-500 500 (Dominion)'
);

-- line #8062
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'Cefuroxime', u'always_empty': u'', u'form': u'', u'brand': u'CEFTADOM GM', u'strength_3': u'', u'company': u'Dominion', u'unit': u''}

-- line #8063
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTAL 50 (TALENT LAB.)',
	'Cefuroxime',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTAL 50 (TALENT LAB.)'
);

-- line #8064
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTAL 125 (TALENT LAB.)',
	'Cefuroxime',
	'DT TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTAL 125 (TALENT LAB.)'
);

-- line #8065
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTAL 250 (TALENT LAB.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTAL 250 (TALENT LAB.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTAL 500 (TALENT LAB.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTAL 500 (TALENT LAB.)'
);

-- line #8066
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTAL 250 (TALENT LAB.)',
	'Cefuroxime',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'750'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTAL 250 (TALENT LAB.)'
);

-- line #8067
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTAV 250 (Taurus Lab)',
	'Cefuroxime',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTAV 250 (Taurus Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTAV 750 (Taurus Lab)',
	'Cefuroxime',
	'VIAL',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTAV 750 (Taurus Lab)'
);

-- line #8068
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefuroxime', u'always_empty': u'', u'form': u'INJ', u'brand': u'CEFTAZ', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #8069
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTIL 250 (Stallion)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTIL 250 (Stallion)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTIL 500 (Stallion)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTIL 500 (Stallion)'
);

-- line #8070
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTIL 250 (Stallion)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTIL 250 (Stallion)'
);

-- line #8071
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTOP 125 (Solitaire)',
	'Cefuroxime',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTOP 125 (Solitaire)'
);

-- line #8072
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTUM 125 (GSK)',
	'Cefuroxime',
	'CAPTAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTUM 125 (GSK)'
);

-- line #8073
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTUM 250 (GSK)',
	'Cefuroxime',
	'CAPTAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTUM 250 (GSK)'
);

-- line #8074
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTUM 500 (GSK)',
	'Cefuroxime',
	'CAPTAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTUM 500 (GSK)'
);

-- line #8075
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTUM 125 (GSK)',
	'Cefuroxime',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTUM 125 (GSK)'
);

-- line #8076
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cefuroxime', u'always_empty': u'', u'form': u'INJ', u'brand': u'CEFUACE', u'strength_3': u'', u'company': u'STAUNCH', u'unit': u''}

-- line #8077
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFUACE 750 (STAUNCH)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFUACE 750 (STAUNCH)'
);

-- line #8078
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFUACE 250 (STAUNCH)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFUACE 250 (STAUNCH)'
);

-- line #8079
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFUACE 500 (STAUNCH)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFUACE 500 (STAUNCH)'
);

-- line #8080
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFUMAX 250 (Biomax Lab)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFUMAX 250 (Biomax Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFUMAX 500 (Biomax Lab)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFUMAX 500 (Biomax Lab)'
);

-- line #8081
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFUMEX 250 (EXCELLA)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFUMEX 250 (EXCELLA)'
);

-- line #8082
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFUMEX 500 (EXCELLA)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFUMEX 500 (EXCELLA)'
);

-- line #8083
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFUNIS 250 (NEISS)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFUNIS 250 (NEISS)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFUNIS 500 (NEISS)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFUNIS 500 (NEISS)'
);

-- line #8084
-- ignoring line: field [strength_1] not numeric: >>>0.75G<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.75G', u'strength_2': u'', u'substance': u'Cefuroxime', u'always_empty': u'', u'form': u'VIAL', u'brand': u'CEFUNIS', u'strength_3': u'', u'company': u'NEISS', u'unit': u'1.5G'}

-- line #8085
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'750', u'strength_2': u'', u'substance': u'Cefuroxime', u'always_empty': u'', u'form': u'', u'brand': u'CEFUNORM', u'strength_3': u'', u'company': u'UNIMARK REM.', u'unit': u'mg'}

-- line #8086
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFURA 250 (Secure)',
	'Cefuroxime',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFURA 250 (Secure)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFURA 500 (Secure)',
	'Cefuroxime',
	'DT',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFURA 500 (Secure)'
);

-- line #8087
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFURA 750 (Secure)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFURA 750 (Secure)'
);

-- line #8088
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFURICA 750 (MOLEKULE)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFURICA 750 (MOLEKULE)'
);

-- line #8089
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFURICA 250 (MOLEKULE)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFURICA 250 (MOLEKULE)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFURICA 500 (MOLEKULE)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFURICA 500 (MOLEKULE)'
);

-- line #8090
-- ignoring line: field [strength_1] not numeric: >>>1.5G<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.5G', u'strength_2': u'750', u'substance': u'Cefuroxime', u'always_empty': u'', u'form': u'VIAL', u'brand': u'CEFURICA', u'strength_3': u'', u'company': u'MOLEKULE', u'unit': u'mg'}

-- line #8091
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFURIN 125 (INVISION)',
	'Cefuroxime',
	'DT TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFURIN 125 (INVISION)'
);

-- line #8092
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFURIN 250 (Intra(INVISION))',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFURIN 250 (Intra(INVISION))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFURIN 500 (Intra(INVISION))',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFURIN 500 (Intra(INVISION))'
);

-- line #8093
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFURONAT 125 (Natco Ph.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFURONAT 125 (Natco Ph.)'
);

-- line #8094
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFURONAT 250 (Natco Ph.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFURONAT 250 (Natco Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFURONAT 500 (Natco Ph.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFURONAT 500 (Natco Ph.)'
);

-- line #8095
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFURON 250 (Ronak Lab.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFURON 250 (Ronak Lab.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFURON 500 (Ronak Lab.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFURON 500 (Ronak Lab.)'
);

-- line #8096
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFUROX 1500 (Csc Ph.)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('1500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFUROX 1500 (Csc Ph.)'
);

-- line #8097
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFUROX 750 (Csc Ph.)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFUROX 750 (Csc Ph.)'
);

-- line #8098
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFUROX-S 750 (Jackson)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFUROX-S 750 (Jackson)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFUROX-S 1500 (Jackson)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('1500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFUROX-S 1500 (Jackson)'
);

-- line #8099
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFUROX 250 (SHRI SWAMI)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFUROX 250 (SHRI SWAMI)'
);

-- line #8100
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFUROX 500 (SHRI SWAMI)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFUROX 500 (SHRI SWAMI)'
);

-- line #8101
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFURSON 250 (DAVIDSON BROCKS)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFURSON 250 (DAVIDSON BROCKS)'
);

-- line #8102
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFUSPAN-250 250 (S.P.A.N.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFUSPAN-250 250 (S.P.A.N.)'
);

-- line #8103
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFUSPAN 500 (S.P.A.N.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFUSPAN 500 (S.P.A.N.)'
);

-- line #8104
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFUTAB-O 125 (Sanjivani)',
	'Cefuroxime',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFUTAB-O 125 (Sanjivani)'
);

-- line #8105
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFUTAB-O 250 (Sanjivani)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFUTAB-O 250 (Sanjivani)'
);

-- line #8106
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFUTAB-O 500 (Sanjivani)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFUTAB-O 500 (Sanjivani)'
);

-- line #8107
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFUVIK 250 (ANKARE)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFUVIK 250 (ANKARE)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFUVIK 500 (ANKARE)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFUVIK 500 (ANKARE)'
);

-- line #8108
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFUVIK 250 (ANKARE)',
	'Cefuroxime',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFUVIK 250 (ANKARE)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFUVIK 500 (ANKARE)',
	'Cefuroxime',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFUVIK 500 (ANKARE)'
);

-- line #8109
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEF-VEPAN 125 (Indoco Rem.)',
	'Cefuroxime',
	'DS SUSP',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEF-VEPAN 125 (Indoco Rem.)'
);

-- line #8110
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEF - VEPAN 125 (Indoco Rem.)',
	'Cefuroxime',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEF - VEPAN 125 (Indoco Rem.)'
);

-- line #8111
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEF-VEPAN 250 (Indoco Rem.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEF-VEPAN 250 (Indoco Rem.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEF-VEPAN 500 (Indoco Rem.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEF-VEPAN 500 (Indoco Rem.)'
);

-- line #8112
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEF - VEPAN 250 (Indoco Rem.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEF - VEPAN 250 (Indoco Rem.)'
);

-- line #8113
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEF - VEPAN 500 (Indoco Rem.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEF - VEPAN 500 (Indoco Rem.)'
);

-- line #8114
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFYREX 250 (Global Med.)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFYREX 250 (Global Med.)'
);

-- line #8115
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFYREX 750 (Global Med.)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFYREX 750 (Global Med.)'
);

-- line #8116
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFYREX 125 (Global Med.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFYREX 125 (Global Med.)'
);

-- line #8117
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFYREX 250 (Global Med.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFYREX 250 (Global Med.)'
);

-- line #8118
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFZEE-H 250 (G.T. Ph.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFZEE-H 250 (G.T. Ph.)'
);

-- line #8119
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFZEE 500 (G.T. Ph.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFZEE 500 (G.T. Ph.)'
);

-- line #8120
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFZIM 1500 (Zee Lab)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('1500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFZIM 1500 (Zee Lab)'
);

-- line #8121
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFZIM 750 (Zee Lab)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFZIM 750 (Zee Lab)'
);

-- line #8122
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFZIM 250 (Zee Lab)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFZIM 250 (Zee Lab)'
);

-- line #8123
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFZIM 500 (Zee Lab)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFZIM 500 (Zee Lab)'
);

-- line #8124
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.5G', u'strength_2': u'', u'substance': u'Cefuroxime', u'always_empty': u'', u'form': u'INJ', u'brand': u'CEMAXCEF', u'strength_3': u'', u'company': u'Wanbury', u'unit': u''}

-- line #8125
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEMAXCEF 750 (Wanbury)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEMAXCEF 750 (Wanbury)'
);

-- line #8126
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEMAX-T 250 (Wanbury)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEMAX-T 250 (Wanbury)'
);

-- line #8127
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEMAX-T 500 (Wanbury)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEMAX-T 500 (Wanbury)'
);

-- line #8128
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPAROX 250 (Mercury Hc.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPAROX 250 (Mercury Hc.)'
);

-- line #8129
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.5G', u'strength_2': u'', u'substance': u'Cefuroxime', u'always_empty': u'', u'form': u'INJ', u'brand': u'CEPOKEM', u'strength_3': u'', u'company': u'TAJ PH.', u'unit': u''}

-- line #8130
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPOKEM 250 (TAJ PH.)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPOKEM 250 (TAJ PH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPOKEM 500 (TAJ PH.)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPOKEM 500 (TAJ PH.)'
);

-- line #8131
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPOKEM 125 (TAJ PH.)',
	'Cefuroxime',
	'SUSP',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPOKEM 125 (TAJ PH.)'
);

-- line #8132
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPOKEM 125 (TAJ PH.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPOKEM 125 (TAJ PH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPOKEM 250 (TAJ PH.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPOKEM 250 (TAJ PH.)'
);

-- line #8133
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPOKEM 500 (TAJ PH.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPOKEM 500 (TAJ PH.)'
);

-- line #8134
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEROM 125 (Piramal Hc.)',
	'Cefuroxime',
	'DS SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEROM 125 (Piramal Hc.)'
);

-- line #8135
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEROM 250 (Nicholas)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEROM 250 (Nicholas)'
);

-- line #8136
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEROM 500 (Nicholas)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEROM 500 (Nicholas)'
);

-- line #8137
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEROX 250 (Soft Ph.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEROX 250 (Soft Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEROX 500 (Soft Ph.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEROX 500 (Soft Ph.)'
);

-- line #8138
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETIL 125 (Lupin)',
	'Cefuroxime',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETIL 125 (Lupin)'
);

-- line #8139
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETIL 125 (Lupin)',
	'Cefuroxime',
	'FC TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETIL 125 (Lupin)'
);

-- line #8140
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETIL 250 (Lupin)',
	'Cefuroxime',
	'FC TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETIL 250 (Lupin)'
);

-- line #8141
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETIL 500 (Lupin)',
	'Cefuroxime',
	'FC TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETIL 500 (Lupin)'
);

-- line #8142
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.5G', u'strength_2': u'', u'substance': u'Cefuroxime', u'always_empty': u'', u'form': u'INJ', u'brand': u'CETIL', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #8143
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETIL 250 (Lupin)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETIL 250 (Lupin)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETIL 750 (Lupin)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETIL 750 (Lupin)'
);

-- line #8144
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEUROX 125 (Medley)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEUROX 125 (Medley)'
);

-- line #8145
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEUROX 250 (Medley)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEUROX 250 (Medley)'
);

-- line #8146
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEUROX 500 (Medley)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEUROX 500 (Medley)'
);

-- line #8147
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEXIM 250 (Devi Form.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEXIM 250 (Devi Form.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEXIM 500 (Devi Form.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEXIM 500 (Devi Form.)'
);

-- line #8148
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-FURO DRY 750 (HETERO HC.)',
	'Cefuroxime',
	'SYP',
	gm.nullify_empty_string('750')::numeric,
	'mg(ANHYDR.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-FURO DRY 750 (HETERO HC.)'
);

-- line #8149
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250', u'strength_2': u'', u'substance': u'Cefuroxime', u'always_empty': u'', u'form': u'', u'brand': u'CFURO', u'strength_3': u'', u'company': u'Genx Ph.', u'unit': u'mg'}

-- line #8150
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500', u'strength_2': u'', u'substance': u'Cefuroxime', u'always_empty': u'', u'form': u'', u'brand': u'CFURO', u'strength_3': u'', u'company': u'Genx Ph.', u'unit': u'mg'}

-- line #8151
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.5GM', u'strength_2': u'', u'substance': u'Cefuroxime', u'always_empty': u'', u'form': u'INJ', u'brand': u'C-FURO GM', u'strength_3': u'', u'company': u'HETERO HC.', u'unit': u''}

-- line #8152
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-FURO 750 (HETERO HC.)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-FURO 750 (HETERO HC.)'
);

-- line #8153
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-FURO 250 (Sayona)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-FURO 250 (Sayona)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-FURO 500 (Sayona)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-FURO 500 (Sayona)'
);

-- line #8154
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIFUZED 250 (Zota Ph.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIFUZED 250 (Zota Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIFUZED 500 (Zota Ph.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIFUZED 500 (Zota Ph.)'
);

-- line #8155
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CM-250 250 (L & V PH.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CM-250 250 (L & V PH.)'
);

-- line #8156
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CM-500 500 (L & V PH.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CM-500 500 (L & V PH.)'
);

-- line #8157
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COVATIL 125 (Macleods)',
	'Cefuroxime',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COVATIL 125 (Macleods)'
);

-- line #8158
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.5G', u'strength_2': u'', u'substance': u'Cefuroxime', u'always_empty': u'', u'form': u'INJ', u'brand': u'COVATIL', u'strength_3': u'', u'company': u'Macleods', u'unit': u''}

-- line #8159
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COVATIL 250 (Macleods)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COVATIL 250 (Macleods)'
);

-- line #8160
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COVATIL 750 (Macleods)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COVATIL 750 (Macleods)'
);

-- line #8161
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COVATIL 250 (Macleods)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COVATIL 250 (Macleods)'
);

-- line #8162
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COVATIL 500 (Macleods)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COVATIL 500 (Macleods)'
);

-- line #8163
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CRFURICA 250 (MOLEKULE)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CRFURICA 250 (MOLEKULE)'
);

-- line #8164
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CRFURICA 500 (MOLEKULE)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CRFURICA 500 (MOLEKULE)'
);

-- line #8165
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-ROCK 125 (Remedies)',
	'Cefuroxime',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-ROCK 125 (Remedies)'
);

-- line #8166
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-ROCK 250 (Remedies)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-ROCK 250 (Remedies)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-ROCK 500 (Remedies)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-ROCK 500 (Remedies)'
);

-- line #8167
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-TRI-T 125 (Emcure)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-TRI-T 125 (Emcure)'
);

-- line #8168
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-TRI-T 100 (Zuventus)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-TRI-T 100 (Zuventus)'
);

-- line #8169
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-TRI-T 250 (Emcure)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-TRI-T 250 (Emcure)'
);

-- line #8170
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-TRI-T 500 (Emcure)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-TRI-T 500 (Emcure)'
);

-- line #8171
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUROXIME 250 (Elfin Ph.)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUROXIME 250 (Elfin Ph.)'
);

-- line #8172
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUROXIME 750 (Elfin Ph.)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUROXIME 750 (Elfin Ph.)'
);

-- line #8173
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUROXIM 250 (Elfin Ph.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUROXIM 250 (Elfin Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUROXIM 500 (Elfin Ph.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUROXIM 500 (Elfin Ph.)'
);

-- line #8174
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUTIL 750 (Curex)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUTIL 750 (Curex)'
);

-- line #8175
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUTIL 500 (Curex)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUTIL 500 (Curex)'
);

-- line #8176
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUXIME 250 (Cubit Hc.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUXIME 250 (Cubit Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUXIME 500 (Cubit Hc.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUXIME 500 (Cubit Hc.)'
);

-- line #8177
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-XIME 750 (SYNER MED.)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg(WFI 10ML)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-XIME 750 (SYNER MED.)'
);

-- line #8178
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DALTUM 250 (Novagen Ph.)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DALTUM 250 (Novagen Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DALTUM 750 (Novagen Ph.)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DALTUM 750 (Novagen Ph.)'
);

-- line #8179
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DALTUM 125 (Novagen Ph.)',
	'Cefuroxime',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DALTUM 125 (Novagen Ph.)'
);

-- line #8180
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DALTUM 250 (Novagen Ph.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DALTUM 250 (Novagen Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DALTUM 500 (Novagen Ph.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DALTUM 500 (Novagen Ph.)'
);

-- line #8181
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DERICEF 125 (PSYCOREM)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DERICEF 125 (PSYCOREM)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DERICEF 250 (PSYCOREM)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DERICEF 250 (PSYCOREM)'
);

-- line #8182
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DERICEF 500 (PSYCOREM)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DERICEF 500 (PSYCOREM)'
);

-- line #8183
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEUXINE 125 (Shreeyam)',
	'Cefuroxime',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEUXINE 125 (Shreeyam)'
);

-- line #8184
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEUXINE 250 (Shreeyam)',
	'Cefuroxime',
	'TABA',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEUXINE 250 (Shreeyam)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEUXINE 500 (Shreeyam)',
	'Cefuroxime',
	'TABA',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEUXINE 500 (Shreeyam)'
);

-- line #8185
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIXIM-F 500 (Dynamic)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIXIM-F 500 (Dynamic)'
);

-- line #8186
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIXIM-K 125 (Dynamic)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIXIM-K 125 (Dynamic)'
);

-- line #8187
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIXIM-P 250 (Dynamic)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIXIM-P 250 (Dynamic)'
);

-- line #8188
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.5G', u'strength_2': u'', u'substance': u'Cefuroxime', u'always_empty': u'', u'form': u'INJ', u'brand': u'DUCATI', u'strength_3': u'', u'company': u'SLANEY HC.', u'unit': u''}

-- line #8189
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUCATI 250 (SLANEY HC.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUCATI 250 (SLANEY HC.)'
);

-- line #8190
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUCATI 500 (SLANEY HC.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUCATI 500 (SLANEY HC.)'
);

-- line #8191
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUXIM 250 (DAKSH)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUXIM 250 (DAKSH)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUXIM 500 (DAKSH)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUXIM 500 (DAKSH)'
);

-- line #8192
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELROXIM 250 (Phytochem)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELROXIM 250 (Phytochem)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELROXIM 500 (Phytochem)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELROXIM 500 (Phytochem)'
);

-- line #8193
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENGEL 125 (Blue Cross)',
	'Cefuroxime',
	'D.SYRUP',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENGEL 125 (Blue Cross)'
);

-- line #8194
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.5G', u'strength_2': u'', u'substance': u'Cefuroxime', u'always_empty': u'', u'form': u'INJ', u'brand': u'ENGEL', u'strength_3': u'', u'company': u'Blue Cross', u'unit': u''}

-- line #8195
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENGEL 750 (Blue Cross)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENGEL 750 (Blue Cross)'
);

-- line #8196
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENGEL 250 (Blue Cross)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENGEL 250 (Blue Cross)'
);

-- line #8197
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENGEL 500 (Blue Cross)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENGEL 500 (Blue Cross)'
);

-- line #8198
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENTUN 250 (EOAN PH.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENTUN 250 (EOAN PH.)'
);

-- line #8199
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUPHOREX 250 (SALVO HC.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUPHOREX 250 (SALVO HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUPHOREX 500 (SALVO HC.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUPHOREX 500 (SALVO HC.)'
);

-- line #8200
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EVERCEF 250 (Orchid Hc.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EVERCEF 250 (Orchid Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EVERCEF 500 (Orchid Hc.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EVERCEF 500 (Orchid Hc.)'
);

-- line #8201
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.5G', u'strength_2': u'', u'substance': u'Cefuroxime', u'always_empty': u'', u'form': u'INJ', u'brand': u'EXEPTION', u'strength_3': u'', u'company': u'Cfl Ph.', u'unit': u''}

-- line #8202
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXEPTION 750 (Cfl Ph.)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXEPTION 750 (Cfl Ph.)'
);

-- line #8203
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXEPTION 250 (Cfl Ph.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXEPTION 250 (Cfl Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXEPTION 500 (Cfl Ph.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXEPTION 500 (Cfl Ph.)'
);

-- line #8204
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.5GM', u'strength_2': u'', u'substance': u'Cefuroxime', u'always_empty': u'', u'form': u'INJ', u'brand': u'FEURO GM', u'strength_3': u'', u'company': u'Medicorp', u'unit': u''}

-- line #8205
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEURO 500 (Medicorp)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEURO 500 (Medicorp)'
);

-- line #8206
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLAMICEF 750 (FLAMINGO PH.)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLAMICEF 750 (FLAMINGO PH.)'
);

-- line #8207
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLCEF 125 (Cataliq)',
	'Cefuroxime',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLCEF 125 (Cataliq)'
);

-- line #8208
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLCEF 250 (Cataliq)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLCEF 250 (Cataliq)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLCEF 500 (Cataliq)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLCEF 500 (Cataliq)'
);

-- line #8209
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORCEF 125 (Aristo)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORCEF 125 (Aristo)'
);

-- line #8210
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORCEF 250 (Aristo)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORCEF 250 (Aristo)'
);

-- line #8211
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORCEF 500 (Aristo)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORCEF 500 (Aristo)'
);

-- line #8212
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORCEF 1500 (Aristo)',
	'Cefuroxime',
	'V',
	gm.nullify_empty_string('1500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORCEF 1500 (Aristo)'
);

-- line #8213
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORCEF 250 (Aristo)',
	'Cefuroxime',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORCEF 250 (Aristo)'
);

-- line #8214
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORCEF 500 (Aristo)',
	'Cefuroxime',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORCEF 500 (Aristo)'
);

-- line #8215
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORCEZ 250 (LAKSUN)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORCEZ 250 (LAKSUN)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORCEZ 500 (LAKSUN)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORCEZ 500 (LAKSUN)'
);

-- line #8216
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORKEM 250 (Forgo Ph.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORKEM 250 (Forgo Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORKEM 500 (Forgo Ph.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORKEM 500 (Forgo Ph.)'
);

-- line #8217
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORU 125 (Bayer)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg(AXETIL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORU 125 (Bayer)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORU 250 (Bayer)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg(AXETIL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORU 250 (Bayer)'
);

-- line #8218
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORU 500 (Bayer)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg(AXETIL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORU 500 (Bayer)'
);

-- line #8219
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.5G', u'strength_2': u'', u'substance': u'Cefuroxime', u'always_empty': u'', u'form': u'INJ', u'brand': u'FUCEF', u'strength_3': u'', u'company': u'Radix Bio.', u'unit': u''}

-- line #8220
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUCEF 250 (Radix Bio.)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUCEF 250 (Radix Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUCEF 750 (Radix Bio.)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUCEF 750 (Radix Bio.)'
);

-- line #8221
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUCEF 250 (Radix Bio.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUCEF 250 (Radix Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUCEF 500 (Radix Bio.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUCEF 500 (Radix Bio.)'
);

-- line #8222
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FURION 250 (ORION BIOTECH.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FURION 250 (ORION BIOTECH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FURION 500 (ORION BIOTECH.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FURION 500 (ORION BIOTECH.)'
);

-- line #8223
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUROBID 125 (Alembic)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUROBID 125 (Alembic)'
);

-- line #8224
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUROBID 250 (Alembic)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUROBID 250 (Alembic)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUROBID 500 (Alembic)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUROBID 500 (Alembic)'
);

-- line #8225
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUROBID 250 (ALEMBIC)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUROBID 250 (ALEMBIC)'
);

-- line #8226
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUROBID 500 (ALEMBIC)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUROBID 500 (ALEMBIC)'
);

-- line #8227
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUROMAX 250 (BIOMAX BIO.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUROMAX 250 (BIOMAX BIO.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUROMAX 500 (BIOMAX BIO.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUROMAX 500 (BIOMAX BIO.)'
);

-- line #8228
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUROMED 125 (Lypho Med)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUROMED 125 (Lypho Med)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUROMED 250 (Lypho Med)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUROMED 250 (Lypho Med)'
);

-- line #8229
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUROMED 500 (Lypho Med)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUROMED 500 (Lypho Med)'
);

-- line #8230
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUROXIL 250 (Torrent)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUROXIL 250 (Torrent)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUROXIL 750 (Torrent)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUROXIL 750 (Torrent)'
);

-- line #8231
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUROXIL 250 (Apex Form.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUROXIL 250 (Apex Form.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUROXIL 500 (Apex Form.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUROXIL 500 (Apex Form.)'
);

-- line #8232
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUROXIME 125 (IP HC.)',
	'Cefuroxime',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUROXIME 125 (IP HC.)'
);

-- line #8233
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUROXIME 125 (IP HC.)',
	'Cefuroxime',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUROXIME 125 (IP HC.)'
);

-- line #8234
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUROXIME 250 (IP HC.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUROXIME 250 (IP HC.)'
);

-- line #8235
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUROX 125 (Mapra)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg(SOD)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUROX 125 (Mapra)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUROX 250 (Mapra)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg(SOD)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUROX 250 (Mapra)'
);

-- line #8236
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUROX 500 (Mapra)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg(SOD)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUROX 500 (Mapra)'
);

-- line #8237
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FURY 250 (Malody Hc.)',
	'Cefuroxime',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FURY 250 (Malody Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FURY 500 (Malody Hc.)',
	'Cefuroxime',
	'DT',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FURY 500 (Malody Hc.)'
);

-- line #8238
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FURY 750 (Malody Hc.)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FURY 750 (Malody Hc.)'
);

-- line #8239
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUTUM 250 (Gcm Lab.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUTUM 250 (Gcm Lab.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUTUM 500 (Gcm Lab.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUTUM 500 (Gcm Lab.)'
);

-- line #8240
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GERICEF 250 (GERRYSUN PH.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GERICEF 250 (GERRYSUN PH.)'
);

-- line #8241
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRAM 250 (Idol Bio.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRAM 250 (Idol Bio.)'
);

-- line #8242
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRAM 500 (Idol Bio.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRAM 500 (Idol Bio.)'
);

-- line #8243
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GYNOX 750 (Kepsee)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GYNOX 750 (Kepsee)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GYNOX 1500 (Kepsee)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('1500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GYNOX 1500 (Kepsee)'
);

-- line #8244
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYCEFT 500 (AXIS LIFE)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYCEFT 500 (AXIS LIFE)'
);

-- line #8245
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYTOS 500 (STARTOS)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYTOS 500 (STARTOS)'
);

-- line #8246
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IFLACEF 125 (Candor Bio.)',
	'Cefuroxime',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IFLACEF 125 (Candor Bio.)'
);

-- line #8247
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IFLACEF 500 (Candor Bio.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IFLACEF 500 (Candor Bio.)'
);

-- line #8248
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDIACEF 125 (Skymax)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg(AXETIL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDIACEF 125 (Skymax)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDIACEF 250 (Skymax)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg(AXETIL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDIACEF 250 (Skymax)'
);

-- line #8249
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDIACEF 500 (Skymax)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg(AXETIL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDIACEF 500 (Skymax)'
);

-- line #8250
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTRACEF 125 (Intra Lab)',
	'Cefuroxime',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTRACEF 125 (Intra Lab)'
);

-- line #8251
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTRACEF 750 (Intra Lab)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTRACEF 750 (Intra Lab)'
);

-- line #8252
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTRACEF 250 (Intra Lab)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTRACEF 250 (Intra Lab)'
);

-- line #8253
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTRACEF 500 (Intra Lab)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTRACEF 500 (Intra Lab)'
);

-- line #8254
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.5G', u'strength_2': u'', u'substance': u'Cefuroxime', u'always_empty': u'', u'form': u'INJ', u'brand': u'IVIROXIME', u'strength_3': u'', u'company': u'VHB', u'unit': u''}

-- line #8255
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IVIROXIME 250 (Vhb)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IVIROXIME 250 (Vhb)'
);

-- line #8256
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IVIROXIME 750 (VHB)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IVIROXIME 750 (VHB)'
);

-- line #8257
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JOSPAR 1500 (D.R.John''S)',
	'Cefuroxime',
	'VIAL',
	gm.nullify_empty_string('1500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JOSPAR 1500 (D.R.John''S)'
);

-- line #8258
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JOSPAR 250 (D.R.John''S)',
	'Cefuroxime',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JOSPAR 250 (D.R.John''S)'
);

-- line #8259
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JOSPAR 750 (D.R.John''S)',
	'Cefuroxime',
	'VIAL',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JOSPAR 750 (D.R.John''S)'
);

-- line #8260
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000', u'strength_2': u'', u'substance': u'Cefuroxime', u'always_empty': u'', u'form': u'', u'brand': u'JOXCY', u'strength_3': u'', u'company': u"D.R.John''S", u'unit': u'mg'}

-- line #8261
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'750', u'strength_2': u'', u'substance': u'Cefuroxime', u'always_empty': u'', u'form': u'', u'brand': u'JOXCY', u'strength_3': u'', u'company': u"D.R.John''S", u'unit': u'mg'}

-- line #8262
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JOXCY 1500 (D.R.John''S)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('1500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JOXCY 1500 (D.R.John''S)'
);

-- line #8263
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JOXCY 250 (D.R.John''S)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JOXCY 250 (D.R.John''S)'
);

-- line #8264
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JOXCY 750 (D.R.John''S)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JOXCY 750 (D.R.John''S)'
);

-- line #8265
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JOXCY 250 (D.R.John''S)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JOXCY 250 (D.R.John''S)'
);

-- line #8266
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JOXCY 500 (D.R.John''S)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JOXCY 500 (D.R.John''S)'
);

-- line #8267
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KAXITEL 250 (Admac (CADMA))',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KAXITEL 250 (Admac (CADMA))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KAXITEL 500 (Admac (CADMA))',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KAXITEL 500 (Admac (CADMA))'
);

-- line #8268
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFLOX 125 (TWILIGHT LIT.)',
	'Cefuroxime',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFLOX 125 (TWILIGHT LIT.)'
);

-- line #8269
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFOX 250 (TWILIGHT LIT.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFOX 250 (TWILIGHT LIT.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFOX 750 (TWILIGHT LIT.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFOX 750 (TWILIGHT LIT.)'
);

-- line #8270
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFSTAR 125 (Wockhardt)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFSTAR 125 (Wockhardt)'
);

-- line #8271
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFSTAR 250 (Wockhardt)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFSTAR 250 (Wockhardt)'
);

-- line #8272
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFSTAR 500 (Wockhardt)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFSTAR 500 (Wockhardt)'
);

-- line #8273
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFSTAR 750 (Wockhardt)',
	'Cefuroxime',
	'V',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFSTAR 750 (Wockhardt)'
);

-- line #8274
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFUEL 250 (Dallas Ph.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFUEL 250 (Dallas Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFUEL 500 (Dallas Ph.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFUEL 500 (Dallas Ph.)'
);

-- line #8275
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.5G', u'strength_2': u'', u'substance': u'Cefuroxime', u'always_empty': u'', u'form': u'V', u'brand': u'KEROXIME', u'strength_3': u'', u'company': u'Eli Lilly', u'unit': u''}

-- line #8276
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEROXIME 750 (Eli Lilly)',
	'Cefuroxime',
	'V',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEROXIME 750 (Eli Lilly)'
);

-- line #8277
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEXTUM 125 (Cadex Lab)',
	'Cefuroxime',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEXTUM 125 (Cadex Lab)'
);

-- line #8278
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEXTUM 250 (Cadex Lab)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEXTUM 250 (Cadex Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEXTUM 500 (Cadex Lab)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEXTUM 500 (Cadex Lab)'
);

-- line #8279
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEXTUM 750 (Cadex Lab)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEXTUM 750 (Cadex Lab)'
);

-- line #8280
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAZOCIN 125 (ALLENGE)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAZOCIN 125 (ALLENGE)'
);

-- line #8281
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAZOCIN 250 (ALLENGE)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAZOCIN 250 (ALLENGE)'
);

-- line #8282
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAZOCIN 500 (ALLENGE)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAZOCIN 500 (ALLENGE)'
);

-- line #8283
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LECEF 750 (Cosmas Ph.)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LECEF 750 (Cosmas Ph.)'
);

-- line #8284
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LECEF 250 (Cosmas Ph.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LECEF 250 (Cosmas Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LECEF 500 (Cosmas Ph.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LECEF 500 (Cosmas Ph.)'
);

-- line #8285
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEXTUM 250 (Biocin Hc.)',
	'Cefuroxime',
	'TAB/ INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEXTUM 250 (Biocin Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEXTUM 750 (Biocin Hc.)',
	'Cefuroxime',
	'TAB/ INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEXTUM 750 (Biocin Hc.)'
);

-- line #8286
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEXTUM 250 (Lexus)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEXTUM 250 (Lexus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEXTUM 500 (Lexus)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEXTUM 500 (Lexus)'
);

-- line #8287
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIFCEF 250 (Hope Life)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIFCEF 250 (Hope Life)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIFCEF 500 (Hope Life)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIFCEF 500 (Hope Life)'
);

-- line #8288
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'L-TUM 250 (Lexus)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'L-TUM 250 (Lexus)'
);

-- line #8289
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'L-TUM 500 (Lexus)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'L-TUM 500 (Lexus)'
);

-- line #8290
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAGNACEF 250 (Magnus Bio.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAGNACEF 250 (Magnus Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAGNACEF 500 (Magnus Bio.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAGNACEF 500 (Magnus Bio.)'
);

-- line #8291
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAGNA 250 (VENSAT)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAGNA 250 (VENSAT)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAGNA 500 (VENSAT)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAGNA 500 (VENSAT)'
);

-- line #8292
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOXIME 250 (Maan)',
	'CefuroximE',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOXIME 250 (Maan)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOXIME 500 (Maan)',
	'CefuroximE',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOXIME 500 (Maan)'
);

-- line #8293
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOXIME 125 (Maan)',
	'CefuroximE',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOXIME 125 (Maan)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOXIME 250 (Maan)',
	'CefuroximE',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOXIME 250 (Maan)'
);

-- line #8294
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOXIME 500 (Maan)',
	'CefuroximE',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOXIME 500 (Maan)'
);

-- line #8295
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAXIM 250 (Meridian)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAXIM 250 (Meridian)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAXIM 500 (Meridian)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAXIM 500 (Meridian)'
);

-- line #8296
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDOXIL 250 (Medopharm)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg(AXETIL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDOXIL 250 (Medopharm)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDOXIL 500 (Medopharm)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg(AXETIL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDOXIL 500 (Medopharm)'
);

-- line #8297
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILCEF 750 (Comed)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILCEF 750 (Comed)'
);

-- line #8298
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.5G', u'strength_2': u'', u'substance': u'Cefuroxime', u'always_empty': u'', u'form': u'INJ', u'brand': u'MILCEF', u'strength_3': u'', u'company': u'Comed Chem.', u'unit': u''}

-- line #8299
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILCEF 750 (Comed Chem.)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILCEF 750 (Comed Chem.)'
);

-- line #8300
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILCEF 125 (Comed)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILCEF 125 (Comed)'
);

-- line #8301
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILCEF 250 (Comed)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg(AXETIL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILCEF 250 (Comed)'
);

-- line #8302
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILCEF 500 (Comed)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg(AXETIL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILCEF 500 (Comed)'
);

-- line #8303
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MORCEF 125 (Shinto Org.)',
	'Cefuroxime',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MORCEF 125 (Shinto Org.)'
);

-- line #8304
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MORCEF 750 (Shinto Org.)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MORCEF 750 (Shinto Org.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MORCEF 1500 (Shinto Org.)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('1500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MORCEF 1500 (Shinto Org.)'
);

-- line #8305
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MORCEF 250 (Shinto Org.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MORCEF 250 (Shinto Org.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MORCEF 500 (Shinto Org.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MORCEF 500 (Shinto Org.)'
);

-- line #8306
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1GM', u'strength_2': u'', u'substance': u'Cefuroxime', u'always_empty': u'', u'form': u'INJ', u'brand': u'MULTICEF', u'strength_3': u'', u'company': u'Redson', u'unit': u''}

-- line #8307
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MULTICEF 250 (Redson)',
	'Cefuroxime',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MULTICEF 250 (Redson)'
);

-- line #8308
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MULTICEF 750 (Redson)',
	'Cefuroxime',
	'V',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MULTICEF 750 (Redson)'
);

-- line #8309
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEROXIM 750 (Nitin Ph.)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEROXIM 750 (Nitin Ph.)'
);

-- line #8310
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEROXIM 250 (Nitin Ph.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEROXIM 250 (Nitin Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEROXIM 500 (Nitin Ph.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEROXIM 500 (Nitin Ph.)'
);

-- line #8311
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEXTRIM 125 (Nexus)',
	'Cefuroxime',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEXTRIM 125 (Nexus)'
);

-- line #8312
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEXTRIM 250 (Nexus)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEXTRIM 250 (Nexus)'
);

-- line #8313
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEXTRIM 750 (Nexus)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEXTRIM 750 (Nexus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEXTRIM 1500 (Nexus)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('1500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEXTRIM 1500 (Nexus)'
);

-- line #8314
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEXTRIM 125 (Nexus)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEXTRIM 125 (Nexus)'
);

-- line #8315
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEXTRIM 250 (Nexus)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEXTRIM 250 (Nexus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEXTRIM 500 (Nexus)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEXTRIM 500 (Nexus)'
);

-- line #8316
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIFOXIME 125 (Sanify)',
	'Cefuroxime',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIFOXIME 125 (Sanify)'
);

-- line #8317
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIFOXIME 750 (Sanify)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIFOXIME 750 (Sanify)'
);

-- line #8318
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIFOXIME 250 (Sanify)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIFOXIME 250 (Sanify)'
);

-- line #8319
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIFOXIME 500 (Sanify)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIFOXIME 500 (Sanify)'
);

-- line #8320
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVAROXIM 125 (Radicura)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVAROXIM 125 (Radicura)'
);

-- line #8321
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVAROXIM 250 (Radicura)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVAROXIM 250 (Radicura)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVAROXIM 500 (Radicura)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVAROXIM 500 (Radicura)'
);

-- line #8322
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.5G', u'strength_2': u'', u'substance': u'Cefuroxime', u'always_empty': u'', u'form': u'VIAL', u'brand': u'NOVAROXIM', u'strength_3': u'', u'company': u'Radicura', u'unit': u''}

-- line #8323
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVAROXIM 250 (Radicura)',
	'Cefuroxime',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVAROXIM 250 (Radicura)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVAROXIM 500 (Radicura)',
	'Cefuroxime',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVAROXIM 500 (Radicura)'
);

-- line #8324
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCEF 750 (Guj.Terce)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCEF 750 (Guj.Terce)'
);

-- line #8325
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'O-CEF 1500 (Oscar Rem.)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('1500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'O-CEF 1500 (Oscar Rem.)'
);

-- line #8326
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'O-CEF 250 (Oscar Rem.)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'O-CEF 250 (Oscar Rem.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'O-CEF 500 (Oscar Rem.)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'O-CEF 500 (Oscar Rem.)'
);

-- line #8327
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCEF 125 (GUJ. TE.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'250'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCEF 125 (GUJ. TE.)'
);

-- line #8328
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCEF 500 (Guj.Terce)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCEF 500 (Guj.Terce)'
);

-- line #8329
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLTUM 125 (Olcare)',
	'Cefuroxime',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLTUM 125 (Olcare)'
);

-- line #8330
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLTUM 250 (Olcare)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLTUM 250 (Olcare)'
);

-- line #8331
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLTUM 500 (Olcare)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLTUM 500 (Olcare)'
);

-- line #8332
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMNIXIM 250 (CIPLA)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMNIXIM 250 (CIPLA)'
);

-- line #8333
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMNIXIM 500 (CIPLA)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMNIXIM 500 (CIPLA)'
);

-- line #8334
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORATIL 125 (Macleods)',
	'Cefuroxime',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORATIL 125 (Macleods)'
);

-- line #8335
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.5G', u'strength_2': u'', u'substance': u'Cefuroxime', u'always_empty': u'', u'form': u'INJ', u'brand': u'ORATIL', u'strength_3': u'', u'company': u'Macleods', u'unit': u''}

-- line #8336
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORATIL 250 (Macleods)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORATIL 250 (Macleods)'
);

-- line #8337
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORATIL 750 (Macleods)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORATIL 750 (Macleods)'
);

-- line #8338
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORATIL 250 (Macleods)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORATIL 250 (Macleods)'
);

-- line #8339
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORATIL 500 (Macleods)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORATIL 500 (Macleods)'
);

-- line #8340
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORAXIM 50 (LARK)',
	'Cefuroxime',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORAXIM 50 (LARK)'
);

-- line #8341
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORAXIM 100 (LARK)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORAXIM 100 (LARK)'
);

-- line #8342
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORAXIM 200 (LARK)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORAXIM 200 (LARK)'
);

-- line #8343
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OTOXIL 250 (Tnt Life)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OTOXIL 250 (Tnt Life)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OTOXIL 500 (Tnt Life)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OTOXIL 500 (Tnt Life)'
);

-- line #8344
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PDCEF 250 (Pharma Drugs)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PDCEF 250 (Pharma Drugs)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PDCEF 500 (Pharma Drugs)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PDCEF 500 (Pharma Drugs)'
);

-- line #8345
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POLOCEF 250 (RASS HC.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POLOCEF 250 (RASS HC.)'
);

-- line #8346
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PULMOCEF 1500 (Brown & B.)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('1500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PULMOCEF 1500 (Brown & B.)'
);

-- line #8347
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PULMOCEF 750 (Brown & B.)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PULMOCEF 750 (Brown & B.)'
);

-- line #8348
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PULMOCEF 125 (Brown & B.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PULMOCEF 125 (Brown & B.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PULMOCEF 250 (Brown & B.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PULMOCEF 250 (Brown & B.)'
);

-- line #8349
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PULMOCEF 500 (Brown & B.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PULMOCEF 500 (Brown & B.)'
);

-- line #8350
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PULMOFIN 750 (Finesse Ph.)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PULMOFIN 750 (Finesse Ph.)'
);

-- line #8351
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELICEF 125 (TRIGENESIS)',
	'Cefuroxime',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELICEF 125 (TRIGENESIS)'
);

-- line #8352
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELICEF 250 (TRIGENESIS)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELICEF 250 (TRIGENESIS)'
);

-- line #8353
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELICEF 500 (TRIGENESIS)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELICEF 500 (TRIGENESIS)'
);

-- line #8354
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.5G', u'strength_2': u'', u'substance': u'Cefuroxime', u'always_empty': u'', u'form': u'INJ', u'brand': u'RESTUM', u'strength_3': u'', u'company': u'Galpha', u'unit': u''}

-- line #8355
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESTUM 250 (Galpha)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESTUM 250 (Galpha)'
);

-- line #8356
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESTUM 500 (Galpha)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESTUM 500 (Galpha)'
);

-- line #8357
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESTUM 750 (Galpha)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESTUM 750 (Galpha)'
);

-- line #8358
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESTUM 250 (Galpha)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESTUM 250 (Galpha)'
);

-- line #8359
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESTUM 500 (Galpha)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESTUM 500 (Galpha)'
);

-- line #8360
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REZICEF 250 (Zenith Hc.)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REZICEF 250 (Zenith Hc.)'
);

-- line #8361
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RHOFUTUM 250 (Rhombus)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RHOFUTUM 250 (Rhombus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RHOFUTUM 500 (Rhombus)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RHOFUTUM 500 (Rhombus)'
);

-- line #8362
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIME 750 (ROSE LABS)',
	'Cefuroxime',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIME 750 (ROSE LABS)'
);

-- line #8363
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIME 250 (ROSE LABS)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIME 250 (ROSE LABS)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIME 500 (ROSE LABS)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIME 500 (ROSE LABS)'
);

-- line #8364
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RINSTEAD 125 (Medicamen)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RINSTEAD 125 (Medicamen)'
);

-- line #8365
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RINSTEAD 250 (Medicamen)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RINSTEAD 250 (Medicamen)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RINSTEAD 500 (Medicamen)',
	'Cefuroxime',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RINSTEAD 500 (Medicamen)'
);

-- line #8366
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CE-100/200 100 (EAST WEST)',
	'Celecoxib',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CE-100/200 100 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CE-100/200 200 (EAST WEST)',
	'Celecoxib',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CE-100/200 200 (EAST WEST)'
);

-- line #8367
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELACT 100 (Sun)',
	'CELECOXIB',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'200'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELACT 100 (Sun)'
);

-- line #8368
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELACT 100 (Sun)',
	'Celecoxib',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELACT 100 (Sun)'
);

-- line #8369
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELACT 200 (Sun)',
	'Celecoxib',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELACT 200 (Sun)'
);

-- line #8370
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELCIB 100 (Khandelwal)',
	'Celecoxib',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELCIB 100 (Khandelwal)'
);

-- line #8371
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELCIB 200 (Khandelwal)',
	'Celecoxib',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELCIB 200 (Khandelwal)'
);

-- line #8372
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELCOX 100 (Lupin)',
	'Celecoxib',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELCOX 100 (Lupin)'
);

-- line #8373
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELCOX 200 (Lupin)',
	'Celecoxib',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELCOX 200 (Lupin)'
);

-- line #8374
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELECAP 100 (Centaur)',
	'Celecoxib',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELECAP 100 (Centaur)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELECAP 200 (Centaur)',
	'Celecoxib',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELECAP 200 (Centaur)'
);

-- line #8375
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELEDOL 100 (Ipca)',
	'Celecoxib',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELEDOL 100 (Ipca)'
);

-- line #8376
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELEDOL 200 (Ipca)',
	'Celecoxib',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELEDOL 200 (Ipca)'
);

-- line #8377
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELEMAX 200 (Cadila Ph.)',
	'CELECOXIB',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELEMAX 200 (Cadila Ph.)'
);

-- line #8378
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELETOP 100 (Nicholas)',
	'Celecoxib',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELETOP 100 (Nicholas)'
);

-- line #8379
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELETOP 200 (Nicholas)',
	'Celecoxib',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELETOP 200 (Nicholas)'
);

-- line #8380
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELFAST 100 (Indchemie)',
	'Celecoxib',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELFAST 100 (Indchemie)'
);

-- line #8381
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELFAST 200 (Indchemie)',
	'Celecoxib',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELFAST 200 (Indchemie)'
);

-- line #8382
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELIB 100 (Unichem)',
	'Celecoxib',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELIB 100 (Unichem)'
);

-- line #8383
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELIB 200 (Unichem)',
	'Celecoxib',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELIB 200 (Unichem)'
);

-- line #8384
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELIRA 100 (Shreya)',
	'Celecoxib',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELIRA 100 (Shreya)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELIRA 200 (Shreya)',
	'Celecoxib',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELIRA 200 (Shreya)'
);

-- line #8385
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIB 100 (Kee Ph.)',
	'Celecoxib',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIB 100 (Kee Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIB 200 (Kee Ph.)',
	'Celecoxib',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIB 200 (Kee Ph.)'
);

-- line #8386
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COBIX 100 (Cipla)',
	'Celecoxib',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COBIX 100 (Cipla)'
);

-- line #8387
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COBIX 200 (Cipla)',
	'Celecoxib',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COBIX 200 (Cipla)'
);

-- line #8388
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COLCIBRA 100 (Croslands)',
	'Celecoxib',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COLCIBRA 100 (Croslands)'
);

-- line #8389
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COLCIBRA 200 (Croslands)',
	'Celecoxib',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COLCIBRA 200 (Croslands)'
);

-- line #8390
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COXIB 100 (Brown & B.)',
	'Celecoxib',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COXIB 100 (Brown & B.)'
);

-- line #8391
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COXIB 200 (Brown & B.)',
	'Celecoxib',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COXIB 200 (Brown & B.)'
);

-- line #8392
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYCELE 200 (Dynamic)',
	'Celecoxib',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYCELE 200 (Dynamic)'
);

-- line #8393
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELOXIB 100 (Emcure)',
	'Celecoxib',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELOXIB 100 (Emcure)'
);

-- line #8394
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ICEL 100 (Zydus Cadila)',
	'Celecoxib',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ICEL 100 (Zydus Cadila)'
);

-- line #8395
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ICEL 200 (Zydus Cadila)',
	'Celecoxib',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ICEL 200 (Zydus Cadila)'
);

-- line #8396
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'J FLEX 100 (VERITAZ)',
	'Celecoxib',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'J FLEX 100 (VERITAZ)'
);

-- line #8397
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'J FLEX 200 (VERITAZ)',
	'Celecoxib',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'J FLEX 200 (VERITAZ)'
);

-- line #8398
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORTHOCEL 100 (Biochem)',
	'Celecoxib',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORTHOCEL 100 (Biochem)'
);

-- line #8399
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORTHOCEL 200 (Biochem)',
	'Celecoxib',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORTHOCEL 200 (Biochem)'
);

-- line #8400
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REVIBRA 100 (Dr.Reddy''S)',
	'Celecoxib',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REVIBRA 100 (Dr.Reddy''S)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REVIBRA 200 (Dr.Reddy''S)',
	'Celecoxib',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REVIBRA 200 (Dr.Reddy''S)'
);

-- line #8401
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELIPRES 100 (Solus)',
	'Celiprolol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELIPRES 100 (Solus)'
);

-- line #8402
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELIPRES 200 (Solus)',
	'Celiprolol',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELIPRES 200 (Solus)'
);

-- line #8403
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CENTRON 30 (Torrent)',
	'Centchroman',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CENTRON 30 (Torrent)'
);

-- line #8404
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANABLOK 5 (Themis Med.)',
	'CENTIBUCRIDINE HCL.',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANABLOK 5 (Themis Med.)'
);

-- line #8405
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACECEP 250 (Integrated)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACECEP 250 (Integrated)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACECEP 500 (Integrated)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACECEP 500 (Integrated)'
);

-- line #8406
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACECEP 125 (Integrated)',
	'Cephalexin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACECEP 125 (Integrated)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACECEP 250 (Integrated)',
	'Cephalexin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACECEP 250 (Integrated)'
);

-- line #8407
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACELAXIN 250 (ACE LAB.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACELAXIN 250 (ACE LAB.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACELAXIN 500 (ACE LAB.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACELAXIN 500 (ACE LAB.)'
);

-- line #8408
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALCEPHIN 250 (Alembic)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALCEPHIN 250 (Alembic)'
);

-- line #8409
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALCEPHIN 500 (Alembic)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALCEPHIN 500 (Alembic)'
);

-- line #8410
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALCEPHIN 125 (Alembic)',
	'Cephalexin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALCEPHIN 125 (Alembic)'
);

-- line #8411
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALCEPHIN 125 (Alembic)',
	'Cephalexin',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALCEPHIN 125 (Alembic)'
);

-- line #8412
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALEXIN 250 (Dabur Ph.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALEXIN 250 (Dabur Ph.)'
);

-- line #8413
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALEXIN 500 (Dabur Ph.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALEXIN 500 (Dabur Ph.)'
);

-- line #8414
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALEXIN 125 (Dabur Ph.)',
	'Cephalexin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALEXIN 125 (Dabur Ph.)'
);

-- line #8415
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALEXIN 125 (Dabur Ph.)',
	'Cephalexin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALEXIN 125 (Dabur Ph.)'
);

-- line #8416
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANPHEXIN 250 (ACTO)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANPHEXIN 250 (ACTO)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANPHEXIN 500 (ACTO)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANPHEXIN 500 (ACTO)'
);

-- line #8417
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANPHEXIN 125 (ACTO)',
	'Cephalexin',
	'DT TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANPHEXIN 125 (ACTO)'
);

-- line #8418
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APKEF 250 (Ajanta Ph.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APKEF 250 (Ajanta Ph.)'
);

-- line #8419
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APKEF 500 (Ajanta Ph.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APKEF 500 (Ajanta Ph.)'
);

-- line #8420
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APKEF 125 (Ajanta Ph.)',
	'Cephalexin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APKEF 125 (Ajanta Ph.)'
);

-- line #8421
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APKEF 125 (Ajanta Ph.)',
	'Cephalexin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APKEF 125 (Ajanta Ph.)'
);

-- line #8422
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARILEX 250 (ANAND HC.)',
	'Cephalexin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARILEX 250 (ANAND HC.)'
);

-- line #8423
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXIN 375 (ALLENGE)',
	'Cephalexin',
	'LA TAB',
	gm.nullify_empty_string('375')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXIN 375 (ALLENGE)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXIN 750 (ALLENGE)',
	'Cephalexin',
	'LA TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXIN 750 (ALLENGE)'
);

-- line #8424
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACTOCEP 250 (BACTOLAC)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACTOCEP 250 (BACTOLAC)'
);

-- line #8425
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACTOCEP 500 (BACTOLAC)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACTOCEP 500 (BACTOLAC)'
);

-- line #8426
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACTOCEP 125 (BACTOLAC)',
	'Cephalexin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACTOCEP 125 (BACTOLAC)'
);

-- line #8427
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BAXEF 250 (Austere)',
	'Cephalexin',
	'D.SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BAXEF 250 (Austere)'
);

-- line #8428
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BECTACEF 500 (Chemo Bio.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BECTACEF 500 (Chemo Bio.)'
);

-- line #8429
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BECTACEF-D 250 (Chemo Bio.)',
	'Cephalexin',
	'SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BECTACEF-D 250 (Chemo Bio.)'
);

-- line #8430
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BECTACEF 125 (Chemo Bio.)',
	'Cephalexin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BECTACEF 125 (Chemo Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BECTACEF 250 (Chemo Bio.)',
	'Cephalexin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BECTACEF 250 (Chemo Bio.)'
);

-- line #8431
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENICEF 250 (Baroque)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENICEF 250 (Baroque)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENICEF 500 (Baroque)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENICEF 500 (Baroque)'
);

-- line #8432
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENICEF 375 (Baroque)',
	'Cephalexin',
	'CD TAB',
	gm.nullify_empty_string('375')::numeric,
	'mg(M.R.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENICEF 375 (Baroque)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENICEF 750 (Baroque)',
	'Cephalexin',
	'CD TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg(M.R.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENICEF 750 (Baroque)'
);

-- line #8433
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENICEF 125 (Baroque)',
	'Cephalexin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENICEF 125 (Baroque)'
);

-- line #8434
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENICEF 125 (Baroque)',
	'Cephalexin',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENICEF 125 (Baroque)'
);

-- line #8435
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETASPORE 250 (Aristo)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETASPORE 250 (Aristo)'
);

-- line #8436
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETASPORE 500 (Aristo)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETASPORE 500 (Aristo)'
);

-- line #8437
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETASPORE 125 (Aristo)',
	'Cephalexin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETASPORE 125 (Aristo)'
);

-- line #8438
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOLEX 500 (Cubit Hc.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOLEX 500 (Cubit Hc.)'
);

-- line #8439
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOLEX 250 (Cubit Hc.)',
	'Cephalexin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOLEX 250 (Cubit Hc.)'
);

-- line #8440
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLUCEF 250 (Blue Cross)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLUCEF 250 (Blue Cross)'
);

-- line #8441
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLUCEF 500 (Blue Cross)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLUCEF 500 (Blue Cross)'
);

-- line #8442
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLUCEF 125 (Blue Cross)',
	'Cephalexin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLUCEF 125 (Blue Cross)'
);

-- line #8443
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLUCEF 250 (Blue Cross)',
	'Cephalexin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLUCEF 250 (Blue Cross)'
);

-- line #8444
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLUCEF-P 125 (Blue Cross)',
	'Cephalexin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLUCEF-P 125 (Blue Cross)'
);

-- line #8445
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAREFEX 125 (Olcare)',
	'Cephalexin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAREFEX 125 (Olcare)'
);

-- line #8446
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAREFEX 250 (Olcare)',
	'Cephalexin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAREFEX 250 (Olcare)'
);

-- line #8447
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAREFEX 500 (Olcare)',
	'Cephalexin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAREFEX 500 (Olcare)'
);

-- line #8448
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CD 500 (Cadex Lab)',
	'Cephalexin',
	'CL CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CD 500 (Cadex Lab)'
);

-- line #8449
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CD CL 250 (Cadex Lab)',
	'Cephalexin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CD CL 250 (Cadex Lab)'
);

-- line #8450
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CD 750 (Cadex Lab)',
	'Cephalexin',
	'CL TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CD 750 (Cadex Lab)'
);

-- line #8451
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CD-PHEX 250 (Cyper Ph.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CD-PHEX 250 (Cyper Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CD-PHEX 500 (Cyper Ph.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CD-PHEX 500 (Cyper Ph.)'
);

-- line #8452
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFACIN 500 (Cure Quick)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFACIN 500 (Cure Quick)'
);

-- line #8453
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFACT 250 (Indu D.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFACT 250 (Indu D.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFACT 500 (Indu D.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFACT 500 (Indu D.)'
);

-- line #8454
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFACT 125 (Indu D.)',
	'Cephalexin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFACT 125 (Indu D.)'
);

-- line #8455
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFACT KID/KID 125 (Indu D.)',
	'Cephalexin',
	'F. TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFACT KID/KID 125 (Indu D.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFACT KID/KID 250 (Indu D.)',
	'Cephalexin',
	'F. TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFACT KID/KID 250 (Indu D.)'
);

-- line #8456
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFACURE 250 (Orchid Hc.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFACURE 250 (Orchid Hc.)'
);

-- line #8457
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFACURE 500 (Orchid Hc.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFACURE 500 (Orchid Hc.)'
);

-- line #8458
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFACURE 125 (Orchid Hc.)',
	'Cephalexin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFACURE 125 (Orchid Hc.)'
);

-- line #8459
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFACURE 250 (Orchid Hc.)',
	'Cephalexin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFACURE 250 (Orchid Hc.)'
);

-- line #8460
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFADYL 250 (Unique)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFADYL 250 (Unique)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFADYL 500 (Unique)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFADYL 500 (Unique)'
);

-- line #8461
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFALEX 250 (P C INDIA)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFALEX 250 (P C INDIA)'
);

-- line #8462
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFALEX 500 (P C INDIA)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFALEX 500 (P C INDIA)'
);

-- line #8463
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFALEX PAED 100 (P C INDIA)',
	'Cephalexin',
	'DPS',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFALEX PAED 100 (P C INDIA)'
);

-- line #8464
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFALEX 125 (P C INDIA)',
	'Cephalexin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFALEX 125 (P C INDIA)'
);

-- line #8465
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFALEX 250 (P C INDIA)',
	'Cephalexin',
	'SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFALEX 250 (P C INDIA)'
);

-- line #8466
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFALIN 250 (Euphoric)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFALIN 250 (Euphoric)'
);

-- line #8467
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFALIN 500 (Euphoric)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFALIN 500 (Euphoric)'
);

-- line #8468
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFALIN 125 (Euphoric)',
	'Cephalexin',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFALIN 125 (Euphoric)'
);

-- line #8469
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAMAX 250 (MAX)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAMAX 250 (MAX)'
);

-- line #8470
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAMAX 500 (MAX)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAMAX 500 (MAX)'
);

-- line #8471
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAMAX 100 (MAX)',
	'Cephalexin',
	'DPS',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAMAX 100 (MAX)'
);

-- line #8472
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAMAX 125 (MAX)',
	'Cephalexin',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAMAX 125 (MAX)'
);

-- line #8473
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAMAX 125 (MAX)',
	'Cephalexin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAMAX 125 (MAX)'
);

-- line #8474
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFASTAR 500 (Mankind)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFASTAR 500 (Mankind)'
);

-- line #8475
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFASTAR 100 (Mankind)',
	'Cephalexin',
	'DPS',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFASTAR 100 (Mankind)'
);

-- line #8476
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFASTAR 250 (Mankind)',
	'Cephalexin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFASTAR 250 (Mankind)'
);

-- line #8477
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAST 500 (ASTER PH.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAST 500 (ASTER PH.)'
);

-- line #8478
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAST 250 (ASTER PH.)',
	'Cephalexin',
	'DT TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAST 250 (ASTER PH.)'
);

-- line #8479
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAX 250 (Inga)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAX 250 (Inga)'
);

-- line #8480
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAX 500 (Inga)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAX 500 (Inga)'
);

-- line #8481
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAX 250 (M.K. Ph.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAX 250 (M.K. Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFAX 500 (M.K. Ph.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFAX 500 (M.K. Ph.)'
);

-- line #8482
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFBACT 250 (Cipla)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFBACT 250 (Cipla)'
);

-- line #8483
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFBACT 500 (Cipla)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFBACT 500 (Cipla)'
);

-- line #8484
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFCIDAL 125 (AKUM(PLETHICO))',
	'Cephalexin',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFCIDAL 125 (AKUM(PLETHICO))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFCIDAL 250 (AKUM(PLETHICO))',
	'Cephalexin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFCIDAL 250 (AKUM(PLETHICO))'
);

-- line #8485
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFEL 500 (Finecure)',
	'CEPHALEXIN',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFEL 500 (Finecure)'
);

-- line #8486
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFEL-D 125 (Finecure)',
	'CEPHALEXIN',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFEL-D 125 (Finecure)'
);

-- line #8487
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFEL 125 (Finecure)',
	'CEPHALEXIN',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFEL 125 (Finecure)'
);

-- line #8488
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFEL 250 (Finecure)',
	'CEPHALEXIN',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFEL 250 (Finecure)'
);

-- line #8489
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFF 250 (Lupin)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFF 250 (Lupin)'
);

-- line #8490
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFF 500 (Lupin)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFF 500 (Lupin)'
);

-- line #8491
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFF 250 (Lupin)',
	'Cephalexin',
	'CF TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFF 250 (Lupin)'
);

-- line #8492
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFF 500 (Lupin)',
	'Cephalexin',
	'CF TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFF 500 (Lupin)'
);

-- line #8493
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFF 100 (Lupin)',
	'Cephalexin',
	'DPS',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFF 100 (Lupin)'
);

-- line #8494
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFF 250 (Lupin)',
	'Cephalexin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFF 250 (Lupin)'
);

-- line #8495
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFF 750 (Lupin)',
	'Cephalexin',
	'ER TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFF 750 (Lupin)'
);

-- line #8496
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFF 125 (Lupin)',
	'Cephalexin',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFF 125 (Lupin)'
);

-- line #8497
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFF PREMIX-F 250 (Lupin)',
	'Cephalexin',
	'SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFF PREMIX-F 250 (Lupin)'
);

-- line #8498
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFF PREMIX 125 (Lupin)',
	'Cephalexin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFF PREMIX 125 (Lupin)'
);

-- line #8499
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFF 125 (Lupin)',
	'Cephalexin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFF 125 (Lupin)'
);

-- line #8500
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFF 250 (Lupin)',
	'Cephalexin',
	'SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFF 250 (Lupin)'
);

-- line #8501
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFIROSE 250 (CHEMO HC.)',
	'Cephalexin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFIROSE 250 (CHEMO HC.)'
);

-- line #8502
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFIROSE 500 (CHEMO HC.)',
	'Cephalexin',
	'TAB/CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFIROSE 500 (CHEMO HC.)'
);

-- line #8503
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFMIX 250 (Cadila Ph.)',
	'CEPHALEXIN',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFMIX 250 (Cadila Ph.)'
);

-- line #8504
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFMIX 500 (Cadila Ph.)',
	'CEPHALEXIN',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFMIX 500 (Cadila Ph.)'
);

-- line #8505
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFMIX 125 (Cadila Ph.)',
	'CEPHALEXIN',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFMIX 125 (Cadila Ph.)'
);

-- line #8506
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFMIX 125 (Cadila Ph.)',
	'CEPHALEXIN',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFMIX 125 (Cadila Ph.)'
);

-- line #8507
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFMIX 250 (Cadila Ph.)',
	'CEPHALEXIN',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFMIX 250 (Cadila Ph.)'
);

-- line #8508
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFRIK 250 (Lanark)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFRIK 250 (Lanark)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFRIK 500 (Lanark)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFRIK 500 (Lanark)'
);

-- line #8509
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEF-SV 500 (Sv Ph.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEF-SV 500 (Sv Ph.)'
);

-- line #8510
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTOP 250 (Ind-Swift)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTOP 250 (Ind-Swift)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTOP 500 (Ind-Swift)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTOP 500 (Ind-Swift)'
);

-- line #8511
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFTOP-D 125 (Ind-Swift)',
	'CEPHALEXIN',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFTOP-D 125 (Ind-Swift)'
);

-- line #8512
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELEXIN 125 (BACTOLAC)',
	'Cephalexin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELEXIN 125 (BACTOLAC)'
);

-- line #8513
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEN KID 125 (Indica)',
	'Cephalexin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEN KID 125 (Indica)'
);

-- line #8514
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEN 500 (Indica)',
	'Cephalexin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEN 500 (Indica)'
);

-- line #8515
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPAHTIC 125 (Relish)',
	'Cephalexin',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPAHTIC 125 (Relish)'
);

-- line #8516
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPEN 250 (TALENT LAB.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPEN 250 (TALENT LAB.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPEN 500 (TALENT LAB.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPEN 500 (TALENT LAB.)'
);

-- line #8517
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPEN 125 (TALENT LAB.)',
	'Cephalexin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPEN 125 (TALENT LAB.)'
);

-- line #8518
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPEN 250 (TALENT LAB.)',
	'Cephalexin',
	'F. D.SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPEN 250 (TALENT LAB.)'
);

-- line #8519
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPEN KID 125 (TALENT LAB.)',
	'Cephalexin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPEN KID 125 (TALENT LAB.)'
);

-- line #8520
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPHACILLIN 250 (Gsk)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPHACILLIN 250 (Gsk)'
);

-- line #8521
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPHACILLIN 500 (Gsk)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPHACILLIN 500 (Gsk)'
);

-- line #8522
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPHADEX 250 (Cipla)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPHADEX 250 (Cipla)'
);

-- line #8523
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPHADEX 500 (Cipla)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPHADEX 500 (Cipla)'
);

-- line #8524
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPHADEX 100 (Cipla)',
	'Cephalexin',
	'DPS',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPHADEX 100 (Cipla)'
);

-- line #8525
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPHADEX 125 (Cipla)',
	'Cephalexin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPHADEX 125 (Cipla)'
);

-- line #8526
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPHADEX 125 (Cipla)',
	'Cephalexin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPHADEX 125 (Cipla)'
);

-- line #8527
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPHADEX 250 (Cipla)',
	'Cephalexin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPHADEX 250 (Cipla)'
);

-- line #8528
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPHADEX 375 (Cipla)',
	'Cephalexin',
	'LA TAB',
	gm.nullify_empty_string('375')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPHADEX 375 (Cipla)'
);

-- line #8529
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPHADEX 750 (Cipla)',
	'Cephalexin',
	'LA TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPHADEX 750 (Cipla)'
);

-- line #8530
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPHADIL 250 (Solvay Ph.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPHADIL 250 (Solvay Ph.)'
);

-- line #8531
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPHADIL 500 (Solvay Ph.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPHADIL 500 (Solvay Ph.)'
);

-- line #8532
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPHADIN 250 (AMEE PH.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPHADIN 250 (AMEE PH.)'
);

-- line #8533
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPHAL 250 (Chemo D.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPHAL 250 (Chemo D.)'
);

-- line #8534
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPHAL 125 (Chemo D.)',
	'Cephalexin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPHAL 125 (Chemo D.)'
);

-- line #8535
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPHALEX 250 (Lexus)',
	'Cephalexin',
	'DT TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPHALEX 250 (Lexus)'
);

-- line #8536
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPHALKEM 250 (Alkem)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPHALKEM 250 (Alkem)'
);

-- line #8537
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPHALKEM 500 (Alkem)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPHALKEM 500 (Alkem)'
);

-- line #8538
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPHALKEM 100 (Alkem)',
	'Cephalexin',
	'DPS',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPHALKEM 100 (Alkem)'
);

-- line #8539
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPHALKEM 125 (Alkem)',
	'Cephalexin',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPHALKEM 125 (Alkem)'
);

-- line #8540
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPHARIL 250 (Reliance)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPHARIL 250 (Reliance)'
);

-- line #8541
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPHARIL 500 (Reliance)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPHARIL 500 (Reliance)'
);

-- line #8542
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPHARIL 250 (Reliance)',
	'Cephalexin',
	'DS TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPHARIL 250 (Reliance)'
);

-- line #8543
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPHARIL 125 (Reliance)',
	'Cephalexin',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPHARIL 125 (Reliance)'
);

-- line #8544
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPHARON 250 (Ronak Lab.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPHARON 250 (Ronak Lab.)'
);

-- line #8545
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPHARON 250 (Ronak Lab.)',
	'Cephalexin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPHARON 250 (Ronak Lab.)'
);

-- line #8546
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPHARON 500 (Ronak Lab.)',
	'Cephalexin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPHARON 500 (Ronak Lab.)'
);

-- line #8547
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPHASTAL 250 (Stallion)',
	'Cephalexin',
	'TAB/CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPHASTAL 250 (Stallion)'
);

-- line #8548
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPHASTAL 500 (Stallion)',
	'Cephalexin',
	'TAB/CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPHASTAL 500 (Stallion)'
);

-- line #8549
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPHATIC 250 (Relish)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPHATIC 250 (Relish)'
);

-- line #8550
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPHATIC 500 (Relish)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPHATIC 500 (Relish)'
);

-- line #8551
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPHAXIN 250 (Biochem)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPHAXIN 250 (Biochem)'
);

-- line #8552
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPHAXIN 500 (Biochem)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPHAXIN 500 (Biochem)'
);

-- line #8553
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPHAXIN 250 (Biochem)',
	'Cephalexin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPHAXIN 250 (Biochem)'
);

-- line #8554
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPHAXIN 125 (Biochem)',
	'Cephalexin',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPHAXIN 125 (Biochem)'
);

-- line #8555
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPHAXIN 125 (Biochem)',
	'Cephalexin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPHAXIN 125 (Biochem)'
);

-- line #8556
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPHLENAT 250 (Natco Ph.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPHLENAT 250 (Natco Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPHLENAT 500 (Natco Ph.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPHLENAT 500 (Natco Ph.)'
);

-- line #8557
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPHLENAT 100 (Natco Ph.)',
	'Cephalexin',
	'DPS',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPHLENAT 100 (Natco Ph.)'
);

-- line #8558
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPHLENAT -D 125 (Natco Ph.)',
	'Cephalexin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPHLENAT -D 125 (Natco Ph.)'
);

-- line #8559
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPHLENAT -D 250 (Natco Ph.)',
	'Cephalexin',
	'SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPHLENAT -D 250 (Natco Ph.)'
);

-- line #8560
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPHOLA 250 (Jarson Ph.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPHOLA 250 (Jarson Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPHOLA 500 (Jarson Ph.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPHOLA 500 (Jarson Ph.)'
);

-- line #8561
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPHSPOR 250 (Beckcem)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPHSPOR 250 (Beckcem)'
);

-- line #8562
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPHSPOR 500 (Beckcem)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPHSPOR 500 (Beckcem)'
);

-- line #8563
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPHTY 250 (Allure Rem.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPHTY 250 (Allure Rem.)'
);

-- line #8564
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPHTY 500 (Allure Rem.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPHTY 500 (Allure Rem.)'
);

-- line #8565
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPHTY 125 (Allure Rem.)',
	'Cephalexin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPHTY 125 (Allure Rem.)'
);

-- line #8566
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEXIN 250 (Ind-Swift)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEXIN 250 (Ind-Swift)'
);

-- line #8567
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEXIN 500 (Ind-Swift)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEXIN 500 (Ind-Swift)'
);

-- line #8568
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEXIN 125 (Ind-Swift)',
	'Cephalexin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEXIN 125 (Ind-Swift)'
);

-- line #8569
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEXIN 125 (Ind-Swift)',
	'Cephalexin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEXIN 125 (Ind-Swift)'
);

-- line #8570
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEXIN 250 (Ind-Swift)',
	'Cephalexin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEXIN 250 (Ind-Swift)'
);

-- line #8571
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIMEXIN 125 (Dcm Lab)',
	'Cephalexin',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIMEXIN 125 (Dcm Lab)'
);

-- line #8572
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIMEXIN 250 (Dcm Lab)',
	'Cephalexin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIMEXIN 250 (Dcm Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIMEXIN 500 (Dcm Lab)',
	'Cephalexin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIMEXIN 500 (Dcm Lab)'
);

-- line #8573
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPHLENAT 250 (Natco Ph.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPHLENAT 250 (Natco Ph.)'
);

-- line #8574
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPHLENAT 500 (Natco Ph.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPHLENAT 500 (Natco Ph.)'
);

-- line #8575
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPHLENAT 100 (Natco Ph.)',
	'Cephalexin',
	'DPS',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPHLENAT 100 (Natco Ph.)'
);

-- line #8576
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPHLENAT 125 (Natco Ph.)',
	'Cephalexin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPHLENAT 125 (Natco Ph.)'
);

-- line #8577
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPHLENAT -D 250 (Natco Ph.)',
	'Cephalexin',
	'SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPHLENAT -D 250 (Natco Ph.)'
);

-- line #8578
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITACEPH 500 (VERITAZ)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITACEPH 500 (VERITAZ)'
);

-- line #8579
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITACEPH 125 (VERITAZ)',
	'Cephalexin',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITACEPH 125 (VERITAZ)'
);

-- line #8580
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITACEPH 250 (VERITAZ)',
	'Cephalexin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITACEPH 250 (VERITAZ)'
);

-- line #8581
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-LEX 125 (Mcneil Ph.)',
	'Cephalexin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-LEX 125 (Mcneil Ph.)'
);

-- line #8582
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUCEF 250 (Elfin Ph.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUCEF 250 (Elfin Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUCEF 500 (Elfin Ph.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUCEF 500 (Elfin Ph.)'
);

-- line #8583
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CULEXIN 500 (Curex)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CULEXIN 500 (Curex)'
);

-- line #8584
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIXIN 500 (Dynamic)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIXIN 500 (Dynamic)'
);

-- line #8585
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIXIN DYR 250 (Dynamic)',
	'Cephalexin',
	'SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIXIN DYR 250 (Dynamic)'
);

-- line #8586
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DT LX-KID 125 (Apex Labs.)',
	'Cephalexin',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DT LX-KID 125 (Apex Labs.)'
);

-- line #8587
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'E CEF OD 750 (Lupin)',
	'Cephalexin',
	'ER TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'E CEF OD 750 (Lupin)'
);

-- line #8588
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELEXIN 250 (AIMCO PH.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELEXIN 250 (AIMCO PH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELEXIN 500 (AIMCO PH.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELEXIN 500 (AIMCO PH.)'
);

-- line #8589
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELEXIN 125 (AIMCO PH.)',
	'Cephalexin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELEXIN 125 (AIMCO PH.)'
);

-- line #8590
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMCEPH 250 (Emcure)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMCEPH 250 (Emcure)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMCEPH 500 (Emcure)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMCEPH 500 (Emcure)'
);

-- line #8591
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMICEF 250 (Emil Ph.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMICEF 250 (Emil Ph.)'
);

-- line #8592
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMICEF 500 (Emil Ph.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMICEF 500 (Emil Ph.)'
);

-- line #8593
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMICEF 125 (Emil Ph.)',
	'Cephalexin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMICEF 125 (Emil Ph.)'
);

-- line #8594
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMICEF 125 (Emil Ph.)',
	'Cephalexin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMICEF 125 (Emil Ph.)'
);

-- line #8595
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EQUITROL CAP 500 (Jagsonpal)',
	'CEPHALEXIN',
	'F.',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EQUITROL CAP 500 (Jagsonpal)'
);

-- line #8596
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EQUITROL 250 (Jagsonpal)',
	'CEPHALEXIN',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EQUITROL 250 (Jagsonpal)'
);

-- line #8597
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EQUITROL 125 (Jagsonpal)',
	'CEPHALEXIN',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EQUITROL 125 (Jagsonpal)'
);

-- line #8598
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXIN 250 (Apex Form.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXIN 250 (Apex Form.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXIN 500 (Apex Form.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXIN 500 (Apex Form.)'
);

-- line #8599
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXIN 125 (Apex Form.)',
	'Cephalexin',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXIN 125 (Apex Form.)'
);

-- line #8600
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXIN 125 (Apex Form.)',
	'Cephalexin',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXIN 125 (Apex Form.)'
);

-- line #8601
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEX 250 (Ordain Hc.)',
	'Cephalexin',
	'D.SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEX 250 (Ordain Hc.)'
);

-- line #8602
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEX 250 (Ordain Hc.)',
	'Cephalexin',
	'D.SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg(ANHYDR.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEX 250 (Ordain Hc.)'
);

-- line #8603
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEX 250 (Ordain Hc.)',
	'Cephalexin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEX 250 (Ordain Hc.)'
);

-- line #8604
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEX 125 (Ordain Hc.)',
	'Cephalexin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEX 125 (Ordain Hc.)'
);

-- line #8605
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEX 375 (Ordain Hc.)',
	'Cephalexin',
	'TAB',
	gm.nullify_empty_string('375')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEX 375 (Ordain Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEX 750 (Ordain Hc.)',
	'Cephalexin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEX 750 (Ordain Hc.)'
);

-- line #8606
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIXOBACT 250 (Cipla)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIXOBACT 250 (Cipla)'
);

-- line #8607
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIXOBACT 500 (Cipla)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIXOBACT 500 (Cipla)'
);

-- line #8608
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIXOBACT 125 (Cipla)',
	'Cephalexin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIXOBACT 125 (Cipla)'
);

-- line #8609
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GELEXIN 250 (Genova)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GELEXIN 250 (Genova)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GELEXIN 500 (Genova)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GELEXIN 500 (Genova)'
);

-- line #8610
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENCEF 500 (Captab)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENCEF 500 (Captab)'
);

-- line #8611
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRAPEXIN 250 (Graf Lab.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRAPEXIN 250 (Graf Lab.)'
);

-- line #8612
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRAPEXIN 500 (Graf Lab.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRAPEXIN 500 (Graf Lab.)'
);

-- line #8613
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRAPEXIN 125 (Graf Lab.)',
	'Cephalexin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRAPEXIN 125 (Graf Lab.)'
);

-- line #8614
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRECEF 250 (Green Cross)',
	'Cephalexin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRECEF 250 (Green Cross)'
);

-- line #8615
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G-SPORIN 500 (Gcm Lab.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G-SPORIN 500 (Gcm Lab.)'
);

-- line #8616
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G-SPORIN 250 (Gcm Lab.)',
	'Cephalexin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G-SPORIN 250 (Gcm Lab.)'
);

-- line #8617
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HUFEX-375 375 (ROSE LABS)',
	'Cephalexin',
	'SR TAB',
	gm.nullify_empty_string('375')::numeric,
	'mg S.R.'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HUFEX-375 375 (ROSE LABS)'
);

-- line #8618
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HUFEX 250 (ROSE LABS)',
	'Cephalexin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HUFEX 250 (ROSE LABS)'
);

-- line #8619
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYCEF 125 (GRANDIX)',
	'Cephalexin',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYCEF 125 (GRANDIX)'
);

-- line #8620
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYCEF 250 (GRANDIX)',
	'Cephalexin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYCEF 250 (GRANDIX)'
);

-- line #8621
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYCEF 500 (GRANDIX)',
	'Cephalexin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYCEF 500 (GRANDIX)'
);

-- line #8622
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INFLEX 250 (Indian R.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INFLEX 250 (Indian R.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INFLEX 500 (Indian R.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INFLEX 500 (Indian R.)'
);

-- line #8623
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFLEX 375 (Ranbaxy)',
	'Cephalexin',
	'BD CAP',
	gm.nullify_empty_string('375')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFLEX 375 (Ranbaxy)'
);

-- line #8624
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFLEX 750 (Ranbaxy)',
	'Cephalexin',
	'BD CAP',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFLEX 750 (Ranbaxy)'
);

-- line #8625
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFLEX 250 (Ranbaxy)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFLEX 250 (Ranbaxy)'
);

-- line #8626
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEFLEX 500 (Ranbaxy)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEFLEX 500 (Ranbaxy)'
);

-- line #8627
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KIDLEX 250 (Radix Bio.)',
	'Cephalexin',
	'D.SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KIDLEX 250 (Radix Bio.)'
);

-- line #8628
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LECEF 250 (Eros Ph.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LECEF 250 (Eros Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LECEF 500 (Eros Ph.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LECEF 500 (Eros Ph.)'
);

-- line #8629
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LECEF-D 125 (Eros Ph.)',
	'Cephalexin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LECEF-D 125 (Eros Ph.)'
);

-- line #8630
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LECEF 125 (Eros Ph.)',
	'Cephalexin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LECEF 125 (Eros Ph.)'
);

-- line #8631
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LECEF 250 (Eros Ph.)',
	'Cephalexin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LECEF 250 (Eros Ph.)'
);

-- line #8632
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEXICA 250 (NIVCA)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEXICA 250 (NIVCA)'
);

-- line #8633
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEXICA 500 (NIVCA)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEXICA 500 (NIVCA)'
);

-- line #8634
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEXICA 125 (NIVCA)',
	'Cephalexin',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEXICA 125 (NIVCA)'
);

-- line #8635
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEXICA 250 (NIVCA)',
	'Cephalexin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEXICA 250 (NIVCA)'
);

-- line #8636
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEXIMAN 500 (Shalman)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEXIMAN 500 (Shalman)'
);

-- line #8637
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEXIMAN 125 (Shalman)',
	'Cephalexin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEXIMAN 125 (Shalman)'
);

-- line #8638
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEXIMAN 250 (Shalman)',
	'Cephalexin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEXIMAN 250 (Shalman)'
);

-- line #8639
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LX-250 250 (Apex Labs.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LX-250 250 (Apex Labs.)'
);

-- line #8640
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LX-500 500 (Apex Labs.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LX-500 500 (Apex Labs.)'
);

-- line #8641
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LX-KID 125 (Apex Labs.)',
	'Cephalexin',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LX-KID 125 (Apex Labs.)'
);

-- line #8642
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MARLEX 250 (Mars Rem.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MARLEX 250 (Mars Rem.)'
);

-- line #8643
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MARLEX 500 (Mars Rem.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MARLEX 500 (Mars Rem.)'
);

-- line #8644
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MARLEX 125 (Mars Rem.)',
	'Cephalexin',
	'DT TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MARLEX 125 (Mars Rem.)'
);

-- line #8645
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MARLEX 250 (Mars Rem.)',
	'Cephalexin',
	'DT TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MARLEX 250 (Mars Rem.)'
);

-- line #8646
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELEXIN 250 (Medico)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELEXIN 250 (Medico)'
);

-- line #8647
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELEXIN 500 (Medico)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELEXIN 500 (Medico)'
);

-- line #8648
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELEXIN 125 (Medico)',
	'Cephalexin',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELEXIN 125 (Medico)'
);

-- line #8649
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEXEF CRY 125 (Nicholas)',
	'Cephalexin',
	'SYRUP',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEXEF CRY 125 (Nicholas)'
);

-- line #8650
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEXEF 750 (Nicholas)',
	'Cephalexin',
	'DS',
	gm.nullify_empty_string('750')::numeric,
	'mg(S.R.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEXEF 750 (Nicholas)'
);

-- line #8651
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEXEF 250 (Piramal Hc.)',
	'Cephalexin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEXEF 250 (Piramal Hc.)'
);

-- line #8652
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEXEF 500 (Piramal Hc.)',
	'Cephalexin',
	'DT',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEXEF 500 (Piramal Hc.)'
);

-- line #8653
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'375', u'strength_2': u'', u'substance': u'Cephalexin', u'always_empty': u'', u'form': u'', u'brand': u'MEXEF', u'strength_3': u'', u'company': u'Nicholas', u'unit': u'mg(S.R.)'}

-- line #8654
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONACEF 250 (Zee Lab)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONACEF 250 (Zee Lab)'
);

-- line #8655
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONACEF 500 (Zee Lab)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONACEF 500 (Zee Lab)'
);

-- line #8656
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONACEF 125 (Zee Lab)',
	'Cephalexin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONACEF 125 (Zee Lab)'
);

-- line #8657
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOCEF 250 (Gsk)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOCEF 250 (Gsk)'
);

-- line #8658
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOCEF 500 (Gsk)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOCEF 500 (Gsk)'
);

-- line #8659
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOCEF 250 (Gsk)',
	'Cephalexin',
	'SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOCEF 250 (Gsk)'
);

-- line #8660
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIPHEX 250 (Nitin Ph.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIPHEX 250 (Nitin Ph.)'
);

-- line #8661
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIPHEX 500 (Nitin Ph.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIPHEX 500 (Nitin Ph.)'
);

-- line #8662
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIPHEX 125 (Nitin Ph.)',
	'Cephalexin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIPHEX 125 (Nitin Ph.)'
);

-- line #8663
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIPHEX 250 (Nitin Ph.)',
	'Cephalexin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIPHEX 250 (Nitin Ph.)'
);

-- line #8664
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIX 125 (Monokem)',
	'Cephalexin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIX 125 (Monokem)'
);

-- line #8665
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIX 125 (Monokem)',
	'Cephalexin',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIX 125 (Monokem)'
);

-- line #8666
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'6G', u'strength_2': u'10ML', u'substance': u'Cephalexin', u'always_empty': u'', u'form': u'DPS', u'brand': u'NUFEX', u'strength_3': u'', u'company': u'Rpg Life', u'unit': u''}

-- line #8667
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUFEX 125 (Rpg Life)',
	'Cephalexin',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUFEX 125 (Rpg Life)'
);

-- line #8668
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUFEX 375 (Rpg Life)',
	'Cephalexin',
	'SR TAB',
	gm.nullify_empty_string('375')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUFEX 375 (Rpg Life)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUFEX 750 (Rpg Life)',
	'Cephalexin',
	'SR TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUFEX 750 (Rpg Life)'
);

-- line #8669
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUFEX 125 (Rpg Life)',
	'Cephalexin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUFEX 125 (Rpg Life)'
);

-- line #8670
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUFEX 250 (Rpg Life)',
	'Cephalexin',
	'SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUFEX 250 (Rpg Life)'
);

-- line #8671
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUFEX 250 (Rpg Life)',
	'Cephalexin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUFEX 250 (Rpg Life)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUFEX 500 (Rpg Life)',
	'Cephalexin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUFEX 500 (Rpg Life)'
);

-- line #8672
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLFEX 125 (Olcare)',
	'Cephalexin',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLFEX 125 (Olcare)'
);

-- line #8673
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORALEXINE 250 (Kentreck)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORALEXINE 250 (Kentreck)'
);

-- line #8674
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORALEXINE 500 (Kentreck)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORALEXINE 500 (Kentreck)'
);

-- line #8675
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORALEXINE 125 (Kentreck)',
	'Cephalexin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORALEXINE 125 (Kentreck)'
);

-- line #8676
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORALEXINE 125 (Kentreck)',
	'Cephalexin',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORALEXINE 125 (Kentreck)'
);

-- line #8677
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORGACEF 250 (Shinto Org.)',
	'Cephalexin',
	'DT/500 CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORGACEF 250 (Shinto Org.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORGACEF 500 (Shinto Org.)',
	'Cephalexin',
	'DT/500 CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORGACEF 500 (Shinto Org.)'
);

-- line #8678
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORIPHEX 250 (Zydus A.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORIPHEX 250 (Zydus A.)'
);

-- line #8679
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORIPHEX 500 (Zydus A.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORIPHEX 500 (Zydus A.)'
);

-- line #8680
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORIPHEX 125 (Zydus A.)',
	'Cephalexin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORIPHEX 125 (Zydus A.)'
);

-- line #8681
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORIPHEX 125 (Zydus A.)',
	'Cephalexin',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORIPHEX 125 (Zydus A.)'
);

-- line #8682
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORLEX 250 (Trio Ph.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORLEX 250 (Trio Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORLEX 500 (Trio Ph.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORLEX 500 (Trio Ph.)'
);

-- line #8683
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORLEX 125 (Trio Rem.)',
	'Cephalexin',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORLEX 125 (Trio Rem.)'
);

-- line #8684
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OROCEPH 100 (Lark Lab)',
	'Cephalexin',
	'DPS',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OROCEPH 100 (Lark Lab)'
);

-- line #8685
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OROCEPH 125 (Lark Lab)',
	'Cephalexin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OROCEPH 125 (Lark Lab)'
);

-- line #8686
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OROCEPH 125 (Lark Labs)',
	'Cephalexin',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OROCEPH 125 (Lark Labs)'
);

-- line #8687
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OROCEPH 250 (Lark Lab)',
	'Cephalexin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OROCEPH 250 (Lark Lab)'
);

-- line #8688
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OROCEPH 500 (Lark Lab)',
	'Cephalexin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OROCEPH 500 (Lark Lab)'
);

-- line #8689
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORYCEF 250 (Jrs Oryx.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORYCEF 250 (Jrs Oryx.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORYCEF 500 (Jrs Oryx.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORYCEF 500 (Jrs Oryx.)'
);

-- line #8690
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORYCEF 125 (Jrs Oryx.)',
	'Cephalexin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORYCEF 125 (Jrs Oryx.)'
);

-- line #8691
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORYCEF 125 (Jrs Oryx.)',
	'Cephalexin',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORYCEF 125 (Jrs Oryx.)'
);

-- line #8692
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEARLEX 125 (Natco Ph.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEARLEX 125 (Natco Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEARLEX 250 (Natco Ph.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEARLEX 250 (Natco Ph.)'
);

-- line #8693
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEARLEX 500 (Natco Ph.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEARLEX 500 (Natco Ph.)'
);

-- line #8694
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEARLEX 125 (Natco Ph.)',
	'Cephalexin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEARLEX 125 (Natco Ph.)'
);

-- line #8695
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENCEF 500 (SAFE PH.)',
	'Cephalexin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENCEF 500 (SAFE PH.)'
);

-- line #8696
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHEXIKID 125 (INVISION(INFALIFE))',
	'Cephalexin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHEXIKID 125 (INVISION(INFALIFE))'
);

-- line #8697
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHEXIKID 250 (INVISION(INFALIFE))',
	'Cephalexin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHEXIKID 250 (INVISION(INFALIFE))'
);

-- line #8698
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHEXIN 375 (Gsk)',
	'Cephalexin',
	'BD CAP',
	gm.nullify_empty_string('375')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHEXIN 375 (Gsk)'
);

-- line #8699
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHEXIN 750 (Gsk)',
	'Cephalexin',
	'BD CAP',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHEXIN 750 (Gsk)'
);

-- line #8700
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHEXIN 250 (Gsk)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHEXIN 250 (Gsk)'
);

-- line #8701
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHEXIN 500 (Gsk)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHEXIN 500 (Gsk)'
);

-- line #8702
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHEXIN 100 (Gsk)',
	'Cephalexin',
	'DPS',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHEXIN 100 (Gsk)'
);

-- line #8703
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHEXIN 250 (Gsk)',
	'Cephalexin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHEXIN 250 (Gsk)'
);

-- line #8704
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHEXIN 125 (Gsk)',
	'Cephalexin',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHEXIN 125 (Gsk)'
);

-- line #8705
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHEXIN 250 (Gsk)',
	'Cephalexin',
	'SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHEXIN 250 (Gsk)'
);

-- line #8706
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHEXIROM 500 (Rhombus)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHEXIROM 500 (Rhombus)'
);

-- line #8707
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHEXIROM KID/250 125 (Rhombus)',
	'Cephalexin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHEXIROM KID/250 125 (Rhombus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHEXIROM KID/250 250 (Rhombus)',
	'Cephalexin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHEXIROM KID/250 250 (Rhombus)'
);

-- line #8708
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHEXTAR 250 (Intra(INVISION))',
	'Cephalexin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHEXTAR 250 (Intra(INVISION))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHEXTAR 500 (Intra(INVISION))',
	'Cephalexin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHEXTAR 500 (Intra(INVISION))'
);

-- line #8709
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIFLEXIN 250 (Pifer Ph.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIFLEXIN 250 (Pifer Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIFLEXIN 500 (Pifer Ph.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIFLEXIN 500 (Pifer Ph.)'
);

-- line #8710
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIFLEXIN 125 (Pifer Ph.)',
	'Cephalexin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIFLEXIN 125 (Pifer Ph.)'
);

-- line #8711
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIFLEXIN KID 125 (Pifer Ph.)',
	'Cephalexin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIFLEXIN KID 125 (Pifer Ph.)'
);

-- line #8712
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREMSPOR 250 (Merind)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREMSPOR 250 (Merind)'
);

-- line #8713
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREMSPOR 500 (Merind)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREMSPOR 500 (Merind)'
);

-- line #8714
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREMSPOR 125 (Merind)',
	'Cephalexin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREMSPOR 125 (Merind)'
);

-- line #8715
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRILEX 250 (Hal)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRILEX 250 (Hal)'
);

-- line #8716
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRILEX 500 (Hal)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRILEX 500 (Hal)'
);

-- line #8717
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRILEX -P 125 (Hal)',
	'Cephalexin',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRILEX -P 125 (Hal)'
);

-- line #8718
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRILEX 125 (Merind)',
	'Cephalexin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRILEX 125 (Merind)'
);

-- line #8719
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRILOCEF 250 (Hal)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRILOCEF 250 (Hal)'
);

-- line #8720
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRILOCEF 500 (Hal)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRILOCEF 500 (Hal)'
);

-- line #8721
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRILOCEF 125 (Hal)',
	'Cephalexin',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRILOCEF 125 (Hal)'
);

-- line #8722
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q CEF 250 (Que Ph.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q CEF 250 (Que Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q CEF 500 (Que Ph.)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q CEF 500 (Que Ph.)'
);

-- line #8723
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q CEF 250 (Que Ph.)',
	'Cephalexin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q CEF 250 (Que Ph.)'
);

-- line #8724
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RACEF 500 (Intra Lab)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RACEF 500 (Intra Lab)'
);

-- line #8725
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RACEF 125 (Intra Lab)',
	'Cephalexin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RACEF 125 (Intra Lab)'
);

-- line #8726
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RACEF 250 (Intra Lab)',
	'Cephalexin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RACEF 250 (Intra Lab)'
);

-- line #8727
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REFLEXIN 250 (Radicura)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REFLEXIN 250 (Radicura)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REFLEXIN 500 (Radicura)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REFLEXIN 500 (Radicura)'
);

-- line #8728
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REFLEXIN 125 (Radicura)',
	'Cephalexin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REFLEXIN 125 (Radicura)'
);

-- line #8729
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REXIN-250 250 (Royal)',
	'Cephalexin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REXIN-250 250 (Royal)'
);

-- line #8730
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REXIN-500 500 (Royal)',
	'Cephalexin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REXIN-500 500 (Royal)'
);

-- line #8731
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cephaloridine', u'always_empty': u'', u'form': u'INJ', u'brand': u'CEPORAN', u'strength_3': u'', u'company': u'Gsk', u'unit': u''}

-- line #8732
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPORAN 500 (Gsk)',
	'Cephaloridine',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPORAN 500 (Gsk)'
);

-- line #8733
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'3-CET 10 (MARLINE BIO.)',
	'Cetirizine',
	'MD TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '3-CET 10 (MARLINE BIO.)'
);

-- line #8734
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'A-CET 5 (ACTO)',
	'Cetirizine',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'A-CET 5 (ACTO)'
);

-- line #8735
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'A-CET 10 (ACTO)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'A-CET 10 (ACTO)'
);

-- line #8736
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'(DIHCL)', u'strength_2': u'', u'substance': u'Cetirizine', u'always_empty': u'', u'form': u'TAB', u'brand': u'ACET', u'strength_3': u'', u'company': u'Shrinivas', u'unit': u''}

-- line #8737
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AFFYCET 10 (AFFY)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AFFYCET 10 (AFFY)'
);

-- line #8738
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AGLOCET 5 (Aglowmed)',
	'Cetirizine',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AGLOCET 5 (Aglowmed)'
);

-- line #8739
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AGLOCET 10 (Aglowmed)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AGLOCET 10 (Aglowmed)'
);

-- line #8740
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AIDAY 10 (Bipl(Radico Lab))',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AIDAY 10 (Bipl(Radico Lab))'
);

-- line #8741
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALCE 10 (Franklin)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg(DIHCL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALCE 10 (Franklin)'
);

-- line #8742
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALCET 10 (Osper)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALCET 10 (Osper)'
);

-- line #8743
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALCITRA 10 (Calibar Ph.)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALCITRA 10 (Calibar Ph.)'
);

-- line #8744
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALERBLOC 5 (Kapl)',
	'Cetirizine',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALERBLOC 5 (Kapl)'
);

-- line #8745
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALERBLOC 10 (Kapl)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALERBLOC 10 (Kapl)'
);

-- line #8746
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALERDIN 10 (Apex Form.)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALERDIN 10 (Apex Form.)'
);

-- line #8747
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALERID 5 (Cipla)',
	'Cetirizine',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALERID 5 (Cipla)'
);

-- line #8748
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALERID 10 (Cipla)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALERID 10 (Cipla)'
);

-- line #8749
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALERTAC 10 (Seagull)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALERTAC 10 (Seagull)'
);

-- line #8750
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALERVIN 5 (Ultramark)',
	'Cetirizine',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALERVIN 5 (Ultramark)'
);

-- line #8751
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALERVIN 10 (Ultramark)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALERVIN 10 (Ultramark)'
);

-- line #8752
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALFREE 10 (Stallion)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALFREE 10 (Stallion)'
);

-- line #8753
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALGY 10 (Biogenetic)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALGY 10 (Biogenetic)'
);

-- line #8754
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALLERCET 5 (Brown & B.)',
	'CETIRIZINE',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALLERCET 5 (Brown & B.)'
);

-- line #8755
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALLERCET 10 (Brown & B.)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALLERCET 10 (Brown & B.)'
);

-- line #8756
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALLERCET 5 (Brown & B.)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALLERCET 5 (Brown & B.)'
);

-- line #8757
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALLERZINE 10 (Jenburkt)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALLERZINE 10 (Jenburkt)'
);

-- line #8758
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALOCET 5 (VILBERRY HC.)',
	'Cetirizine',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALOCET 5 (VILBERRY HC.)'
);

-- line #8759
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALTIN 10 (Sysmed)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALTIN 10 (Sysmed)'
);

-- line #8760
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZINE 10 (Claris L.)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZINE 10 (Claris L.)'
);

-- line #8761
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANTIZED 5 (Kentreck)',
	'Cetirizine',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANTIZED 5 (Kentreck)'
);

-- line #8762
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANTIZED 10 (Kentreck)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANTIZED 10 (Kentreck)'
);

-- line #8763
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASERT 100 (Nicholas)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASERT 100 (Nicholas)'
);

-- line #8764
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASERT 50 (Nicholas)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASERT 50 (Nicholas)'
);

-- line #8765
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATCET 10 (Atoz Ph.)',
	'Cetirizine',
	'MD TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg(DIHCL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATCET 10 (Atoz Ph.)'
);

-- line #8766
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATRIZINE 10 (AIMCO PH.)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATRIZINE 10 (AIMCO PH.)'
);

-- line #8767
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVIZIN 5 (Avalanche)',
	'CETIRIZINE',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVIZIN 5 (Avalanche)'
);

-- line #8768
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVIZIN 10 (Avalanche)',
	'CETIRIZINE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVIZIN 10 (Avalanche)'
);

-- line #8769
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZ 10 (Sienna Form.)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZ 10 (Sienna Form.)'
);

-- line #8770
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BANCET 10 (Bantom)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BANCET 10 (Bantom)'
);

-- line #8771
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BATRIZ 10 (Baroque)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BATRIZ 10 (Baroque)'
);

-- line #8772
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BEALERT 10 (Genix Ph.)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BEALERT 10 (Genix Ph.)'
);

-- line #8773
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIO ACT 10 (Bio-Drug)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIO ACT 10 (Bio-Drug)'
);

-- line #8774
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOZIN 10 (BIOMEDICA)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOZIN 10 (BIOMEDICA)'
);

-- line #8775
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-DAY 5 (Suvik Hit.)',
	'Cetirizine',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-DAY 5 (Suvik Hit.)'
);

-- line #8776
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-DAY 10 (Suvik Hit.)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-DAY 10 (Suvik Hit.)'
);

-- line #8777
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CD-CET 10 (Cadex Lab)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CD-CET 10 (Cadex Lab)'
);

-- line #8778
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFID 10 (Novamed)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFID 10 (Novamed)'
);

-- line #8779
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CENT 10 (Aronex Life)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CENT 10 (Aronex Life)'
);

-- line #8780
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CERIN 5 (Arvind Lab.)',
	'Cetirizine',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CERIN 5 (Arvind Lab.)'
);

-- line #8781
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CERIN 10 (Arvind Lab.)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CERIN 10 (Arvind Lab.)'
);

-- line #8782
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CERIZINE-FT 5 (Emcure)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CERIZINE-FT 5 (Emcure)'
);

-- line #8783
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETALORE 10 (Klm Ph.)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETALORE 10 (Klm Ph.)'
);

-- line #8784
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETCIP 10 (Cipla)',
	'Cetirizine',
	'SR CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETCIP 10 (Cipla)'
);

-- line #8785
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETCIP 5 (Cipla)',
	'Cetirizine',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETCIP 5 (Cipla)'
);

-- line #8786
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETCIP 10 (Cipla)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETCIP 10 (Cipla)'
);

-- line #8787
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Cetirizine', u'always_empty': u'', u'form': u'SYP', u'brand': u'CETCOM', u'strength_3': u'', u'company': u'NIVCA', u'unit': u''}

-- line #8788
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Cetirizine', u'always_empty': u'', u'form': u'TAB', u'brand': u'CETCOM', u'strength_3': u'', u'company': u'NIVCA', u'unit': u''}

-- line #8789
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETCURE 10 (Allure Rem.)',
	'Cetirizine',
	'DT TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETCURE 10 (Allure Rem.)'
);

-- line #8790
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETEN 5 (Arbro Ph.)',
	'Cetirizine',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETEN 5 (Arbro Ph.)'
);

-- line #8791
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETEN 10 (Arbro Ph.)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETEN 10 (Arbro Ph.)'
);

-- line #8792
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETER 10 (LUSTRE)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETER 10 (LUSTRE)'
);

-- line #8793
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETERZOL 5 (EAST WEST)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETERZOL 5 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETERZOL 10 (EAST WEST)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETERZOL 10 (EAST WEST)'
);

-- line #8794
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETFORD 10 (Ronak Lab.)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETFORD 10 (Ronak Lab.)'
);

-- line #8795
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETGEL 10 (Universal)',
	'Cetirizine',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETGEL 10 (Universal)'
);

-- line #8796
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETGIN 10 (BIOGEN PH.)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETGIN 10 (BIOGEN PH.)'
);

-- line #8797
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETICAD 10 (Zydus Cadila)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETICAD 10 (Zydus Cadila)'
);

-- line #8798
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETIN 5 (Ind-Swift)',
	'Cetirizine',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETIN 5 (Ind-Swift)'
);

-- line #8799
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETIN 10 (Ind-Swift)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETIN 10 (Ind-Swift)'
);

-- line #8800
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETIRIZ 5 (Alkem)',
	'Cetirizine',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETIRIZ 5 (Alkem)'
);

-- line #8801
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETIRIZ 10 (Alkem)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETIRIZ 10 (Alkem)'
);

-- line #8802
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETIZ 10 (Runa Ph.)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETIZ 10 (Runa Ph.)'
);

-- line #8803
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Cetirizine', u'always_empty': u'', u'form': u'TAB', u'brand': u'CETIZ', u'strength_3': u'', u'company': u'SAFE PH.', u'unit': u''}

-- line #8804
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETLONG 5 (RND LAB)',
	'Cetirizine',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETLONG 5 (RND LAB)'
);

-- line #8805
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETLONG 10 (RND LAB)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETLONG 10 (RND LAB)'
);

-- line #8806
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETMAC 5 (Ikon Rem)',
	'Cetirizine',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETMAC 5 (Ikon Rem)'
);

-- line #8807
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETMAC 10 (Ikon Rem)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETMAC 10 (Ikon Rem)'
);

-- line #8808
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETMET 10 (ALMET)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETMET 10 (ALMET)'
);

-- line #8809
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETNAZ 10 (Khandelwal)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETNAZ 10 (Khandelwal)'
);

-- line #8810
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETOZ 10 (Marc Lab)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETOZ 10 (Marc Lab)'
);

-- line #8811
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETPAN 10 (PANTHER PH.)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETPAN 10 (PANTHER PH.)'
);

-- line #8812
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETRA CARE 10 (Royal)',
	'Cetirizine',
	'MD',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETRA CARE 10 (Royal)'
);

-- line #8813
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETRACARE 10 (Royal Lab)',
	'Cetirizine',
	'MD TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETRACARE 10 (Royal Lab)'
);

-- line #8814
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETRACT 10 (Active Hc.)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETRACT 10 (Active Hc.)'
);

-- line #8815
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETRAHIST 5 (Numarck Ph.)',
	'Cetirizine',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETRAHIST 5 (Numarck Ph.)'
);

-- line #8816
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETRAHIST 10 (Numarck Ph.)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETRAHIST 10 (Numarck Ph.)'
);

-- line #8817
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETRAL 10 (N.A.)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETRAL 10 (N.A.)'
);

-- line #8818
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETRA 10 (Prochem)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETRA 10 (Prochem)'
);

-- line #8819
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETREZOL 5 (EAST WEST)',
	'Cetirizine',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETREZOL 5 (EAST WEST)'
);

-- line #8820
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETREZOL 5 (EAST WEST)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETREZOL 5 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETREZOL 10 (EAST WEST)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETREZOL 10 (EAST WEST)'
);

-- line #8821
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETRIDOC 10 (Glenmark)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETRIDOC 10 (Glenmark)'
);

-- line #8822
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETRIKAA 10 (Troikaa)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETRIKAA 10 (Troikaa)'
);

-- line #8823
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETRILIN 5 (TAJ PH.)',
	'Cetirizine',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETRILIN 5 (TAJ PH.)'
);

-- line #8824
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETRILIN 5 (TAJ PH.)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETRILIN 5 (TAJ PH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETRILIN 10 (TAJ PH.)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETRILIN 10 (TAJ PH.)'
);

-- line #8825
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETRIL 10 (TRIDENT PH.)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETRIL 10 (TRIDENT PH.)'
);

-- line #8826
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETRIMAN 10 (Maan)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETRIMAN 10 (Maan)'
);

-- line #8827
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETRIMOL 10 (Merit Org.)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETRIMOL 10 (Merit Org.)'
);

-- line #8828
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETRINA 10 (Sayona)',
	'Cetirizine',
	'MD TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETRINA 10 (Sayona)'
);

-- line #8829
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETRINEM 10 (NEMI PH.)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETRINEM 10 (NEMI PH.)'
);

-- line #8830
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETRINE 1 (Dr.Reddy''S)',
	'Cetirizine',
	'SYR',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETRINE 1 (Dr.Reddy''S)'
);

-- line #8831
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETRINE 10 (Dr.Reddy''S)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETRINE 10 (Dr.Reddy''S)'
);

-- line #8832
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETRIQ 10 (Aquila)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETRIQ 10 (Aquila)'
);

-- line #8833
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETRISAN 10 (Sanjivani)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETRISAN 10 (Sanjivani)'
);

-- line #8834
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETRISON 5 (Patson)',
	'Cetirizine',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETRISON 5 (Patson)'
);

-- line #8835
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETRISON 10 (Patson)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETRISON 10 (Patson)'
);

-- line #8836
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETRITOP-10 10 (Alde Medi.)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETRITOP-10 10 (Alde Medi.)'
);

-- line #8837
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETRIWAL 10 (Wallace)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETRIWAL 10 (Wallace)'
);

-- line #8838
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETRIZET 10 (Sun)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETRIZET 10 (Sun)'
);

-- line #8839
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETRIZET 5 (Sun)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETRIZET 5 (Sun)'
);

-- line #8840
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETRIZINE-FT 10 (Emcure)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETRIZINE-FT 10 (Emcure)'
);

-- line #8841
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETRIZ 10 (Samson)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETRIZ 10 (Samson)'
);

-- line #8842
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETRON 5 (Stanford)',
	'Cetirizine',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETRON 5 (Stanford)'
);

-- line #8843
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Cetirizine', u'always_empty': u'', u'form': u'TAB', u'brand': u'CETRON', u'strength_3': u'', u'company': u'Allure Rem.', u'unit': u''}

-- line #8844
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CET 10 (MEDISYS)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CET 10 (MEDISYS)'
);

-- line #8845
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETTOP 10 (Reliance)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg(HCL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETTOP 10 (Reliance)'
);

-- line #8846
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETURE 10 (Allure Rem.)',
	'Cetirizine',
	'DT',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETURE 10 (Allure Rem.)'
);

-- line #8847
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETVEN 10 (VENSAT)',
	'Cetirizine',
	'DT TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETVEN 10 (VENSAT)'
);

-- line #8848
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETZIKAN 10 (Kansas Lab)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETZIKAN 10 (Kansas Lab)'
);

-- line #8849
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETZINE 10 (Gsk)',
	'Cetirizine',
	'CAPTAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETZINE 10 (Gsk)'
);

-- line #8850
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETZINE 5 (Gsk)',
	'Cetirizine',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETZINE 5 (Gsk)'
);

-- line #8851
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETZY 10 (Zee Lab)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETZY 10 (Zee Lab)'
);

-- line #8852
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEZINE 10 (Anikem Lab.)',
	'Cetirizine',
	'DT',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEZINE 10 (Anikem Lab.)'
);

-- line #8853
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEZINE 5 (Anikem Lab.)',
	'Cetirizine',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEZINE 5 (Anikem Lab.)'
);

-- line #8854
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEZ 10 (Finecure)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEZ 10 (Finecure)'
);

-- line #8855
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-FRESH 10 (SMART LAB.)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-FRESH 10 (SMART LAB.)'
);

-- line #8856
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CISTIN 5 (D.R.John''S)',
	'Cetirizine',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CISTIN 5 (D.R.John''S)'
);

-- line #8857
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CISTIN 10 (D.R.John''S)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CISTIN 10 (D.R.John''S)'
);

-- line #8858
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITLA 10 (Medoz Ph.)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITLA 10 (Medoz Ph.)'
);

-- line #8859
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITNOR 10 (Nordic Ph.)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITNOR 10 (Nordic Ph.)'
);

-- line #8860
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITOL 10 (Olcare)',
	'Cetirizine',
	'DT',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITOL 10 (Olcare)'
);

-- line #8861
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITOL 10 (Olcare)',
	'Cetirizine',
	'DT SYR',
	gm.nullify_empty_string('10')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITOL 10 (Olcare)'
);

-- line #8862
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITOL 10 (Olcare)',
	'Cetirizine',
	'DT TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITOL 10 (Olcare)'
);

-- line #8863
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITOL 10 (Olcare)',
	'Cetirizine',
	'SYR',
	gm.nullify_empty_string('10')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITOL 10 (Olcare)'
);

-- line #8864
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITRAZAN 10 (Mac)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITRAZAN 10 (Mac)'
);

-- line #8865
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITRITO 10 (SHINE PH.)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITRITO 10 (SHINE PH.)'
);

-- line #8866
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITZEN 10 (Kaizen Ph.)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITZEN 10 (Kaizen Ph.)'
);

-- line #8867
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLARITEC 10 (Wanbury)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLARITEC 10 (Wanbury)'
);

-- line #8868
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COLDCET 10 (CHEMO HC.)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COLDCET 10 (CHEMO HC.)'
);

-- line #8869
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COPE 10 (Mankind)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COPE 10 (Mankind)'
);

-- line #8870
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COSZIN 5 (Cfl Ph.)',
	'Cetirizine',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COSZIN 5 (Cfl Ph.)'
);

-- line #8871
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COSZIN 10 (Cfl Ph.)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COSZIN 10 (Cfl Ph.)'
);

-- line #8872
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CRAB 10 (Kwik Hc.)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CRAB 10 (Kwik Hc.)'
);

-- line #8873
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CRAZIN 10 (Tnt Life)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CRAZIN 10 (Tnt Life)'
);

-- line #8874
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CT-10 10 (Ampus Life)',
	'Cetirizine',
	'SG CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CT-10 10 (Ampus Life)'
);

-- line #8875
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-TEC 10 (Perk Ph.)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-TEC 10 (Perk Ph.)'
);

-- line #8876
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-TRIZ 10 (CORONA)',
	'Cetirizine',
	'DT',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-TRIZ 10 (CORONA)'
);

-- line #8877
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CTZ 10 (Pil)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CTZ 10 (Pil)'
);

-- line #8878
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUCET 10 (Cubit Hc.)',
	'Cetirizine',
	'DT',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUCET 10 (Cubit Hc.)'
);

-- line #8879
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CZ-3 5 (Lupin)',
	'Cetirizine',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CZ-3 5 (Lupin)'
);

-- line #8880
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CZ-3 10 (Lupin)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CZ-3 10 (Lupin)'
);

-- line #8881
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'D-ALLER 10 (Ophthal R.)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'D-ALLER 10 (Ophthal R.)'
);

-- line #8882
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAYTIME 10 (Hi-Tec)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAYTIME 10 (Hi-Tec)'
);

-- line #8883
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICET 10 (Cambridge Hc.)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICET 10 (Cambridge Hc.)'
);

-- line #8884
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETRID 10 (BIOMIICRON)',
	'Cetirizine Dihydrochloride',
	'OD TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETRID 10 (BIOMIICRON)'
);

-- line #8885
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIO-1 10 (Unison)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIO-1 10 (Unison)'
);

-- line #8886
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'E-CET MD 10 (MARLINE BIO.)',
	'Cetirizine',
	'DT',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'E-CET MD 10 (MARLINE BIO.)'
);

-- line #8887
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EKOCET 10 (Kamron)',
	'Cetirizine',
	'DT TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EKOCET 10 (Kamron)'
);

-- line #8888
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EKON 10 (Blue Cross)',
	'Cetirizine',
	'DT',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EKON 10 (Blue Cross)'
);

-- line #8889
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EKON 5 (Blue Cross)',
	'Cetirizine',
	'DT',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EKON 5 (Blue Cross)'
);

-- line #8890
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EKON 10 (Blue Cross)',
	'Cetirizine',
	'DT TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EKON 10 (Blue Cross)'
);

-- line #8891
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EKON 5 (Blue Cross)',
	'Cetirizine',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EKON 5 (Blue Cross)'
);

-- line #8892
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELART 5 (TALENT LAB.)',
	'Cetirizine',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELART 5 (TALENT LAB.)'
);

-- line #8893
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELART 10 (TALENT LAB.)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELART 10 (TALENT LAB.)'
);

-- line #8894
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELCET 10 (Elysium)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELCET 10 (Elysium)'
);

-- line #8895
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELGNIL 5 (CADILA)',
	'Cetirizine',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELGNIL 5 (CADILA)'
);

-- line #8896
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELGNIL 10 (CADILA)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELGNIL 10 (CADILA)'
);

-- line #8897
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELTRIZIN 10 (Lancer)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELTRIZIN 10 (Lancer)'
);

-- line #8898
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUZENE 10 (Epoch Ph.)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUZENE 10 (Epoch Ph.)'
);

-- line #8899
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EZE 10 (Saga Lab)',
	'Cetirizine',
	'DT',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EZE 10 (Saga Lab)'
);

-- line #8900
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLAMOSET 5 (FLAMINGO PH.)',
	'Cetirizine',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg (HCL.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLAMOSET 5 (FLAMINGO PH.)'
);

-- line #8901
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLORAMIN 10 (Bestochem)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLORAMIN 10 (Bestochem)'
);

-- line #8902
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOMICET 10 (Geno Ph.)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOMICET 10 (Geno Ph.)'
);

-- line #8903
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORMICET 10 (Group Ph.)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORMICET 10 (Group Ph.)'
);

-- line #8904
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G-CET 10 (Graf Lab.)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G-CET 10 (Graf Lab.)'
);

-- line #8905
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HICET 5 (Micro Nova)',
	'Cetirizine',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HICET 5 (Micro Nova)'
);

-- line #8906
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HICET 10 (Micro Nova)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HICET 10 (Micro Nova)'
);

-- line #8907
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HISNOFIL 5 (Rextar)',
	'Cetirizine',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HISNOFIL 5 (Rextar)'
);

-- line #8908
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HISNOFIL 10 (Rextar)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HISNOFIL 10 (Rextar)'
);

-- line #8909
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Cetirizine', u'always_empty': u'', u'form': u'SYR', u'brand': u'HISTACET', u'strength_3': u'', u'company': u'Merril Ph.', u'unit': u''}

-- line #8910
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HISTACET 10 (Merril Ph.)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HISTACET 10 (Merril Ph.)'
);

-- line #8911
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HISTRIZ 10 (Theo Ph.)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HISTRIZ 10 (Theo Ph.)'
);

-- line #8912
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ICET-IR 10 (GALLICA PH.)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ICET-IR 10 (GALLICA PH.)'
);

-- line #8913
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IFYCET 10 (Sanify)',
	'Cetirizine',
	'DT',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IFYCET 10 (Sanify)'
);

-- line #8914
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INCEZ 10 (Intra Lab)',
	'Cetirizine',
	'DT',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INCEZ 10 (Intra Lab)'
);

-- line #8915
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INCEZ 5 (Intra Lab)',
	'Cetirizine',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INCEZ 5 (Intra Lab)'
);

-- line #8916
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INCID-L 5 (Bayer)',
	'Cetirizine',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INCID-L 5 (Bayer)'
);

-- line #8917
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INCID-L 10 (Bayer)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INCID-L 10 (Bayer)'
);

-- line #8918
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JOCET 10 (Unique)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JOCET 10 (Unique)'
);

-- line #8919
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JYOCET 10 (Malody Hc.)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JYOCET 10 (Malody Hc.)'
);

-- line #8920
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KIVICET 10 (KIVI LABS)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KIVICET 10 (KIVI LABS)'
);

-- line #8921
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEZINE 10 (Lexus)',
	'Cetirizine',
	'DT',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEZINE 10 (Lexus)'
);

-- line #8922
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LGNIL 5 (Lglsi)',
	'Cetirizine',
	'LS SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LGNIL 5 (Lglsi)'
);

-- line #8923
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIGNIL 5 (Cadila Hc.)',
	'Cetirizine',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIGNIL 5 (Cadila Hc.)'
);

-- line #8924
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LODIZIN 10 (NOVARTIS)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LODIZIN 10 (NOVARTIS)'
);

-- line #8925
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'M-CIT 10 (MADHAV BIO.)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'M-CIT 10 (MADHAV BIO.)'
);

-- line #8926
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METRIZ 10 (Mamta Ph.)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METRIZ 10 (Mamta Ph.)'
);

-- line #8927
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILCET 10 (Shaimil)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILCET 10 (Shaimil)'
);

-- line #8928
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MORAZIN 5 (Moraceae)',
	'Cetirizine',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MORAZIN 5 (Moraceae)'
);

-- line #8929
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MORAZIN 10 (Moraceae)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MORAZIN 10 (Moraceae)'
);

-- line #8930
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NANOZIN 10 (ZEDR)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NANOZIN 10 (ZEDR)'
);

-- line #8931
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEUSONIL 10 (P C INDIA)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEUSONIL 10 (P C INDIA)'
);

-- line #8932
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'N-ZIN 5 (Nestor)',
	'Cetirizine',
	'SUS',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'N-ZIN 5 (Nestor)'
);

-- line #8933
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'N-ZIN 10 (Nestor)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'N-ZIN 10 (Nestor)'
);

-- line #8934
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODACET 5 (Mapra)',
	'Cetirizine',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODACET 5 (Mapra)'
);

-- line #8935
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODACET 10 (Mapra)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODACET 10 (Mapra)'
);

-- line #8936
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODITEC 10 (ANAND HC.)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODITEC 10 (ANAND HC.)'
);

-- line #8937
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OKACET 5 (Cipla)',
	'Cetirizine',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OKACET 5 (Cipla)'
);

-- line #8938
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OKACET 10 (Cipla)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OKACET 10 (Cipla)'
);

-- line #8939
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONCET 10 (Medley)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONCET 10 (Medley)'
);

-- line #8940
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSHZIN 10 (Oshin Lab)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSHZIN 10 (Oshin Lab)'
);

-- line #8941
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANCET 10 (Panjon)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANCET 10 (Panjon)'
);

-- line #8942
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARCET 10 (Paras Lab)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARCET 10 (Paras Lab)'
);

-- line #8943
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERCET 10 (Perch)',
	'Cetirizine',
	'DT',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERCET 10 (Perch)'
);

-- line #8944
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERCET 5 (Perch)',
	'Cetirizine',
	'DT',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERCET 5 (Perch)'
);

-- line #8945
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERCET 5 (Perch)',
	'Cetirizine',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERCET 5 (Perch)'
);

-- line #8946
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROZINE 10 (Mars Rem.)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROZINE 10 (Mars Rem.)'
);

-- line #8947
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PULCET 10 (Pulse Ph.)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PULCET 10 (Pulse Ph.)'
);

-- line #8948
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUZINE 10 (Armour Rem.)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUZINE 10 (Armour Rem.)'
);

-- line #8949
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10', u'strength_2': u'', u'substance': u'Cetirizine', u'always_empty': u'', u'form': u'', u'brand': u'RECET SOFTGEL', u'strength_3': u'', u'company': u'Royal', u'unit': u'mg'}

-- line #8950
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Cetirizine', u'always_empty': u'', u'form': u'SYR', u'brand': u'RECET', u'strength_3': u'', u'company': u'SANCHEZ LAB.', u'unit': u''}

-- line #8951
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RECET 10 (FORTUNE HC.)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RECET 10 (FORTUNE HC.)'
);

-- line #8952
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RHIZIN 5 (Zydus Cadila)',
	'Cetirizine',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RHIZIN 5 (Zydus Cadila)'
);

-- line #8953
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RHIZIN 10 (Zydus Cadila)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RHIZIN 10 (Zydus Cadila)'
);

-- line #8954
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RHYNAL 10 (MINOVA)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RHYNAL 10 (MINOVA)'
);

-- line #8955
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RINITRIN 10 (Svizera)',
	'Cetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RINITRIN 10 (Svizera)'
);

-- line #8956
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250MCG', u'strength_2': u'', u'substance': u'Cetorelix Acetate', u'always_empty': u'', u'form': u'VIAL', u'brand': u'CETROTIDE', u'strength_3': u'', u'company': u'Serum Int.', u'unit': u''}

-- line #8957
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETACID 0.5 (Hind.Trust)',
	'Cetrimide',
	'CRM',
	gm.nullify_empty_string('0.5')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETACID 0.5 (Hind.Trust)'
);

-- line #8958
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'Cetrimide', u'always_empty': u'', u'form': u'', u'brand': u'CETAVLON CONC', u'strength_3': u'', u'company': u'I C I', u'unit': u'%W/V'}

-- line #8959
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETRILAK-MILD 5 (Shalaks)',
	'Cetrimide',
	'SOL',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETRILAK-MILD 5 (Shalaks)'
);

-- line #8960
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETRILAK 20 (Shalaks)',
	'Cetrimide',
	'SOL(1000)',
	gm.nullify_empty_string('20')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETRILAK 20 (Shalaks)'
);

-- line #8961
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETRILAK 20 (Shalaks)',
	'Cetrimide',
	'SOL',
	gm.nullify_empty_string('20')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETRILAK 20 (Shalaks)'
);

-- line #8962
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETRIMIDE-CONC 20 (Nicholas)',
	'Cetrimide',
	'SOL',
	gm.nullify_empty_string('20')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETRIMIDE-CONC 20 (Nicholas)'
);

-- line #8963
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORAL 0.5 (BIOSCIENCES)',
	'Cetrimide',
	'SOAP',
	gm.nullify_empty_string('0.5')::numeric,
	'%(+ALOE VERA 1'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORAL 0.5 (BIOSCIENCES)'
);

-- line #8964
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NESTOLEN-S 20 (Nestor)',
	'Cetrimide',
	'SOL',
	gm.nullify_empty_string('20')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NESTOLEN-S 20 (Nestor)'
);

-- line #8965
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETROLIX 0.25 (Intas)',
	'CETRORELIX ACETATE',
	'INJ',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETROLIX 0.25 (Intas)'
);

-- line #8966
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,25', u'strength_2': u'', u'substance': u'CETRORELIX ACETATE', u'always_empty': u'', u'form': u'', u'brand': u'CETROLIX-PFS', u'strength_3': u'', u'company': u'Intas', u'unit': u'mg'}

-- line #8967
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CISCURE 0.25 (Emcure)',
	'CETRORELIX ACETATE',
	'INJ',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CISCURE 0.25 (Emcure)'
);

-- line #8968
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OVUCET 0.25 (German R.)',
	'CETRORELIX ACETATE',
	'INJ',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OVUCET 0.25 (German R.)'
);

-- line #8969
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OVURELIX 0.25 (SUN)',
	'CETRORELIX ACETATE',
	'INJ',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OVURELIX 0.25 (SUN)'
);

-- line #8970
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETAPHIL MOIST 2 (Galderma)',
	'Cetyl Alcohol',
	'CRM',
	gm.nullify_empty_string('2')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETAPHIL MOIST 2 (Galderma)'
);

-- line #8971
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETAPHIL MOIST 0.04 (Galderma)',
	'Cetyl Alcohol',
	'LOT',
	gm.nullify_empty_string('0.04')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETAPHIL MOIST 0.04 (Galderma)'
);

-- line #8972
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Cetyl Alcohol', u'always_empty': u'', u'form': u'CRM', u'brand': u'MOIZ MM', u'strength_3': u'', u'company': u'GLOWDERMA', u'unit': u''}

-- line #8973
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KOLQ 1.4 (Blue Cross)',
	'CETYLPYRIDINIUM',
	'LOZENGES',
	gm.nullify_empty_string('1.4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KOLQ 1.4 (Blue Cross)'
);

-- line #8974
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELKERAN 2 (CELON(VIVILON))',
	'Chlorambucil',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'5'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELKERAN 2 (CELON(VIVILON))'
);

-- line #8975
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHLOZ 2 (Intas)',
	'Chlorambucil',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHLOZ 2 (Intas)'
);

-- line #8976
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHLOZ 5 (Intas)',
	'Chlorambucil',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHLOZ 5 (Intas)'
);

-- line #8977
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEUKERAN 2 (Gsk)',
	'Chlorambucil',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEUKERAN 2 (Gsk)'
);

-- line #8978
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEUKERAN 5 (Gsk)',
	'Chlorambucil',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEUKERAN 5 (Gsk)'
);

-- line #8979
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AGLOMYCETIN 250 (Aglowmed)',
	'Chloramphenicol',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AGLOMYCETIN 250 (Aglowmed)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AGLOMYCETIN 500 (Aglowmed)',
	'Chloramphenicol',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AGLOMYCETIN 500 (Aglowmed)'
);

-- line #8980
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AGLOMYCETIN 125 (Aglowmed)',
	'Chloramphenicol',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AGLOMYCETIN 125 (Aglowmed)'
);

-- line #8981
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AGLOWMYCETIN 250 (Aglowmed)',
	'Chloramphenicol',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AGLOWMYCETIN 250 (Aglowmed)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AGLOWMYCETIN 500 (Aglowmed)',
	'Chloramphenicol',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AGLOWMYCETIN 500 (Aglowmed)'
);

-- line #8982
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBUMYCETIN 0.4 (Indus)',
	'Chloramphenicol',
	'EYE DPS',
	gm.nullify_empty_string('0.4')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBUMYCETIN 0.4 (Indus)'
);

-- line #8983
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'PALMITATE', u'strength_2': u'', u'substance': u'Chloramphenicol', u'always_empty': u'', u'form': u'SUS', u'brand': u'ALCOL', u'strength_3': u'', u'company': u'SANCHEZ LAB.', u'unit': u''}

-- line #8984
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMPHEN 125 (Leben)',
	'Chloramphenicol',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMPHEN 125 (Leben)'
);

-- line #8985
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANDRECIN 1 (Intas)',
	'Chloramphenicol',
	'DPS',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANDRECIN 1 (Intas)'
);

-- line #8986
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANDRECIN 1 (Intas)',
	'Chloramphenicol',
	'OINT',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANDRECIN 1 (Intas)'
);

-- line #8987
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Chloramphenicol', u'always_empty': u'', u'form': u'EYE DPS', u'brand': u'BECHLORPHEN', u'strength_3': u'', u'company': u'Brooks Ph.', u'unit': u''}

-- line #8988
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G(SOD. SUCC.)', u'strength_2': u'', u'substance': u'Chloramphenicol', u'always_empty': u'', u'form': u'INJ', u'brand': u'BIOPHENICOL', u'strength_3': u'', u'company': u'Biochem', u'unit': u''}

-- line #8989
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAFCOL 500 (Dynamic)',
	'Chloramphenicol',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAFCOL 500 (Dynamic)'
);

-- line #8990
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAREMYCIN 250 (Olcare)',
	'Chloramphenicol',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAREMYCIN 250 (Olcare)'
);

-- line #8991
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAREMYCIN 500 (Olcare)',
	'Chloramphenicol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAREMYCIN 500 (Olcare)'
);

-- line #8992
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHEMOCETIN 125 (Chemo D.)',
	'Chloramphenicol',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHEMOCETIN 125 (Chemo D.)'
);

-- line #8993
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHLORAMPHENICOL 125 (Sanofi Aventis)',
	'Chloramphenicol',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHLORAMPHENICOL 125 (Sanofi Aventis)'
);

-- line #8994
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Chloramphenicol', u'always_empty': u'', u'form': u'V', u'brand': u'CHLORAMPHENICOL', u'strength_3': u'', u'company': u'HETERO HC.', u'unit': u''}

-- line #8995
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHLORAXIN 250 (Cipla)',
	'Chloramphenicol',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHLORAXIN 250 (Cipla)'
);

-- line #8996
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHLORAXIN 500 (Cipla)',
	'Chloramphenicol',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHLORAXIN 500 (Cipla)'
);

-- line #8997
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHLORMET 1 (Sun)',
	'Chloramphenicol',
	'DPS',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHLORMET 1 (Sun)'
);

-- line #8998
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHLOROCIN 250 (Jagsonpal)',
	'Chloramphenicol',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHLOROCIN 250 (Jagsonpal)'
);

-- line #8999
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHLOROCIN 500 (Jagsonpal)',
	'Chloramphenicol',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHLOROCIN 500 (Jagsonpal)'
);

-- line #9000
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHLOROCIN 125 (Jagsonpal)',
	'Chloramphenicol',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHLOROCIN 125 (Jagsonpal)'
);

-- line #9001
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHLOROCOL 1 (Jawa Ph.)',
	'Chloramphenicol',
	'EYE OINT',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHLOROCOL 1 (Jawa Ph.)'
);

-- line #9002
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHLOROKEM 500 (CHEMO HC.)',
	'Chloramphenicol',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHLOROKEM 500 (CHEMO HC.)'
);

-- line #9003
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHLOROKEM 250 (CHEMO HC.)',
	'Chloramphenicol',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHLOROKEM 250 (CHEMO HC.)'
);

-- line #9004
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHLOROMYCETIN 1 (Pfizer)',
	'Chloramphenicol',
	'APLICAPS',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHLOROMYCETIN 1 (Pfizer)'
);

-- line #9005
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHLOROMYCETIN 250 (Pfizer)',
	'Chloramphenicol',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHLOROMYCETIN 250 (Pfizer)'
);

-- line #9006
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHLOROMYCETIN 500 (Pfizer)',
	'Chloramphenicol',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHLOROMYCETIN 500 (Pfizer)'
);

-- line #9007
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHLOROMYCETIN 1 (Pfizer)',
	'Chloramphenicol',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHLOROMYCETIN 1 (Pfizer)'
);

-- line #9008
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHLOROMYCETIN KAPSEALS 250 (Pfizer)',
	'Chloramphenicol',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHLOROMYCETIN KAPSEALS 250 (Pfizer)'
);

-- line #9009
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHLOROMYCETIN PALMITATE 125 (Pfizer)',
	'Chloramphenicol',
	'SUSP',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHLOROMYCETIN PALMITATE 125 (Pfizer)'
);

-- line #9010
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'V.', u'substance': u'Chloramphenicol', u'always_empty': u'', u'form': u'INJ', u'brand': u'CHLOROMYCETIN SUCC', u'strength_3': u'', u'company': u'Pfizer', u'unit': u''}

-- line #9011
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHLOROMYCETIN 125 (Pfizer)',
	'Chloramphenicol',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHLOROMYCETIN 125 (Pfizer)'
);

-- line #9012
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHLOROMYCETIN 10 (Pfizer)',
	'Chloramphenicol',
	'TOPICAL',
	gm.nullify_empty_string('10')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHLOROMYCETIN 10 (Pfizer)'
);

-- line #9013
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G(SS)', u'strength_2': u'', u'substance': u'Chloramphenicol', u'always_empty': u'', u'form': u'INJ', u'brand': u'CHLORO-SS', u'strength_3': u'', u'company': u'HETERO HC.', u'unit': u''}

-- line #9014
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Chloramphenicol', u'always_empty': u'', u'form': u'DPS', u'brand': u'CHLOROTIN', u'strength_3': u'', u'company': u'Sterfil', u'unit': u''}

-- line #9015
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CINCOL 0.5 (Biocin Hc.)',
	'Chloramphenicol',
	'EYE DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CINCOL 0.5 (Biocin Hc.)'
);

-- line #9016
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COL 250 (Mamta Ph.)',
	'Chloramphenicol',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COL 250 (Mamta Ph.)'
);

-- line #9017
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CURAMYCIN 1000 (Csc Ph.)',
	'Chloramphenicol',
	'VIAL',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CURAMYCIN 1000 (Csc Ph.)'
);

-- line #9018
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DACLOR 250 (Dwd)',
	'Chloramphenicol',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DACLOR 250 (Dwd)'
);

-- line #9019
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DACLOR 500 (Dwd)',
	'Chloramphenicol',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DACLOR 500 (Dwd)'
);

-- line #9020
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECOL 125 (Alde Medi.)',
	'Chloramphenicol',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECOL 125 (Alde Medi.)'
);

-- line #9021
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Chloramphenicol', u'always_empty': u'', u'form': u'DROPS', u'brand': u'DIVICOL EYE', u'strength_3': u'', u'company': u'DIVINE LAB.', u'unit': u''}

-- line #9022
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENCLOR 250 (Mcneil & ARGUS)',
	'Chloramphenicol',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENCLOR 250 (Mcneil & ARGUS)'
);

-- line #9023
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENTEROMYCETIN 250 (Dey''S)',
	'Chloramphenicol',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENTEROMYCETIN 250 (Dey''S)'
);

-- line #9024
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENTEROMYCETIN 500 (Dey''S)',
	'Chloramphenicol',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENTEROMYCETIN 500 (Dey''S)'
);

-- line #9025
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENTEROMYCETINE-E 0.5 (Dey''S)',
	'Chloramphenicol',
	'DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENTEROMYCETINE-E 0.5 (Dey''S)'
);

-- line #9026
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENTEROMYCETIN IM 125 (Dey''S)',
	'Chloramphenicol',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENTEROMYCETIN IM 125 (Dey''S)'
);

-- line #9027
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENTEROMYCETIN 1 (Dey''S)',
	'Chloramphenicol',
	'OINT',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENTEROMYCETIN 1 (Dey''S)'
);

-- line #9028
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENTEROMYCETIN 125 (Dey''S)',
	'Chloramphenicol',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENTEROMYCETIN 125 (Dey''S)'
);

-- line #9029
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERAMYCET 250 (Fairdeal Res.)',
	'Chloramphenicol',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERAMYCET 250 (Fairdeal Res.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERAMYCET 500 (Fairdeal Res.)',
	'Chloramphenicol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERAMYCET 500 (Fairdeal Res.)'
);

-- line #9030
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FENCOL 250 (Ind-Swift)',
	'Chloramphenicol',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FENCOL 250 (Ind-Swift)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FENCOL 500 (Ind-Swift)',
	'Chloramphenicol',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FENCOL 500 (Ind-Swift)'
);

-- line #9031
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FENCOL 125 (Ind-Swift)',
	'Chloramphenicol',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FENCOL 125 (Ind-Swift)'
);

-- line #9032
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEMICETINE 250 (Mac)',
	'Chloramphenicol',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEMICETINE 250 (Mac)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEMICETINE 500 (Mac)',
	'Chloramphenicol',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEMICETINE 500 (Mac)'
);

-- line #9033
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEMICETINE 0.5 (Mac)',
	'Chloramphenicol',
	'DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEMICETINE 0.5 (Mac)'
);

-- line #9034
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Chloramphenicol', u'always_empty': u'', u'form': u'INJ', u'brand': u'KEMICETINE', u'strength_3': u'', u'company': u'Mac', u'unit': u''}

-- line #9035
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEMICETINE 1 (Mac)',
	'Chloramphenicol',
	'OINT',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEMICETINE 1 (Mac)'
);

-- line #9036
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1', u'strength_2': u'', u'substance': u'Chloramphenicol', u'always_empty': u'', u'form': u'', u'brand': u'KEMICETINE OTOLOGICAL %', u'strength_3': u'', u'company': u'Mac', u'unit': u'%(10'}

-- line #9037
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u' mg/ML)', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5', u'strength_2': u'', u'substance': u'Chloramphenicol', u'always_empty': u'', u'form': u'', u'brand': u'KEMICETINE OTOLOGICAL %', u'strength_3': u'', u'company': u'Mac', u'unit': u'%(50'}

-- line #9038
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEMICETINE PAL 125 (Mac)',
	'Chloramphenicol',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEMICETINE PAL 125 (Mac)'
);

-- line #9039
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEMICETINE 500 (Mac)',
	'Chloramphenicol',
	'VAG SUPPOS',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEMICETINE 500 (Mac)'
);

-- line #9040
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KOPHENICOL 125 (Kosha Lab.)',
	'Chloramphenicol',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KOPHENICOL 125 (Kosha Lab.)'
);

-- line #9041
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LARMYCETIN 250 (Lark Labs)',
	'Chloramphenicol',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LARMYCETIN 250 (Lark Labs)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LARMYCETIN 500 (Lark Labs)',
	'Chloramphenicol',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LARMYCETIN 500 (Lark Labs)'
);

-- line #9042
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LARMYCETIN 125 (Lark Labs)',
	'Chloramphenicol',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LARMYCETIN 125 (Lark Labs)'
);

-- line #9043
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYKACETIN 250 (HETERO HC.)',
	'Chloramphenicol',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYKACETIN 250 (HETERO HC.)'
);

-- line #9044
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYKACETIN 125 (HETERO HC.)',
	'Chloramphenicol',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYKACETIN 125 (HETERO HC.)'
);

-- line #9045
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Chloramphenicol', u'always_empty': u'', u'form': u'EYE DPS', u'brand': u'MIXIT', u'strength_3': u'', u'company': u'Brooks Ph.', u'unit': u''}

-- line #9046
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCOL 0.5 (Ophthal R.)',
	'Chloramphenicol',
	'EYE DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCOL 0.5 (Ophthal R.)'
);

-- line #9047
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCUCHLOR 0.5 (Elder)',
	'Chloramphenicol',
	'EYE DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCUCHLOR 0.5 (Elder)'
);

-- line #9048
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCULOR 0.4 (Parenteral)',
	'Chloramphenicol',
	'DPS',
	gm.nullify_empty_string('0.4')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCULOR 0.4 (Parenteral)'
);

-- line #9049
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPTICON 0.5 (Indiana O.)',
	'Chloramphenicol',
	'EYE DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPTICON 0.5 (Indiana O.)'
);

-- line #9050
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPTRON 1 (Indiana O.)',
	'Chloramphenicol',
	'EYE OINT',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPTRON 1 (Indiana O.)'
);

-- line #9051
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARAXIN 250 (Nicholas)',
	'Chloramphenicol',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARAXIN 250 (Nicholas)'
);

-- line #9052
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARAXIN 500 (Nicholas)',
	'Chloramphenicol',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARAXIN 500 (Nicholas)'
);

-- line #9053
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARAXIN 4 (Nicholas)',
	'Chloramphenicol',
	'DPS/OINT',
	gm.nullify_empty_string('4')::numeric,
	'%/1'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARAXIN 4 (Nicholas)'
);

-- line #9054
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250', u'strength_2': u'', u'substance': u'Chloramphenicol', u'always_empty': u'', u'form': u'', u'brand': u'PARAXIN DRA', u'strength_3': u'', u'company': u'Nicholas', u'unit': u'mg'}

-- line #9055
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Chloramphenicol', u'always_empty': u'', u'form': u'INJ', u'brand': u'PARAXIN', u'strength_3': u'', u'company': u'Nicholas', u'unit': u''}

-- line #9056
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Chloramphenicol', u'always_empty': u'', u'form': u'INJ', u'brand': u'PARAXIN', u'strength_3': u'', u'company': u'Piramal Hc.', u'unit': u''}

-- line #9057
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARAXIN PALMITATE 125 (Nicholas)',
	'Chloramphenicol',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML(PALMITATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARAXIN PALMITATE 125 (Nicholas)'
);

-- line #9058
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1,1', u'strength_2': u'', u'substance': u'Chloramphenicol', u'always_empty': u'', u'form': u'', u'brand': u'PARAXIN SOFTICAPS', u'strength_3': u'', u'company': u'Nicholas', u'unit': u'%'}

-- line #9059
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARAXIN 125 (Piramal Hc.)',
	'Chloramphenicol',
	'SUSP',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARAXIN 125 (Piramal Hc.)'
);

-- line #9060
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARAXIN 250 (Piramal Hc.)',
	'Chloramphenicol',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARAXIN 250 (Piramal Hc.)'
);

-- line #9061
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHENIC-1 1 (Dynamic)',
	'Chloramphenicol',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'mg/V.'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHENIC-1 1 (Dynamic)'
);

-- line #9062
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHENIMYCIN SUCCINATE 250 (P C INDIA)',
	'Chloramphenicol',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHENIMYCIN SUCCINATE 250 (P C INDIA)'
);

-- line #9063
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHENIMYCIN SUCCINATE 500 (P C INDIA)',
	'Chloramphenicol',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHENIMYCIN SUCCINATE 500 (P C INDIA)'
);

-- line #9064
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Chloramphenicol', u'always_empty': u'', u'form': u'V', u'brand': u'PHENIMYCIN SUCCINATE', u'strength_3': u'', u'company': u'P C INDIA', u'unit': u''}

-- line #9065
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RECLOR 250 (Nicholas)',
	'Chloramphenicol',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RECLOR 250 (Nicholas)'
);

-- line #9066
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RECLOR 500 (Nicholas)',
	'Chloramphenicol',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RECLOR 500 (Nicholas)'
);

-- line #9067
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELICHLOR 250 (Reliance)',
	'Chloramphenicol',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELICHLOR 250 (Reliance)'
);

-- line #9068
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELICHLOR 500 (Reliance)',
	'Chloramphenicol',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELICHLOR 500 (Reliance)'
);

-- line #9069
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANXIBRIUM 10 (Theo Ph.)',
	'Chlordiazepoxide',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANXIBRIUM 10 (Theo Ph.)'
);

-- line #9070
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANXIBRIUM 25 (Theo Ph.)',
	'Chlordiazepoxide',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANXIBRIUM 25 (Theo Ph.)'
);

-- line #9071
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANXIZIDE 10 (Pil)',
	'Chlordiazepoxide',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANXIZIDE 10 (Pil)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANXIZIDE 20 (Pil)',
	'Chlordiazepoxide',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANXIZIDE 20 (Pil)'
);

-- line #9072
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEBRUM 25 (PSYCOREM)',
	'Chlordiazepoxide',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEBRUM 25 (PSYCOREM)'
);

-- line #9073
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEBRUM 5 (PSYCOREM)',
	'Chlordiazepoxide',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEBRUM 5 (PSYCOREM)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEBRUM 10 (PSYCOREM)',
	'Chlordiazepoxide',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEBRUM 10 (PSYCOREM)'
);

-- line #9074
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOXIDE 10 (LA PHARMA)',
	'Chlordiazepoxide',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOXIDE 10 (LA PHARMA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOXIDE 25 (LA PHARMA)',
	'Chlordiazepoxide',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOXIDE 25 (LA PHARMA)'
);

-- line #9075
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIBRIUM 10 (Mano)',
	'Chlordiazepoxide',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIBRIUM 10 (Mano)'
);

-- line #9076
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIBRIUM 25 (Mano)',
	'Chlordiazepoxide',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIBRIUM 25 (Mano)'
);

-- line #9077
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EBRIUM 10 (EAST WEST)',
	'Chlordiazepoxide',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EBRIUM 10 (EAST WEST)'
);

-- line #9078
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EBRIUM 25 (EAST WEST)',
	'Chlordiazepoxide',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EBRIUM 25 (EAST WEST)'
);

-- line #9079
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EQUILIBRIUM 10 (Jagsonpal)',
	'Chlordiazepoxide',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EQUILIBRIUM 10 (Jagsonpal)'
);

-- line #9080
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIB-CT 10 (EAST WEST)',
	'Chlordiazepoxide',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIB-CT 10 (EAST WEST)'
);

-- line #9081
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIBREL 10 (Synokem)',
	'Chlordiazepoxide',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIBREL 10 (Synokem)'
);

-- line #9082
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIBRIUM 10 (Piramal Hc.)',
	'Chlordiazepoxide',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIBRIUM 10 (Piramal Hc.)'
);

-- line #9083
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIBRIUM 25 (Piramal Hc.)',
	'Chlordiazepoxide',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIBRIUM 25 (Piramal Hc.)'
);

-- line #9084
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POXID 10 (Mano)',
	'Chlordiazepoxide',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg/25'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POXID 10 (Mano)'
);

-- line #9085
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,5', u'strength_2': u'', u'substance': u'Chlorhexidine Acetate', u'always_empty': u'', u'form': u'', u'brand': u'BACTIGRAS CM*10CM', u'strength_3': u'', u'company': u'Smith+N.', u'unit': u'%'}

-- line #9086
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Chlorhexidine', u'always_empty': u'', u'form': u'SOAP', u'brand': u'D-FENCE', u'strength_3': u'', u'company': u'Dial Ph.', u'unit': u''}

-- line #9087
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLASEPT 1 (Galderma)',
	'Chlorhexidine',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLASEPT 1 (Galderma)'
);

-- line #9088
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AFRESHO 2 (Zee Lab)',
	'Chlorhexidine Gluconate',
	'MOUTH WASH',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AFRESHO 2 (Zee Lab)'
);

-- line #9089
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHLORHEXIDINE 20 (Nicholas)',
	'Chlorhexidine Gluconate',
	'SOL',
	gm.nullify_empty_string('20')::numeric,
	'%V/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHLORHEXIDINE 20 (Nicholas)'
);

-- line #9090
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOHEX 0.2 (Dr.Reddy''S)',
	'Chlorhexidine Gluconate',
	'MOUTH WASH',
	gm.nullify_empty_string('0.2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOHEX 0.2 (Dr.Reddy''S)'
);

-- line #9091
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CMW 0.2 (Zydus Cadila)',
	'Chlorhexidine Gluconate',
	'LIQ',
	gm.nullify_empty_string('0.2')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CMW 0.2 (Zydus Cadila)'
);

-- line #9092
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COOL CAD 0.2 (HAMPS BIO)',
	'Chlorhexidine Gluconate',
	'MOUTH WASH',
	gm.nullify_empty_string('0.2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COOL CAD 0.2 (HAMPS BIO)'
);

-- line #9093
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DENTRA 0.2 (Intra Lab)',
	'Chlorhexidine Gluconate',
	'GUM PAINT',
	gm.nullify_empty_string('0.2')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DENTRA 0.2 (Intra Lab)'
);

-- line #9094
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEVLONE 1 (Mahavir Ent.)',
	'Chlorhexidine Gluconate',
	'SOAP',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEVLONE 1 (Mahavir Ent.)'
);

-- line #9095
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,004', u'strength_2': u'', u'substance': u'Chlorhexidine Gluconate', u'always_empty': u'', u'form': u'', u'brand': u'ELGYDIUM ANTI PLAQUE TOOTHPASTE', u'strength_3': u'', u'company': u'Win-Medicare', u'unit': u'%W/W'}

-- line #9096
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,004', u'strength_2': u'', u'substance': u'Chlorhexidine Gluconate', u'always_empty': u'', u'form': u'', u'brand': u'ELGYDIUM SENSITIVE TOOTHPASTE', u'strength_3': u'', u'company': u'Win-Medicare', u'unit': u'%W/W'}

-- line #9097
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELUDRIL 0.1 (Win-Medicare)',
	'Chlorhexidine Gluconate',
	'MOUTH WASH',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELUDRIL 0.1 (Win-Medicare)'
);

-- line #9098
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,2', u'strength_2': u'', u'substance': u'Chlorhexidine Gluconate', u'always_empty': u'', u'form': u'', u'brand': u'ELUGEL', u'strength_3': u'', u'company': u'Win-Medicare', u'unit': u'%W/W'}

-- line #9099
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GARGYLE 0.2 (SALVO HC.)',
	'Chlorhexidine Gluconate',
	'SOL',
	gm.nullify_empty_string('0.2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GARGYLE 0.2 (SALVO HC.)'
);

-- line #9100
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYCOSEPTOL 0.2 (Jupiter Ph.)',
	'Chlorhexidine Gluconate',
	'LIQ',
	gm.nullify_empty_string('0.2')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYCOSEPTOL 0.2 (Jupiter Ph.)'
);

-- line #9101
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,2', u'strength_2': u'', u'substance': u'Chlorhexidine Gluconate', u'always_empty': u'', u'form': u'', u'brand': u'HEXCOR', u'strength_3': u'', u'company': u'Corona', u'unit': u'%'}

-- line #9102
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEXEEDONE 0.2 (Gujarat Ph.)',
	'Chlorhexidine Gluconate',
	'MOUTH WASH',
	gm.nullify_empty_string('0.2')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEXEEDONE 0.2 (Gujarat Ph.)'
);

-- line #9103
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEXIDE 2 (Dey''S)',
	'Chlorhexidine Gluconate',
	'LIQ',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEXIDE 2 (Dey''S)'
);

-- line #9104
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEXIDINE 0.2 (Icpa)',
	'Chlorhexidine Gluconate',
	'MOUTH WASH',
	gm.nullify_empty_string('0.2')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEXIDINE 0.2 (Icpa)'
);

-- line #9105
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEXID 0.2 (Taurus Lab)',
	'Chlorhexidine Gluconate',
	'MOUTH WASH',
	gm.nullify_empty_string('0.2')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEXID 0.2 (Taurus Lab)'
);

-- line #9106
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEXIPLUS 0.2 (Mdc Ph.)',
	'Chlorhexidine Gluconate',
	'MOUTH WASH',
	gm.nullify_empty_string('0.2')::numeric,
	'%W/V(+2'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEXIPLUS 0.2 (Mdc Ph.)'
);

-- line #9107
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEXY-MW 0.2 (Chem+Med)',
	'Chlorhexidine Gluconate',
	'MOUTH WASH',
	gm.nullify_empty_string('0.2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEXY-MW 0.2 (Chem+Med)'
);

-- line #9108
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYGEEN 2 (ETHIX HC.)',
	'Chlorhexidine Gluconate',
	'MOUTH WASH',
	gm.nullify_empty_string('2')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYGEEN 2 (ETHIX HC.)'
);

-- line #9109
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYGINA 0.2 (Hygeia Ph.)',
	'Chlorhexidine Gluconate',
	'GARGLE',
	gm.nullify_empty_string('0.2')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYGINA 0.2 (Hygeia Ph.)'
);

-- line #9110
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYMAX 0.2 (Vasphar)',
	'Chlorhexidine Gluconate',
	'MOUTH WASH',
	gm.nullify_empty_string('0.2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYMAX 0.2 (Vasphar)'
);

-- line #9111
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Chlorhexidine Gluconate', u'always_empty': u'', u'form': u'MOUTH WASH', u'brand': u'KLOBIT', u'strength_3': u'', u'company': u'AXYZEN LIFE', u'unit': u''}

-- line #9112
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEFRESH 0.2 (Lexus)',
	'Chlorhexidine Gluconate',
	'MOUTH WASH',
	gm.nullify_empty_string('0.2')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEFRESH 0.2 (Lexus)'
);

-- line #9113
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAGHEX 0.2 (Magnus Bio.)',
	'Chlorhexidine Gluconate',
	'MOUTHWASH',
	gm.nullify_empty_string('0.2')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAGHEX 0.2 (Magnus Bio.)'
);

-- line #9114
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICROSHIELD 2 (J.&J.)',
	'Chlorhexidine Gluconate',
	'SOL %',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICROSHIELD 2 (J.&J.)'
);

-- line #9115
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICROSHIELD 20 (J.&J.)',
	'Chlorhexidine Gluconate',
	'SOL %',
	gm.nullify_empty_string('20')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICROSHIELD 20 (J.&J.)'
);

-- line #9116
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICROSHIELD 4 (J.&J.)',
	'Chlorhexidine Gluconate',
	'SOL %',
	gm.nullify_empty_string('4')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICROSHIELD 4 (J.&J.)'
);

-- line #9117
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICROSHIELD 5 (J.&J.)',
	'Chlorhexidine Gluconate',
	'SOL %',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICROSHIELD 5 (J.&J.)'
);

-- line #9118
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITRA HEX 0.25 (Eros Ph.)',
	'Chlorhexidine Gluconate',
	'LIQ',
	gm.nullify_empty_string('0.25')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITRA HEX 0.25 (Eros Ph.)'
);

-- line #9119
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'O2 FRESH 0.2 (GENESIS)',
	'Chlorhexidine Gluconate',
	'MOUTH WASH',
	gm.nullify_empty_string('0.2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'O2 FRESH 0.2 (GENESIS)'
);

-- line #9120
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLSEPT MW 0.2 (Olcare)',
	'Chlorhexidine Gluconate',
	'SOL',
	gm.nullify_empty_string('0.2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLSEPT MW 0.2 (Olcare)'
);

-- line #9121
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORAHEX 0.2 (Nicholas)',
	'Chlorhexidine Gluconate',
	'ORAL RINSE',
	gm.nullify_empty_string('0.2')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORAHEX 0.2 (Nicholas)'
);

-- line #9122
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Chlorhexidine Gluconate', u'always_empty': u'', u'form': u'SOL', u'brand': u'ORHEX-G', u'strength_3': u'', u'company': u'GENESIS ORG.', u'unit': u''}

-- line #9123
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORINSE 0.2 (Centaur)',
	'Chlorhexidine Gluconate',
	'MOUTHWASH',
	gm.nullify_empty_string('0.2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORINSE 0.2 (Centaur)'
);

-- line #9124
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OROBA 0.2 (Ravian)',
	'Chlorhexidine Gluconate',
	'MOUTH WASH',
	gm.nullify_empty_string('0.2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OROBA 0.2 (Ravian)'
);

-- line #9125
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Chlorhexidine Gluconate', u'always_empty': u'', u'form': u'LIQ', u'brand': u'OROFRESH', u'strength_3': u'', u'company': u'Synapse', u'unit': u''}

-- line #9126
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEARLCARE 1 (Pharma synth)',
	'Chlorhexidine Gluconate',
	'MOUTH WASH',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEARLCARE 1 (Pharma synth)'
);

-- line #9127
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERIEX 0.2 (DENT-AIDS)',
	'Chlorhexidine Gluconate',
	'SOL',
	gm.nullify_empty_string('0.2')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERIEX 0.2 (DENT-AIDS)'
);

-- line #9128
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Chlorhexidine Gluconate', u'always_empty': u'', u'form': u'', u'brand': u'REFRESH-M WASH', u'strength_3': u'', u'company': u'Meridian', u'unit': u''}

-- line #9129
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REXIDIN 0.2 (Warren)',
	'Chlorhexidine Gluconate',
	'MOUTHWASH',
	gm.nullify_empty_string('0.2')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REXIDIN 0.2 (Warren)'
);

-- line #9130
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RINZIN 0.2 (MED MANOR)',
	'Chlorhexidine Gluconate',
	'MOUTH WASH',
	gm.nullify_empty_string('0.2')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RINZIN 0.2 (MED MANOR)'
);

-- line #9131
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,2', u'strength_2': u'', u'substance': u'Chlorhexidine', u'always_empty': u'', u'form': u'', u'brand': u'HEXIDINE-M WASH', u'strength_3': u'', u'company': u'Icpa', u'unit': u'%W/V'}

-- line #9132
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1', u'strength_2': u'', u'substance': u'Chlorhexidine', u'always_empty': u'', u'form': u'', u'brand': u'HEXIGEL DNT-GEL', u'strength_3': u'', u'company': u'Icpa', u'unit': u'%W/W'}

-- line #9133
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEXIPREP 0.4 (Icpa)',
	'Chlorhexidine',
	'SOLN',
	gm.nullify_empty_string('0.4')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEXIPREP 0.4 (Icpa)'
);

-- line #9134
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORAGINE 5 (Dr.Reddy''S)',
	'Chlorhexidine',
	'GEL',
	gm.nullify_empty_string('5')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORAGINE 5 (Dr.Reddy''S)'
);

-- line #9135
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,2', u'strength_2': u'', u'substance': u'Chlorhexidine', u'always_empty': u'', u'form': u'', u'brand': u'OSIHEX-M WASH', u'strength_3': u'', u'company': u'Osper', u'unit': u'%'}

-- line #9136
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,2', u'strength_2': u'', u'substance': u'Chlorhexidine', u'always_empty': u'', u'form': u'', u'brand': u'PENDIN M-WASH', u'strength_3': u'', u'company': u'VENSAT', u'unit': u'%(0.2'}

-- line #9137
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHLOROQUINE 40 (Cadila (GENSTAR))',
	'Chloroquine',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHLOROQUINE 40 (Cadila (GENSTAR))'
);

-- line #9138
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOQUIN 250 (Indoco Rem.)',
	'Chloroquine',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOQUIN 250 (Indoco Rem.)'
);

-- line #9139
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALIGON 250 (UNIJULES)',
	'Chloroquine',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALIGON 250 (UNIJULES)'
);

-- line #9140
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALIGON 100 (Un.MEDIKIT)',
	'Chloroquine',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALIGON 100 (Un.MEDIKIT)'
);

-- line #9141
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALIGON 250 (Un.MEDIKIT)',
	'Chloroquine',
	'SUS',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALIGON 250 (Un.MEDIKIT)'
);

-- line #9142
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIVAQUINE 40 (Piramal Hc.)',
	'Chloroquine',
	'AMP',
	gm.nullify_empty_string('40')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIVAQUINE 40 (Piramal Hc.)'
);

-- line #9143
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIVAQUINE-P 50 (Piramal Hc.)',
	'Chloroquine',
	'SUSP',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIVAQUINE-P 50 (Piramal Hc.)'
);

-- line #9144
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIVAQUINE-P 250 (Piramal Hc.)',
	'Chloroquine',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIVAQUINE-P 250 (Piramal Hc.)'
);

-- line #9145
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOQUIN 500 (Brown & B.)',
	'Chloroquine Phosphate',
	'DS TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOQUIN 500 (Brown & B.)'
);

-- line #9146
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOQUIN 250 (Brown & B.)',
	'Chloroquine Phosphate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOQUIN 250 (Brown & B.)'
);

-- line #9147
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BITAQUIN 40 (Bombay T.)',
	'Chloroquine Phosphate',
	'AMP/V',
	gm.nullify_empty_string('40')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BITAQUIN 40 (Bombay T.)'
);

-- line #9148
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BITAQUIN 50 (Bombay T.)',
	'Chloroquine Phosphate',
	'DPS',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BITAQUIN 50 (Bombay T.)'
);

-- line #9149
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BITAQUIN 500 (Bombay T.)',
	'Chloroquine Phosphate',
	'DS TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BITAQUIN 500 (Bombay T.)'
);

-- line #9150
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BITAQUIN 160 (Bombay T.)',
	'Chloroquine Phosphate',
	'SYR',
	gm.nullify_empty_string('160')::numeric,
	'mg/10ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BITAQUIN 160 (Bombay T.)'
);

-- line #9151
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BITAQUIN 250 (Bombay T.)',
	'Chloroquine Phosphate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BITAQUIN 250 (Bombay T.)'
);

-- line #9152
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOKIT JUN 750 (Indoco Rem.)',
	'Chloroquine Phosphate',
	'KIT',
	gm.nullify_empty_string('750')::numeric,
	'mg(PINK T.) & 375'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOKIT JUN 750 (Indoco Rem.)'
);

-- line #9153
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOKIT 1000 (Indoco Rem.)',
	'Chloroquine Phosphate',
	'KIT',
	gm.nullify_empty_string('1000')::numeric,
	'mg(1T) & 500'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOKIT 1000 (Indoco Rem.)'
);

-- line #9154
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOQUIN 500 (Indoco Rem.)',
	'Chloroquine Phosphate',
	'DS TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOQUIN 500 (Indoco Rem.)'
);

-- line #9155
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOQUIN INJ/ 40 (Indoco Rem.)',
	'Chloroquine Phosphate',
	'V',
	gm.nullify_empty_string('40')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOQUIN INJ/ 40 (Indoco Rem.)'
);

-- line #9156
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOQUIN 100 (Indoco Rem.)',
	'Chloroquine Phosphate',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/10ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOQUIN 100 (Indoco Rem.)'
);

-- line #9157
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-QUIN 50 (Ikon Rem)',
	'Chloroquine Phosphate',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-QUIN 50 (Ikon Rem)'
);

-- line #9158
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMQUIN 500 (Merck)',
	'Chloroquine Phosphate',
	'DS TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMQUIN 500 (Merck)'
);

-- line #9159
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMQUIN 310 (Merck)',
	'Chloroquine Phosphate',
	'DT',
	gm.nullify_empty_string('310')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMQUIN 310 (Merck)'
);

-- line #9160
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Chloroquine Phosphate', u'always_empty': u'', u'form': u'INJ', u'brand': u'EMQUIN', u'strength_3': u'', u'company': u'Merck', u'unit': u''}

-- line #9161
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMQUIN 100 (Merck)',
	'Chloroquine Phosphate',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/10ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMQUIN 100 (Merck)'
);

-- line #9162
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMQUIN 155 (Merck)',
	'Chloroquine Phosphate',
	'TAB',
	gm.nullify_empty_string('155')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMQUIN 155 (Merck)'
);

-- line #9163
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMQUIN 250 (Merck)',
	'Chloroquine Phosphate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMQUIN 250 (Merck)'
);

-- line #9164
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMQUIN 40 (Merck)',
	'Chloroquine Phosphate',
	'V',
	gm.nullify_empty_string('40')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMQUIN 40 (Merck)'
);

-- line #9165
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'E-VIVAX 40 (Themis Med.)',
	'Chloroquine Phosphate',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'E-VIVAX 40 (Themis Med.)'
);

-- line #9166
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'E-VIVAX 500 (Themis Med.)',
	'Chloroquine Phosphate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'E-VIVAX 500 (Themis Med.)'
);

-- line #9167
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FALCIN 80 (Southsourne)',
	'Chloroquine Phosphate',
	'SUS',
	gm.nullify_empty_string('80')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FALCIN 80 (Southsourne)'
);

-- line #9168
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FALCIN 250 (Southsourne)',
	'Chloroquine Phosphate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FALCIN 250 (Southsourne)'
);

-- line #9169
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FALCIN 500 (Southsourne)',
	'Chloroquine Phosphate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FALCIN 500 (Southsourne)'
);

-- line #9170
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IDIQUIN 250 (Idpl)',
	'Chloroquine Phosphate',
	'SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IDIQUIN 250 (Idpl)'
);

-- line #9171
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IDIQUIN 250 (Idpl)',
	'Chloroquine Phosphate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IDIQUIN 250 (Idpl)'
);

-- line #9172
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INGAQUIN 250 (Inga)',
	'Chloroquine Phosphate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INGAQUIN 250 (Inga)'
);

-- line #9173
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JAGQUIN 50 (Jagsonpal)',
	'Chloroquine Phosphate',
	'SYR TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JAGQUIN 50 (Jagsonpal)'
);

-- line #9174
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JAGQUIN 250 (Jagsonpal)',
	'Chloroquine Phosphate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JAGQUIN 250 (Jagsonpal)'
);

-- line #9175
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAQUIN 64.5 (Stadmed)',
	'Chloroquine Phosphate',
	'INJ',
	gm.nullify_empty_string('64.5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAQUIN 64.5 (Stadmed)'
);

-- line #9176
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAQUIN 160 (Stadmed)',
	'Chloroquine Phosphate',
	'SYR',
	gm.nullify_empty_string('160')::numeric,
	'mg/10ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAQUIN 160 (Stadmed)'
);

-- line #9177
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAQUIN 250 (Stadmed)',
	'Chloroquine Phosphate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAQUIN 250 (Stadmed)'
);

-- line #9178
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAQUIN 500 (Stadmed)',
	'Chloroquine Phosphate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAQUIN 500 (Stadmed)'
);

-- line #9179
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LARIAGO 500 (Ipca)',
	'Chloroquine Phosphate',
	'DS TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LARIAGO 500 (Ipca)'
);

-- line #9180
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LARIAGO 40 (Ipca)',
	'Chloroquine Phosphate',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LARIAGO 40 (Ipca)'
);

-- line #9181
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LARIAGO 50 (Ipca)',
	'Chloroquine Phosphate',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LARIAGO 50 (Ipca)'
);

-- line #9182
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LARIAGO 250 (Ipca)',
	'Chloroquine Phosphate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LARIAGO 250 (Ipca)'
);

-- line #9183
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAROVER 250 (Aglowmed)',
	'Chloroquine Phosphate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAROVER 250 (Aglowmed)'
);

-- line #9184
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LARQUIN 100 (Lark Lab)',
	'Chloroquine Phosphate',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/10ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LARQUIN 100 (Lark Lab)'
);

-- line #9185
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LARQUIN 250 (Lark Lab)',
	'Chloroquine Phosphate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LARQUIN 250 (Lark Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LARQUIN 500 (Lark Lab)',
	'Chloroquine Phosphate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LARQUIN 500 (Lark Lab)'
);

-- line #9186
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINCOQUIN 80 (Lincoln)',
	'Chloroquine Phosphate',
	'DPS',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINCOQUIN 80 (Lincoln)'
);

-- line #9187
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINCOQUIN 250 (Lincoln)',
	'Chloroquine Phosphate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINCOQUIN 250 (Lincoln)'
);

-- line #9188
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINCOQUIN 500 (Lincoln)',
	'Chloroquine Phosphate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINCOQUIN 500 (Lincoln)'
);

-- line #9189
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALABEST 250 (TALENT LAB.)',
	'Chloroquine Phosphate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALABEST 250 (TALENT LAB.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALABEST 500 (TALENT LAB.)',
	'Chloroquine Phosphate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALABEST 500 (TALENT LAB.)'
);

-- line #9190
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALACLOR 250 (Unicure)',
	'Chloroquine Phosphate',
	'EC TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALACLOR 250 (Unicure)'
);

-- line #9191
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALACLOR 500 (Unicure)',
	'Chloroquine Phosphate',
	'EC TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALACLOR 500 (Unicure)'
);

-- line #9192
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALACURE 80 (Patson)',
	'Chloroquine Phosphate',
	'DPS',
	gm.nullify_empty_string('80')::numeric,
	'mg/1ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALACURE 80 (Patson)'
);

-- line #9193
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALACURE 500 (Patson)',
	'Chloroquine Phosphate',
	'F. TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALACURE 500 (Patson)'
);

-- line #9194
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALACURE 160 (Patson)',
	'Chloroquine Phosphate',
	'SUS',
	gm.nullify_empty_string('160')::numeric,
	'mg/10ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALACURE 160 (Patson)'
);

-- line #9195
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALACURE 250 (Patson)',
	'Chloroquine Phosphate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALACURE 250 (Patson)'
);

-- line #9196
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALAQUIN 40 (P C INDIA)',
	'Chloroquine Phosphate',
	'AMP',
	gm.nullify_empty_string('40')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALAQUIN 40 (P C INDIA)'
);

-- line #9197
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Chloroquine Phosphate', u'always_empty': u'', u'form': u'DPS', u'brand': u'MALAQUIN', u'strength_3': u'', u'company': u'P C INDIA', u'unit': u''}

-- line #9198
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALAQUIN 80.65 (P C INDIA)',
	'Chloroquine Phosphate',
	'SUS',
	gm.nullify_empty_string('80.65')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALAQUIN 80.65 (P C INDIA)'
);

-- line #9199
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALAQUIN 100 (P C INDIA)',
	'Chloroquine Phosphate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALAQUIN 100 (P C INDIA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALAQUIN 500 (P C INDIA)',
	'Chloroquine Phosphate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALAQUIN 500 (P C INDIA)'
);

-- line #9200
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALAQUIN 40 (P C INDIA)',
	'Chloroquine Phosphate',
	'VIAL',
	gm.nullify_empty_string('40')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALAQUIN 40 (P C INDIA)'
);

-- line #9201
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALAQUIT 250 (SANCHEZ LAB.)',
	'Chloroquine Phosphate',
	'DS TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALAQUIT 250 (SANCHEZ LAB.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALAQUIT 500 (SANCHEZ LAB.)',
	'Chloroquine Phosphate',
	'DS TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALAQUIT 500 (SANCHEZ LAB.)'
);

-- line #9202
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Chloroquine Phosphate', u'always_empty': u'', u'form': u'INJ', u'brand': u'MALAQUIT', u'strength_3': u'', u'company': u'SANCHEZ LAB.', u'unit': u''}

-- line #9203
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Chloroquine Phosphate', u'always_empty': u'', u'form': u'SUS', u'brand': u'MALAQUIT', u'strength_3': u'', u'company': u'SANCHEZ LAB.', u'unit': u''}

-- line #9204
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALARBIN 80 (Acron Ph.)',
	'Chloroquine Phosphate',
	'DPS',
	gm.nullify_empty_string('80')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALARBIN 80 (Acron Ph.)'
);

-- line #9205
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALARBIN 80 (Acron Ph.)',
	'Chloroquine Phosphate',
	'SUS',
	gm.nullify_empty_string('80')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALARBIN 80 (Acron Ph.)'
);

-- line #9206
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALARBIN 250 (Acron Ph.)',
	'Chloroquine Phosphate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALARBIN 250 (Acron Ph.)'
);

-- line #9207
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALARBIN 500 (Acron Ph.)',
	'Chloroquine Phosphate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALARBIN 500 (Acron Ph.)'
);

-- line #9208
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALIAGO 250 (CIPLA)',
	'Chloroquine Phosphate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALIAGO 250 (CIPLA)'
);

-- line #9209
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALIAGO 500 (CIPLA)',
	'Chloroquine Phosphate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALIAGO 500 (CIPLA)'
);

-- line #9210
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALSWIFT 40 (Ind-Swift)',
	'Chloroquine Phosphate',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALSWIFT 40 (Ind-Swift)'
);

-- line #9211
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MATCH-Q 50 (Mankind)',
	'Chloroquine Phosphate',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MATCH-Q 50 (Mankind)'
);

-- line #9212
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MATCH-Q 250 (LIFESTAR)',
	'Chloroquine Phosphate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MATCH-Q 250 (LIFESTAR)'
);

-- line #9213
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MATCH-Q 500 (LIFESTAR)',
	'Chloroquine Phosphate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MATCH-Q 500 (LIFESTAR)'
);

-- line #9214
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELUBRIN 250 (Ranbaxy)',
	'Chloroquine Phosphate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELUBRIN 250 (Ranbaxy)'
);

-- line #9215
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOQUIN 40 (Neon)',
	'Chloroquine Phosphate',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOQUIN 40 (Neon)'
);

-- line #9216
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOQUIN 64.5 (Neon)',
	'Chloroquine Phosphate',
	'INJ',
	gm.nullify_empty_string('64.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOQUIN 64.5 (Neon)'
);

-- line #9217
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOQUIN 250 (Neon)',
	'Chloroquine Phosphate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOQUIN 250 (Neon)'
);

-- line #9218
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIVAQUIN-P 500 (Piramal Hc.)',
	'Chloroquine Phosphate',
	'F. TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIVAQUIN-P 500 (Piramal Hc.)'
);

-- line #9219
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIVAQUIN-P 40 (Piramal Hc.)',
	'Chloroquine Phosphate',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIVAQUIN-P 40 (Piramal Hc.)'
);

-- line #9220
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIVAQUIN-P 50 (Piramal Hc.)',
	'Chloroquine Phosphate',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIVAQUIN-P 50 (Piramal Hc.)'
);

-- line #9221
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIVAQUIN-P 250 (Piramal Hc.)',
	'Chloroquine Phosphate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIVAQUIN-P 250 (Piramal Hc.)'
);

-- line #9222
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIVAQUIN-P 40 (Piramal Hc.)',
	'Chloroquine Phosphate',
	'VIAL',
	gm.nullify_empty_string('40')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIVAQUIN-P 40 (Piramal Hc.)'
);

-- line #9223
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARAQUIN 500 (Shreya)',
	'Chloroquine Phosphate',
	'DS TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARAQUIN 500 (Shreya)'
);

-- line #9224
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARAQUIN 50 (Shreya)',
	'Chloroquine Phosphate',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARAQUIN 50 (Shreya)'
);

-- line #9225
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARAQUIN 40 (Shreya)',
	'Chloroquine Phosphate',
	'V',
	gm.nullify_empty_string('40')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARAQUIN 40 (Shreya)'
);

-- line #9226
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLASMOQUIN 50 (Life Line)',
	'Chloroquine Phosphate',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLASMOQUIN 50 (Life Line)'
);

-- line #9227
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLASMOQUIN 500 (Life Line)',
	'Chloroquine Phosphate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLASMOQUIN 500 (Life Line)'
);

-- line #9228
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Chloroquine Phosphate', u'always_empty': u'', u'form': u'SUS', u'brand': u'QUINAR', u'strength_3': u'', u'company': u'Rhombus', u'unit': u''}

-- line #9229
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Chloroquine Phosphate', u'always_empty': u'', u'form': u'TAB', u'brand': u'QUINAR', u'strength_3': u'', u'company': u'Rhombus', u'unit': u''}

-- line #9230
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINEX 250 (Intra Lab)',
	'Chloroquine Phosphate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINEX 250 (Intra Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINEX 500 (Intra Lab)',
	'Chloroquine Phosphate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINEX 500 (Intra Lab)'
);

-- line #9231
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINOWIN 80 (Taurus Lab)',
	'Chloroquine Phosphate',
	'SYR',
	gm.nullify_empty_string('80')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINOWIN 80 (Taurus Lab)'
);

-- line #9232
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINOWIN 250 (Taurus Lab)',
	'Chloroquine Phosphate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINOWIN 250 (Taurus Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINOWIN 500 (Taurus Lab)',
	'Chloroquine Phosphate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINOWIN 500 (Taurus Lab)'
);

-- line #9233
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINROSS 500 (Merind)',
	'Chloroquine Phosphate',
	'DS TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINROSS 500 (Merind)'
);

-- line #9234
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINROSS 64.5 (Merind)',
	'Chloroquine Phosphate',
	'INJ/V',
	gm.nullify_empty_string('64.5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINROSS 64.5 (Merind)'
);

-- line #9235
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINROSS 80 (Merind)',
	'Chloroquine Phosphate',
	'SYR',
	gm.nullify_empty_string('80')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINROSS 80 (Merind)'
);

-- line #9236
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINROSS 250 (Merind)',
	'Chloroquine Phosphate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINROSS 250 (Merind)'
);

-- line #9237
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESOCHIN 500 (Bayer)',
	'Chloroquine Phosphate',
	'DS TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESOCHIN 500 (Bayer)'
);

-- line #9238
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESOCHIN INJ/ 40 (Bayer)',
	'Chloroquine Phosphate',
	'V',
	gm.nullify_empty_string('40')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESOCHIN INJ/ 40 (Bayer)'
);

-- line #9239
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESOCHIN 100 (Bayer)',
	'Chloroquine Phosphate',
	'SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg/10ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESOCHIN 100 (Bayer)'
);

-- line #9240
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESOCHIN 250 (Bayer)',
	'Chloroquine Phosphate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESOCHIN 250 (Bayer)'
);

-- line #9241
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIMOQUIN 500 (A.F.D.)',
	'Chloroquine Phosphate',
	'DS TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIMOQUIN 500 (A.F.D.)'
);

-- line #9242
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIMOQUIN 64.5 (A.F.D.)',
	'Chloroquine Phosphate',
	'INJ',
	gm.nullify_empty_string('64.5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIMOQUIN 64.5 (A.F.D.)'
);

-- line #9243
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DETTOL ANTISEPTIC 0.8 (RECKITT B.)',
	'Chloroxylenol',
	'CRM',
	gm.nullify_empty_string('0.8')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DETTOL ANTISEPTIC 0.8 (RECKITT B.)'
);

-- line #9244
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPIAM TR 8 (Natco Ph.)',
	'Chlorpheniramine Maleate',
	'CAP',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPIAM TR 8 (Natco Ph.)'
);

-- line #9245
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CESIRAN 10 (NEON)',
	'Chlorpheniramine Maleate',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CESIRAN 10 (NEON)'
);

-- line #9246
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHLORAM 10 (P C INDIA)',
	'Chlorpheniramine Maleate',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHLORAM 10 (P C INDIA)'
);

-- line #9247
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'4', u'strength_2': u'', u'substance': u'Chlorpheniramine Maleate', u'always_empty': u'', u'form': u'', u'brand': u'CHLORPHENIRAMINE MALEATE', u'strength_3': u'', u'company': u'Shalaks', u'unit': u'mg'}

-- line #9248
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COFTON 4 (Cipla)',
	'Chlorpheniramine Maleate',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COFTON 4 (Cipla)'
);

-- line #9249
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECLOR 6 (Indilina Ph.)',
	'Chlorpheniramine Maleate',
	'SR TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECLOR 6 (Indilina Ph.)'
);

-- line #9250
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIRITON 4 (GSK)',
	'Chlorpheniramine Maleate',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIRITON 4 (GSK)'
);

-- line #9251
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAIN 25 (Neon)',
	'Chlorpromazine Hcl.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAIN 25 (Neon)'
);

-- line #9252
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAIN 100 (Neon)',
	'Chlorpromazine Hcl.',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAIN 100 (Neon)'
);

-- line #9253
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHLORPROMAZINE 2.5 (NPIL)',
	'Chlorpromazine Hcl.',
	'INJ',
	gm.nullify_empty_string('2.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHLORPROMAZINE 2.5 (NPIL)'
);

-- line #9254
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHLORPROMAZINE 2.5 (Piramal Hc.)',
	'Chlorpromazine Hcl.',
	'INJ',
	gm.nullify_empty_string('2.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHLORPROMAZINE 2.5 (Piramal Hc.)'
);

-- line #9255
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHLORPROMAZINE 100 (NPIL)',
	'Chlorpromazine Hcl.',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHLORPROMAZINE 100 (NPIL)'
);

-- line #9256
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHLORPROMAZINE 25 (NPIL)',
	'Chlorpromazine Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHLORPROMAZINE 25 (NPIL)'
);

-- line #9257
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHLORPROMAZINE 50 (NPIL)',
	'Chlorpromazine Hcl.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHLORPROMAZINE 50 (NPIL)'
);

-- line #9258
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHLORPROMAZINE 10 (Piramal Hc.)',
	'Chlorpromazine Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'25'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHLORPROMAZINE 10 (Piramal Hc.)'
);

-- line #9259
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHLORPROMAZINE 50 (Piramal Hc.)',
	'Chlorpromazine Hcl.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHLORPROMAZINE 50 (Piramal Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHLORPROMAZINE 100 (Piramal Hc.)',
	'Chlorpromazine Hcl.',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHLORPROMAZINE 100 (Piramal Hc.)'
);

-- line #9260
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHLORPROMAZINE 100 (Sun)',
	'Chlorpromazine Hcl.',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHLORPROMAZINE 100 (Sun)'
);

-- line #9261
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHLORPROMAZINE 200 (Sun)',
	'Chlorpromazine Hcl.',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHLORPROMAZINE 200 (Sun)'
);

-- line #9262
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHLORPROMAZINE 25 (Sun)',
	'Chlorpromazine Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHLORPROMAZINE 25 (Sun)'
);

-- line #9263
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHLORPROMAZINE 50 (Sun)',
	'Chlorpromazine Hcl.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHLORPROMAZINE 50 (Sun)'
);

-- line #9264
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLORUS 100 (Taurus Lab)',
	'Chlorpromazine Hcl.',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLORUS 100 (Taurus Lab)'
);

-- line #9265
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLORUS 200 (Taurus Lab)',
	'Chlorpromazine Hcl.',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLORUS 200 (Taurus Lab)'
);

-- line #9266
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLORUS 25 (Taurus Lab)',
	'Chlorpromazine Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLORUS 25 (Taurus Lab)'
);

-- line #9267
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLORUS 50 (Taurus Lab)',
	'Chlorpromazine Hcl.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLORUS 50 (Taurus Lab)'
);

-- line #9268
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOZINE 200 (OREVA DARMO.)',
	'Chlorpromazine Hcl.',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOZINE 200 (OREVA DARMO.)'
);

-- line #9269
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOZINE 50 (OREVA DARMO.)',
	'Chlorpromazine Hcl.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOZINE 50 (OREVA DARMO.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOZINE 100 (OREVA DARMO.)',
	'Chlorpromazine Hcl.',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOZINE 100 (OREVA DARMO.)'
);

-- line #9270
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOZINE 200 (Pil)',
	'Chlorpromazine Hcl.',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOZINE 200 (Pil)'
);

-- line #9271
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOZINE 50 (Pil)',
	'Chlorpromazine Hcl.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOZINE 50 (Pil)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOZINE 100 (Pil)',
	'Chlorpromazine Hcl.',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOZINE 100 (Pil)'
);

-- line #9272
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMETIL 25 (LA DRUG)',
	'Chlorpromazine Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMETIL 25 (LA DRUG)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMETIL 50 (LA DRUG)',
	'Chlorpromazine Hcl.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMETIL 50 (LA DRUG)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMETIL 100 (LA DRUG)',
	'Chlorpromazine Hcl.',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMETIL 100 (LA DRUG)'
);

-- line #9273
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOCHLOR 100 (Orchid Hc.)',
	'Chlorpromazine Hcl.',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOCHLOR 100 (Orchid Hc.)'
);

-- line #9274
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOCHLOR 10 (Orchid Hc.)',
	'Chlorpromazine Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOCHLOR 10 (Orchid Hc.)'
);

-- line #9275
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOCHLOR 200 (Orchid Hc.)',
	'Chlorpromazine Hcl.',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOCHLOR 200 (Orchid Hc.)'
);

-- line #9276
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOCHLOR 25 (Orchid Hc.)',
	'Chlorpromazine Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOCHLOR 25 (Orchid Hc.)'
);

-- line #9277
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOCHLOR 50 (Orchid Hc.)',
	'Chlorpromazine Hcl.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOCHLOR 50 (Orchid Hc.)'
);

-- line #9278
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOCHLOR 75 (Orchid Hc.)',
	'Chlorpromazine Hcl.',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOCHLOR 75 (Orchid Hc.)'
);

-- line #9279
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGATIL 50 (Intas)',
	'Chlorpromazine Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/2 ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGATIL 50 (Intas)'
);

-- line #9280
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGATIL 100 (Intas)',
	'Chlorpromazine Hcl.',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGATIL 100 (Intas)'
);

-- line #9281
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGATIL 200 (Intas)',
	'Chlorpromazine Hcl.',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGATIL 200 (Intas)'
);

-- line #9282
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGATIL 25 (Intas)',
	'Chlorpromazine Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGATIL 25 (Intas)'
);

-- line #9283
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGATIL 50 (Intas)',
	'Chlorpromazine Hcl.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGATIL 50 (Intas)'
);

-- line #9284
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAUSILAX 100 (Arbro Ph.)',
	'Chlorpromazine Hcl.',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAUSILAX 100 (Arbro Ph.)'
);

-- line #9285
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAUSILAX 200 (Arbro Ph.)',
	'Chlorpromazine Hcl.',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAUSILAX 200 (Arbro Ph.)'
);

-- line #9286
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PSYCONEX 100 (Theo Ph.)',
	'Chlorpromazine Hcl.',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PSYCONEX 100 (Theo Ph.)'
);

-- line #9287
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PSYCONEX 10 (Theo Ph.)',
	'Chlorpromazine Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PSYCONEX 10 (Theo Ph.)'
);

-- line #9288
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PSYCONEX 200 (Theo Ph.)',
	'Chlorpromazine Hcl.',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PSYCONEX 200 (Theo Ph.)'
);

-- line #9289
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PSYCONEX 25 (Theo Ph.)',
	'Chlorpromazine Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PSYCONEX 25 (Theo Ph.)'
);

-- line #9290
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PSYCONEX 50 (Theo Ph.)',
	'Chlorpromazine Hcl.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PSYCONEX 50 (Theo Ph.)'
);

-- line #9291
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELITIL 25 (Reliance)',
	'Chlorpromazine Hcl.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELITIL 25 (Reliance)'
);

-- line #9292
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELITIL 100 (Reliance)',
	'Chlorpromazine Hcl.',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELITIL 100 (Reliance)'
);

-- line #9293
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELITIL 25 (Reliance)',
	'Chlorpromazine Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELITIL 25 (Reliance)'
);

-- line #9294
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELITIL 50 (Reliance)',
	'Chlorpromazine Hcl.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELITIL 50 (Reliance)'
);

-- line #9295
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COPAMIDE 250 (Dey''S)',
	'Chlorpropamide',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COPAMIDE 250 (Dey''S)'
);

-- line #9296
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CTD 12.5 (Ipca)',
	'Chlorthalidone',
	'TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CTD 12.5 (Ipca)'
);

-- line #9297
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CTD 6.25 (Ipca)',
	'Chlorthalidone',
	'TAB',
	gm.nullify_empty_string('6.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CTD 6.25 (Ipca)'
);

-- line #9298
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYTHALTON 100 (Nicholas)',
	'Chlorthalidone',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYTHALTON 100 (Nicholas)'
);

-- line #9299
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARAFON DSC 500 (Ethnor)',
	'Chlorzoxazone',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARAFON DSC 500 (Ethnor)'
);

-- line #9300
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'400IU', u'strength_2': u'', u'substance': u'Cholecalciferol', u'always_empty': u'', u'form': u'', u'brand': u'ARBIVIT', u'strength_3': u'', u'company': u'R.B.', u'unit': u''}

-- line #9301
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'6000IU.', u'strength_2': u'', u'substance': u'Cholecalciferol', u'always_empty': u'', u'form': u'SAC', u'brand': u'CAFROL', u'strength_3': u'', u'company': u'Nippon Siy.', u'unit': u''}

-- line #9302
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALCI-BEST 60 (Bestochem)',
	'Cholecalciferol',
	'SAC',
	gm.nullify_empty_string('60')::numeric,
	'000IU.'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALCI-BEST 60 (Bestochem)'
);

-- line #9303
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALCIKIND 60 (Mankind)',
	'Cholecalciferol',
	'SAC',
	gm.nullify_empty_string('60')::numeric,
	'000IU.'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALCIKIND 60 (Mankind)'
);

-- line #9304
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALDIKIND 60 (Mankind)',
	'Cholecalciferol',
	'SAC',
	gm.nullify_empty_string('60')::numeric,
	'000IU.'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALDIKIND 60 (Mankind)'
);

-- line #9305
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALSI-BEST 60 (Bestochem)',
	'Cholecalciferol',
	'SAC',
	gm.nullify_empty_string('60')::numeric,
	'000 I.U.'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALSI-BEST 60 (Bestochem)'
);

-- line #9306
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'60', u'strength_2': u'', u'substance': u'Cholecalciferol', u'always_empty': u'', u'form': u'', u'brand': u'CAROL', u'strength_3': u'', u'company': u'ERIS LIFE', u'unit': u'000IU'}

-- line #9307
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000IU.', u'strength_2': u'', u'substance': u'Cholecalciferol', u'always_empty': u'', u'form': u'TAB', u'brand': u'CHLORICH', u'strength_3': u'', u'company': u'BAJAJ MEDI.', u'unit': u''}

-- line #9308
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'60', u'strength_2': u'', u'substance': u'Cholecalciferol', u'always_empty': u'', u'form': u'', u'brand': u'D-RISE', u'strength_3': u'', u'company': u'USV', u'unit': u'000IU'}

-- line #9309
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2000IU', u'strength_2': u'', u'substance': u'Cholecalciferol', u'always_empty': u'', u'form': u'', u'brand': u'DVITAL K', u'strength_3': u'', u'company': u'Astrum Hc.', u'unit': u''}

-- line #9310
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'60000IU', u'strength_2': u'', u'substance': u'Cholecalciferol', u'always_empty': u'', u'form': u'TAB', u'brand': u'DVITAL-K', u'strength_3': u'', u'company': u'Astrum Hc.', u'unit': u''}

-- line #9311
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'300000IU.', u'strength_2': u'', u'substance': u'Cholecalciferol', u'always_empty': u'', u'form': u'INJ L', u'brand': u'KALZIN', u'strength_3': u'', u'company': u'Unimarck', u'unit': u''}

-- line #9312
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'600000IU.', u'strength_2': u'', u'substance': u'Cholecalciferol', u'always_empty': u'', u'form': u'INJ L', u'brand': u'KALZIN', u'strength_3': u'', u'company': u'Unimarck', u'unit': u''}

-- line #9313
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'6LAC U.', u'strength_2': u'', u'substance': u'Cholecalciferol', u'always_empty': u'', u'form': u'INJ', u'brand': u'MAG-D3', u'strength_3': u'', u'company': u'Magnus Bio.', u'unit': u''}

-- line #9314
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSSOBONE 60 (RADHE BIO.)',
	'Cholecalciferol',
	'POUCH',
	gm.nullify_empty_string('60')::numeric,
	'000IU.'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSSOBONE 60 (RADHE BIO.)'
);

-- line #9315
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'6LAC U.', u'strength_2': u'', u'substance': u'Cholecalciferol', u'always_empty': u'', u'form': u'GRAN', u'brand': u'RD3', u'strength_3': u'', u'company': u'FORTUNE HC.', u'unit': u''}

-- line #9316
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'CHOLERA VACCINE', u'always_empty': u'', u'form': u'VACCINE', u'brand': u'CHOLERA', u'strength_3': u'', u'company': u'Haffkine', u'unit': u''}

-- line #9317
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHOLTRAN 4 (Ajanta Ph.)',
	'CHOLESTYRAMINE',
	'SAC',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHOLTRAN 4 (Ajanta Ph.)'
);

-- line #9318
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'4G', u'strength_2': u'', u'substance': u'CHOLESTYRAMINE', u'always_empty': u'', u'form': u'SAC', u'brand': u'CO DIET', u'strength_3': u'', u'company': u'THEMIS MEDICARE', u'unit': u''}

-- line #9319
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200MCG', u'strength_2': u'', u'substance': u'Chromium Picolinate', u'always_empty': u'', u'form': u'TAB', u'brand': u'CP', u'strength_3': u'', u'company': u'Bal Ph.', u'unit': u''}

-- line #9320
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Chromium Picolinate', u'always_empty': u'', u'form': u'TAB', u'brand': u'CP', u'strength_3': u'', u'company': u'Bal Ph.', u'unit': u''}

-- line #9321
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'CHYANWANPRASH', u'always_empty': u'', u'form': u'', u'brand': u'CHYAWAN ACTIVE PASTE', u'strength_3': u'', u'company': u'RANBAXY(GCH)', u'unit': u''}

-- line #9322
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'160MCG', u'strength_2': u'', u'substance': u'CICLESONIDE', u'always_empty': u'', u'form': u'TAB', u'brand': u'CICLEZ', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #9323
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'80MCG', u'strength_2': u'', u'substance': u'CICLESONIDE', u'always_empty': u'', u'form': u'TAB', u'brand': u'CICLEZ', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #9324
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'160MCG', u'strength_2': u'', u'substance': u'CICLESONIDE', u'always_empty': u'', u'form': u'', u'brand': u'CICLOHALE INH', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #9325
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'80MCG', u'strength_2': u'', u'substance': u'CICLESONIDE', u'always_empty': u'', u'form': u'', u'brand': u'CICLOHALE INH', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #9326
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'400MCG', u'strength_2': u'', u'substance': u'CICLESONIDE', u'always_empty': u'', u'form': u'ROTACAPS', u'brand': u'CICLOHALE', u'strength_3': u'', u'company': u'CIPLA', u'unit': u''}

-- line #9327
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'CICLESONIDE', u'always_empty': u'', u'form': u'ROTACAPS', u'brand': u'CICLOHALE', u'strength_3': u'', u'company': u'CIPLA', u'unit': u''}

-- line #9328
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50MCG(0.12', u'strength_2': u'', u'substance': u'CICLESONIDE', u'always_empty': u'', u'form': u'', u'brand': u'CICLOSPRAY', u'strength_3': u'', u'company': u'Cipla', u'unit': u'% POT.SORBATE AS PRES.)'}

-- line #9329
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200MCG', u'strength_2': u'', u'substance': u'CICLESONIDE', u'always_empty': u'', u'form': u'RESICAPS', u'brand': u'CILVESCO', u'strength_3': u'', u'company': u'German R.', u'unit': u''}

-- line #9330
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'400MCG', u'strength_2': u'', u'substance': u'CICLESONIDE', u'always_empty': u'', u'form': u'RESICAPS', u'brand': u'CILVESCO', u'strength_3': u'', u'company': u'German R.', u'unit': u''}

-- line #9331
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50MCG', u'strength_2': u'', u'substance': u'CICLESONIDE', u'always_empty': u'', u'form': u'NASAL SPRAY', u'brand': u'OSONASE', u'strength_3': u'', u'company': u'Ranbaxy', u'unit': u''}

-- line #9332
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BATRAFAN 10 (Sanofi Aventis)',
	'Ciclopirox olamine',
	'CRM',
	gm.nullify_empty_string('10')::numeric,
	'mg/G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BATRAFAN 10 (Sanofi Aventis)'
);

-- line #9333
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BATRAFAN 10 (Sanofi Aventis)',
	'Ciclopirox olamine',
	'SOLN',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BATRAFAN 10 (Sanofi Aventis)'
);

-- line #9334
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Ciclopirox olamine', u'always_empty': u'', u'form': u'CRM', u'brand': u'BATRAFAN-V', u'strength_3': u'', u'company': u'Sanofi Aventis', u'unit': u''}

-- line #9335
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIROX 1 (Dermatak)',
	'Ciclopirox olamine',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIROX 1 (Dermatak)'
);

-- line #9336
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUMIN 1 (Zydus Cadila)',
	'Ciclopirox olamine',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUMIN 1 (Zydus Cadila)'
);

-- line #9337
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAPROX 10 (HETERO HC.)',
	'Ciclopirox olamine',
	'CRM',
	gm.nullify_empty_string('10')::numeric,
	'mg/GM'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAPROX 10 (HETERO HC.)'
);

-- line #9338
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAPROX 10 (HETERO HC.)',
	'Ciclopirox olamine',
	'SOL',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAPROX 10 (HETERO HC.)'
);

-- line #9339
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAPROX VAGINAL 10 (HETERO HC.)',
	'Ciclopirox olamine',
	'CRM',
	gm.nullify_empty_string('10')::numeric,
	'mg/GM'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAPROX VAGINAL 10 (HETERO HC.)'
);

-- line #9340
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLAMIN 1 (Micro Labs)',
	'Ciclopirox olamine',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLAMIN 1 (Micro Labs)'
);

-- line #9341
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLAMIN SCALP 1.5 (MICRO LABS)',
	'Ciclopirox olamine',
	'LOT',
	gm.nullify_empty_string('1.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLAMIN SCALP 1.5 (MICRO LABS)'
);

-- line #9342
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXAMIN 1 (Sunways)',
	'Ciclopirox olamine',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXAMIN 1 (Sunways)'
);

-- line #9343
-- ignoring line: field [strength_1] not numeric: >>>160MCG(+POT. SORBATE 0.12<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'160MCG(+POT. SORBATE 0.12', u'strength_2': u'', u'substance': u'CICLOSONIDE', u'always_empty': u'', u'form': u'NASAL SPRAY', u'brand': u'CINASE', u'strength_3': u'', u'company': u'RESPICARE(GERMAN R.)', u'unit': u'%W/W)'}

-- line #9344
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'160MCG', u'strength_2': u'', u'substance': u'CICLOSONIDE', u'always_empty': u'', u'form': u'RHEOCAPS', u'brand': u'OSONIDE', u'strength_3': u'', u'company': u'Ranbaxy', u'unit': u''}

-- line #9345
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'320MCG', u'strength_2': u'', u'substance': u'CICLOSONIDE', u'always_empty': u'', u'form': u'RHEOCAPS', u'brand': u'OSONIDE', u'strength_3': u'', u'company': u'Ranbaxy', u'unit': u''}

-- line #9346
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'CILNIDIPINE', u'always_empty': u'', u'form': u'', u'brand': u'CILACAR', u'strength_3': u'', u'company': u'J.B.Chem.', u'unit': u'mg'}

-- line #9347
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CILACAR 10 (J. B. Chem.)',
	'CILNIDIPINE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CILACAR 10 (J. B. Chem.)'
);

-- line #9348
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CILACAR 5 (J. B. Chem.)',
	'CILNIDIPINE',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CILACAR 5 (J. B. Chem.)'
);

-- line #9349
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CILODOC 100 (Lupin)',
	'Cilostazol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CILODOC 100 (Lupin)'
);

-- line #9350
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CILODOC 50 (Lupin)',
	'Cilostazol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CILODOC 50 (Lupin)'
);

-- line #9351
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CILOKEM 100 (ALKEM)',
	'Cilostazol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CILOKEM 100 (ALKEM)'
);

-- line #9352
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CILOKEM 50 (ALKEM)',
	'Cilostazol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CILOKEM 50 (ALKEM)'
);

-- line #9353
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLETOZ 50 (Cipla)',
	'Cilostazol',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLETOZ 50 (Cipla)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLETOZ 100 (Cipla)',
	'Cilostazol',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLETOZ 100 (Cipla)'
);

-- line #9354
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIMETIDINE 200 (Zydus Cadila)',
	'Cimetidine',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIMETIDINE 200 (Zydus Cadila)'
);

-- line #9355
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIMETIGET 200 (Franco I.)',
	'Cimetidine',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg/400'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIMETIGET 200 (Franco I.)'
);

-- line #9356
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIMETIN 200 (P C INDIA)',
	'Cimetidine',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIMETIN 200 (P C INDIA)'
);

-- line #9357
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIMETIN 400 (P C INDIA)',
	'Cimetidine',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIMETIN 400 (P C INDIA)'
);

-- line #9358
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-MET 400 (Cyper Ph.)',
	'Cimetidine',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-MET 400 (Cyper Ph.)'
);

-- line #9359
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOCK-2 200 (Zydus Cadila)',
	'Cimetidine',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOCK-2 200 (Zydus Cadila)'
);

-- line #9360
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAPICET 30 (Emcure)',
	'CINACALCET',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAPICET 30 (Emcure)'
);

-- line #9361
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIMCIPAR 30 (Panacea)',
	'CINACALCET',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIMCIPAR 30 (Panacea)'
);

-- line #9362
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIMCIPAR 60 (Panacea)',
	'CINACALCET',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIMCIPAR 60 (Panacea)'
);

-- line #9363
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PTH 30 (Intas)',
	'CINACALCET',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PTH 30 (Intas)'
);

-- line #9364
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PTH 60 (Intas)',
	'CINACALCET',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PTH 60 (Intas)'
);

-- line #9365
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PTH 90 (Intas)',
	'CINACALCET',
	'TAB',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PTH 90 (Intas)'
);

-- line #9366
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUPERCAINAL 1.1 (Novartis)',
	'Cinchocaine Hcl.',
	'OINT',
	gm.nullify_empty_string('1.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUPERCAINAL 1.1 (Novartis)'
);

-- line #9367
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CINEMOV 1 (Cipla)',
	'CINITAPRIDE',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CINEMOV 1 (Cipla)'
);

-- line #9368
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CINTAFLUX 1 (Mankind)',
	'CINITAPRIDE',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CINTAFLUX 1 (Mankind)'
);

-- line #9369
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CINTAPRO 3 (Zydus A.)',
	'CINITAPRIDE',
	'OD TAB',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CINTAPRO 3 (Zydus A.)'
);

-- line #9370
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CINTAPRO 1 (NEXTGEN HC.)',
	'CINITAPRIDE',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CINTAPRO 1 (NEXTGEN HC.)'
);

-- line #9371
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1', u'strength_2': u'', u'substance': u'CINITAPRIDE', u'always_empty': u'', u'form': u'', u'brand': u"ENDEAVOUR''S CINESTA", u'strength_3': u'', u'company': u'Lupin', u'unit': u'mg'}

-- line #9372
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOGIT 1 (TASMED)',
	'CINITAPRIDE',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOGIT 1 (TASMED)'
);

-- line #9373
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROGIT 1 (Micro Labs)',
	'CINITAPRIDE',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROGIT 1 (Micro Labs)'
);

-- line #9374
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVIDAZINE 25 (Bell Ph.)',
	'Cinnarizine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVIDAZINE 25 (Bell Ph.)'
);

-- line #9375
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BAROZINE 25 (Baroque)',
	'Cinnarizine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BAROZINE 25 (Baroque)'
);

-- line #9376
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CINADIL 25 (Pil)',
	'Cinnarizine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CINADIL 25 (Pil)'
);

-- line #9377
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CINADIL 75 (Pil)',
	'Cinnarizine',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CINADIL 75 (Pil)'
);

-- line #9378
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CINARIN 25 (Sunrise Rem.)',
	'Cinnarizine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CINARIN 25 (Sunrise Rem.)'
);

-- line #9379
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CINAZ 25 (EAST WEST)',
	'Cinnarizine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CINAZ 25 (EAST WEST)'
);

-- line #9380
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CINAZ 75 (EAST WEST)',
	'Cinnarizine',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CINAZ 75 (EAST WEST)'
);

-- line #9381
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CINI 25 (Ind-Swift)',
	'Cinnarizine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CINI 25 (Ind-Swift)'
);

-- line #9382
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CINNAR 75 (Arvind Lab.)',
	'Cinnarizine',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CINNAR 75 (Arvind Lab.)'
);

-- line #9383
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CINTIGO 75 (Wallace)',
	'Cinnarizine',
	'FC TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CINTIGO 75 (Wallace)'
);

-- line #9384
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CINTIGO 25 (Wallace)',
	'Cinnarizine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CINTIGO 25 (Wallace)'
);

-- line #9385
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CINVERT 25 (BARODA)',
	'Cinnarizine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CINVERT 25 (BARODA)'
);

-- line #9386
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CINVERT 75 (BARODA)',
	'Cinnarizine',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CINVERT 75 (BARODA)'
);

-- line #9387
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CINZAN 25 (F D C)',
	'Cinnarizine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CINZAN 25 (F D C)'
);

-- line #9388
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CINZAN 75 (F D C)',
	'Cinnarizine',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CINZAN 75 (F D C)'
);

-- line #9389
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-ZINE-F 75 (Mano)',
	'Cinnarizine',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-ZINE-F 75 (Mano)'
);

-- line #9390
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-ZINE 25 (Mano)',
	'Cinnarizine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-ZINE 25 (Mano)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-ZINE 50 (Mano)',
	'Cinnarizine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-ZINE 50 (Mano)'
);

-- line #9391
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIZIKIND MD 75 (LIFESTAR)',
	'Cinnarizine',
	'F. TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIZIKIND MD 75 (LIFESTAR)'
);

-- line #9392
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIZIKIND 25 (LIFESTAR)',
	'Cinnarizine',
	'MD TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIZIKIND 25 (LIFESTAR)'
);

-- line #9393
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIZIRON-F 75 (Glenmark)',
	'Cinnarizine',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIZIRON-F 75 (Glenmark)'
);

-- line #9394
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIZIRON 25 (Glenmark)',
	'Cinnarizine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIZIRON 25 (Glenmark)'
);

-- line #9395
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIZNIL 25 (GRANDIX)',
	'Cinnarizine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIZNIL 25 (GRANDIX)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIZNIL 75 (GRANDIX)',
	'Cinnarizine',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIZNIL 75 (GRANDIX)'
);

-- line #9396
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMZINE 25 (HANDS PH.)',
	'Cinnarizine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMZINE 25 (HANDS PH.)'
);

-- line #9397
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'M-C Z 25 (Merit Org.)',
	'Cinnarizine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'M-C Z 25 (Merit Org.)'
);

-- line #9398
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ABACT 200 (Abbott)',
	'Ciprofloxacin',
	'INF',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ABACT 200 (Abbott)'
);

-- line #9399
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ABACT 250 (Abbott)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ABACT 250 (Abbott)'
);

-- line #9400
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ABACT 500 (Abbott)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ABACT 500 (Abbott)'
);

-- line #9401
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ABACT 750 (Abbott)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ABACT 750 (Abbott)'
);

-- line #9402
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACEBID 500 (Ascent Lab)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACEBID 500 (Ascent Lab)'
);

-- line #9403
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACIP 250 (ACE LAB.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACIP 250 (ACE LAB.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACIP 500 (ACE LAB.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACIP 500 (ACE LAB.)'
);

-- line #9404
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACROCIP 250 (Acron Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACROCIP 250 (Acron Ph.)'
);

-- line #9405
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACROCIP 500 (Acron Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACROCIP 500 (Acron Ph.)'
);

-- line #9406
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADCIP 500 (Admac Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADCIP 500 (Admac Ph.)'
);

-- line #9407
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,01', u'strength_2': u'', u'substance': u'CIPROFLOXACIN', u'always_empty': u'', u'form': u'', u'brand': u'ADIFLOX APPLICAPS', u'strength_3': u'', u'company': u'Intas', u'unit': u'%'}

-- line #9408
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALCIPRO 3 (Alkem)',
	'Ciprofloxacin',
	'EYE DPS',
	gm.nullify_empty_string('3')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALCIPRO 3 (Alkem)'
);

-- line #9409
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALCIPRO 2 (Alkem)',
	'Ciprofloxacin',
	'INF',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALCIPRO 2 (Alkem)'
);

-- line #9410
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALCIPRO 1000 (Alkem)',
	'Ciprofloxacin',
	'OD TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALCIPRO 1000 (Alkem)'
);

-- line #9411
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALCIPRO 500 (Alkem)',
	'Ciprofloxacin',
	'OD TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALCIPRO 500 (Alkem)'
);

-- line #9412
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALCIPRO 250 (Alkem)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALCIPRO 250 (Alkem)'
);

-- line #9413
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALCIPRO 500 (Alkem)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALCIPRO 500 (Alkem)'
);

-- line #9414
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALCIPRO 750 (Alkem)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALCIPRO 750 (Alkem)'
);

-- line #9415
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALCIP 500 (ALLENGE)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALCIP 500 (ALLENGE)'
);

-- line #9416
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALQUIN 250 (GRANDIX)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALQUIN 250 (GRANDIX)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALQUIN 500 (GRANDIX)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALQUIN 500 (GRANDIX)'
);

-- line #9417
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMPRO 250 (AIMCO PH.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMPRO 250 (AIMCO PH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMPRO 500 (AIMCO PH.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMPRO 500 (AIMCO PH.)'
);

-- line #9418
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANIFLOX 500 (Sanify)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANIFLOX 500 (Sanify)'
);

-- line #9419
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AQUIPRO 250 (Aquila)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AQUIPRO 250 (Aquila)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AQUIPRO 500 (Aquila)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AQUIPRO 500 (Aquila)'
);

-- line #9420
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AROLET 500 (Aronex Life)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AROLET 500 (Aronex Life)'
);

-- line #9421
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATOCIP 250 (Atoz Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATOCIP 250 (Atoz Ph.)'
);

-- line #9422
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATOCIP 500 (Atoz Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATOCIP 500 (Atoz Ph.)'
);

-- line #9423
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AUROBID 500 (Auroma Life)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AUROBID 500 (Auroma Life)'
);

-- line #9424
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVCIP 500 (POSITIF(AFIVE))',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVCIP 500 (POSITIF(AFIVE))'
);

-- line #9425
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVILOX 500 (Avalanche)',
	'Ciprofloxacin',
	'F. TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVILOX 500 (Avalanche)'
);

-- line #9426
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVILOX 125 (Avalanche)',
	'Ciprofloxacin',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVILOX 125 (Avalanche)'
);

-- line #9427
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVILOX 250 (Avalanche)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVILOX 250 (Avalanche)'
);

-- line #9428
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXCIPRO 500 (AXYZEN LIFE)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXCIPRO 500 (AXYZEN LIFE)'
);

-- line #9429
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACTINIL 250 (Varun Life)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACTINIL 250 (Varun Life)'
);

-- line #9430
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACTINIL 500 (Varun Life)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACTINIL 500 (Varun Life)'
);

-- line #9431
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACTOCIN 250 (Graf Lab.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACTOCIN 250 (Graf Lab.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACTOCIN 500 (Graf Lab.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACTOCIN 500 (Graf Lab.)'
);

-- line #9432
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACTONIL 250 (Allure Rem.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACTONIL 250 (Allure Rem.)'
);

-- line #9433
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACTONIL 500 (Allure Rem.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACTONIL 500 (Allure Rem.)'
);

-- line #9434
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500', u'strength_2': u'', u'substance': u'Ciprofloxacin', u'always_empty': u'', u'form': u'', u'brand': u'BACTOP', u'strength_3': u'', u'company': u'Mars Rem.', u'unit': u'mg'}

-- line #9435
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACTOP 250 (Mars Rem.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACTOP 250 (Mars Rem.)'
);

-- line #9436
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACTOQUIN 500 (Otsira)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACTOQUIN 500 (Otsira)'
);

-- line #9437
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACTOR 0.3 (Cadex Lab)',
	'Ciprofloxacin',
	'E/E DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACTOR 0.3 (Cadex Lab)'
);

-- line #9438
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACTOR 250 (Cadex Lab)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACTOR 250 (Cadex Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACTOR 500 (Cadex Lab)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACTOR 500 (Cadex Lab)'
);

-- line #9439
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BAYCIP 100 (Bayer)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BAYCIP 100 (Bayer)'
);

-- line #9440
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BAYCIP 250 (Bayer)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BAYCIP 250 (Bayer)'
);

-- line #9441
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BAYCIP 500 (Bayer)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BAYCIP 500 (Bayer)'
);

-- line #9442
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BAYCIP 750 (Bayer)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BAYCIP 750 (Bayer)'
);

-- line #9443
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BAYCIP-URO 100 (Bayer)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BAYCIP-URO 100 (Bayer)'
);

-- line #9444
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Ciprofloxacin', u'always_empty': u'', u'form': u'DPS', u'brand': u'BEGRAM-E', u'strength_3': u'', u'company': u'Brooks Ph.', u'unit': u''}

-- line #9445
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BEKAYCIN 250 (Sanofi Aventis)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BEKAYCIN 250 (Sanofi Aventis)'
);

-- line #9446
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BEKAYCIN 500 (Sanofi Aventis)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BEKAYCIN 500 (Sanofi Aventis)'
);

-- line #9447
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BICIPRO 250 (Kee Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BICIPRO 250 (Kee Ph.)'
);

-- line #9448
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BICIPRO 500 (Kee Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BICIPRO 500 (Kee Ph.)'
);

-- line #9449
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOCIP 400 (Biochem)',
	'Ciprofloxacin',
	'INF',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOCIP 400 (Biochem)'
);

-- line #9450
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIO CIPRON 500 (Bio-Drug)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIO CIPRON 500 (Bio-Drug)'
);

-- line #9451
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOCIP 250 (Biochem)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOCIP 250 (Biochem)'
);

-- line #9452
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOCIP 500 (Biochem)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOCIP 500 (Biochem)'
);

-- line #9453
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Ciprofloxacin', u'always_empty': u'', u'form': u'EYE DPS', u'brand': u'BIOFLOX', u'strength_3': u'', u'company': u'Bio-Tech Opth.', u'unit': u''}

-- line #9454
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOFLOX 250 (Bioguard Org.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOFLOX 250 (Bioguard Org.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOFLOX 500 (Bioguard Org.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOFLOX 500 (Bioguard Org.)'
);

-- line #9455
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOQUIN 500 (Bipl(Radico Lab))',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOQUIN 500 (Bipl(Radico Lab))'
);

-- line #9456
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CADIWIN 500 (Cadila)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CADIWIN 500 (Cadila)'
);

-- line #9457
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALCIP 250 (Calibar Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALCIP 250 (Calibar Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALCIP 500 (Calibar Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALCIP 500 (Calibar Ph.)'
);

-- line #9458
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALYCIP 250 (Calyx Rem.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALYCIP 250 (Calyx Rem.)'
);

-- line #9459
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALYCIP 500 (Calyx Rem.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALYCIP 500 (Calyx Rem.)'
);

-- line #9460
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANIRON 250 (Candor Bio.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANIRON 250 (Candor Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANIRON 500 (Candor Bio.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANIRON 500 (Candor Bio.)'
);

-- line #9461
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CASPRO 250 (CASCA)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CASPRO 250 (CASCA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CASPRO 500 (CASCA)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CASPRO 500 (CASCA)'
);

-- line #9462
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CBIC 250 (Cubit Hc.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CBIC 250 (Cubit Hc.)'
);

-- line #9463
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CBIC 500 (Cubit Hc.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CBIC 500 (Cubit Hc.)'
);

-- line #9464
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEBECT 250 (Shreya)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEBECT 250 (Shreya)'
);

-- line #9465
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEBECT 500 (Shreya)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEBECT 500 (Shreya)'
);

-- line #9466
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEBECT 750 (Shreya)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEBECT 750 (Shreya)'
);

-- line #9467
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEBRAN 3 (Blue Cross)',
	'Ciprofloxacin',
	'EYE DPS',
	gm.nullify_empty_string('3')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEBRAN 3 (Blue Cross)'
);

-- line #9468
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEBRAN 200 (Blue Cross)',
	'Ciprofloxacin',
	'INF',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEBRAN 200 (Blue Cross)'
);

-- line #9469
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEBRAN 100 (Blue Cross)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEBRAN 100 (Blue Cross)'
);

-- line #9470
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEBRAN 250 (Blue Cross)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEBRAN 250 (Blue Cross)'
);

-- line #9471
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEBRAN 500 (Blue Cross)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEBRAN 500 (Blue Cross)'
);

-- line #9472
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEBRAN 750 (Blue Cross)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEBRAN 750 (Blue Cross)'
);

-- line #9473
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEEL 250 (Elf Biomed)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEEL 250 (Elf Biomed)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEEL 500 (Elf Biomed)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEEL 500 (Elf Biomed)'
);

-- line #9474
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEEPRO 250 (Lincoln)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEEPRO 250 (Lincoln)'
);

-- line #9475
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEEPRO 500 (Lincoln)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEEPRO 500 (Lincoln)'
);

-- line #9476
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEEPRO 750 (Lincoln)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEEPRO 750 (Lincoln)'
);

-- line #9477
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CE-FLOX 0.3 (Unicure)',
	'Ciprofloxacin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CE-FLOX 0.3 (Unicure)'
);

-- line #9478
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFLOX 500 (Green Cross)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFLOX 500 (Green Cross)'
);

-- line #9479
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOBAC 250 (Rusan Hc)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOBAC 250 (Rusan Hc)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOBAC 500 (Rusan Hc)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOBAC 500 (Rusan Hc)'
);

-- line #9480
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFOMED 0.3 (Aglowmed)',
	'Ciprofloxacin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFOMED 0.3 (Aglowmed)'
);

-- line #9481
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPLOX 100 (Sun)',
	'Ciprofloxacin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPLOX 100 (Sun)'
);

-- line #9482
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPLOX 250 (Sun)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPLOX 250 (Sun)'
);

-- line #9483
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPLOX 500 (Sun)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPLOX 500 (Sun)'
);

-- line #9484
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPLOX 750 (Sun)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPLOX 750 (Sun)'
);

-- line #9485
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPROGIN 250 (BIOGEN PH.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPROGIN 250 (BIOGEN PH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPROGIN 500 (BIOGEN PH.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPROGIN 500 (BIOGEN PH.)'
);

-- line #9486
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPROLEN 0.3 (Warren)',
	'Ciprofloxacin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPROLEN 0.3 (Warren)'
);

-- line #9487
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPROLEN 250 (Warren)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPROLEN 250 (Warren)'
);

-- line #9488
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEPROLEN 500 (Warren)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEPROLEN 500 (Warren)'
);

-- line #9489
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CFT 250 (Unicure)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CFT 250 (Unicure)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CFT 500 (Unicure)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CFT 500 (Unicure)'
);

-- line #9490
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CFX-500 500 (Stadmed)',
	'CIPROFLOXACIN',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CFX-500 500 (Stadmed)'
);

-- line #9491
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CFX 250 (Remedies)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CFX 250 (Remedies)'
);

-- line #9492
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CFX 500 (Remedies)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CFX 500 (Remedies)'
);

-- line #9493
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Ciprofloxacin', u'always_empty': u'', u'form': u'EYE DPS', u'brand': u'CIBRON', u'strength_3': u'', u'company': u'Finesse Ph.', u'unit': u''}

-- line #9494
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIDALOX 250 (Chemo D.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIDALOX 250 (Chemo D.)'
);

-- line #9495
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIDALOX 500 (Chemo D.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIDALOX 500 (Chemo D.)'
);

-- line #9496
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIDALOX 750 (Chemo D.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIDALOX 750 (Chemo D.)'
);

-- line #9497
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIFGEN 500 (Antigen Hc.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIFGEN 500 (Antigen Hc.)'
);

-- line #9498
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIFOID 250 (Norris Med.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIFOID 250 (Norris Med.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIFOID 500 (Norris Med.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIFOID 500 (Norris Med.)'
);

-- line #9499
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIFOLINE 250 (Life Line)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIFOLINE 250 (Life Line)'
);

-- line #9500
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIFOLINE 500 (Life Line)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIFOLINE 500 (Life Line)'
);

-- line #9501
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIFOMED 0.3 (Aglowmed)',
	'Ciprofloxacin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIFOMED 0.3 (Aglowmed)'
);

-- line #9502
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIFOMED 100 (Aglowmed)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIFOMED 100 (Aglowmed)'
);

-- line #9503
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIFOMED 250 (Aglowmed)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIFOMED 250 (Aglowmed)'
);

-- line #9504
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIFOMED 500 (Aglowmed)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIFOMED 500 (Aglowmed)'
);

-- line #9505
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIFOMED 750 (Aglowmed)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIFOMED 750 (Aglowmed)'
);

-- line #9506
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIFRAN 100 (Ranbaxy)',
	'Ciprofloxacin',
	'INF',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIFRAN 100 (Ranbaxy)'
);

-- line #9507
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIFRAN 200 (Ranbaxy)',
	'Ciprofloxacin',
	'INF',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIFRAN 200 (Ranbaxy)'
);

-- line #9508
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIFRAN 400 (Ranbaxy)',
	'Ciprofloxacin',
	'INF',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIFRAN 400 (Ranbaxy)'
);

-- line #9509
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIFRAN 500 (Ranbaxy)',
	'Ciprofloxacin',
	'OD GM',
	gm.nullify_empty_string('500')::numeric,
	'mg/1G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIFRAN 500 (Ranbaxy)'
);

-- line #9510
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIFRAN 500 (Ranbaxy)',
	'Ciprofloxacin',
	'OD',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIFRAN 500 (Ranbaxy)'
);

-- line #9511
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIFRAN 100 (Ranbaxy)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIFRAN 100 (Ranbaxy)'
);

-- line #9512
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIFRAN 250 (Ranbaxy)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIFRAN 250 (Ranbaxy)'
);

-- line #9513
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIFRAN 500 (Ranbaxy)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIFRAN 500 (Ranbaxy)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIFRAN 750 (Ranbaxy)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIFRAN 750 (Ranbaxy)'
);

-- line #9514
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIFRODIS 500 (MEDISYS)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIFRODIS 500 (MEDISYS)'
);

-- line #9515
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIF 500 (Uniroyal)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIF 500 (Uniroyal)'
);

-- line #9516
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIGRAM 0.3 (Parenteral)',
	'Ciprofloxacin',
	'EYE DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIGRAM 0.3 (Parenteral)'
);

-- line #9517
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIMFLOX 250 (Dcm Lab)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIMFLOX 250 (Dcm Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIMFLOX 500 (Dcm Lab)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIMFLOX 500 (Dcm Lab)'
);

-- line #9518
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CINA 250 (Sayona)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CINA 250 (Sayona)'
);

-- line #9519
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CINA 500 (Sayona)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CINA 500 (Sayona)'
);

-- line #9520
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CINOVY 500 (Zedip Form.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CINOVY 500 (Zedip Form.)'
);

-- line #9521
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPAC 250 (Acme Ph)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPAC 250 (Acme Ph)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPAC 500 (Acme Ph)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPAC 500 (Acme Ph)'
);

-- line #9522
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPACT 250 (MEDICO HEALTH)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPACT 250 (MEDICO HEALTH)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPACT 500 (MEDICO HEALTH)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPACT 500 (MEDICO HEALTH)'
);

-- line #9523
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPAD 2 (Albert D.)',
	'Ciprofloxacin',
	'INF',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPAD 2 (Albert D.)'
);

-- line #9524
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPAD 250 (Albert D.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPAD 250 (Albert D.)'
);

-- line #9525
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPAD 500 (Albert D.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPAD 500 (Albert D.)'
);

-- line #9526
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPAR 250 (Arvind Lab.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPAR 250 (Arvind Lab.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPAR 500 (Arvind Lab.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPAR 500 (Arvind Lab.)'
);

-- line #9527
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPAR 750 (Arvind Lab.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPAR 750 (Arvind Lab.)'
);

-- line #9528
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIP BID 500 (AASHRAY)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIP BID 500 (AASHRAY)'
);

-- line #9529
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPCENT 500 (ASCENT REM.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPCENT 500 (ASCENT REM.)'
);

-- line #9530
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPCIN 250 (AKUM(WELCARE))',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPCIN 250 (AKUM(WELCARE))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPCIN 500 (AKUM(WELCARE))',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPCIN 500 (AKUM(WELCARE))'
);

-- line #9531
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPEX 250 (Apex Form.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPEX 250 (Apex Form.)'
);

-- line #9532
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPEX 500 (Apex Form.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPEX 500 (Apex Form.)'
);

-- line #9533
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIP FAST 500 (Atrimed Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIP FAST 500 (Atrimed Ph.)'
);

-- line #9534
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPFLOX 250 (Chemech)',
	'Ciprofloxacin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPFLOX 250 (Chemech)'
);

-- line #9535
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPFLOX 500 (Chemech)',
	'Ciprofloxacin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPFLOX 500 (Chemech)'
);

-- line #9536
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPGEN 250 (Cadila Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPGEN 250 (Cadila Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPGEN 500 (Cadila Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPGEN 500 (Cadila Ph.)'
);

-- line #9537
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ciprofloxacin', u'always_empty': u'', u'form': u'OD TAB', u'brand': u'CIPIC', u'strength_3': u'', u'company': u'Biological E.', u'unit': u''}

-- line #9538
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPIC 100 (Biological E.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPIC 100 (Biological E.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPIC 250 (Biological E.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPIC 250 (Biological E.)'
);

-- line #9539
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPIC 500 (Biological E.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPIC 500 (Biological E.)'
);

-- line #9540
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPIND 250 (Indian R.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPIND 250 (Indian R.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPIND 500 (Indian R.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPIND 500 (Indian R.)'
);

-- line #9541
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPIQUIN 250 (AGIO PH.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPIQUIN 250 (AGIO PH.)'
);

-- line #9542
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPIQUIN 500 (AGIO PH.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPIQUIN 500 (AGIO PH.)'
);

-- line #9543
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPKEM 250 (Anikem Lab.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPKEM 250 (Anikem Lab.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPKEM 500 (Anikem Lab.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPKEM 500 (Anikem Lab.)'
);

-- line #9544
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPKON 500 (Briskon)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPKON 500 (Briskon)'
);

-- line #9545
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPLOX 5 (Cipla)',
	'Ciprofloxacin',
	'CRM',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPLOX 5 (Cipla)'
);

-- line #9546
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPLOX 0.3 (Cipla)',
	'Ciprofloxacin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPLOX 0.3 (Cipla)'
);

-- line #9547
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ciprofloxacin', u'always_empty': u'', u'form': u'ER TAB', u'brand': u'CIPLOX', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #9548
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPLOX 500 (Cipla)',
	'Ciprofloxacin',
	'ER TAB',
	gm.nullify_empty_string('500')::numeric,
	'750'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPLOX 500 (Cipla)'
);

-- line #9549
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPLOX-I 0.3 (Cipla)',
	'Ciprofloxacin',
	'CAPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPLOX-I 0.3 (Cipla)'
);

-- line #9550
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPLOX 2 (Cipla)',
	'Ciprofloxacin',
	'INF',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPLOX 2 (Cipla)'
);

-- line #9551
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPLOX 500 (Cipla)',
	'Ciprofloxacin',
	'OD TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg(ER)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPLOX 500 (Cipla)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPLOX 1000 (Cipla)',
	'Ciprofloxacin',
	'OD TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg(ER)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPLOX 1000 (Cipla)'
);

-- line #9552
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPLOX 0.3 (Cipla)',
	'Ciprofloxacin',
	'OINT',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPLOX 0.3 (Cipla)'
);

-- line #9553
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPLOX 100 (Cipla)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPLOX 100 (Cipla)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPLOX 250 (Cipla)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPLOX 250 (Cipla)'
);

-- line #9554
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPLOX 500 (Cipla)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPLOX 500 (Cipla)'
);

-- line #9555
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPLOX 750 (Cipla)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPLOX 750 (Cipla)'
);

-- line #9556
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Ciprofloxacin', u'always_empty': u'', u'form': u'DROPS', u'brand': u'CIPMAX', u'strength_3': u'', u'company': u'NIVCA', u'unit': u''}

-- line #9557
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPNAC 500 (Nac Int.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPNAC 500 (Nac Int.)'
);

-- line #9558
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPORIC 250 (Euphoric)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPORIC 250 (Euphoric)'
);

-- line #9559
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPORIC 500 (Euphoric)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPORIC 500 (Euphoric)'
);

-- line #9560
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPRAV 250 (Ravian)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPRAV 250 (Ravian)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPRAV 500 (Ravian)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPRAV 500 (Ravian)'
);

-- line #9561
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPRAY 250 (Ray Rem.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPRAY 250 (Ray Rem.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPRAY 500 (Ray Rem.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPRAY 500 (Ray Rem.)'
);

-- line #9562
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPREX 250 (ETHIX HC.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPREX 250 (ETHIX HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPREX 500 (ETHIX HC.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPREX 500 (ETHIX HC.)'
);

-- line #9563
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPRIDE 100 (Torrent)',
	'Ciprofloxacin',
	'INF',
	gm.nullify_empty_string('100')::numeric,
	'mg/50ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPRIDE 100 (Torrent)'
);

-- line #9564
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPRIDE 250 (Torrent)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPRIDE 250 (Torrent)'
);

-- line #9565
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPRIDE 500 (Torrent)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPRIDE 500 (Torrent)'
);

-- line #9566
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPRIND 250 (Indoco Rem.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPRIND 250 (Indoco Rem.)'
);

-- line #9567
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPRIND 500 (Indoco Rem.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPRIND 500 (Indoco Rem.)'
);

-- line #9568
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROACE 250 (RANBAXY)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROACE 250 (RANBAXY)'
);

-- line #9569
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROACE 500 (RANBAXY)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROACE 500 (RANBAXY)'
);

-- line #9570
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROBACT 250 (Guj.Terce)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROBACT 250 (Guj.Terce)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROBACT 500 (Guj.Terce)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROBACT 500 (Guj.Terce)'
);

-- line #9571
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROBEX 100 (Apex Rem.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROBEX 100 (Apex Rem.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROBEX 250 (Apex Rem.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROBEX 250 (Apex Rem.)'
);

-- line #9572
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROBEX 500 (Apex Rem.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROBEX 500 (Apex Rem.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROBEX 750 (Apex Rem.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROBEX 750 (Apex Rem.)'
);

-- line #9573
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROBID 0.3 (Zydus Cadila)',
	'Ciprofloxacin',
	'E/E DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V(LACT.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROBID 0.3 (Zydus Cadila)'
);

-- line #9574
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROBID 2 (Zydus Cadila)',
	'Ciprofloxacin',
	'INF',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROBID 2 (Zydus Cadila)'
);

-- line #9575
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROBID 100 (Zydus Cadila)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROBID 100 (Zydus Cadila)'
);

-- line #9576
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROBID 250 (Zydus Cadila)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROBID 250 (Zydus Cadila)'
);

-- line #9577
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROBID 500 (Zydus Cadila)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROBID 500 (Zydus Cadila)'
);

-- line #9578
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROBID 750 (Zydus Cadila)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROBID 750 (Zydus Cadila)'
);

-- line #9579
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROBIOTIC 0.3 (Emcure)',
	'Ciprofloxacin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROBIOTIC 0.3 (Emcure)'
);

-- line #9580
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROBIOTIC 100 (Emcure)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROBIOTIC 100 (Emcure)'
);

-- line #9581
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROBIOTIC 250 (Emcure)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROBIOTIC 250 (Emcure)'
);

-- line #9582
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROBIOTIC 500 (Emcure)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROBIOTIC 500 (Emcure)'
);

-- line #9583
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROBIOTIC 750 (Emcure)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROBIOTIC 750 (Emcure)'
);

-- line #9584
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Ciprofloxacin', u'always_empty': u'', u'form': u'SOL', u'brand': u'CIPROB', u'strength_3': u'', u'company': u'Aabtac Life', u'unit': u''}

-- line #9585
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROB 250 (Aabtac Life)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROB 250 (Aabtac Life)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROB 500 (Aabtac Life)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROB 500 (Aabtac Life)'
);

-- line #9586
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROCAP 250 (Pharma synth)',
	'Ciprofloxacin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROCAP 250 (Pharma synth)'
);

-- line #9587
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROCAP 500 (Pharma synth)',
	'Ciprofloxacin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROCAP 500 (Pharma synth)'
);

-- line #9588
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROCARE 250 (Healthcare)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROCARE 250 (Healthcare)'
);

-- line #9589
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROCARE 500 (Healthcare)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROCARE 500 (Healthcare)'
);

-- line #9590
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROCENT 0.3 (Centaur)',
	'Ciprofloxacin',
	'E/E DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROCENT 0.3 (Centaur)'
);

-- line #9591
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPRO-CENT 0.3 (CENTUAR)',
	'Ciprofloxacin',
	'EYE DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPRO-CENT 0.3 (CENTUAR)'
);

-- line #9592
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPRO-CENT 0.3 (CENTUAR)',
	'Ciprofloxacin',
	'EYE OINT',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPRO-CENT 0.3 (CENTUAR)'
);

-- line #9593
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROCENT 0.3 (Centaur)',
	'Ciprofloxacin',
	'OINT',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROCENT 0.3 (Centaur)'
);

-- line #9594
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROCID 0.3 (Indus)',
	'Ciprofloxacin',
	'E/E DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROCID 0.3 (Indus)'
);

-- line #9595
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROCID 250 (Patson)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROCID 250 (Patson)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROCID 500 (Patson)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROCID 500 (Patson)'
);

-- line #9596
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROCON 0.3 (Indiana O.)',
	'Ciprofloxacin',
	'EYE DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROCON 0.3 (Indiana O.)'
);

-- line #9597
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROCORE 250 (Claris L.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROCORE 250 (Claris L.)'
);

-- line #9598
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROCORE 500 (Claris L.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROCORE 500 (Claris L.)'
);

-- line #9599
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROCTA 250 (Obzone Ph.)',
	'CIPROFLOXACIN',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROCTA 250 (Obzone Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROCTA 500 (Obzone Ph.)',
	'CIPROFLOXACIN',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROCTA 500 (Obzone Ph.)'
);

-- line #9600
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROCURE 250 (Radicura)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROCURE 250 (Radicura)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROCURE 500 (Radicura)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROCURE 500 (Radicura)'
);

-- line #9601
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPRODAC 0.3 (Zydus A.)',
	'Ciprofloxacin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPRODAC 0.3 (Zydus A.)'
);

-- line #9602
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPRODAC 2 (Zydus A.)',
	'Ciprofloxacin',
	'INF',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPRODAC 2 (Zydus A.)'
);

-- line #9603
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPRODAC 250 (Zydus A.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPRODAC 250 (Zydus A.)'
);

-- line #9604
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPRODAC 500 (Zydus A.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPRODAC 500 (Zydus A.)'
);

-- line #9605
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPRODAC 750 (Zydus A.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPRODAC 750 (Zydus A.)'
);

-- line #9606
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPRODAY 0.3 (Bestochem)',
	'Ciprofloxacin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPRODAY 0.3 (Bestochem)'
);

-- line #9607
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPRODAY 100 (Bestochem)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPRODAY 100 (Bestochem)'
);

-- line #9608
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPRODAY 250 (Bestochem)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPRODAY 250 (Bestochem)'
);

-- line #9609
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPRODAY 500 (Bestochem)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPRODAY 500 (Bestochem)'
);

-- line #9610
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPRODAY 750 (Bestochem)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPRODAY 750 (Bestochem)'
);

-- line #9611
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPRODEL 250 (VERITAZ)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPRODEL 250 (VERITAZ)'
);

-- line #9612
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPRODEL 500 (VERITAZ)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPRODEL 500 (VERITAZ)'
);

-- line #9613
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2', u'strength_2': u'', u'substance': u'Ciprofloxacin', u'always_empty': u'', u'form': u'', u'brand': u'CIPRODEX IV', u'strength_3': u'', u'company': u'Parenteral', u'unit': u'mg+ANHY. DEXTROSE 50'}

-- line #9614
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPRODEX 250 (Parenteral)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPRODEX 250 (Parenteral)'
);

-- line #9615
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPRODEX 500 (Parenteral)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPRODEX 500 (Parenteral)'
);

-- line #9616
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPRODEX 750 (Parenteral)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPRODEX 750 (Parenteral)'
);

-- line #9617
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPRODIL 250 (Dial Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPRODIL 250 (Dial Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPRODIL 500 (Dial Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPRODIL 500 (Dial Ph.)'
);

-- line #9618
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPRODIP 0.3 (Pfiscar Ind.)',
	'Ciprofloxacin',
	'E/E DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPRODIP 0.3 (Pfiscar Ind.)'
);

-- line #9619
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROFEN 250 (Franklin)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROFEN 250 (Franklin)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROFEN 500 (Franklin)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROFEN 500 (Franklin)'
);

-- line #9620
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROFLOXACIN 2 (Albert D.)',
	'Ciprofloxacin',
	'INF',
	gm.nullify_empty_string('2')::numeric,
	'mg+SOD.CHL. 9'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROFLOXACIN 2 (Albert D.)'
);

-- line #9621
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROGEN-F 250 (Zenith Hc.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROGEN-F 250 (Zenith Hc.)'
);

-- line #9622
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROGEN-F 500 (Zenith Hc.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROGEN-F 500 (Zenith Hc.)'
);

-- line #9623
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROGLEN 100 (Glenmark)',
	'Ciprofloxacin',
	'INF',
	gm.nullify_empty_string('100')::numeric,
	'mg/50ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROGLEN 100 (Glenmark)'
);

-- line #9624
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROGLEN 250 (Glenmark)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROGLEN 250 (Glenmark)'
);

-- line #9625
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROGLEN 500 (Glenmark)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROGLEN 500 (Glenmark)'
);

-- line #9626
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPRO 200 (Claris L.)',
	'Ciprofloxacin',
	'INF',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPRO 200 (Claris L.)'
);

-- line #9627
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROLAN 250 (Lan Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROLAN 250 (Lan Ph.)'
);

-- line #9628
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROLAN 500 (Lan Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROLAN 500 (Lan Ph.)'
);

-- line #9629
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROLAR 0.5 (Lark Lab)',
	'Ciprofloxacin',
	'CRM',
	gm.nullify_empty_string('0.5')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROLAR 0.5 (Lark Lab)'
);

-- line #9630
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROLAR 125 (Lark Lab)',
	'Ciprofloxacin',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROLAR 125 (Lark Lab)'
);

-- line #9631
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROLAR 250 (Lark Lab)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROLAR 250 (Lark Lab)'
);

-- line #9632
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROLAR 500 (Lark Lab)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROLAR 500 (Lark Lab)'
);

-- line #9633
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROLAR 750 (Lark Lab)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROLAR 750 (Lark Lab)'
);

-- line #9634
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROLEB 250 (Leben)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROLEB 250 (Leben)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROLEB 500 (Leben)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROLEB 500 (Leben)'
);

-- line #9635
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROLES 250 (Leben)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROLES 250 (Leben)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROLES 500 (Leben)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROLES 500 (Leben)'
);

-- line #9636
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROLET 500 (Dr.Reddy''S)',
	'Ciprofloxacin',
	'DS TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROLET 500 (Dr.Reddy''S)'
);

-- line #9637
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROLET 0.3 (Dr.Reddy''S)',
	'Ciprofloxacin',
	'E/E DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROLET 0.3 (Dr.Reddy''S)'
);

-- line #9638
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROLET 20 (Dr.Reddy''S)',
	'Ciprofloxacin',
	'INF',
	gm.nullify_empty_string('20')::numeric,
	'mg/10ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROLET 20 (Dr.Reddy''S)'
);

-- line #9639
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROLET 100 (Dr.Reddy''S)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROLET 100 (Dr.Reddy''S)'
);

-- line #9640
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROLET 250 (Dr.Reddy''S)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROLET 250 (Dr.Reddy''S)'
);

-- line #9641
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROLET 750 (Dr.Reddy''S)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROLET 750 (Dr.Reddy''S)'
);

-- line #9642
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROLIFE 250 (Life Line)',
	'Ciprofloxacin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROLIFE 250 (Life Line)'
);

-- line #9643
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROLIFE 250 (Life Line)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROLIFE 250 (Life Line)'
);

-- line #9644
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROLIFE 500 (Life Line)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROLIFE 500 (Life Line)'
);

-- line #9645
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROLIFE 750 (Life Line)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROLIFE 750 (Life Line)'
);

-- line #9646
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROLON 250 (Suvik Hit.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROLON 250 (Suvik Hit.)'
);

-- line #9647
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROLON 500 (Suvik Hit.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROLON 500 (Suvik Hit.)'
);

-- line #9648
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROLUCK 500 (Goodluck Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROLUCK 500 (Goodluck Ph.)'
);

-- line #9649
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROMAN 250 (Shalman)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROMAN 250 (Shalman)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROMAN 500 (Shalman)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROMAN 500 (Shalman)'
);

-- line #9650
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROMARK 0.3 (Ultramark)',
	'Ciprofloxacin',
	'EYE DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROMARK 0.3 (Ultramark)'
);

-- line #9651
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROMARK 250 (Ultramark)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROMARK 250 (Ultramark)'
);

-- line #9652
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROMARK 500 (Ultramark)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROMARK 500 (Ultramark)'
);

-- line #9653
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROMED 250 (Alde Medi.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg(HCL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROMED 250 (Alde Medi.)'
);

-- line #9654
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROMED 500 (Alde Medi.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROMED 500 (Alde Medi.)'
);

-- line #9655
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROMED 750 (Alde Medi.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg(HCL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROMED 750 (Alde Medi.)'
);

-- line #9656
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROMED 250 (Medopharm)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROMED 250 (Medopharm)'
);

-- line #9657
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROMED 500 (Medopharm)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROMED 500 (Medopharm)'
);

-- line #9658
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROMET 500 (Merit Org.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROMET 500 (Merit Org.)'
);

-- line #9659
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROMYCETIN 0.3 (Mac)',
	'Ciprofloxacin',
	'E/E DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROMYCETIN 0.3 (Mac)'
);

-- line #9660
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROMYCETINE 200 (Mac)',
	'Ciprofloxacin',
	'INF',
	gm.nullify_empty_string('200')::numeric,
	'mg/100ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROMYCETINE 200 (Mac)'
);

-- line #9661
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROMYCETINE 500 (Mac)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROMYCETINE 500 (Mac)'
);

-- line #9662
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPRONAT 250 (Natco Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPRONAT 250 (Natco Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPRONAT 500 (Natco Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPRONAT 500 (Natco Ph.)'
);

-- line #9663
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPRONEX 250 (Nestor)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPRONEX 250 (Nestor)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPRONEX 500 (Nestor)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPRONEX 500 (Nestor)'
);

-- line #9664
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPRONIC 250 (Emil Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPRONIC 250 (Emil Ph.)'
);

-- line #9665
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPRONIC 500 (Emil Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPRONIC 500 (Emil Ph.)'
);

-- line #9666
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPRONIX 500 (ORION BIOTECH.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPRONIX 500 (ORION BIOTECH.)'
);

-- line #9667
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROPAN 250 (Panacea)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROPAN 250 (Panacea)'
);

-- line #9668
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROPAN 500 (Panacea)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROPAN 500 (Panacea)'
);

-- line #9669
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROPLUS 250 (HETERO HC)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROPLUS 250 (HETERO HC)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROPLUS 500 (HETERO HC)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROPLUS 500 (HETERO HC)'
);

-- line #9670
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROQUIN 200 (Kopran)',
	'Ciprofloxacin',
	'INF',
	gm.nullify_empty_string('200')::numeric,
	'mg/100ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROQUIN 200 (Kopran)'
);

-- line #9671
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROQUIN 250 (Kopran)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROQUIN 250 (Kopran)'
);

-- line #9672
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROQUIN 500 (Kopran)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROQUIN 500 (Kopran)'
);

-- line #9673
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROQUIN 750 (Kopran)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROQUIN 750 (Kopran)'
);

-- line #9674
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPRORED 250 (Adison Lab)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPRORED 250 (Adison Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPRORED 500 (Adison Lab)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPRORED 500 (Adison Lab)'
);

-- line #9675
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPRO 500 (Parasol)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPRO 500 (Parasol)'
);

-- line #9676
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROTAM 250 (Shantam Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROTAM 250 (Shantam Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROTAM 500 (Shantam Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROTAM 500 (Shantam Ph.)'
);

-- line #9677
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROTECH 250 (PHARMATECH)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROTECH 250 (PHARMATECH)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROTECH 500 (PHARMATECH)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROTECH 500 (PHARMATECH)'
);

-- line #9678
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROTIC 250 (Relish)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROTIC 250 (Relish)'
);

-- line #9679
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROTIC 500 (Relish)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROTIC 500 (Relish)'
);

-- line #9680
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROTUM 250 (Profic)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROTUM 250 (Profic)'
);

-- line #9681
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROTUM 500 (Profic)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROTUM 500 (Profic)'
);

-- line #9682
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROVA 250 (LUPINOVA)',
	'Ciprofloxacin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROVA 250 (LUPINOVA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROVA 500 (LUPINOVA)',
	'Ciprofloxacin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROVA 500 (LUPINOVA)'
);

-- line #9683
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROVA 2 (Lupin)',
	'Ciprofloxacin',
	'INF',
	gm.nullify_empty_string('2')::numeric,
	'mg/1ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROVA 2 (Lupin)'
);

-- line #9684
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROVAR 250 (Zota Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROVAR 250 (Zota Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROVAR 500 (Zota Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROVAR 500 (Zota Ph.)'
);

-- line #9685
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROVA 250 (Lupin)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROVA 250 (Lupin)'
);

-- line #9686
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROVA 500 (Lupin)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROVA 500 (Lupin)'
);

-- line #9687
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROVA 750 (Lupin)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROVA 750 (Lupin)'
);

-- line #9688
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROVIT 0.3 (Prohealth)',
	'Ciprofloxacin',
	'E/E DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROVIT 0.3 (Prohealth)'
);

-- line #9689
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROWIN 100 (Alembic)',
	'Ciprofloxacin',
	'INFUSION',
	gm.nullify_empty_string('100')::numeric,
	'mg/50ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROWIN 100 (Alembic)'
);

-- line #9690
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROWIN 250 (Alembic)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROWIN 250 (Alembic)'
);

-- line #9691
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROWIN 500 (Alembic)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROWIN 500 (Alembic)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROWIN 750 (Alembic)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROWIN 750 (Alembic)'
);

-- line #9692
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROX 200 (Claris L.)',
	'CIPROFLOXACIN',
	'INF',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROX 200 (Claris L.)'
);

-- line #9693
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROXIN 250 (NRB-INDIA)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROXIN 250 (NRB-INDIA)'
);

-- line #9694
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROXIN 500 (NRB-INDIA)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROXIN 500 (NRB-INDIA)'
);

-- line #9695
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROXIN 250 (Trio Rem.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROXIN 250 (Trio Rem.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROXIN 500 (Trio Rem.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROXIN 500 (Trio Rem.)'
);

-- line #9696
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROXYL 250 (Shinto Org.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROXYL 250 (Shinto Org.)'
);

-- line #9697
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROXYL 500 (Shinto Org.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROXYL 500 (Shinto Org.)'
);

-- line #9698
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROXYL 750 (Shinto Org.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROXYL 750 (Shinto Org.)'
);

-- line #9699
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROZED 250 (Zota Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROZED 250 (Zota Ph.)'
);

-- line #9700
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROZED 500 (Zota Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROZED 500 (Zota Ph.)'
);

-- line #9701
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROZEN-F 250 (Zenith Hc.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROZEN-F 250 (Zenith Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROZEN-F 500 (Zenith Hc.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROZEN-F 500 (Zenith Hc.)'
);

-- line #9702
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROZEN-F 750 (Zenith Hc.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROZEN-F 750 (Zenith Hc.)'
);

-- line #9703
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROZEN 250 (Kaizen Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROZEN 250 (Kaizen Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROZEN 500 (Kaizen Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROZEN 500 (Kaizen Ph.)'
);

-- line #9704
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROZET 250 (Meridian)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROZET 250 (Meridian)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROZET 500 (Meridian)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROZET 500 (Meridian)'
);

-- line #9705
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROZOL 250 (Mankind)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROZOL 250 (Mankind)'
);

-- line #9706
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPROZOL 500 (Mankind)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPROZOL 500 (Mankind)'
);

-- line #9707
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPRO 500 (ZOREX REM.)',
	'Ciprofloxacin',
	'ZR TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPRO 500 (ZOREX REM.)'
);

-- line #9708
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPRUS 250 (Rhombus)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPRUS 250 (Rhombus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPRUS 500 (Rhombus)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPRUS 500 (Rhombus)'
);

-- line #9709
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPSAM 250 (Samson)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPSAM 250 (Samson)'
);

-- line #9710
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPSAM 500 (Samson)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPSAM 500 (Samson)'
);

-- line #9711
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPSEM 250 (Semsun Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPSEM 250 (Semsun Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPSEM 500 (Semsun Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPSEM 500 (Semsun Ph.)'
);

-- line #9712
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPS 500 (SHRESHTHA)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPS 500 (SHRESHTHA)'
);

-- line #9713
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIP 250 (Helios Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIP 250 (Helios Ph.)'
);

-- line #9714
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIP 500 (Helios Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIP 500 (Helios Ph.)'
);

-- line #9715
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPTAM 250 (Sun)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPTAM 250 (Sun)'
);

-- line #9716
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPTAM 500 (Sun)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPTAM 500 (Sun)'
);

-- line #9717
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPTA 250 (ANQUIS(SANCHEZ))',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPTA 250 (ANQUIS(SANCHEZ))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPTA 500 (ANQUIS(SANCHEZ))',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPTA 500 (ANQUIS(SANCHEZ))'
);

-- line #9718
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPTEC 250 (Cipla)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPTEC 250 (Cipla)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPTEC 500 (Cipla)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPTEC 500 (Cipla)'
);

-- line #9719
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPTID 250 (Stallion)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPTID 250 (Stallion)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPTID 500 (Stallion)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPTID 500 (Stallion)'
);

-- line #9720
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPTOP 500 (Systopic)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPTOP 500 (Systopic)'
);

-- line #9721
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPURE 250 (Finecure)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPURE 250 (Finecure)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPURE 500 (Finecure)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPURE 500 (Finecure)'
);

-- line #9722
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPVEN 250 (VENSAT)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPVEN 250 (VENSAT)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPVEN 500 (VENSAT)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPVEN 500 (VENSAT)'
);

-- line #9723
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPZON 500 (Medizone)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPZON 500 (Medizone)'
);

-- line #9724
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Ciprofloxacin', u'always_empty': u'', u'form': u'EYE DPS', u'brand': u'CIPZY', u'strength_3': u'', u'company': u'Zee Lab', u'unit': u''}

-- line #9725
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPZY 125 (Zee Lab)',
	'Ciprofloxacin',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPZY 125 (Zee Lab)'
);

-- line #9726
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPZY 250 (Zee Lab)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPZY 250 (Zee Lab)'
);

-- line #9727
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPZY 500 (Zee Lab)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPZY 500 (Zee Lab)'
);

-- line #9728
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIRONEX 250 (Nestor)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIRONEX 250 (Nestor)'
);

-- line #9729
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIRPOTECH 250 (PHARMATECH)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIRPOTECH 250 (PHARMATECH)'
);

-- line #9730
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIRPOWIN 750 (Alembic)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIRPOWIN 750 (Alembic)'
);

-- line #9731
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIWI 250 (Winsome Lab)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIWI 250 (Winsome Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIWI 500 (Winsome Lab)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIWI 500 (Winsome Lab)'
);

-- line #9732
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIXIN 250 (Chemo Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIXIN 250 (Chemo Ph.)'
);

-- line #9733
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIXIN 500 (Chemo Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIXIN 500 (Chemo Ph.)'
);

-- line #9734
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C 500 (Gsk)',
	'Ciprofloxacin',
	'OD TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C 500 (Gsk)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C 1000 (Gsk)',
	'Ciprofloxacin',
	'OD TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C 1000 (Gsk)'
);

-- line #9735
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ciprofloxacin', u'always_empty': u'', u'form': u'TAB', u'brand': u'COFLOX', u'strength_3': u'', u'company': u'Macleods', u'unit': u''}

-- line #9736
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COFLOX 500 (Macleods)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COFLOX 500 (Macleods)'
);

-- line #9737
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COFLOX 750 (Macleods)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COFLOX 750 (Macleods)'
);

-- line #9738
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONFLOX 3 (Concept)',
	'Ciprofloxacin',
	'E/E DPS',
	gm.nullify_empty_string('3')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONFLOX 3 (Concept)'
);

-- line #9739
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONFLOX 200 (Concept)',
	'Ciprofloxacin',
	'INF',
	gm.nullify_empty_string('200')::numeric,
	'mg/100ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONFLOX 200 (Concept)'
);

-- line #9740
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONFLOX 250 (Concept)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONFLOX 250 (Concept)'
);

-- line #9741
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONFLOX 500 (Concept)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONFLOX 500 (Concept)'
);

-- line #9742
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORPATH 250 (Corona)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORPATH 250 (Corona)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORPATH 500 (Corona)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORPATH 500 (Corona)'
);

-- line #9743
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COSFLOX 0.3 (Cosme Hc.)',
	'Ciprofloxacin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COSFLOX 0.3 (Cosme Hc.)'
);

-- line #9744
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COSFLOX 250 (Cosme Hc.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COSFLOX 250 (Cosme Hc.)'
);

-- line #9745
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COSFLOX 500 (Cosme Hc.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COSFLOX 500 (Cosme Hc.)'
);

-- line #9746
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COUTIM 250 (Jagsonpal)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COUTIM 250 (Jagsonpal)'
);

-- line #9747
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COUTIM 500 (Jagsonpal)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COUTIM 500 (Jagsonpal)'
);

-- line #9748
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-PRO 250 (Corona)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-PRO 250 (Corona)'
);

-- line #9749
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-PRO 500 (Corona)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-PRO 500 (Corona)'
);

-- line #9750
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CROMED 250 (Biosmith)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CROMED 250 (Biosmith)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CROMED 500 (Biosmith)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CROMED 500 (Biosmith)'
);

-- line #9751
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYPRIN 3 (Intra Lab)',
	'Ciprofloxacin',
	'DPS',
	gm.nullify_empty_string('3')::numeric,
	'mg/ML+HPMC'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYPRIN 3 (Intra Lab)'
);

-- line #9752
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYPRIN 250 (Intra Lab)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYPRIN 250 (Intra Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYPRIN 500 (Intra Lab)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYPRIN 500 (Intra Lab)'
);

-- line #9753
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DALPIC 250 (Dallas Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DALPIC 250 (Dallas Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DALPIC 500 (Dallas Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DALPIC 500 (Dallas Ph.)'
);

-- line #9754
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DARWIN 250 (Ferret Int.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DARWIN 250 (Ferret Int.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DARWIN 500 (Ferret Int.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DARWIN 500 (Ferret Int.)'
);

-- line #9755
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DENCIP 250 (Eden Hc.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DENCIP 250 (Eden Hc.)'
);

-- line #9756
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DENCIP 500 (Eden Hc.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DENCIP 500 (Eden Hc.)'
);

-- line #9757
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DISQUIN 100 (Wockhardt)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DISQUIN 100 (Wockhardt)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DISQUIN 250 (Wockhardt)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DISQUIN 250 (Wockhardt)'
);

-- line #9758
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUCIP 250 (Depone)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUCIP 250 (Depone)'
);

-- line #9759
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUCIP 500 (Depone)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUCIP 500 (Depone)'
);

-- line #9760
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DURAFLOX 0.3 (Ophthal R.)',
	'Ciprofloxacin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DURAFLOX 0.3 (Ophthal R.)'
);

-- line #9761
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DURAFLOX 250 (Ophthal R.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DURAFLOX 250 (Ophthal R.)'
);

-- line #9762
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DURAFLOX 500 (Ophthal R.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DURAFLOX 500 (Ophthal R.)'
);

-- line #9763
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYCIP-250/500 250 (Dynamic)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYCIP-250/500 250 (Dynamic)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYCIP-250/500 500 (Dynamic)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYCIP-250/500 500 (Dynamic)'
);

-- line #9764
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYCIP 0.3 (Dynamic)',
	'Ciprofloxacin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYCIP 0.3 (Dynamic)'
);

-- line #9765
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'E-CIP 250 (MARLINE BIO.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'E-CIP 250 (MARLINE BIO.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'E-CIP 500 (MARLINE BIO.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'E-CIP 500 (MARLINE BIO.)'
);

-- line #9766
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'E-FLOX 500 (Fairdeal Res.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'E-FLOX 500 (Fairdeal Res.)'
);

-- line #9767
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELQUIN 250 (Lancer)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELQUIN 250 (Lancer)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELQUIN 500 (Lancer)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELQUIN 500 (Lancer)'
);

-- line #9768
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMCIP 250 (Medico)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMCIP 250 (Medico)'
);

-- line #9769
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMCIP 500 (Medico)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMCIP 500 (Medico)'
);

-- line #9770
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESTALO 500 (R.B.REM.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESTALO 500 (R.B.REM.)'
);

-- line #9771
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUCIP 250 (Dynamic)',
	'Ciprofloxacin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUCIP 250 (Dynamic)'
);

-- line #9772
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUCIP 250 (Dynamic)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUCIP 250 (Dynamic)'
);

-- line #9773
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUCIP 500 (Dynamic)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUCIP 500 (Dynamic)'
);

-- line #9774
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOCY 0.3 (Sun)',
	'Ciprofloxacin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOCY 0.3 (Sun)'
);

-- line #9775
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOCY 250 (Sun)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOCY 250 (Sun)'
);

-- line #9776
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOCY 500 (Sun)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOCY 500 (Sun)'
);

-- line #9777
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOTOX 500 (Medoz Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg(HCL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOTOX 500 (Medoz Ph.)'
);

-- line #9778
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXANIL 250 (Marc Lab)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXANIL 250 (Marc Lab)'
);

-- line #9779
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXANIL 500 (Marc Lab)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXANIL 500 (Marc Lab)'
);

-- line #9780
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXAQUIN-C 250 (Themis)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg(HCL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXAQUIN-C 250 (Themis)'
);

-- line #9781
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXAQUIN-C 500 (Themis)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg(HCL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXAQUIN-C 500 (Themis)'
);

-- line #9782
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXCIN 500 (LUSTRE)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXCIN 500 (LUSTRE)'
);

-- line #9783
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOX-C 250 (Zorex Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOX-C 250 (Zorex Ph.)'
);

-- line #9784
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOX-C 500 (Zorex Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOX-C 500 (Zorex Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOX-C 750 (Zorex Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOX-C 750 (Zorex Ph.)'
);

-- line #9785
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXIGARD 3 (Guardian)',
	'Ciprofloxacin',
	'EYE DPS',
	gm.nullify_empty_string('3')::numeric,
	'mg(LACTATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXIGARD 3 (Guardian)'
);

-- line #9786
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXIMIL 250 (Shaimil)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg(HCL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXIMIL 250 (Shaimil)'
);

-- line #9787
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXIMIL 500 (Shaimil)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg(HCL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXIMIL 500 (Shaimil)'
);

-- line #9788
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXIP 100 (Max)',
	'Ciprofloxacin',
	'INF',
	gm.nullify_empty_string('100')::numeric,
	'mg/50ML(AS LACTATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXIP 100 (Max)'
);

-- line #9789
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXIP 250 (Max)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg(HCL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXIP 250 (Max)'
);

-- line #9790
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXIP 500 (Max)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg(HCL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXIP 500 (Max)'
);

-- line #9791
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXONIL 250 (Marc Lab)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXONIL 250 (Marc Lab)'
);

-- line #9792
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXONIL 500 (Marc Lab)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXONIL 500 (Marc Lab)'
);

-- line #9793
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXONIL 750 (Marc Lab)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXONIL 750 (Marc Lab)'
);

-- line #9794
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORCIP 250 (Health Care)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORCIP 250 (Health Care)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORCIP 500 (Health Care)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORCIP 500 (Health Care)'
);

-- line #9795
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FRENCIP 250 (Indo French)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FRENCIP 250 (Indo French)'
);

-- line #9796
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FRENCIP 500 (Indo French)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FRENCIP 500 (Indo French)'
);

-- line #9797
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FULGRAM 250 (U S V)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg(HCL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FULGRAM 250 (U S V)'
);

-- line #9798
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FULGRAM 500 (U S V)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg(HCL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FULGRAM 500 (U S V)'
);

-- line #9799
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FYCIP 500 (Phytochem)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FYCIP 500 (Phytochem)'
);

-- line #9800
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G''FLOX 0.3 (Gland Ph.)',
	'Ciprofloxacin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G''FLOX 0.3 (Gland Ph.)'
);

-- line #9801
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G-FLOX 500 (Shrinivas)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G-FLOX 500 (Shrinivas)'
);

-- line #9802
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLOCIP 250 (Globus)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLOCIP 250 (Globus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLOCIP 500 (Globus)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLOCIP 500 (Globus)'
);

-- line #9803
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEXCIN 500 (HEXAL PH.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEXCIN 500 (HEXAL PH.)'
);

-- line #9804
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HICIP 250 (Intra Lab)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HICIP 250 (Intra Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HICIP 500 (Intra Lab)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HICIP 500 (Intra Lab)'
);

-- line #9805
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ICIP 3 (Elder)',
	'Ciprofloxacin',
	'DPS',
	gm.nullify_empty_string('3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ICIP 3 (Elder)'
);

-- line #9806
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ICIP 0.3 (Elder)',
	'Ciprofloxacin',
	'E/E DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ICIP 0.3 (Elder)'
);

-- line #9807
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IFICIPRO 200 (Unique)',
	'Ciprofloxacin',
	'INF',
	gm.nullify_empty_string('200')::numeric,
	'mg/100ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IFICIPRO 200 (Unique)'
);

-- line #9808
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INCIPRO 500 (Indu D.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INCIPRO 500 (Indu D.)'
);

-- line #9809
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INFACIN 250 (Indu D.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INFACIN 250 (Indu D.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INFACIN 500 (Indu D.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INFACIN 500 (Indu D.)'
);

-- line #9810
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INVINCIN 250 (Mount M.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INVINCIN 250 (Mount M.)'
);

-- line #9811
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INVINCIN 500 (Mount M.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INVINCIN 500 (Mount M.)'
);

-- line #9812
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IPHALOX 250 (National)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IPHALOX 250 (National)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IPHALOX 500 (National)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IPHALOX 500 (National)'
);

-- line #9813
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JIPROCARE 500 (J.P. HC.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JIPROCARE 500 (J.P. HC.)'
);

-- line #9814
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JOXIN 0.3 (Jawa Ph.)',
	'Ciprofloxacin',
	'OINT',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JOXIN 0.3 (Jawa Ph.)'
);

-- line #9815
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KIMPRO 250 (Kim Lab)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KIMPRO 250 (Kim Lab)'
);

-- line #9816
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KIMPRO 500 (Kim Lab)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KIMPRO 500 (Kim Lab)'
);

-- line #9817
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LACIPRON 250 (ACTO)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LACIPRON 250 (ACTO)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LACIPRON 500 (ACTO)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LACIPRON 500 (ACTO)'
);

-- line #9818
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAKCIP 250 (LAKSUN)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAKCIP 250 (LAKSUN)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAKCIP 500 (LAKSUN)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAKCIP 500 (LAKSUN)'
);

-- line #9819
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEXFLOX 250 (Lexus)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEXFLOX 250 (Lexus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEXFLOX 500 (Lexus)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEXFLOX 500 (Lexus)'
);

-- line #9820
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LONGACIN 0.3 (M.S.Opth.)',
	'Ciprofloxacin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LONGACIN 0.3 (M.S.Opth.)'
);

-- line #9821
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUCIPRO 250 (LUPIN)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUCIPRO 250 (LUPIN)'
);

-- line #9822
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUCIPRO 500 (LUPIN)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUCIPRO 500 (LUPIN)'
);

-- line #9823
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYPRO 250 (HETERO HC.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYPRO 250 (HETERO HC.)'
);

-- line #9824
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYPRO 500 (HETERO HC.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYPRO 500 (HETERO HC.)'
);

-- line #9825
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAFLO 0.3 (Mapra)',
	'Ciprofloxacin',
	'EYE DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAFLO 0.3 (Mapra)'
);

-- line #9826
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAFLO 0.3 (Mapra)',
	'Ciprofloxacin',
	'OINT',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAFLO 0.3 (Mapra)'
);

-- line #9827
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAFLO 250 (Mapra)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAFLO 250 (Mapra)'
);

-- line #9828
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAFLO 500 (Mapra)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAFLO 500 (Mapra)'
);

-- line #9829
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALCIP 250 (Malar Hc.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALCIP 250 (Malar Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALCIP 500 (Malar Hc.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALCIP 500 (Malar Hc.)'
);

-- line #9830
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALOCIP 500 (Malody Hc.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALOCIP 500 (Malody Hc.)'
);

-- line #9831
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANCIPRO 250 (Maan)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANCIPRO 250 (Maan)'
);

-- line #9832
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANCIPRO 500 (Maan)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANCIPRO 500 (Maan)'
);

-- line #9833
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANCIPRO 750 (Maan)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANCIPRO 750 (Maan)'
);

-- line #9834
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICROCIP 250 (Ikon Rem)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICROCIP 250 (Ikon Rem)'
);

-- line #9835
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICROCIP 500 (Ikon Rem)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICROCIP 500 (Ikon Rem)'
);

-- line #9836
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICROFLOX 0.3 (Micro Nova)',
	'Ciprofloxacin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICROFLOX 0.3 (Micro Nova)'
);

-- line #9837
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICROFLOX 250 (Micro Nova)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICROFLOX 250 (Micro Nova)'
);

-- line #9838
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICROFLOX 500 (Micro Nova)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICROFLOX 500 (Micro Nova)'
);

-- line #9839
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILFLOX 0.3 (Milmet)',
	'Ciprofloxacin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILFLOX 0.3 (Milmet)'
);

-- line #9840
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOCIP 125 (Cipla)',
	'Ciprofloxacin',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOCIP 125 (Cipla)'
);

-- line #9841
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOCIP 250 (Cipla)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOCIP 250 (Cipla)'
);

-- line #9842
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOCIP 500 (Cipla)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOCIP 500 (Cipla)'
);

-- line #9843
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEWCIP 500 (Indchemie)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEWCIP 500 (Indchemie)'
);

-- line #9844
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEXCIP 500 (Nitin Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEXCIP 500 (Nitin Ph.)'
);

-- line #9845
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIDAQUIN 500 (Bipl(Radico Lab))',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIDAQUIN 500 (Bipl(Radico Lab))'
);

-- line #9846
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVACIP 250 (Genova)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVACIP 250 (Genova)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVACIP 500 (Genova)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVACIP 500 (Genova)'
);

-- line #9847
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'N-T BEC 250 (Neon)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'N-T BEC 250 (Neon)'
);

-- line #9848
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'N-T BEC 500 (Neon)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'N-T BEC 500 (Neon)'
);

-- line #9849
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUCIPRO 0.3 (Nulife)',
	'Ciprofloxacin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUCIPRO 0.3 (Nulife)'
);

-- line #9850
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUCIP 500 (Armour Rem.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUCIP 500 (Armour Rem.)'
);

-- line #9851
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OBLID 125 (Olcare)',
	'Ciprofloxacin',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OBLID 125 (Olcare)'
);

-- line #9852
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OBLID 250 (Olcare)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OBLID 250 (Olcare)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OBLID 500 (Olcare)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OBLID 500 (Olcare)'
);

-- line #9853
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OBLID 750 (Olcare)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OBLID 750 (Olcare)'
);

-- line #9854
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODICIP 0.3 (Radix Bio.)',
	'Ciprofloxacin',
	'E/E DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODICIP 0.3 (Radix Bio.)'
);

-- line #9855
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODICIP 500 (Radix Bio.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODICIP 500 (Radix Bio.)'
);

-- line #9856
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLBID 125 (Olcare)',
	'Ciprofloxacin',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLBID 125 (Olcare)'
);

-- line #9857
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLBID 250 (Olcare)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLBID 250 (Olcare)'
);

-- line #9858
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLBID 500 (Olcare)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLBID 500 (Olcare)'
);

-- line #9859
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLBID 750 (Olcare)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLBID 750 (Olcare)'
);

-- line #9860
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMIBACT 500 (Osper)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMIBACT 500 (Osper)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMIBACT 750 (Osper)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMIBACT 750 (Osper)'
);

-- line #9861
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Ciprofloxacin', u'always_empty': u'', u'form': u'SUS', u'brand': u'OMNIFLOX', u'strength_3': u'', u'company': u'Embiotic Lab.', u'unit': u''}

-- line #9862
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMNIFLOX 250 (Embiotic Lab.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMNIFLOX 250 (Embiotic Lab.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMNIFLOX 500 (Embiotic Lab.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMNIFLOX 500 (Embiotic Lab.)'
);

-- line #9863
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMNIFLOX 750 (Embiotic Lab.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMNIFLOX 750 (Embiotic Lab.)'
);

-- line #9864
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONGEN 250 (Medicamen)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg(HCL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONGEN 250 (Medicamen)'
);

-- line #9865
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONGEN 500 (Medicamen)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg(HCL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONGEN 500 (Medicamen)'
);

-- line #9866
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORACIP 0.3 (Mercury)',
	'Ciprofloxacin',
	'E/E DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORACIP 0.3 (Mercury)'
);

-- line #9867
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORACIP 250 (Mercury)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORACIP 250 (Mercury)'
);

-- line #9868
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORACIP 500 (Mercury)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORACIP 500 (Mercury)'
);

-- line #9869
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORPIC 250 (Dey''S)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORPIC 250 (Dey''S)'
);

-- line #9870
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORPIC 500 (Dey''S)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORPIC 500 (Dey''S)'
);

-- line #9871
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORYBID 125 (Jrs Oryx.)',
	'Ciprofloxacin',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORYBID 125 (Jrs Oryx.)'
);

-- line #9872
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORYBID 250 (Jrs Oryx.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORYBID 250 (Jrs Oryx.)'
);

-- line #9873
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSOBID 250 (Osho Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSOBID 250 (Osho Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSOBID 500 (Osho Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSOBID 500 (Osho Ph.)'
);

-- line #9874
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OX-250/500 250 (Prochem)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OX-250/500 250 (Prochem)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OX-250/500 500 (Prochem)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OX-250/500 500 (Prochem)'
);

-- line #9875
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OZOCIP 500 (Ozone Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OZOCIP 500 (Ozone Ph.)'
);

-- line #9876
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANZER 250 (Medispan)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANZER 250 (Medispan)'
);

-- line #9877
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANZER 500 (Medispan)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANZER 500 (Medispan)'
);

-- line #9878
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANZER 0.3 (Medispan)',
	'Ciprofloxacin',
	'VIAL',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANZER 0.3 (Medispan)'
);

-- line #9879
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANZER 0.3 (Medispan)',
	'Ciprofloxacin',
	'VIAL',
	gm.nullify_empty_string('0.3')::numeric,
	'% W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANZER 0.3 (Medispan)'
);

-- line #9880
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENCIP 500 (SAFE PH.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENCIP 500 (SAFE PH.)'
);

-- line #9881
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENQUIN 100 (Hal)',
	'Ciprofloxacin',
	'INFUSION',
	gm.nullify_empty_string('100')::numeric,
	'mg/50ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENQUIN 100 (Hal)'
);

-- line #9882
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENQUIN 250 (Hal)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENQUIN 250 (Hal)'
);

-- line #9883
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENQUIN 500 (Hal)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENQUIN 500 (Hal)'
);

-- line #9884
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERKOCIP 250 (Perk Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERKOCIP 250 (Perk Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERKOCIP 500 (Perk Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERKOCIP 500 (Perk Ph.)'
);

-- line #9885
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POWERCIP 250 (INVISION(INFALIFE))',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POWERCIP 250 (INVISION(INFALIFE))'
);

-- line #9886
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROBID 250 (Active Hc.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROBID 250 (Active Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROBID 500 (Active Hc.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROBID 500 (Active Hc.)'
);

-- line #9887
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRODEL 250 (Citadel)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRODEL 250 (Citadel)'
);

-- line #9888
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRODEL 500 (Citadel)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRODEL 500 (Citadel)'
);

-- line #9889
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROX 250 (Pharmed)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROX 250 (Pharmed)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROX 500 (Pharmed)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROX 500 (Pharmed)'
);

-- line #9890
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q-BACT 250 (Saga Lab)',
	'Ciprofloxacin',
	'SUS',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q-BACT 250 (Saga Lab)'
);

-- line #9891
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q-BACT 250 (Saga Lab)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q-BACT 250 (Saga Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q-BACT 500 (Saga Lab)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q-BACT 500 (Saga Lab)'
);

-- line #9892
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q-BID 0.3 (Kamron)',
	'Ciprofloxacin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q-BID 0.3 (Kamron)'
);

-- line #9893
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q-BID 250 (Kamron)',
	'Ciprofloxacin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q-BID 250 (Kamron)'
);

-- line #9894
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q BID 250 (Kamron)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q BID 250 (Kamron)'
);

-- line #9895
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q-BID 250 (Kamron)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q-BID 250 (Kamron)'
);

-- line #9896
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q BID 500 (Kamron)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q BID 500 (Kamron)'
);

-- line #9897
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q-BID 500 (Kamron)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q-BID 500 (Kamron)'
);

-- line #9898
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q BID 750 (Kamron)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q BID 750 (Kamron)'
);

-- line #9899
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QCBI 250 (Pharmed)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QCBI 250 (Pharmed)'
);

-- line #9900
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QCBI 500 (Pharmed)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QCBI 500 (Pharmed)'
);

-- line #9901
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q CIPROX 250 (Que Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q CIPROX 250 (Que Ph.)'
);

-- line #9902
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q CIPROX 500 (Que Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q CIPROX 500 (Que Ph.)'
);

-- line #9903
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QCIP 250 (Lanark)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QCIP 250 (Lanark)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QCIP 500 (Lanark)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QCIP 500 (Lanark)'
);

-- line #9904
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QFLOX 500 (SIFAM PH.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QFLOX 500 (SIFAM PH.)'
);

-- line #9905
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUEP 250 (Neo Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUEP 250 (Neo Ph.)'
);

-- line #9906
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUEP 500 (Neo Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUEP 500 (Neo Ph.)'
);

-- line #9907
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUFLOX 250 (Beckcem)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUFLOX 250 (Beckcem)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUFLOX 500 (Beckcem)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUFLOX 500 (Beckcem)'
);

-- line #9908
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINCIP 250 (Baroque)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINCIP 250 (Baroque)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINCIP 500 (Baroque)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINCIP 500 (Baroque)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINCIP 750 (Baroque)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINCIP 750 (Baroque)'
);

-- line #9909
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINCIP 500 (Smiles Inc.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINCIP 500 (Smiles Inc.)'
);

-- line #9910
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUIN-C 250 (Kapl)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUIN-C 250 (Kapl)'
);

-- line #9911
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUIN-C 500 (Kapl)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUIN-C 500 (Kapl)'
);

-- line #9912
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINCY 250 (Gland Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINCY 250 (Gland Ph.)'
);

-- line #9913
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINCY 500 (Gland Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINCY 500 (Gland Ph.)'
);

-- line #9914
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINOBACT 250 (Abbott)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINOBACT 250 (Abbott)'
);

-- line #9915
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINOBACT 500 (Abbott)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINOBACT 500 (Abbott)'
);

-- line #9916
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINOBA 250 (Life Line)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINOBA 250 (Life Line)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINOBA 500 (Life Line)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINOBA 500 (Life Line)'
);

-- line #9917
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINOCIP 500 (UNI OR.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINOCIP 500 (UNI OR.)'
);

-- line #9918
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINOLOP 250 (TALENT LAB.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINOLOP 250 (TALENT LAB.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINOLOP 500 (TALENT LAB.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINOLOP 500 (TALENT LAB.)'
);

-- line #9919
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINOPIC 250 (Alpic Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINOPIC 250 (Alpic Ph.)'
);

-- line #9920
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINOPIC 500 (Alpic Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINOPIC 500 (Alpic Ph.)'
);

-- line #9921
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINOPIC 750 (Alpic Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINOPIC 750 (Alpic Ph.)'
);

-- line #9922
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINORID 500 (Elfin Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINORID 500 (Elfin Ph.)'
);

-- line #9923
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINOSAR 250 (Serve Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINOSAR 250 (Serve Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINOSAR 500 (Serve Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINOSAR 500 (Serve Ph.)'
);

-- line #9924
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINOTAB 250 (Gsk)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINOTAB 250 (Gsk)'
);

-- line #9925
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINOTAB 500 (Gsk)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINOTAB 500 (Gsk)'
);

-- line #9926
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINOWIN 50 (Taurus Lab)',
	'Ciprofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINOWIN 50 (Taurus Lab)'
);

-- line #9927
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINOXIN 250 (Chemo Bio.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINOXIN 250 (Chemo Bio.)'
);

-- line #9928
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINOXIN 500 (Chemo Bio.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINOXIN 500 (Chemo Bio.)'
);

-- line #9929
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINOXIN 750 (Chemo Bio.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINOXIN 750 (Chemo Bio.)'
);

-- line #9930
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINOX 250 (Arbro Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg(HCL MON.HYD.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINOX 250 (Arbro Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINOX 500 (Arbro Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg(HCL MON.HYD.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINOX 500 (Arbro Ph.)'
);

-- line #9931
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINTOR 2 (Torrent)',
	'Ciprofloxacin',
	'INF',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINTOR 2 (Torrent)'
);

-- line #9932
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINTOR 1000 (Torrent)',
	'Ciprofloxacin',
	'OD TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINTOR 1000 (Torrent)'
);

-- line #9933
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINTOR 500 (Torrent)',
	'Ciprofloxacin',
	'OD TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINTOR 500 (Torrent)'
);

-- line #9934
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINTOR 250 (Torrent)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINTOR 250 (Torrent)'
);

-- line #9935
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINTOR 500 (Torrent)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINTOR 500 (Torrent)'
);

-- line #9936
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINTOR 750 (Torrent)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINTOR 750 (Torrent)'
);

-- line #9937
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAFLOX 250 (Shreya)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAFLOX 250 (Shreya)'
);

-- line #9938
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAFLOX 500 (Shreya)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAFLOX 500 (Shreya)'
);

-- line #9939
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'R-CIPRON 250 (Reliance)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'R-CIPRON 250 (Reliance)'
);

-- line #9940
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'R-CIPRON 500 (Reliance)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'R-CIPRON 500 (Reliance)'
);

-- line #9941
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REALCIP-500 500 (Royal)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REALCIP-500 500 (Royal)'
);

-- line #9942
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REBAC 250 (Hygeia Ph.)',
	'Ciprofloxacin',
	'INF',
	gm.nullify_empty_string('250')::numeric,
	'mg/10ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REBAC 250 (Hygeia Ph.)'
);

-- line #9943
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RECIPRO 250 (Aurobindo)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RECIPRO 250 (Aurobindo)'
);

-- line #9944
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RECIPRO 500 (Aurobindo)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RECIPRO 500 (Aurobindo)'
);

-- line #9945
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RECOCIF 100 (Zydus Cadila)',
	'Ciprofloxacin',
	'INF',
	gm.nullify_empty_string('100')::numeric,
	'mg/50ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RECOCIF 100 (Zydus Cadila)'
);

-- line #9946
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RECOCIF 250 (Zydus Cadila)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RECOCIF 250 (Zydus Cadila)'
);

-- line #9947
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RECOCIF 500 (Zydus Cadila)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RECOCIF 500 (Zydus Cadila)'
);

-- line #9948
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REECIP 500 (Remedy)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REECIP 500 (Remedy)'
);

-- line #9949
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REFLOX 250 (FORTUNE HC.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REFLOX 250 (FORTUNE HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REFLOX 500 (FORTUNE HC.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REFLOX 500 (FORTUNE HC.)'
);

-- line #9950
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIFLOXIN 250 (Ritz Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIFLOXIN 250 (Ritz Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIFLOXIN 500 (Ritz Ph.)',
	'Ciprofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIFLOXIN 500 (Ritz Ph.)'
);

-- line #9951
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALIPRIDE 10 (Centaur)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALIPRIDE 10 (Centaur)'
);

-- line #9952
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPRISE 10 (Emil Ph.)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPRISE 10 (Emil Ph.)'
);

-- line #9953
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEASEALL 10 (Allure Rem.)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEASEALL 10 (Allure Rem.)'
);

-- line #9954
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CENZ 10 (LA DRUG)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CENZ 10 (LA DRUG)'
);

-- line #9955
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CILOID FLASH 10 (NOVARTIS)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CILOID FLASH 10 (NOVARTIS)'
);

-- line #9956
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CILOID 10 (NOVARTIS)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CILOID 10 (NOVARTIS)'
);

-- line #9957
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CINZA 10 (Norris Med.)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CINZA 10 (Norris Med.)'
);

-- line #9958
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPID 10 (Shinto Org.)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPID 10 (Shinto Org.)'
);

-- line #9959
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CISADE 1 (Unichem)',
	'Cisapride',
	'SUS',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CISADE 1 (Unichem)'
);

-- line #9960
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CISADE 10 (Unichem)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CISADE 10 (Unichem)'
);

-- line #9961
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CISALONE 5 (Svizera)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg/10'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CISALONE 5 (Svizera)'
);

-- line #9962
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CISANORM 10 (Gufic Bio.)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg(MONOHYDR.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CISANORM 10 (Gufic Bio.)'
);

-- line #9963
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CISAPID 1 (Kopran)',
	'Cisapride',
	'SUS',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CISAPID 1 (Kopran)'
);

-- line #9964
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CISAPID 10 (Kopran)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CISAPID 10 (Kopran)'
);

-- line #9965
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CISAPRO 1 (Zydus A.)',
	'Cisapride',
	'SUS',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CISAPRO 1 (Zydus A.)'
);

-- line #9966
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CISAPRO 10 (Zydus A.)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CISAPRO 10 (Zydus A.)'
);

-- line #9967
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CISAPRO 5 (Zydus A.)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CISAPRO 5 (Zydus A.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CISAPRO 20 (Zydus A.)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CISAPRO 20 (Zydus A.)'
);

-- line #9968
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CISARIDE 10 (Armour Rem.)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CISARIDE 10 (Armour Rem.)'
);

-- line #9969
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CISATAUR 10 (Taurus Lab)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CISATAUR 10 (Taurus Lab)'
);

-- line #9970
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CISATEN 10 (Kamron)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CISATEN 10 (Kamron)'
);

-- line #9971
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CISAWAL 10 (Wallace)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CISAWAL 10 (Wallace)'
);

-- line #9972
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CISPEL 1 (Panacea)',
	'Cisapride',
	'SUS',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CISPEL 1 (Panacea)'
);

-- line #9973
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CISPEL 10 (Panacea)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CISPEL 10 (Panacea)'
);

-- line #9974
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CISPEL 5 (Panacea)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CISPEL 5 (Panacea)'
);

-- line #9975
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CISZY 10 (Zee Lab)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CISZY 10 (Zee Lab)'
);

-- line #9976
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIZAFAST 10 (Claris L.)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIZAFAST 10 (Claris L.)'
);

-- line #9977
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIZAP 10 (Reliance)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg(MONOHYDR.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIZAP 10 (Reliance)'
);

-- line #9978
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIZA 1 (Intas)',
	'Cisapride',
	'SUS',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIZA 1 (Intas)'
);

-- line #9979
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIZA 20 (Intas)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIZA 20 (Intas)'
);

-- line #9980
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIZA 5 (Intas)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg/10'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIZA 5 (Intas)'
);

-- line #9981
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENTRONORM 10 (Beckcem)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENTRONORM 10 (Beckcem)'
);

-- line #9982
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESOPRIDE 5 (Makers)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg/10'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESOPRIDE 5 (Makers)'
);

-- line #9983
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESORID 20 (Sun)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESORID 20 (Sun)'
);

-- line #9984
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESORID 5 (Sun)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg/10'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESORID 5 (Sun)'
);

-- line #9985
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GASTRON 10 (Inga)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GASTRON 10 (Inga)'
);

-- line #9986
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GASTROPEN 5 (Morepen)',
	'Cisapride',
	'DT',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GASTROPEN 5 (Morepen)'
);

-- line #9987
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GASTROPEN 10 (Morepen)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg/20'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GASTROPEN 10 (Morepen)'
);

-- line #9988
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GASTRO 10 (Cipla)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GASTRO 10 (Cipla)'
);

-- line #9989
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GIM 10 (LUSTRE)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GIM 10 (LUSTRE)'
);

-- line #9990
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEMOPRIDE 10 (Chemo D.)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg(ANHYDR.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEMOPRIDE 10 (Chemo D.)'
);

-- line #9991
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAKPRIDE 10 (Shalaks)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAKPRIDE 10 (Shalaks)'
);

-- line #9992
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILPRIDE 10 (Shaimil)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILPRIDE 10 (Shaimil)'
);

-- line #9993
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOCIS 10 (Olcare)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOCIS 10 (Olcare)'
);

-- line #9994
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOSYS 5 (Systopic)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOSYS 5 (Systopic)'
);

-- line #9995
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOTEN 1 (Ranbaxy)',
	'Cisapride',
	'SUSP',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOTEN 1 (Ranbaxy)'
);

-- line #9996
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOTEN 1 (Rexcel)',
	'Cisapride',
	'SUS',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOTEN 1 (Rexcel)'
);

-- line #9997
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOTEN 10 (Ranbaxy)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOTEN 10 (Ranbaxy)'
);

-- line #9998
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOTEN 10 (Rexcel)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOTEN 10 (Rexcel)'
);

-- line #9999
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOTICARE 10 (Infar)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOTICARE 10 (Infar)'
);

-- line #10000
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOTILAX 1 (U S V)',
	'Cisapride',
	'SUS',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOTILAX 1 (U S V)'
);

-- line #10001
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOTILAX 10 (U S V)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOTILAX 10 (U S V)'
);

-- line #10002
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORMOKIME 10 (Wanbury)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORMOKIME 10 (Wanbury)'
);

-- line #10003
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORMOPEL 10 (Waves Bio.)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORMOPEL 10 (Waves Bio.)'
);

-- line #10004
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NRMOPEL 10 (Waves Bio.)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NRMOPEL 10 (Waves Bio.)'
);

-- line #10005
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUPRIDE 10 (East India)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUPRIDE 10 (East India)'
);

-- line #10006
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERISTAL 10 (Marc Lab)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERISTAL 10 (Marc Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERISTAL 20 (Marc Lab)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERISTAL 20 (Marc Lab)'
);

-- line #10007
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERISTIL 1 (Dr.Reddy''S)',
	'Cisapride',
	'SUS',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERISTIL 1 (Dr.Reddy''S)'
);

-- line #10008
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERISTIL 5 (Dr.Reddy''S)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg/10'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERISTIL 5 (Dr.Reddy''S)'
);

-- line #10009
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREPULSID 5 (Ethnor)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg/10'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREPULSID 5 (Ethnor)'
);

-- line #10010
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIDE 10 (Dial Ph.)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIDE 10 (Dial Ph.)'
);

-- line #10011
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROCISA 10 (Jenburkt)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROCISA 10 (Jenburkt)'
);

-- line #10012
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROGIT 10 (Bal Ph.)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROGIT 10 (Bal Ph.)'
);

-- line #10013
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROGIT 10 (Jenburkt)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROGIT 10 (Jenburkt)'
);

-- line #10014
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROKINE 5 (Rpg Life)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg/10'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROKINE 5 (Rpg Life)'
);

-- line #10015
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRYDE 10 (Aurobindo)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRYDE 10 (Aurobindo)'
);

-- line #10016
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PULSID 1 (Max)',
	'Cisapride',
	'SUS',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML(MONOHYDR.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PULSID 1 (Max)'
);

-- line #10017
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PULSID 10 (Max)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg(MONOHYDR.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PULSID 10 (Max)'
);

-- line #10018
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PULSID 5 (Max)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg (MONOHYDR.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PULSID 5 (Max)'
);

-- line #10019
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYROCIZ 10 (Strassenburg)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYROCIZ 10 (Strassenburg)'
);

-- line #10020
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RHONEPRIDE 10 (Nicholas)',
	'Cisapride',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RHONEPRIDE 10 (Nicholas)'
);

-- line #10021
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMCIS 10 (AMRONCO)',
	'Cisplatin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMCIS 10 (AMRONCO)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMCIS 50 (AMRONCO)',
	'Cisplatin',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMCIS 50 (AMRONCO)'
);

-- line #10022
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLASTOLEM 10 (Elder)',
	'Cisplatin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLASTOLEM 10 (Elder)'
);

-- line #10023
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLASTOLEM 50 (Elder)',
	'Cisplatin',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLASTOLEM 50 (Elder)'
);

-- line #10024
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELPAT 10 (CELON(VIVILON))',
	'Cisplatin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'50'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELPAT 10 (CELON(VIVILON))'
);

-- line #10025
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CISPA 10 (Novatech)',
	'Cisplatin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CISPA 10 (Novatech)'
);

-- line #10026
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CISPA 50 (Novatech)',
	'Cisplatin',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CISPA 50 (Novatech)'
);

-- line #10027
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CISPLAN 10 (Natco Ph.)',
	'Cisplatin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CISPLAN 10 (Natco Ph.)'
);

-- line #10028
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CISPLAN 50 (Natco Ph.)',
	'Cisplatin',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CISPLAN 50 (Natco Ph.)'
);

-- line #10029
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1', u'strength_2': u'', u'substance': u'Cisplatin', u'always_empty': u'', u'form': u'', u'brand': u'CISPLATIN', u'strength_3': u'', u'company': u"Dr.Reddy''S", u'unit': u'mg/ML'}

-- line #10030
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CISPLATIN 10 (Biochem)',
	'Cisplatin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg/20ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CISPLATIN 10 (Biochem)'
);

-- line #10031
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CISPLATIN 50 (Biochem)',
	'Cisplatin',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CISPLATIN 50 (Biochem)'
);

-- line #10032
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CISPLATIN 10 (Khandelwal)',
	'Cisplatin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg/20ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CISPLATIN 10 (Khandelwal)'
);

-- line #10033
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CISPLATIN 10 (Vhb)',
	'Cisplatin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CISPLATIN 10 (Vhb)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CISPLATIN 50 (Vhb)',
	'Cisplatin',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CISPLATIN 50 (Vhb)'
);

-- line #10034
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CISPLAT 10 (Biochem)',
	'Cisplatin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg/10ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CISPLAT 10 (Biochem)'
);

-- line #10035
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CISPLAT 50 (Biochem)',
	'Cisplatin',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/50ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CISPLAT 50 (Biochem)'
);

-- line #10036
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CISTEEN 10 (Vhb)',
	'Cisplatin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CISTEEN 10 (Vhb)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CISTEEN 50 (Vhb)',
	'Cisplatin',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CISTEEN 50 (Vhb)'
);

-- line #10037
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CISTEEN 10 (MIRACALUS)',
	'Cisplatin',
	'VIAL',
	gm.nullify_empty_string('10')::numeric,
	'mg/20ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CISTEEN 10 (MIRACALUS)'
);

-- line #10038
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CISTEEN 50 (MIRACALUS)',
	'Cisplatin',
	'VIAL',
	gm.nullify_empty_string('50')::numeric,
	'mg/20ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CISTEEN 50 (MIRACALUS)'
);

-- line #10039
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CISTRIZ 10 (Shantha Bio.)',
	'Cisplatin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CISTRIZ 10 (Shantha Bio.)'
);

-- line #10040
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CISTRIZ 50 (Shantha Bio.)',
	'Cisplatin',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CISTRIZ 50 (Shantha Bio.)'
);

-- line #10041
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CISTRIZ 200 (Shantha Bio.)',
	'Cisplatin',
	'VIAL',
	gm.nullify_empty_string('200')::numeric,
	'1000'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CISTRIZ 200 (Shantha Bio.)'
);

-- line #10042
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYTOPLATIN 10 (Cipla)',
	'Cisplatin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYTOPLATIN 10 (Cipla)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYTOPLATIN 50 (Cipla)',
	'Cisplatin',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYTOPLATIN 50 (Cipla)'
);

-- line #10043
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUPLAT 10 (Samarth)',
	'Cisplatin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUPLAT 10 (Samarth)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUPLAT 50 (Samarth)',
	'Cisplatin',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUPLAT 50 (Samarth)'
);

-- line #10044
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEMOPLAT 10 (Dabur Ph.)',
	'Cisplatin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEMOPLAT 10 (Dabur Ph.)'
);

-- line #10045
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEMOPLAT 50 (Dabur Ph.)',
	'Cisplatin',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEMOPLAT 50 (Dabur Ph.)'
);

-- line #10046
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOPLAT 10 (Biological E.)',
	'Cisplatin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOPLAT 10 (Biological E.)'
);

-- line #10047
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOPLAT 50 (Biological E.)',
	'Cisplatin',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOPLAT 50 (Biological E.)'
);

-- line #10048
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONCOPLATIN-AQ 10 (Sun)',
	'Cisplatin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONCOPLATIN-AQ 10 (Sun)'
);

-- line #10049
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONCOPLATIN-AQ 50 (Sun)',
	'Cisplatin',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONCOPLATIN-AQ 50 (Sun)'
);

-- line #10050
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PALTIONOCO 10 (CH.Bhagat)',
	'Cisplatin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PALTIONOCO 10 (CH.Bhagat)'
);

-- line #10051
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLATICARE 1 (Criticare)',
	'Cisplatin',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLATICARE 1 (Criticare)'
);

-- line #10052
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLATICIS 10 (German R.)',
	'Cisplatin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLATICIS 10 (German R.)'
);

-- line #10053
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLATICIS 50 (German R.)',
	'Cisplatin',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLATICIS 50 (German R.)'
);

-- line #10054
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLATIKEM 10 (Cytomed(Alkem))',
	'Cisplatin',
	'V',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLATIKEM 10 (Cytomed(Alkem))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLATIKEM 50 (Cytomed(Alkem))',
	'Cisplatin',
	'V',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLATIKEM 50 (Cytomed(Alkem))'
);

-- line #10055
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLATINEX 10 (Khandelwal)',
	'Cisplatin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg/10'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLATINEX 10 (Khandelwal)'
);

-- line #10056
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLATIN 10 (Cadila Ph.)',
	'Cisplatin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg/V.'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLATIN 10 (Cadila Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLATIN 50 (Cadila Ph.)',
	'Cisplatin',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/V.'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLATIN 50 (Cadila Ph.)'
);

-- line #10057
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLATIONCO 10 (CH.Bhagat)',
	'Cisplatin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLATIONCO 10 (CH.Bhagat)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLATIONCO 50 (CH.Bhagat)',
	'Cisplatin',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLATIONCO 50 (CH.Bhagat)'
);

-- line #10058
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLATIPAR 10 (Parenteral)',
	'Cisplatin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg/10ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLATIPAR 10 (Parenteral)'
);

-- line #10059
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLATIPAR 50 (Parenteral)',
	'Cisplatin',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/50ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLATIPAR 50 (Parenteral)'
);

-- line #10060
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELEPRA 10 (Synapse)',
	'Citalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELEPRA 10 (Synapse)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELEPRA 20 (Synapse)',
	'Citalopram',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELEPRA 20 (Synapse)'
);

-- line #10061
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELEPRA 40 (Synapse)',
	'Citalopram',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELEPRA 40 (Synapse)'
);

-- line #10062
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELEXA 10 (Cyril Ph.)',
	'Citalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELEXA 10 (Cyril Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELEXA 20 (Cyril Ph.)',
	'Citalopram',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELEXA 20 (Cyril Ph.)'
);

-- line #10063
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELICA 10 (Solus)',
	'Citalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELICA 10 (Solus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELICA 20 (Solus)',
	'Citalopram',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELICA 20 (Solus)'
);

-- line #10064
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELICA 40 (Solus)',
	'Citalopram',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELICA 40 (Solus)'
);

-- line #10065
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITADELM 20 (OREVA DARMO.)',
	'Citalopram',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITADELM 20 (OREVA DARMO.)'
);

-- line #10066
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITADEP 10 (Protec)',
	'Citalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITADEP 10 (Protec)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITADEP 20 (Protec)',
	'Citalopram',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITADEP 20 (Protec)'
);

-- line #10067
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITADEP 40 (Protec)',
	'Citalopram',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITADEP 40 (Protec)'
);

-- line #10068
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITALOMINE 10 (PSYCOREM)',
	'Citalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITALOMINE 10 (PSYCOREM)'
);

-- line #10069
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITALOMINE 20 (PSYCOREM)',
	'Citalopram',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITALOMINE 20 (PSYCOREM)'
);

-- line #10070
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITALOMINE 40 (PSYCOREM)',
	'Citalopram',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITALOMINE 40 (PSYCOREM)'
);

-- line #10071
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITALOP 10 (EAST WEST)',
	'Citalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITALOP 10 (EAST WEST)'
);

-- line #10072
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITALOP 20 (EAST WEST)',
	'Citalopram',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITALOP 20 (EAST WEST)'
);

-- line #10073
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITALOP 40 (EAST WEST)',
	'Citalopram',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITALOP 40 (EAST WEST)'
);

-- line #10074
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITALOP 10 (Rpg Life)',
	'Citalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITALOP 10 (Rpg Life)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITALOP 20 (Rpg Life)',
	'Citalopram',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITALOP 20 (Rpg Life)'
);

-- line #10075
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITALOP 40 (Rpg Life)',
	'Citalopram',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITALOP 40 (Rpg Life)'
);

-- line #10076
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITARA 10 (Intas)',
	'Citalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITARA 10 (Intas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITARA 20 (Intas)',
	'Citalopram',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITARA 20 (Intas)'
);

-- line #10077
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITARA 40 (Intas)',
	'Citalopram',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITARA 40 (Intas)'
);

-- line #10078
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITOLA 10 (LA DRUG)',
	'Citalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITOLA 10 (LA DRUG)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITOLA 20 (LA DRUG)',
	'Citalopram',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITOLA 20 (LA DRUG)'
);

-- line #10079
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITOLA 40 (LA DRUG)',
	'Citalopram',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITOLA 40 (LA DRUG)'
);

-- line #10080
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'Citalopram', u'always_empty': u'', u'form': u'', u'brand': u'CITOPAM', u'strength_3': u'', u'company': u'Synergy', u'unit': u'mg'}

-- line #10081
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40', u'strength_2': u'', u'substance': u'Citalopram', u'always_empty': u'', u'form': u'', u'brand': u'CITOPAM', u'strength_3': u'', u'company': u'Synergy', u'unit': u'mg'}

-- line #10082
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10', u'strength_2': u'', u'substance': u'Citalopram', u'always_empty': u'', u'form': u'', u'brand': u'CITOPM', u'strength_3': u'', u'company': u'Synergy', u'unit': u'mg'}

-- line #10083
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C PRAM 10 (Neu-Foreva)',
	'Citalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C PRAM 10 (Neu-Foreva)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C PRAM 20 (Neu-Foreva)',
	'Citalopram',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C PRAM 20 (Neu-Foreva)'
);

-- line #10084
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C PRAM 40 (Neu-Foreva)',
	'Citalopram',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C PRAM 40 (Neu-Foreva)'
);

-- line #10085
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-TALO 10 (Pentacare)',
	'Citalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-TALO 10 (Pentacare)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-TALO 20 (Pentacare)',
	'Citalopram',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-TALO 20 (Pentacare)'
);

-- line #10086
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-TALO 40 (Pentacare)',
	'Citalopram',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-TALO 40 (Pentacare)'
);

-- line #10087
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYTOP 10 (Merind)',
	'CITALOPRAM',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYTOP 10 (Merind)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYTOP 20 (Merind)',
	'CITALOPRAM',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYTOP 20 (Merind)'
);

-- line #10088
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYTOP 40 (Merind)',
	'CITALOPRAM',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYTOP 40 (Merind)'
);

-- line #10089
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FELIZ 10 (Torrent)',
	'Citalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FELIZ 10 (Torrent)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FELIZ 20 (Torrent)',
	'Citalopram',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FELIZ 20 (Torrent)'
);

-- line #10090
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FELIZ 40 (Torrent)',
	'Citalopram',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FELIZ 40 (Torrent)'
);

-- line #10091
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOPRAM 10 (Ind-Swift)',
	'Citalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOPRAM 10 (Ind-Swift)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOPRAM 20 (Ind-Swift)',
	'Citalopram',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOPRAM 20 (Ind-Swift)'
);

-- line #10092
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MADAM 10 (Panacea)',
	'Citalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MADAM 10 (Panacea)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MADAM 20 (Panacea)',
	'Citalopram',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MADAM 20 (Panacea)'
);

-- line #10093
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MADAM 40 (Panacea)',
	'Citalopram',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MADAM 40 (Panacea)'
);

-- line #10094
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOTIVA 10 (Saga Lab)',
	'Citalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOTIVA 10 (Saga Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOTIVA 20 (Saga Lab)',
	'Citalopram',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOTIVA 20 (Saga Lab)'
);

-- line #10095
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOTIVA 40 (Saga Lab)',
	'Citalopram',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOTIVA 40 (Saga Lab)'
);

-- line #10096
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PALOCIT 10 (Triton Hc.)',
	'Citalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PALOCIT 10 (Triton Hc.)'
);

-- line #10097
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PALOCIT 20 (Triton Hc.)',
	'Citalopram',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PALOCIT 20 (Triton Hc.)'
);

-- line #10098
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRAMCIT 20 (Rkg)',
	'Citalopram',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRAMCIT 20 (Rkg)'
);

-- line #10099
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEHAM 500 (Alkem)',
	'CITICOLINE',
	'GRAN\.',
	gm.nullify_empty_string('500')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEHAM 500 (Alkem)'
);

-- line #10100
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEHAM 250 (Alkem)',
	'CITICOLINE',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEHAM 250 (Alkem)'
);

-- line #10101
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEHAM 500 (Alkem)',
	'CITICOLINE',
	'SYR',
	gm.nullify_empty_string('500')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEHAM 500 (Alkem)'
);

-- line #10102
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEHAM 500 (Alkem)',
	'CITICOLINE',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEHAM 500 (Alkem)'
);

-- line #10103
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CICOLIN 500 (Rpg Life)',
	'CITICOLINE',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CICOLIN 500 (Rpg Life)'
);

-- line #10104
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'CITICOLINE', u'always_empty': u'', u'form': u'OD TAB', u'brand': u'CITELEC', u'strength_3': u'', u'company': u'Ranbaxy', u'unit': u''}

-- line #10105
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1GM', u'strength_2': u'', u'substance': u'CITICOLINE', u'always_empty': u'', u'form': u'CR GM', u'brand': u'CITICO', u'strength_3': u'', u'company': u'Zydus N.S.', u'unit': u''}

-- line #10106
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITICO 250 (Zydus N.S.)',
	'CITICOLINE',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/ML(SOD.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITICO 250 (Zydus N.S.)'
);

-- line #10107
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITICO 500 (Zydus N.S.)',
	'CITICOLINE',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITICO 500 (Zydus N.S.)'
);

-- line #10108
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITILIN 250 (Neu-Foreva)',
	'CITICOLINE',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITILIN 250 (Neu-Foreva)'
);

-- line #10109
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITILIN 100 (Unichem)',
	'CITICOLINE',
	'SR GM',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITILIN 100 (Unichem)'
);

-- line #10110
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITILIN 500 (Neu-Foreva)',
	'CITICOLINE',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITILIN 500 (Neu-Foreva)'
);

-- line #10111
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITINERVE 500 (USV CENTRA)',
	'CITICOLINE',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITINERVE 500 (USV CENTRA)'
);

-- line #10112
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITINOVA 500 (Ipca)',
	'CITICOLINE',
	'GRAN',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITINOVA 500 (Ipca)'
);

-- line #10113
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITINOVA 250 (Ipca)',
	'CITICOLINE',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITINOVA 250 (Ipca)'
);

-- line #10114
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITINOVA 500 (Ipca)',
	'CITICOLINE',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITINOVA 500 (Ipca)'
);

-- line #10115
-- ignoring line: field [strength_1] not numeric: >>>N.I. (+METHYL PARABEN<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I. (+METHYL PARABEN', u'strength_2': u'', u'substance': u'CITICOLINE', u'always_empty': u'', u'form': u'INJ', u'brand': u'CITINRRVE', u'strength_3': u'', u'company': u'USV CENTRA', u'unit': u'PROPYL PARABEN)'}

-- line #10116
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITISTAR 250 (Lupin)',
	'CITICOLINE',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITISTAR 250 (Lupin)'
);

-- line #10117
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITISTAR 1000 (Lupin)',
	'CITICOLINE',
	'TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITISTAR 1000 (Lupin)'
);

-- line #10118
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITISTAR 500 (Lupin)',
	'CITICOLINE',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITISTAR 500 (Lupin)'
);

-- line #10119
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITISTAR 750 (Lupin)',
	'CITICOLINE',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITISTAR 750 (Lupin)'
);

-- line #10120
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITROK 250 (MOLEKULE)',
	'CITICOLINE',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITROK 250 (MOLEKULE)'
);

-- line #10121
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITROK 500 (MOLEKULE)',
	'CITICOLINE',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITROK 500 (MOLEKULE)'
);

-- line #10122
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLINAXON 250 (Piramal Hc.)',
	'CITICOLINE',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLINAXON 250 (Piramal Hc.)'
);

-- line #10123
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLINAXON 1000 (Piramal Hc.)',
	'CITICOLINE',
	'OD TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLINAXON 1000 (Piramal Hc.)'
);

-- line #10124
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLINAXON 500 (Piramal Hc.)',
	'CITICOLINE',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLINAXON 500 (Piramal Hc.)'
);

-- line #10125
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'CITICOLINE', u'always_empty': u'', u'form': u'', u'brand': u'EPIMA CHRONO', u'strength_3': u'', u'company': u'Zydus N.S.', u'unit': u''}

-- line #10126
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTICOL 500 (NEISS)',
	'CITICOLINE',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTICOL 500 (NEISS)'
);

-- line #10127
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINAXONE 250 (Nicholas)',
	'CITICOLINE',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINAXONE 250 (Nicholas)'
);

-- line #10128
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINAXONE 500 (Nicholas)',
	'CITICOLINE',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINAXONE 500 (Nicholas)'
);

-- line #10129
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINAXON 500 (Piramal Hc.)',
	'CITICOLINE',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINAXON 500 (Piramal Hc.)'
);

-- line #10130
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NERUCITI 250 (Win Medicare)',
	'CITICOLINE',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NERUCITI 250 (Win Medicare)'
);

-- line #10131
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NERUCITI 500 (Win Medicare)',
	'CITICOLINE',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NERUCITI 500 (Win Medicare)'
);

-- line #10132
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NERUCITI 750 (Win Medicare)',
	'CITICOLINE',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NERUCITI 750 (Win Medicare)'
);

-- line #10133
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEUROSPARK 250 (VENUS REM.)',
	'CITICOLINE',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEUROSPARK 250 (VENUS REM.)'
);

-- line #10134
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEUROSPARK 500 (VENUS REM.)',
	'CITICOLINE',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEUROSPARK 500 (VENUS REM.)'
);

-- line #10135
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREVANOR 250 (Intas)',
	'CITICOLINE',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREVANOR 250 (Intas)'
);

-- line #10136
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREVANOR 500 (INTAS)',
	'CITICOLINE',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREVANOR 500 (INTAS)'
);

-- line #10137
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREVANOR 750 (Intas)',
	'CITICOLINE',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREVANOR 750 (Intas)'
);

-- line #10138
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREXARON 250 (Intas)',
	'CITICOLINE',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREXARON 250 (Intas)'
);

-- line #10139
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREXARON 1000 (Intas)',
	'CITICOLINE',
	'SR TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREXARON 1000 (Intas)'
);

-- line #10140
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RECOGNIX 125 (Grandix)',
	'CITICOLINE',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RECOGNIX 125 (Grandix)'
);

-- line #10141
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RECOGNIX 250 (Grandix)',
	'CITICOLINE',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RECOGNIX 250 (Grandix)'
);

-- line #10142
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RECOGNIX 1000 (GRANDIX)',
	'CITICOLINE',
	'TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RECOGNIX 1000 (GRANDIX)'
);

-- line #10143
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RECOGNIX 500 (GRANDIX)',
	'CITICOLINE',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RECOGNIX 500 (GRANDIX)'
);

-- line #10144
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REXARON 500 (Intas)',
	'CITICOLINE',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REXARON 500 (Intas)'
);

-- line #10145
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITELEC 250 (Ranbaxy)',
	'CITIHOLINE',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITELEC 250 (Ranbaxy)'
);

-- line #10146
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACEM 250 (Emcure)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACEM 250 (Emcure)'
);

-- line #10147
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACGEL 1 (Rapross)',
	'Clarithromycin',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACGEL 1 (Rapross)'
);

-- line #10148
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACGEL 1 (Rapross)',
	'Clarithromycin',
	'LOT',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACGEL 1 (Rapross)'
);

-- line #10149
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACNESOL 1 (Systopic)',
	'Clarithromycin',
	'CL GEL',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACNESOL 1 (Systopic)'
);

-- line #10150
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACNESOL 1 (Systopic)',
	'Clarithromycin',
	'CL LOT',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACNESOL 1 (Systopic)'
);

-- line #10151
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACNESONE 5 (Systopic)',
	'Clarithromycin',
	'GEL',
	gm.nullify_empty_string('5')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACNESONE 5 (Systopic)'
);

-- line #10152
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXYTEF 250 (AXYZEN LIFE)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXYTEF 250 (AXYZEN LIFE)'
);

-- line #10153
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BICLAR 250 (Unichem)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BICLAR 250 (Unichem)'
);

-- line #10154
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOCLAR 125 (BIOCHEM)',
	'Clarithromycin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOCLAR 125 (BIOCHEM)'
);

-- line #10155
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOCLAR 250 (Biochem)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOCLAR 250 (Biochem)'
);

-- line #10156
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BROCLARS 125 (Shreeyam)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BROCLARS 125 (Shreeyam)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BROCLARS 250 (Shreeyam)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BROCLARS 250 (Shreeyam)'
);

-- line #10157
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALITH 250 (Arbro Ph.)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALITH 250 (Arbro Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALITH 500 (Arbro Ph.)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALITH 500 (Arbro Ph.)'
);

-- line #10158
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELEX 250 (Gsk)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELEX 250 (Gsk)'
);

-- line #10159
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELEX 500 (Gsk)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELEX 500 (Gsk)'
);

-- line #10160
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLAIR 1 (G.Nine Form.)',
	'Clarithromycin',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLAIR 1 (G.Nine Form.)'
);

-- line #10161
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLAMYCIN 250 (Lupin)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLAMYCIN 250 (Lupin)'
);

-- line #10162
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLARBACT 250 (Ipca)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLARBACT 250 (Ipca)'
);

-- line #10163
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLARBACT 500 (Ipca)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLARBACT 500 (Ipca)'
);

-- line #10164
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLARCIN 125 (Waves Bio.)',
	'Clarithromycin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLARCIN 125 (Waves Bio.)'
);

-- line #10165
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLARCIN 250 (Waves Bio.)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLARCIN 250 (Waves Bio.)'
);

-- line #10166
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLARIBID 125 (Pharmacia)',
	'Clarithromycin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLARIBID 125 (Pharmacia)'
);

-- line #10167
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLARIBID 250 (Pharmacia)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLARIBID 250 (Pharmacia)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLARIBID 500 (Pharmacia)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLARIBID 500 (Pharmacia)'
);

-- line #10168
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLARICIN 125 (Waves Bio.)',
	'CLARITHROMYCIN',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLARICIN 125 (Waves Bio.)'
);

-- line #10169
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLARICIN 250 (Waves Bio.)',
	'CLARITHROMYCIN',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLARICIN 250 (Waves Bio.)'
);

-- line #10170
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLARICIP 250 (Cipla)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLARICIP 250 (Cipla)'
);

-- line #10171
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLARICS 250 (Osper)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLARICS 250 (Osper)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLARICS 500 (Osper)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLARICS 500 (Osper)'
);

-- line #10172
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLARIDASE 125 (Ordain Hc.)',
	'Clarithromycin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLARIDASE 125 (Ordain Hc.)'
);

-- line #10173
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLARIE DRY 250 (Ind-Swift)',
	'Clarithromycin',
	'SYP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLARIE DRY 250 (Ind-Swift)'
);

-- line #10174
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLARIE 125 (Ind-Swift)',
	'Clarithromycin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLARIE 125 (Ind-Swift)'
);

-- line #10175
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLARIE 500 (Ind-Swift)',
	'Clarithromycin',
	'OD TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLARIE 500 (Ind-Swift)'
);

-- line #10176
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLARIE 250 (Ind-Swift)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLARIE 250 (Ind-Swift)'
);

-- line #10177
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLARIGEN 250 (Genix Ph.)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLARIGEN 250 (Genix Ph.)'
);

-- line #10178
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLARIMAC 250 (Zydus Cadila)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLARIMAC 250 (Zydus Cadila)'
);

-- line #10179
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLARIMAC 500 (Zydus Cadila)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLARIMAC 500 (Zydus Cadila)'
);

-- line #10180
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLARIOL 250 (Olcare)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLARIOL 250 (Olcare)'
);

-- line #10181
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLARIPAX 250 (Bipl(Radico Lab))',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLARIPAX 250 (Bipl(Radico Lab))'
);

-- line #10182
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLARITAL 250 (TALENT LAB.)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLARITAL 250 (TALENT LAB.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLARITAL 500 (TALENT LAB.)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLARITAL 500 (TALENT LAB.)'
);

-- line #10183
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'30ML', u'strength_2': u'', u'substance': u'Clarithromycin', u'always_empty': u'', u'form': u'D.SYR', u'brand': u'CLARIT', u'strength_3': u'', u'company': u'Finecure', u'unit': u''}

-- line #10184
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLARIT 125 (Finecure)',
	'Clarithromycin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLARIT 125 (Finecure)'
);

-- line #10185
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLARITHRO 250 (Alembic)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLARITHRO 250 (Alembic)'
);

-- line #10186
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLARITHRO 500 (Alembic)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLARITHRO 500 (Alembic)'
);

-- line #10187
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLARITHRO 500 (Alembic)',
	'Clarithromycin',
	'XR TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLARITHRO 500 (Alembic)'
);

-- line #10188
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLARIT 250 (Finecure)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLARIT 250 (Finecure)'
);

-- line #10189
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLARIWIN 250 (Brown & B.)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLARIWIN 250 (Brown & B.)'
);

-- line #10190
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLARIWIN 500 (Brown & B.)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLARIWIN 500 (Brown & B.)'
);

-- line #10191
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLAR 250 (HETERO HC.)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLAR 250 (HETERO HC.)'
);

-- line #10192
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLARYCIN 250 (Chemo D.)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLARYCIN 250 (Chemo D.)'
);

-- line #10193
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLEAR 125 (ALKEM)',
	'Clarithromycin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLEAR 125 (ALKEM)'
);

-- line #10194
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLEAR 250 (Alkem)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLEAR 250 (Alkem)'
);

-- line #10195
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CREOL 125 (CHEMO HC.)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CREOL 125 (CHEMO HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CREOL 250 (CHEMO HC.)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CREOL 250 (CHEMO HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CREOL 500 (CHEMO HC.)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CREOL 500 (CHEMO HC.)'
);

-- line #10196
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CRIXAN 125 (Rexcel)',
	'Clarithromycin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CRIXAN 125 (Rexcel)'
);

-- line #10197
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CRIXAN 125 (Rexcel)',
	'Clarithromycin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CRIXAN 125 (Rexcel)'
);

-- line #10198
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CRIXAN 500 (Rexcel)',
	'Clarithromycin',
	'ER TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CRIXAN 500 (Rexcel)'
);

-- line #10199
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CRIXAN 500 (Rexcel)',
	'Clarithromycin',
	'OD TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CRIXAN 500 (Rexcel)'
);

-- line #10200
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CRIXAN 250 (Rexcel)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CRIXAN 250 (Rexcel)'
);

-- line #10201
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CRIXAN 500 (Rexcel)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CRIXAN 500 (Rexcel)'
);

-- line #10202
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ECLY 125 (Biocin Hc.)',
	'Clarithromycin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ECLY 125 (Biocin Hc.)'
);

-- line #10203
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'125', u'strength_2': u'', u'substance': u'Clarithromycin', u'always_empty': u'', u'form': u'', u'brand': u'F CLAR DRYSYR', u'strength_3': u'', u'company': u'Finecure', u'unit': u'mg/5ML'}

-- line #10204
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'F CLAR 125 (Finecure)',
	'Clarithromycin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'F CLAR 125 (Finecure)'
);

-- line #10205
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'F CLAR 250 (Finecure)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'F CLAR 250 (Finecure)'
);

-- line #10206
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HELICLAR 500 (Pharmacia)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HELICLAR 500 (Pharmacia)'
);

-- line #10207
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'I CLAR 125 (IP HC.)',
	'Clarithromycin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'I CLAR 125 (IP HC.)'
);

-- line #10208
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'I CLAR 125 (IP HC.)',
	'Clarithromycin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'I CLAR 125 (IP HC.)'
);

-- line #10209
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'I CLAR 250 (IP HC.)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'I CLAR 250 (IP HC.)'
);

-- line #10210
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KLACID 500 (Abbott)',
	'Clarithromycin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg/1 VIAL'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KLACID 500 (Abbott)'
);

-- line #10211
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KLACIN 250 (Cipla)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KLACIN 250 (Cipla)'
);

-- line #10212
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KLARIM 125 (Morepen)',
	'Clarithromycin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KLARIM 125 (Morepen)'
);

-- line #10213
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KLARIM 125 (Morepen)',
	'Clarithromycin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KLARIM 125 (Morepen)'
);

-- line #10214
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KLARIM 250 (Morepen)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KLARIM 250 (Morepen)'
);

-- line #10215
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KLARIM 500 (Morepen)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KLARIM 500 (Morepen)'
);

-- line #10216
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LARIT 125 (Chemo Bio.)',
	'Clarithromycin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LARIT 125 (Chemo Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LARIT 250 (Chemo Bio.)',
	'Clarithromycin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LARIT 250 (Chemo Bio.)'
);

-- line #10217
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LARIT 500 (Chemo Bio.)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LARIT 500 (Chemo Bio.)'
);

-- line #10218
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACLAR 125 (Gracewell)',
	'Clarithromycin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACLAR 125 (Gracewell)'
);

-- line #10219
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACLAR 500 (Gracewell)',
	'Clarithromycin',
	'SR TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACLAR 500 (Gracewell)'
);

-- line #10220
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACLAR 125 (Gracewell)',
	'Clarithromycin',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACLAR 125 (Gracewell)'
);

-- line #10221
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACLAR 250 (Gracewell)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACLAR 250 (Gracewell)'
);

-- line #10222
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACLAR 500 (Gracewell)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACLAR 500 (Gracewell)'
);

-- line #10223
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACROCLAR 250 (EAST WEST)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACROCLAR 250 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACROCLAR 500 (EAST WEST)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACROCLAR 500 (EAST WEST)'
);

-- line #10224
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGAMAC 125 (Indchemie)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGAMAC 125 (Indchemie)'
);

-- line #10225
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGAMAC 250 (Indchemie)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGAMAC 250 (Indchemie)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGAMAC 500 (Indchemie)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGAMAC 500 (Indchemie)'
);

-- line #10226
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MODCLAR 500 (MODHIKE)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MODCLAR 500 (MODHIKE)'
);

-- line #10227
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEKLITRO 125 (Nestor)',
	'Clarithromycin',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEKLITRO 125 (Nestor)'
);

-- line #10228
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEKLITRO 250 (Nestor)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEKLITRO 250 (Nestor)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEKLITRO 500 (Nestor)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEKLITRO 500 (Nestor)'
);

-- line #10229
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEUCLAR 250 (Nicholas)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEUCLAR 250 (Nicholas)'
);

-- line #10230
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVACLAR 125 (Novagen Ph.)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVACLAR 125 (Novagen Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVACLAR 250 (Novagen Ph.)',
	'Clarithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVACLAR 250 (Novagen Ph.)'
);

-- line #10231
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'125', u'strength_2': u'', u'substance': u'Clarithromycin', u'always_empty': u'', u'form': u'', u'brand': u'OMNICERIN REDIUSE', u'strength_3': u'', u'company': u'Cipla', u'unit': u'mg'}

-- line #10232
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLEBOPRO 0.5 (German R.)',
	'CLEBOPRIDE',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLEBOPRO 0.5 (German R.)'
);

-- line #10233
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLAMIST 0.5 (Wanbury)',
	'Clemastine',
	'SYR',
	gm.nullify_empty_string('0.5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLAMIST 0.5 (Wanbury)'
);

-- line #10234
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLAMIST 1 (Wanbury)',
	'Clemastine',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLAMIST 1 (Wanbury)'
);

-- line #10235
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACLODERM 1 (Dermocare)',
	'Clindamycin',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%(PHOSPH.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACLODERM 1 (Dermocare)'
);

-- line #10236
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACNECLIN 1 (Themis)',
	'Clindamycin',
	'GEL/CREAM',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACNECLIN 1 (Themis)'
);

-- line #10237
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1', u'strength_2': u'', u'substance': u'Clindamycin', u'always_empty': u'', u'form': u'', u'brand': u'ACNEFRESH', u'strength_3': u'', u'company': u'SMART LAB.', u'unit': u'%'}

-- line #10238
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACNERIS 1 (PSYCOREM)',
	'Clindamycin',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACNERIS 1 (PSYCOREM)'
);

-- line #10239
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACNESOL 1 (Systopic)',
	'Clindamycin',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%(PHOSPH.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACNESOL 1 (Systopic)'
);

-- line #10240
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACNESOL 1 (Systopic)',
	'Clindamycin',
	'SOL',
	gm.nullify_empty_string('1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACNESOL 1 (Systopic)'
);

-- line #10241
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Clindamycin', u'always_empty': u'', u'form': u'CAP', u'brand': u'BIOLINX', u'strength_3': u'', u'company': u'BIOSCIENCES', u'unit': u''}

-- line #10242
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLENCHIN 1 (Rowan Bio.)',
	'Clindamycin',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLENCHIN 1 (Rowan Bio.)'
);

-- line #10243
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLEX 1 (Cadex Lab)',
	'Clindamycin',
	'OINT',
	gm.nullify_empty_string('1')::numeric,
	'%(PHOSPH.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLEX 1 (Cadex Lab)'
);

-- line #10244
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLID 150 (Bennet Ph.)',
	'Clindamycin',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg(HCL.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLID 150 (Bennet Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLID 300 (Bennet Ph.)',
	'Clindamycin',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg(HCL.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLID 300 (Bennet Ph.)'
);

-- line #10245
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLID 1 (Bennet Ph.)',
	'Clindamycin',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLID 1 (Bennet Ph.)'
);

-- line #10246
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLID 300 (Bennet Ph.)',
	'Clindamycin',
	'INJ',
	gm.nullify_empty_string('300')::numeric,
	'mg/2ML(HCL.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLID 300 (Bennet Ph.)'
);

-- line #10247
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1', u'strength_2': u'', u'substance': u'Clindamycin', u'always_empty': u'', u'form': u'', u'brand': u'CLIGEL', u'strength_3': u'', u'company': u'EAST WEST', u'unit': u'%'}

-- line #10248
-- ignoring line: field [strength_1] not numeric: >>>1(0.10<<<
-- {u'list_of_values_of_unknown_fields': [u' %PROPYL PARABEN)', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1(0.10', u'strength_2': u'', u'substance': u'Clindamycin', u'always_empty': u'', u'form': u'GEL', u'brand': u'CLIMPLE', u'strength_3': u'', u'company': u'Cadila Ph.', u'unit': u'%METHYL PARABEN'}

-- line #10249
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLIMYCIN 150 (NEON)',
	'Clindamycin',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLIMYCIN 150 (NEON)'
);

-- line #10250
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLINCIN 150 (Indi Ph.)',
	'Clindamycin',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg(HCL.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLINCIN 150 (Indi Ph.)'
);

-- line #10251
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLINCIN 300 (Indi Ph.)',
	'Clindamycin',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg(HCL.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLINCIN 300 (Indi Ph.)'
);

-- line #10252
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLINCIN 1 (Indi Ph.)',
	'Clindamycin',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%(PHOSPH.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLINCIN 1 (Indi Ph.)'
);

-- line #10253
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLINCIN 150 (Indi Ph.)',
	'Clindamycin',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg(+9.45'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLINCIN 150 (Indi Ph.)'
);

-- line #10254
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLINDAC-A 1 (Galderma)',
	'Clindamycin',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%(PHOSPH.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLINDAC-A 1 (Galderma)'
);

-- line #10255
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLINDAC-A 1 (Galderma)',
	'Clindamycin',
	'SOL',
	gm.nullify_empty_string('1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLINDAC-A 1 (Galderma)'
);

-- line #10256
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLINDAC-A 1 (Indi Ph.)',
	'Clindamycin',
	'SOL',
	gm.nullify_empty_string('1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLINDAC-A 1 (Indi Ph.)'
);

-- line #10257
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLINDAFIN 1 (HBC LIFESCIENCE)',
	'Clindamycin',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLINDAFIN 1 (HBC LIFESCIENCE)'
);

-- line #10258
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLINDA 1 (Apex Form.)',
	'Clindamycin',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%(PHOSPH.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLINDA 1 (Apex Form.)'
);

-- line #10259
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLINDAL-A 1 (Alive)',
	'Clindamycin',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%(PHOSPH.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLINDAL-A 1 (Alive)'
);

-- line #10260
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLINDATEC 150 (United Bio.)',
	'Clindamycin',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLINDATEC 150 (United Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLINDATEC 300 (United Bio.)',
	'Clindamycin',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLINDATEC 300 (United Bio.)'
);

-- line #10261
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLINDATEC 300 (United Bio.)',
	'Clindamycin',
	'INJ',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLINDATEC 300 (United Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLINDATEC 600 (United Bio.)',
	'Clindamycin',
	'INJ',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLINDATEC 600 (United Bio.)'
);

-- line #10262
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLINDAZ 1 (ADVIK)',
	'Clindamycin',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLINDAZ 1 (ADVIK)'
);

-- line #10263
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLINDERM 1 (AGIO PH.)',
	'Clindamycin',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%(PHOSPH.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLINDERM 1 (AGIO PH.)'
);

-- line #10264
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLINDOL 150 (VENUS REM.)',
	'Clindamycin',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLINDOL 150 (VENUS REM.)'
);

-- line #10265
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLINDOL 300 (VENUS REM.)',
	'Clindamycin',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLINDOL 300 (VENUS REM.)'
);

-- line #10266
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'150', u'strength_2': u'', u'substance': u'Clindamycin', u'always_empty': u'', u'form': u'', u'brand': u'CLINDOL', u'strength_3': u'', u'company': u'VENUS REM.', u'unit': u'mg AS PHOSPHATE(BENZYL ALCOHOL AS PRES.)'}

-- line #10267
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLINDOXYL 1 (Gsk)',
	'Clindamycin',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%W/W( BENZOYL PEROXIDE PH. EUR. EQ TO ANHYDROUS BENZOY PEROXIDE 5'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLINDOXYL 1 (Gsk)'
);

-- line #10268
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLINKA 1 (Intas)',
	'Clindamycin',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLINKA 1 (Intas)'
);

-- line #10269
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Clindamycin', u'always_empty': u'', u'form': u'', u'brand': u'CLINMIFACE', u'strength_3': u'', u'company': u'PRISM LIFESCI.', u'unit': u''}

-- line #10270
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLINSCAR 1 (Intra Lab)',
	'Clindamycin',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%(PHOSPH.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLINSCAR 1 (Intra Lab)'
);

-- line #10271
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLINTOP 1 (D.P.P.L.)',
	'Clindamycin',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLINTOP 1 (D.P.P.L.)'
);

-- line #10272
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'D,ACNE 1 (Glenmark)',
	'Clindamycin',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%W/W:ALCOHOL 95'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'D,ACNE 1 (Glenmark)'
);

-- line #10273
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DALACIN-C 150 (MAX)',
	'Clindamycin',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg(HCL.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DALACIN-C 150 (MAX)'
);

-- line #10274
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DALACIN-C 300 (MAX)',
	'Clindamycin',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg(HCL.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DALACIN-C 300 (MAX)'
);

-- line #10275
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DALACIN-C 150 (MAX)',
	'Clindamycin',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/ML(HCL.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DALACIN-C 150 (MAX)'
);

-- line #10276
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DALCAP 150 (Unichem)',
	'Clindamycin',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg(HCL.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DALCAP 150 (Unichem)'
);

-- line #10277
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DALCINEX 150 (Cipla)',
	'Clindamycin',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DALCINEX 150 (Cipla)'
);

-- line #10278
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DALCINEX 300 (Cipla)',
	'Clindamycin',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DALCINEX 300 (Cipla)'
);

-- line #10279
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DALCINEX 150 (Cipla)',
	'Clindamycin',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DALCINEX 150 (Cipla)'
);

-- line #10280
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DALCINEX 150 (Cipla)',
	'Clindamycin',
	'LIQ',
	gm.nullify_empty_string('150')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DALCINEX 150 (Cipla)'
);

-- line #10281
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DALTREX 150 (NEON)',
	'Clindamycin',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DALTREX 150 (NEON)'
);

-- line #10282
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DALTREX 300 (NEON)',
	'Clindamycin',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DALTREX 300 (NEON)'
);

-- line #10283
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Clindamycin', u'always_empty': u'', u'form': u'GEL', u'brand': u'DIVICLIN', u'strength_3': u'', u'company': u'DIVINE LAB.', u'unit': u''}

-- line #10284
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Clindamycin', u'always_empty': u'', u'form': u'', u'brand': u'EVADERM GMS', u'strength_3': u'', u'company': u'Ttk Hc.', u'unit': u''}

-- line #10285
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1', u'strength_2': u'', u'substance': u'Clindamycin', u'always_empty': u'', u'form': u'', u'brand': u'FACECLIN', u'strength_3': u'', u'company': u'NICHOLAS PIRAMAL', u'unit': u'%W/W'}

-- line #10286
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUNEM 150 (UNITED BIO.)',
	'Clindamycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg (+9'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUNEM 150 (UNITED BIO.)'
);

-- line #10287
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KLEANGEL 1 (Wattyl Ph.)',
	'Clindamycin',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%(PHOSPH.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KLEANGEL 1 (Wattyl Ph.)'
);

-- line #10288
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KLINSER 1 (Lancer)',
	'Clindamycin',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KLINSER 1 (Lancer)'
);

-- line #10289
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KLINSPEC 1 (Sandoz)',
	'Clindamycin',
	'TUBE',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KLINSPEC 1 (Sandoz)'
);

-- line #10290
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KLYNX 1 (WALLACE)',
	'Clindamycin',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%(PHOSPH.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KLYNX 1 (WALLACE)'
);

-- line #10291
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Clindamycin', u'always_empty': u'', u'form': u'GEL', u'brand': u'MAGCLIN', u'strength_3': u'', u'company': u'Magnus Bio.', u'unit': u''}

-- line #10292
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIMOSEE 1 (Intas)',
	'Clindamycin',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIMOSEE 1 (Intas)'
);

-- line #10293
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Clindamycin', u'always_empty': u'', u'form': u'CD SUPP', u'brand': u'NUFORCE', u'strength_3': u'', u'company': u'Discovery M.', u'unit': u''}

-- line #10294
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PATHOCLIN 300 (NEISS)',
	'Clindamycin',
	'INJ',
	gm.nullify_empty_string('300')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PATHOCLIN 300 (NEISS)'
);

-- line #10295
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AEDON 5 (Sanofi Aventis)',
	'Clobazam',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AEDON 5 (Sanofi Aventis)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AEDON 10 (Sanofi Aventis)',
	'Clobazam',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AEDON 10 (Sanofi Aventis)'
);

-- line #10296
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BAZZY 5 (Glenmark)',
	'Clobazam',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BAZZY 5 (Glenmark)'
);

-- line #10297
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOBAKEM 10 (Alkem)',
	'Clobazam',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOBAKEM 10 (Alkem)'
);

-- line #10298
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOBAKEM 5 (Alkem)',
	'Clobazam',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOBAKEM 5 (Alkem)'
);

-- line #10299
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOBA 10 (Intas)',
	'Clobazam',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOBA 10 (Intas)'
);

-- line #10300
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOBA 20 (Intas)',
	'Clobazam',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOBA 20 (Intas)'
);

-- line #10301
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOBA 5 (Intas)',
	'Clobazam',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOBA 5 (Intas)'
);

-- line #10302
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOBATOR 10 (Torrent)',
	'Clobazam',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOBATOR 10 (Torrent)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOBATOR 20 (Torrent)',
	'Clobazam',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOBATOR 20 (Torrent)'
);

-- line #10303
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOBATOR 5 (Torrent)',
	'Clobazam',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOBATOR 5 (Torrent)'
);

-- line #10304
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOBAZ 5 (Tripada Hc.)',
	'Clobazam',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOBAZ 5 (Tripada Hc.)'
);

-- line #10305
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLODUS 20 (Zydus Cadila)',
	'Clobazam',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLODUS 20 (Zydus Cadila)'
);

-- line #10306
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLODUS 5 (Zydus Cadila)',
	'Clobazam',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLODUS 5 (Zydus Cadila)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLODUS 10 (Zydus Cadila)',
	'Clobazam',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLODUS 10 (Zydus Cadila)'
);

-- line #10307
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOZAM 10 (Nicholas)',
	'Clobazam',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOZAM 10 (Nicholas)'
);

-- line #10308
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOZAM 20 (Nicholas)',
	'Clobazam',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOZAM 20 (Nicholas)'
);

-- line #10309
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOZAM 5 (Nicholas)',
	'Clobazam',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOZAM 5 (Nicholas)'
);

-- line #10310
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CZAM 5 (SHINE PH.)',
	'Clobazam',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'10'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CZAM 5 (SHINE PH.)'
);

-- line #10311
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPIZAM 10 (PSYCOREM)',
	'Clobazam',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPIZAM 10 (PSYCOREM)'
);

-- line #10312
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPIZAM 20 (PSYCOREM)',
	'Clobazam',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPIZAM 20 (PSYCOREM)'
);

-- line #10313
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPIZAM 5 (PSYCOREM)',
	'Clobazam',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPIZAM 5 (PSYCOREM)'
);

-- line #10314
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FRISIUM 10 (Sanofi Aventis)',
	'Clobazam',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FRISIUM 10 (Sanofi Aventis)'
);

-- line #10315
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FRISIUM 20 (Sanofi Aventis)',
	'Clobazam',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FRISIUM 20 (Sanofi Aventis)'
);

-- line #10316
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FRISIUM 5 (Sanofi Aventis)',
	'Clobazam',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FRISIUM 5 (Sanofi Aventis)'
);

-- line #10317
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LABOZAM 10 (Sun)',
	'Clobazam',
	'MD TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LABOZAM 10 (Sun)'
);

-- line #10318
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LABOZAM 5 (Sun)',
	'Clobazam',
	'MD TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LABOZAM 5 (Sun)'
);

-- line #10319
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOBAZAM 10 (SUN)',
	'Clobazam',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOBAZAM 10 (SUN)'
);

-- line #10320
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOBAZAM 20 (SUN)',
	'Clobazam',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOBAZAM 20 (SUN)'
);

-- line #10321
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOBAZAM 5 (SUN)',
	'Clobazam',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOBAZAM 5 (SUN)'
);

-- line #10322
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADIVATE 0.05 (Glat)',
	'Clobetasol Propionate',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADIVATE 0.05 (Glat)'
);

-- line #10323
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AGICLOB 0.05 (AGIO PH.)',
	'Clobetasol Propionate',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AGICLOB 0.05 (AGIO PH.)'
);

-- line #10324
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AGICLOB 0.05 (AGIO PH.)',
	'Clobetasol Propionate',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AGICLOB 0.05 (AGIO PH.)'
);

-- line #10325
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETANATE 0.05 (Cosme Hc.)',
	'Clobetasol Propionate',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETANATE 0.05 (Cosme Hc.)'
);

-- line #10326
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-BESTA 0.05 (Unichem)',
	'Clobetasol Propionate',
	'OINT',
	gm.nullify_empty_string('0.05')::numeric,
	'%(0.10'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-BESTA 0.05 (Unichem)'
);

-- line #10327
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CBS 0.05 (Serve Ph.)',
	'Clobetasol Propionate',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CBS 0.05 (Serve Ph.)'
);

-- line #10328
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Clobetasol Propionate', u'always_empty': u'', u'form': u'CRM', u'brand': u'CBZEE', u'strength_3': u'', u'company': u'ADMIT', u'unit': u''}

-- line #10329
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOBCY 0.05 (Cadex Lab)',
	'Clobetasol Propionate',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOBCY 0.05 (Cadex Lab)'
);

-- line #10330
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOBENATE 0.05 (Ind-Swift)',
	'Clobetasol Propionate',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOBENATE 0.05 (Ind-Swift)'
);

-- line #10331
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOBETAGEN 0.05 (Alkem)',
	'Clobetasol Propionate',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOBETAGEN 0.05 (Alkem)'
);

-- line #10332
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOBETAMIL 0.05 (Merck)',
	'Clobetasol Propionate',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOBETAMIL 0.05 (Merck)'
);

-- line #10333
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOBETASOL 0.05 (Dopson Ph.)',
	'Clobetasol Propionate',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOBETASOL 0.05 (Dopson Ph.)'
);

-- line #10334
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOBETAVATE 0.05 (Lupin)',
	'Clobetasol Propionate',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOBETAVATE 0.05 (Lupin)'
);

-- line #10335
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOBETOL 0.05 (Croslands)',
	'Clobetasol Propionate',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOBETOL 0.05 (Croslands)'
);

-- line #10336
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOBETYL 0.05 (Wattyl Ph.)',
	'Clobetasol Propionate',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOBETYL 0.05 (Wattyl Ph.)'
);

-- line #10337
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOBISPAN 0.05 (Merind)',
	'Clobetasol Propionate',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOBISPAN 0.05 (Merind)'
);

-- line #10338
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLODERM 0.05 (Cipla)',
	'Clobetasol Propionate',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLODERM 0.05 (Cipla)'
);

-- line #10339
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLODERM 0.05 (Hygeia Ph.)',
	'Clobetasol Propionate',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLODERM 0.05 (Hygeia Ph.)'
);

-- line #10340
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLODIP 0.05 (Intra Lab)',
	'Clobetasol Propionate',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLODIP 0.05 (Intra Lab)'
);

-- line #10341
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOFIN 0.05 (HBC LIFESCIENCE)',
	'Clobetasol Propionate',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOFIN 0.05 (HBC LIFESCIENCE)'
);

-- line #10342
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOFOAM 0.05 (Cipla)',
	'Clobetasol Propionate',
	'FOAM',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOFOAM 0.05 (Cipla)'
);

-- line #10343
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOMIC 0.05 (EAST WEST)',
	'Clobetasol Propionate',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOMIC 0.05 (EAST WEST)'
);

-- line #10344
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLONEXT 0.05 (ETHINEXT PHARMA)',
	'Clobetasol Propionate',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLONEXT 0.05 (ETHINEXT PHARMA)'
);

-- line #10345
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLONIT 0.05 (Karlin)',
	'Clobetasol Propionate',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLONIT 0.05 (Karlin)'
);

-- line #10346
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOPAD 0.05 (Tripada BIO.)',
	'Clobetasol Propionate',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOPAD 0.05 (Tripada BIO.)'
);

-- line #10347
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOP 0.05 (Liva Hc.)',
	'Clobetasol Propionate',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOP 0.05 (Liva Hc.)'
);

-- line #10348
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOP-E 0.05 (Liva Hc.)',
	'Clobetasol Propionate',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOP-E 0.05 (Liva Hc.)'
);

-- line #10349
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOP 0.05 (Liva Hc.)',
	'Clobetasol Propionate',
	'LOT',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOP 0.05 (Liva Hc.)'
);

-- line #10350
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLORAP 0.05 (Rapross)',
	'Clobetasol Propionate',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLORAP 0.05 (Rapross)'
);

-- line #10351
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOVATE 0.05 (Dermocare)',
	'Clobetasol Propionate',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOVATE 0.05 (Dermocare)'
);

-- line #10352
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORTIMAX 0.05 (Zuventus)',
	'Clobetasol Propionate',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORTIMAX 0.05 (Zuventus)'
);

-- line #10353
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORTISOL 0.05 (PSYCOREM)',
	'Clobetasol Propionate',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORTISOL 0.05 (PSYCOREM)'
);

-- line #10354
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,05', u'strength_2': u'', u'substance': u'Clobetasol Propionate', u'always_empty': u'', u'form': u'', u'brand': u'CORTISOL LOITON', u'strength_3': u'', u'company': u'PSYCOREM', u'unit': u'%W/V'}

-- line #10355
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COSVATE 0.05 (Cosme Hc.)',
	'Clobetasol Propionate',
	'GEL',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COSVATE 0.05 (Cosme Hc.)'
);

-- line #10356
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COTRIMAX 0.05 (Emcure)',
	'Clobetasol Propionate',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COTRIMAX 0.05 (Emcure)'
);

-- line #10357
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DERMOTYL SKIN 0.05 (HETERO HC.)',
	'Clobetasol Propionate',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DERMOTYL SKIN 0.05 (HETERO HC.)'
);

-- line #10358
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ECZICLO 0.05 (Cfl Ph.)',
	'Clobetasol Propionate',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ECZICLO 0.05 (Cfl Ph.)'
);

-- line #10359
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENDERM 0.05 (Leben)',
	'Clobetasol Propionate',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENDERM 0.05 (Leben)'
);

-- line #10360
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPIVATE 0.05 (PRISM LIFESCI.)',
	'Clobetasol Propionate',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPIVATE 0.05 (PRISM LIFESCI.)'
);

-- line #10361
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETAVONE 0.05 (Rowan Bio.)',
	'Clobetasol Propionate',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETAVONE 0.05 (Rowan Bio.)'
);

-- line #10362
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXCEL 0.05 (RANBAXY(CONSUMER HC))',
	'Clobetasol Propionate',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXCEL 0.05 (RANBAXY(CONSUMER HC))'
);

-- line #10363
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXEL 0.05 (Ranbaxy)',
	'Clobetasol Propionate',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXEL 0.05 (Ranbaxy)'
);

-- line #10364
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEMI-C 0.05 (Dr.Arvind Shah''S)',
	'Clobetasol Propionate',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEMI-C 0.05 (Dr.Arvind Shah''S)'
);

-- line #10365
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLOBETAMIL 0.05 (Merck)',
	'Clobetasol Propionate',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLOBETAMIL 0.05 (Merck)'
);

-- line #10366
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALODERM 0.05 (Micro)',
	'Clobetasol Propionate',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALODERM 0.05 (Micro)'
);

-- line #10367
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTEGA 0.05 (Waves Bio.)',
	'Clobetasol Propionate',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTEGA 0.05 (Waves Bio.)'
);

-- line #10368
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KLORYL 0.05 (Unimarck)',
	'Clobetasol Propionate',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KLORYL 0.05 (Unimarck)'
);

-- line #10369
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KLOSOFT 0.05 (Sandoz)',
	'Clobetasol Propionate',
	'TUBE',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KLOSOFT 0.05 (Sandoz)'
);

-- line #10370
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOBATE 0.05 (Nicholas)',
	'Clobetasol Propionate',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOBATE 0.05 (Nicholas)'
);

-- line #10371
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAGCLO 0.05 (Magnus Bio.)',
	'Clobetasol Propionate',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAGCLO 0.05 (Magnus Bio.)'
);

-- line #10372
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORMADERM 0.05 (Issar Ph.)',
	'Clobetasol Propionate',
	'CR CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORMADERM 0.05 (Issar Ph.)'
);

-- line #10373
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OBET 0.05 (SUNWAYS)',
	'Clobetasol Propionate',
	'OINT',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OBET 0.05 (SUNWAYS)'
);

-- line #10374
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Clobetasol Propionate', u'always_empty': u'', u'form': u'CRM', u'brand': u'OCOVATE', u'strength_3': u'', u'company': u'Ochoa', u'unit': u''}

-- line #10375
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLCLOBEE 0.05 (Olcare)',
	'Clobetasol Propionate',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLCLOBEE 0.05 (Olcare)'
);

-- line #10376
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POWERCORT 0.05 (Glenmark)',
	'Clobetasol Propionate',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POWERCORT 0.05 (Glenmark)'
);

-- line #10377
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PSOROBET 0.05 (Bombay T.)',
	'Clobetasol Propionate',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PSOROBET 0.05 (Bombay T.)'
);

-- line #10378
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUMOSONE 0.05 (Gsk)',
	'Clobetasone Butyrate',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUMOSONE 0.05 (Gsk)'
);

-- line #10379
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEMBESOL 0.05 (Fem care)',
	'Clobetasone Butyrate',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/W(17)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEMBESOL 0.05 (Fem care)'
);

-- line #10380
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOFOZINE 100 (Astrazeneca)',
	'Clofazimine',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOFOZINE 100 (Astrazeneca)'
);

-- line #10381
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOFOZINE 50 (Astrazeneca)',
	'Clofazimine',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOFOZINE 50 (Astrazeneca)'
);

-- line #10382
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAZIM 50 (Lark Lab)',
	'Clofazimine',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAZIM 50 (Lark Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAZIM 100 (Lark Lab)',
	'Clofazimine',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAZIM 100 (Lark Lab)'
);

-- line #10383
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HANSEPRAN 100 (Nicholas)',
	'Clofazimine',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HANSEPRAN 100 (Nicholas)'
);

-- line #10384
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HANSEPRAN 50 (Nicholas)',
	'Clofazimine',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HANSEPRAN 50 (Nicholas)'
);

-- line #10385
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEE CEE 50 (Medoz Ph.)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEE CEE 50 (Medoz Ph.)'
);

-- line #10386
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOFERT 100 (Svizera)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOFERT 100 (Svizera)'
);

-- line #10387
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOFERT 25 (Svizera)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOFERT 25 (Svizera)'
);

-- line #10388
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOFERT 50 (Svizera)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOFERT 50 (Svizera)'
);

-- line #10389
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOMATE 50 (SIFAM PH.)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOMATE 50 (SIFAM PH.)'
);

-- line #10390
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOME 100 (Solvay Ph.)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOME 100 (Solvay Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOME 150 (Solvay Ph.)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOME 150 (Solvay Ph.)'
);

-- line #10391
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOME 25 (Solvay Ph.)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOME 25 (Solvay Ph.)'
);

-- line #10392
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOME 50 (Solvay Ph.)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOME 50 (Solvay Ph.)'
);

-- line #10393
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOMICITE 50 (Cambridge Hc.)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOMICITE 50 (Cambridge Hc.)'
);

-- line #10394
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOMIKA 50 (AMIKA PH.)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOMIKA 50 (AMIKA PH.)'
);

-- line #10395
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOMISUR 25 (SURGE BIOTECH)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOMISUR 25 (SURGE BIOTECH)'
);

-- line #10396
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOMISUR 50 (SURGE BIOTECH)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOMISUR 50 (SURGE BIOTECH)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOMISUR 100 (SURGE BIOTECH)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOMISUR 100 (SURGE BIOTECH)'
);

-- line #10397
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOMI 50 (WEST COAST)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOMI 50 (WEST COAST)'
);

-- line #10398
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOMITROP 25 (Modi Mundi)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOMITROP 25 (Modi Mundi)'
);

-- line #10399
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOMITROP 50 (Modi Mundi)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOMITROP 50 (Modi Mundi)'
);

-- line #10400
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOMOCIT 25 (Merit Org.)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOMOCIT 25 (Merit Org.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOMOCIT 50 (Merit Org.)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOMOCIT 50 (Merit Org.)'
);

-- line #10401
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOMSET 25 (Dahlia Ph.)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOMSET 25 (Dahlia Ph.)'
);

-- line #10402
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOMSET 50 (Dahlia Ph.)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOMSET 50 (Dahlia Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOMSET 100 (Dahlia Ph.)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOMSET 100 (Dahlia Ph.)'
);

-- line #10403
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOPREG 25 (Kee Ph.)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOPREG 25 (Kee Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOPREG 50 (Kee Ph.)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOPREG 50 (Kee Ph.)'
);

-- line #10404
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOREK 50 (Rekvina)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOREK 50 (Rekvina)'
);

-- line #10405
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONCIVE 25 (TRIDENT PH.)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONCIVE 25 (TRIDENT PH.)'
);

-- line #10406
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONCIVE 50 (TRIDENT PH.)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONCIVE 50 (TRIDENT PH.)'
);

-- line #10407
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYTOVIM 50 (Alkem)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYTOVIM 50 (Alkem)'
);

-- line #10408
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUTCHCOM 100 (Dutch Rem.)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUTCHCOM 100 (Dutch Rem.)'
);

-- line #10409
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUTCHCOM 25 (Dutch Rem.)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUTCHCOM 25 (Dutch Rem.)'
);

-- line #10410
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUTCHCOM 50 (Dutch Rem.)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUTCHCOM 50 (Dutch Rem.)'
);

-- line #10411
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERPILL 25 (Intas)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERPILL 25 (Intas)'
);

-- line #10412
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERPILL 50 (Intas)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERPILL 50 (Intas)'
);

-- line #10413
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERTEX-M 25 (HIND. LATEX)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERTEX-M 25 (HIND. LATEX)'
);

-- line #10414
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERTEX 100 (HIND. LATEX)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERTEX 100 (HIND. LATEX)'
);

-- line #10415
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERTEX 50 (HIND. LATEX)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERTEX 50 (HIND. LATEX)'
);

-- line #10416
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERTICLO 50 (AXYZEN LIFE)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERTICLO 50 (AXYZEN LIFE)'
);

-- line #10417
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERTIK 50 (Zee Lab)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERTIK 50 (Zee Lab)'
);

-- line #10418
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERTILIN 50 (Ind-Swift)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERTILIN 50 (Ind-Swift)'
);

-- line #10419
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERTOMID 25 (Cipla)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERTOMID 25 (Cipla)'
);

-- line #10420
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERTOMID 50 (Cipla)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERTOMID 50 (Cipla)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERTOMID 100 (Cipla)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERTOMID 100 (Cipla)'
);

-- line #10421
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERTON 25 (Inga)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERTON 25 (Inga)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERTON 50 (Inga)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERTON 50 (Inga)'
);

-- line #10422
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERTOTAB 25 (Gsk)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERTOTAB 25 (Gsk)'
);

-- line #10423
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERTOTAB 50 (Gsk)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERTOTAB 50 (Gsk)'
);

-- line #10424
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERTOVA 25 (Triton Hc.)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERTOVA 25 (Triton Hc.)'
);

-- line #10425
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERTOVA 50 (Triton Hc.)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERTOVA 50 (Triton Hc.)'
);

-- line #10426
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERTYL-M 25 (Ar-Ex Labs.)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERTYL-M 25 (Ar-Ex Labs.)'
);

-- line #10427
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERTYL SUPER 100 (Ar-Ex Labs.)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERTYL SUPER 100 (Ar-Ex Labs.)'
);

-- line #10428
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERTYL 50 (Ar-Ex Labs.)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERTYL 50 (Ar-Ex Labs.)'
);

-- line #10429
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FETROP 25 (SOLITAIRE(RADIX))',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FETROP 25 (SOLITAIRE(RADIX))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FETROP 50 (SOLITAIRE(RADIX))',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FETROP 50 (SOLITAIRE(RADIX))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FETROP 100 (SOLITAIRE(RADIX))',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FETROP 100 (SOLITAIRE(RADIX))'
);

-- line #10430
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLISTIM 100 (Zydus Cadila)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLISTIM 100 (Zydus Cadila)'
);

-- line #10431
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLISTIM 50 (Zydus Cadila)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLISTIM 50 (Zydus Cadila)'
);

-- line #10432
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FULFYN 25 (Micro Nova)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FULFYN 25 (Micro Nova)'
);

-- line #10433
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FULFYN 50 (Micro Nova)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FULFYN 50 (Micro Nova)'
);

-- line #10434
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HUMANOVA 100 (ROSE LABS)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HUMANOVA 100 (ROSE LABS)'
);

-- line #10435
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HUMANOVA 25 (ROSE LABS)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HUMANOVA 25 (ROSE LABS)'
);

-- line #10436
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HUMANOVA 50 (ROSE LABS)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HUMANOVA 50 (ROSE LABS)'
);

-- line #10437
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INFERT 50 (Southsourne)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INFERT 50 (Southsourne)'
);

-- line #10438
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INFOTYL 25 (Shreeyam)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INFOTYL 25 (Shreeyam)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INFOTYL 50 (Shreeyam)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INFOTYL 50 (Shreeyam)'
);

-- line #10439
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMICITE 50 (Torrent)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMICITE 50 (Torrent)'
);

-- line #10440
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OVAGEN 100 (Walter B.)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OVAGEN 100 (Walter B.)'
);

-- line #10441
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OVAGEN 25 (Walter B.)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OVAGEN 25 (Walter B.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OVAGEN 50 (Walter B.)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OVAGEN 50 (Walter B.)'
);

-- line #10442
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OVIPHENE-25 25 (Lupin)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OVIPHENE-25 25 (Lupin)'
);

-- line #10443
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OVIPHENE-50 50 (Lupin)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OVIPHENE-50 50 (Lupin)'
);

-- line #10444
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OVIPREG 25 (Win-Medicare)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OVIPREG 25 (Win-Medicare)'
);

-- line #10445
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OVIPREG 50 (Win-Medicare)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OVIPREG 50 (Win-Medicare)'
);

-- line #10446
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OVITEC 100 (BIOMAX BIO.)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OVITEC 100 (BIOMAX BIO.)'
);

-- line #10447
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OVOFAR 50 (Infar)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OVOFAR 50 (Infar)'
);

-- line #10448
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OVOFAR 100 (Organon)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OVOFAR 100 (Organon)'
);

-- line #10449
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OVUCLOM 100 (Life Sciences)',
	'CLOMIPHENE',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OVUCLOM 100 (Life Sciences)'
);

-- line #10450
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OVUCLOM 25 (Life Sciences)',
	'CLOMIPHENE',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OVUCLOM 25 (Life Sciences)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OVUCLOM 50 (Life Sciences)',
	'CLOMIPHENE',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OVUCLOM 50 (Life Sciences)'
);

-- line #10451
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OVUFERT 25 (Pifer Ph.)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OVUFERT 25 (Pifer Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OVUFERT 50 (Pifer Ph.)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OVUFERT 50 (Pifer Ph.)'
);

-- line #10452
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OVULANTA 300 (Mankind)',
	'Clomiphene',
	'KIT',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OVULANTA 300 (Mankind)'
);

-- line #10453
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGMATE-M 25 (Helios Ph.)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGMATE-M 25 (Helios Ph.)'
);

-- line #10454
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGMATE 50 (Helios Ph.)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGMATE 50 (Helios Ph.)'
);

-- line #10455
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REFERT 50 (Uni-Sank.)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REFERT 50 (Uni-Sank.)'
);

-- line #10456
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REJUN 100 (Uni-Sank.)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REJUN 100 (Uni-Sank.)'
);

-- line #10457
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REJUN 25 (Uni-Sank.)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REJUN 25 (Uni-Sank.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REJUN 50 (Uni-Sank.)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REJUN 50 (Uni-Sank.)'
);

-- line #10458
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESET 50 (Dial Ph.)',
	'Clomiphene',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESET 50 (Dial Ph.)'
);

-- line #10459
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANAFRANIL 10 (Novartis)',
	'Clomipramine Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANAFRANIL 10 (Novartis)'
);

-- line #10460
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANAFRANIL 25 (Novartis)',
	'Clomipramine Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANAFRANIL 25 (Novartis)'
);

-- line #10461
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOLOMIN 50 (Chemo Bio.)',
	'Clomipramine Hcl.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOLOMIN 50 (Chemo Bio.)'
);

-- line #10462
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOFRANIL 75 (Sun)',
	'Clomipramine Hcl.',
	'SR TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOFRANIL 75 (Sun)'
);

-- line #10463
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOFRANIL 10 (Sun)',
	'Clomipramine Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOFRANIL 10 (Sun)'
);

-- line #10464
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOFRANIL 25 (Sun)',
	'Clomipramine Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOFRANIL 25 (Sun)'
);

-- line #10465
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOFRANIL 50 (Sun)',
	'Clomipramine Hcl.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOFRANIL 50 (Sun)'
);

-- line #10466
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOMIDAC 25 (CADILA)',
	'Clomipramine Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOMIDAC 25 (CADILA)'
);

-- line #10467
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOMIDAC 50 (CADILA)',
	'Clomipramine Hcl.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOMIDAC 50 (CADILA)'
);

-- line #10468
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOMIDIP 25 (AMEE PH.)',
	'Clomipramine Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOMIDIP 25 (AMEE PH.)'
);

-- line #10469
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOMIDIP 75 (AMEE PH.)',
	'Clomipramine Hcl.',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOMIDIP 75 (AMEE PH.)'
);

-- line #10470
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOMIFRIL 10 (Torrent)',
	'Clomipramine Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOMIFRIL 10 (Torrent)'
);

-- line #10471
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOMIFRIL 25 (Torrent)',
	'Clomipramine Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOMIFRIL 25 (Torrent)'
);

-- line #10472
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOMINE 25 (Pil)',
	'Clomipramine Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOMINE 25 (Pil)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOMINE 50 (Pil)',
	'Clomipramine Hcl.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOMINE 50 (Pil)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOMINE 75 (Pil)',
	'Clomipramine Hcl.',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOMINE 75 (Pil)'
);

-- line #10473
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOMIP 10 (Reliance)',
	'Clomipramine Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOMIP 10 (Reliance)'
);

-- line #10474
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOMIP 25 (Reliance)',
	'Clomipramine Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOMIP 25 (Reliance)'
);

-- line #10475
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOMIP 50 (Reliance)',
	'Clomipramine Hcl.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOMIP 50 (Reliance)'
);

-- line #10476
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOMIZIL 25 (Gufic Bio.)',
	'Clomipramine Hcl.',
	'CAP',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOMIZIL 25 (Gufic Bio.)'
);

-- line #10477
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOM 75 (Sali Hc.)',
	'Clomipramine Hcl.',
	'SR TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOM 75 (Sali Hc.)'
);

-- line #10478
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLONIL 75 (Intas)',
	'Clomipramine Hcl.',
	'SR TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLONIL 75 (Intas)'
);

-- line #10479
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLONIL 10 (Intas)',
	'Clomipramine Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLONIL 10 (Intas)'
);

-- line #10480
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLONIL 25 (Intas)',
	'Clomipramine Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLONIL 25 (Intas)'
);

-- line #10481
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLONIL 50 (Intas)',
	'Clomipramine Hcl.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLONIL 50 (Intas)'
);

-- line #10482
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLO 25 (Mano)',
	'Clomipramine Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLO 25 (Mano)'
);

-- line #10483
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLO 50 (Mano)',
	'Clomipramine Hcl.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLO 50 (Mano)'
);

-- line #10484
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPNIL 25 (Cipla)',
	'Clomipramine Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPNIL 25 (Cipla)'
);

-- line #10485
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPRESSOR 75 (Theo Ph.)',
	'Clomipramine Hcl.',
	'SR TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPRESSOR 75 (Theo Ph.)'
);

-- line #10486
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPRESSOR 25 (Theo Ph.)',
	'Clomipramine Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPRESSOR 25 (Theo Ph.)'
);

-- line #10487
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPRESSOR 50 (Theo Ph.)',
	'Clomipramine Hcl.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPRESSOR 50 (Theo Ph.)'
);

-- line #10488
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FETICLO 50 (ALPHA TH.)',
	'Clomipramine Hcl.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FETICLO 50 (ALPHA TH.)'
);

-- line #10489
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KLOMIN 25 (Rkg)',
	'Clomipramine Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KLOMIN 25 (Rkg)'
);

-- line #10490
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCIFRIL 25 (LA DRUG)',
	'Clomipramine Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCIFRIL 25 (LA DRUG)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCIFRIL 50 (LA DRUG)',
	'Clomipramine Hcl.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCIFRIL 50 (LA DRUG)'
);

-- line #10491
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCIFRIL 75 (La Drug)',
	'Clomipramine Hcl.',
	'XR TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg(ER)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCIFRIL 75 (La Drug)'
);

-- line #10492
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSIDY 25 (Crystal Ph.)',
	'Clomipramine Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSIDY 25 (Crystal Ph.)'
);

-- line #10493
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANXIPAR 0.25 (Torrent)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANXIPAR 0.25 (Torrent)'
);

-- line #10494
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANXIPAR 0.5 (Torrent)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANXIPAR 0.5 (Torrent)'
);

-- line #10495
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APLAZ 0.25 (Crescent Th.)',
	'Clonazepam',
	'DT TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APLAZ 0.25 (Crescent Th.)'
);

-- line #10496
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APLAZ 0.5 (Crescent Th.)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APLAZ 0.5 (Crescent Th.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APLAZ 1 (Crescent Th.)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APLAZ 1 (Crescent Th.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APLAZ 2 (Crescent Th.)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APLAZ 2 (Crescent Th.)'
);

-- line #10497
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOCLON 0.5 (Rhombus)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOCLON 0.5 (Rhombus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOCLON 2 (Rhombus)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOCLON 2 (Rhombus)'
);

-- line #10498
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CATIER 0.25 (D.R.John''S)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'0,5'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CATIER 0.25 (D.R.John''S)'
);

-- line #10499
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CERGO 0.5 (Novartis)',
	'Clonazepam',
	'MD TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CERGO 0.5 (Novartis)'
);

-- line #10500
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Clonazepam', u'always_empty': u'', u'form': u'TAB', u'brand': u'CINZEP-05', u'strength_3': u'', u'company': u'Biocin Hc.', u'unit': u''}

-- line #10501
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CINZEP 0.5 (Biocia Hc.)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CINZEP 0.5 (Biocia Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CINZEP 1 (Biocia Hc.)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CINZEP 1 (Biocia Hc.)'
);

-- line #10502
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CINZEP 2 (Biocia Hc.)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CINZEP 2 (Biocia Hc.)'
);

-- line #10503
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLEPS 0.5 (OREVA DARMO.)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLEPS 0.5 (OREVA DARMO.)'
);

-- line #10504
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLODEP 0.25 (BCC HC.)',
	'Clonazepam',
	'MD TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLODEP 0.25 (BCC HC.)'
);

-- line #10505
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLODEP 0.5 (BCC HC.)',
	'Clonazepam',
	'MD TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLODEP 0.5 (BCC HC.)'
);

-- line #10506
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLONA CURE 0.25 (AVITECH)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLONA CURE 0.25 (AVITECH)'
);

-- line #10507
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLONA CURE 0.5 (AVITECH)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLONA CURE 0.5 (AVITECH)'
);

-- line #10508
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLONADEV 0.5 (AMEE PH.)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLONADEV 0.5 (AMEE PH.)'
);

-- line #10509
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLONAFIT 0.25 (Mankind)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLONAFIT 0.25 (Mankind)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLONAFIT 0.5 (Mankind)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLONAFIT 0.5 (Mankind)'
);

-- line #10510
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLONAM 0.25 (Tripada Hc.)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLONAM 0.25 (Tripada Hc.)'
);

-- line #10511
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLONAPAX 0.5 (Reliance)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLONAPAX 0.5 (Reliance)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLONAPAX 1 (Reliance)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLONAPAX 1 (Reliance)'
);

-- line #10512
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLONAPAX 2 (Reliance)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLONAPAX 2 (Reliance)'
);

-- line #10513
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLONAPIK 0.25 (Aarpik Ph.)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLONAPIK 0.25 (Aarpik Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLONAPIK 0.5 (Aarpik Ph.)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLONAPIK 0.5 (Aarpik Ph.)'
);

-- line #10514
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLONAPIK 1 (Aarpik Ph.)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLONAPIK 1 (Aarpik Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLONAPIK 2 (Aarpik Ph.)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLONAPIK 2 (Aarpik Ph.)'
);

-- line #10515
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLONATRAC 0.5 (MINOVA(PSYCHONOVA))',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLONATRAC 0.5 (MINOVA(PSYCHONOVA))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLONATRAC 1 (MINOVA(PSYCHONOVA))',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLONATRAC 1 (MINOVA(PSYCHONOVA))'
);

-- line #10516
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLONAV 0.25 (NAVNIDHI LIFE)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLONAV 0.25 (NAVNIDHI LIFE)'
);

-- line #10517
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLONAV 0.5 (NAVNIDHI LIFE)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLONAV 0.5 (NAVNIDHI LIFE)'
);

-- line #10518
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLONAXYL 0.5 (Marc Lab)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLONAXYL 0.5 (Marc Lab)'
);

-- line #10519
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLONAXYL 2 (Marc Lab)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLONAXYL 2 (Marc Lab)'
);

-- line #10520
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLONOPAM 0.25 (MOLEKULE)',
	'Clonazepam',
	'MD TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLONOPAM 0.25 (MOLEKULE)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLONOPAM 5 (MOLEKULE)',
	'Clonazepam',
	'MD TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLONOPAM 5 (MOLEKULE)'
);

-- line #10521
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLONOPAM 1 (MOLEKULE)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLONOPAM 1 (MOLEKULE)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLONOPAM 2 (MOLEKULE)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLONOPAM 2 (MOLEKULE)'
);

-- line #10522
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLONOTRIL 0.25 (Torrent)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLONOTRIL 0.25 (Torrent)'
);

-- line #10523
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLONOTRIL 0.5 (Torrent)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLONOTRIL 0.5 (Torrent)'
);

-- line #10524
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLONOTRIL 1 (Torrent)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLONOTRIL 1 (Torrent)'
);

-- line #10525
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLONOTRIL 2 (Torrent)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLONOTRIL 2 (Torrent)'
);

-- line #10526
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLONZY 0.5 (Vega Lab)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLONZY 0.5 (Vega Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLONZY 1 (Vega Lab)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLONZY 1 (Vega Lab)'
);

-- line #10527
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLONZY 2 (Vega Lab)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLONZY 2 (Vega Lab)'
);

-- line #10528
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOPAM 0.5 (EAST WEST)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOPAM 0.5 (EAST WEST)'
);

-- line #10529
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOPAM 1 (EAST WEST)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOPAM 1 (EAST WEST)'
);

-- line #10530
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOPAM 2 (EAST WEST)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOPAM 2 (EAST WEST)'
);

-- line #10531
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOSED 0.25 (Corona)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOSED 0.25 (Corona)'
);

-- line #10532
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOSED 0.5 (Corona)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOSED 0.5 (Corona)'
);

-- line #10533
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOSPIN 0.5 (Cerspin)',
	'Clonazepam',
	'MD TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOSPIN 0.5 (Cerspin)'
);

-- line #10534
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOTAS SR-05 0.5 (Tasmed)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOTAS SR-05 0.5 (Tasmed)'
);

-- line #10535
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOTAS SR-1 1 (Tasmed)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOTAS SR-1 1 (Tasmed)'
);

-- line #10536
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOTAS 0.5 (TASMED)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOTAS 0.5 (TASMED)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOTAS 1 (TASMED)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOTAS 1 (TASMED)'
);

-- line #10537
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOTAS 2 (TASMED)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOTAS 2 (TASMED)'
);

-- line #10538
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOVAS 0.5 (Theo Ph.)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOVAS 0.5 (Theo Ph.)'
);

-- line #10539
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOVAS 1 (Theo Ph.)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOVAS 1 (Theo Ph.)'
);

-- line #10540
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOVAS 2 (Theo Ph.)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOVAS 2 (Theo Ph.)'
);

-- line #10541
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOVIND 0.5 (Dr.Arvind Shah''S)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOVIND 0.5 (Dr.Arvind Shah''S)'
);

-- line #10542
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOZARIL 0.25 (NAVNIDHI LIFE)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOZARIL 0.25 (NAVNIDHI LIFE)'
);

-- line #10543
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOZARIL 0.5 (NAVNIDHI LIFE)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOZARIL 0.5 (NAVNIDHI LIFE)'
);

-- line #10544
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOZEPAM 0.25 (IP HC.)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOZEPAM 0.25 (IP HC.)'
);

-- line #10545
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOZEPAM 0.5 (IP HC.)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOZEPAM 0.5 (IP HC.)'
);

-- line #10546
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOZEP 0.5 (Elite Ph.)',
	'Clonazepam',
	'DT',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOZEP 0.5 (Elite Ph.)'
);

-- line #10547
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOZEP 0.5 (Elite Ph.)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOZEP 0.5 (Elite Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOZEP 1 (Elite Ph.)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOZEP 1 (Elite Ph.)'
);

-- line #10548
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOZEP 2 (Elite Ph.)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOZEP 2 (Elite Ph.)'
);

-- line #10549
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONVACLON 0.5 (BARODA)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONVACLON 0.5 (BARODA)'
);

-- line #10550
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONVACLON 2 (BARODA)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONVACLON 2 (BARODA)'
);

-- line #10551
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COZIL 0.5 (Medico)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COZIL 0.5 (Medico)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COZIL 1 (Medico)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COZIL 1 (Medico)'
);

-- line #10552
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CZPAM 0.25 (Alkem)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CZPAM 0.25 (Alkem)'
);

-- line #10553
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CZPAM 0.5 (Alkem)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CZPAM 0.5 (Alkem)'
);

-- line #10554
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CZPAM 1 (Alkem)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CZPAM 1 (Alkem)'
);

-- line #10555
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ECOTRIL 0.5 (ECON HC.)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ECOTRIL 0.5 (ECON HC.)'
);

-- line #10556
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPCON 0.25 (LA PHARMA)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'0.5'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPCON 0.25 (LA PHARMA)'
);

-- line #10557
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPCON 1 (LA PHARMA)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPCON 1 (LA PHARMA)'
);

-- line #10558
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPCON 2 (LA PHARMA)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPCON 2 (LA PHARMA)'
);

-- line #10559
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPICLOZ 0.5 (Olcare)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPICLOZ 0.5 (Olcare)'
);

-- line #10560
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPICLOZ 2 (Olcare)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPICLOZ 2 (Olcare)'
);

-- line #10561
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPITRIAL MD 0.5 (Novartis)',
	'Clonazepam',
	'DT',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPITRIAL MD 0.5 (Novartis)'
);

-- line #10562
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPITRIL 0.5 (Novartis)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPITRIL 0.5 (Novartis)'
);

-- line #10563
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPITRIL 2 (Novartis)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPITRIL 2 (Novartis)'
);

-- line #10564
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPIZAM 0.25 (Cipla)',
	'Clonazepam',
	'MD TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPIZAM 0.25 (Cipla)'
);

-- line #10565
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPIZAM 0.5 (Cipla)',
	'Clonazepam',
	'MD TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPIZAM 0.5 (Cipla)'
);

-- line #10566
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPIZAM 1 (Cipla)',
	'Clonazepam',
	'MD TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPIZAM 1 (Cipla)'
);

-- line #10567
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPIZAM 2 (Cipla)',
	'Clonazepam',
	'MD TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPIZAM 2 (Cipla)'
);

-- line #10568
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HOPE 0.5 (Rkg)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HOPE 0.5 (Rkg)'
);

-- line #10569
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,25', u'strength_2': u'', u'substance': u'Clonazepam', u'always_empty': u'', u'form': u'', u'brand': u'KLONAZ', u'strength_3': u'', u'company': u'KIVI HC.', u'unit': u'mg'}

-- line #10570
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,5', u'strength_2': u'', u'substance': u'Clonazepam', u'always_empty': u'', u'form': u'', u'brand': u'KLONAZ', u'strength_3': u'', u'company': u'KIVI HC.', u'unit': u'mg'}

-- line #10571
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KLON 0.5 (MAYFLOWER IND.)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KLON 0.5 (MAYFLOWER IND.)'
);

-- line #10572
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KLON 0.5 (STADCHEM)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KLON 0.5 (STADCHEM)'
);

-- line #10573
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KLON 2 (STADCHEM)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KLON 2 (STADCHEM)'
);

-- line #10574
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LONACEN 0.25 (CENTRA(USV))',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LONACEN 0.25 (CENTRA(USV))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LONACEN 0.5 (CENTRA(USV))',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LONACEN 0.5 (CENTRA(USV))'
);

-- line #10575
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LONACEN 1 (CENTRA(USV))',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LONACEN 1 (CENTRA(USV))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LONACEN 2 (CENTRA(USV))',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LONACEN 2 (CENTRA(USV))'
);

-- line #10576
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LONAPAM 0.25 (SHINE PH.)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LONAPAM 0.25 (SHINE PH.)'
);

-- line #10577
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LONAPAM 0.5 (SHINE PH.)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LONAPAM 0.5 (SHINE PH.)'
);

-- line #10578
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LONAZEP 1 (Sun)',
	'Clonazepam',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LONAZEP 1 (Sun)'
);

-- line #10579
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LONAZEP 0.25 (Sun)',
	'Clonazepam',
	'MD TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LONAZEP 0.25 (Sun)'
);

-- line #10580
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LONAZEP 0.5 (Sun)',
	'Clonazepam',
	'MD TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LONAZEP 0.5 (Sun)'
);

-- line #10581
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LONAZEP 2 (Sun)',
	'Clonazepam',
	'MD TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LONAZEP 2 (Sun)'
);

-- line #10582
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LONAZEP 0.25 (Sun)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LONAZEP 0.25 (Sun)'
);

-- line #10583
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LONAZEP 0.5 (Sun)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LONAZEP 0.5 (Sun)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LONAZEP 1 (Sun)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LONAZEP 1 (Sun)'
);

-- line #10584
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LONAZEP 2 (Sun)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LONAZEP 2 (Sun)'
);

-- line #10585
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LONIN 0.5 (Chemo Bio.)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LONIN 0.5 (Chemo Bio.)'
);

-- line #10586
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LONIN 2 (Chemo Bio.)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LONIN 2 (Chemo Bio.)'
);

-- line #10587
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LONNA 0.5 (TRITON(CALYX))',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LONNA 0.5 (TRITON(CALYX))'
);

-- line #10588
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LONNA 1 (TRITON(CALYX))',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LONNA 1 (TRITON(CALYX))'
);

-- line #10589
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LONNA 2 (TRITON(CALYX))',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LONNA 2 (TRITON(CALYX))'
);

-- line #10590
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOZEP 0.5 (Pil)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOZEP 0.5 (Pil)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOZEP 2 (Pil)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOZEP 2 (Pil)'
);

-- line #10591
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,5', u'strength_2': u'', u'substance': u'Clonazepam', u'always_empty': u'', u'form': u'', u'brand': u'MEDIZEP', u'strength_3': u'', u'company': u'MEDIFORECE', u'unit': u'mg'}

-- line #10592
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,25', u'strength_2': u'', u'substance': u'Clonazepam', u'always_empty': u'', u'form': u'', u'brand': u'MELOPRAX-025(NEW FORMULA)', u'strength_3': u'', u'company': u'Mankind', u'unit': u'mg'}

-- line #10593
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,5', u'strength_2': u'', u'substance': u'Clonazepam', u'always_empty': u'', u'form': u'', u'brand': u'MELOPRAX-050(NEW FORMULA)', u'strength_3': u'', u'company': u'Mankind', u'unit': u'mg'}

-- line #10594
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELZAP 0.25 (Alkem)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELZAP 0.25 (Alkem)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELZAP 0.5 (Alkem)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELZAP 0.5 (Alkem)'
);

-- line #10595
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELZAP 1 (Alkem)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELZAP 1 (Alkem)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELZAP 2 (Alkem)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELZAP 2 (Alkem)'
);

-- line #10596
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAZEE 0.5 (Medizone)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAZEE 0.5 (Medizone)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAZEE 2 (Medizone)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAZEE 2 (Medizone)'
);

-- line #10597
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOREP 0.5 (Mankind MAGNET)',
	'Clonazepam',
	'DT',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOREP 0.5 (Mankind MAGNET)'
);

-- line #10598
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOREP 0.5 (Mankind MAGNET)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOREP 0.5 (Mankind MAGNET)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOREP 1 (Mankind MAGNET)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOREP 1 (Mankind MAGNET)'
);

-- line #10599
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOREP 2 (Mankind MAGNET)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOREP 2 (Mankind MAGNET)'
);

-- line #10600
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONAPIL 0.5 (Cyril Ph.)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONAPIL 0.5 (Cyril Ph.)'
);

-- line #10601
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OZEPAM 0.5 (IPCA(INNOVA))',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OZEPAM 0.5 (IPCA(INNOVA))'
);

-- line #10602
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OZEPAM 2 (IPCA(INNOVA))',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OZEPAM 2 (IPCA(INNOVA))'
);

-- line #10603
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,5', u'strength_2': u'', u'substance': u'Clonazepam', u'always_empty': u'', u'form': u'', u'brand': u'PAM', u'strength_3': u'', u'company': u'ROSE LABS', u'unit': u'mg'}

-- line #10604
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PETRIL 0.25 (Synapse)',
	'Clonazepam',
	'MD TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PETRIL 0.25 (Synapse)'
);

-- line #10605
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PETRIL 0.5 (Synapse)',
	'Clonazepam',
	'MD TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PETRIL 0.5 (Synapse)'
);

-- line #10606
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PETRIL 0.5 (Synapse)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PETRIL 0.5 (Synapse)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PETRIL 1 (Synapse)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PETRIL 1 (Synapse)'
);

-- line #10607
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PETRIL 2 (Synapse)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PETRIL 2 (Synapse)'
);

-- line #10608
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESTOPAM 0.25 (AVIS LIFE)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESTOPAM 0.25 (AVIS LIFE)'
);

-- line #10609
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESTOPAM 0.5 (AVIS LIFE)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESTOPAM 0.5 (AVIS LIFE)'
);

-- line #10610
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESTOVEL 0.25 (Kinedex Hc.)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESTOVEL 0.25 (Kinedex Hc.)'
);

-- line #10611
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESTOVEL 0.5 (Kinedex Hc.)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESTOVEL 0.5 (Kinedex Hc.)'
);

-- line #10612
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESTOVIS 25 (AVIS LIFE)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESTOVIS 25 (AVIS LIFE)'
);

-- line #10613
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESTOVIS 5 (AVIS LIFE)',
	'Clonazepam',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESTOVIS 5 (AVIS LIFE)'
);

-- line #10614
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100MCG', u'strength_2': u'', u'substance': u'Clonidine Hcl.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ARKAMIN', u'strength_3': u'', u'company': u'Unichem', u'unit': u''}

-- line #10615
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100MCG', u'strength_2': u'', u'substance': u'Clonidine Hcl.', u'always_empty': u'', u'form': u'TAB', u'brand': u'CATAPRES', u'strength_3': u'', u'company': u'German R.', u'unit': u''}

-- line #10616
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'150MCG', u'strength_2': u'ML', u'substance': u'Clonidine Hcl.', u'always_empty': u'', u'form': u'INJ', u'brand': u'CLONEON', u'strength_3': u'', u'company': u'Neon', u'unit': u''}

-- line #10617
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRINALDIX 20 (Novartis)',
	'Clopamide',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRINALDIX 20 (Novartis)'
);

-- line #10618
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACLOTIL 75 (Bal Ph.)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACLOTIL 75 (Bal Ph.)'
);

-- line #10619
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANTIBAN 75 (Blue Cross)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANTIBAN 75 (Blue Cross)'
);

-- line #10620
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANTICOG 75 (Marc Lab)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANTICOG 75 (Marc Lab)'
);

-- line #10621
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANTIPLAR 75 (Nucron Ph.)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANTIPLAR 75 (Nucron Ph.)'
);

-- line #10622
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APLATIN 75 (Saga Lab)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APLATIN 75 (Saga Lab)'
);

-- line #10623
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APTOGREL 75 (Argus)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APTOGREL 75 (Argus)'
);

-- line #10624
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASOGREL 75 (AS PHARMA)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASOGREL 75 (AS PHARMA)'
);

-- line #10625
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLOTHIN 75 (Indi Ph.)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLOTHIN 75 (Indi Ph.)'
);

-- line #10626
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAPLOR 75 (Ind-Swift)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAPLOR 75 (Ind-Swift)'
);

-- line #10627
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARPIGREL 75 (SHRRISHTI HC.)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARPIGREL 75 (SHRRISHTI HC.)'
);

-- line #10628
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CERUVIN 150 (Ranbaxy)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CERUVIN 150 (Ranbaxy)'
);

-- line #10629
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CERUVIN 75 (Ranbaxy Cv)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CERUVIN 75 (Ranbaxy Cv)'
);

-- line #10630
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-GREL 75 (TRITON(CALYX))',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-GREL 75 (TRITON(CALYX))'
);

-- line #10631
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-GREL 75 (Triton Hc.)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-GREL 75 (Triton Hc.)'
);

-- line #10632
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIDOGREL 75 (Kapl)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIDOGREL 75 (Kapl)'
);

-- line #10633
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLASS 75 (TALENT PH.)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLASS 75 (TALENT PH.)'
);

-- line #10634
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLAVIX 150 (Intas)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLAVIX 150 (Intas)'
);

-- line #10635
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLAVIX 300 (Intas)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLAVIX 300 (Intas)'
);

-- line #10636
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLAVIX 75 (Intas)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLAVIX 75 (Intas)'
);

-- line #10637
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLODREL 75 (Unichem)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLODREL 75 (Unichem)'
);

-- line #10638
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOFIRST 150 (SINSAN PH.)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOFIRST 150 (SINSAN PH.)'
);

-- line #10639
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOFIRST 75 (SINSAN PH.)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOFIRST 75 (SINSAN PH.)'
);

-- line #10640
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOFLOW 75 (Otsira)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOFLOW 75 (Otsira)'
);

-- line #10641
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOFRE 75 (EAST WEST)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOFRE 75 (EAST WEST)'
);

-- line #10642
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOLYSE 75 (AKESISS)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOLYSE 75 (AKESISS)'
);

-- line #10643
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOPICARD 75 (Cipla)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOPICARD 75 (Cipla)'
);

-- line #10644
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOPICRON 75 (Acron Ph.)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOPICRON 75 (Acron Ph.)'
);

-- line #10645
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOPID 75 (HETERO HC.)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOPID 75 (HETERO HC.)'
);

-- line #10646
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOPIGREL 75 (U S V)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOPIGREL 75 (U S V)'
);

-- line #10647
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'300', u'strength_2': u'', u'substance': u'Clopidogrel', u'always_empty': u'', u'form': u'', u'brand': u'CLOPIGREL', u'strength_3': u'', u'company': u'USV PHARMA', u'unit': u'mg'}

-- line #10648
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOPIJOY 75 (Torrent)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOPIJOY 75 (Torrent)'
);

-- line #10649
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOPIKIND 75 (Mankind)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOPIKIND 75 (Mankind)'
);

-- line #10650
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOPILET 150 (Sun)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOPILET 150 (Sun)'
);

-- line #10651
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOPILET 75 (Sun)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOPILET 75 (Sun)'
);

-- line #10652
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOPIRAD 75 (Indoco Rem.)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOPIRAD 75 (Indoco Rem.)'
);

-- line #10653
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOPI 150 (Skymax)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOPI 150 (Skymax)'
);

-- line #10654
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOPI 75 (Skymax)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOPI 75 (Skymax)'
);

-- line #10655
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOPITAB 150 (Lupin)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOPITAB 150 (Lupin)'
);

-- line #10656
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOPITAB 75 (Lupin)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOPITAB 75 (Lupin)'
);

-- line #10657
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOPIVAS-150 150 (Cipla)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOPIVAS-150 150 (Cipla)'
);

-- line #10658
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOPIVAS 75 (Cipla)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOPIVAS 75 (Cipla)'
);

-- line #10659
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOPIZIDE 75 (ESSWEIL)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOPIZIDE 75 (ESSWEIL)'
);

-- line #10660
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOPLAT 75 (Ipca)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOPLAT 75 (Ipca)'
);

-- line #10661
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOPOD 75 (Biochem)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOPOD 75 (Biochem)'
);

-- line #10662
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOPREZ 75 (Rpg Life)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOPREZ 75 (Rpg Life)'
);

-- line #10663
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOTSAFE 75 (MSN LAB.)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOTSAFE 75 (MSN LAB.)'
);

-- line #10664
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COMPIVAS 75 (Cipla)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COMPIVAS 75 (Cipla)'
);

-- line #10665
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CPG-150 150 (Sunij)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CPG-150 150 (Sunij)'
);

-- line #10666
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CPG 75 (Sunij)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CPG 75 (Sunij)'
);

-- line #10667
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPLATT 150 (Torrent)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPLATT 150 (Torrent)'
);

-- line #10668
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPLATT 75 (Torrent)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPLATT 75 (Torrent)'
);

-- line #10669
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Clopidogrel', u'always_empty': u'', u'form': u'TAB', u'brand': u'GLORY', u'strength_3': u'', u'company': u'ETHIX HC.', u'unit': u''}

-- line #10670
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRELET 75 (Intra Lab)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRELET 75 (Intra Lab)'
);

-- line #10671
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KLOV 75 (Zee Lab)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KLOV 75 (Zee Lab)'
);

-- line #10672
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LO-PLATT 75 (AEGIS)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LO-PLATT 75 (AEGIS)'
);

-- line #10673
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOKLOT 300 (ZYDUS CND)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOKLOT 300 (ZYDUS CND)'
);

-- line #10674
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOKLOT 75 (Zydus Med.)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOKLOT 75 (Zydus Med.)'
);

-- line #10675
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOPLAQ 75 (Alkem)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOPLAQ 75 (Alkem)'
);

-- line #10676
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUGREL 75 (Synapse)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUGREL 75 (Synapse)'
);

-- line #10677
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORAWIS 75 (Merck)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORAWIS 75 (Merck)'
);

-- line #10678
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENCIL 50 (Cadila Ph.)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENCIL 50 (Cadila Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENCIL 100 (Cadila Ph.)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENCIL 100 (Cadila Ph.)'
);

-- line #10679
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIAGRIL GOLD 300 (Dr.Reddy''S)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIAGRIL GOLD 300 (Dr.Reddy''S)'
);

-- line #10680
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIDLET 75 (Mano)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIDLET 75 (Mano)'
);

-- line #10681
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLAGERINE 75 (Carsyon)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLAGERINE 75 (Carsyon)'
);

-- line #10682
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLAGRIL GOLD 75 (DR. REDDY''S)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLAGRIL GOLD 75 (DR. REDDY''S)'
);

-- line #10683
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLAGRIL 75 (Dr.Reddy''S)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLAGRIL 75 (Dr.Reddy''S)'
);

-- line #10684
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLATFREE 75 (Medley)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLATFREE 75 (Medley)'
);

-- line #10685
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLATFRIN 75 (Medley)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLATFRIN 75 (Medley)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLATFRIN 150 (Medley)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLATFRIN 150 (Medley)'
);

-- line #10686
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLATLOC 75 (Unichem)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLATLOC 75 (Unichem)'
);

-- line #10687
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLAVIX 75 (Sanofi Aventis)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLAVIX 75 (Sanofi Aventis)'
);

-- line #10688
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREVA 75 (Intas)',
	'Clopidogrel',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREVA 75 (Intas)'
);

-- line #10689
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ABZORB 1 (Croslands)',
	'Clotrimazole',
	'POW',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ABZORB 1 (Croslands)'
);

-- line #10690
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANTICAN 10 (BARODA)',
	'Clotrimazole',
	'CRM',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANTICAN 10 (BARODA)'
);

-- line #10691
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Clotrimazole', u'always_empty': u'', u'form': u'TAB', u'brand': u'ANTICAN VEG', u'strength_3': u'', u'company': u'BARODA', u'unit': u''}

-- line #10692
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALCREM 1 (R.B.)',
	'Clotrimazole',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALCREM 1 (R.B.)'
);

-- line #10693
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANAZOLE 1 (Lupin)',
	'Clotrimazole',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANAZOLE 1 (Lupin)'
);

-- line #10694
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANCAP VT VEG 100 (Ind-Swift)',
	'Clotrimazole',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANCAP VT VEG 100 (Ind-Swift)'
);

-- line #10695
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANDEX-2 2 (Karlin)',
	'Clotrimazole',
	'CRM',
	gm.nullify_empty_string('2')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANDEX-2 2 (Karlin)'
);

-- line #10696
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANDEX-2 2 (Karlin)',
	'Clotrimazole',
	'LOT',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANDEX-2 2 (Karlin)'
);

-- line #10697
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANDEX-2 2 (Karlin)',
	'Clotrimazole',
	'POW',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANDEX-2 2 (Karlin)'
);

-- line #10698
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANDEX 1 (Karlin)',
	'Clotrimazole',
	'CRM/LOT',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANDEX 1 (Karlin)'
);

-- line #10699
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANDICLO 1 (STERLING)',
	'Clotrimazole',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANDICLO 1 (STERLING)'
);

-- line #10700
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANDICLO-V 200 (STERLING)',
	'Clotrimazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANDICLO-V 200 (STERLING)'
);

-- line #10701
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANDICUL 100 (Mapra)',
	'Clotrimazole',
	'VAGTAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANDICUL 100 (Mapra)'
);

-- line #10702
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANDID 1 (Glenmark)',
	'Clotrimazole',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANDID 1 (Glenmark)'
);

-- line #10703
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANDID 1 (Glenmark)',
	'Clotrimazole',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANDID 1 (Glenmark)'
);

-- line #10704
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANDID 1 (Glenmark)',
	'Clotrimazole',
	'LOT',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANDID 1 (Glenmark)'
);

-- line #10705
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1', u'strength_2': u'', u'substance': u'Clotrimazole', u'always_empty': u'', u'form': u'', u'brand': u'CANDID MICRO SPY', u'strength_3': u'', u'company': u'Glenmark', u'unit': u'%W/W'}

-- line #10706
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1', u'strength_2': u'', u'substance': u'Clotrimazole', u'always_empty': u'', u'form': u'', u'brand': u'CANDID MOUTHPAINT', u'strength_3': u'', u'company': u'Glenmark', u'unit': u'%W/V PROPYLENE GLYCOL&GLYCERINE BASE'}

-- line #10707
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANDID 1 (Glenmark)',
	'Clotrimazole',
	'POW',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANDID 1 (Glenmark)'
);

-- line #10708
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANDID 1 (Glenmark)',
	'Clotrimazole',
	'SOAP',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANDID 1 (Glenmark)'
);

-- line #10709
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANDID 100 (Glenmark)',
	'Clotrimazole',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'200'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANDID 100 (Glenmark)'
);

-- line #10710
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANDID 500 (Glenmark)',
	'Clotrimazole',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANDID 500 (Glenmark)'
);

-- line #10711
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANDID-V 2 (Glenmark)',
	'Clotrimazole',
	'GEL',
	gm.nullify_empty_string('2')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANDID-V 2 (Glenmark)'
);

-- line #10712
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANDID-V 100 (Glenmark)',
	'Clotrimazole',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANDID-V 100 (Glenmark)'
);

-- line #10713
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANDID-V 200 (Glenmark)',
	'Clotrimazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANDID-V 200 (Glenmark)'
);

-- line #10714
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANDID-V 500 (Glenmark)',
	'Clotrimazole',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANDID-V 500 (Glenmark)'
);

-- line #10715
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANDINIL 100 (Inga)',
	'Clotrimazole',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANDINIL 100 (Inga)'
);

-- line #10716
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANESTEN 10 (Bayer)',
	'Clotrimazole',
	'CRM',
	gm.nullify_empty_string('10')::numeric,
	'mg/G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANESTEN 10 (Bayer)'
);

-- line #10717
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANESTEN 1 (Bayer)',
	'Clotrimazole',
	'SOL',
	gm.nullify_empty_string('1')::numeric,
	'%/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANESTEN 1 (Bayer)'
);

-- line #10718
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANESTEN VAG 20 (Bayer)',
	'Clotrimazole',
	'CRM',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANESTEN VAG 20 (Bayer)'
);

-- line #10719
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANESTEN -V 100 (Bayer)',
	'Clotrimazole',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANESTEN -V 100 (Bayer)'
);

-- line #10720
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANESTEN -V 200 (Bayer)',
	'Clotrimazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANESTEN -V 200 (Bayer)'
);

-- line #10721
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANESTEN -V 500 (Bayer)',
	'Clotrimazole',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANESTEN -V 500 (Bayer)'
);

-- line #10722
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANFEM VAG 20 (German R.)',
	'Clotrimazole',
	'CRM',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANFEM VAG 20 (German R.)'
);

-- line #10723
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANFEM 100 (German R.)',
	'Clotrimazole',
	'VAG SUPP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANFEM 100 (German R.)'
);

-- line #10724
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANFEM 200 (German R.)',
	'Clotrimazole',
	'VAG SUPP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANFEM 200 (German R.)'
);

-- line #10725
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANISON 1 (AGIO PH.)',
	'Clotrimazole',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANISON 1 (AGIO PH.)'
);

-- line #10726
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANISON 1 (AGIO PH.)',
	'Clotrimazole',
	'POW',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANISON 1 (AGIO PH.)'
);

-- line #10727
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANISON 10 (AGIO PH.)',
	'Clotrimazole',
	'SOL',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANISON 10 (AGIO PH.)'
);

-- line #10728
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANISON VAG 100 (AGIO PH.)',
	'Clotrimazole',
	'CRM',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANISON VAG 100 (AGIO PH.)'
);

-- line #10729
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANISON-V 2 (AGIO PH.)',
	'Clotrimazole',
	'GEL',
	gm.nullify_empty_string('2')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANISON-V 2 (AGIO PH.)'
);

-- line #10730
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANITEN 100 (Cyper Ph.)',
	'Clotrimazole',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANITEN 100 (Cyper Ph.)'
);

-- line #10731
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100', u'strength_2': u'', u'substance': u'Clotrimazole', u'always_empty': u'', u'form': u'', u'brand': u'CANSOFT PESSARYS', u'strength_3': u'', u'company': u'Sun', u'unit': u'mg'}

-- line #10732
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANSOFT 100 (Sun)',
	'Clotrimazole',
	'SUPP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANSOFT 100 (Sun)'
);

-- line #10733
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAZOL 1 (Ind-Swift)',
	'Clotrimazole',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAZOL 1 (Ind-Swift)'
);

-- line #10734
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAZOL 1 (Ind-Swift)',
	'Clotrimazole',
	'PWD',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAZOL 1 (Ind-Swift)'
);

-- line #10735
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CENORUSH TROCHE 100 (Dwd)',
	'Clotrimazole',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CENORUSH TROCHE 100 (Dwd)'
);

-- line #10736
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEZEL DUSTING 1 (OREVA DARMO.)',
	'Clotrimazole',
	'POW',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEZEL DUSTING 1 (OREVA DARMO.)'
);

-- line #10737
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEZEL 1 (OREVA DARMO.)',
	'Clotrimazole',
	'LOT',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEZEL 1 (OREVA DARMO.)'
);

-- line #10738
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10', u'strength_2': u'', u'substance': u'Clotrimazole', u'always_empty': u'', u'form': u'', u'brand': u'CLENORUSH TROCHE', u'strength_3': u'', u'company': u'Dwd', u'unit': u'mg'}

-- line #10739
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOBEN 1 (Indoco Rem.)',
	'Clotrimazole',
	'POW',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOBEN 1 (Indoco Rem.)'
);

-- line #10740
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOBEN VT-3 200 (Indoco Rem.)',
	'Clotrimazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOBEN VT-3 200 (Indoco Rem.)'
);

-- line #10741
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOBEN VT-6 100 (Indoco Rem.)',
	'Clotrimazole',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOBEN VT-6 100 (Indoco Rem.)'
);

-- line #10742
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOBRATE 10 (Mac)',
	'Clotrimazole',
	'CRM',
	gm.nullify_empty_string('10')::numeric,
	'mg/G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOBRATE 10 (Mac)'
);

-- line #10743
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100', u'strength_2': u'', u'substance': u'Clotrimazole', u'always_empty': u'', u'form': u'', u'brand': u'CLOBRATE-VT', u'strength_3': u'', u'company': u'Mac', u'unit': u'mg'}

-- line #10744
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOCIP 1 (Cipla)',
	'Clotrimazole',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOCIP 1 (Cipla)'
);

-- line #10745
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOCIP DUST 1 (Cipla)',
	'Clotrimazole',
	'POW',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOCIP DUST 1 (Cipla)'
);

-- line #10746
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOCIP VG 100 (Cipla)',
	'Clotrimazole',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOCIP VG 100 (Cipla)'
);

-- line #10747
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLODERM TOP 1 (Amee Cosmo)',
	'Clotrimazole',
	'SOLN',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLODERM TOP 1 (Amee Cosmo)'
);

-- line #10748
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Clotrimazole', u'always_empty': u'', u'form': u'POW', u'brand': u'CLOFRESH', u'strength_3': u'', u'company': u'SMART LAB.', u'unit': u''}

-- line #10749
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOFUN 1 (Nestor)',
	'Clotrimazole',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOFUN 1 (Nestor)'
);

-- line #10750
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOGEN 10 (Novatech)',
	'Clotrimazole',
	'LOZENGES',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOGEN 10 (Novatech)'
);

-- line #10751
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOGRA 1 (Graf Lab.)',
	'Clotrimazole',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOGRA 1 (Graf Lab.)'
);

-- line #10752
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOMAX 1 (Bombay T.)',
	'Clotrimazole',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOMAX 1 (Bombay T.)'
);

-- line #10753
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOMAX-V 2 (Bombay T.)',
	'Clotrimazole',
	'GEL',
	gm.nullify_empty_string('2')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOMAX-V 2 (Bombay T.)'
);

-- line #10754
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOMAX-V 100 (Bombay T.)',
	'Clotrimazole',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOMAX-V 100 (Bombay T.)'
);

-- line #10755
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOMAX -V 200 (Bombay T.)',
	'Clotrimazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOMAX -V 200 (Bombay T.)'
);

-- line #10756
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOMAX -V 500 (Bombay T.)',
	'Clotrimazole',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOMAX -V 500 (Bombay T.)'
);

-- line #10757
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOMEZ-V 100 (Merit Org.)',
	'Clotrimazole',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg(APPLICATOR)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOMEZ-V 100 (Merit Org.)'
);

-- line #10758
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOSOFT 1 (PANTHER PH.)',
	'Clotrimazole',
	'POW',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOSOFT 1 (PANTHER PH.)'
);

-- line #10759
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOTRIM-V 2 (Cipla)',
	'Clotrimazole',
	'CRM',
	gm.nullify_empty_string('2')::numeric,
	'%W/W (+BENZYL ALCOHOL 1.0'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOTRIM-V 2 (Cipla)'
);

-- line #10760
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOTRIMYL 1 (Wattyl Ph.)',
	'Clotrimazole',
	'CRM/LOTION',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOTRIMYL 1 (Wattyl Ph.)'
);

-- line #10761
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOTRIN 1 (Nulife)',
	'Clotrimazole',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOTRIN 1 (Nulife)'
);

-- line #10762
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOTRIN 1 (Nulife)',
	'Clotrimazole',
	'EAR DPS',
	gm.nullify_empty_string('1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOTRIN 1 (Nulife)'
);

-- line #10763
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOTRIN 1 (Nulife)',
	'Clotrimazole',
	'LOT',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOTRIN 1 (Nulife)'
);

-- line #10764
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1', u'strength_2': u'', u'substance': u'Clotrimazole', u'always_empty': u'', u'form': u'', u'brand': u'CLOTRIN MOUTH PAINT', u'strength_3': u'', u'company': u'Nulife', u'unit': u'%'}

-- line #10765
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOTRIN-V 100 (Nulife)',
	'Clotrimazole',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOTRIN-V 100 (Nulife)'
);

-- line #10766
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOTRIVIN TROCHE 10 (DELVIN)',
	'Clotrimazole',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOTRIVIN TROCHE 10 (DELVIN)'
);

-- line #10767
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOTROMIN-V6 100 (Alpha Lab)',
	'Clotrimazole',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOTROMIN-V6 100 (Alpha Lab)'
);

-- line #10768
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOZIP 1 (NIVCA)',
	'Clotrimazole',
	'POW',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOZIP 1 (NIVCA)'
);

-- line #10769
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CTZOLE 1 (NEON)',
	'Clotrimazole',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CTZOLE 1 (NEON)'
);

-- line #10770
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECAND 1 (Comed)',
	'Clotrimazole',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECAND 1 (Comed)'
);

-- line #10771
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECAND V3 200 (Comed)',
	'Clotrimazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECAND V3 200 (Comed)'
);

-- line #10772
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECAND V6 100 (Comed)',
	'Clotrimazole',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECAND V6 100 (Comed)'
);

-- line #10773
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENDID 1 (Emcure)',
	'Clotrimazole',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENDID 1 (Emcure)'
);

-- line #10774
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEM-V 100 (Brawn Lab)',
	'Clotrimazole',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEM-V 100 (Brawn Lab)'
);

-- line #10775
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNGISTAT 1 (Group Ph.)',
	'Clotrimazole',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNGISTAT 1 (Group Ph.)'
);

-- line #10776
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNGISTAT-V 100 (Group Ph.)',
	'Clotrimazole',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNGISTAT-V 100 (Group Ph.)'
);

-- line #10777
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNGISTAT-V 200 (Group Ph.)',
	'Clotrimazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNGISTAT-V 200 (Group Ph.)'
);

-- line #10778
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNGISTAT-V 500 (Group Ph.)',
	'Clotrimazole',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNGISTAT-V 500 (Group Ph.)'
);

-- line #10779
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GYNOSTATUM 2 (Croslands)',
	'Clotrimazole',
	'CRM',
	gm.nullify_empty_string('2')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GYNOSTATUM 2 (Croslands)'
);

-- line #10780
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GYNOSTATUM-V 100 (Croslands)',
	'Clotrimazole',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GYNOSTATUM-V 100 (Croslands)'
);

-- line #10781
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GYNOTRIM V1 500 (Svizera)',
	'Clotrimazole',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GYNOTRIM V1 500 (Svizera)'
);

-- line #10782
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GYNOTRIM V3 200 (Svizera)',
	'Clotrimazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GYNOTRIM V3 200 (Svizera)'
);

-- line #10783
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GYNOTRIM V6 100 (Svizera)',
	'Clotrimazole',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GYNOTRIM V6 100 (Svizera)'
);

-- line #10784
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GYNOTRIM VAG 2 (Svizera)',
	'Clotrimazole',
	'GEL',
	gm.nullify_empty_string('2')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GYNOTRIM VAG 2 (Svizera)'
);

-- line #10785
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMIDIL 1 (HETERO HC.)',
	'Clotrimazole',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMIDIL 1 (HETERO HC.)'
);

-- line #10786
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMIDIL DUSTING 1 (HETERO HC.)',
	'Clotrimazole',
	'POW',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMIDIL DUSTING 1 (HETERO HC.)'
);

-- line #10787
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Clotrimazole', u'always_empty': u'', u'form': u'CRM', u'brand': u'IMIDIL PLUS', u'strength_3': u'', u'company': u'HETERO HC.', u'unit': u''}

-- line #10788
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMIDIL 1 (HETERO HC.)',
	'Clotrimazole',
	'SOL',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMIDIL 1 (HETERO HC.)'
);

-- line #10789
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMIDIL 200 (HETERO HC.)',
	'Clotrimazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMIDIL 200 (HETERO HC.)'
);

-- line #10790
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMIDIL 500 (HETERO HC.)',
	'Clotrimazole',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMIDIL 500 (HETERO HC.)'
);

-- line #10791
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Clotrimazole', u'always_empty': u'', u'form': u'VAG SUPP', u'brand': u'IMIDIL-VS', u'strength_3': u'', u'company': u'HETERO HC.', u'unit': u''}

-- line #10792
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMIDIL-V 100 (HETERO HC.)',
	'Clotrimazole',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMIDIL-V 100 (HETERO HC.)'
);

-- line #10793
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTRAMOL-V6 VAG 100 (Intra Lab)',
	'Clotrimazole',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg E.R.'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTRAMOL-V6 VAG 100 (Intra Lab)'
);

-- line #10794
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KICAN 100 (Shaimil)',
	'Clotrimazole',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KICAN 100 (Shaimil)'
);

-- line #10795
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KICAN 200 (Shaimil)',
	'Clotrimazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KICAN 200 (Shaimil)'
);

-- line #10796
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KIVZOLE 1 (KIVI LABS)',
	'Clotrimazole',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KIVZOLE 1 (KIVI LABS)'
);

-- line #10797
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOTRIL 1 (Gufic Bio.)',
	'Clotrimazole',
	'CRM POW',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOTRIL 1 (Gufic Bio.)'
);

-- line #10798
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOTRIL 10 (Gufic Bio.)',
	'Clotrimazole',
	'LOT',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOTRIL 10 (Gufic Bio.)'
);

-- line #10799
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100', u'strength_2': u'', u'substance': u'Clotrimazole', u'always_empty': u'', u'form': u'', u'brand': u'LOTRIL PESSARY', u'strength_3': u'', u'company': u'Gufic Bio.', u'unit': u'mg'}

-- line #10800
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOTRIM 1 (Bal Ph.)',
	'Clotrimazole',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOTRIM 1 (Bal Ph.)'
);

-- line #10801
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAZODERM 1 (Sandoz)',
	'Clotrimazole',
	'TUBE',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAZODERM 1 (Sandoz)'
);

-- line #10802
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MENSTAN VAG 100 (Medicamen)',
	'Clotrimazole',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MENSTAN VAG 100 (Medicamen)'
);

-- line #10803
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1', u'strength_2': u'', u'substance': u'Clotrimazole', u'always_empty': u'', u'form': u'', u'brand': u'MYCOBAN MOUTH PAINT', u'strength_3': u'', u'company': u'Perch', u'unit': u'%W/V'}

-- line #10804
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCOCID 1 (Chemo D.)',
	'Clotrimazole',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCOCID 1 (Chemo D.)'
);

-- line #10805
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCOCID 1 (INTERMED)',
	'CLOTRIMAZOLE',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCOCID 1 (INTERMED)'
);

-- line #10806
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCOCID 1 (INTERMED)',
	'CLOTRIMAZOLE',
	'LOT',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCOCID 1 (INTERMED)'
);

-- line #10807
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCOCID-V 100 (INTERMED)',
	'CLOTRIMAZOLE',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCOCID-V 100 (INTERMED)'
);

-- line #10808
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Clotrimazole', u'always_empty': u'', u'form': u'POW SP', u'brand': u'MYCOCLEAR', u'strength_3': u'', u'company': u'Liva Hc.', u'unit': u''}

-- line #10809
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCODERM-C 1 (F D C)',
	'Clotrimazole',
	'POW',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCODERM-C 1 (F D C)'
);

-- line #10810
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1', u'strength_2': u'', u'substance': u'Clotrimazole', u'always_empty': u'', u'form': u'', u'brand': u'NIFUGAL MOUTHPAINT', u'strength_3': u'', u'company': u'Gsk', u'unit': u'%W/V'}

-- line #10811
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIFUGAL 1 (Gsk)',
	'Clotrimazole',
	'OINT',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIFUGAL 1 (Gsk)'
);

-- line #10812
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1', u'strength_2': u'', u'substance': u'Clotrimazole', u'always_empty': u'', u'form': u'', u'brand': u'NUFORCE DUSTPOW', u'strength_3': u'', u'company': u'LIFESTAR', u'unit': u'%W/W'}

-- line #10813
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1', u'strength_2': u'', u'substance': u'Clotrimazole', u'always_empty': u'', u'form': u'', u'brand': u'NUFORCE MOUTH PAINT', u'strength_3': u'', u'company': u'Discovery M.', u'unit': u'%W/V'}

-- line #10814
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUFORCE-V6 100 (Discovery M.)',
	'Clotrimazole',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUFORCE-V6 100 (Discovery M.)'
);

-- line #10815
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORALOZ 10 (Cytomed(Alkem))',
	'Clotrimazole',
	'LOZENGE',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORALOZ 10 (Cytomed(Alkem))'
);

-- line #10816
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REFUR 1 (Stanford)',
	'Clotrimazole',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REFUR 1 (Stanford)'
);

-- line #10817
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACLOX 250 (Osper)',
	'Cloxacillin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACLOX 250 (Osper)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACLOX 500 (Osper)',
	'Cloxacillin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACLOX 500 (Osper)'
);

-- line #10818
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOCLOX 250 (Biochem)',
	'Cloxacillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOCLOX 250 (Biochem)'
);

-- line #10819
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOCLOX 500 (Biochem)',
	'Cloxacillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOCLOX 500 (Biochem)'
);

-- line #10820
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOCLOX 250 (Biochem)',
	'Cloxacillin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOCLOX 250 (Biochem)'
);

-- line #10821
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOCLOX 500 (Biochem)',
	'Cloxacillin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOCLOX 500 (Biochem)'
);

-- line #10822
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOCILIN 250 (P C INDIA)',
	'Cloxacillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOCILIN 250 (P C INDIA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOCILIN 500 (P C INDIA)',
	'Cloxacillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOCILIN 500 (P C INDIA)'
);

-- line #10823
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOCILIN 500 (P C INDIA)',
	'Cloxacillin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOCILIN 500 (P C INDIA)'
);

-- line #10824
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOCILIN 250 (P C INDIA)',
	'Cloxacillin',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOCILIN 250 (P C INDIA)'
);

-- line #10825
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOCILLIN 500 (P C INDIA)',
	'Cloxacillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOCILLIN 500 (P C INDIA)'
);

-- line #10826
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOPEN 250 (Lark Lab)',
	'Cloxacillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOPEN 250 (Lark Lab)'
);

-- line #10827
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOPEN 500 (Lark Lab)',
	'Cloxacillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOPEN 500 (Lark Lab)'
);

-- line #10828
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOPEN 125 (Lark Lab)',
	'Cloxacillin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOPEN 125 (Lark Lab)'
);

-- line #10829
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOXACILLIN 250 (Dopson Ph.)',
	'Cloxacillin',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOXACILLIN 250 (Dopson Ph.)'
);

-- line #10830
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KLOX 250 (HETERO HC.)',
	'Cloxacillin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KLOX 250 (HETERO HC.)'
);

-- line #10831
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KLOX 500 (HETERO HC.)',
	'Cloxacillin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KLOX 500 (HETERO HC.)'
);

-- line #10832
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KLOX 125 (HETERO HC.)',
	'Cloxacillin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KLOX 125 (HETERO HC.)'
);

-- line #10833
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KLOX 250 (HETERO HC.)',
	'Cloxacillin',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KLOX 250 (HETERO HC.)'
);

-- line #10834
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KLOX 500 (HETERO HC.)',
	'Cloxacillin',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KLOX 500 (HETERO HC.)'
);

-- line #10835
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOCLOX 250 (NEON)',
	'Cloxacillin',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOCLOX 250 (NEON)'
);

-- line #10836
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOCLOX 500 (NEON)',
	'Cloxacillin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOCLOX 500 (NEON)'
);

-- line #10837
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHROZAP 100 (Sali Hc.)',
	'Clozapine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHROZAP 100 (Sali Hc.)'
);

-- line #10838
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHROZAP 25 (Sali Hc.)',
	'Clozapine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHROZAP 25 (Sali Hc.)'
);

-- line #10839
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHROZAP 50 (Sali Hc.)',
	'Clozapine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHROZAP 50 (Sali Hc.)'
);

-- line #10840
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOCALM 25 (Biocin Hc.)',
	'Clozapine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOCALM 25 (Biocin Hc.)'
);

-- line #10841
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOMACH 100 (LA DRUG)',
	'Clozapine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOMACH 100 (LA DRUG)'
);

-- line #10842
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOMACH 25 (LA DRUG)',
	'Clozapine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOMACH 25 (LA DRUG)'
);

-- line #10843
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOMACH 50 (LA DRUG)',
	'Clozapine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOMACH 50 (LA DRUG)'
);

-- line #10844
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLONEX 100 (Theo Ph.)',
	'Clozapine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLONEX 100 (Theo Ph.)'
);

-- line #10845
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLONEX 25 (Theo Ph.)',
	'Clozapine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLONEX 25 (Theo Ph.)'
);

-- line #10846
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLONEX 50 (Theo Ph.)',
	'Clozapine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLONEX 50 (Theo Ph.)'
);

-- line #10847
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOPAZ 100 (Triton Hc.)',
	'Clozapine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOPAZ 100 (Triton Hc.)'
);

-- line #10848
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOPAZ 25 (Triton Hc.)',
	'Clozapine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOPAZ 25 (Triton Hc.)'
);

-- line #10849
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'25', u'strength_2': u'', u'substance': u'Clozapine', u'always_empty': u'', u'form': u'', u'brand': u'CLOPAZ', u'strength_3': u'', u'company': u'Triton', u'unit': u'mg'}

-- line #10850
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOPIN 25 (EAST WEST)',
	'Clozapine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOPIN 25 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOPIN 100 (EAST WEST)',
	'Clozapine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOPIN 100 (EAST WEST)'
);

-- line #10851
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOSIN 100 (S P Ph.)',
	'Clozapine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOSIN 100 (S P Ph.)'
);

-- line #10852
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOSIN 25 (S P Ph.)',
	'Clozapine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOSIN 25 (S P Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOSIN 50 (S P Ph.)',
	'Clozapine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOSIN 50 (S P Ph.)'
);

-- line #10853
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOZ 100 (Crystal Ph.)',
	'Clozapine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOZ 100 (Crystal Ph.)'
);

-- line #10854
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOZAPIN 100 (Torrent)',
	'Clozapine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOZAPIN 100 (Torrent)'
);

-- line #10855
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOZAPIN 25 (Torrent)',
	'Clozapine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOZAPIN 25 (Torrent)'
);

-- line #10856
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOZAPIN 50 (TORRENT)',
	'Clozapine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOZAPIN 50 (TORRENT)'
);

-- line #10857
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOZIN 100 (Pifer Ph.)',
	'Clozapine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOZIN 100 (Pifer Ph.)'
);

-- line #10858
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOZIN 25 (Pifer Ph.)',
	'Clozapine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOZIN 25 (Pifer Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOZIN 50 (Pifer Ph.)',
	'Clozapine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOZIN 50 (Pifer Ph.)'
);

-- line #10859
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEUROPIN 25 (Zenith Hc.)',
	'Clozapine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEUROPIN 25 (Zenith Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEUROPIN 50 (Zenith Hc.)',
	'Clozapine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEUROPIN 50 (Zenith Hc.)'
);

-- line #10860
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYNE 100 (Rkg)',
	'Clozapine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYNE 100 (Rkg)'
);

-- line #10861
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REFRACT 25 (Crescent Th.)',
	'Clozapine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REFRACT 25 (Crescent Th.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REFRACT 50 (Crescent Th.)',
	'Clozapine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REFRACT 50 (Crescent Th.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REFRACT 100 (Crescent Th.)',
	'Clozapine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REFRACT 100 (Crescent Th.)'
);

-- line #10862
-- ignoring line: field [strength_1] not numeric: >>>600IU.(PLASMA PROTEIN HUMAN+NACL<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'600IU.(PLASMA PROTEIN HUMAN+NACL', u'strength_2': u'', u'substance': u'COAGULATION FACTOR LX', u'always_empty': u'', u'form': u'V INJ', u'brand': u'PZYCADILA-A T I', u'strength_3': u'', u'company': u'Pharmacia', u'unit': u'SOD.CIT.)'}

-- line #10863
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COTAR 5 (Brawn Lab)',
	'Coaltar',
	'OINT',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COTAR 5 (Brawn Lab)'
);

-- line #10864
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Coaltar', u'always_empty': u'', u'form': u'OIL', u'brand': u'CT', u'strength_3': u'', u'company': u'Shalaks', u'unit': u''}

-- line #10865
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELTAR SCALP 5 (Elder)',
	'Coaltar',
	'LOT',
	gm.nullify_empty_string('5')::numeric,
	'%(EXT.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELTAR SCALP 5 (Elder)'
);

-- line #10866
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHITAR 2 (ETHINAXT PHARMA)',
	'Coaltar',
	'SOAP',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHITAR 2 (ETHINAXT PHARMA)'
);

-- line #10867
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CODIFOS 10 (Cipla)',
	'Codeine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CODIFOS 10 (Cipla)'
);

-- line #10868
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CODIN-30 30 (Somatico)',
	'Codeine Phosphate',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CODIN-30 30 (Somatico)'
);

-- line #10869
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELCODIN 10 (Elysium)',
	'Codeine Phosphate',
	'SYR',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELCODIN 10 (Elysium)'
);

-- line #10870
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINCOTUSS 15 (Macleods)',
	'Codeine Phosphate',
	'SYR',
	gm.nullify_empty_string('15')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINCOTUSS 15 (Macleods)'
);

-- line #10871
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONTOKUF 15 (Shreya)',
	'Codeine Phosphate',
	'SYR',
	gm.nullify_empty_string('15')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONTOKUF 15 (Shreya)'
);

-- line #10872
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'15', u'strength_2': u'', u'substance': u'Codeine Sulphate', u'always_empty': u'', u'form': u'', u'brand': u'CODEINE SULPHATE', u'strength_3': u'', u'company': u'Zydus A.', u'unit': u'mg'}

-- line #10873
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CODINE LINC 15 (Zydus A.)',
	'Codeine Sulphate',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CODINE LINC 15 (Zydus A.)'
);

-- line #10874
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CODINE LINCTUS 15 (Zydus A.)',
	'Codeine Sulphate',
	'LIQ',
	gm.nullify_empty_string('15')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CODINE LINCTUS 15 (Zydus A.)'
);

-- line #10875
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'15', u'strength_2': u'', u'substance': u'Codeine Sulphate', u'always_empty': u'', u'form': u'', u'brand': u'CODIN LINCTUS', u'strength_3': u'', u'company': u'Zydus A.', u'unit': u'mg/5ML'}

-- line #10876
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AD-SOFT 300 (Guj. Liq.)',
	'Cod Liver Oil',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AD-SOFT 300 (Guj. Liq.)'
);

-- line #10877
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Co-Enzyme Q10', u'always_empty': u'', u'form': u'CAP', u'brand': u'COQ', u'strength_3': u'', u'company': u'Universal', u'unit': u''}

-- line #10878
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'30', u'strength_2': u'', u'substance': u'Co-Enzyme Q10', u'always_empty': u'', u'form': u'', u'brand': u'CO-Q PLUS', u'strength_3': u'', u'company': u'Deccan', u'unit': u'mg'}

-- line #10879
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COTEN 30 (Aglowmed)',
	'Co-Enzyme Q10',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COTEN 30 (Aglowmed)'
);

-- line #10880
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESPRIT 100 (NICON)',
	'Co-Enzyme Q10',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESPRIT 100 (NICON)'
);

-- line #10881
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIRAQULE 100 (Alchem Phy.)',
	'Co-Enzyme Q10',
	'SG CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIRAQULE 100 (Alchem Phy.)'
);

-- line #10882
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIRAQULE 50 (Alchem Phy.)',
	'Co-Enzyme Q10',
	'SG CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIRAQULE 50 (Alchem Phy.)'
);

-- line #10883
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIRAQULE 100 (ALCHEM PHY.)',
	'Co-Enzyme Q10',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg(UBIDECARENONE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIRAQULE 100 (ALCHEM PHY.)'
);

-- line #10884
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEP-Q 50 (Pharmed)',
	'Co-Enzyme Q10',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEP-Q 50 (Pharmed)'
);

-- line #10885
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q-GUARD 60 (CIPLA)',
	'Co-Enzyme Q10',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q-GUARD 60 (CIPLA)'
);

-- line #10886
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q SOFT 100 (SOFTECH PH.)',
	'Co-Enzyme Q10',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg(UBIDECARENONE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q SOFT 100 (SOFTECH PH.)'
);

-- line #10887
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q-TEN 100 (EXCELLA)',
	'Co-Enzyme Q10',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q-TEN 100 (EXCELLA)'
);

-- line #10888
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUTE 120 (Yash Ph.)',
	'Co-Enzyme Q10',
	'CAP',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUTE 120 (Yash Ph.)'
);

-- line #10889
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RECHARJ 100 (Troikaa)',
	'Co-Enzyme Q10',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg(UBIDECARENONE WITH VIT. E.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RECHARJ 100 (Troikaa)'
);

-- line #10890
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Co-Enzyme Q10', u'always_empty': u'', u'form': u'CAP', u'brand': u'RECHARJE', u'strength_3': u'', u'company': u'Troikaa', u'unit': u''}

-- line #10891
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COLCHICINDON 0.5 (Zydus A.)',
	'Colchicine',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COLCHICINDON 0.5 (Zydus A.)'
);

-- line #10892
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COLJOY 0.5 (Cadila Ph.)',
	'Colchicine',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COLJOY 0.5 (Cadila Ph.)'
);

-- line #10893
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GOUTNIL 0.5 (Inga)',
	'Colchicine',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GOUTNIL 0.5 (Inga)'
);

-- line #10894
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACOSTIN 10 (Ranbaxy)',
	'COLISTIMETHATE SODIUM',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'0'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACOSTIN 10 (Ranbaxy)'
);

-- line #10895
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COLY-MONAS INJ MILLION IU/ 10 (Glenmark)',
	'COLISTIMETHATE SODIUM',
	'VIAL',
	gm.nullify_empty_string('10')::numeric,
	'0'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COLY-MONAS INJ MILLION IU/ 10 (Glenmark)'
);

-- line #10896
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REMERGIN 10 (Astrazeneca)',
	'COLISTIMETHATE SODIUM',
	'VIAL',
	gm.nullify_empty_string('10')::numeric,
	'0'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REMERGIN 10 (Astrazeneca)'
);

-- line #10897
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Colistin Sulph.', u'always_empty': u'', u'form': u'DS D.SYR', u'brand': u'COLIGYL', u'strength_3': u'', u'company': u'MANKIND', u'unit': u''}

-- line #10898
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COLIGYL 12.5 (Discovery M.)',
	'Colistin Sulph.',
	'D.SYR',
	gm.nullify_empty_string('12.5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COLIGYL 12.5 (Discovery M.)'
);

-- line #10899
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COLIGYL 12.5 (Mankind)',
	'Colistin Sulph.',
	'DT',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COLIGYL 12.5 (Mankind)'
);

-- line #10900
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COLISTOP 25 (Indi Ph.)',
	'Colistin Sulph.',
	'DS SUS',
	gm.nullify_empty_string('25')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COLISTOP 25 (Indi Ph.)'
);

-- line #10901
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COLISTOP 12.5 (Indi Ph.)',
	'Colistin Sulph.',
	'SUS',
	gm.nullify_empty_string('12.5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COLISTOP 12.5 (Indi Ph.)'
);

-- line #10902
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GDSAFE 25 (Ind-Swift)',
	'Colistin Sulph.',
	'DS SYR',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GDSAFE 25 (Ind-Swift)'
);

-- line #10903
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GDSAFE 12.5 (Ind-Swift)',
	'Colistin Sulph.',
	'SYR',
	gm.nullify_empty_string('12.5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GDSAFE 12.5 (Ind-Swift)'
);

-- line #10904
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KOSTIN 12.5 (Fairdeal Res.)',
	'Colistin Sulph.',
	'SYR',
	gm.nullify_empty_string('12.5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KOSTIN 12.5 (Fairdeal Res.)'
);

-- line #10905
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'M-CID-C 12.5 (Group Ph.)',
	'Colistin Sulph.',
	'SYR',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'M-CID-C 12.5 (Group Ph.)'
);

-- line #10906
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'M-CID NT 100 (Group Ph.)',
	'Colistin Sulph.',
	'SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'M-CID NT 100 (Group Ph.)'
);

-- line #10907
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1 MIN IU', u'strength_2': u'', u'substance': u'COLITHEMETHEATE SODIUM', u'always_empty': u'', u'form': u'', u'brand': u'INNOCOL-M', u'strength_3': u'', u'company': u'INNOVA LIFESCI.', u'unit': u''}

-- line #10908
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10G(APPROXIMATELY)', u'strength_2': u'', u'substance': u'COLLAGEN PEPTISIDE', u'always_empty': u'', u'form': u'', u'brand': u'COLAFLEX', u'strength_3': u'', u'company': u'Universal', u'unit': u''}

-- line #10909
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DERMAVIVE CONDITIONING 2 (UAS PHARMA)',
	'COLLOIDAL OATMEAL',
	'SHAMPOO',
	gm.nullify_empty_string('2')::numeric,
	'% (+CITRIC ACID'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DERMAVIVE CONDITIONING 2 (UAS PHARMA)'
);

-- line #10910
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'LACTIC ACID', u'SUNFLOWER OIL)', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5', u'strength_2': u'', u'substance': u'COLLOIDAL OATMEAL', u'always_empty': u'', u'form': u'', u'brand': u'DERMAVIVE DRY SKIN CLEANSING BAR', u'strength_3': u'', u'company': u'UAS PHARMA', u'unit': u'% (+NAPCA'}

-- line #10911
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DERMAVIVE DRY SKIN 5 (UAS PHARMA)',
	'COLLOIDAL OATMEAL',
	'CRM',
	gm.nullify_empty_string('5')::numeric,
	'% (+NAPCA'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DERMAVIVE DRY SKIN 5 (UAS PHARMA)'
);

-- line #10912
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DERMAVIVE MOISTURISING 2 (UAS PHARMA)',
	'COLLOIDAL OATMEAL',
	'LOT',
	gm.nullify_empty_string('2')::numeric,
	'% (+NAPCA LIGHT MINERAL OIL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DERMAVIVE MOISTURISING 2 (UAS PHARMA)'
);

-- line #10913
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DERMAVIVE SHAMPOO & 2.5 (UAS PHARMA)',
	'COLLOIDAL OATMEAL',
	'BODY WASH',
	gm.nullify_empty_string('2.5')::numeric,
	'% (+NAPCA'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DERMAVIVE SHAMPOO & 2.5 (UAS PHARMA)'
);

-- line #10914
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DERMAVIVE SHOWER BATH 5 (UAS PHARMA)',
	'COLLOIDAL OATMEAL',
	'OIL',
	gm.nullify_empty_string('5')::numeric,
	'% (+NAPCA'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DERMAVIVE SHOWER BATH 5 (UAS PHARMA)'
);

-- line #10915
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DERMAVIVE 2 (UAS PHARMA)',
	'COLLOIDAL OATMEAL',
	'SOAP FREE WASH',
	gm.nullify_empty_string('2')::numeric,
	'% (+NAPCA'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DERMAVIVE 2 (UAS PHARMA)'
);

-- line #10916
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5', u'strength_2': u'', u'substance': u'COLLOIDAL OATMEAL', u'always_empty': u'', u'form': u'', u'brand': u'DEWMIS BAR', u'strength_3': u'', u'company': u'Gracewell', u'unit': u'%W/W'}

-- line #10917
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIRST LACT 500 (INTRA(INVENTURE))',
	'COLOSTRUM',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIRST LACT 500 (INTRA(INVENTURE))'
);

-- line #10918
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISTRUM 700 (Wockhardt)',
	'COLOSTRUM',
	'POW',
	gm.nullify_empty_string('700')::numeric,
	'mg/3G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISTRUM 700 (Wockhardt)'
);

-- line #10919
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NECTERA 500 (Lupin)',
	'COLOSTRUM',
	'POW',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NECTERA 500 (Lupin)'
);

-- line #10920
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500', u'strength_2': u'', u'substance': u'COLOSTRUM', u'always_empty': u'', u'form': u'', u'brand': u'NEETERA', u'strength_3': u'', u'company': u'Lupin', u'unit': u'mg(20'}

-- line #10921
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREMELLE CYCLE 5 (Wyeth)',
	'Conjugated Estrogen And Medroxyprogesterone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREMELLE CYCLE 5 (Wyeth)'
);

-- line #10922
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREMELLE 2.5 (Wyeth)',
	'Conjugated Estrogen And Medroxyprogesterone',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREMELLE 2.5 (Wyeth)'
);

-- line #10923
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREMARIN 25 (Wyeth)',
	'Conjugated Estrogens',
	'VIAL',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREMARIN 25 (Wyeth)'
);

-- line #10924
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONJUGASE 0.625 (Elder)',
	'Conjugated Oestrogens',
	'TAB',
	gm.nullify_empty_string('0.625')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONJUGASE 0.625 (Elder)'
);

-- line #10925
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESPAUZ 0.625 (GLENMARK)',
	'Conjugated Oestrogens',
	'TAB',
	gm.nullify_empty_string('0.625')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESPAUZ 0.625 (GLENMARK)'
);

-- line #10926
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREMARIN 0.3 (Wyeth)',
	'Conjugated Oestrogens',
	'TAB',
	gm.nullify_empty_string('0.3')::numeric,
	'mg(ESTROGENS)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREMARIN 0.3 (Wyeth)'
);

-- line #10927
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREMARIN 0.625 (Wyeth)',
	'Conjugated Oestrogens',
	'TAB',
	gm.nullify_empty_string('0.625')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREMARIN 0.625 (Wyeth)'
);

-- line #10928
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREMARIN 1.25 (Wyeth)',
	'Conjugated Oestrogens',
	'TAB',
	gm.nullify_empty_string('1.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREMARIN 1.25 (Wyeth)'
);

-- line #10929
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'INTRAUTERINE COPPER CONTRACEPTIVE DEVICE PRVIDING COPPER SURFACE AREA OF 250SQ. MM', u'strength_2': u'', u'substance': u'CONTRACEPTIVE DEVICE', u'always_empty': u'', u'form': u'', u'brand': u'MULTILOAD CU', u'strength_3': u'', u'company': u'Infar', u'unit': u''}

-- line #10930
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'INTRAUTERINE COPPER CONTRACEPTIVE DEVICE PRVIDING COPPER SURFACE AREA OF 375SQ. MM', u'strength_2': u'', u'substance': u'CONTRACEPTIVE DEVICE', u'always_empty': u'', u'form': u'', u'brand': u'MULTILOAD CU', u'strength_3': u'', u'company': u'Infar', u'unit': u''}

-- line #10931
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'COPPER LENGTH', u'always_empty': u'', u'form': u'', u'brand': u"EVE''S COPPER T", u'strength_3': u'', u'company': u'JOHN BIOTECH', u'unit': u''}

-- line #10932
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIPODEM 200 (MERIDIAN ENT.)',
	'COUMARIN',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIPODEM 200 (MERIDIAN ENT.)'
);

-- line #10933
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CRANPAC 300 (IPCA LAB.)',
	'CRANBERRY',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CRANPAC 300 (IPCA LAB.)'
);

-- line #10934
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CRANBE SOFTGEL 300 (Elder)',
	'CRANBERRY POW.',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CRANBE SOFTGEL 300 (Elder)'
);

-- line #10935
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CROTON 10 (Sunways)',
	'Crotamiton',
	'CRM/LOT',
	gm.nullify_empty_string('10')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CROTON 10 (Sunways)'
);

-- line #10936
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CROTORAX 10 (Nicholas)',
	'Crotamiton',
	'CRM',
	gm.nullify_empty_string('10')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CROTORAX 10 (Nicholas)'
);

-- line #10937
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CROTORAX 10 (Nicholas)',
	'Crotamiton',
	'LOT',
	gm.nullify_empty_string('10')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CROTORAX 10 (Nicholas)'
);

-- line #10938
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'CURCUMA LONGA GLYCYRRHIZA GLABRA WITHANIA SOMNIFERA ETC', u'always_empty': u'', u'form': u'', u'brand': u'IMROX', u'strength_3': u'', u'company': u'PINK HEALTH', u'unit': u''}

-- line #10939
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'400', u'strength_2': u'', u'substance': u'Cyclandelate', u'always_empty': u'', u'form': u'', u'brand': u'CYCLASYN MG', u'strength_3': u'', u'company': u'Cipla', u'unit': u'mg'}

-- line #10940
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYCLASYN 200 (Cipla)',
	'Cyclandelate',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYCLASYN 200 (Cipla)'
);

-- line #10941
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYCLOSPASMOL 200 (Elder)',
	'Cyclandelate',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYCLOSPASMOL 200 (Elder)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYCLOSPASMOL 400 (Elder)',
	'Cyclandelate',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYCLOSPASMOL 400 (Elder)'
);

-- line #10942
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYCLSPASMOL 400 (Elder)',
	'Cyclandelate',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYCLSPASMOL 400 (Elder)'
);

-- line #10943
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MARTISPASMOL 200 (Walter B.)',
	'Cyclandelate',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MARTISPASMOL 200 (Walter B.)'
);

-- line #10944
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MARTISPASMOL 400 (Walter B.)',
	'Cyclandelate',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MARTISPASMOL 400 (Walter B.)'
);

-- line #10945
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENZADAY 15 (Sun)',
	'CYCLOBENZAPRINE HCL',
	'CAP',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENZADAY 15 (Sun)'
);

-- line #10946
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENZADAY 30 (Sun)',
	'CYCLOBENZAPRINE HCL',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENZADAY 30 (Sun)'
);

-- line #10947
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLEXABENZ 5 (Macleods)',
	'CYCLOBENZAPRINE HCL',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLEXABENZ 5 (Macleods)'
);

-- line #10948
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOBRINE IR 10 (Ranbaxy)',
	'CYCLOBENZAPRINE HCL',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOBRINE IR 10 (Ranbaxy)'
);

-- line #10949
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOBRINE IR 5 (Ranbaxy)',
	'CYCLOBENZAPRINE HCL',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOBRINE IR 5 (Ranbaxy)'
);

-- line #10950
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOBRIN 15 (Ranbaxy)',
	'CYCLOBENZAPRINE HCL',
	'OD CAP',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOBRIN 15 (Ranbaxy)'
);

-- line #10951
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOBRIN 30 (Ranbaxy)',
	'CYCLOBENZAPRINE HCL',
	'OD CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOBRIN 30 (Ranbaxy)'
);

-- line #10952
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BELL PENTOLATE 1 (Bell Ph.)',
	'Cyclopentolate Hcl.',
	'DPS',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BELL PENTOLATE 1 (Bell Ph.)'
);

-- line #10953
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-PENT 1 (Appasamy)',
	'Cyclopentolate Hcl.',
	'DPS',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-PENT 1 (Appasamy)'
);

-- line #10954
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-PENT 1 (ADVENTUS)',
	'Cyclopentolate Hcl.',
	'EYE DPS',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-PENT 1 (ADVENTUS)'
);

-- line #10955
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYCLIN 1 (Oscar Rem.)',
	'Cyclopentolate Hcl.',
	'DPS',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYCLIN 1 (Oscar Rem.)'
);

-- line #10956
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYCLOGIK 1 (F D C)',
	'Cyclopentolate Hcl.',
	'DPS',
	gm.nullify_empty_string('1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYCLOGIK 1 (F D C)'
);

-- line #10957
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYCLOPENT 0.5 (Milmet)',
	'Cyclopentolate Hcl.',
	'DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%/1'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYCLOPENT 0.5 (Milmet)'
);

-- line #10958
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYCLOSIGN EYE 1 (SUNSIGN PH.)',
	'Cyclopentolate Hcl.',
	'DROPS',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYCLOSIGN EYE 1 (SUNSIGN PH.)'
);

-- line #10959
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILATE 1 (Micro V.)',
	'Cyclopentolate Hcl.',
	'DPS',
	gm.nullify_empty_string('1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILATE 1 (Micro V.)'
);

-- line #10960
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'D LATE 1 (DREAM PH.)',
	'Cyclopentolate Hcl.',
	'DPS',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'D LATE 1 (DREAM PH.)'
);

-- line #10961
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EYEPEN EYE 10 (DIVINE LAB.)',
	'Cyclopentolate Hcl.',
	'DROPS',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EYEPEN EYE 10 (DIVINE LAB.)'
);

-- line #10962
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPTICYL 1 (Ophthal R.)',
	'Cyclopentolate Hcl.',
	'EYE DPS',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPTICYL 1 (Ophthal R.)'
);

-- line #10963
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENTOCYL 1 (Indiana O.)',
	'Cyclopentolate Hcl.',
	'EYE DPS',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENTOCYL 1 (Indiana O.)'
);

-- line #10964
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENTOLATE 1 (Sunways)',
	'Cyclopentolate Hcl.',
	'EYE DPS',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENTOLATE 1 (Sunways)'
);

-- line #10965
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cyclophosphamide', u'always_empty': u'', u'form': u'INJ', u'brand': u'CYCLOCEL', u'strength_3': u'', u'company': u'CELON(VIVILON)', u'unit': u''}

-- line #10966
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYCLOCEL 200 (CELON(VIVILON))',
	'Cyclophosphamide',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYCLOCEL 200 (CELON(VIVILON))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYCLOCEL 500 (CELON(VIVILON))',
	'Cyclophosphamide',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYCLOCEL 500 (CELON(VIVILON))'
);

-- line #10967
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cyclophosphamide', u'always_empty': u'', u'form': u'INJ', u'brand': u'CYCLOPHOSPHAMIDE', u'strength_3': u'', u'company': u'Vhb', u'unit': u''}

-- line #10968
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYCLOPHOSPHAMIDE 200 (Vhb)',
	'Cyclophosphamide',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYCLOPHOSPHAMIDE 200 (Vhb)'
);

-- line #10969
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYCLOPHOSPHAMIDE 500 (Vhb)',
	'Cyclophosphamide',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYCLOPHOSPHAMIDE 500 (Vhb)'
);

-- line #10970
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cyclophosphamide', u'always_empty': u'', u'form': u'INJ', u'brand': u'CYCLOXAN', u'strength_3': u'', u'company': u'Biochem', u'unit': u''}

-- line #10971
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYCLOXAN 200 (Biochem)',
	'Cyclophosphamide',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYCLOXAN 200 (Biochem)'
);

-- line #10972
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYCLOXAN 500 (Biochem)',
	'Cyclophosphamide',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYCLOXAN 500 (Biochem)'
);

-- line #10973
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYCLOXAN 50 (Biochem)',
	'Cyclophosphamide',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYCLOXAN 50 (Biochem)'
);

-- line #10974
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYCRAME 100 (Vhb)',
	'Cyclophosphamide',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYCRAME 100 (Vhb)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYCRAME 200 (Vhb)',
	'Cyclophosphamide',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYCRAME 200 (Vhb)'
);

-- line #10975
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYCRAME 500 (Vhb)',
	'Cyclophosphamide',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg/1G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYCRAME 500 (Vhb)'
);

-- line #10976
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYDOXAN 100 (Cytomed(Alkem))',
	'Cyclophosphamide',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYDOXAN 100 (Cytomed(Alkem))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYDOXAN 200 (Cytomed(Alkem))',
	'Cyclophosphamide',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYDOXAN 200 (Cytomed(Alkem))'
);

-- line #10977
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cyclophosphamide', u'always_empty': u'', u'form': u'INJ', u'brand': u'CYDOXAN', u'strength_3': u'', u'company': u'Cytomed(Alkem)', u'unit': u''}

-- line #10978
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYDOXAN 500 (Cytomed(Alkem))',
	'Cyclophosphamide',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYDOXAN 500 (Cytomed(Alkem))'
);

-- line #10979
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cyclophosphamide', u'always_empty': u'', u'form': u'INJ', u'brand': u'CYPHOS', u'strength_3': u'', u'company': u'Intas', u'unit': u''}

-- line #10980
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYPHOS 200 (Intas)',
	'Cyclophosphamide',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYPHOS 200 (Intas)'
);

-- line #10981
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYPHOS 500 (Intas)',
	'Cyclophosphamide',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYPHOS 500 (Intas)'
);

-- line #10982
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cyclophosphamide', u'always_empty': u'', u'form': u'V', u'brand': u'CYRRAM', u'strength_3': u'', u'company': u'Vhb', u'unit': u''}

-- line #10983
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cyclophosphamide', u'always_empty': u'', u'form': u'INJ', u'brand': u'CYSMIDE', u'strength_3': u'', u'company': u'Samarth', u'unit': u''}

-- line #10984
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYSMIDE 500 (Samarth)',
	'Cyclophosphamide',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYSMIDE 500 (Samarth)'
);

-- line #10985
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELDAMIDE 100 (Elder)',
	'Cyclophosphamide',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELDAMIDE 100 (Elder)'
);

-- line #10986
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELDAMIDE 200 (Elder)',
	'Cyclophosphamide',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELDAMIDE 200 (Elder)'
);

-- line #10987
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELDAMIDE 500 (Elder)',
	'Cyclophosphamide',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELDAMIDE 500 (Elder)'
);

-- line #10988
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELDAMIDE 50 (Elder)',
	'Cyclophosphamide',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELDAMIDE 50 (Elder)'
);

-- line #10989
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cyclophosphamide', u'always_empty': u'', u'form': u'INJ', u'brand': u'ENDOXAN-ASTA', u'strength_3': u'', u'company': u'German R.', u'unit': u''}

-- line #10990
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENDOXAN-ASTA 200 (German R.)',
	'Cyclophosphamide',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENDOXAN-ASTA 200 (German R.)'
);

-- line #10991
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENDOXAN-ASTA 500 (German R.)',
	'Cyclophosphamide',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENDOXAN-ASTA 500 (German R.)'
);

-- line #10992
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENDOXAN-ASTA 50 (German R.)',
	'Cyclophosphamide',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENDOXAN-ASTA 50 (German R.)'
);

-- line #10993
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cyclophosphamide', u'always_empty': u'', u'form': u'INJ', u'brand': u'LEDOXAN', u'strength_3': u'', u'company': u'Dabur Ph.', u'unit': u''}

-- line #10994
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEDOXAN 500 (Dabur Ph.)',
	'Cyclophosphamide',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEDOXAN 500 (Dabur Ph.)'
);

-- line #10995
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEDOXAN 200 (Dabur Ph.)',
	'Cyclophosphamide',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEDOXAN 200 (Dabur Ph.)'
);

-- line #10996
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEDOXAN 50 (Dabur Ph.)',
	'Cyclophosphamide',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEDOXAN 50 (Dabur Ph.)'
);

-- line #10997
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cyclophosphamide', u'always_empty': u'', u'form': u'INJ', u'brand': u'NEOPHOS', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #10998
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOPHOS 200 (Cipla)',
	'Cyclophosphamide',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOPHOS 200 (Cipla)'
);

-- line #10999
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOPHOS 500 (Cipla)',
	'Cyclophosphamide',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOPHOS 500 (Cipla)'
);

-- line #11000
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cyclophosphamide', u'always_empty': u'', u'form': u'INJ', u'brand': u'ONCOMIDE', u'strength_3': u'', u'company': u'Khandelwal', u'unit': u''}

-- line #11001
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONCOMIDE 200 (Khandelwal)',
	'Cyclophosphamide',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONCOMIDE 200 (Khandelwal)'
);

-- line #11002
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONCOMIDE 500 (Khandelwal)',
	'Cyclophosphamide',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONCOMIDE 500 (Khandelwal)'
);

-- line #11003
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONCOMIDE 50 (Khandelwal)',
	'Cyclophosphamide',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONCOMIDE 50 (Khandelwal)'
);

-- line #11004
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cyclophosphamide', u'always_empty': u'', u'form': u'V', u'brand': u'ONCOPHOS', u'strength_3': u'', u'company': u'Cadila Ph.', u'unit': u''}

-- line #11005
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONCOPHOS 200 (Cadila Ph.)',
	'Cyclophosphamide',
	'V',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONCOPHOS 200 (Cadila Ph.)'
);

-- line #11006
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONCOPHOS 500 (Cadila Ph.)',
	'Cyclophosphamide',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONCOPHOS 500 (Cadila Ph.)'
);

-- line #11007
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cyclophosphamide', u'always_empty': u'', u'form': u'INJ', u'brand': u'ONCOXAN', u'strength_3': u'', u'company': u'CH.Bhagat', u'unit': u''}

-- line #11008
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONCOXAN 200 (CH.Bhagat)',
	'Cyclophosphamide',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONCOXAN 200 (CH.Bhagat)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONCOXAN 500 (CH.Bhagat)',
	'Cyclophosphamide',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONCOXAN 500 (CH.Bhagat)'
);

-- line #11009
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONSIRAL 100 (Emcure)',
	'CYCLOPORINE',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg(ABSOLUTE ALCOHOL 10'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONSIRAL 100 (Emcure)'
);

-- line #11010
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONSIRAL 25 (Emcure)',
	'CYCLOPORINE',
	'CAP',
	gm.nullify_empty_string('25')::numeric,
	'mg(ABSOLUTE ALCOHOL 10'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONSIRAL 25 (Emcure)'
);

-- line #11011
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONSIRAL 50 (Emcure)',
	'CYCLOPORINE',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg(ABSOLUTE ALCOHOL 10'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONSIRAL 50 (Emcure)'
);

-- line #11012
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,5', u'strength_2': u'', u'substance': u'CYCLOPORINE', u'always_empty': u'', u'form': u'', u'brand': u'IMUDROPS', u'strength_3': u'', u'company': u'Cipla', u'unit': u'mg'}

-- line #11013
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COXERIN 250 (Macleods)',
	'Cycloserine',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COXERIN 250 (Macleods)'
);

-- line #11014
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYCLOKOX 250 (Radicura)',
	'Cycloserine',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYCLOKOX 250 (Radicura)'
);

-- line #11015
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYCLORINE 250 (Lupin)',
	'Cycloserine',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYCLORINE 250 (Lupin)'
);

-- line #11016
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYSERIN 250 (Vhb)',
	'Cycloserine',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYSERIN 250 (Vhb)'
);

-- line #11017
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MD SERINE 250 (Maneesh)',
	'Cycloserine',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MD SERINE 250 (Maneesh)'
);

-- line #11018
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MDSERIN 250 (Maneesh)',
	'Cycloserine',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MDSERIN 250 (Maneesh)'
);

-- line #11019
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYSER 250 (Panacea)',
	'Cycloserine',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYSER 250 (Panacea)'
);

-- line #11020
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAMSERINE 250 (Samarth)',
	'Cycloserine',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAMSERINE 250 (Samarth)'
);

-- line #11021
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYCLOPHIL-ME 100 (Biocon)',
	'Cyclosporin A',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYCLOPHIL-ME 100 (Biocon)'
);

-- line #11022
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYCLOPHIL-ME 25 (Biocon)',
	'Cyclosporin A',
	'CAP',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYCLOPHIL-ME 25 (Biocon)'
);

-- line #11023
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYCLOPHIL-ME 50 (Biocon)',
	'Cyclosporin A',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYCLOPHIL-ME 50 (Biocon)'
);

-- line #11024
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100', u'strength_2': u'', u'substance': u'Cyclosporin A', u'always_empty': u'', u'form': u'', u'brand': u'CYCLOPHIL-ME ORAL', u'strength_3': u'', u'company': u'Biocon', u'unit': u'mg/ML'}

-- line #11025
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYRIN 100 (Claris L.)',
	'Cyclosporin A',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYRIN 100 (Claris L.)'
);

-- line #11026
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYRIN 10 (Claris L.)',
	'Cyclosporin A',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYRIN 10 (Claris L.)'
);

-- line #11027
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYRIN 25 (Claris L.)',
	'Cyclosporin A',
	'CAP',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYRIN 25 (Claris L.)'
);

-- line #11028
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYRIN 50 (Claris L.)',
	'Cyclosporin A',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYRIN 50 (Claris L.)'
);

-- line #11029
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYRIN 100 (Claris L.)',
	'Cyclosporin A',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYRIN 100 (Claris L.)'
);

-- line #11030
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRAFTIN 100 (Ranbaxy)',
	'Cyclosporin A',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRAFTIN 100 (Ranbaxy)'
);

-- line #11031
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRAFTIN 25 (Ranbaxy)',
	'Cyclosporin A',
	'CAP',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRAFTIN 25 (Ranbaxy)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRAFTIN 50 (Ranbaxy)',
	'Cyclosporin A',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRAFTIN 50 (Ranbaxy)'
);

-- line #11032
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRAFTIN 100 (Ranbaxy)',
	'Cyclosporin A',
	'SOL',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRAFTIN 100 (Ranbaxy)'
);

-- line #11033
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMMUSOL 100 (Dabur Ph.)',
	'Cyclosporin A',
	'SOL',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMMUSOL 100 (Dabur Ph.)'
);

-- line #11034
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMUSPORIN 100 (Cipla)',
	'Cyclosporin A',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMUSPORIN 100 (Cipla)'
);

-- line #11035
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMUSPORIN 25 (Cipla)',
	'Cyclosporin A',
	'CAP',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMUSPORIN 25 (Cipla)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMUSPORIN 50 (Cipla)',
	'Cyclosporin A',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMUSPORIN 50 (Cipla)'
);

-- line #11036
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMUSPORIN 100 (Cipla)',
	'Cyclosporin A',
	'SOL',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMUSPORIN 100 (Cipla)'
);

-- line #11037
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANIMUN BIORAL 100 (Panacea)',
	'Cyclosporin A',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANIMUN BIORAL 100 (Panacea)'
);

-- line #11038
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANIMUN BIORAL 25 (Panacea)',
	'Cyclosporin A',
	'CAP',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANIMUN BIORAL 25 (Panacea)'
);

-- line #11039
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANIMUN BIORAL 50 (Panacea)',
	'Cyclosporin A',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANIMUN BIORAL 50 (Panacea)'
);

-- line #11040
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANIMUN BIORAL 100 (Panacea)',
	'Cyclosporin A',
	'SOL',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANIMUN BIORAL 100 (Panacea)'
);

-- line #11041
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,05', u'strength_2': u'', u'substance': u'Cyclosporin A', u'always_empty': u'', u'form': u'', u'brand': u'RESTASIS %', u'strength_3': u'', u'company': u'Allergan', u'unit': u'%'}

-- line #11042
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYCLOMUNE 0.05 (SUN)',
	'Cyclosporine',
	'EYE DPS',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYCLOMUNE 0.05 (SUN)'
);

-- line #11043
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYCLOMUNE 0.1 (SUN)',
	'Cyclosporine',
	'EYE DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYCLOMUNE 0.1 (SUN)'
);

-- line #11044
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYCLOMUNE % 5 (SUN(AVESTA))',
	'Cyclosporine',
	'EYE DPS',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYCLOMUNE % 5 (SUN(AVESTA))'
);

-- line #11045
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONCYCLO 100 (Bharat S.)',
	'Cyclosporine',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg(+DEHYDRATED ALCOHOL 12.0 VOL'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONCYCLO 100 (Bharat S.)'
);

-- line #11046
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONCYCLO 25 (Bharat S.)',
	'Cyclosporine',
	'CAP',
	gm.nullify_empty_string('25')::numeric,
	'mg(+DEHYDRATED ALCOHOL 12.0 VOL'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONCYCLO 25 (Bharat S.)'
);

-- line #11047
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONCYCLO 50 (Bharat S.)',
	'Cyclosporine',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg(+DEHYDRATED ALCOHOL 12.0 VOL'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONCYCLO 50 (Bharat S.)'
);

-- line #11048
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONCYCLO 100 (Bharat S.)',
	'Cyclosporine',
	'SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg(+DEHYDRATED ALCOHOL 12.0 VOL'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONCYCLO 100 (Bharat S.)'
);

-- line #11049
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100', u'strength_2': u'', u'substance': u'Cyclosporine', u'always_empty': u'', u'form': u'', u'brand': u'PSORID', u'strength_3': u'', u'company': u'BIOCON LTD.', u'unit': u'mg'}

-- line #11050
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'25', u'strength_2': u'', u'substance': u'Cyclosporine', u'always_empty': u'', u'form': u'', u'brand': u'PSORID', u'strength_3': u'', u'company': u'BIOCON LTD.', u'unit': u'mg'}

-- line #11051
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50', u'strength_2': u'', u'substance': u'Cyclosporine', u'always_empty': u'', u'form': u'', u'brand': u'PSORID', u'strength_3': u'', u'company': u'BIOCON LTD.', u'unit': u'mg'}

-- line #11052
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Cyclosporine', u'always_empty': u'', u'form': u'SOL', u'brand': u'PSORID ORAL', u'strength_3': u'', u'company': u'BIOCON LTD.', u'unit': u''}

-- line #11053
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADD APP 2 (Cadila)',
	'Cyproheptadine Hcl.',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADD APP 2 (Cadila)'
);

-- line #11054
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANABOL 2 (Sayona)',
	'Cyproheptadine Hcl.',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANABOL 2 (Sayona)'
);

-- line #11055
-- ignoring line: empty field [company]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'4', u'strength_2': u'', u'substance': u'Cyproheptadine Hcl.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ANABOL', u'strength_3': u'', u'company': u'', u'unit': u'mg'}

-- line #11056
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANOREXIN 2 (Strassenburg)',
	'Cyproheptadine Hcl.',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANOREXIN 2 (Strassenburg)'
);

-- line #11057
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APEL 1.5 (Lancer)',
	'Cyproheptadine Hcl.',
	'DPS',
	gm.nullify_empty_string('1.5')::numeric,
	'mg/1ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APEL 1.5 (Lancer)'
);

-- line #11058
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APEL 2 (Lancer)',
	'Cyproheptadine Hcl.',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APEL 2 (Lancer)'
);

-- line #11059
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APEL 4 (Lancer)',
	'Cyproheptadine Hcl.',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APEL 4 (Lancer)'
);

-- line #11060
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APENORM 4 (Cipla)',
	'Cyproheptadine Hcl.',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APENORM 4 (Cipla)'
);

-- line #11061
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APEPLUS 2 (Radicura)',
	'Cyproheptadine Hcl.',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APEPLUS 2 (Radicura)'
);

-- line #11062
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APETIZ 4 (Meridian)',
	'Cyproheptadine Hcl.',
	'SYR',
	gm.nullify_empty_string('4')::numeric,
	'mg(ANHYDR.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APETIZ 4 (Meridian)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APETIZ 2 (Meridian)',
	'Cyproheptadine Hcl.',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg(ANHYDR.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APETIZ 2 (Meridian)'
);

-- line #11063
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APETONE 4 (Synokem)',
	'Cyproheptadine Hcl.',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APETONE 4 (Synokem)'
);

-- line #11064
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APEWIN 4 (Stanford)',
	'Cyproheptadine Hcl.',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APEWIN 4 (Stanford)'
);

-- line #11065
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APIP 2 (Izen Ph.)',
	'Cyproheptadine Hcl.',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APIP 2 (Izen Ph.)'
);

-- line #11066
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APPETIDIN 2 (Om Bio.)',
	'Cyproheptadine Hcl.',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APPETIDIN 2 (Om Bio.)'
);

-- line #11067
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APPETIDIN 4 (Om Bio.)',
	'Cyproheptadine Hcl.',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APPETIDIN 4 (Om Bio.)'
);

-- line #11068
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APPETON 2 (VIBRANT PH.)',
	'Cyproheptadine Hcl.',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APPETON 2 (VIBRANT PH.)'
);

-- line #11069
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Cyproheptadine Hcl.', u'always_empty': u'', u'form': u'DPS', u'brand': u'APPON', u'strength_3': u'', u'company': u'SAFE PH.', u'unit': u''}

-- line #11070
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Cyproheptadine Hcl.', u'always_empty': u'', u'form': u'TAB', u'brand': u'APPRI', u'strength_3': u'', u'company': u'Rhombus', u'unit': u''}

-- line #11071
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APTAUR 2 (Taurus Lab)',
	'Cyproheptadine Hcl.',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APTAUR 2 (Taurus Lab)'
);

-- line #11072
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2', u'strength_2': u'', u'substance': u'Cyproheptadine Hcl.', u'always_empty': u'', u'form': u'', u'brand': u'APYTON', u'strength_3': u'', u'company': u'NECTAR HC.', u'unit': u'mg'}

-- line #11073
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APZED 2 (Zota Ph.)',
	'Cyproheptadine Hcl.',
	'DPS',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APZED 2 (Zota Ph.)'
);

-- line #11074
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Cyproheptadine Hcl.', u'always_empty': u'', u'form': u'SYR', u'brand': u'ATRIC PLUS', u'strength_3': u'', u'company': u'Admac Ph.', u'unit': u''}

-- line #11075
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BAL-RIACTIN 2 (Bal Ph.)',
	'Cyproheptadine Hcl.',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BAL-RIACTIN 2 (Bal Ph.)'
);

-- line #11076
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BONAPET 2 (Orison Ph.)',
	'Cyproheptadine Hcl.',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BONAPET 2 (Orison Ph.)'
);

-- line #11077
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BONAPET 4 (Orison Ph.)',
	'Cyproheptadine Hcl.',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BONAPET 4 (Orison Ph.)'
);

-- line #11078
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C APETITE 2 (Corona)',
	'Cyproheptadine Hcl.',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C APETITE 2 (Corona)'
);

-- line #11079
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEDEL 2 (Zee Lab)',
	'Cyproheptadine Hcl.',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEDEL 2 (Zee Lab)'
);

-- line #11080
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPLACTIN 2 (Cipla)',
	'Cyproheptadine Hcl.',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg(0.263ML ALCOHOL);5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPLACTIN 2 (Cipla)'
);

-- line #11081
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPLACTIN 2 (Cipla)',
	'Cyproheptadine Hcl.',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'4'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPLACTIN 2 (Cipla)'
);

-- line #11082
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORDIN 4 (Corona)',
	'Cyproheptadine Hcl.',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORDIN 4 (Corona)'
);

-- line #11083
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Cyproheptadine Hcl.', u'always_empty': u'', u'form': u'SYP', u'brand': u'CYLAC', u'strength_3': u'', u'company': u'NIVCA', u'unit': u''}

-- line #11084
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYPODINE 2 (Cosmas Ph.)',
	'Cyproheptadine Hcl.',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYPODINE 2 (Cosmas Ph.)'
);

-- line #11085
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYPO 2 (Shinto Org.)',
	'Cyproheptadine Hcl.',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYPO 2 (Shinto Org.)'
);

-- line #11086
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYPRINE 2 (Hema Lab)',
	'Cyproheptadine Hcl.',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYPRINE 2 (Hema Lab)'
);

-- line #11087
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYPROB 2 (IP HC.)',
	'Cyproheptadine Hcl.',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYPROB 2 (IP HC.)'
);

-- line #11088
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYPRODIN 2 (Auroma Life)',
	'Cyproheptadine Hcl.',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYPRODIN 2 (Auroma Life)'
);

-- line #11089
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYPROFORD 2 (Ronak Lab.)',
	'Cyproheptadine Hcl.',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYPROFORD 2 (Ronak Lab.)'
);

-- line #11090
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYPROFORD 4 (Ronak Lab.)',
	'Cyproheptadine Hcl.',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYPROFORD 4 (Ronak Lab.)'
);

-- line #11091
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYPROLAND 2 (L & V PH.)',
	'Cyproheptadine Hcl.',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYPROLAND 2 (L & V PH.)'
);

-- line #11092
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYPROLUCK 2 (Goodluck Ph.)',
	'Cyproheptadine Hcl.',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYPROLUCK 2 (Goodluck Ph.)'
);

-- line #11093
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYPROSON 1.5 (Patson)',
	'Cyproheptadine Hcl.',
	'DPS',
	gm.nullify_empty_string('1.5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYPROSON 1.5 (Patson)'
);

-- line #11094
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYPROSON 2 (Patson)',
	'Cyproheptadine Hcl.',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYPROSON 2 (Patson)'
);

-- line #11095
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYPROSON 4 (Patson)',
	'Cyproheptadine Hcl.',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYPROSON 4 (Patson)'
);

-- line #11096
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYPTOL 2 (Baroque)',
	'Cyproheptadine Hcl.',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYPTOL 2 (Baroque)'
);

-- line #11097
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECYP-P 1.5 (Alde Medi.)',
	'Cyproheptadine Hcl.',
	'DPS',
	gm.nullify_empty_string('1.5')::numeric,
	'mg/1ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECYP-P 1.5 (Alde Medi.)'
);

-- line #11098
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECYP-P 2 (Alde Medi.)',
	'Cyproheptadine Hcl.',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECYP-P 2 (Alde Medi.)'
);

-- line #11099
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECYP-P 4 (Alde Medi.)',
	'Cyproheptadine Hcl.',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg(ANHY.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECYP-P 4 (Alde Medi.)'
);

-- line #11100
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMACTIN 4 (Emil Ph.)',
	'Cyproheptadine Hcl.',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMACTIN 4 (Emil Ph.)'
);

-- line #11101
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Cyproheptadine Hcl.', u'always_empty': u'', u'form': u'SYRUP', u'brand': u'GROWELL', u'strength_3': u'', u'company': u'Royal', u'unit': u''}

-- line #11102
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEPADIN 2 (Shalman)',
	'Cyproheptadine Hcl.',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEPADIN 2 (Shalman)'
);

-- line #11103
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEPT-2 2 (Corona)',
	'Cyproheptadine Hcl.',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEPT-2 2 (Corona)'
);

-- line #11104
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEPTINE 4 (Trio Rem.)',
	'Cyproheptadine Hcl.',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEPTINE 4 (Trio Rem.)'
);

-- line #11105
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HUNGRY 4 (Tripada Hc.)',
	'Cyproheptadine Hcl.',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HUNGRY 4 (Tripada Hc.)'
);

-- line #11106
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'L-CETOL 2 (Mamta Ph.)',
	'Cyproheptadine Hcl.',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'L-CETOL 2 (Mamta Ph.)'
);

-- line #11107
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEPLLER 2 (Active Hc.)',
	'Cyproheptadine Hcl.',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEPLLER 2 (Active Hc.)'
);

-- line #11108
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERITOL 1.5 (Themis)',
	'Cyproheptadine Hcl.',
	'DPS',
	gm.nullify_empty_string('1.5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERITOL 1.5 (Themis)'
);

-- line #11109
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERITOL 2 (Themis)',
	'Cyproheptadine Hcl.',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERITOL 2 (Themis)'
);

-- line #11110
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERITOL 4 (Themis)',
	'Cyproheptadine Hcl.',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERITOL 4 (Themis)'
);

-- line #11111
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRACTIN 2 (Merind)',
	'Cyproheptadine Hcl.',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRACTIN 2 (Merind)'
);

-- line #11112
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRACTIN 4 (Merind)',
	'Cyproheptadine Hcl.',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRACTIN 4 (Merind)'
);

-- line #11113
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRODIN 1 (Briskon)',
	'Cyproheptadine Hcl.',
	'DPS',
	gm.nullify_empty_string('1')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRODIN 1 (Briskon)'
);

-- line #11114
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRODIN 2 (Briskon)',
	'Cyproheptadine Hcl.',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRODIN 2 (Briskon)'
);

-- line #11115
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FRENY 2 (Dahlia Ph.)',
	'CYPROTERONE ACETATE',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FRENY 2 (Dahlia Ph.)'
);

-- line #11116
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARASID 100 (Novatech)',
	'Cytosine Arabinoside',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARASID 100 (Novatech)'
);

-- line #11117
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cytosine Arabinoside', u'always_empty': u'', u'form': u'INJ', u'brand': u'ARASID', u'strength_3': u'', u'company': u'Novatech', u'unit': u''}

-- line #11118
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARASID 500 (Novatech)',
	'Cytosine Arabinoside',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARASID 500 (Novatech)'
);

-- line #11119
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOBIN 100 (Biochem)',
	'Cytosine Arabinoside',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOBIN 100 (Biochem)'
);

-- line #11120
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOBIN 500 (Biochem)',
	'Cytosine Arabinoside',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOBIN 500 (Biochem)'
);

-- line #11121
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'IG', u'strength_2': u'', u'substance': u'Cytosine Arabinoside', u'always_empty': u'', u'form': u'INJ', u'brand': u'BIOBIN', u'strength_3': u'', u'company': u'Biochem', u'unit': u''}

-- line #11122
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANCYT 100 (MIRACALUS)',
	'Cytosine Arabinoside',
	'VIAL',
	gm.nullify_empty_string('100')::numeric,
	'mg(CYTARABINE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANCYT 100 (MIRACALUS)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANCYT 500 (MIRACALUS)',
	'Cytosine Arabinoside',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg(CYTARABINE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANCYT 500 (MIRACALUS)'
);

-- line #11123
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G(CYTARABINE)', u'strength_2': u'', u'substance': u'Cytosine Arabinoside', u'always_empty': u'', u'form': u'VIAL', u'brand': u'CANCYT', u'strength_3': u'', u'company': u'MIRACALUS', u'unit': u''}

-- line #11124
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYBIN-PF 100 (VHB)',
	'Cytosine Arabinoside',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYBIN-PF 100 (VHB)'
);

-- line #11125
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'10ML', u'substance': u'Cytosine Arabinoside', u'always_empty': u'', u'form': u'INJ', u'brand': u'CYBIN-PF', u'strength_3': u'', u'company': u'VHB', u'unit': u''}

-- line #11126
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYBIN-PF 500 (VHB)',
	'Cytosine Arabinoside',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYBIN-PF 500 (VHB)'
);

-- line #11127
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYTABIN 1000 (Zydus Cadila)',
	'Cytosine Arabinoside',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYTABIN 1000 (Zydus Cadila)'
);

-- line #11128
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYTABIN 100 (Zydus Cadila)',
	'Cytosine Arabinoside',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYTABIN 100 (Zydus Cadila)'
);

-- line #11129
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYTABIN 500 (Zydus Cadila)',
	'Cytosine Arabinoside',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYTABIN 500 (Zydus Cadila)'
);

-- line #11130
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYTALON 100 (CELON(VIVILON))',
	'Cytosine Arabinoside',
	'VIAL',
	gm.nullify_empty_string('100')::numeric,
	'mg(CYTARABINE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYTALON 100 (CELON(VIVILON))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYTALON 500 (CELON(VIVILON))',
	'Cytosine Arabinoside',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg(CYTARABINE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYTALON 500 (CELON(VIVILON))'
);

-- line #11131
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cytosine Arabinoside', u'always_empty': u'', u'form': u'VIAL', u'brand': u'CYTALON', u'strength_3': u'', u'company': u'CELON(VIVILON)', u'unit': u''}

-- line #11132
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYTARABINE 1000 (Pharmacia)',
	'Cytosine Arabinoside',
	'V',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYTARABINE 1000 (Pharmacia)'
);

-- line #11133
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYTARABINE 100 (Pharmacia)',
	'Cytosine Arabinoside',
	'V',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYTARABINE 100 (Pharmacia)'
);

-- line #11134
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYTARABINE 500 (Pharmacia)',
	'Cytosine Arabinoside',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYTARABINE 500 (Pharmacia)'
);

-- line #11135
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYTARABIN 100 (Biochem)',
	'Cytosine Arabinoside',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYTARABIN 100 (Biochem)'
);

-- line #11136
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYTARABIN 500 (Biochem)',
	'Cytosine Arabinoside',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYTARABIN 500 (Biochem)'
);

-- line #11137
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYTARABIN 100 (SG PH.)',
	'Cytosine Arabinoside',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYTARABIN 100 (SG PH.)'
);

-- line #11138
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYTARASIDE 100 (CH.Bhagat)',
	'Cytosine Arabinoside',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYTARASIDE 100 (CH.Bhagat)'
);

-- line #11139
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'10ML', u'substance': u'Cytosine Arabinoside', u'always_empty': u'', u'form': u'INJ', u'brand': u'CYTARASIDE', u'strength_3': u'', u'company': u'CH.Bhagat', u'unit': u''}

-- line #11140
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYTARASIDE 500 (CH.Bhagat)',
	'Cytosine Arabinoside',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYTARASIDE 500 (CH.Bhagat)'
);

-- line #11141
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYTARINE 100 (Dabur Ph.)',
	'Cytosine Arabinoside',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYTARINE 100 (Dabur Ph.)'
);

-- line #11142
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cytosine Arabinoside', u'always_empty': u'', u'form': u'INJ', u'brand': u'CYTARINE', u'strength_3': u'', u'company': u'Dabur Ph.', u'unit': u''}

-- line #11143
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYTARINE 500 (Dabur Ph.)',
	'Cytosine Arabinoside',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYTARINE 500 (Dabur Ph.)'
);

-- line #11144
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYTOSAR 1000 (Pfizer)',
	'Cytosine Arabinoside',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg(CYTARABINE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYTOSAR 1000 (Pfizer)'
);

-- line #11145
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYTOSAR 100 (Pfizer)',
	'Cytosine Arabinoside',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg(CYTARABINE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYTOSAR 100 (Pfizer)'
);

-- line #11146
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYTOSAR 500 (Pfizer)',
	'Cytosine Arabinoside',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg(CYTARABINE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYTOSAR 500 (Pfizer)'
);

-- line #11147
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYTOSAR 100 (Vhb)',
	'Cytosine Arabinoside',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYTOSAR 100 (Vhb)'
);

-- line #11148
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cytosine Arabinoside', u'always_empty': u'', u'form': u'INJ', u'brand': u'CYTOSAR', u'strength_3': u'', u'company': u'Vhb', u'unit': u''}

-- line #11149
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYTOSAR 500 (Vhb)',
	'Cytosine Arabinoside',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYTOSAR 500 (Vhb)'
);

-- line #11150
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYTROSAR 100 (Vhb)',
	'Cytosine Arabinoside',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYTROSAR 100 (Vhb)'
);

-- line #11151
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'10ML', u'substance': u'Cytosine Arabinoside', u'always_empty': u'', u'form': u'V', u'brand': u'CYTROSAR', u'strength_3': u'', u'company': u'Vhb', u'unit': u''}

-- line #11152
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYTROSAR 500 (Vhb)',
	'Cytosine Arabinoside',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYTROSAR 500 (Vhb)'
);

-- line #11153
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONCOTAR 100 (United Bio.)',
	'Cytosine Arabinoside',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONCOTAR 100 (United Bio.)'
);

-- line #11154
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cytosine Arabinoside', u'always_empty': u'', u'form': u'INJ', u'brand': u'ONCOTAR', u'strength_3': u'', u'company': u'United Bio.', u'unit': u''}

-- line #11155
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REMCYTA 100 (Cytomed(Alkem))',
	'Cytosine Arabinoside',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REMCYTA 100 (Cytomed(Alkem))'
);

-- line #11156
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cytosine Arabinoside', u'always_empty': u'', u'form': u'INJ', u'brand': u'REMCYTA', u'strength_3': u'', u'company': u'Cytomed(Alkem)', u'unit': u''}

-- line #11157
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REMCYTA 500 (Cytomed(Alkem))',
	'Cytosine Arabinoside',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REMCYTA 500 (Cytomed(Alkem))'
);

-- line #11158
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REMYCTA 100 (Cytomed(Alkem))',
	'Cytosine Arabinoside',
	'V',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REMYCTA 100 (Cytomed(Alkem))'
);

-- line #11159
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Cytosine Arabinoside', u'always_empty': u'', u'form': u'V', u'brand': u'REMYCTA', u'strength_3': u'', u'company': u'Cytomed(Alkem)', u'unit': u''}

-- line #11160
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REMYCTA 500 (Cytomed(Alkem))',
	'Cytosine Arabinoside',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REMYCTA 500 (Cytomed(Alkem))'
);

-- line #11161
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARZI 100 (MIRACALUS)',
	'Dacarbazine',
	'VIAL',
	gm.nullify_empty_string('100')::numeric,
	'200'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARZI 100 (MIRACALUS)'
);

-- line #11162
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Dacarbazine', u'always_empty': u'', u'form': u'VIAL', u'brand': u'ARZI', u'strength_3': u'', u'company': u'MIRACALUS', u'unit': u''}

-- line #11163
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELDAZ 100 (CELON(VIVILON))',
	'Dacarbazine',
	'VIAL',
	gm.nullify_empty_string('100')::numeric,
	'200'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELDAZ 100 (CELON(VIVILON))'
);

-- line #11164
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELDAZ 500 (CELON(VIVILON))',
	'Dacarbazine',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELDAZ 500 (CELON(VIVILON))'
);

-- line #11165
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DABAZ 100 (Novatech)',
	'Dacarbazine',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DABAZ 100 (Novatech)'
);

-- line #11166
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DABAZ 200 (Novatech)',
	'Dacarbazine',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DABAZ 200 (Novatech)'
);

-- line #11167
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DABAZ 500 (Novatech)',
	'Dacarbazine',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DABAZ 500 (Novatech)'
);

-- line #11168
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DACARBA 100 (CH.Bhagat)',
	'Dacarbazine',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/V.'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DACARBA 100 (CH.Bhagat)'
);

-- line #11169
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DACARBA 200 (CH.Bhagat)',
	'Dacarbazine',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg/V.'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DACARBA 200 (CH.Bhagat)'
);

-- line #11170
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DACARBA 500 (CH.Bhagat)',
	'Dacarbazine',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DACARBA 500 (CH.Bhagat)'
);

-- line #11171
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DACAREX 100 (Cytomed(Alkem))',
	'Dacarbazine',
	'VIAL',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DACAREX 100 (Cytomed(Alkem))'
);

-- line #11172
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DACAREX 200 (Cytomed(Alkem))',
	'Dacarbazine',
	'VIAL',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DACAREX 200 (Cytomed(Alkem))'
);

-- line #11173
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DACAREX 500 (Cytomed(Alkem))',
	'Dacarbazine',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DACAREX 500 (Cytomed(Alkem))'
);

-- line #11174
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DACARIN 100 (Vhb)',
	'Dacarbazine',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DACARIN 100 (Vhb)'
);

-- line #11175
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DACARIN 200 (Vhb)',
	'Dacarbazine',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DACARIN 200 (Vhb)'
);

-- line #11176
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DACARIN 500 (Vhb)',
	'Dacarbazine',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DACARIN 500 (Vhb)'
);

-- line #11177
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DACARZINE 200 (Khandelwal)',
	'Dacarbazine',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DACARZINE 200 (Khandelwal)'
);

-- line #11178
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DACZIN 200 (Cadila Hc.)',
	'Dacarbazine',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DACZIN 200 (Cadila Hc.)'
);

-- line #11179
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DT CARE 200 (Criticare)',
	'Dacarbazine',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg/V.'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DT CARE 200 (Criticare)'
);

-- line #11180
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DTIC-VHB 100 (Vhb)',
	'Dacarbazine',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DTIC-VHB 100 (Vhb)'
);

-- line #11181
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DTIC-VHB 200 (Vhb)',
	'Dacarbazine',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DTIC-VHB 200 (Vhb)'
);

-- line #11182
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DTIC-VHB 500 (Vhb)',
	'Dacarbazine',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DTIC-VHB 500 (Vhb)'
);

-- line #11183
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Dactinomycin', u'always_empty': u'', u'form': u'INJ', u'brand': u'COSMEGEN', u'strength_3': u'', u'company': u'Merind', u'unit': u''}

-- line #11184
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DACILON 0.5 (CELON(VIVILON))',
	'Dactinomycin',
	'INJ',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DACILON 0.5 (CELON(VIVILON))'
);

-- line #11185
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Dactinomycin', u'always_empty': u'', u'form': u'INJ', u'brand': u'DACMOZEN', u'strength_3': u'', u'company': u'Vhb', u'unit': u''}

-- line #11186
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DACTINO 0.5 (CH.Bhagat)',
	'Dactinomycin',
	'VIAL',
	gm.nullify_empty_string('0.5')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DACTINO 0.5 (CH.Bhagat)'
);

-- line #11187
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DANOGEN 100 (Cipla)',
	'Danazol',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DANOGEN 100 (Cipla)'
);

-- line #11188
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DANOGEN 200 (Cipla)',
	'Danazol',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DANOGEN 200 (Cipla)'
);

-- line #11189
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DANOGEN 50 (Cipla)',
	'Danazol',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DANOGEN 50 (Cipla)'
);

-- line #11190
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENDOMETRYL 100 (Ar-Ex Labs.)',
	'Danazol',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENDOMETRYL 100 (Ar-Ex Labs.)'
);

-- line #11191
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENDOMETRYL 200 (Ar-Ex Labs.)',
	'Danazol',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENDOMETRYL 200 (Ar-Ex Labs.)'
);

-- line #11192
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENDOMETRYL 50 (Ar-Ex Labs.)',
	'Danazol',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENDOMETRYL 50 (Ar-Ex Labs.)'
);

-- line #11193
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENDOZOL 100 (VHB)',
	'Danazol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENDOZOL 100 (VHB)'
);

-- line #11194
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENDOZOL 200 (VHB)',
	'Danazol',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENDOZOL 200 (VHB)'
);

-- line #11195
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENDOZOL 50 (VHB)',
	'Danazol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENDOZOL 50 (VHB)'
);

-- line #11196
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GONABLOK 100 (Win-Medicare)',
	'Danazol',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GONABLOK 100 (Win-Medicare)'
);

-- line #11197
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GONABLOK 200 (Win-Medicare)',
	'Danazol',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GONABLOK 200 (Win-Medicare)'
);

-- line #11198
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GONABLOK 50 (Win-Medicare)',
	'Danazol',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GONABLOK 50 (Win-Medicare)'
);

-- line #11199
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GYNADOM 100 (EAST WEST)',
	'Danazol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GYNADOM 100 (EAST WEST)'
);

-- line #11200
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GYNADOM 200 (EAST WEST)',
	'Danazol',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GYNADOM 200 (EAST WEST)'
);

-- line #11201
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GYNAZOL 100 (Spectra)',
	'Danazol',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GYNAZOL 100 (Spectra)'
);

-- line #11202
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GYNAZOL 200 (Spectra)',
	'Danazol',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GYNAZOL 200 (Spectra)'
);

-- line #11203
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GYNAZOL 50 (Spectra)',
	'Danazol',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GYNAZOL 50 (Spectra)'
);

-- line #11204
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GYNODAN 100 (Uni-Sank.)',
	'Danazol',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GYNODAN 100 (Uni-Sank.)'
);

-- line #11205
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GYNODAN 200 (Uni-Sank.)',
	'Danazol',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GYNODAN 200 (Uni-Sank.)'
);

-- line #11206
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GYNODAN 50 (Uni-Sank.)',
	'Danazol',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GYNODAN 50 (Uni-Sank.)'
);

-- line #11207
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GYNOL 100 (Globus)',
	'Danazol',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GYNOL 100 (Globus)'
);

-- line #11208
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GYNOL 200 (Globus)',
	'Danazol',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GYNOL 200 (Globus)'
);

-- line #11209
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GYNOL 50 (Globus)',
	'Danazol',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GYNOL 50 (Globus)'
);

-- line #11210
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LADOGAL 100 (Sanofi Aventis)',
	'Danazol',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LADOGAL 100 (Sanofi Aventis)'
);

-- line #11211
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LADOGAL 200 (Sanofi Aventis)',
	'Danazol',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LADOGAL 200 (Sanofi Aventis)'
);

-- line #11212
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LADOGAL 50 (Sanofi Aventis)',
	'Danazol',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LADOGAL 50 (Sanofi Aventis)'
);

-- line #11213
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAPOXY 30 (ALEMBIC)',
	'DAPOXETINE',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAPOXY 30 (ALEMBIC)'
);

-- line #11214
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPOX 30 (Ranbaxy)',
	'DAPOXETINE',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPOX 30 (Ranbaxy)'
);

-- line #11215
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPOX 60 (Ranbaxy)',
	'DAPOXETINE',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPOX 60 (Ranbaxy)'
);

-- line #11216
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DURAJECT 30 (AKUMENTIS HC.)',
	'DAPOXETINE',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DURAJECT 30 (AKUMENTIS HC.)'
);

-- line #11217
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DURAJECT 60 (AKUMENTIS HC.)',
	'DAPOXETINE',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DURAJECT 60 (AKUMENTIS HC.)'
);

-- line #11218
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DURALAST 30 (Sun)',
	'DAPOXETINE',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DURALAST 30 (Sun)'
);

-- line #11219
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DURALAST 60 (Sun)',
	'DAPOXETINE',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DURALAST 60 (Sun)'
);

-- line #11220
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EJALONG 30 (LASOR PH.)',
	'DAPOXETINE',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EJALONG 30 (LASOR PH.)'
);

-- line #11221
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JUSTINEX-30 30 (Emcure)',
	'DAPOXETINE',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JUSTINEX-30 30 (Emcure)'
);

-- line #11222
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JUSTINEX-60 60 (Emcure)',
	'DAPOXETINE',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JUSTINEX-60 60 (Emcure)'
);

-- line #11223
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRILYXET 30 (Sun)',
	'DAPOXETINE',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRILYXET 30 (Sun)'
);

-- line #11224
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRILYXET 60 (Sun)',
	'DAPOXETINE',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRILYXET 60 (Sun)'
);

-- line #11225
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAPSONE 100 (Gsk)',
	'Dapsone',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAPSONE 100 (Gsk)'
);

-- line #11226
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAPSONE 25 (Gsk)',
	'Dapsone',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAPSONE 25 (Gsk)'
);

-- line #11227
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAPSONE 50 (Gsk)',
	'Dapsone',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAPSONE 50 (Gsk)'
);

-- line #11228
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'25MCG - (R-DNA ORIGIN) 25MCG', u'strength_2': u'', u'substance': u'DARBEPOETIN ALPHA', u'always_empty': u'', u'form': u'INJ (PFS)', u'brand': u'CRESP MCG', u'strength_3': u'', u'company': u"DR. REDDY''S", u'unit': u''}

-- line #11229
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40MCG - (R-DNA ORIGIN) 25MCG', u'strength_2': u'', u'substance': u'DARBEPOETIN ALPHA', u'always_empty': u'', u'form': u'INJ (PFS)', u'brand': u'CRESP MCG', u'strength_3': u'', u'company': u"DR. REDDY''S", u'unit': u''}

-- line #11230
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'25MCG - (R-DNA ORIGIN) 25MCG', u'strength_2': u'', u'substance': u'DARBEPOETIN ALPHA', u'always_empty': u'', u'form': u'INJ (VIAL)', u'brand': u'CRESP MCG', u'strength_3': u'', u'company': u"DR. REDDY''S", u'unit': u''}

-- line #11231
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40MCG - (R-DNA ORIGIN) 25MCG', u'strength_2': u'', u'substance': u'DARBEPOETIN ALPHA', u'always_empty': u'', u'form': u'INJ (VIAL)', u'brand': u'CRESP MCG', u'strength_3': u'', u'company': u"DR. REDDY''S", u'unit': u''}

-- line #11232
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CRESP PFS 100 (Dr.Reddy''S)',
	'DARBEPOETIN ALPHA',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg(R-DNA ORIGIN)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CRESP PFS 100 (Dr.Reddy''S)'
);

-- line #11233
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CRESP PFS 200 (Dr.Reddy''S)',
	'DARBEPOETIN ALPHA',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg(R-DNA ORIGIN)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CRESP PFS 200 (Dr.Reddy''S)'
);

-- line #11234
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DARIF 7.5 (SUMMIT)',
	'DARIFENACIN HBR',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DARIF 7.5 (SUMMIT)'
);

-- line #11235
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'15', u'strength_2': u'', u'substance': u'DARIFENACIN HBR', u'always_empty': u'', u'form': u'', u'brand': u'DARILONG', u'strength_3': u'', u'company': u'Sun', u'unit': u'mg'}

-- line #11236
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'7,5', u'strength_2': u'', u'substance': u'DARIFENACIN HBR', u'always_empty': u'', u'form': u'', u'brand': u'DARILONG', u'strength_3': u'', u'company': u'Sun', u'unit': u'mg'}

-- line #11237
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAUNOTEC 20 (Cipla)',
	'DAUNORUBICIN',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAUNOTEC 20 (Cipla)'
);

-- line #11238
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAUNOBIN 20 (Oncomed)',
	'Daunorubicin Hcl.',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAUNOBIN 20 (Oncomed)'
);

-- line #11239
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAUNOCIN 20 (Vhb)',
	'Daunorubicin Hcl.',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAUNOCIN 20 (Vhb)'
);

-- line #11240
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAUNOMYCIN 20 (Pharmacia)',
	'Daunorubicin Hcl.',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAUNOMYCIN 20 (Pharmacia)'
);

-- line #11241
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAUNOSIDE 20 (CH.Bhagat)',
	'Daunorubicin Hcl.',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAUNOSIDE 20 (CH.Bhagat)'
);

-- line #11242
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORUBIN 20 (Cadila Ph.)',
	'Daunorubicin',
	'VIAL',
	gm.nullify_empty_string('20')::numeric,
	'mg(+MANNITOL 200'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORUBIN 20 (Cadila Ph.)'
);

-- line #11243
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'DECA PEPTIDE', u'always_empty': u'', u'form': u'CRM', u'brand': u'LUMIXYL BRIGHTENING', u'strength_3': u'', u'company': u'THEMIS MEDICARE', u'unit': u''}

-- line #11244
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2', u'strength_2': u'', u'substance': u'DECA PEPTIDE', u'always_empty': u'', u'form': u'', u'brand': u'MELBACK', u'strength_3': u'', u'company': u'U S V', u'unit': u'mg'}

-- line #11245
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELGAIN 2 (Alkem)',
	'DECA-PEPTIDE',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELGAIN 2 (Alkem)'
);

-- line #11246
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELGAIN 5 (Alkem)',
	'DECA-PEPTIDE',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELGAIN 5 (Alkem)'
);

-- line #11247
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELGAIN 2 (ISSAR PH.)',
	'DECA-PEPTIDE',
	'LIQ',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELGAIN 2 (ISSAR PH.)'
);

-- line #11248
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEFRIJET 250 (Sun)',
	'DEFERASIROX',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEFRIJET 250 (Sun)'
);

-- line #11249
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEFRIJET 500 (Sun)',
	'DEFERASIROX',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEFRIJET 500 (Sun)'
);

-- line #11250
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DESIROX 250 (Cipla)',
	'DEFERASIROX',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DESIROX 250 (Cipla)'
);

-- line #11251
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DESIROX 500 (Cipla)',
	'DEFERASIROX',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DESIROX 500 (Cipla)'
);

-- line #11252
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KELFER 250 (Cipla)',
	'DEFERIPRONE',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KELFER 250 (Cipla)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KELFER 500 (Cipla)',
	'DEFERIPRONE',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KELFER 500 (Cipla)'
);

-- line #11253
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASTERIDE 30 (Dr.Reddy''S)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASTERIDE 30 (Dr.Reddy''S)'
);

-- line #11254
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASTERIDE 6 (Dr.Reddy''S)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASTERIDE 6 (Dr.Reddy''S)'
);

-- line #11255
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAFLACORT 1 (RESPIRATORY)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAFLACORT 1 (RESPIRATORY)'
);

-- line #11256
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAFLACORT 30 (RESPIRATORY)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAFLACORT 30 (RESPIRATORY)'
);

-- line #11257
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAFLACORT 6 (RESPIRATORY)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAFLACORT 6 (RESPIRATORY)'
);

-- line #11258
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORDEF 30 (BIOMAX BIO.)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORDEF 30 (BIOMAX BIO.)'
);

-- line #11259
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORDEF 6 (BIOMAX BIO.)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORDEF 6 (BIOMAX BIO.)'
);

-- line #11260
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORTACE-6 6 (SHREE BALAJI PH.)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORTACE-6 6 (SHREE BALAJI PH.)'
);

-- line #11261
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'DEFLAZACORT', u'always_empty': u'', u'form': u'TAB', u'brand': u'CORTACE-6', u'strength_3': u'', u'company': u'SHREE BALAJI PH.', u'unit': u''}

-- line #11262
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORTIFLAZ 30 (ERIS LIFE)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORTIFLAZ 30 (ERIS LIFE)'
);

-- line #11263
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORTIFLAZ 6 (ERIS LIFE)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORTIFLAZ 6 (ERIS LIFE)'
);

-- line #11264
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORTIMAX 6 (Zuventus)',
	'DEFLAZACORT',
	'SUS',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORTIMAX 6 (Zuventus)'
);

-- line #11265
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORTIMAX 1 (Zuventus)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORTIMAX 1 (Zuventus)'
);

-- line #11266
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORTIMAX 24 (Zuventus)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('24')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORTIMAX 24 (Zuventus)'
);

-- line #11267
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORTIMAX 30 (Zuventus)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORTIMAX 30 (Zuventus)'
);

-- line #11268
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORTIMAX 6 (Zuventus)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORTIMAX 6 (Zuventus)'
);

-- line #11269
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORTISURE 1 (Alembic)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORTISURE 1 (Alembic)'
);

-- line #11270
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORTISURE 6 (Alembic)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORTISURE 6 (Alembic)'
);

-- line #11271
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORTIZA 6 (STAUNCH)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORTIZA 6 (STAUNCH)'
);

-- line #11272
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECOTAZ 30 (Intas)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECOTAZ 30 (Intas)'
);

-- line #11273
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECOTAZ 6 (Intas)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECOTAZ 6 (Intas)'
);

-- line #11274
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEEF-6 6 (BIOKIND HC.)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEEF-6 6 (BIOKIND HC.)'
);

-- line #11275
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEFCORT 6 (Macleods)',
	'DEFLAZACORT',
	'ORAL SUS',
	gm.nullify_empty_string('6')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEFCORT 6 (Macleods)'
);

-- line #11276
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEFCORT 18 (Macleods)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('18')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEFCORT 18 (Macleods)'
);

-- line #11277
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEFCORT 24 (Macleods)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('24')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEFCORT 24 (Macleods)'
);

-- line #11278
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEFGLU 6 (NEISS)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEFGLU 6 (NEISS)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEFGLU 30 (NEISS)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEFGLU 30 (NEISS)'
);

-- line #11279
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEFLACHEK 6 (Indoco Rem.)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEFLACHEK 6 (Indoco Rem.)'
);

-- line #11280
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEFLAFIT 30 (Intas)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEFLAFIT 30 (Intas)'
);

-- line #11281
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEFLAFIT 6 (Intas)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEFLAFIT 6 (Intas)'
);

-- line #11282
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEFLASTAR 6 (STARTOS)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEFLASTAR 6 (STARTOS)'
);

-- line #11283
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEFLAZEN 30 (Torrent)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEFLAZEN 30 (Torrent)'
);

-- line #11284
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEFLAZEN 6 (Torrent)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEFLAZEN 6 (Torrent)'
);

-- line #11285
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEFLAZ 1 (Intas)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEFLAZ 1 (Intas)'
);

-- line #11286
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEFLAZ 30 (Intas)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEFLAZ 30 (Intas)'
);

-- line #11287
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEFLAZ 6 (Intas)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEFLAZ 6 (Intas)'
);

-- line #11288
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'6', u'strength_2': u'', u'substance': u'DEFLAZACORT', u'always_empty': u'', u'form': u'', u'brand': u'DEFLOMAC-6', u'strength_3': u'', u'company': u'MACWELL PH.', u'unit': u'mg'}

-- line #11289
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEFNALONE 6 (Lupin)',
	'DEFLAZACORT',
	'ORAL SUS',
	gm.nullify_empty_string('6')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEFNALONE 6 (Lupin)'
);

-- line #11290
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEFNALONE 1 (LUPIN)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEFNALONE 1 (LUPIN)'
);

-- line #11291
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEFNALONE 24 (Lupin)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('24')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEFNALONE 24 (Lupin)'
);

-- line #11292
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEFNALONE 30 (LUPIN)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEFNALONE 30 (LUPIN)'
);

-- line #11293
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEFNALONE 6 (LUPIN)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEFNALONE 6 (LUPIN)'
);

-- line #11294
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEFROY-6 6 (Royal)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEFROY-6 6 (Royal)'
);

-- line #11295
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEFSURE 6 (Emcure)',
	'DEFLAZACORT',
	'SUS',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEFSURE 6 (Emcure)'
);

-- line #11296
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEFSURE 1 (Emcure)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEFSURE 1 (Emcure)'
);

-- line #11297
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEFSURE 30 (Emcure)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEFSURE 30 (Emcure)'
);

-- line #11298
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEFSURE 6 (Emcure)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEFSURE 6 (Emcure)'
);

-- line #11299
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEFTECT 6 (Tripada BIO.)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEFTECT 6 (Tripada BIO.)'
);

-- line #11300
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEFZA 1 (Wallace)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEFZA 1 (Wallace)'
);

-- line #11301
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEFZA 30 (Wallace)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEFZA 30 (Wallace)'
);

-- line #11302
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEFZA 6 (Wallace)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEFZA 6 (Wallace)'
);

-- line #11303
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEFZONA 1 (ZYDUS SYNO.)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEFZONA 1 (ZYDUS SYNO.)'
);

-- line #11304
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEFZONA 6 (ZYDUS SYNO.)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEFZONA 6 (ZYDUS SYNO.)'
);

-- line #11305
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEZACOR 6 (Aristo)',
	'DEFLAZACORT',
	'SUSPENSION',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEZACOR 6 (Aristo)'
);

-- line #11306
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEZACOR 18 (Aristo)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('18')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEZACOR 18 (Aristo)'
);

-- line #11307
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEZACOR 1 (Aristo)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEZACOR 1 (Aristo)'
);

-- line #11308
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEZACOR 24 (Aristo)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('24')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEZACOR 24 (Aristo)'
);

-- line #11309
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEZACOR 30 (Aristo)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEZACOR 30 (Aristo)'
);

-- line #11310
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEZACOR 6 (Aristo)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEZACOR 6 (Aristo)'
);

-- line #11311
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEZERT 6 (ICARUS)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEZERT 6 (ICARUS)'
);

-- line #11312
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEZOCORT 6 (German R.)',
	'DEFLAZACORT',
	'SUS',
	gm.nullify_empty_string('6')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEZOCORT 6 (German R.)'
);

-- line #11313
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEZOCORT 6 (RESPICARE(GERMAN R.))',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEZOCORT 6 (RESPICARE(GERMAN R.))'
);

-- line #11314
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DFZ 1 (Ipca)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DFZ 1 (Ipca)'
);

-- line #11315
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DFZ 24 (Ipca)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('24')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DFZ 24 (Ipca)'
);

-- line #11316
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DFZ 30 (Ipca)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DFZ 30 (Ipca)'
);

-- line #11317
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DFZ 6 (Ipca)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DFZ 6 (Ipca)'
);

-- line #11318
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'D-INFLA 6 (WANBURY)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'D-INFLA 6 (WANBURY)'
);

-- line #11319
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUCORT 6 (ZENON HC.)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUCORT 6 (ZENON HC.)'
);

-- line #11320
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'6', u'strength_2': u'', u'substance': u'DEFLAZACORT', u'always_empty': u'', u'form': u'', u'brand': u'DZSPIN-6', u'strength_3': u'', u'company': u'Cerspin', u'unit': u'mg'}

-- line #11321
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'24', u'strength_2': u'', u'substance': u'DEFLAZACORT', u'always_empty': u'', u'form': u'', u'brand': u'ELDOCORT', u'strength_3': u'', u'company': u'Elder', u'unit': u'mg'}

-- line #11322
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'30', u'strength_2': u'', u'substance': u'DEFLAZACORT', u'always_empty': u'', u'form': u'', u'brand': u'ELDOCORT', u'strength_3': u'', u'company': u'Elder', u'unit': u'mg'}

-- line #11323
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'6', u'strength_2': u'', u'substance': u'DEFLAZACORT', u'always_empty': u'', u'form': u'', u'brand': u'ELDOCORT', u'strength_3': u'', u'company': u'Elder', u'unit': u'mg'}

-- line #11324
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMSOLONE-D 6 (Medopharm)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMSOLONE-D 6 (Medopharm)'
);

-- line #11325
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMZACORT 6 (EMAR)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMZACORT 6 (EMAR)'
);

-- line #11326
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENZOCORT 6 (Alkem)',
	'DEFLAZACORT',
	'SUS',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENZOCORT 6 (Alkem)'
);

-- line #11327
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENZOCORT 24 (Alkem)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('24')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENZOCORT 24 (Alkem)'
);

-- line #11328
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENZOCORT 1 (Bergen)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENZOCORT 1 (Bergen)'
);

-- line #11329
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENZOCORT 30 (Bergen)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENZOCORT 30 (Bergen)'
);

-- line #11330
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENZOCORT 6 (Bergen)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENZOCORT 6 (Bergen)'
);

-- line #11331
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETICORT 6 (Franco I.)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETICORT 6 (Franco I.)'
);

-- line #11332
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOZAMIN 6 (MINOVA)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOZAMIN 6 (MINOVA)'
);

-- line #11333
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOZASTAR 6 (INVISION)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOZASTAR 6 (INVISION)'
);

-- line #11334
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAZA 6 (VILBERRY HC.)',
	'DEFLAZACORT',
	'ORAL SUS',
	gm.nullify_empty_string('6')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAZA 6 (VILBERRY HC.)'
);

-- line #11335
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAZA 30 (VILBERRY HC.)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAZA 30 (VILBERRY HC.)'
);

-- line #11336
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1', u'strength_2': u'', u'substance': u'DEFLAZACORT', u'always_empty': u'', u'form': u'', u'brand': u'LAZA', u'strength_3': u'', u'company': u'VILBERRY HC.', u'unit': u'mg'}

-- line #11337
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'6', u'strength_2': u'', u'substance': u'DEFLAZACORT', u'always_empty': u'', u'form': u'', u'brand': u'LAZA', u'strength_3': u'', u'company': u'VILBERRY HC.', u'unit': u'mg'}

-- line #11338
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAHACORT 6 (Mankind)',
	'DEFLAZACORT',
	'DZ SUSP',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAHACORT 6 (Mankind)'
);

-- line #11339
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAHACORT 1 (Mankind)',
	'DEFLAZACORT',
	'DZ TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAHACORT 1 (Mankind)'
);

-- line #11340
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAHACORT 30 (Mankind)',
	'DEFLAZACORT',
	'DZ TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAHACORT 30 (Mankind)'
);

-- line #11341
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAHACORT 6 (Mankind)',
	'DEFLAZACORT',
	'DZ TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAHACORT 6 (Mankind)'
);

-- line #11342
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MDCORT 6 (MDC PHARMA)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'30'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MDCORT 6 (MDC PHARMA)'
);

-- line #11343
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NESTACORT 6 (Cipla)',
	'DEFLAZACORT',
	'ORAL SUSP',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NESTACORT 6 (Cipla)'
);

-- line #11344
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NESTACORT 30 (Cipla)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NESTACORT 30 (Cipla)'
);

-- line #11345
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NESTACORT 6 (Cipla)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NESTACORT 6 (Cipla)'
);

-- line #11346
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEW PREMISOL 30 (MOLEKULE)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEW PREMISOL 30 (MOLEKULE)'
);

-- line #11347
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEW PREMISOL 6 (MOLEKULE)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEW PREMISOL 6 (MOLEKULE)'
);

-- line #11348
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORTHOCORT 12 (Macleods)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('12')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORTHOCORT 12 (Macleods)'
);

-- line #11349
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORTHOCORT 18 (Macleods)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('18')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORTHOCORT 18 (Macleods)'
);

-- line #11350
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORTHOCORT 24 (Macleods)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('24')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORTHOCORT 24 (Macleods)'
);

-- line #11351
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORTHOCORT 6 (Macleods)',
	'DEFLAZACORT',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORTHOCORT 6 (Macleods)'
);

-- line #11352
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEHYDROEMETINE 30 (Piramal Hc.)',
	'Dehydroemetine Hcl.',
	'INJ',
	gm.nullify_empty_string('30')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEHYDROEMETINE 30 (Piramal Hc.)'
);

-- line #11353
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEHYDROEMETINE 10 (Piramal Hc.)',
	'Dehydroemetine Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEHYDROEMETINE 10 (Piramal Hc.)'
);

-- line #11354
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OVIGEN-D 25 (Alembic)',
	'DEHYDROEPIANDROSTERONE',
	'CAP',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OVIGEN-D 25 (Alembic)'
);

-- line #11355
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APIDOX 100 (ALICON PH.)',
	'Demeclocycline Hcl.',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APIDOX 100 (ALICON PH.)'
);

-- line #11356
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOX-M 100 (Moraceae)',
	'Demeclocycline Hcl.',
	'DT TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOX-M 100 (Moraceae)'
);

-- line #11357
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEDERMYCIN 150 (Wyeth)',
	'Demeclocycline Hcl.',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEDERMYCIN 150 (Wyeth)'
);

-- line #11358
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEDERMYCIN 300 (Wyeth)',
	'Demeclocycline Hcl.',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEDERMYCIN 300 (Wyeth)'
);

-- line #11359
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Denture Adhesions', u'always_empty': u'', u'form': u'CRM', u'brand': u'FITTYDENT', u'strength_3': u'', u'company': u"Dr.Reddy''S", u'unit': u''}

-- line #11360
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Denture Adhesions', u'always_empty': u'', u'form': u'', u'brand': u'FITTYDENT CUSHIONS', u'strength_3': u'', u'company': u'Group Ph.', u'unit': u''}

-- line #11361
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Denture Adhesions', u'always_empty': u'', u'form': u'', u'brand': u'FITTYDENT POD', u'strength_3': u'', u'company': u"Dr.Reddy''S", u'unit': u''}

-- line #11362
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Denture Adhesions', u'always_empty': u'', u'form': u'TABLETS', u'brand': u'FITTYDENT', u'strength_3': u'', u'company': u'Group Ph.', u'unit': u''}

-- line #11363
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPO-PROGESTIN 150 (DKT I.)',
	'Depo Medroxyprogesterone Acetate',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPO-PROGESTIN 150 (DKT I.)'
);

-- line #11364
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPO-PROVERA 150 (Pharmacia)',
	'Depo Medroxyprogesterone Acetate',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPO-PROVERA 150 (Pharmacia)'
);

-- line #11365
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Depo Medroxyprogesterone Acetate', u'always_empty': u'', u'form': u'TAB', u'brand': u'DUB', u'strength_3': u'', u'company': u'Unicure', u'unit': u''}

-- line #11366
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYONE DEPOT 150 (Sun)',
	'Depo Medroxyprogesterone Acetate',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYONE DEPOT 150 (Sun)'
);

-- line #11367
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PETOGEN 150 (HIND. LATEX)',
	'Depo Medroxyprogesterone Acetate',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PETOGEN 150 (HIND. LATEX)'
);

-- line #11368
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEQUADIN 0.25 (Gsk)',
	'Dequalinium Chl.',
	'LOZ',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEQUADIN 0.25 (Gsk)'
);

-- line #11369
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,5', u'strength_2': u'', u'substance': u'Dequalinium Chl.', u'always_empty': u'', u'form': u'', u'brand': u'DEQUADIN MOUTHPAINT', u'strength_3': u'', u'company': u'Allenburys', u'unit': u'%'}

-- line #11370
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'15', u'strength_2': u'', u'substance': u'DERIFENACIN', u'always_empty': u'', u'form': u'', u'brand': u'DERITAS', u'strength_3': u'', u'company': u'Intas', u'unit': u'mg'}

-- line #11371
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'7,5', u'strength_2': u'', u'substance': u'DERIFENACIN', u'always_empty': u'', u'form': u'', u'brand': u'DERITAS', u'strength_3': u'', u'company': u'Intas', u'unit': u'mg'}

-- line #11372
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50IU.', u'strength_2': u'', u'substance': u'Desamino Oxytocin', u'always_empty': u'', u'form': u'TAB IU INJ', u'brand': u'BUCTOCIN', u'strength_3': u'', u'company': u'Wanbury', u'unit': u''}

-- line #11373
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DESFERAL 500 (Novartis)',
	'Desferrioxamine',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DESFERAL 500 (Novartis)'
);

-- line #11374
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALERDAIN 5 (Ordain Hc.)',
	'Desloratadine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALERDAIN 5 (Ordain Hc.)'
);

-- line #11375
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALLERDE 5 (EAST WEST)',
	'Desloratadine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALLERDE 5 (EAST WEST)'
);

-- line #11376
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALLEREDE 5 (EAST WEST)',
	'Desloratadine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALLEREDE 5 (EAST WEST)'
);

-- line #11377
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALLERGESIC 5 (Meridian)',
	'Desloratadine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALLERGESIC 5 (Meridian)'
);

-- line #11378
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAZIT 5 (Sun)',
	'Desloratadine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAZIT 5 (Sun)'
);

-- line #11379
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DELORTA 5 (Nicholas)',
	'Desloratadine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DELORTA 5 (Nicholas)'
);

-- line #11380
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DELOTID 5 (Dwd)',
	'Desloratadine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DELOTID 5 (Dwd)'
);

-- line #11381
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DESCARE 5 (Azime Hc.)',
	'Desloratadine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DESCARE 5 (Azime Hc.)'
);

-- line #11382
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DES CURE 5 (CURE N CURE)',
	'Desloratadine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DES CURE 5 (CURE N CURE)'
);

-- line #11383
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DESENT 5 (Indoco Rem.)',
	'Desloratadine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DESENT 5 (Indoco Rem.)'
);

-- line #11384
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DESLOR 5 (Solares (Sun))',
	'Desloratadine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DESLOR 5 (Solares (Sun))'
);

-- line #11385
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DESNOVA 5 (Morepen)',
	'Desloratadine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DESNOVA 5 (Morepen)'
);

-- line #11386
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DES 5 (Le Sante)',
	'Desloratadine',
	'OD TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DES 5 (Le Sante)'
);

-- line #11387
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEXLY 5 (HETERO HC.)',
	'Desloratadine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEXLY 5 (HETERO HC.)'
);

-- line #11388
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILORA 5 (Intra(INVISION))',
	'Desloratadine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILORA 5 (Intra(INVISION))'
);

-- line #11389
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'D-LORATIN 5 (Protec)',
	'Desloratadine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'D-LORATIN 5 (Protec)'
);

-- line #11390
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'D-LORDEX 5 (Ind-Swift)',
	'Desloratadine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'D-LORDEX 5 (Ind-Swift)'
);

-- line #11391
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYL 5 (Ajanta Ph.)',
	'Desloratadine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYL 5 (Ajanta Ph.)'
);

-- line #11392
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2,5', u'strength_2': u'', u'substance': u'Desloratadine', u'always_empty': u'', u'form': u'', u'brand': u'ELORA ODT', u'strength_3': u'', u'company': u'DELVIN', u'unit': u'mg'}

-- line #11393
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5', u'strength_2': u'', u'substance': u'Desloratadine', u'always_empty': u'', u'form': u'', u'brand': u'ELORA ODT', u'strength_3': u'', u'company': u'DELVIN', u'unit': u'mg'}

-- line #11394
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORDAY 5 (Cosme Hc.)',
	'Desloratadine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORDAY 5 (Cosme Hc.)'
);

-- line #11395
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORETA 5 (Zuventus)',
	'Desloratadine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORETA 5 (Zuventus)'
);

-- line #11396
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LTCET 5 (KIVI LABS)',
	'Desloratadine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LTCET 5 (KIVI LABS)'
);

-- line #11397
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NELORA-5 5 (Ochoa)',
	'Desloratadine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NELORA-5 5 (Ochoa)'
);

-- line #11398
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5', u'strength_2': u'', u'substance': u'Desloratadine', u'always_empty': u'', u'form': u'', u'brand': u'NEOLORIDIN RAPITAB', u'strength_3': u'', u'company': u'Zydus Cadila', u'unit': u'mg'}

-- line #11399
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOLORIDIN 5 (Zydus Cadila)',
	'Desloratadine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOLORIDIN 5 (Zydus Cadila)'
);

-- line #11400
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUCOPE 5 (Mankind)',
	'Desloratadine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUCOPE 5 (Mankind)'
);

-- line #11401
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OTRIVIN-ALERT 5 (Novartis)',
	'Desloratadine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OTRIVIN-ALERT 5 (Novartis)'
);

-- line #11402
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,1', u'strength_2': u'0,2', u'substance': u'Desmopressin', u'always_empty': u'', u'form': u'SPRAY', u'brand': u'ADIURETIN', u'strength_3': u'', u'company': u'Stancare', u'unit': u''}

-- line #11403
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADIURETIN 0.1 (Stancare)',
	'Desmopressin',
	'TAB',
	gm.nullify_empty_string('0.1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADIURETIN 0.1 (Stancare)'
);

-- line #11404
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADIURETIN 0.2 (Stancare)',
	'Desmopressin',
	'TAB',
	gm.nullify_empty_string('0.2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADIURETIN 0.2 (Stancare)'
);

-- line #11405
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1MCG', u'strength_2': u'ML', u'substance': u'Desmopressin', u'always_empty': u'', u'form': u'NASAL SPRAY', u'brand': u'D-VOID', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #11406
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'4MCG', u'strength_2': u'ML', u'substance': u'Desmopressin', u'always_empty': u'', u'form': u'INJ', u'brand': u'MINIRIN', u'strength_3': u'', u'company': u'Ferring Ph.', u'unit': u''}

-- line #11407
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250MCG(ACETATE TRIHYDR.)', u'strength_2': u'', u'substance': u'Desmopressin', u'always_empty': u'', u'form': u'SPRAY', u'brand': u'MINIRIN', u'strength_3': u'', u'company': u'Ferring Ph.', u'unit': u''}

-- line #11408
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MINIRIN 0.1 (Ferring Ph.)',
	'Desmopressin',
	'TAB',
	gm.nullify_empty_string('0.1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MINIRIN 0.1 (Ferring Ph.)'
);

-- line #11409
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MINIRIN 0.2 (FERRING PH.)',
	'Desmopressin',
	'TAB',
	gm.nullify_empty_string('0.2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MINIRIN 0.2 (FERRING PH.)'
);

-- line #11410
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75MCG', u'strength_2': u'', u'substance': u'Desogestrol', u'always_empty': u'', u'form': u'TAB', u'brand': u'DESOGEST', u'strength_3': u'', u'company': u'HIND. LATEX', u'unit': u''}

-- line #11411
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATONIDE 0.05 (CURATIO HC.)',
	'Desonide',
	'GEL',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATONIDE 0.05 (CURATIO HC.)'
);

-- line #11412
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DESOWEN 0.05 (Galderma)',
	'Desonide',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DESOWEN 0.05 (Galderma)'
);

-- line #11413
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DESOWEN 0.05 (Galderma)',
	'Desonide',
	'LOT',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DESOWEN 0.05 (Galderma)'
);

-- line #11414
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DENLAFAX 100 (Emcure)',
	'DESVENLAFAXINE',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DENLAFAX 100 (Emcure)'
);

-- line #11415
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DENLAFAX 50 (Emcure)',
	'DESVENLAFAXINE',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DENLAFAX 50 (Emcure)'
);

-- line #11416
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DESNILA 100 (Lupin)',
	'DESVENLAFAXINE',
	'OD TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DESNILA 100 (Lupin)'
);

-- line #11417
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DESNILA 50 (Lupin)',
	'DESVENLAFAXINE',
	'OD TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DESNILA 50 (Lupin)'
);

-- line #11418
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MDD 100 (Piramal Hc.)',
	'DESVENLAFAXINE',
	'XR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MDD 100 (Piramal Hc.)'
);

-- line #11419
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MDD 50 (Piramal Hc.)',
	'DESVENLAFAXINE',
	'XR TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MDD 50 (Piramal Hc.)'
);

-- line #11420
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEWVEN 100 (Torrent)',
	'DESVENLAFAXINE',
	'OD TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEWVEN 100 (Torrent)'
);

-- line #11421
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEWVEN 50 (Torrent)',
	'DESVENLAFAXINE',
	'OD TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEWVEN 50 (Torrent)'
);

-- line #11422
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEXVENIA 50 (ALKEM)',
	'DESVENLAFAXINE',
	'OD TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEXVENIA 50 (ALKEM)'
);

-- line #11423
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEXVENLA 100 (ALKEM)',
	'DESVENLAFAXINE',
	'OD TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEXVENLA 100 (ALKEM)'
);

-- line #11424
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'FOR ASTHAMA INHALER', u'strength_2': u'', u'substance': u'DEVICE', u'always_empty': u'', u'form': u'', u'brand': u'MYHALER DEVICE', u'strength_3': u'', u'company': u'Macleods', u'unit': u''}

-- line #11425
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APRIDEX 4 (Indus)',
	'Dexamethasone',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg/ML(SOD.PHOS.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APRIDEX 4 (Indus)'
);

-- line #11426
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Dexamethasone', u'always_empty': u'', u'form': u'TAB', u'brand': u'BIODEXONE', u'strength_3': u'', u'company': u'Biochem', u'unit': u''}

-- line #11427
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORT 4 (Chemech)',
	'Dexamethasone',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORT 4 (Chemech)'
);

-- line #11428
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORT 0.5 (Chemech)',
	'Dexamethasone',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORT 0.5 (Chemech)'
);

-- line #11429
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Dexamethasone', u'always_empty': u'', u'form': u'INJ', u'brand': u'DAXAFIN', u'strength_3': u'', u'company': u'Finesse Ph.', u'unit': u''}

-- line #11430
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECA 1 (Merind)',
	'Dexamethasone',
	'F. TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECA 1 (Merind)'
);

-- line #11431
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECDAK 0.5 (Merind)',
	'Dexamethasone',
	'ST TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECDAK 0.5 (Merind)'
);

-- line #11432
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECDAK 5 (Merind)',
	'Dexamethasone',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECDAK 5 (Merind)'
);

-- line #11433
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECDAN 4 (Merind)',
	'Dexamethasone',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECDAN 4 (Merind)'
);

-- line #11434
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECDAN 0.5 (Merind)',
	'Dexamethasone',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECDAN 0.5 (Merind)'
);

-- line #11435
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECICORT 0.5 (Galpha)',
	'Dexamethasone',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg(PHOS.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECICORT 0.5 (Galpha)'
);

-- line #11436
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECRINA 4 (Intra Lab)',
	'Dexamethasone',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECRINA 4 (Intra Lab)'
);

-- line #11437
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEDRON 4 (Sanjivani)',
	'Dexamethasone',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEDRON 4 (Sanjivani)'
);

-- line #11438
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEMISOL 4 (CADILA)',
	'Dexamethasone',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEMISOL 4 (CADILA)'
);

-- line #11439
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEMISONE 0.5 (Cadila Ph.)',
	'Dexamethasone',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEMISONE 0.5 (Cadila Ph.)'
);

-- line #11440
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEOSONE 4 (P C INDIA)',
	'Dexamethasone',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEOSONE 4 (P C INDIA)'
);

-- line #11441
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEXACIP 0.1 (Cipla)',
	'Dexamethasone',
	'EYE DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEXACIP 0.1 (Cipla)'
);

-- line #11442
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEXACIP 4 (Cipla)',
	'Dexamethasone',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEXACIP 4 (Cipla)'
);

-- line #11443
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEXACIP 0.5 (Cipla)',
	'Dexamethasone',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEXACIP 0.5 (Cipla)'
);

-- line #11444
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEXAGEN 4 (GENESIS ORG.)',
	'Dexamethasone',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEXAGEN 4 (GENESIS ORG.)'
);

-- line #11445
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEXAGEN 8 (GENESIS ORG.)',
	'Dexamethasone',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEXAGEN 8 (GENESIS ORG.)'
);

-- line #11446
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEXA-G 4 (Graf Lab.)',
	'Dexamethasone',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEXA-G 4 (Graf Lab.)'
);

-- line #11447
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEXAMAG 0.5 (Shalaks)',
	'Dexamethasone',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEXAMAG 0.5 (Shalaks)'
);

-- line #11448
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEXAMETHASONE 8 (Sanjivani)',
	'Dexamethasone',
	'INJ',
	gm.nullify_empty_string('8')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEXAMETHASONE 8 (Sanjivani)'
);

-- line #11449
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEXAMETHASONE 0.5 (Sanjivani)',
	'Dexamethasone',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEXAMETHASONE 0.5 (Sanjivani)'
);

-- line #11450
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEXAMINE 0.5 (BARODA)',
	'Dexamethasone',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEXAMINE 0.5 (BARODA)'
);

-- line #11451
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEXANE 4 (Samarth)',
	'Dexamethasone',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEXANE 4 (Samarth)'
);

-- line #11452
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEXAR 4 (RASS HC.)',
	'Dexamethasone',
	'VIAL',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEXAR 4 (RASS HC.)'
);

-- line #11453
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEXASONE 4 (Cadila Ph.)',
	'Dexamethasone',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEXASONE 4 (Cadila Ph.)'
);

-- line #11454
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEXASONE 0.5 (Cadila Ph.)',
	'Dexamethasone',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEXASONE 0.5 (Cadila Ph.)'
);

-- line #11455
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEXIM 4 (Ophthal R.)',
	'Dexamethasone',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEXIM 4 (Ophthal R.)'
);

-- line #11456
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEXINGA 0.5 (Inga)',
	'Dexamethasone',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEXINGA 0.5 (Inga)'
);

-- line #11457
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEX 4 (NEON)',
	'Dexamethasone',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEX 4 (NEON)'
);

-- line #11458
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEXONA 0.5 (Zydus Cadila)',
	'Dexamethasone',
	'DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEXONA 0.5 (Zydus Cadila)'
);

-- line #11459
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEXONA 20 (Zydus Cadila)',
	'Dexamethasone',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEXONA 20 (Zydus Cadila)'
);

-- line #11460
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEXONA 4 (Zydus Cadila)',
	'Dexamethasone',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEXONA 4 (Zydus Cadila)'
);

-- line #11461
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEXONA 0.5 (Zydus Cadila)',
	'Dexamethasone',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEXONA 0.5 (Zydus Cadila)'
);

-- line #11462
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Dexamethasone', u'always_empty': u'', u'form': u'INJ', u'brand': u'DEXONE', u'strength_3': u'', u'company': u'SANCHEZ LAB.', u'unit': u''}

-- line #11463
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEX-V 4 (VENSAT)',
	'Dexamethasone',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEX-V 4 (VENSAT)'
);

-- line #11464
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Dexamethasone', u'always_empty': u'', u'form': u'INJ', u'brand': u'DEXZY', u'strength_3': u'', u'company': u'Zee Lab', u'unit': u''}

-- line #11465
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVICORT 4 (DIVINE LAB.)',
	'Dexamethasone',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVICORT 4 (DIVINE LAB.)'
);

-- line #11466
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Dexamethasone', u'always_empty': u'', u'form': u'INJ', u'brand': u'FULDEX', u'strength_3': u'', u'company': u'Solitaire', u'unit': u''}

-- line #11467
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IDIZONE 4 (Idpl)',
	'Dexamethasone',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IDIZONE 4 (Idpl)'
);

-- line #11468
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IDIZONE 0.5 (Idpl)',
	'Dexamethasone',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IDIZONE 0.5 (Idpl)'
);

-- line #11469
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTRADEX 4 (Intra Lab)',
	'Dexamethasone',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTRADEX 4 (Intra Lab)'
);

-- line #11470
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGADEX 4 (B.M.Ph.)',
	'Dexamethasone',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGADEX 4 (B.M.Ph.)'
);

-- line #11471
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICRODEX 4 (Phytochem)',
	'Dexamethasone',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICRODEX 4 (Phytochem)'
);

-- line #11472
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Dexamethasone', u'always_empty': u'', u'form': u'EYE DPS', u'brand': u'MINIDEX', u'strength_3': u'', u'company': u'Optho Rem.', u'unit': u''}

-- line #11473
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCIDEX 0.5 (Mac)',
	'Dexamethasone',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCIDEX 0.5 (Mac)'
);

-- line #11474
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PFIDEX 4 (Pfiscar Ind.)',
	'Dexamethasone',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PFIDEX 4 (Pfiscar Ind.)'
);

-- line #11475
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RADIX 4 (Radix Bio.)',
	'Dexamethasone',
	'DX INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RADIX 4 (Radix Bio.)'
);

-- line #11476
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Dexamethasone Sod.Phos.', u'always_empty': u'', u'form': u'INJ', u'brand': u'BEDEXA', u'strength_3': u'', u'company': u'Brooks Ph.', u'unit': u''}

-- line #11477
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECICORT 4 (Galpha)',
	'Dexamethasone Sod.Phos.',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECICORT 4 (Galpha)'
);

-- line #11478
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECOLITE 0.01 (Intas)',
	'Dexamethasone Sod.Phos.',
	'DPS',
	gm.nullify_empty_string('0.01')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECOLITE 0.01 (Intas)'
);

-- line #11479
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEXAJECT 4 (Sterfil)',
	'Dexamethasone Sod.Phos.',
	'VIAL',
	gm.nullify_empty_string('4')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEXAJECT 4 (Sterfil)'
);

-- line #11480
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEXALET 4 (Dynamic)',
	'Dexamethasone Sod.Phos.',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEXALET 4 (Dynamic)'
);

-- line #11481
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Dexamethasone Sod.Phos.', u'always_empty': u'', u'form': u'INJ', u'brand': u'DEXAM', u'strength_3': u'', u'company': u'Eg Ph.', u'unit': u''}

-- line #11482
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MINIDEX 0.01 (Optho Rem.)',
	'Dexamethasone Sod.Phos.',
	'DPS',
	gm.nullify_empty_string('0.01')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MINIDEX 0.01 (Optho Rem.)'
);

-- line #11483
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCUDEX 0.01 (Oscar Rem.)',
	'Dexamethasone Sod.Phos.',
	'EYE DPS',
	gm.nullify_empty_string('0.01')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCUDEX 0.01 (Oscar Rem.)'
);

-- line #11484
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAVICORT 4 (Ravian)',
	'Dexamethasone Sod.Phos.',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAVICORT 4 (Ravian)'
);

-- line #11485
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILLICORTENOL 0.1 (Novartis)',
	'Dexamethasone Trimethyl Acetate',
	'CRM',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILLICORTENOL 0.1 (Novartis)'
);

-- line #11486
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALDEX 2 (OREVA DARMO.)',
	'Dexchlorpheniramine Maleate',
	'SR TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALDEX 2 (OREVA DARMO.)'
);

-- line #11487
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENACOF 25 (TAJ PH.)',
	'Dexchlorpheniramine Maleate',
	'CAP',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENACOF 25 (TAJ PH.)'
);

-- line #11488
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORTIFLAM-D 2 (Bennet Ph.)',
	'Dexchlorpheniramine Maleate',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORTIFLAM-D 2 (Bennet Ph.)'
);

-- line #11489
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEXCPM 6 (Yash Ph.)',
	'Dexchlorpheniramine Maleate',
	'SR TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEXCPM 6 (Yash Ph.)'
);

-- line #11490
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEXODIL 6 (Pil)',
	'Dexchlorpheniramine Maleate',
	'SR TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEXODIL 6 (Pil)'
);

-- line #11491
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEXODIL 2 (Pil)',
	'Dexchlorpheniramine Maleate',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEXODIL 2 (Pil)'
);

-- line #11492
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEXZIM 6 (AXYZEN LIFE)',
	'Dexchlorpheniramine Maleate',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEXZIM 6 (AXYZEN LIFE)'
);

-- line #11493
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIOMINIC 6 (Unison)',
	'Dexchlorpheniramine Maleate',
	'SR TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIOMINIC 6 (Unison)'
);

-- line #11494
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIOMINIC 2 (Unison)',
	'Dexchlorpheniramine Maleate',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIOMINIC 2 (Unison)'
);

-- line #11495
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIOWIN 2 (Theo Ph.)',
	'Dexchlorpheniramine Maleate',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIOWIN 2 (Theo Ph.)'
);

-- line #11496
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOZ 6 (DAKSH)',
	'Dexchlorpheniramine Maleate',
	'SR TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOZ 6 (DAKSH)'
);

-- line #11497
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DPM-2 2 (BIOSCIENCES)',
	'Dexchlorpheniramine Maleate',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DPM-2 2 (BIOSCIENCES)'
);

-- line #11498
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HISLER-2 2 (Olcare)',
	'Dexchlorpheniramine Maleate',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HISLER-2 2 (Olcare)'
);

-- line #11499
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HISTADEX 2 (VIBRANT PH.)',
	'Dexchlorpheniramine Maleate',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HISTADEX 2 (VIBRANT PH.)'
);

-- line #11500
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'6', u'strength_2': u'', u'substance': u'Dexchlorpheniramine Maleate', u'always_empty': u'', u'form': u'', u'brand': u'POLARAMINE REPETAB', u'strength_3': u'', u'company': u'Fulford', u'unit': u'mg'}

-- line #11501
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POLARAMINE 0.5 (Fulford)',
	'Dexchlorpheniramine Maleate',
	'SYR',
	gm.nullify_empty_string('0.5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POLARAMINE 0.5 (Fulford)'
);

-- line #11502
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POLARAMINE 2 (Fulford)',
	'Dexchlorpheniramine Maleate',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POLARAMINE 2 (Fulford)'
);

-- line #11503
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POLOSTAN 2 (LIFESTAR)',
	'Dexchlorpheniramine Maleate',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POLOSTAN 2 (LIFESTAR)'
);

-- line #11504
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POLOSTAR 6 (LIFESTAR)',
	'Dexchlorpheniramine Maleate',
	'SR TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POLOSTAR 6 (LIFESTAR)'
);

-- line #11505
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRUTEK-200 200 (Zuventus)',
	'DEXIBUPROFEN',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRUTEK-200 200 (Zuventus)'
);

-- line #11506
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRUTEK-300 300 (Zuventus)',
	'DEXIBUPROFEN',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRUTEK-300 300 (Zuventus)'
);

-- line #11507
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRUTEK-400 400 (Zuventus)',
	'DEXIBUPROFEN',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRUTEK-400 400 (Zuventus)'
);

-- line #11508
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IBUDEX 300 (MEDLEY)',
	'DEXIBUPROFEN',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IBUDEX 300 (MEDLEY)'
);

-- line #11509
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IBUSOFT 300 (Emcure)',
	'DEXIBUPROFEN',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IBUSOFT 300 (Emcure)'
);

-- line #11510
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IBUSOFT 400 (Emcure)',
	'DEXIBUPROFEN',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IBUSOFT 400 (Emcure)'
);

-- line #11511
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLOSPAN 75 (Emcure)',
	'DEXKetoprofen',
	'OD TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLOSPAN 75 (Emcure)'
);

-- line #11512
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INFEN GM 12.5 (Emcure)',
	'DEXKetoprofen',
	'GEL',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INFEN GM 12.5 (Emcure)'
);

-- line #11513
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INFEN 25 (Emcure)',
	'DEXKetoprofen',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INFEN 25 (Emcure)'
);

-- line #11514
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INFEN 75 (Emcure)',
	'DEXKetoprofen',
	'OD TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INFEN 75 (Emcure)'
);

-- line #11515
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INFEN 12.5 (Emcure)',
	'DEXKetoprofen',
	'TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INFEN 12.5 (Emcure)'
);

-- line #11516
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INFEN 25 (Emcure)',
	'DEXKetoprofen',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INFEN 25 (Emcure)'
);

-- line #11517
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INFEN 50 (Emcure)',
	'DEXKetoprofen',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INFEN 50 (Emcure)'
);

-- line #11518
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PURON 12.5 (Zuventus)',
	'DEXKetoprofen',
	'GEL',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PURON 12.5 (Zuventus)'
);

-- line #11519
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PURON 25 (Zuventus)',
	'DEXKetoprofen',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PURON 25 (Zuventus)'
);

-- line #11520
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100MCG', u'strength_2': u'', u'substance': u'DEXMEDETOMIDINE', u'always_empty': u'', u'form': u'', u'brand': u'DEXDINE', u'strength_3': u'', u'company': u'Macleods', u'unit': u''}

-- line #11521
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100MCG', u'strength_2': u'', u'substance': u'DEXMEDETOMIDINE', u'always_empty': u'', u'form': u'INJ', u'brand': u'DEXELEX', u'strength_3': u'', u'company': u'Ranbaxy', u'unit': u''}

-- line #11522
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100MCG', u'strength_2': u'', u'substance': u'DEXMEDETOMIDINE', u'always_empty': u'', u'form': u'INJ', u'brand': u'DEXEM', u'strength_3': u'', u'company': u'THEMIS MEDICARE', u'unit': u''}

-- line #11523
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200MCG', u'strength_2': u'', u'substance': u'DEXMEDETOMIDINE', u'always_empty': u'', u'form': u'INJ', u'brand': u'DEXTOMID', u'strength_3': u'', u'company': u'Neon', u'unit': u''}

-- line #11524
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTHE 50 (Ajanta Ph.)',
	'DEXPANTHENOL',
	'GEL',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTHE 50 (Ajanta Ph.)'
);

-- line #11525
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEXICOOL 10 (Intra(INVISION))',
	'DEXRABEPRAZOLE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEXICOOL 10 (Intra(INVISION))'
);

-- line #11526
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEXPURE 5 (Emcure)',
	'DEXRABEPRAZOLE',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEXPURE 5 (Emcure)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEXPURE 10 (Emcure)',
	'DEXRABEPRAZOLE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEXPURE 10 (Emcure)'
);

-- line #11527
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'DEXRABEPRAZOLE', u'always_empty': u'', u'form': u'TAB', u'brand': u'DIRAB', u'strength_3': u'', u'company': u'HETERO HC.', u'unit': u''}

-- line #11528
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KYRAB 10 (J. & J.)',
	'DEXRABEPRAZOLE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KYRAB 10 (J. & J.)'
);

-- line #11529
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REPEPSA 10 (AKUMENTIS HC.)',
	'DEXRABEPRAZOLE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REPEPSA 10 (AKUMENTIS HC.)'
);

-- line #11530
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40 5D', u'strength_2': u'40NS', u'substance': u'DEXTRAN', u'always_empty': u'', u'form': u'INJ', u'brand': u'NIRTRAN D/NS', u'strength_3': u'', u'company': u'NIRLIFE HEALTH', u'unit': u''}

-- line #11531
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10', u'strength_2': u'', u'substance': u'DEXTRAN', u'always_empty': u'', u'form': u'', u'brand': u'RALLIDEX IN DEXTROSE', u'strength_3': u'', u'company': u'Shreya', u'unit': u'%W/V'}

-- line #11532
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALEX 10 (Glenmark)',
	'Dextromethorphan Hbr',
	'LOZENGE',
	gm.nullify_empty_string('10')::numeric,
	'100'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALEX 10 (Glenmark)'
);

-- line #11533
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHERICOF 5 (Stancare)',
	'Dextromethorphan Hbr',
	'LOZ',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHERICOF 5 (Stancare)'
);

-- line #11534
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHEROCOF 5 (Ranbaxy)',
	'Dextromethorphan Hbr',
	'LOZENGES',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHEROCOF 5 (Ranbaxy)'
);

-- line #11535
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEZEX 5 (Medico)',
	'Dextromethorphan Hbr',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEZEX 5 (Medico)'
);

-- line #11536
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LASTUSS-CT 10 (F D C)',
	'Dextromethorphan Hbr',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LASTUSS-CT 10 (F D C)'
);

-- line #11537
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LASTUSS 30 (F D C)',
	'Dextromethorphan Hbr',
	'LA SYR',
	gm.nullify_empty_string('30')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LASTUSS 30 (F D C)'
);

-- line #11538
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEXCOF COUGH 5 (Cipla)',
	'Dextromethorphan Hbr',
	'LOZ',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEXCOF COUGH 5 (Cipla)'
);

-- line #11539
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARVODEX 65 (Jagsonpal)',
	'Dextropropoxyphene Hcl.',
	'CAP',
	gm.nullify_empty_string('65')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARVODEX 65 (Jagsonpal)'
);

-- line #11540
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'10% DEXTROSE 10 (Albert D.)',
	'Dextrose',
	'INF',
	gm.nullify_empty_string('10')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '10% DEXTROSE 10 (Albert D.)'
);

-- line #11541
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'10% DEXTROSE 10 (Claris L.)',
	'Dextrose',
	'INF',
	gm.nullify_empty_string('10')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '10% DEXTROSE 10 (Claris L.)'
);

-- line #11542
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'10% DEXTROSE 10 (K.K.)',
	'Dextrose',
	'INF',
	gm.nullify_empty_string('10')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '10% DEXTROSE 10 (K.K.)'
);

-- line #11543
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'10% DEXTROSE 10 (Mount M.)',
	'Dextrose',
	'INF',
	gm.nullify_empty_string('10')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '10% DEXTROSE 10 (Mount M.)'
);

-- line #11544
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'10% DEXTROSE 10 (Parenteral)',
	'Dextrose',
	'INF',
	gm.nullify_empty_string('10')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '10% DEXTROSE 10 (Parenteral)'
);

-- line #11545
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'10% DEXTROSE 10 (TABLETS I.)',
	'Dextrose',
	'INF',
	gm.nullify_empty_string('10')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '10% DEXTROSE 10 (TABLETS I.)'
);

-- line #11546
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'20% DEXTROSE 20 (Albert D.)',
	'Dextrose',
	'INF',
	gm.nullify_empty_string('20')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '20% DEXTROSE 20 (Albert D.)'
);

-- line #11547
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'20% DEXTROSE 20 (K.K.)',
	'Dextrose',
	'INF',
	gm.nullify_empty_string('20')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '20% DEXTROSE 20 (K.K.)'
);

-- line #11548
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'20% DEXTROSE 20 (Mount M.)',
	'Dextrose',
	'INF',
	gm.nullify_empty_string('20')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '20% DEXTROSE 20 (Mount M.)'
);

-- line #11549
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'20% DEXTROSE 20 (Parenteral)',
	'Dextrose',
	'INF',
	gm.nullify_empty_string('20')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '20% DEXTROSE 20 (Parenteral)'
);

-- line #11550
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'25% DEXTROSE 25 (Albert D.)',
	'Dextrose',
	'INF',
	gm.nullify_empty_string('25')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '25% DEXTROSE 25 (Albert D.)'
);

-- line #11551
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'25% DEXTROSE 2.5 (Albert D.)',
	'Dextrose',
	'INF',
	gm.nullify_empty_string('2.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '25% DEXTROSE 2.5 (Albert D.)'
);

-- line #11552
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'25% DEXTROSE 25 (Claris L.)',
	'Dextrose',
	'INF',
	gm.nullify_empty_string('25')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '25% DEXTROSE 25 (Claris L.)'
);

-- line #11553
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'25% DEXTROSE 25 (K.K.)',
	'Dextrose',
	'INF',
	gm.nullify_empty_string('25')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '25% DEXTROSE 25 (K.K.)'
);

-- line #11554
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'25% DEXTROSE 2.5 (K.K.)',
	'Dextrose',
	'INF',
	gm.nullify_empty_string('2.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '25% DEXTROSE 2.5 (K.K.)'
);

-- line #11555
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'25% DEXTROSE 25 (Mount M.)',
	'Dextrose',
	'INF',
	gm.nullify_empty_string('25')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '25% DEXTROSE 25 (Mount M.)'
);

-- line #11556
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'25% DEXTROSE 25 (Parenteral)',
	'Dextrose',
	'INF',
	gm.nullify_empty_string('25')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '25% DEXTROSE 25 (Parenteral)'
);

-- line #11557
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'50% DEXTROSE 50 (Albert D.)',
	'Dextrose',
	'INF',
	gm.nullify_empty_string('50')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '50% DEXTROSE 50 (Albert D.)'
);

-- line #11558
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'50% DEXTROSE 50 (K.K.)',
	'Dextrose',
	'INF',
	gm.nullify_empty_string('50')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '50% DEXTROSE 50 (K.K.)'
);

-- line #11559
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'50% DEXTROSE 50 (Parenteral)',
	'Dextrose',
	'INF',
	gm.nullify_empty_string('50')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '50% DEXTROSE 50 (Parenteral)'
);

-- line #11560
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'5% DEXTROSE 5 (K.K.)',
	'Dextrose',
	'INF',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '5% DEXTROSE 5 (K.K.)'
);

-- line #11561
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'5% DEXTROSE 5 (Albert D.)',
	'Dextrose',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '5% DEXTROSE 5 (Albert D.)'
);

-- line #11562
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'5% DEXTROSE 5 (Claris L.)',
	'Dextrose',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '5% DEXTROSE 5 (Claris L.)'
);

-- line #11563
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'5% DEXTROSE 5 (Mount M.)',
	'Dextrose',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '5% DEXTROSE 5 (Mount M.)'
);

-- line #11564
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'5% DEXTROSE 5 (Parenteral)',
	'Dextrose',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '5% DEXTROSE 5 (Parenteral)'
);

-- line #11565
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'5% DEXTROSE 5 (TABLETS I.)',
	'Dextrose',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '5% DEXTROSE 5 (TABLETS I.)'
);

-- line #11566
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEXTROSE % 5 (TABLETS I.)',
	'Dextrose',
	'INF',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEXTROSE % 5 (TABLETS I.)'
);

-- line #11567
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEXTROSE 250 (Albert D.)',
	'Dextrose',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEXTROSE 250 (Albert D.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEXTROSE 500 (Albert D.)',
	'Dextrose',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEXTROSE 500 (Albert D.)'
);

-- line #11568
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALTOCERIN 50 (ACTO)',
	'DIACEREIN',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALTOCERIN 50 (ACTO)'
);

-- line #11569
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANCE 50 (Zee Lab)',
	'DIACEREIN',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANCE 50 (Zee Lab)'
);

-- line #11570
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARILEX 50 (Alembic)',
	'DIACEREIN',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARILEX 50 (Alembic)'
);

-- line #11571
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARITMAX 50 (Lekar)',
	'DIACEREIN',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARITMAX 50 (Lekar)'
);

-- line #11572
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARTEED 50 (Cadex Lab)',
	'DIACEREIN',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARTEED 50 (Cadex Lab)'
);

-- line #11573
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARTHOCERIN 50 (Pulse Ph.)',
	'DIACEREIN',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARTHOCERIN 50 (Pulse Ph.)'
);

-- line #11574
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARTHROMUV 50 (Aristo)',
	'DIACEREIN',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARTHROMUV 50 (Aristo)'
);

-- line #11575
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'DIACEREIN', u'always_empty': u'', u'form': u'CAP', u'brand': u'ARTHROMUV', u'strength_3': u'', u'company': u'Aristo', u'unit': u''}

-- line #11576
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARTICARE 50 (AUSTER)',
	'DIACEREIN',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARTICARE 50 (AUSTER)'
);

-- line #11577
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARTIFIT 50 (F D C)',
	'DIACEREIN',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARTIFIT 50 (F D C)'
);

-- line #11578
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARTRODAR 50 (Elder)',
	'DIACEREIN',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARTRODAR 50 (Elder)'
);

-- line #11579
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXYRIN 50 (AXYZEN LIFE)',
	'DIACEREIN',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXYRIN 50 (AXYZEN LIFE)'
);

-- line #11580
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARTIDIN 50 (Croslands)',
	'DIACEREIN',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARTIDIN 50 (Croslands)'
);

-- line #11581
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARTIEL-D 50 (Obsurge)',
	'DIACEREIN',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARTIEL-D 50 (Obsurge)'
);

-- line #11582
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARTIGARD 50 (Helios Ph.)',
	'DIACEREIN',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARTIGARD 50 (Helios Ph.)'
);

-- line #11583
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARTIZ 50 (Ritz Ph.)',
	'DIACEREIN',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARTIZ 50 (Ritz Ph.)'
);

-- line #11584
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARTRODAR 50 (Elder)',
	'DIACEREIN',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARTRODAR 50 (Elder)'
);

-- line #11585
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEDIA 50 (INVISION)',
	'DIACEREIN',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEDIA 50 (INVISION)'
);

-- line #11586
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CERIN 50 (MOLEKULE)',
	'DIACEREIN',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CERIN 50 (MOLEKULE)'
);

-- line #11587
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DALET 50 (D.R.John''S)',
	'DIACEREIN',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DALET 50 (D.R.John''S)'
);

-- line #11588
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DCR 50 (MOLEKULE)',
	'DIACEREIN',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DCR 50 (MOLEKULE)'
);

-- line #11589
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIACER 50 (IRM PH.)',
	'DIACEREIN',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIACER 50 (IRM PH.)'
);

-- line #11590
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIACERON 50 (Cosme F.)',
	'DIACEREIN',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIACERON 50 (Cosme F.)'
);

-- line #11591
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIADOL 50 (CHEMO HC.)',
	'DIACEREIN',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIADOL 50 (CHEMO HC.)'
);

-- line #11592
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIAJOINT 50 (Meyer Org.)',
	'DIACEREIN',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIAJOINT 50 (Meyer Org.)'
);

-- line #11593
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIASOL 50 (IPCA LAB.)',
	'DIACEREIN',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIASOL 50 (IPCA LAB.)'
);

-- line #11594
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIASTEN 50 (Unichem (SP.DIV.))',
	'DIACEREIN',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIASTEN 50 (Unichem (SP.DIV.))'
);

-- line #11595
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICIMAX 50 (Biomax Lab)',
	'DIACEREIN',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICIMAX 50 (Biomax Lab)'
);

-- line #11596
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIEZ 50 (LAKSUN)',
	'DIACEREIN',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIEZ 50 (LAKSUN)'
);

-- line #11597
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIOSTEO 50 (Indoco Rem.)',
	'DIACEREIN',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIOSTEO 50 (Indoco Rem.)'
);

-- line #11598
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DISKARE 50 (ANKARE)',
	'DIACEREIN',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DISKARE 50 (ANKARE)'
);

-- line #11599
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DJC 50 (Systopic)',
	'DIACEREIN',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DJC 50 (Systopic)'
);

-- line #11600
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DURAJOINT 50 (Piramal Hc.)',
	'DIACEREIN',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DURAJOINT 50 (Piramal Hc.)'
);

-- line #11601
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYCERIN 50 (Glenmark)',
	'DIACEREIN',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYCERIN 50 (Glenmark)'
);

-- line #11602
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELTRODAR 50 (Elder)',
	'DIACEREIN',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELTRODAR 50 (Elder)'
);

-- line #11603
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLEXIBEL-D 50 (BLUBELL)',
	'DIACEREIN',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLEXIBEL-D 50 (BLUBELL)'
);

-- line #11604
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLEXTOR 50 (Aksigen Hosp.)',
	'DIACEREIN',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLEXTOR 50 (Aksigen Hosp.)'
);

-- line #11605
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEM CERIN 50 (Bergen)',
	'DIACEREIN',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEM CERIN 50 (Bergen)'
);

-- line #11606
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GUDCERIN 50 (Mankind)',
	'DIACEREIN',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GUDCERIN 50 (Mankind)'
);

-- line #11607
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HILIN 50 (DR. REDDY''S)',
	'DIACEREIN',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HILIN 50 (DR. REDDY''S)'
);

-- line #11608
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ICERIN 50 (Intra Lab)',
	'DIACEREIN',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ICERIN 50 (Intra Lab)'
);

-- line #11609
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JAIZZY 50 (AAMORB)',
	'DIACEREIN',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JAIZZY 50 (AAMORB)'
);

-- line #11610
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JOINCERIN 50 (TORRENT)',
	'DIACEREIN',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JOINCERIN 50 (TORRENT)'
);

-- line #11611
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KONDRO CERIN 50 (Panacea)',
	'DIACEREIN',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KONDRO CERIN 50 (Panacea)'
);

-- line #11612
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUCERIN 50 (Novagen Ph.)',
	'DIACEREIN',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUCERIN 50 (Novagen Ph.)'
);

-- line #11613
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORCERIN 50 (Macleods)',
	'DIACEREIN',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORCERIN 50 (Macleods)'
);

-- line #11614
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50', u'strength_2': u'', u'substance': u'DIACEREIN', u'always_empty': u'', u'form': u'', u'brand': u'OSTAN', u'strength_3': u'', u'company': u'Deccan', u'unit': u'mg'}

-- line #11615
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSTEASE 50 (SVIZERA HC.)',
	'DIACEREIN',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSTEASE 50 (SVIZERA HC.)'
);

-- line #11616
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSTEOCERIN 50 (Wanbury)',
	'DIACEREIN',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSTEOCERIN 50 (Wanbury)'
);

-- line #11617
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSTICER 50 (Sanat)',
	'DIACEREIN',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSTICER 50 (Sanat)'
);

-- line #11618
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSTOCERIN 50 (Medopharm)',
	'DIACEREIN',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSTOCERIN 50 (Medopharm)'
);

-- line #11619
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSTODAR 50 (Khandelwal)',
	'DIACEREIN',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSTODAR 50 (Khandelwal)'
);

-- line #11620
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSTOGARD 50 (Micro Labs)',
	'DIACEREIN',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSTOGARD 50 (Micro Labs)'
);

-- line #11621
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSTOMOD 50 (Cipla)',
	'DIACEREIN',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSTOMOD 50 (Cipla)'
);

-- line #11622
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSTORIN 50 (Medley)',
	'DIACEREIN',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSTORIN 50 (Medley)'
);

-- line #11623
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RECARTIX DN 50 (Comed Chem.)',
	'DIACEREIN',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RECARTIX DN 50 (Comed Chem.)'
);

-- line #11624
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REEF 50 (Blue Cross)',
	'DIACEREIN',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REEF 50 (Blue Cross)'
);

-- line #11625
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZEPAM 10 (PSYCOREM)',
	'Diazepam',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZEPAM 10 (PSYCOREM)'
);

-- line #11626
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZEPAM 2 (PSYCOREM)',
	'Diazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZEPAM 2 (PSYCOREM)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZEPAM 5 (PSYCOREM)',
	'Diazepam',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZEPAM 5 (PSYCOREM)'
);

-- line #11627
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANXOL 5 (Svizera)',
	'Diazepam',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANXOL 5 (Svizera)'
);

-- line #11628
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANXOL 10 (Svizera)',
	'Diazepam',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANXOL 10 (Svizera)'
);

-- line #11629
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANXOL 2 (Svizera)',
	'Diazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANXOL 2 (Svizera)'
);

-- line #11630
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANXOL 5 (Svizera)',
	'Diazepam',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANXOL 5 (Svizera)'
);

-- line #11631
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANXOL 5 (Svizera)',
	'Diazepam',
	'VIAL',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANXOL 5 (Svizera)'
);

-- line #11632
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALMOD 5 (Idpl)',
	'Diazepam',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALMOD 5 (Idpl)'
);

-- line #11633
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALMONA 5 (Csc Ph.)',
	'Diazepam',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALMONA 5 (Csc Ph.)'
);

-- line #11634
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALMPOSE 10 (Ranbaxy)',
	'Diazepam',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg/2 ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALMPOSE 10 (Ranbaxy)'
);

-- line #11635
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALMPOSE 2 (Ranbaxy)',
	'Diazepam',
	'SUS',
	gm.nullify_empty_string('2')::numeric,
	'mg/5 ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALMPOSE 2 (Ranbaxy)'
);

-- line #11636
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALMPOSE 10 (Ranbaxy)',
	'Diazepam',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALMPOSE 10 (Ranbaxy)'
);

-- line #11637
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALMPOSE 2.5 (Ranbaxy)',
	'Diazepam',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'5'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALMPOSE 2.5 (Ranbaxy)'
);

-- line #11638
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALMTACK 5 (Indus)',
	'Diazepam',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALMTACK 5 (Indus)'
);

-- line #11639
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAMRELEASE-TR 15 (Natco Ph.)',
	'Diazepam',
	'CAP',
	gm.nullify_empty_string('15')::numeric,
	'mg(TR)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAMRELEASE-TR 15 (Natco Ph.)'
);

-- line #11640
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAMRELEASE-TR 10 (Natco Ph.)',
	'Diazepam',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg(TR)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAMRELEASE-TR 10 (Natco Ph.)'
);

-- line #11641
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECALM 5 (Emil Ph.)',
	'Diazepam',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECALM 5 (Emil Ph.)'
);

-- line #11642
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIACLAM 5 (EAST WEST)',
	'Diazepam',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIACLAM 5 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIACLAM 10 (EAST WEST)',
	'Diazepam',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIACLAM 10 (EAST WEST)'
);

-- line #11643
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIAZECALM 10 (Medopharm)',
	'Diazepam',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIAZECALM 10 (Medopharm)'
);

-- line #11644
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIAZECALM 5 (Medopharm)',
	'Diazepam',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIAZECALM 5 (Medopharm)'
);

-- line #11645
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIAZE 5 (Ind-Swift)',
	'Diazepam',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIAZE 5 (Ind-Swift)'
);

-- line #11646
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIAZEPAM 5 (Stedman)',
	'Diazepam',
	'SUPP',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIAZEPAM 5 (Stedman)'
);

-- line #11647
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIAZ 10 (Mano)',
	'Diazepam',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIAZ 10 (Mano)'
);

-- line #11648
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIPAX 10 (Reliance)',
	'Diazepam',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIPAX 10 (Reliance)'
);

-- line #11649
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIPAX 5 (Reliance)',
	'Diazepam',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIPAX 5 (Reliance)'
);

-- line #11650
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIREC 2 (Sun)',
	'Diazepam',
	'SOL',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIREC 2 (Sun)'
);

-- line #11651
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIZEP-P 5 (Intas)',
	'Diazepam',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIZEP-P 5 (Intas)'
);

-- line #11652
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIZEP 10 (Intas)',
	'Diazepam',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIZEP 10 (Intas)'
);

-- line #11653
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIZEP 5 (Intas)',
	'Diazepam',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIZEP 5 (Intas)'
);

-- line #11654
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DPM 10 (Vgr Bio.)',
	'Diazepam',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DPM 10 (Vgr Bio.)'
);

-- line #11655
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELCION 10 (Ranbaxy)',
	'Diazepam',
	'CR CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELCION 10 (Ranbaxy)'
);

-- line #11656
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EQUIMOOD 5 (Nulife)',
	'Diazepam',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EQUIMOOD 5 (Nulife)'
);

-- line #11657
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Diazepam', u'always_empty': u'', u'form': u'INJ', u'brand': u'EQUIPAM', u'strength_3': u'', u'company': u'Theo Ph.', u'unit': u''}

-- line #11658
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EQUIPAM 5 (Theo Ph.)',
	'Diazepam',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EQUIPAM 5 (Theo Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EQUIPAM 10 (Theo Ph.)',
	'Diazepam',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EQUIPAM 10 (Theo Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EQUIPAM 20 (Theo Ph.)',
	'Diazepam',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EQUIPAM 20 (Theo Ph.)'
);

-- line #11659
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYPOSE 5 (Trio Rem.)',
	'Diazepam',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYPOSE 5 (Trio Rem.)'
);

-- line #11660
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INGATRAN 5 (Inga)',
	'Diazepam',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INGATRAN 5 (Inga)'
);

-- line #11661
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JUNIZ RDS 2.5 (Elder)',
	'Diazepam',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JUNIZ RDS 2.5 (Elder)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JUNIZ RDS 5 (Elder)',
	'Diazepam',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JUNIZ RDS 5 (Elder)'
);

-- line #11662
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAKPAM 5 (Shalaks)',
	'Diazepam',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAKPAM 5 (Shalaks)'
);

-- line #11663
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORI 5 (Neon)',
	'Diazepam',
	'AMP',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORI 5 (Neon)'
);

-- line #11664
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOMESMAR 5 (Dey''S)',
	'Diazepam',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOMESMAR 5 (Dey''S)'
);

-- line #11665
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUPOSE 5 (Pharma synth)',
	'Diazepam',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUPOSE 5 (Pharma synth)'
);

-- line #11666
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PACIQUIL 5 (Stadmed)',
	'Diazepam',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PACIQUIL 5 (Stadmed)'
);

-- line #11667
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PACIQUIL 5 (Stadmed)',
	'Diazepam',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PACIQUIL 5 (Stadmed)'
);

-- line #11668
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAXUM 5 (East India)',
	'Diazepam',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAXUM 5 (East India)'
);

-- line #11669
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAXUM 5 (East India)',
	'Diazepam',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAXUM 5 (East India)'
);

-- line #11670
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEACIN 5 (LA PHARMA)',
	'Diazepam',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEACIN 5 (LA PHARMA)'
);

-- line #11671
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLACIDOX 10 (Lupin)',
	'Diazepam',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLACIDOX 10 (Lupin)'
);

-- line #11672
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLACIDOX 2 (Lupin)',
	'Diazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLACIDOX 2 (Lupin)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLACIDOX 5 (Lupin)',
	'Diazepam',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLACIDOX 5 (Lupin)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLACIDOX 10 (Lupin)',
	'Diazepam',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLACIDOX 10 (Lupin)'
);

-- line #11673
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REC 2.5 (HETERO HC.)',
	'Diazepam',
	'DZ',
	gm.nullify_empty_string('2.5')::numeric,
	'5'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REC 2.5 (HETERO HC.)'
);

-- line #11674
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELIPAM 2 (Reliance)',
	'Diazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELIPAM 2 (Reliance)'
);

-- line #11675
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELIPAM 5 (Reliance)',
	'Diazepam',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELIPAM 5 (Reliance)'
);

-- line #11676
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALEFEN 25 (ALLENGE)',
	'Diclofenac',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALEFEN 25 (ALLENGE)'
);

-- line #11677
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARTILON 50 (UNI ORANGE(MAX))',
	'Diclofenac',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARTILON 50 (UNI ORANGE(MAX))'
);

-- line #11678
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'DICLOFENAC', u'always_empty': u'', u'form': u'AMP', u'brand': u'CADMAX', u'strength_3': u'', u'company': u'Admac (CADMA)', u'unit': u''}

-- line #11679
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLON-F 50 (Dynamic)',
	'Diclofenac',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg(FREE ACID)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLON-F 50 (Dynamic)'
);

-- line #11680
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLONOVA 50 (LUPINOVA)',
	'Diclofenac',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLONOVA 50 (LUPINOVA)'
);

-- line #11681
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Diclofenac', u'always_empty': u'', u'form': u'INJ', u'brand': u'DICLORAN AQ', u'strength_3': u'', u'company': u'J. B. Chem.', u'unit': u''}

-- line #11682
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLOSTAR 25 (CADILA(GENSTAR))',
	'Diclofenac',
	'AMP',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLOSTAR 25 (CADILA(GENSTAR))'
);

-- line #11683
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLORAN 1 (Lekar)',
	'Diclofenac Diethylamine',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLORAN 1 (Lekar)'
);

-- line #11684
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BINAFEN 1.16 (Biocin Hc.)',
	'Diclofenac Diethylammonium',
	'GEL',
	gm.nullify_empty_string('1.16')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BINAFEN 1.16 (Biocin Hc.)'
);

-- line #11685
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOCARE 1 (Olcare)',
	'Diclofenac Diethylammonium',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOCARE 1 (Olcare)'
);

-- line #11686
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOPAR 1.16 (Taurus Lab)',
	'Diclofenac Diethylammonium',
	'GEL',
	gm.nullify_empty_string('1.16')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOPAR 1.16 (Taurus Lab)'
);

-- line #11687
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAC 1.16 (Rhombus)',
	'Diclofenac Diethylammonium',
	'GEL',
	gm.nullify_empty_string('1.16')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAC 1.16 (Rhombus)'
);

-- line #11688
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Diclofenac Diethylammonium', u'always_empty': u'', u'form': u'GEL OINT', u'brand': u'DF', u'strength_3': u'', u'company': u'QUE PH.', u'unit': u''}

-- line #11689
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLOMAX POWER 1.16 (Torrent)',
	'Diclofenac Diethylammonium',
	'GEL',
	gm.nullify_empty_string('1.16')::numeric,
	'% +METHYL SALICYLATE & CAPSAICIN'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLOMAX POWER 1.16 (Torrent)'
);

-- line #11690
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Diclofenac Diethylammonium', u'always_empty': u'', u'form': u'CRM', u'brand': u'DICLOMOVE-NDS', u'strength_3': u'', u'company': u'Emcure', u'unit': u''}

-- line #11691
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLOTAL 1 (Blue Cross)',
	'Diclofenac Diethylammonium',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLOTAL 1 (Blue Cross)'
);

-- line #11692
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMFLAM 1.16 (Merck)',
	'Diclofenac Diethylammonium',
	'GEL',
	gm.nullify_empty_string('1.16')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMFLAM 1.16 (Merck)'
);

-- line #11693
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXFLAM 1.16 (Merck)',
	'Diclofenac Diethylammonium',
	'GEL',
	gm.nullify_empty_string('1.16')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXFLAM 1.16 (Merck)'
);

-- line #11694
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FENGEL 1.16 (Maneesh)',
	'Diclofenac Diethylammonium',
	'OINT',
	gm.nullify_empty_string('1.16')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FENGEL 1.16 (Maneesh)'
);

-- line #11695
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FENSAID 1.16 (Nicholas)',
	'Diclofenac Diethylammonium',
	'GEL',
	gm.nullify_empty_string('1.16')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FENSAID 1.16 (Nicholas)'
);

-- line #11696
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G-NAC 1 (Gujarat Ph.)',
	'Diclofenac Diethylammonium',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G-NAC 1 (Gujarat Ph.)'
);

-- line #11697
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Diclofenac Diethylammonium', u'always_empty': u'', u'form': u'GEL', u'brand': u'INAC', u'strength_3': u'', u'company': u'Zydus Cadila', u'unit': u''}

-- line #11698
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JONAC 1.16 (German R.)',
	'Diclofenac Diethylammonium',
	'GEL',
	gm.nullify_empty_string('1.16')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JONAC 1.16 (German R.)'
);

-- line #11699
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUBRIL 1.16 (Yash Ph.)',
	'Diclofenac Diethylammonium',
	'GEL',
	gm.nullify_empty_string('1.16')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUBRIL 1.16 (Yash Ph.)'
);

-- line #11700
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOBINAK 1.16 (Croslands)',
	'Diclofenac Diethylammonium',
	'GEL',
	gm.nullify_empty_string('1.16')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOBINAK 1.16 (Croslands)'
);

-- line #11701
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOBYLE 1.16 (Ind-Swift)',
	'Diclofenac Diethylammonium',
	'OINT',
	gm.nullify_empty_string('1.16')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOBYLE 1.16 (Ind-Swift)'
);

-- line #11702
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAC 2 (Systopic)',
	'Diclofenac Diethylammonium',
	'GEL %',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAC 2 (Systopic)'
);

-- line #11703
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NACLO 1 (Sun)',
	'Diclofenac Diethylammonium',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NACLO 1 (Sun)'
);

-- line #11704
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEODOL 1 (Brown & B.)',
	'Diclofenac Diethylammonium',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEODOL 1 (Brown & B.)'
);

-- line #11705
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Diclofenac Diethylammonium', u'always_empty': u'', u'form': u'GEL', u'brand': u'NOACK', u'strength_3': u'', u'company': u'SAFE PH.', u'unit': u''}

-- line #11706
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUFENAC 1.16 (Kapl)',
	'Diclofenac Diethylammonium',
	'GEL',
	gm.nullify_empty_string('1.16')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUFENAC 1.16 (Kapl)'
);

-- line #11707
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Diclofenac Diethylammonium', u'always_empty': u'', u'form': u'GEL', u'brand': u'OXALGIN', u'strength_3': u'', u'company': u'Zydus Cadila', u'unit': u''}

-- line #11708
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POWERFLAM 1.16 (Alkem)',
	'Diclofenac Diethylammonium',
	'GEL',
	gm.nullify_empty_string('1.16')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POWERFLAM 1.16 (Alkem)'
);

-- line #11709
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELIGEL 1.16 (Rpg Life)',
	'Diclofenac Diethylammonium',
	'PC GEL',
	gm.nullify_empty_string('1.16')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELIGEL 1.16 (Rpg Life)'
);

-- line #11710
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIFENAC 50 (INTERMED)',
	'DICLOFENAC',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIFENAC 50 (INTERMED)'
);

-- line #11711
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,74', u'strength_2': u'', u'substance': u'DICLOFENAC', u'always_empty': u'', u'form': u'', u'brand': u'DISORAL', u'strength_3': u'', u'company': u'Elder', u'unit': u'%W/V'}

-- line #11712
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DISORAL 0.074 (Elder)',
	'Diclofenac',
	'ORAL RINSE',
	gm.nullify_empty_string('0.074')::numeric,
	'%W/V(ACID)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DISORAL 0.074 (Elder)'
);

-- line #11713
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLEXIGESIC 1 (INVISION)',
	'Diclofenac',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'% W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLEXIGESIC 1 (INVISION)'
);

-- line #11714
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLEXIGESIC 25 (INVISION)',
	'Diclofenac',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLEXIGESIC 25 (INVISION)'
);

-- line #11715
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLEXIGESIC-K 100 (INVISION)',
	'Diclofenac',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLEXIGESIC-K 100 (INVISION)'
);

-- line #11716
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Diclofenac', u'always_empty': u'', u'form': u'SUPP', u'brand': u'JUSTIN', u'strength_3': u'', u'company': u'NEON', u'unit': u''}

-- line #11717
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAFEN 100 (DATLA)',
	'Diclofenac',
	'SR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAFEN 100 (DATLA)'
);

-- line #11718
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPCY 1.16 (Comed)',
	'Diclofenac',
	'GEL',
	gm.nullify_empty_string('1.16')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPCY 1.16 (Comed)'
);

-- line #11719
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPCY 25 (Comed)',
	'Diclofenac',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPCY 25 (Comed)'
);

-- line #11720
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPCY 50 (Comed)',
	'Diclofenac',
	'SR TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPCY 50 (Comed)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPCY 100 (Comed)',
	'Diclofenac',
	'SR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPCY 100 (Comed)'
);

-- line #11721
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOFEN 1.16 (Bal Ph.)',
	'Diclofenac',
	'GEL',
	gm.nullify_empty_string('1.16')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOFEN 1.16 (Bal Ph.)'
);

-- line #11722
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Diclofenac', u'always_empty': u'', u'form': u'GEL', u'brand': u'MOBYLE', u'strength_3': u'', u'company': u'Ind-Swift', u'unit': u''}

-- line #11723
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAL-M 25 (MADHAV BIO.)',
	'Diclofenac',
	'AMP',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAL-M 25 (MADHAV BIO.)'
);

-- line #11724
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONTAC 100 (Elder)',
	'Diclofenac',
	'SUPP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONTAC 100 (Elder)'
);

-- line #11725
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AGILE-K 50 (Ind-Swift)',
	'Diclofenac Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AGILE-K 50 (Ind-Swift)'
);

-- line #11726
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AQUIFENAC 50 (Aquila)',
	'Diclofenac Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AQUIFENAC 50 (Aquila)'
);

-- line #11727
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARK-75 75 (Apex Labs.)',
	'Diclofenac Pot.',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARK-75 75 (Apex Labs.)'
);

-- line #11728
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARMDIC 50 (Armour Rem.)',
	'Diclofenac Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARMDIC 50 (Armour Rem.)'
);

-- line #11729
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BESTODEK 25 (Bestochem)',
	'Diclofenac Pot.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg (2'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BESTODEK 25 (Bestochem)'
);

-- line #11730
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Diclofenac POT.', u'always_empty': u'', u'form': u'GEL', u'brand': u'COOL-P', u'strength_3': u'', u'company': u"Dr.Arvind Shah''S", u'unit': u''}

-- line #11731
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DELTA-K 50 (Croslands)',
	'Diclofenac Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DELTA-K 50 (Croslands)'
);

-- line #11732
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEMO 50 (Nordic Ph.)',
	'Diclofenac Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEMO 50 (Nordic Ph.)'
);

-- line #11733
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLO-K 50 (Morepen)',
	'Diclofenac Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLO-K 50 (Morepen)'
);

-- line #11734
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLONIJ-K 50 (Sunij)',
	'Diclofenac Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLONIJ-K 50 (Sunij)'
);

-- line #11735
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLOPACE 50 (Fem care)',
	'Diclofenac Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLOPACE 50 (Fem care)'
);

-- line #11736
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'25', u'strength_2': u'', u'substance': u'Diclofenac Pot.', u'always_empty': u'', u'form': u'', u'brand': u'DICNACX', u'strength_3': u'', u'company': u'SHINCE PH.', u'unit': u'mg/ML'}

-- line #11737
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICNIC 50 (RADHE BIO.)',
	'Diclofenac Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICNIC 50 (RADHE BIO.)'
);

-- line #11738
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIKUL 50 (Global Med.)',
	'Diclofenac Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIKUL 50 (Global Med.)'
);

-- line #11739
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVOREL-K 50 (MEDISYS)',
	'Diclofenac Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVOREL-K 50 (MEDISYS)'
);

-- line #11740
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DK-50 50 (Somatico)',
	'Diclofenac Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DK-50 50 (Somatico)'
);

-- line #11741
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLENTIA 100 (AKUMENTIS HC.)',
	'Diclofenac Pot.',
	'SR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLENTIA 100 (AKUMENTIS HC.)'
);

-- line #11742
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLOACT 50 (Ochoa)',
	'Diclofenac Pot.',
	'DT TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLOACT 50 (Ochoa)'
);

-- line #11743
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLOCIDE-K 50 (Kee Ph.)',
	'Diclofenac Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLOCIDE-K 50 (Kee Ph.)'
);

-- line #11744
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYZOX-50 50 (Devotec Hc.)',
	'Diclofenac Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYZOX-50 50 (Devotec Hc.)'
);

-- line #11745
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLEXYL-K 50 (Perch)',
	'Diclofenac Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLEXYL-K 50 (Perch)'
);

-- line #11746
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTEG-D 25 (MEGAVISION)',
	'Diclofenac Pot.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTEG-D 25 (MEGAVISION)'
);

-- line #11747
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KNAC 50 (Astrazeneca)',
	'Diclofenac Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KNAC 50 (Astrazeneca)'
);

-- line #11748
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KYMOVIL PLUS 50 (VILBERRY HC.)',
	'Diclofenac Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KYMOVIL PLUS 50 (VILBERRY HC.)'
);

-- line #11749
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Diclofenac Pot.', u'always_empty': u'', u'form': u'INJ', u'brand': u'LOFY-K', u'strength_3': u'', u'company': u'BIOMAX BIO.', u'unit': u''}

-- line #11750
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDIDOL-P 50 (MEDISTREAM)',
	'Diclofenac Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDIDOL-P 50 (MEDISTREAM)'
);

-- line #11751
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDINAC 50 (Alde Medi.)',
	'Diclofenac Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDINAC 50 (Alde Medi.)'
);

-- line #11752
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEODOL-K 50 (Brown & B.)',
	'Diclofenac Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEODOL-K 50 (Brown & B.)'
);

-- line #11753
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEUROFLAME - 50 (Novartis)',
	'Diclofenac Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEUROFLAME - 50 (Novartis)'
);

-- line #11754
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Diclofenac', u'always_empty': u'', u'form': u'SPRAY', u'brand': u'PRS', u'strength_3': u'', u'company': u'MIDAS CARE', u'unit': u''}

-- line #11755
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REDIRINSE 0.074 (Elder)',
	'Diclofenac',
	'ORAL RINSE',
	gm.nullify_empty_string('0.074')::numeric,
	'%W/V(ACID)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REDIRINSE 0.074 (Elder)'
);

-- line #11756
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELAXYL 1.16 (Franco I.)',
	'Diclofenac',
	'GEL',
	gm.nullify_empty_string('1.16')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELAXYL 1.16 (Franco I.)'
);

-- line #11757
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Diclofenac Sod.', u'always_empty': u'', u'form': u'INJ', u'brand': u'ACLOMAX', u'strength_3': u'', u'company': u'Admac Ph.', u'unit': u''}

-- line #11758
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADIFLAM 1 (Leben)',
	'Diclofenac Sod.',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADIFLAM 1 (Leben)'
);

-- line #11759
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADIFLAM 25 (Leben)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADIFLAM 25 (Leben)'
);

-- line #11760
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AGILE-D 50 (Ind-Swift)',
	'Diclofenac Sod.',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AGILE-D 50 (Ind-Swift)'
);

-- line #11761
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AGILE-D 25 (Ind-Swift)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AGILE-D 25 (Ind-Swift)'
);

-- line #11762
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AGILE-D 100 (Ind-Swift)',
	'Diclofenac Sod.',
	'SR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AGILE-D 100 (Ind-Swift)'
);

-- line #11763
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AGILE 50 (Ind-Swift)',
	'Diclofenac Sod.',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AGILE 50 (Ind-Swift)'
);

-- line #11764
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AGILE 1 (Ind-Swift)',
	'Diclofenac Sod.',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AGILE 1 (Ind-Swift)'
);

-- line #11765
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AGILE 25 (Ind-Swift)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AGILE 25 (Ind-Swift)'
);

-- line #11766
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AGILE 100 (Ind-Swift)',
	'Diclofenac Sod.',
	'SR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AGILE 100 (Ind-Swift)'
);

-- line #11767
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOFEN 75 (Radix Bio.)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('75')::numeric,
	'mg/3ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOFEN 75 (Radix Bio.)'
);

-- line #11768
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AQUAGESIC 75 (Rapross)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AQUAGESIC 75 (Rapross)'
);

-- line #11769
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARGESIC 25 (Centaur)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARGESIC 25 (Centaur)'
);

-- line #11770
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Diclofenac Sod.', u'always_empty': u'', u'form': u'INJ', u'brand': u'ASTRAFLAM', u'strength_3': u'', u'company': u'YASHTRA HEALTH', u'unit': u''}

-- line #11771
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BEDICLO 25 (Brooks Ph.)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BEDICLO 25 (Brooks Ph.)'
);

-- line #11772
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIDNAC 1 (Gsk)',
	'Diclofenac Sod.',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIDNAC 1 (Gsk)'
);

-- line #11773
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIORAN RAPID 50 (Rusan Hc)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIORAN RAPID 50 (Rusan Hc)'
);

-- line #11774
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALDORUB 75 (TREFOIL PH.)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALDORUB 75 (TREFOIL PH.)'
);

-- line #11775
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANNACT 50 (Astrazeneca)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANNACT 50 (Astrazeneca)'
);

-- line #11776
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOCARE 100 (Olcare)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOCARE 100 (Olcare)'
);

-- line #11777
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOCARE 50 (Olcare)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOCARE 50 (Olcare)'
);

-- line #11778
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOFEN 25 (Salvo Hc.)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOFEN 25 (Salvo Hc.)'
);

-- line #11779
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOPAR 0.1 (Taurus Lab)',
	'Diclofenac Sod.',
	'EYE DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOPAR 0.1 (Taurus Lab)'
);

-- line #11780
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOPAR 25 (Taurus Lab)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOPAR 25 (Taurus Lab)'
);

-- line #11781
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COFENAC 1 (Protec)',
	'Diclofenac Sod.',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COFENAC 1 (Protec)'
);

-- line #11782
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COFENAC 50 (Protec)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COFENAC 50 (Protec)'
);

-- line #11783
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAN 100 (Unison)',
	'Diclofenac Sod.',
	'SR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAN 100 (Unison)'
);

-- line #11784
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAN 50 (Unison)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAN 50 (Unison)'
);

-- line #11785
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEECLO 1 (Cadila Ph.)',
	'Diclofenac Sod.',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEECLO 1 (Cadila Ph.)'
);

-- line #11786
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEFEN 50 (Arbro Ph.)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEFEN 50 (Arbro Ph.)'
);

-- line #11787
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DELBITOL 25 (Citadel)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DELBITOL 25 (Citadel)'
);

-- line #11788
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DELBITOL 50 (Citadel)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DELBITOL 50 (Citadel)'
);

-- line #11789
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DENAC 100 (Franklin)',
	'Diclofenac Sod.',
	'SR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DENAC 100 (Franklin)'
);

-- line #11790
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Diclofenac Sod.', u'always_empty': u'', u'form': u'GEL', u'brand': u'DIALGIN', u'strength_3': u'', u'company': u'Dial Ph.', u'unit': u''}

-- line #11791
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Diclofenac Sod.', u'always_empty': u'', u'form': u'INJ', u'brand': u'DICAX', u'strength_3': u'', u'company': u'AXYZEN LIFE', u'unit': u''}

-- line #11792
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICKY 100 (CHEMO HC.)',
	'Diclofenac Sod.',
	'SR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICKY 100 (CHEMO HC.)'
);

-- line #11793
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLEN 0.1 (Ophthal R.)',
	'Diclofenac Sod.',
	'EYE DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLEN 0.1 (Ophthal R.)'
);

-- line #11794
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLEN 25 (Ophthal R.)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLEN 25 (Ophthal R.)'
);

-- line #11795
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLOACT 100 (Cadila Ph.)',
	'Diclofenac Sod.',
	'SR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLOACT 100 (Cadila Ph.)'
);

-- line #11796
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLOACT 50 (CADILA(GENVISTA))',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLOACT 50 (CADILA(GENVISTA))'
);

-- line #11797
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLOAT 75 (Atoz Ph.)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLOAT 75 (Atoz Ph.)'
);

-- line #11798
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLOBEER 100 (ABEER PH.)',
	'Diclofenac Sod.',
	'SR',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLOBEER 100 (ABEER PH.)'
);

-- line #11799
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLODOL 75 (Neon)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLODOL 75 (Neon)'
);

-- line #11800
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLO 50 (Morepen)',
	'Diclofenac Sod.',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLO 50 (Morepen)'
);

-- line #11801
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLODYNE 1 (Bliss)',
	'Diclofenac Sod.',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLODYNE 1 (Bliss)'
);

-- line #11802
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLOFAST 50 (Lark Lab)',
	'Diclofenac Sod.',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLOFAST 50 (Lark Lab)'
);

-- line #11803
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLOFAST 25 (Lark Lab)',
	'Diclofenac Sod.',
	'SUS',
	gm.nullify_empty_string('25')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLOFAST 25 (Lark Lab)'
);

-- line #11804
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLOFENAC 75 (Claris L.)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLOFENAC 75 (Claris L.)'
);

-- line #11805
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLOFENAC 50 (Lark Lab)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLOFENAC 50 (Lark Lab)'
);

-- line #11806
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLOFEN 25 (Biochem)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLOFEN 25 (Biochem)'
);

-- line #11807
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLOFEN 50 (Biochem)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLOFEN 50 (Biochem)'
);

-- line #11808
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLOFLAM-50 50 (Reliance)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLOFLAM-50 50 (Reliance)'
);

-- line #11809
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLOFORD 50 (Ronak Lab.)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLOFORD 50 (Ronak Lab.)'
);

-- line #11810
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLOGEN 25 (AGIO PH.)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg(BENZYL ALCOHOL 4$W/V)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLOGEN 25 (AGIO PH.)'
);

-- line #11811
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLOMAX 1 (Torrent)',
	'Diclofenac Sod.',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLOMAX 1 (Torrent)'
);

-- line #11812
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLOMAX 25 (Torrent)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLOMAX 25 (Torrent)'
);

-- line #11813
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLOMAX 100 (Torrent)',
	'Diclofenac Sod.',
	'SR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLOMAX 100 (Torrent)'
);

-- line #11814
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLOMAX 25 (Torrent)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLOMAX 25 (Torrent)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLOMAX 50 (Torrent)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLOMAX 50 (Torrent)'
);

-- line #11815
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLOMAX 75 (Torrent)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLOMAX 75 (Torrent)'
);

-- line #11816
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLOMOL 1 (Win-Medicare)',
	'Diclofenac Sod.',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLOMOL 1 (Win-Medicare)'
);

-- line #11817
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLOMOL 75 (Win-Medicare)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('75')::numeric,
	'mg/3ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLOMOL 75 (Win-Medicare)'
);

-- line #11818
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLOMOL 100 (Win-Medicare)',
	'Diclofenac Sod.',
	'SR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLOMOL 100 (Win-Medicare)'
);

-- line #11819
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLOMOVE 75 (Emcure)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLOMOVE 75 (Emcure)'
);

-- line #11820
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLOMOVE 100 (Emcure)',
	'Diclofenac Sod.',
	'SR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLOMOVE 100 (Emcure)'
);

-- line #11821
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLOMOVE 50 (Emcure)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLOMOVE 50 (Emcure)'
);

-- line #11822
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLONAC 50 (Lupin)',
	'Diclofenac Sod.',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLONAC 50 (Lupin)'
);

-- line #11823
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLONAC 100 (Lupin)',
	'Diclofenac Sod.',
	'ER TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLONAC 100 (Lupin)'
);

-- line #11824
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLONAC 0.1 (Oscar Rem.)',
	'Diclofenac Sod.',
	'EYE DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLONAC 0.1 (Oscar Rem.)'
);

-- line #11825
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Diclofenac Sod.', u'always_empty': u'', u'form': u'GEL', u'brand': u'DICLONAC', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #11826
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLONAC 25 (Lupin)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLONAC 25 (Lupin)'
);

-- line #11827
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLONAC 100 (Lupin)',
	'Diclofenac Sod.',
	'SR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLONAC 100 (Lupin)'
);

-- line #11828
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLONAC 50 (Lupin)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLONAC 50 (Lupin)'
);

-- line #11829
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLONIJ 50 (Sunij)',
	'Diclofenac Sod.',
	'DT TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLONIJ 50 (Sunij)'
);

-- line #11830
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLONIJ 50 (Sunij)',
	'Diclofenac Sod.',
	'EC TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLONIJ 50 (Sunij)'
);

-- line #11831
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLONIJ 100 (Sunij)',
	'Diclofenac Sod.',
	'SR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLONIJ 100 (Sunij)'
);

-- line #11832
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLONOR 20 (Norris Med.)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLONOR 20 (Norris Med.)'
);

-- line #11833
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLONOVA 25 (LUPINOVA)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLONOVA 25 (LUPINOVA)'
);

-- line #11834
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLON-S 25 (Dynamic)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLON-S 25 (Dynamic)'
);

-- line #11835
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75', u'strength_2': u'', u'substance': u'Diclofenac Sod.', u'always_empty': u'', u'form': u'', u'brand': u'DICLO QUEST', u'strength_3': u'', u'company': u'ALCHEM PHY.', u'unit': u'mg'}

-- line #11836
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLOQUEST 50 (ALCHEM PHY.)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLOQUEST 50 (ALCHEM PHY.)'
);

-- line #11837
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLORAN 0.1 (Lekar)',
	'Diclofenac Sod.',
	'EYE DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLORAN 0.1 (Lekar)'
);

-- line #11838
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLORAN 75 (Lekar)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLORAN 75 (Lekar)'
);

-- line #11839
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLORAN 100 (Lekar)',
	'Diclofenac Sod.',
	'SR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLORAN 100 (Lekar)'
);

-- line #11840
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLORAN 50 (Lekar)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLORAN 50 (Lekar)'
);

-- line #11841
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLORIC 1 (Dolphin)',
	'Diclofenac Sod.',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLORIC 1 (Dolphin)'
);

-- line #11842
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLORIC 25 (Dolphin)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLORIC 25 (Dolphin)'
);

-- line #11843
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLORIC 50 (Dolphin)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLORIC 50 (Dolphin)'
);

-- line #11844
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLOROY 25 (Royal)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLOROY 25 (Royal)'
);

-- line #11845
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLOSON 50 (Patson)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLOSON 50 (Patson)'
);

-- line #11846
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLOSTAR 25 (Cadila Ph.)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLOSTAR 25 (Cadila Ph.)'
);

-- line #11847
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLOSYN 25 (Kentreck)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLOSYN 25 (Kentreck)'
);

-- line #11848
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Diclofenac Sod.', u'always_empty': u'', u'form': u'TAB', u'brand': u'DICLOSYN', u'strength_3': u'', u'company': u'Kentreck', u'unit': u''}

-- line #11849
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLOTAL 100 (Blue Cross)',
	'Diclofenac Sod.',
	'CR CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLOTAL 100 (Blue Cross)'
);

-- line #11850
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLOTAL 50 (Blue Cross)',
	'Diclofenac Sod.',
	'DT/ SR TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg/100'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLOTAL 50 (Blue Cross)'
);

-- line #11851
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLOTAL 25 (Blue Cross)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLOTAL 25 (Blue Cross)'
);

-- line #11852
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLOTAL MULTI DOSE 25 (Blue Cross)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg(BENZYL ALCOHOL 4'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLOTAL MULTI DOSE 25 (Blue Cross)'
);

-- line #11853
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Diclofenac Sod.', u'always_empty': u'', u'form': u'INJ', u'brand': u'DICLOVAR', u'strength_3': u'', u'company': u'ZOTA', u'unit': u''}

-- line #11854
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLOWIN 50 (Wings)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLOWIN 50 (Wings)'
);

-- line #11855
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLOX 25 (B.M.Ph.)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLOX 25 (B.M.Ph.)'
);

-- line #11856
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLOZED 75 (ZOTA)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLOZED 75 (ZOTA)'
);

-- line #11857
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICO 25 (Finecure)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICO 25 (Finecure)'
);

-- line #11858
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICO 25 (Finecure)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICO 25 (Finecure)'
);

-- line #11859
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICOL 0.1 (Ind-Swift)',
	'Diclofenac Sod.',
	'DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICOL 0.1 (Ind-Swift)'
);

-- line #11860
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICOL INJ 25 (Ind-Swift)',
	'Diclofenac Sod.',
	'V',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICOL INJ 25 (Ind-Swift)'
);

-- line #11861
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICOLIV 25 (Ind-Swift)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICOLIV 25 (Ind-Swift)'
);

-- line #11862
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICOLIV 100 (Ind-Swift)',
	'Diclofenac Sod.',
	'SR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICOLIV 100 (Ind-Swift)'
);

-- line #11863
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICONAC 0.1 (Oscar Rem.)',
	'Diclofenac Sod.',
	'EYE DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICONAC 0.1 (Oscar Rem.)'
);

-- line #11864
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICO 50 (Finecure)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICO 50 (Finecure)'
);

-- line #11865
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICRON 25 (Kamron)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICRON 25 (Kamron)'
);

-- line #11866
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICRON 50 (Kamron)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICRON 50 (Kamron)'
);

-- line #11867
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIFENIC 0.1 (Intas)',
	'Diclofenac Sod.',
	'DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIFENIC 0.1 (Intas)'
);

-- line #11868
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIFISAL 25 (Kramer)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg(4'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIFISAL 25 (Kramer)'
);

-- line #11869
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIFISAL 100 (Kramer)',
	'Diclofenac Sod.',
	'SR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIFISAL 100 (Kramer)'
);

-- line #11870
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIFISAL 50 (Kramer)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIFISAL 50 (Kramer)'
);

-- line #11871
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIKLOFEN 50 (Stadmed)',
	'Diclofenac Sod.',
	'SUPPOS',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIKLOFEN 50 (Stadmed)'
);

-- line #11872
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILONA 0.1 (Mapra)',
	'Diclofenac Sod.',
	'EYE DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILONA 0.1 (Mapra)'
);

-- line #11873
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILONA 25 (Mapra)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILONA 25 (Mapra)'
);

-- line #11874
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILONA 50 (Mapra)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILONA 50 (Mapra)'
);

-- line #11875
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DINAC 25 (Eg Ph.)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DINAC 25 (Eg Ph.)'
);

-- line #11876
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIOFIN 25 (Jawa Ph.)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIOFIN 25 (Jawa Ph.)'
);

-- line #11877
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DION 50 (Monokem)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DION 50 (Monokem)'
);

-- line #11878
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIPKON 25 (Briskon)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIPKON 25 (Briskon)'
);

-- line #11879
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIRAN 50 (Indica)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIRAN 50 (Indica)'
);

-- line #11880
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVEXX 50 (Zuventus)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVEXX 50 (Zuventus)'
);

-- line #11881
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVON 25 (Eros Ph.)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVON 25 (Eros Ph.)'
);

-- line #11882
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVON 100 (Eros Ph.)',
	'Diclofenac Sod.',
	'SR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVON 100 (Eros Ph.)'
);

-- line #11883
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVON 50 (Eros Ph.)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVON 50 (Eros Ph.)'
);

-- line #11884
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVOREL 100 (MEDISYS)',
	'Diclofenac Sod.',
	'CR CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVOREL 100 (MEDISYS)'
);

-- line #11885
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVOREL 50 (MEDISYS)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVOREL 50 (MEDISYS)'
);

-- line #11886
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOFEC 25 (Dwd)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/3ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOFEC 25 (Dwd)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOFEC 75 (Dwd)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('75')::numeric,
	'mg/3ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOFEC 75 (Dwd)'
);

-- line #11887
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOFEC 50 (Dwd)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOFEC 50 (Dwd)'
);

-- line #11888
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOFLEX 25 (Jagsonpal)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOFLEX 25 (Jagsonpal)'
);

-- line #11889
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOFLEX 100 (Jagsonpal)',
	'Diclofenac Sod.',
	'SR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOFLEX 100 (Jagsonpal)'
);

-- line #11890
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOFLEX 50 (Jagsonpal)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOFLEX 50 (Jagsonpal)'
);

-- line #11891
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLACT 50 (Intra Lab)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLACT 50 (Intra Lab)'
);

-- line #11892
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLENTIA AQ 75 (AKUMENTIS HC.)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLENTIA AQ 75 (AKUMENTIS HC.)'
);

-- line #11893
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLOACT 25 (Ochoa)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLOACT 25 (Ochoa)'
);

-- line #11894
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLOBAN-AQUA 75 (LIFESTAR)',
	'Diclofenac SOD.',
	'INJ',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLOBAN-AQUA 75 (LIFESTAR)'
);

-- line #11895
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLOBAN 25 (LIFESTAR)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLOBAN 25 (LIFESTAR)'
);

-- line #11896
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLOBAN SR-100 100 (LIFESTAR)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLOBAN SR-100 100 (LIFESTAR)'
);

-- line #11897
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLOKIND-AQUA 75 (Mankind)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLOKIND-AQUA 75 (Mankind)'
);

-- line #11898
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLONAC 50 (Baroque)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLONAC 50 (Baroque)'
);

-- line #11899
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'D-PAIN 100 (Genx Ph.)',
	'Diclofenac Sod.',
	'SR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'D-PAIN 100 (Genx Ph.)'
);

-- line #11900
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'D-PAIN 50 (Genx Ph.)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'D-PAIN 50 (Genx Ph.)'
);

-- line #11901
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUVA 25 (Dallas Ph.)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUVA 25 (Dallas Ph.)'
);

-- line #11902
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYKAY 25 (Remedies)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYKAY 25 (Remedies)'
);

-- line #11903
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYKLO 10 (Gland Ph.)',
	'Diclofenac Sod.',
	'GEL',
	gm.nullify_empty_string('10')::numeric,
	'mg/G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYKLO 10 (Gland Ph.)'
);

-- line #11904
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYKLOJECT 25 (Gland Ph.)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYKLOJECT 25 (Gland Ph.)'
);

-- line #11905
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYKLOTAB 50 (Gland Ph.)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYKLOTAB 50 (Gland Ph.)'
);

-- line #11906
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYNAMAX 25 (Troikaa)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYNAMAX 25 (Troikaa)'
);

-- line #11907
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYNAMAX 50 (Troikaa)',
	'Diclofenac Sod.',
	'SR TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYNAMAX 50 (Troikaa)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYNAMAX 100 (Troikaa)',
	'Diclofenac Sod.',
	'SR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYNAMAX 100 (Troikaa)'
);

-- line #11908
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYNAPAR AQ 75 (Troikaa)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYNAPAR AQ 75 (Troikaa)'
);

-- line #11909
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Diclofenac Sod.', u'always_empty': u'', u'form': u'', u'brand': u'DYNAPAR AQ PFS', u'strength_3': u'', u'company': u'Troikaa', u'unit': u''}

-- line #11910
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYNAPAR 25 (Troikaa)',
	'Diclofenac Sod.',
	'EC TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYNAPAR 25 (Troikaa)'
);

-- line #11911
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYNAPAR 50 (Troikaa)',
	'Diclofenac Sod.',
	'EC TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYNAPAR 50 (Troikaa)'
);

-- line #11912
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYNAPAR 25 (Troikaa)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYNAPAR 25 (Troikaa)'
);

-- line #11913
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYNAPAR 100 (Troikaa)',
	'Diclofenac Sod.',
	'SR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYNAPAR 100 (Troikaa)'
);

-- line #11914
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYNAPAR 75 (Troikaa)',
	'Diclofenac Sod.',
	'SR TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYNAPAR 75 (Troikaa)'
);

-- line #11915
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Diclofenac Sod.', u'always_empty': u'', u'form': u'SUPP', u'brand': u'DYNAPAR', u'strength_3': u'', u'company': u'TROIKAA', u'unit': u''}

-- line #11916
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYNAPAR 25 (Troikaa)',
	'Diclofenac Sod.',
	'VIAL',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYNAPAR 25 (Troikaa)'
);

-- line #11917
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYNATROY AQ 75 (Troikaa)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('75')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYNATROY AQ 75 (Troikaa)'
);

-- line #11918
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMFEN 50 (Medico)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMFEN 50 (Medico)'
);

-- line #11919
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMFLAM 25 (Merck)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMFLAM 25 (Merck)'
);

-- line #11920
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMFLAM 50 (Merck)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMFLAM 50 (Merck)'
);

-- line #11921
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENAC 1 (UNIVERSAL PH.)',
	'Diclofenac Sod.',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENAC 1 (UNIVERSAL PH.)'
);

-- line #11922
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESGIPYRIN 25 (Nicholas)',
	'Diclofenac Sod.',
	'DS INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESGIPYRIN 25 (Nicholas)'
);

-- line #11923
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXFLAM 25 (Merck)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXFLAM 25 (Merck)'
);

-- line #11924
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXFLAM 50 (Merck)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXFLAM 50 (Merck)'
);

-- line #11925
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEGAN 0.2 (Allergan)',
	'Diclofenac Sod.',
	'DPS',
	gm.nullify_empty_string('0.2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEGAN 0.2 (Allergan)'
);

-- line #11926
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FENADEC 50 (Maneesh)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FENADEC 50 (Maneesh)'
);

-- line #11927
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FENEC 50 (Claris L.)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FENEC 50 (Claris L.)'
);

-- line #11928
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FENGEL 1 (Maneesh)',
	'Diclofenac Sod.',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FENGEL 1 (Maneesh)'
);

-- line #11929
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEN 1 (Maneesh)',
	'Diclofenac Sod.',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%W/W;G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEN 1 (Maneesh)'
);

-- line #11930
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FENIC 50 (Kosha Lab.)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FENIC 50 (Kosha Lab.)'
);

-- line #11931
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FENSAIDE 1 (Nicholas)',
	'Diclofenac Sod.',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FENSAIDE 1 (Nicholas)'
);

-- line #11932
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FENSAIDE 25 (Nicholas)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FENSAIDE 25 (Nicholas)'
);

-- line #11933
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FENSAIDE 50 (Nicholas)',
	'Diclofenac Sod.',
	'SR TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FENSAIDE 50 (Nicholas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FENSAIDE 100 (Nicholas)',
	'Diclofenac Sod.',
	'SR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FENSAIDE 100 (Nicholas)'
);

-- line #11934
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLAGON 50 (Unicure)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLAGON 50 (Unicure)'
);

-- line #11935
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLAMESE 25 (Meridian)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLAMESE 25 (Meridian)'
);

-- line #11936
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLEXYL 25 (Perch)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLEXYL 25 (Perch)'
);

-- line #11937
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FRENAC 50 (Waves Bio.)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FRENAC 50 (Waves Bio.)'
);

-- line #11938
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALORAN 1 (Hal)',
	'Diclofenac Sod.',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALORAN 1 (Hal)'
);

-- line #11939
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALORAN 100 (Hal)',
	'Diclofenac Sod.',
	'SR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALORAN 100 (Hal)'
);

-- line #11940
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALORAN 50 (Hal)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALORAN 50 (Hal)'
);

-- line #11941
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'I-GESIC 0.1 (Centaur)',
	'Diclofenac Sod.',
	'DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'I-GESIC 0.1 (Centaur)'
);

-- line #11942
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INAC 50 (Zydus Cadila)',
	'Diclofenac Sod.',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg (FREE ACID)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INAC 50 (Zydus Cadila)'
);

-- line #11943
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INAC 75 (Zydus Cadila)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INAC 75 (Zydus Cadila)'
);

-- line #11944
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INAC 50 (Zydus Cadila)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INAC 50 (Zydus Cadila)'
);

-- line #11945
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INAC-TR 100 (Zydus Cadila)',
	'Diclofenac Sod.',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INAC-TR 100 (Zydus Cadila)'
);

-- line #11946
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDIAFLAM 50 (Votary Lab)',
	'Diclofenac Sod.',
	'MD TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDIAFLAM 50 (Votary Lab)'
);

-- line #11947
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INFAMOL 100 (Panjon)',
	'Diclofenac Sod.',
	'SR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INFAMOL 100 (Panjon)'
);

-- line #11948
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INFLAMOL 100 (Panjon)',
	'Diclofenac Sod.',
	'SR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INFLAMOL 100 (Panjon)'
);

-- line #11949
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INFLAWIN 25 (Indus)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INFLAWIN 25 (Indus)'
);

-- line #11950
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTRAGESIC 25 (Intra Lab)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTRAGESIC 25 (Intra Lab)'
);

-- line #11951
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JOLE 25 (Jollen Med.)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JOLE 25 (Jollen Med.)'
);

-- line #11952
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JONAC 100 (German R.)',
	'Diclofenac Sod.',
	'CR CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JONAC 100 (German R.)'
);

-- line #11953
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JONAC 100 (German R.)',
	'Diclofenac Sod.',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JONAC 100 (German R.)'
);

-- line #11954
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JONAC 25 (German R.)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JONAC 25 (German R.)'
);

-- line #11955
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JONAC 12.5 (German R.)',
	'Diclofenac Sod.',
	'SUPPOS',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JONAC 12.5 (German R.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JONAC 100 (German R.)',
	'Diclofenac Sod.',
	'SUPPOS',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JONAC 100 (German R.)'
);

-- line #11956
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JONAC 50 (German R.)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JONAC 50 (German R.)'
);

-- line #11957
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JUSTIN 100 (Neon)',
	'Diclofenac Sod.',
	'SUPPOS',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JUSTIN 100 (Neon)'
);

-- line #11958
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Diclofenac Sod.', u'always_empty': u'', u'form': u'AMP', u'brand': u'LEEMAX', u'strength_3': u'', u'company': u'ADMAC (LEE BENZ)', u'unit': u''}

-- line #11959
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPSY 25 (Comed)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPSY 25 (Comed)'
);

-- line #11960
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPSY 100 (Comed)',
	'Diclofenac Sod.',
	'SR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPSY 100 (Comed)'
);

-- line #11961
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75G', u'strength_2': u'', u'substance': u'Diclofenac Sod.', u'always_empty': u'', u'form': u'INJ', u'brand': u'LYSOFLAM-AQ', u'strength_3': u'', u'company': u'Cachet', u'unit': u''}

-- line #11962
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYSOFLAM DIG 25 (Cachet)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYSOFLAM DIG 25 (Cachet)'
);

-- line #11963
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAXREL 1 (Dey''S)',
	'Diclofenac Sod.',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAXREL 1 (Dey''S)'
);

-- line #11964
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Diclofenac Sod.', u'always_empty': u'', u'form': u'INJ', u'brand': u'MINDOL', u'strength_3': u'', u'company': u'USP LIFE', u'unit': u''}

-- line #11965
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOBIAID 25 (Ajanta Ph.)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOBIAID 25 (Ajanta Ph.)'
);

-- line #11966
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOBIAID 100 (Ajanta Ph.)',
	'Diclofenac Sod.',
	'SR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOBIAID 100 (Ajanta Ph.)'
);

-- line #11967
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOBIAID 50 (Ajanta Ph.)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOBIAID 50 (Ajanta Ph.)'
);

-- line #11968
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOBILENE 25 (Mefro Ph.)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOBILENE 25 (Mefro Ph.)'
);

-- line #11969
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOBINAK 25 (Croslands)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOBINAK 25 (Croslands)'
);

-- line #11970
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOBINAK 50 (Croslands)',
	'Diclofenac Sod.',
	'SR TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOBINAK 50 (Croslands)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOBINAK 100 (Croslands)',
	'Diclofenac Sod.',
	'SR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOBINAK 100 (Croslands)'
);

-- line #11971
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOVONAC 10 (Nicholas)',
	'Diclofenac Sod.',
	'CRM',
	gm.nullify_empty_string('10')::numeric,
	'mg/G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOVONAC 10 (Nicholas)'
);

-- line #11972
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOVONAC 25 (Nicholas)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOVONAC 25 (Nicholas)'
);

-- line #11973
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOVONAC (SR) 50 (Nicholas)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOVONAC (SR) 50 (Nicholas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOVONAC (SR) 100 (Nicholas)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOVONAC (SR) 100 (Nicholas)'
);

-- line #11974
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAC 75 (Systopic)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('75')::numeric,
	'mg/3ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAC 75 (Systopic)'
);

-- line #11975
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NACLO 25 (Natco Ph.)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NACLO 25 (Natco Ph.)'
);

-- line #11976
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NACLO 50 (Natco Ph.)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NACLO 50 (Natco Ph.)'
);

-- line #11977
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NACLO TR 100 (Natco Ph.)',
	'Diclofenac Sod.',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NACLO TR 100 (Natco Ph.)'
);

-- line #11978
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAC 150 (Systopic)',
	'Diclofenac Sod.',
	'SR TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAC 150 (Systopic)'
);

-- line #11979
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAC 75 (Systopic)',
	'Diclofenac Sod.',
	'SR TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg/100'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAC 75 (Systopic)'
);

-- line #11980
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAC 50 (Systopic)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAC 50 (Systopic)'
);

-- line #11981
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAM 50 (Systopic)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAM 50 (Systopic)'
);

-- line #11982
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEODOL 0.1 (Micro V.)',
	'Diclofenac Sod.',
	'DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEODOL 0.1 (Micro V.)'
);

-- line #11983
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEODOL 25 (Brown & B.)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEODOL 25 (Brown & B.)'
);

-- line #11984
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEODOL 100 (Brown & B.)',
	'Diclofenac Sod.',
	'SR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEODOL 100 (Brown & B.)'
);

-- line #11985
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEODOL 50 (Brown & B.)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEODOL 50 (Brown & B.)'
);

-- line #11986
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NSAID 0.1 (Syntho)',
	'Diclofenac Sod.',
	'EYE DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NSAID 0.1 (Syntho)'
);

-- line #11987
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUDICLO 75 (Macleods)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('75')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUDICLO 75 (Macleods)'
);

-- line #11988
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUFENAC 25 (Kapl)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUFENAC 25 (Kapl)'
);

-- line #11989
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUFENAC 100 (Kapl)',
	'Diclofenac Sod.',
	'SR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUFENAC 100 (Kapl)'
);

-- line #11990
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUFENAC 50 (Kapl)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUFENAC 50 (Kapl)'
);

-- line #11991
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCUNAC 0.1 (Sante V.)',
	'Diclofenac Sod.',
	'DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCUNAC 0.1 (Sante V.)'
);

-- line #11992
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Diclofenac Sod.', u'always_empty': u'', u'form': u'INJ', u'brand': u'ONAFEN', u'strength_3': u'', u'company': u'Sayona', u'unit': u''}

-- line #11993
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONTAC 25 (Elder)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONTAC 25 (Elder)'
);

-- line #11994
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONTAC 50 (Elder)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONTAC 50 (Elder)'
);

-- line #11995
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORONAC 25 (Embiotic Lab.)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORONAC 25 (Embiotic Lab.)'
);

-- line #11996
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORONAC 100 (Embiotic Lab.)',
	'Diclofenac Sod.',
	'SR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORONAC 100 (Embiotic Lab.)'
);

-- line #11997
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORONAC 50 (Embiotic Lab.)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORONAC 50 (Embiotic Lab.)'
);

-- line #11998
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSTEOFLAM 25 (Indoco Rem.)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSTEOFLAM 25 (Indoco Rem.)'
);

-- line #11999
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSTEOFLAM 50 (Indoco Rem.)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSTEOFLAM 50 (Indoco Rem.)'
);

-- line #12000
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXALGIN-D 25 (Zydus Cadila)',
	'Diclofenac Sod.',
	'AMP',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXALGIN-D 25 (Zydus Cadila)'
);

-- line #12001
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXALGIN 0.1 (Zydus Cadila)',
	'Diclofenac Sod.',
	'DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXALGIN 0.1 (Zydus Cadila)'
);

-- line #12002
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXALGIN NANO 1 (Zydus Cad.)',
	'Diclofenac Sod.',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXALGIN NANO 1 (Zydus Cad.)'
);

-- line #12003
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXALGIN 100 (Zydus Cadila)',
	'Diclofenac Sod.',
	'SR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXALGIN 100 (Zydus Cadila)'
);

-- line #12004
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXYNAL 25 (Euphoric)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXYNAL 25 (Euphoric)'
);

-- line #12005
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAIN OFF 25 (Mercury)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML(4'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAIN OFF 25 (Mercury)'
);

-- line #12006
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAINOXOL 25 (Graf Lab.)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAINOXOL 25 (Graf Lab.)'
);

-- line #12007
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARAFORTAN 25 (Khandelwal)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARAFORTAN 25 (Khandelwal)'
);

-- line #12008
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERKOGESIC 25 (Perk Ph.)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERKOGESIC 25 (Perk Ph.)'
);

-- line #12009
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Diclofenac Sod.', u'always_empty': u'', u'form': u'INJ', u'brand': u'PHENADIC', u'strength_3': u'', u'company': u'SANCHEZ LAB.', u'unit': u''}

-- line #12010
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POWERFLAM 50 (Alkem)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POWERFLAM 50 (Alkem)'
);

-- line #12011
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROFENAC 0.1 (Protec)',
	'Diclofenac Sod.',
	'DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROFENAC 0.1 (Protec)'
);

-- line #12012
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROFENAC PLUS 50 (Cipla)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROFENAC PLUS 50 (Cipla)'
);

-- line #12013
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAPINAC 25 (Varun Life)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAPINAC 25 (Varun Life)'
);

-- line #12014
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REACTINE 25 (Cipla)',
	'Diclofenac Sod.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/3ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REACTINE 25 (Cipla)'
);

-- line #12015
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REACTINE 100 (Cipla)',
	'Diclofenac Sod.',
	'SR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REACTINE 100 (Cipla)'
);

-- line #12016
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REACTINE 50 (Cipla)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REACTINE 50 (Cipla)'
);

-- line #12017
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REDU 50 (Osho Ph.)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REDU 50 (Osho Ph.)'
);

-- line #12018
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELAXYL 100 (Franco I.)',
	'Diclofenac Sod.',
	'SR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELAXYL 100 (Franco I.)'
);

-- line #12019
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELAXYL 50 (Franco I.)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELAXYL 50 (Franco I.)'
);

-- line #12020
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RHUMADIC 50 (Shaimil)',
	'Diclofenac Sod.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RHUMADIC 50 (Shaimil)'
);

-- line #12021
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KLOX-D 250 (HETERO HC.)',
	'DICLOXACILLIN',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg(SOD.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KLOX-D 250 (HETERO HC.)'
);

-- line #12022
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KLOX-D 500 (HETERO HC.)',
	'DICLOXACILLIN',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg(SOD.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KLOX-D 500 (HETERO HC.)'
);

-- line #12023
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRUSPASM 20 (Brooks Ph.)',
	'Dicyclomine Hcl.',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRUSPASM 20 (Brooks Ph.)'
);

-- line #12024
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CENTWIN 10 (Centaur)',
	'Dicyclomine Hcl.',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CENTWIN 10 (Centaur)'
);

-- line #12025
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOMIN 10 (Claris L.)',
	'Dicyclomine Hcl.',
	'DPS',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOMIN 10 (Claris L.)'
);

-- line #12026
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOMIN 20 (Claris L.)',
	'Dicyclomine Hcl.',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOMIN 20 (Claris L.)'
);

-- line #12027
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COLIGON 20 (Fourrts)',
	'Dicyclomine Hcl.',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COLIGON 20 (Fourrts)'
);

-- line #12028
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Dicyclomine Hcl.', u'always_empty': u'', u'form': u'TAB', u'brand': u'COLINET', u'strength_3': u'', u'company': u'Bal Ph.', u'unit': u''}

-- line #12029
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COLIZA 10 (Dwd)',
	'Dicyclomine Hcl.',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COLIZA 10 (Dwd)'
);

-- line #12030
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYCLOPAM 10 (Indoco Rem.)',
	'Dicyclomine Hcl.',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYCLOPAM 10 (Indoco Rem.)'
);

-- line #12031
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYCLOPAM 10 (Indoco Rem.)',
	'Dicyclomine Hcl.',
	'VIAL',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYCLOPAM 10 (Indoco Rem.)'
);

-- line #12032
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYCLOZOBID 10 (Nicholas)',
	'Dicyclomine Hcl.',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYCLOZOBID 10 (Nicholas)'
);

-- line #12033
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECOLIC 10 (Kontest)',
	'Dicyclomine Hcl.',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECOLIC 10 (Kontest)'
);

-- line #12034
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICLOMINE 20 (Sanjivani)',
	'Dicyclomine Hcl.',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICLOMINE 20 (Sanjivani)'
);

-- line #12035
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICMOL 20 (Pfiscar Ind.)',
	'Dicyclomine Hcl.',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICMOL 20 (Pfiscar Ind.)'
);

-- line #12036
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICYCLOMINE 20 (Claris L.)',
	'Dicyclomine Hcl.',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICYCLOMINE 20 (Claris L.)'
);

-- line #12037
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIMACE-P 20 (UNISEARCH HC.)',
	'Dicyclomine Hcl.',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIMACE-P 20 (UNISEARCH HC.)'
);

-- line #12038
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIOSPAS 10 (Shalaks)',
	'Dicyclomine Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg/20'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIOSPAS 10 (Shalaks)'
);

-- line #12039
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYSMEN 10 (Svizera)',
	'Dicyclomine Hcl.',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYSMEN 10 (Svizera)'
);

-- line #12040
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUPISPAS 10 (Lupin)',
	'Dicyclomine Hcl.',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUPISPAS 10 (Lupin)'
);

-- line #12041
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Dicyclomine Hcl.', u'always_empty': u'', u'form': u'INJ', u'brand': u'MEFOSPAS', u'strength_3': u'', u'company': u'SANCHEZ LAB.', u'unit': u''}

-- line #12042
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEFTAL SPAS 10 (Blue Cross)',
	'Dicyclomine Hcl.',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEFTAL SPAS 10 (Blue Cross)'
);

-- line #12043
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEFTAL-SPAS MULTI DOSE 10 (Blue Cross)',
	'Dicyclomine Hcl.',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg(BENZYL ALCOHOL 2'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEFTAL-SPAS MULTI DOSE 10 (Blue Cross)'
);

-- line #12044
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIPCOL 20 (Geno Ph.)',
	'Dicyclomine Hcl.',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIPCOL 20 (Geno Ph.)'
);

-- line #12045
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DDRETRO 250 (Cytomed(Alkem))',
	'Didanosine',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DDRETRO 250 (Cytomed(Alkem))'
);

-- line #12046
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DDRETRO 400 (Cytomed(Alkem))',
	'Didanosine',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DDRETRO 400 (Cytomed(Alkem))'
);

-- line #12047
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DINEX 250 (Cipla)',
	'Didanosine',
	'EC CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DINEX 250 (Cipla)'
);

-- line #12048
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DINEX 400 (Cipla)',
	'Didanosine',
	'EC CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DINEX 400 (Cipla)'
);

-- line #12049
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DINEX 100 (Cipla)',
	'Didanosine',
	'EC CHEWTAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DINEX 100 (Cipla)'
);

-- line #12050
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DINOSIN 250 (HETERO HC.)',
	'Didanosine',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DINOSIN 250 (HETERO HC.)'
);

-- line #12051
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DINOSIN 400 (HETERO HC.)',
	'Didanosine',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DINOSIN 400 (HETERO HC.)'
);

-- line #12052
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DINOSIN EP 250 (HETERO HC.)',
	'Didanosine',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DINOSIN EP 250 (HETERO HC.)'
);

-- line #12053
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DINOSIN EP 400 (HETERO HC.)',
	'Didanosine',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DINOSIN EP 400 (HETERO HC.)'
);

-- line #12054
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DINOSIN 100 (HETERO HC.)',
	'Didanosine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DINOSIN 100 (HETERO HC.)'
);

-- line #12055
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'D-SINE 100 (Mcneil & ARGUS)',
	'Didanosine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'D-SINE 100 (Mcneil & ARGUS)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'D-SINE 200 (Mcneil & ARGUS)',
	'Didanosine',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'D-SINE 200 (Mcneil & ARGUS)'
);

-- line #12056
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MULTIGESIC 10 (Nicholas)',
	'Diethylamine Salicylate',
	'GEL',
	gm.nullify_empty_string('10')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MULTIGESIC 10 (Nicholas)'
);

-- line #12057
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BANOCIDE-F 100 (Gsk)',
	'Diethyl Carbamazine Citrate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BANOCIDE-F 100 (Gsk)'
);

-- line #12058
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BANOCIDE 50 (Gsk)',
	'Diethyl Carbamazine Citrate',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BANOCIDE 50 (Gsk)'
);

-- line #12059
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BANOCIDE 50 (Gsk)',
	'Diethyl Carbamazine Citrate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BANOCIDE 50 (Gsk)'
);

-- line #12060
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECET 150 (RND LAB)',
	'Diethyl Carbamazine Citrate',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECET 150 (RND LAB)'
);

-- line #12061
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEECEE PAED 50 (Shrinivas)',
	'Diethyl Carbamazine Citrate',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEECEE PAED 50 (Shrinivas)'
);

-- line #12062
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEECEE 120 (Shrinivas)',
	'Diethyl Carbamazine Citrate',
	'SYR',
	gm.nullify_empty_string('120')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEECEE 120 (Shrinivas)'
);

-- line #12063
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEECEE 100 (Shrinivas)',
	'Diethyl Carbamazine Citrate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEECEE 100 (Shrinivas)'
);

-- line #12064
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICARB 100 (Inga)',
	'Diethyl Carbamazine Citrate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICARB 100 (Inga)'
);

-- line #12065
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EOFIL 150 (Fourrts)',
	'Diethyl Carbamazine Citrate',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EOFIL 150 (Fourrts)'
);

-- line #12066
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HETRAZAN 120 (Wyeth)',
	'Diethyl Carbamazine Citrate',
	'SYR',
	gm.nullify_empty_string('120')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HETRAZAN 120 (Wyeth)'
);

-- line #12067
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HETRAZAN 100 (Wyeth)',
	'Diethyl Carbamazine Citrate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HETRAZAN 100 (Wyeth)'
);

-- line #12068
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HETRAZAN 50 (Wyeth)',
	'Diethyl Carbamazine Citrate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HETRAZAN 50 (Wyeth)'
);

-- line #12069
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIFLORATE 0.05 (Micro Labs)',
	'DIFLORASONE DIACETATE',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIFLORATE 0.05 (Micro Labs)'
);

-- line #12070
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIFLORATE 0.05 (Micro Labs)',
	'DIFLORASONE DIACETATE',
	'OINT',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIFLORATE 0.05 (Micro Labs)'
);

-- line #12071
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDDIG 0.25 (Mano)',
	'Digoxin',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDDIG 0.25 (Mano)'
);

-- line #12072
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDIN 0.25 (Chemo Bio.)',
	'Digoxin',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDIN 0.25 (Chemo Bio.)'
);

-- line #12073
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDIOXIN 0.25 (Novartis)',
	'Digoxin',
	'TAB/INJ',
	gm.nullify_empty_string('0.25')::numeric,
	'mg/0.25'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDIOXIN 0.25 (Novartis)'
);

-- line #12074
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'2ML', u'substance': u'Digoxin', u'always_empty': u'', u'form': u'AMP', u'brand': u'CELOXIN', u'strength_3': u'', u'company': u'CELON(REVILON)', u'unit': u''}

-- line #12075
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELOXIN 1.5 (CELON(REVILON))',
	'Digoxin',
	'SYR',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELOXIN 1.5 (CELON(REVILON))'
);

-- line #12076
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELOXIN 0.25 (CELON(REVILON))',
	'Digoxin',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELOXIN 0.25 (CELON(REVILON))'
);

-- line #12077
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIGITRAN 0.25 (Macleods)',
	'Digoxin',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIGITRAN 0.25 (Macleods)'
);

-- line #12078
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIGON 0.25 (TASMED)',
	'Digoxin',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIGON 0.25 (TASMED)'
);

-- line #12079
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIGOSYP 0.05 (Le Sante)',
	'Digoxin',
	'LIQ',
	gm.nullify_empty_string('0.05')::numeric,
	'%(+ ETHANOL 0.053)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIGOSYP 0.05 (Le Sante)'
);

-- line #12080
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIGOXIN 0.5 (Gsk)',
	'Digoxin',
	'INJ',
	gm.nullify_empty_string('0.5')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIGOXIN 0.5 (Gsk)'
);

-- line #12081
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,05', u'strength_2': u'', u'substance': u'Digoxin', u'always_empty': u'', u'form': u'', u'brand': u'DIGOXIN PAED ELX', u'strength_3': u'', u'company': u'Gsk', u'unit': u'mg'}

-- line #12082
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIGOX 0.25 (Zydus Cadila)',
	'Digoxin',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIGOX 0.25 (Zydus Cadila)'
);

-- line #12083
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIXIN 0.5 (Samarth)',
	'Digoxin',
	'AMP',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIXIN 0.5 (Samarth)'
);

-- line #12084
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIXIN 1.5 (Samarth)',
	'Digoxin',
	'SYR',
	gm.nullify_empty_string('1.5')::numeric,
	'mg/30ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIXIN 1.5 (Samarth)'
);

-- line #12085
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIXIN 0.25 (Samarth)',
	'Digoxin',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIXIN 0.25 (Samarth)'
);

-- line #12086
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANOXIN 0.25 (Gsk)',
	'Digoxin',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANOXIN 0.25 (Gsk)'
);

-- line #12087
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYDRALAZE 25 (Dahlia Ph.)',
	'Dihydralazine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYDRALAZE 25 (Dahlia Ph.)'
);

-- line #12088
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEPRESOL 25 (Novartis)',
	'Dihydralazine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEPRESOL 25 (Novartis)'
);

-- line #12089
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DHE 1 (Inga)',
	'Dihydroergotamine Mesylate',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DHE 1 (Inga)'
);

-- line #12090
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIGRANIL 1 (Inga)',
	'Dihydroergotamine Mesylate',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIGRANIL 1 (Inga)'
);

-- line #12091
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CERELOID 1 (Sun)',
	'Dihydroergotoxine(Codergocrine)',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CERELOID 1 (Sun)'
);

-- line #12092
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.3 ML', u'strength_2': u'ML', u'substance': u'Dihydroergotoxine(Codergocrine)', u'always_empty': u'', u'form': u'INJ', u'brand': u'HYDERGINE', u'strength_3': u'', u'company': u'Novartis', u'unit': u''}

-- line #12093
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYDERGINE 1 (Novartis)',
	'Dihydroergotoxine(Codergocrine)',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYDERGINE 1 (Novartis)'
);

-- line #12094
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Dihydrotestosterone', u'always_empty': u'', u'form': u'GEL', u'brand': u'ANDRACTIM', u'strength_3': u'', u'company': u'Chemech', u'unit': u''}

-- line #12095
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIODOQUIN 210 (Rpg Life)',
	'Di-Iodohydroxyquin',
	'SUS',
	gm.nullify_empty_string('210')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIODOQUIN 210 (Rpg Life)'
);

-- line #12096
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIODOQUIN 650 (Rpg Life)',
	'Di-Iodohydroxyquin',
	'TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIODOQUIN 650 (Rpg Life)'
);

-- line #12097
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORMELIAN 100 (Khandelwal)',
	'Dilazep',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORMELIAN 100 (Khandelwal)'
);

-- line #12098
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMICLINE 500 (Franco I.)',
	'Diloxanide Furoate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMICLINE 500 (Franco I.)'
);

-- line #12099
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FURAMIDE 500 (Abbott)',
	'Diloxanide Furoate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FURAMIDE 500 (Abbott)'
);

-- line #12100
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANGIZEM 120 (Sun)',
	'Diltiazem',
	'CD TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANGIZEM 120 (Sun)'
);

-- line #12101
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANGIZEM 180 (Sun)',
	'Diltiazem',
	'CD TAB',
	gm.nullify_empty_string('180')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANGIZEM 180 (Sun)'
);

-- line #12102
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANGIZEM 90 (Sun)',
	'Diltiazem',
	'CD TAB',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANGIZEM 90 (Sun)'
);

-- line #12103
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANGIZEM 30 (Sun)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANGIZEM 30 (Sun)'
);

-- line #12104
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANGIZEM 60 (Sun)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANGIZEM 60 (Sun)'
);

-- line #12105
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANGIZEN 120 (Sun)',
	'Diltiazem',
	'DP CAP',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANGIZEN 120 (Sun)'
);

-- line #12106
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANGIZEN 90 (Sun)',
	'Diltiazem',
	'DP CAP',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANGIZEN 90 (Sun)'
);

-- line #12107
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDEM 30 (A.F.D.)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDEM 30 (A.F.D.)'
);

-- line #12108
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDEM 60 (A.F.D.)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDEM 60 (A.F.D.)'
);

-- line #12109
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDISEC 120 (TAJ PH.)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDISEC 120 (TAJ PH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDISEC 180 (TAJ PH.)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('180')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDISEC 180 (TAJ PH.)'
);

-- line #12110
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDISEC 30 (TAJ PH.)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDISEC 30 (TAJ PH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDISEC 60 (TAJ PH.)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDISEC 60 (TAJ PH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDISEC 80 (TAJ PH.)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDISEC 80 (TAJ PH.)'
);

-- line #12111
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARZEM 30 (AEGIS)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARZEM 30 (AEGIS)'
);

-- line #12112
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHANNEL 120 (Micro Labs)',
	'Diltiazem',
	'SR TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHANNEL 120 (Micro Labs)'
);

-- line #12113
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHANNEL 90 (Micro Labs)',
	'Diltiazem',
	'SR TAB',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHANNEL 90 (Micro Labs)'
);

-- line #12114
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHANNEL 30 (Micro Labs)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHANNEL 30 (Micro Labs)'
);

-- line #12115
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHANNEL 60 (Micro Labs)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHANNEL 60 (Micro Labs)'
);

-- line #12116
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORIEM 120 (Stancare)',
	'Diltiazem',
	'XL CAP',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORIEM 120 (Stancare)'
);

-- line #12117
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORIEM 180 (Stancare)',
	'Diltiazem',
	'XL CAP',
	gm.nullify_empty_string('180')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORIEM 180 (Stancare)'
);

-- line #12118
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORIEM 240 (Stancare)',
	'Diltiazem',
	'XL CAP',
	gm.nullify_empty_string('240')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORIEM 240 (Stancare)'
);

-- line #12119
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CREMAGEL DILTIAZEM 2 (ABBOTT)',
	'Diltiazem',
	'GEL %',
	gm.nullify_empty_string('2')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CREMAGEL DILTIAZEM 2 (ABBOTT)'
);

-- line #12120
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICARD 90 (Intas)',
	'Diltiazem',
	'SR TAB',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICARD 90 (Intas)'
);

-- line #12121
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICARD 30 (Intas)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICARD 30 (Intas)'
);

-- line #12122
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICARD 60 (Intas)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICARD 60 (Intas)'
);

-- line #12123
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILCAL 90 (SANOFI AV.)',
	'Diltiazem',
	'SR TAB',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILCAL 90 (SANOFI AV.)'
);

-- line #12124
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILCAL 30 (SANOFI AV.)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILCAL 30 (SANOFI AV.)'
);

-- line #12125
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILCAL 60 (SANOFI AV.)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILCAL 60 (SANOFI AV.)'
);

-- line #12126
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILCARDIA 90 (J.B.Chem.)',
	'Diltiazem',
	'SR TAB',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILCARDIA 90 (J.B.Chem.)'
);

-- line #12127
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILCARDIA 30 (J.B.Chem.)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILCARDIA 30 (J.B.Chem.)'
);

-- line #12128
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILCARDIA 60 (J.B.Chem.)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILCARDIA 60 (J.B.Chem.)'
);

-- line #12129
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILCARE 30 (Olcare)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILCARE 30 (Olcare)'
);

-- line #12130
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILCARE 60 (Olcare)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILCARE 60 (Olcare)'
);

-- line #12131
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILCHEM 30 (Chemo Bio.)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILCHEM 30 (Chemo Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILCHEM 60 (Chemo Bio.)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILCHEM 60 (Chemo Bio.)'
);

-- line #12132
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILCONTIN 60 (Modi Mundi)',
	'Diltiazem',
	'CR TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILCONTIN 60 (Modi Mundi)'
);

-- line #12133
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILCONTIN 120 (Modi Mundi)',
	'Diltiazem',
	'XL TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILCONTIN 120 (Modi Mundi)'
);

-- line #12134
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILCONTIN 180 (Modi Mundi)',
	'Diltiazem',
	'XL TAB',
	gm.nullify_empty_string('180')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILCONTIN 180 (Modi Mundi)'
);

-- line #12135
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILCONTIN 90 (Modi Mundi)',
	'Diltiazem',
	'XL TAB',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILCONTIN 90 (Modi Mundi)'
);

-- line #12136
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILCOR 30 (Mano)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILCOR 30 (Mano)'
);

-- line #12137
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILCOR 60 (Mano)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILCOR 60 (Mano)'
);

-- line #12138
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILGARD 30 (Cipla)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILGARD 30 (Cipla)'
);

-- line #12139
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILGARD 120 (Cipla)',
	'Diltiazem',
	'XL CAP',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILGARD 120 (Cipla)'
);

-- line #12140
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILGARD 180 (Cipla)',
	'Diltiazem',
	'XL CAP',
	gm.nullify_empty_string('180')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILGARD 180 (Cipla)'
);

-- line #12141
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILGARD 90 (Cipla)',
	'Diltiazem',
	'XL CAP',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILGARD 90 (Cipla)'
);

-- line #12142
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILGINA 30 (Kopran)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILGINA 30 (Kopran)'
);

-- line #12143
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILGINA 60 (Kopran)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILGINA 60 (Kopran)'
);

-- line #12144
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILI 30 (Mapra)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILI 30 (Mapra)'
);

-- line #12145
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILI 60 (Mapra)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILI 60 (Mapra)'
);

-- line #12146
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILOCOR 30 (BARODA)',
	'Diltiazem',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILOCOR 30 (BARODA)'
);

-- line #12147
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILOCOR 60 (BARODA)',
	'Diltiazem',
	'CAP',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILOCOR 60 (BARODA)'
);

-- line #12148
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILOCOR 120 (BARODA)',
	'Diltiazem',
	'XR TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILOCOR 120 (BARODA)'
);

-- line #12149
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILOCOR 90 (BARODA)',
	'Diltiazem',
	'XR TAB',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILOCOR 90 (BARODA)'
);

-- line #12150
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILTARA 30 (MEDISYS)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILTARA 30 (MEDISYS)'
);

-- line #12151
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILTER 120 (Sun)',
	'Diltiazem',
	'CD CAP',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILTER 120 (Sun)'
);

-- line #12152
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILTER 60 (Sun)',
	'Diltiazem',
	'CD CAP',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILTER 60 (Sun)'
);

-- line #12153
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILTER 90 (Sun)',
	'Diltiazem',
	'CD CAP',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILTER 90 (Sun)'
);

-- line #12154
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILTIAZ 30 (Shreya)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILTIAZ 30 (Shreya)'
);

-- line #12155
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILTIAZ 60 (Shreya)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILTIAZ 60 (Shreya)'
);

-- line #12156
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILTIAZ 120 (Shreya)',
	'Diltiazem',
	'XL TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILTIAZ 120 (Shreya)'
);

-- line #12157
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILTIAZ 180 (Shreya)',
	'Diltiazem',
	'XL TAB',
	gm.nullify_empty_string('180')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILTIAZ 180 (Shreya)'
);

-- line #12158
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILTIAZ 90 (Shreya)',
	'Diltiazem',
	'XL TAB',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILTIAZ 90 (Shreya)'
);

-- line #12159
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILTICARD 30 (Intra Lab)',
	'Diltiazem',
	'SR TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILTICARD 30 (Intra Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILTICARD 60 (Intra Lab)',
	'Diltiazem',
	'SR TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILTICARD 60 (Intra Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILTICARD 90 (Intra Lab)',
	'Diltiazem',
	'SR TAB',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILTICARD 90 (Intra Lab)'
);

-- line #12160
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILTILONG 30 (Mankind)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILTILONG 30 (Mankind)'
);

-- line #12161
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILTILONG 60 (Mankind)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILTILONG 60 (Mankind)'
);

-- line #12162
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILTILONG 90 (Mankind)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILTILONG 90 (Mankind)'
);

-- line #12163
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILTIME 120 (Zydus cnd)',
	'Diltiazem',
	'SR TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILTIME 120 (Zydus cnd)'
);

-- line #12164
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILTIME 90 (Zydus cnd)',
	'Diltiazem',
	'SR TAB',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILTIME 90 (Zydus cnd)'
);

-- line #12165
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILTIME 30 (Zydus cnd)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILTIME 30 (Zydus cnd)'
);

-- line #12166
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILTIME 60 (Zydus cnd)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILTIME 60 (Zydus cnd)'
);

-- line #12167
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILTIP 30 (Dallas Ph.)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILTIP 30 (Dallas Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILTIP 60 (Dallas Ph.)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILTIP 60 (Dallas Ph.)'
);

-- line #12168
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILTISYN 30 (Themis)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILTISYN 30 (Themis)'
);

-- line #12169
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILTISYN 60 (Themis)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILTISYN 60 (Themis)'
);

-- line #12170
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILTI 30 (Stallion)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILTI 30 (Stallion)'
);

-- line #12171
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILTI 60 (Stallion)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILTI 60 (Stallion)'
);

-- line #12172
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILTP 30 (Taurus Lab)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILTP 30 (Taurus Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILTP 60 (Taurus Lab)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILTP 60 (Taurus Lab)'
);

-- line #12173
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILT 30 (Sain Med.)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILT 30 (Sain Med.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILT 60 (Sain Med.)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILT 60 (Sain Med.)'
);

-- line #12174
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILZEM 120 (Torrent)',
	'Diltiazem',
	'CD CAP',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILZEM 120 (Torrent)'
);

-- line #12175
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILZEM 180 (Torrent)',
	'Diltiazem',
	'CD CAP',
	gm.nullify_empty_string('180')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILZEM 180 (Torrent)'
);

-- line #12176
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILZEM 240 (Torrent)',
	'Diltiazem',
	'CD CAP',
	gm.nullify_empty_string('240')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILZEM 240 (Torrent)'
);

-- line #12177
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILZEM 90 (Torrent)',
	'Diltiazem',
	'CD CAP',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILZEM 90 (Torrent)'
);

-- line #12178
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILZEM 5 (Torrent)',
	'Diltiazem',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILZEM 5 (Torrent)'
);

-- line #12179
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILZEM 90 (Torrent)',
	'Diltiazem',
	'SR TAB',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILZEM 90 (Torrent)'
);

-- line #12180
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILZEM 30 (Torrent)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILZEM 30 (Torrent)'
);

-- line #12181
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILZEM 60 (Torrent)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILZEM 60 (Torrent)'
);

-- line #12182
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILZOR 120 (VHB)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILZOR 120 (VHB)'
);

-- line #12183
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILZOR 30 (VHB)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILZOR 30 (VHB)'
);

-- line #12184
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILZOR 60 (VHB)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILZOR 60 (VHB)'
);

-- line #12185
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILZOR 90 (VHB)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILZOR 90 (VHB)'
);

-- line #12186
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DTM 90 (Biochem)',
	'Diltiazem',
	'SR TAB',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DTM 90 (Biochem)'
);

-- line #12187
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DTM 30 (Biochem)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DTM 30 (Biochem)'
);

-- line #12188
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DTM 60 (Biochem)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DTM 60 (Biochem)'
);

-- line #12189
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DZ 90 (Sunij)',
	'Diltiazem',
	'CD CAP',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DZ 90 (Sunij)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DZ 120 (Sunij)',
	'Diltiazem',
	'CD CAP',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DZ 120 (Sunij)'
);

-- line #12190
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DZ 30 (Sunij)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DZ 30 (Sunij)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DZ 60 (Sunij)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DZ 60 (Sunij)'
);

-- line #12191
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEARTIL 120 (Life Med.)',
	'Diltiazem',
	'CR TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEARTIL 120 (Life Med.)'
);

-- line #12192
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEARTIL 90 (Life Med.)',
	'Diltiazem',
	'CR TAB',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEARTIL 90 (Life Med.)'
);

-- line #12193
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEARTIL 120 (Life Med.)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEARTIL 120 (Life Med.)'
);

-- line #12194
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEARTIL 30 (Life Med.)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEARTIL 30 (Life Med.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEARTIL 60 (Life Med.)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEARTIL 60 (Life Med.)'
);

-- line #12195
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HERBESSER 100 (TANABE)',
	'Diltiazem',
	'ER CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HERBESSER 100 (TANABE)'
);

-- line #12196
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HERBESSER 200 (TANABE)',
	'Diltiazem',
	'ER CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HERBESSER 200 (TANABE)'
);

-- line #12197
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HERBESSER 90 (TANABE)',
	'Diltiazem',
	'SR CAP',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HERBESSER 90 (TANABE)'
);

-- line #12198
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ICIDIL 120 (Nicholas)',
	'Diltiazem',
	'CD TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ICIDIL 120 (Nicholas)'
);

-- line #12199
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ICIDIL 90 (Nicholas)',
	'Diltiazem',
	'CD TAB',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ICIDIL 90 (Nicholas)'
);

-- line #12200
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ICIDIL 90 (Piramal Hc.)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ICIDIL 90 (Piramal Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ICIDIL 120 (Piramal Hc.)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ICIDIL 120 (Piramal Hc.)'
);

-- line #12201
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IONOZEM 120 (PFIZER)',
	'Diltiazem',
	'CD TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IONOZEM 120 (PFIZER)'
);

-- line #12202
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IONOZEM 90 (PFIZER)',
	'Diltiazem',
	'CD TAB',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IONOZEM 90 (PFIZER)'
);

-- line #12203
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IONOZEM 30 (PFIZER)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IONOZEM 30 (PFIZER)'
);

-- line #12204
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IONOZEM 60 (PFIZER)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IONOZEM 60 (PFIZER)'
);

-- line #12205
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISDIL 30 (Stadmed)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISDIL 30 (Stadmed)'
);

-- line #12206
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISDIL 60 (Stadmed)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISDIL 60 (Stadmed)'
);

-- line #12207
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISKI 120 (Stadmed)',
	'Diltiazem',
	'SR TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISKI 120 (Stadmed)'
);

-- line #12208
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISKI 90 (Stadmed)',
	'Diltiazem',
	'SR TAB',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISKI 90 (Stadmed)'
);

-- line #12209
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISKI 30 (Stadmed)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISKI 30 (Stadmed)'
);

-- line #12210
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISKI 60 (Stadmed)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISKI 60 (Stadmed)'
);

-- line #12211
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KAIZEM 120 (Wockhardt)',
	'Diltiazem',
	'CD CAP',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KAIZEM 120 (Wockhardt)'
);

-- line #12212
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KAIZEM 180 (Wockhardt)',
	'Diltiazem',
	'CD CAP',
	gm.nullify_empty_string('180')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KAIZEM 180 (Wockhardt)'
);

-- line #12213
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KAIZEM 30 (Wockhardt)',
	'Diltiazem',
	'CD CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KAIZEM 30 (Wockhardt)'
);

-- line #12214
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KAIZEM 60 (Wockhardt)',
	'Diltiazem',
	'CD CAP',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KAIZEM 60 (Wockhardt)'
);

-- line #12215
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KAIZEM 90 (Wockhardt)',
	'Diltiazem',
	'CD CAP',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KAIZEM 90 (Wockhardt)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KAIZEM 120 (Wockhardt)',
	'Diltiazem',
	'CD CAP',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KAIZEM 120 (Wockhardt)'
);

-- line #12216
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KAIZEM 90 (Wockhardt)',
	'Diltiazem',
	'CD CAP',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KAIZEM 90 (Wockhardt)'
);

-- line #12217
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MASDIL 180 (Lupin)',
	'Diltiazem',
	'OD TAB',
	gm.nullify_empty_string('180')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MASDIL 180 (Lupin)'
);

-- line #12218
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MASDIL 240 (Lupin)',
	'Diltiazem',
	'OD TAB',
	gm.nullify_empty_string('240')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MASDIL 240 (Lupin)'
);

-- line #12219
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MASDIL 120 (Lupin)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MASDIL 120 (Lupin)'
);

-- line #12220
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MASDIL 30 (Lupin)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MASDIL 30 (Lupin)'
);

-- line #12221
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MASDIL 60 (Lupin)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MASDIL 60 (Lupin)'
);

-- line #12222
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MASDIL 90 (Lupin)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MASDIL 90 (Lupin)'
);

-- line #12223
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILCARD 30 (Shaimil)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILCARD 30 (Shaimil)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILCARD 60 (Shaimil)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILCARD 60 (Shaimil)'
);

-- line #12224
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONZEM 180 (Novartis)',
	'Diltiazem',
	'SR CAP',
	gm.nullify_empty_string('180')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONZEM 180 (Novartis)'
);

-- line #12225
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONZEM 90 (Novartis)',
	'Diltiazem',
	'SR CAP',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONZEM 90 (Novartis)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONZEM 120 (Novartis)',
	'Diltiazem',
	'SR CAP',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONZEM 120 (Novartis)'
);

-- line #12226
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONZEM 30 (Novartis)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONZEM 30 (Novartis)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONZEM 60 (Novartis)',
	'Diltiazem',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONZEM 60 (Novartis)'
);

-- line #12227
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q-DIL 120 (Argus)',
	'Diltiazem',
	'CD TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q-DIL 120 (Argus)'
);

-- line #12228
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q-DIL 90 (Argus)',
	'Diltiazem',
	'CD TAB',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q-DIL 90 (Argus)'
);

-- line #12229
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DRAMAMINE 50 (Rpg Life)',
	'Dimenhydrinate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DRAMAMINE 50 (Rpg Life)'
);

-- line #12230
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DRAMAMINE 15.63 (Rpg Life)',
	'Dimenhydrinate',
	'LIQ',
	gm.nullify_empty_string('15.63')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DRAMAMINE 15.63 (Rpg Life)'
);

-- line #12231
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DRAMAMINE 50 (Rpg Life)',
	'Dimenhydrinate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DRAMAMINE 50 (Rpg Life)'
);

-- line #12232
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DRAMINATE 50 (Rpg Life)',
	'Dimenhydrinate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DRAMINATE 50 (Rpg Life)'
);

-- line #12233
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DRAMINATE 3.125 (Rpg Life)',
	'Dimenhydrinate',
	'LIQ',
	gm.nullify_empty_string('3.125')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DRAMINATE 3.125 (Rpg Life)'
);

-- line #12234
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DRAMINATE 50 (Rpg Life)',
	'Dimenhydrinate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DRAMINATE 50 (Rpg Life)'
);

-- line #12235
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRAVOL 50 (Wallace)',
	'Dimenhydrinate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRAVOL 50 (Wallace)'
);

-- line #12236
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BAL50 50 (Samarth)',
	'Dimercaprol',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BAL50 50 (Samarth)'
);

-- line #12237
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BAL 100 (ABBOTT)',
	'Dimercaprol',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BAL 100 (ABBOTT)'
);

-- line #12238
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICON-I 40 (Brawn Lab)',
	'Dimethicone',
	'DPS',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICON-I 40 (Brawn Lab)'
);

-- line #12239
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEDRIN 4 (Win Medicare)',
	'Dimethicone',
	'SOL',
	gm.nullify_empty_string('4')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEDRIN 4 (Win Medicare)'
);

-- line #12240
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2,5', u'strength_2': u'', u'substance': u'Dimethindene Maleate', u'always_empty': u'', u'form': u'', u'brand': u'FORISTAL LONTABS', u'strength_3': u'', u'company': u'Novartis', u'unit': u'mg'}

-- line #12241
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORISTAL 1 (Novartis)',
	'Dimethindene Maleate',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORISTAL 1 (Novartis)'
);

-- line #12242
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10', u'strength_2': u'', u'substance': u'Dinoprostone', u'always_empty': u'', u'form': u'', u'brand': u'CERVIDIL PASS', u'strength_3': u'', u'company': u'Solvay Ph.', u'unit': u'mg (PROSTAGLANDIN E2)'}

-- line #12243
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CERVIPRIME 0.5 (Astrazeneca)',
	'Dinoprostone',
	'GEL',
	gm.nullify_empty_string('0.5')::numeric,
	'mg/3G WITH SYR/CATH.'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CERVIPRIME 0.5 (Astrazeneca)'
);

-- line #12244
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DINORIPE 0.5 (Dr.Reddy''S)',
	'Dinoprostone',
	'GEL',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DINORIPE 0.5 (Dr.Reddy''S)'
);

-- line #12245
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DINORIPE 0.5 (Dr.Reddy''S)',
	'Dinoprostone',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DINORIPE 0.5 (Dr.Reddy''S)'
);

-- line #12246
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PG 0.5 (Dr.Reddy''S)',
	'Dinoprostone',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PG 0.5 (Dr.Reddy''S)'
);

-- line #12247
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,5', u'strength_2': u'', u'substance': u'Dinoprostone', u'always_empty': u'', u'form': u'', u'brand': u'PRIMIGYN', u'strength_3': u'', u'company': u'Bharat S.', u'unit': u'mg'}

-- line #12248
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIMIPROST 0.5 (Astrazeneca)',
	'Dinoprostone',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIMIPROST 0.5 (Astrazeneca)'
);

-- line #12249
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'DIOCTAHEDRAL SMECTITE', u'always_empty': u'', u'form': u'DT', u'brand': u'DIOSMEC', u'strength_3': u'', u'company': u'Organon', u'unit': u''}

-- line #12250
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3G', u'strength_2': u'SAC.', u'substance': u'DIOCTAHEDRAL SMECTITE', u'always_empty': u'', u'form': u'SAC', u'brand': u'DIOSMEC', u'strength_3': u'', u'company': u'Ajanta Ph.', u'unit': u''}

-- line #12251
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3G', u'strength_2': u'', u'substance': u'DIOCTAHEDRAL SMECTITE', u'always_empty': u'', u'form': u'', u'brand': u'PEDISMEC GM', u'strength_3': u'', u'company': u'Rpg Life', u'unit': u''}

-- line #12252
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3G', u'strength_2': u'SAC.', u'substance': u'DIOCTAHEDRAL SMECTITE', u'always_empty': u'', u'form': u'SAC', u'brand': u'RIDOSMEC', u'strength_3': u'', u'company': u'Ajanta Ph.', u'unit': u''}

-- line #12253
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELLUBRIL 100 (Astrazeneca)',
	'Dioctyl Sod.Sulphosuccinate(DOCUSATES)',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELLUBRIL 100 (Astrazeneca)'
);

-- line #12254
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELLUBRIL 50 (Astrazeneca)',
	'Dioctyl Sod.Sulphosuccinate(DOCUSATES)',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELLUBRIL 50 (Astrazeneca)'
);

-- line #12255
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOSLAX 150 (R.B.)',
	'Dioctyl Sod.Sulphosuccinate(DOCUSATES)',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOSLAX 150 (R.B.)'
);

-- line #12256
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,25', u'strength_2': u'', u'substance': u'Dioctyl Sod.Sulphosuccinate(DOCUSATES)', u'always_empty': u'', u'form': u'', u'brand': u'LAXICON ENEMA', u'strength_3': u'', u'company': u'Stadmed', u'unit': u'%SOL.'}

-- line #12257
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAXICON 50 (Stadmed)',
	'Dioctyl Sod.Sulphosuccinate(DOCUSATES)',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAXICON 50 (Stadmed)'
);

-- line #12258
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAXICON 100 (Stadmed)',
	'Dioctyl Sod.Sulphosuccinate(DOCUSATES)',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAXICON 100 (Stadmed)'
);

-- line #12259
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OTOSOFT 50 (Yash Vision)',
	'Dioctyl Sod.Sulphosuccinate(DOCUSATES)',
	'EAR DPS',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OTOSOFT 50 (Yash Vision)'
);

-- line #12260
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAPIMIN 150 (Helios Ph.)',
	'Diosmins',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAPIMIN 150 (Helios Ph.)'
);

-- line #12261
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAPIMIN 300 (Helios Ph.)',
	'Diosmins',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAPIMIN 300 (Helios Ph.)'
);

-- line #12262
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICROSMIN 300 (Emcure)',
	'Diosmins',
	'F. TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICROSMIN 300 (Emcure)'
);

-- line #12263
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENADRYL 25 (Pfizer)',
	'Diphenhydramine Hcl.',
	'CAP',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENADRYL 25 (Pfizer)'
);

-- line #12264
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENADRYL 50 (Pfizer)',
	'Diphenhydramine Hcl.',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENADRYL 50 (Pfizer)'
);

-- line #12265
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENADRYL 2 (Pfizer)',
	'Diphenhydramine Hcl.',
	'CRM',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENADRYL 2 (Pfizer)'
);

-- line #12266
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENADRYL 12.5 (Pfizer)',
	'Diphenhydramine Hcl.',
	'SYR',
	gm.nullify_empty_string('12.5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENADRYL 12.5 (Pfizer)'
);

-- line #12267
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Diphenhydramine Hcl.', u'always_empty': u'', u'form': u'SYR', u'brand': u'COFRYL', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #12268
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COFRYL 25 (Cipla)',
	'Diphenhydramine Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COFRYL 25 (Cipla)'
);

-- line #12269
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIPHTHERIA ANTITOXIN 10 (Haffkine)',
	'DIPHTHERIA ANTITOXIN',
	'V',
	gm.nullify_empty_string('10')::numeric,
	'000IU.'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIPHTHERIA ANTITOXIN 10 (Haffkine)'
);

-- line #12270
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'DIPHTHERIA PERTUSIS AND TETANUS & HIB', u'always_empty': u'', u'form': u'VACC', u'brand': u'PENTAVAC', u'strength_3': u'', u'company': u'Serum Inst.', u'unit': u''}

-- line #12271
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'DIPHTHERIA PERTUSIS AND TETANUS & HIB', u'always_empty': u'', u'form': u'VACC', u'brand': u'QUADROVAX', u'strength_3': u'', u'company': u'Serum Inst.', u'unit': u''}

-- line #12272
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.4G', u'strength_2': u'5ML', u'substance': u'Dipotassium Hydrogen Cit.', u'always_empty': u'', u'form': u'LIQ', u'brand': u'DIPOSOL', u'strength_3': u'', u'company': u'Stadmed', u'unit': u''}

-- line #12273
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDIWELL 100 (Torrent)',
	'Dipyridamole',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDIWELL 100 (Torrent)'
);

-- line #12274
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDIWELL 25 (Torrent)',
	'Dipyridamole',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDIWELL 25 (Torrent)'
);

-- line #12275
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDIWELL 75 (Torrent)',
	'Dipyridamole',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDIWELL 75 (Torrent)'
);

-- line #12276
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPLATOL 100 (Martin & H.)',
	'Dipyridamole',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPLATOL 100 (Martin & H.)'
);

-- line #12277
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPLATOL 25 (Martin & H.)',
	'Dipyridamole',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPLATOL 25 (Martin & H.)'
);

-- line #12278
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYNACARD 100 (U S V)',
	'Dipyridamole',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYNACARD 100 (U S V)'
);

-- line #12279
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERSANTIN 25 (German R.)',
	'Dipyridamole',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERSANTIN 25 (German R.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERSANTIN 100 (German R.)',
	'Dipyridamole',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERSANTIN 100 (German R.)'
);

-- line #12280
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Disodium Hydrogen Citrate', u'always_empty': u'', u'form': u'SYR', u'brand': u'ADKALIZER', u'strength_3': u'', u'company': u'Admac Ph.', u'unit': u''}

-- line #12281
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.38GM', u'strength_2': u'', u'substance': u'Disodium Hydrogen Citrate', u'always_empty': u'', u'form': u'SYR', u'brand': u'ALKALAR', u'strength_3': u'', u'company': u'Orison Ph.', u'unit': u''}

-- line #12282
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.25G', u'strength_2': u'5ML', u'substance': u'Disodium Hydrogen Citrate', u'always_empty': u'', u'form': u'SYR', u'brand': u'ALKALEB', u'strength_3': u'', u'company': u'Leben', u'unit': u''}

-- line #12283
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.4G;5ML', u'strength_2': u'', u'substance': u'Disodium Hydrogen Citrate', u'always_empty': u'', u'form': u'LIQ', u'brand': u'ALKALINE CITRATE', u'strength_3': u'', u'company': u'VERITAZ', u'unit': u''}

-- line #12284
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.25G', u'strength_2': u'5ML', u'substance': u'Disodium Hydrogen Citrate', u'always_empty': u'', u'form': u'SYR', u'brand': u'ALKANORM', u'strength_3': u'', u'company': u'Ultramark', u'unit': u''}

-- line #12285
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.4G', u'strength_2': u'5ML', u'substance': u'Di-Sodium Hydrogen Citrate', u'always_empty': u'', u'form': u'LIQ', u'brand': u'ALKARYL', u'strength_3': u'', u'company': u'Cadila Ph.', u'unit': u''}

-- line #12286
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.4G', u'strength_2': u'5ML', u'substance': u'Disodium Hydrogen Citrate', u'always_empty': u'', u'form': u'SYR', u'brand': u'ALKASOL', u'strength_3': u'', u'company': u'Stadmed', u'unit': u''}

-- line #12287
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Disodium Hydrogen Citrate', u'always_empty': u'', u'form': u'SYP', u'brand': u'ALKAZER', u'strength_3': u'', u'company': u'NIVCA', u'unit': u''}

-- line #12288
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.04G', u'strength_2': u'5ML', u'substance': u'Disodium Hydrogen Citrate', u'always_empty': u'', u'form': u'SYR', u'brand': u'ALKCIT', u'strength_3': u'', u'company': u'Goodluck Ph.', u'unit': u''}

-- line #12289
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.55G', u'strength_2': u'', u'substance': u'Disodium Hydrogen Citrate', u'always_empty': u'', u'form': u'SYR', u'brand': u'ALKIROM', u'strength_3': u'', u'company': u'Rhombus', u'unit': u''}

-- line #12290
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.2G', u'strength_2': u'5ML', u'substance': u'Disodium Hydrogen Citrate', u'always_empty': u'', u'form': u'LIQ', u'brand': u'ALKITER', u'strength_3': u'', u'company': u'Neuron Ph.', u'unit': u''}

-- line #12291
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.53G', u'strength_2': u'', u'substance': u'Disodium Hydrogen Citrate', u'always_empty': u'', u'form': u'SYR', u'brand': u'ALKOMNI', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #12292
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.4G', u'strength_2': u'', u'substance': u'Disodium Hydrogen Citrate', u'always_empty': u'', u'form': u'LIQ', u'brand': u'ALYZER', u'strength_3': u'', u'company': u'ANON PH.', u'unit': u''}

-- line #12293
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOCETRAL 1.53 (Bioguard Org.)',
	'Disodium Hydrogen Citrate',
	'SUS',
	gm.nullify_empty_string('1.53')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOCETRAL 1.53 (Bioguard Org.)'
);

-- line #12294
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.37G', u'strength_2': u'5ML', u'substance': u'Disodium Hydrogen Citrate', u'always_empty': u'', u'form': u'SYR', u'brand': u'CITAL', u'strength_3': u'', u'company': u'Indoco Rem.', u'unit': u''}

-- line #12295
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.38G', u'strength_2': u'5ML', u'substance': u'Disodium Hydrogen Citrate', u'always_empty': u'', u'form': u'SYR', u'brand': u'CITRAGLOW', u'strength_3': u'', u'company': u'Aglowmed', u'unit': u''}

-- line #12296
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.53G', u'strength_2': u'5ML', u'substance': u'Disodium Hydrogen Citrate', u'always_empty': u'', u'form': u'SYR', u'brand': u'CITRA KOLA', u'strength_3': u'', u'company': u'Kosha Lab.', u'unit': u''}

-- line #12297
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.53G', u'strength_2': u'5ML', u'substance': u'Disodium Hydrogen Citrate', u'always_empty': u'', u'form': u'SYR', u'brand': u'CITRAKUL', u'strength_3': u'', u'company': u'Finecure', u'unit': u''}

-- line #12298
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.53G', u'strength_2': u'5ML', u'substance': u'Disodium Hydrogen Citrate', u'always_empty': u'', u'form': u'SYR', u'brand': u'CITRALKA', u'strength_3': u'', u'company': u'Pfizer', u'unit': u''}

-- line #12299
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.52G', u'strength_2': u'5ML', u'substance': u'Disodium Hydrogen Citrate', u'always_empty': u'', u'form': u'SYR', u'brand': u'CITRA', u'strength_3': u'', u'company': u'Sbeed Hc.', u'unit': u''}

-- line #12300
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Disodium Hydrogen Citrate', u'always_empty': u'', u'form': u'LIQ', u'brand': u'CITROX', u'strength_3': u'', u'company': u'OXYGEN PH.', u'unit': u''}

-- line #12301
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.4G', u'strength_2': u'5ML', u'substance': u'Disodium Hydrogen Citrate', u'always_empty': u'', u'form': u'SYR', u'brand': u'DICETRAL', u'strength_3': u'', u'company': u'Samson', u'unit': u''}

-- line #12302
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.5G', u'strength_2': u'5ML', u'substance': u'Disodium Hydrogen Citrate', u'always_empty': u'', u'form': u'LIQ', u'brand': u'HUTAL', u'strength_3': u'', u'company': u'ROSE LABS', u'unit': u''}

-- line #12303
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.53G', u'strength_2': u'5ML', u'substance': u'Disodium Hydrogen Citrate', u'always_empty': u'', u'form': u'SYR', u'brand': u'HYDISOL', u'strength_3': u'', u'company': u'Ethilex Hc.', u'unit': u''}

-- line #12304
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.38G', u'strength_2': u'5ML', u'substance': u'Disodium Hydrogen Citrate', u'always_empty': u'', u'form': u'SYR', u'brand': u'JCITRON', u'strength_3': u'', u'company': u'Jupiter Ph.', u'unit': u''}

-- line #12305
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.4GM', u'strength_2': u'5ML', u'substance': u'Disodium Hydrogen Citrate', u'always_empty': u'', u'form': u'SYR', u'brand': u'JUCITRON', u'strength_3': u'', u'company': u'UNIJULES', u'unit': u''}

-- line #12306
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.25G', u'strength_2': u'5ML', u'substance': u'Disodium Hydrogen Citrate', u'always_empty': u'', u'form': u'SYR', u'brand': u'MAKCIT', u'strength_3': u'', u'company': u'Makbro Hc.', u'unit': u''}

-- line #12307
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.53G', u'strength_2': u'5ML', u'substance': u'Disodium Hydrogen Citrate', u'always_empty': u'', u'form': u'SYR', u'brand': u'MEDICITRON', u'strength_3': u'', u'company': u'Medico', u'unit': u''}

-- line #12308
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'4G', u'strength_2': u'15ML', u'substance': u'Disodium Hydrogen Citrate', u'always_empty': u'', u'form': u'LIQ', u'brand': u'METALKA', u'strength_3': u'', u'company': u'Mount M.', u'unit': u''}

-- line #12309
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.2G', u'strength_2': u'', u'substance': u'Disodium Hydrogen Citrate', u'always_empty': u'', u'form': u'SYR', u'brand': u'MITYGAT', u'strength_3': u'', u'company': u'Southsourne', u'unit': u''}

-- line #12310
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.4G;5ML', u'strength_2': u'', u'substance': u'Disodium Hydrogen Citrate', u'always_empty': u'', u'form': u'SYR', u'brand': u'MODS-ALSOL', u'strength_3': u'', u'company': u'MODHIKE', u'unit': u''}

-- line #12311
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.4G', u'strength_2': u'5ML', u'substance': u'Disodium Hydrogen Citrate', u'always_empty': u'', u'form': u'LIQ', u'brand': u'NATRALKA', u'strength_3': u'', u'company': u'Citadel', u'unit': u''}

-- line #12312
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.38G', u'strength_2': u'5ML', u'substance': u'Disodium Hydrogen Citrate', u'always_empty': u'', u'form': u'SYR', u'brand': u'ORICITRAL', u'strength_3': u'', u'company': u'Ttk Hc.', u'unit': u''}

-- line #12313
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1,2', u'strength_2': u'', u'substance': u'Disodium Hydrogen Citrate', u'always_empty': u'', u'form': u'', u'brand': u'PCITRAL SY', u'strength_3': u'', u'company': u'Patson', u'unit': u'mg'}

-- line #12314
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Disodium Hydrogen Citrate', u'always_empty': u'', u'form': u'LIQ', u'brand': u'Q-CITRA', u'strength_3': u'', u'company': u'Que Ph.', u'unit': u''}

-- line #12315
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.4G', u'strength_2': u'5ML', u'substance': u'Disodium Hydrogen Citrate', u'always_empty': u'', u'form': u'LIQ', u'brand': u'REMICITRON', u'strength_3': u'', u'company': u'Remedies', u'unit': u''}

-- line #12316
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.25G', u'strength_2': u'', u'substance': u'Disodium Hydrogen Citrate', u'always_empty': u'', u'form': u'SYR', u'brand': u'REPLAY', u'strength_3': u'', u'company': u'Intra Lab', u'unit': u''}

-- line #12317
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHEERIO 0.35 (Dr.Reddy''S)',
	'Disodium Monofluorophos.',
	'TUBE',
	gm.nullify_empty_string('0.35')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHEERIO 0.35 (Dr.Reddy''S)'
);

-- line #12318
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORPACE 100 (Rpg Life)',
	'Disopyramide',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORPACE 100 (Rpg Life)'
);

-- line #12319
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORPACE 150 (Rpg Life)',
	'Disopyramide',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORPACE 150 (Rpg Life)'
);

-- line #12320
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REGUBEAT 100 (GSK)',
	'Disopyramide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REGUBEAT 100 (GSK)'
);

-- line #12321
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANTADICT 250 (Intas)',
	'Disulfiram',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANTADICT 250 (Intas)'
);

-- line #12322
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHRONOL 500 (KOLSON''S)',
	'Disulfiram',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHRONOL 500 (KOLSON''S)'
);

-- line #12323
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEADICT 200 (Pil)',
	'Disulfiram',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEADICT 200 (Pil)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEADICT 250 (Pil)',
	'Disulfiram',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEADICT 250 (Pil)'
);

-- line #12324
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIABUSE 500 (Samarth)',
	'Disulfiram',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIABUSE 500 (Samarth)'
);

-- line #12325
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DISULFIRAM 250 (Intas)',
	'Disulfiram',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DISULFIRAM 250 (Intas)'
);

-- line #12326
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIZONE 250 (Ozone Ph.)',
	'Disulfiram',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIZONE 250 (Ozone Ph.)'
);

-- line #12327
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESPERAL 250 (Torrent)',
	'Disulfiram',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESPERAL 250 (Torrent)'
);

-- line #12328
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIRAM 250 (Tripada Hc.)',
	'Disulfiram',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIRAM 250 (Tripada Hc.)'
);

-- line #12329
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PSORINOL 0.25 (Ipca)',
	'DITHRANOL',
	'OINT',
	gm.nullify_empty_string('0.25')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PSORINOL 0.25 (Ipca)'
);

-- line #12330
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PSORINOL 0.5 (Ipca)',
	'DITHRANOL',
	'OINT',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PSORINOL 0.5 (Ipca)'
);

-- line #12331
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PSORINOL 1.15 (Ipca)',
	'DITHRANOL',
	'OINT',
	gm.nullify_empty_string('1.15')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PSORINOL 1.15 (Ipca)'
);

-- line #12332
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G(VALPORIC ACID)', u'strength_2': u'', u'substance': u'Divalproex', u'always_empty': u'', u'form': u'OD TAB', u'brand': u'DAYO', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #12333
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAYO 250 (Lupin)',
	'Divalproex',
	'OD TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg (ER)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAYO 250 (Lupin)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAYO 500 (Lupin)',
	'Divalproex',
	'OD TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg (ER)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAYO 500 (Lupin)'
);

-- line #12334
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAYO 750 (Lupin)',
	'Divalproex',
	'OD TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg (ER)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAYO 750 (Lupin)'
);

-- line #12335
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICORATE 1000 (Sun)',
	'Divalproex',
	'ER TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICORATE 1000 (Sun)'
);

-- line #12336
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICORATE 125 (Sun)',
	'Divalproex',
	'ER TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICORATE 125 (Sun)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICORATE 250 (Sun)',
	'Divalproex',
	'ER TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICORATE 250 (Sun)'
);

-- line #12337
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICORATE 500 (Sun)',
	'Divalproex',
	'ER TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICORATE 500 (Sun)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICORATE 750 (Sun)',
	'Divalproex',
	'ER TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICORATE 750 (Sun)'
);

-- line #12338
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICORATE 250 (Sun)',
	'Divalproex',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg(VALPROIC ACID)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICORATE 250 (Sun)'
);

-- line #12339
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICORATE 500 (Sun)',
	'Divalproex',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg(VALPROIC ACID)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICORATE 500 (Sun)'
);

-- line #12340
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILPRA 250 (Emcure)',
	'Divalproex',
	'XR TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg(VALPROIC ACID)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILPRA 250 (Emcure)'
);

-- line #12341
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILPRA 500 (Emcure)',
	'Divalproex',
	'XR TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg(VALPROIC ACID)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILPRA 500 (Emcure)'
);

-- line #12342
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIPROEX 250 (Neu-Foreva)',
	'Divalproex',
	'ER TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg(SOD.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIPROEX 250 (Neu-Foreva)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIPROEX 500 (Neu-Foreva)',
	'Divalproex',
	'ER TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg(SOD.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIPROEX 500 (Neu-Foreva)'
);

-- line #12343
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIPROEX 125 (Neu-Foreva)',
	'Divalproex',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIPROEX 125 (Neu-Foreva)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIPROEX 250 (Neu-Foreva)',
	'Divalproex',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIPROEX 250 (Neu-Foreva)'
);

-- line #12344
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIPROEX 500 (Neu-Foreva)',
	'Divalproex',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIPROEX 500 (Neu-Foreva)'
);

-- line #12345
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIPROEX 750 (Neu-Foreva)',
	'Divalproex',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIPROEX 750 (Neu-Foreva)'
);

-- line #12346
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIROX 250 (OREVA DARMO.)',
	'Divalproex',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIROX 250 (OREVA DARMO.)'
);

-- line #12347
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIROX 500 (OREVA DARMO.)',
	'Divalproex',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIROX 500 (OREVA DARMO.)'
);

-- line #12348
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DISORATE 250 (Mankind)',
	'Divalproex',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DISORATE 250 (Mankind)'
);

-- line #12349
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DISOVAL 250 (La Drug)',
	'Divalproex',
	'ER TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DISOVAL 250 (La Drug)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DISOVAL 500 (La Drug)',
	'Divalproex',
	'ER TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DISOVAL 500 (La Drug)'
);

-- line #12350
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVAA 250 (Intas)',
	'Divalproex',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVAA 250 (Intas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVAA 500 (Intas)',
	'Divalproex',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVAA 500 (Intas)'
);

-- line #12351
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVAA 750 (AQUILA)',
	'Divalproex',
	'OD GM TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg/1G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVAA 750 (AQUILA)'
);

-- line #12352
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVAA 250 (AQUILA)',
	'Divalproex',
	'OD TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVAA 250 (AQUILA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVAA 500 (AQUILA)',
	'Divalproex',
	'OD TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVAA 500 (AQUILA)'
);

-- line #12353
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVAA 125 (Intas)',
	'Divalproex',
	'OD TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVAA 125 (Intas)'
);

-- line #12354
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVAA 125 (Intas)',
	'Divalproex',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVAA 125 (Intas)'
);

-- line #12355
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVALIN 250 (MOLEKULE)',
	'Divalproex',
	'OD TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVALIN 250 (MOLEKULE)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVALIN 500 (MOLEKULE)',
	'Divalproex',
	'OD TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVALIN 500 (MOLEKULE)'
);

-- line #12356
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVALIN 750 (MOLEKULE)',
	'Divalproex',
	'OD TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVALIN 750 (MOLEKULE)'
);

-- line #12357
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVALOP 250 (Rkg)',
	'Divalproex',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVALOP 250 (Rkg)'
);

-- line #12358
-- ignoring line: empty field [company]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250', u'strength_2': u'', u'substance': u'Divalproex', u'always_empty': u'', u'form': u'ER TAB', u'brand': u'DI-VALP', u'strength_3': u'', u'company': u'', u'unit': u'mg'}

-- line #12359
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DI-VALP 1000 (MISSION RES.)',
	'Divalproex',
	'ER TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DI-VALP 1000 (MISSION RES.)'
);

-- line #12360
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DI-VALP 500 (MISSION RES.)',
	'Divalproex',
	'ER TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DI-VALP 500 (MISSION RES.)'
);

-- line #12361
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVALPRID 1000 (Micro Labs)',
	'Divalproex',
	'OD TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg(E.R.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVALPRID 1000 (Micro Labs)'
);

-- line #12362
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVALPRID 500 (Micro Labs)',
	'Divalproex',
	'OD TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg(E.R.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVALPRID 500 (Micro Labs)'
);

-- line #12363
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVALPRID 750 (Micro Labs)',
	'Divalproex',
	'OD TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg(E.R.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVALPRID 750 (Micro Labs)'
);

-- line #12364
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVALPRID 250 (Synapse)',
	'Divalproex',
	'OD TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg(E.R.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVALPRID 250 (Synapse)'
);

-- line #12365
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G E.R.', u'strength_2': u'', u'substance': u'Divalproex', u'always_empty': u'', u'form': u'XR TAB', u'brand': u'DIVALPRO', u'strength_3': u'', u'company': u'Zydus N.S.', u'unit': u''}

-- line #12366
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVALRATE 125 (IPCA LAB.)',
	'Divalproex',
	'ER TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVALRATE 125 (IPCA LAB.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVALRATE 250 (IPCA LAB.)',
	'Divalproex',
	'ER TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVALRATE 250 (IPCA LAB.)'
);

-- line #12367
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVALRATE 500 (IPCA LAB.)',
	'Divalproex',
	'ER TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVALRATE 500 (IPCA LAB.)'
);

-- line #12368
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVALTEC 250 (Tripada Hc.)',
	'Divalproex',
	'ER TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg(VALPROIC ACID)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVALTEC 250 (Tripada Hc.)'
);

-- line #12369
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVALTEC 500 (Tripada Hc.)',
	'Divalproex',
	'ER TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg(VALPROIC ACID)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVALTEC 500 (Tripada Hc.)'
);

-- line #12370
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVELLA 250 (Marksans)',
	'Divalproex',
	'ER TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg ER'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVELLA 250 (Marksans)'
);

-- line #12371
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVELLA 500 (Marksans)',
	'Divalproex',
	'ER TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg ER'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVELLA 500 (Marksans)'
);

-- line #12372
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVELLA 750 (Marksans)',
	'Divalproex',
	'ER TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg ER'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVELLA 750 (Marksans)'
);

-- line #12373
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVEX 250 (Theo Ph.)',
	'Divalproex',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVEX 250 (Theo Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVEX 500 (Theo Ph.)',
	'Divalproex',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVEX 500 (Theo Ph.)'
);

-- line #12374
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVEX 750 (Theo Ph.)',
	'Divalproex',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg/1G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVEX 750 (Theo Ph.)'
);

-- line #12375
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVUNA 1000 (Ucb India)',
	'Divalproex',
	'ER TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVUNA 1000 (Ucb India)'
);

-- line #12376
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVUNA 250 (Ucb India)',
	'Divalproex',
	'ER TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVUNA 250 (Ucb India)'
);

-- line #12377
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVUNA 500 (Ucb India)',
	'Divalproex',
	'ER TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVUNA 500 (Ucb India)'
);

-- line #12378
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENCORATE CHRONO 200 (SUN)',
	'Divalproex',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENCORATE CHRONO 200 (SUN)'
);

-- line #12379
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENCORATE CHRONO 300 (SUN)',
	'Divalproex',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENCORATE CHRONO 300 (SUN)'
);

-- line #12380
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENCORATE CHRONO 500 (SUN)',
	'Divalproex',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENCORATE CHRONO 500 (SUN)'
);

-- line #12381
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROVAL 250 (PSYCOREM)',
	'Divalproex',
	'ER TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROVAL 250 (PSYCOREM)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROVAL 500 (PSYCOREM)',
	'Divalproex',
	'ER TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROVAL 500 (PSYCOREM)'
);

-- line #12382
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REX 250 (Abbott)',
	'Divalproex',
	'XR TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg(VALPROIC ACID)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REX 250 (Abbott)'
);

-- line #12383
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REX 500 (Abbott)',
	'Divalproex',
	'XR TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg(VALPROIC ACID)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REX 500 (Abbott)'
);

-- line #12384
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPAKOTE 250 (Sanofi Aventis)',
	'Divalproex Sodium',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPAKOTE 250 (Sanofi Aventis)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPAKOTE 500 (Sanofi Aventis)',
	'Divalproex Sodium',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPAKOTE 500 (Sanofi Aventis)'
);

-- line #12385
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DESVAL 125 (Solus)',
	'Divalproex Sodium',
	'ER TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DESVAL 125 (Solus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DESVAL 250 (Solus)',
	'Divalproex Sodium',
	'ER TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DESVAL 250 (Solus)'
);

-- line #12386
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Divalproex Sodium', u'always_empty': u'', u'form': u'ER TAB', u'brand': u'DESVAL', u'strength_3': u'', u'company': u'Solus', u'unit': u''}

-- line #12387
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DESVAL 500 (Solus)',
	'Divalproex Sodium',
	'ER TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DESVAL 500 (Solus)'
);

-- line #12388
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DESVAL 750 (Solus)',
	'Divalproex Sodium',
	'ER TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DESVAL 750 (Solus)'
);

-- line #12389
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILEX 125 (Merind)',
	'Divalproex Sodium',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILEX 125 (Merind)'
);

-- line #12390
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILEX 250 (Merind)',
	'Divalproex Sodium',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILEX 250 (Merind)'
);

-- line #12391
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILEX 500 (Merind)',
	'Divalproex Sodium',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILEX 500 (Merind)'
);

-- line #12392
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVALEX 125 (Crescent Th.)',
	'Divalproex Sodium',
	'OD TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVALEX 125 (Crescent Th.)'
);

-- line #12393
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVALEX 250 (Crescent Th.)',
	'Divalproex Sodium',
	'OD TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVALEX 250 (Crescent Th.)'
);

-- line #12394
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVALEX 500 (Crescent Th.)',
	'Divalproex Sodium',
	'OD TAB',
	gm.nullify_empty_string('500')::numeric,
	'750'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVALEX 500 (Crescent Th.)'
);

-- line #12395
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVALIN 1000 (MOLEKULE)',
	'Divalproex Sodium',
	'TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVALIN 1000 (MOLEKULE)'
);

-- line #12396
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVALIN 250 (MOLEKULE)',
	'Divalproex Sodium',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVALIN 250 (MOLEKULE)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVALIN 500 (MOLEKULE)',
	'Divalproex Sodium',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVALIN 500 (MOLEKULE)'
);

-- line #12397
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVALIN 750 (MOLEKULE)',
	'Divalproex Sodium',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVALIN 750 (MOLEKULE)'
);

-- line #12398
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DI-VALP 750 (MISSION RES.)',
	'Divalproex Sodium',
	'ER TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg(VALPROIC ACID)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DI-VALP 750 (MISSION RES.)'
);

-- line #12399
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVALPRO 125 (Zydus N.S.)',
	'Divalproex Sodium',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVALPRO 125 (Zydus N.S.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVALPRO 250 (Zydus N.S.)',
	'Divalproex Sodium',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVALPRO 250 (Zydus N.S.)'
);

-- line #12400
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVALPRO 500 (Zydus N.S.)',
	'Divalproex Sodium',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVALPRO 500 (Zydus N.S.)'
);

-- line #12401
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'D-VAL 250 (BARODA)',
	'Divalproex Sodium',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg (ER)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'D-VAL 250 (BARODA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'D-VAL 500 (BARODA)',
	'Divalproex Sodium',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg (ER)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'D-VAL 500 (BARODA)'
);

-- line #12402
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROVAL 750 (PSYCOREM)',
	'Divalproex Sodium',
	'ER TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg/1G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROVAL 750 (PSYCOREM)'
);

-- line #12403
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDIFORCE 12.5 (TORRENT)',
	'Dobutamine Hcl.',
	'INJ',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDIFORCE 12.5 (TORRENT)'
);

-- line #12404
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDIJECT 250 (Sun)',
	'Dobutamine Hcl.',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/20ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDIJECT 250 (Sun)'
);

-- line #12405
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDIJECT 50 (Sun)',
	'Dobutamine Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/4ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDIJECT 50 (Sun)'
);

-- line #12406
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50', u'strength_2': u'', u'substance': u'Dobutamine Hcl.', u'always_empty': u'', u'form': u'', u'brand': u'CARDIO PLUS ML', u'strength_3': u'', u'company': u'SYNER MED.', u'unit': u'mg(BENZYL ALCOHOL)'}

-- line #12407
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDOB 250 (UNIMARK REM.)',
	'Dobutamine Hcl.',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/20ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDOB 250 (UNIMARK REM.)'
);

-- line #12408
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Dobutamine Hcl.', u'always_empty': u'', u'form': u'INFCONC', u'brand': u'DOBICARD', u'strength_3': u'', u'company': u'U S V', u'unit': u''}

-- line #12409
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOBIER 250 (CH.Bhagat)',
	'Dobutamine Hcl.',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOBIER 250 (CH.Bhagat)'
);

-- line #12410
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOBIER LYPHO 250 (CH.Bhagat)',
	'Dobutamine Hcl.',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg(LYPHOLISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOBIER LYPHO 250 (CH.Bhagat)'
);

-- line #12411
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOBIER-S 250 (CH.Bhagat)',
	'Dobutamine Hcl.',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOBIER-S 250 (CH.Bhagat)'
);

-- line #12412
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOBION 250 (BIOSENA)',
	'Dobutamine Hcl.',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOBION 250 (BIOSENA)'
);

-- line #12413
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Dobutamine Hcl.', u'always_empty': u'', u'form': u'INJ', u'brand': u'DOBONIS', u'strength_3': u'', u'company': u'NEISS', u'unit': u''}

-- line #12414
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOBONIS 250 (NEISS)',
	'Dobutamine Hcl.',
	'LP VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOBONIS 250 (NEISS)'
);

-- line #12415
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOBUCARD 250 (Csc Ph.)',
	'Dobutamine Hcl.',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOBUCARD 250 (Csc Ph.)'
);

-- line #12416
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOBUCARD 50 (Intra(INVISION))',
	'Dobutamine Hcl.',
	'VIAL',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOBUCARD 50 (Intra(INVISION))'
);

-- line #12417
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOBUCARE 250 (Criticare)',
	'Dobutamine Hcl.',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOBUCARE 250 (Criticare)'
);

-- line #12418
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOBUCEF 250 (Vhb)',
	'Dobutamine Hcl.',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg(LYPHOLISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOBUCEF 250 (Vhb)'
);

-- line #12419
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOBUCIN 50 (Troikaa)',
	'Dobutamine Hcl.',
	'AMP',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOBUCIN 50 (Troikaa)'
);

-- line #12420
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOBUGEN-PF 250 (SG PH.)',
	'Dobutamine Hcl.',
	'AMP',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOBUGEN-PF 250 (SG PH.)'
);

-- line #12421
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOBUGEN-PFV 250 (SG PH.)',
	'Dobutamine Hcl.',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg/20ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOBUGEN-PFV 250 (SG PH.)'
);

-- line #12422
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOBULON 250 (CELON(REVILON))',
	'Dobutamine Hcl.',
	'AMP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOBULON 250 (CELON(REVILON))'
);

-- line #12423
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOBUNEX PF 250 (Vhb)',
	'Dobutamine Hcl.',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg (PRESR.FREE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOBUNEX PF 250 (Vhb)'
);

-- line #12424
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOBUPRESS 250 (Medicorp)',
	'Dobutamine Hcl.',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOBUPRESS 250 (Medicorp)'
);

-- line #12425
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOBURAN 250 (Vhb)',
	'Dobutamine Hcl.',
	'AMP',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOBURAN 250 (Vhb)'
);

-- line #12426
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOBUSOL 250 (United Bio.)',
	'Dobutamine Hcl.',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOBUSOL 250 (United Bio.)'
);

-- line #12427
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOBUSTAT 250 (Samarth)',
	'Dobutamine Hcl.',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOBUSTAT 250 (Samarth)'
);

-- line #12428
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOBUSTAT 250 (SAMARTH)',
	'Dobutamine Hcl.',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg(LYOPHILISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOBUSTAT 250 (SAMARTH)'
);

-- line #12429
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOBUTAM 250 (United Bio.)',
	'Dobutamine Hcl.',
	'V',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOBUTAM 250 (United Bio.)'
);

-- line #12430
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOBUTASYS 250 (SYSTACARE)',
	'Dobutamine Hcl.',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOBUTASYS 250 (SYSTACARE)'
);

-- line #12431
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOBUTREX 250 (Eli Lilly)',
	'Dobutamine Hcl.',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg (250'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOBUTREX 250 (Eli Lilly)'
);

-- line #12432
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOBUTREX 250 (Eli Lilly)',
	'Dobutamine Hcl.',
	'VIALFLEX IV BAG',
	gm.nullify_empty_string('250')::numeric,
	'mg (250'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOBUTREX 250 (Eli Lilly)'
);

-- line #12433
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOBUTREX 250 (Piramal Hc.)',
	'Dobutamine Hcl.',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOBUTREX 250 (Piramal Hc.)'
);

-- line #12434
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOFUSE 250 (Lupin)',
	'Dobutamine Hcl.',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOFUSE 250 (Lupin)'
);

-- line #12435
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOTAMIN 250 (Neon)',
	'Dobutamine Hcl.',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOTAMIN 250 (Neon)'
);

-- line #12436
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250', u'strength_2': u'', u'substance': u'Dobutamine Hcl.', u'always_empty': u'', u'form': u'', u'brand': u'DOTAMIN-LYO', u'strength_3': u'', u'company': u'Neon', u'unit': u'mg'}

-- line #12437
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOTROP 250 (Emcure)',
	'Dobutamine Hcl.',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML (Q.S. MANNITOL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOTROP 250 (Emcure)'
);

-- line #12438
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ICIDOB 250 (Nicholas)',
	'Dobutamine Hcl.',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/V.'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ICIDOB 250 (Nicholas)'
);

-- line #12439
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INOJECT 12.5 (Gland Ph.)',
	'Dobutamine Hcl.',
	'INJ',
	gm.nullify_empty_string('12.5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INOJECT 12.5 (Gland Ph.)'
);

-- line #12440
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250', u'strength_2': u'', u'substance': u'Dobutamine Hcl.', u'always_empty': u'', u'form': u'', u'brand': u'KARDIA IV', u'strength_3': u'', u'company': u'Panacea', u'unit': u'mg/5ML'}

-- line #12441
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRESIN 50 (Destin Lab)',
	'Dobutamine Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRESIN 50 (Destin Lab)'
);

-- line #12442
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMTERE 20 (AMRONCO)',
	'Docetaxel',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMTERE 20 (AMRONCO)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMTERE 80 (AMRONCO)',
	'Docetaxel',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMTERE 80 (AMRONCO)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMTERE 120 (AMRONCO)',
	'Docetaxel',
	'INJ',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMTERE 120 (AMRONCO)'
);

-- line #12443
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELTERE 120 (CELON(VIVILON))',
	'Docetaxel',
	'VIAL',
	gm.nullify_empty_string('120')::numeric,
	'mg/3ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELTERE 120 (CELON(VIVILON))'
);

-- line #12444
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELTERE 20 (CELON(VIVILON))',
	'Docetaxel',
	'VIAL',
	gm.nullify_empty_string('20')::numeric,
	'mg/0.5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELTERE 20 (CELON(VIVILON))'
);

-- line #12445
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELTERE 80 (CELON(VIVILON))',
	'Docetaxel',
	'VIAL',
	gm.nullify_empty_string('80')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELTERE 80 (CELON(VIVILON))'
);

-- line #12446
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAXOTEL 20 (Dabur Ph.)',
	'Docetaxel',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg(SOLVENT FOR INJ. 1.5ML)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAXOTEL 20 (Dabur Ph.)'
);

-- line #12447
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAXOTEL 80 (Dabur Ph.)',
	'Docetaxel',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg(SOLVENT FOR INJ. 6ML)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAXOTEL 80 (Dabur Ph.)'
);

-- line #12448
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOCEFREZ 20 (SUN)',
	'Docetaxel',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOCEFREZ 20 (SUN)'
);

-- line #12449
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOCEFREZ 80 (SUN)',
	'Docetaxel',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOCEFREZ 80 (SUN)'
);

-- line #12450
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOCEPAR 120 (Parenteral)',
	'Docetaxel',
	'INJ',
	gm.nullify_empty_string('120')::numeric,
	'mg/3ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOCEPAR 120 (Parenteral)'
);

-- line #12451
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOCEPAR 20 (Parenteral)',
	'Docetaxel',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg/0.5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOCEPAR 20 (Parenteral)'
);

-- line #12452
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOCEPAR 80 (Parenteral)',
	'Docetaxel',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOCEPAR 80 (Parenteral)'
);

-- line #12453
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOCETAX 120 (Cipla)',
	'Docetaxel',
	'INJ',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOCETAX 120 (Cipla)'
);

-- line #12454
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOCETAX 20 (Cipla)',
	'Docetaxel',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOCETAX 20 (Cipla)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOCETAX 80 (Cipla)',
	'Docetaxel',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOCETAX 80 (Cipla)'
);

-- line #12455
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOCETEC 20 (United Bio.)',
	'Docetaxel',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOCETEC 20 (United Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOCETEC 80 (United Bio.)',
	'Docetaxel',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOCETEC 80 (United Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOCETEC 120 (United Bio.)',
	'Docetaxel',
	'INJ',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOCETEC 120 (United Bio.)'
);

-- line #12456
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOCETERE 120 (Dr.Reddy''S)',
	'Docetaxel',
	'INJ',
	gm.nullify_empty_string('120')::numeric,
	'mg/3ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOCETERE 120 (Dr.Reddy''S)'
);

-- line #12457
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOCETERE 20 (Dr.Reddy''S)',
	'Docetaxel',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg/0.5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOCETERE 20 (Dr.Reddy''S)'
);

-- line #12458
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOCETERE 80 (Dr.Reddy''S)',
	'Docetaxel',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOCETERE 80 (Dr.Reddy''S)'
);

-- line #12459
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOCETERO 120 (HETERO HC.)',
	'Docetaxel',
	'INJ',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOCETERO 120 (HETERO HC.)'
);

-- line #12460
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOCETERO 20 (HETERO HC.)',
	'Docetaxel',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOCETERO 20 (HETERO HC.)'
);

-- line #12461
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOCETERO 80 (HETERO HC.)',
	'Docetaxel',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOCETERO 80 (HETERO HC.)'
);

-- line #12462
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOCET 20 (Samarth)',
	'Docetaxel',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOCET 20 (Samarth)'
);

-- line #12463
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOCET 80 (Samarth)',
	'Docetaxel',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOCET 80 (Samarth)'
);

-- line #12464
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOCETRUST 120 (Panacea)',
	'Docetaxel',
	'VIAL',
	gm.nullify_empty_string('120')::numeric,
	'mg (POLYSORDATE BO IP Q.S.3ML)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOCETRUST 120 (Panacea)'
);

-- line #12465
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOCETRUST 20 (Panacea)',
	'Docetaxel',
	'VIAL',
	gm.nullify_empty_string('20')::numeric,
	'mg (POLYSORDATE BO IP Q.S.0.5ML)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOCETRUST 20 (Panacea)'
);

-- line #12466
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOCETRUST 80 (Panacea)',
	'Docetaxel',
	'VIAL',
	gm.nullify_empty_string('80')::numeric,
	'mg (POLYSORDATE BO IP Q.S.2ML)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOCETRUST 80 (Panacea)'
);

-- line #12467
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOTEL 20 (Wockhardt)',
	'Docetaxel',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOTEL 20 (Wockhardt)'
);

-- line #12468
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOTEL 80 (Wockhardt)',
	'Docetaxel',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOTEL 80 (Wockhardt)'
);

-- line #12469
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXEL 20 (Shantha Bio.)',
	'Docetaxel',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg/0.5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXEL 20 (Shantha Bio.)'
);

-- line #12470
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXEL 80 (Shantha Bio.)',
	'Docetaxel',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXEL 80 (Shantha Bio.)'
);

-- line #12471
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'D-TAIL 20 (Khandelwal)',
	'Docetaxel',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'D-TAIL 20 (Khandelwal)'
);

-- line #12472
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'D-TAIL 80 (Khandelwal)',
	'Docetaxel',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'D-TAIL 80 (Khandelwal)'
);

-- line #12473
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERDOTAX 120 (FERON LS)',
	'Docetaxel',
	'INJ',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERDOTAX 120 (FERON LS)'
);

-- line #12474
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERDOTAX 20 (FERON LS)',
	'Docetaxel',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERDOTAX 20 (FERON LS)'
);

-- line #12475
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERDOTAX 80 (FERON LS)',
	'Docetaxel',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERDOTAX 80 (FERON LS)'
);

-- line #12476
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GTERE 20 (GENESIS ORG.)',
	'Docetaxel',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GTERE 20 (GENESIS ORG.)'
);

-- line #12477
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GTERE 80 (GENESIS ORG.)',
	'Docetaxel',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GTERE 80 (GENESIS ORG.)'
);

-- line #12478
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GTERE 120 (GENESIS ORG.)',
	'Docetaxel',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GTERE 120 (GENESIS ORG.)'
);

-- line #12479
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MA-DHA 300 (Nouveau)',
	'Docosahexaenoic Acid',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MA-DHA 300 (Nouveau)'
);

-- line #12480
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NATOLAC 300 (Sai Mirra)',
	'Docosahexaenoic Acid',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NATOLAC 300 (Sai Mirra)'
);

-- line #12481
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ABDOME 1 (Arbro Ph.)',
	'Domperidone',
	'SUS',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ABDOME 1 (Arbro Ph.)'
);

-- line #12482
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AGLODOM 10 (Aglowmed)',
	'Domperidone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AGLODOM 10 (Aglowmed)'
);

-- line #12483
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AQDOM 10 (Aquila)',
	'Domperidone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AQDOM 10 (Aquila)'
);

-- line #12484
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZINORM 10 (Azime Hc.)',
	'Domperidone',
	'DT',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZINORM 10 (Azime Hc.)'
);

-- line #12485
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZINORM 1 (Azime Hc.)',
	'Domperidone',
	'SUS',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZINORM 1 (Azime Hc.)'
);

-- line #12486
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COSDOME 5 (Cosme Hc.)',
	'Domperidone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COSDOME 5 (Cosme Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COSDOME 10 (Cosme Hc.)',
	'Domperidone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COSDOME 10 (Cosme Hc.)'
);

-- line #12487
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUDOM 10 (Cubit Hc.)',
	'Domperidone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUDOM 10 (Cubit Hc.)'
);

-- line #12488
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'D0M 10 (EAST WEST)',
	'Domperidone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'D0M 10 (EAST WEST)'
);

-- line #12489
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIMPY 1 (Group Ph.)',
	'Domperidone',
	'SUS',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIMPY 1 (Group Ph.)'
);

-- line #12490
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMACT 10 (Intra Lab)',
	'Domperidone',
	'DT',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMACT 10 (Intra Lab)'
);

-- line #12491
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMACT 1 (Intra Lab)',
	'Domperidone',
	'SUS',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMACT 1 (Intra Lab)'
);

-- line #12492
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMAIM 1 (AIMCO PH.)',
	'Domperidone',
	'SUS',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMAIM 1 (AIMCO PH.)'
);

-- line #12493
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMAIM 10 (AIMCO PH.)',
	'Domperidone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMAIM 10 (AIMCO PH.)'
);

-- line #12494
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMAR 10 (Runa Ph.)',
	'Domperidone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMAR 10 (Runa Ph.)'
);

-- line #12495
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMAT 10 (Atoz Ph.)',
	'Domperidone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMAT 10 (Atoz Ph.)'
);

-- line #12496
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMAX 10 (Lanark)',
	'Domperidone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMAX 10 (Lanark)'
);

-- line #12497
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMBEER 10 (ABEER PH.)',
	'Domperidone',
	'DT TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMBEER 10 (ABEER PH.)'
);

-- line #12498
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMCOLIC 1 (Zydus Cadila)',
	'Domperidone',
	'SYR',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMCOLIC 1 (Zydus Cadila)'
);

-- line #12499
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMCOLIC 10 (Zydus Cadila)',
	'Domperidone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMCOLIC 10 (Zydus Cadila)'
);

-- line #12500
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMDAY 30 (Ordain Hc.)',
	'Domperidone',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg(SR)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMDAY 30 (Ordain Hc.)'
);

-- line #12501
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOM 5 (Morepen)',
	'Domperidone',
	'DT',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOM 5 (Morepen)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOM 10 (Morepen)',
	'Domperidone',
	'DT',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOM 10 (Morepen)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOM 20 (Morepen)',
	'Domperidone',
	'DT',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOM 20 (Morepen)'
);

-- line #12502
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMEL 10 (Intas)',
	'Domperidone',
	'MT TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMEL 10 (Intas)'
);

-- line #12503
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMET 1 (National)',
	'Domperidone',
	'DPS',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMET 1 (National)'
);

-- line #12504
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMINOL 1 (Stanford)',
	'Domperidone',
	'SYR',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMINOL 1 (Stanford)'
);

-- line #12505
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMINOL 10 (Stanford)',
	'Domperidone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMINOL 10 (Stanford)'
);

-- line #12506
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMI 1 (Lincoln)',
	'Domperidone',
	'SUS',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMI 1 (Lincoln)'
);

-- line #12507
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMI 10 (Lincoln)',
	'Domperidone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMI 10 (Lincoln)'
);

-- line #12508
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMITIL 10 (Bal Ph.)',
	'Domperidone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMITIL 10 (Bal Ph.)'
);

-- line #12509
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMIT 10 (Shinto Org.)',
	'Domperidone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMIT 10 (Shinto Org.)'
);

-- line #12510
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMLUS 10 (LUSTRE)',
	'Domperidone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMLUS 10 (LUSTRE)'
);

-- line #12511
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMNE 30 (R.B.)',
	'Domperidone',
	'CR TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMNE 30 (R.B.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMNE 40 (R.B.)',
	'Domperidone',
	'CR TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMNE 40 (R.B.)'
);

-- line #12512
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMNORM 5 (Ipca)',
	'Domperidone',
	'DT/ TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMNORM 5 (Ipca)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMNORM 10 (Ipca)',
	'Domperidone',
	'DT/ TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMNORM 10 (Ipca)'
);

-- line #12513
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMPED 10 (Medispan)',
	'Domperidone',
	'DT',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMPED 10 (Medispan)'
);

-- line #12514
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMPED 5 (Medispan)',
	'Domperidone',
	'DT',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMPED 5 (Medispan)'
);

-- line #12515
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMPED 1 (Medispan)',
	'Domperidone',
	'SUS',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMPED 1 (Medispan)'
);

-- line #12516
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMPED 10 (Medispan)',
	'Domperidone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMPED 10 (Medispan)'
);

-- line #12517
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMPER 5 (Ethicare)',
	'Domperidone',
	'DT TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMPER 5 (Ethicare)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMPER 10 (Ethicare)',
	'Domperidone',
	'DT TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMPER 10 (Ethicare)'
);

-- line #12518
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMPERI 10 (Ipca)',
	'Domperidone',
	'DT',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMPERI 10 (Ipca)'
);

-- line #12519
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMPERI 5 (Ipca)',
	'Domperidone',
	'DT',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMPERI 5 (Ipca)'
);

-- line #12520
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMPERISTAL 10 (Kontest)',
	'Domperidone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMPERISTAL 10 (Kontest)'
);

-- line #12521
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMPERI 1 (Ipca)',
	'Domperidone',
	'SUS',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMPERI 1 (Ipca)'
);

-- line #12522
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMPERON 10 (Le Sante)',
	'Domperidone',
	'DPS',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMPERON 10 (Le Sante)'
);

-- line #12523
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10', u'strength_2': u'', u'substance': u'Domperidone', u'always_empty': u'', u'form': u'', u'brand': u'DOMPERON MELTAB', u'strength_3': u'', u'company': u'Irm Ph.', u'unit': u'mg'}

-- line #12524
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5', u'strength_2': u'', u'substance': u'Domperidone', u'always_empty': u'', u'form': u'', u'brand': u'DOMPERON MELTAB', u'strength_3': u'', u'company': u'Irm Ph.', u'unit': u'mg'}

-- line #12525
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMPERON 30 (Irm Ph.)',
	'Domperidone',
	'OD CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMPERON 30 (Irm Ph.)'
);

-- line #12526
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMPERON 1 (Irm Ph.)',
	'Domperidone',
	'SUS',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMPERON 1 (Irm Ph.)'
);

-- line #12527
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMPET 10 (Patson)',
	'Domperidone',
	'DT',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMPET 10 (Patson)'
);

-- line #12528
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMPET 10 (Chemo Bio.)',
	'Domperidone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMPET 10 (Chemo Bio.)'
);

-- line #12529
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMPON 1 (Finecure)',
	'Domperidone',
	'SUS',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMPON 1 (Finecure)'
);

-- line #12530
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMPON 10 (Finecure)',
	'Domperidone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMPON 10 (Finecure)'
);

-- line #12531
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMPUS 1 (Ampus Life)',
	'Domperidone',
	'DPS',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMPUS 1 (Ampus Life)'
);

-- line #12532
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMPUS 10 (Ampus Life)',
	'Domperidone',
	'DT',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMPUS 10 (Ampus Life)'
);

-- line #12533
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Domperidone', u'always_empty': u'', u'form': u'DPS', u'brand': u'DOMSAN', u'strength_3': u'', u'company': u'SANCHEZ LAB.', u'unit': u''}

-- line #12534
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMSAN 10 (ANQUIS(SANCHEZ))',
	'Domperidone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMSAN 10 (ANQUIS(SANCHEZ))'
);

-- line #12535
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMSAN 10 (SANCHEZ LAB.)',
	'Domperidone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMSAN 10 (SANCHEZ LAB.)'
);

-- line #12536
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMSETTLER 1 (Lifeon)',
	'Domperidone',
	'SUS',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML(IN CYCLODEXTRINE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMSETTLER 1 (Lifeon)'
);

-- line #12537
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMSIN 1 (Helax Hc.)',
	'Domperidone',
	'DPS',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMSIN 1 (Helax Hc.)'
);

-- line #12538
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMSTAL BABY 10 (Torrent)',
	'Domperidone',
	'DPS',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMSTAL BABY 10 (Torrent)'
);

-- line #12539
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMSTAL 10 (Torrent)',
	'Domperidone',
	'DPS',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMSTAL 10 (Torrent)'
);

-- line #12540
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMSTAL 10 (Torrent)',
	'Domperidone',
	'DT/MT',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMSTAL 10 (Torrent)'
);

-- line #12541
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMSTAL 5 (Torrent)',
	'Domperidone',
	'DT/MT',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMSTAL 5 (Torrent)'
);

-- line #12542
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMSTAL 5 (Torrent)',
	'Domperidone',
	'DT TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMSTAL 5 (Torrent)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMSTAL 10 (Torrent)',
	'Domperidone',
	'DT TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMSTAL 10 (Torrent)'
);

-- line #12543
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMSTAL MEL 5 (Torrent)',
	'Domperidone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMSTAL MEL 5 (Torrent)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMSTAL MEL 10 (Torrent)',
	'Domperidone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMSTAL MEL 10 (Torrent)'
);

-- line #12544
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMSTAL 1 (Torrent)',
	'Domperidone',
	'SUSP',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMSTAL 1 (Torrent)'
);

-- line #12545
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMSTAL 1 (Torrent)',
	'Domperidone',
	'SUS',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMSTAL 1 (Torrent)'
);

-- line #12546
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMSTAL 10 (Torrent)',
	'Domperidone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMSTAL 10 (Torrent)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMSTAL 20 (Torrent)',
	'Domperidone',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMSTAL 20 (Torrent)'
);

-- line #12547
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMSTAL 10 (Torrent)',
	'Domperidone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMSTAL 10 (Torrent)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMSTAL 30 (Torrent)',
	'Domperidone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMSTAL 30 (Torrent)'
);

-- line #12548
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMSTAL 10 (Torrent)',
	'Domperidone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg/30'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMSTAL 10 (Torrent)'
);

-- line #12549
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOM 1 (Morepen)',
	'Domperidone',
	'SUS',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOM 1 (Morepen)'
);

-- line #12550
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOM 10 (EAST WEST)',
	'Domperidone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOM 10 (EAST WEST)'
);

-- line #12551
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMTOP 10 (Ind-Swift)',
	'Domperidone',
	'DT',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMTOP 10 (Ind-Swift)'
);

-- line #12552
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMTOP P 1 (Ind-Swift)',
	'Domperidone',
	'DPS',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMTOP P 1 (Ind-Swift)'
);

-- line #12553
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMWEL 10 (WELABLE PH.)',
	'Domperidone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMWEL 10 (WELABLE PH.)'
);

-- line #12554
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMZEN 10 (Zenith Ph.)',
	'Domperidone',
	'SUS',
	gm.nullify_empty_string('10')::numeric,
	'mg/10ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMZEN 10 (Zenith Ph.)'
);

-- line #12555
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMZEN 10 (Zenith Ph.)',
	'Domperidone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMZEN 10 (Zenith Ph.)'
);

-- line #12556
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Domperidone', u'always_empty': u'', u'form': u'TAB', u'brand': u'DOMZOLE', u'strength_3': u'', u'company': u'Burgeon Ph.', u'unit': u''}

-- line #12557
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DON-10 10 (Ozone Ph.)',
	'Domperidone',
	'DT',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DON-10 10 (Ozone Ph.)'
);

-- line #12558
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOPIN 1 (Esken)',
	'Domperidone',
	'SUS',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOPIN 1 (Esken)'
);

-- line #12559
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOVEN 10 (VENSAT)',
	'Domperidone',
	'DT TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOVEN 10 (VENSAT)'
);

-- line #12560
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DPD 10 (Kosha Lab.)',
	'Domperidone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DPD 10 (Kosha Lab.)'
);

-- line #12561
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYSFLUX 10 (Trio Rem.)',
	'Domperidone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYSFLUX 10 (Trio Rem.)'
);

-- line #12562
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMESTAL 1 (Saga Lab)',
	'Domperidone',
	'SUS',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMESTAL 1 (Saga Lab)'
);

-- line #12563
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMESTAL 10 (Saga Lab)',
	'Domperidone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMESTAL 10 (Saga Lab)'
);

-- line #12564
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMIDON 10 (Kapl)',
	'Domperidone',
	'DT',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMIDON 10 (Kapl)'
);

-- line #12565
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMIDON 1 (Kapl)',
	'Domperidone',
	'SUS',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMIDON 1 (Kapl)'
);

-- line #12566
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMITIN 1 (Cachet)',
	'Domperidone',
	'SUS',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMITIN 1 (Cachet)'
);

-- line #12567
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMITIN 10 (Cachet)',
	'Domperidone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMITIN 10 (Cachet)'
);

-- line #12568
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENDOPACE 1 (Themis)',
	'Domperidone',
	'SUS',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENDOPACE 1 (Themis)'
);

-- line #12569
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENDOPACE 10 (Themis)',
	'Domperidone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENDOPACE 10 (Themis)'
);

-- line #12570
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPRID 10 (Ophthal R.)',
	'Domperidone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPRID 10 (Ophthal R.)'
);

-- line #12571
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GASTRACTIV 1 (Ethnor)',
	'Domperidone',
	'SUS',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GASTRACTIV 1 (Ethnor)'
);

-- line #12572
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GASTRACTIV 10 (Ethnor)',
	'Domperidone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GASTRACTIV 10 (Ethnor)'
);

-- line #12573
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GASTRIUM 10 (Micro Nova)',
	'Domperidone',
	'DT',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GASTRIUM 10 (Micro Nova)'
);

-- line #12574
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GASTRIUM 1 (Micro Nova)',
	'Domperidone',
	'SUS',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GASTRIUM 1 (Micro Nova)'
);

-- line #12575
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HELDON 10 (Healthgaurd)',
	'Domperidone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HELDON 10 (Healthgaurd)'
);

-- line #12576
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JUDOM 1 (D.R.John''S)',
	'Domperidone',
	'DPS',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JUDOM 1 (D.R.John''S)'
);

-- line #12577
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JUNIDOM RDS 10 (Elder)',
	'Domperidone',
	'SUPP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JUNIDOM RDS 10 (Elder)'
);

-- line #12578
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JUNIDOM RDS 30 (Elder)',
	'Domperidone',
	'SUPP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JUNIDOM RDS 30 (Elder)'
);

-- line #12579
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOTIDOM 10 (TASMED)',
	'Domperidone',
	'DT/ TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOTIDOM 10 (TASMED)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOTIDOM 10 (TASMED)',
	'Domperidone',
	'DT/ TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOTIDOM 10 (TASMED)'
);

-- line #12580
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOTIMIN 1 (Mdc Ph.)',
	'Domperidone',
	'DPS',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOTIMIN 1 (Mdc Ph.)'
);

-- line #12581
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOTINORM 10 (Medley)',
	'Domperidone',
	'DPS',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOTINORM 10 (Medley)'
);

-- line #12582
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOTINORM 10 (Medley)',
	'Domperidone',
	'DT TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOTINORM 10 (Medley)'
);

-- line #12583
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOTINORM 5 (Medley)',
	'Domperidone',
	'SUS',
	gm.nullify_empty_string('5')::numeric,
	'mg/5 ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOTINORM 5 (Medley)'
);

-- line #12584
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Domperidone', u'always_empty': u'', u'form': u'SYR', u'brand': u'MOTINORM', u'strength_3': u'', u'company': u'Medley', u'unit': u''}

-- line #12585
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOTINORM 10 (Medley)',
	'Domperidone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOTINORM 10 (Medley)'
);

-- line #12586
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOTINORM 30 (Medley)',
	'Domperidone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOTINORM 30 (Medley)'
);

-- line #12587
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOTIWIN 10 (Svizera)',
	'Domperidone',
	'DPS',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOTIWIN 10 (Svizera)'
);

-- line #12588
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOTIWIN 5 (Svizera)',
	'Domperidone',
	'SUS',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOTIWIN 5 (Svizera)'
);

-- line #12589
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOTIWIN 10 (Svizera)',
	'Domperidone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOTIWIN 10 (Svizera)'
);

-- line #12590
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAUSHI 1 (Bestochem)',
	'Domperidone',
	'SUS',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAUSHI 1 (Bestochem)'
);

-- line #12591
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAUSIDOME 1 (ABBOTT)',
	'Domperidone',
	'SUS',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAUSIDOME 1 (ABBOTT)'
);

-- line #12592
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAUSIDOME 10 (ABBOTT)',
	'Domperidone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAUSIDOME 10 (ABBOTT)'
);

-- line #12593
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAUTIGO 10 (Bell Ph.)',
	'Domperidone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAUTIGO 10 (Bell Ph.)'
);

-- line #12594
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEUVACID-D 10 (HELVETICA)',
	'Domperidone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEUVACID-D 10 (HELVETICA)'
);

-- line #12595
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORMETIC 1 (Lupin)',
	'Domperidone',
	'SUS',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORMETIC 1 (Lupin)'
);

-- line #12596
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORMETIC 10 (Lupin)',
	'Domperidone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORMETIC 10 (Lupin)'
);

-- line #12597
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVOM 10 (TALENT LAB.)',
	'Domperidone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVOM 10 (TALENT LAB.)'
);

-- line #12598
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUDOM-10 10 (Mankind)',
	'Domperidone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUDOM-10 10 (Mankind)'
);

-- line #12599
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERIDOM 10 (Dial Ph.)',
	'Domperidone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERIDOM 10 (Dial Ph.)'
);

-- line #12600
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERIDONE 1 (AUSTRALIAN)',
	'Domperidone',
	'DROPS',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERIDONE 1 (AUSTRALIAN)'
);

-- line #12601
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERIDON 1 (Mercury)',
	'Domperidone',
	'SUS',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERIDON 1 (Mercury)'
);

-- line #12602
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERIDON 10 (Mercury)',
	'Domperidone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERIDON 10 (Mercury)'
);

-- line #12603
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERIN 10 (Dynamic)',
	'Domperidone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERIN 10 (Dynamic)'
);

-- line #12604
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRODOM 10 (Wallace)',
	'Domperidone',
	'DPS',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRODOM 10 (Wallace)'
);

-- line #12605
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRODOM 10 (Wallace)',
	'Domperidone',
	'DPS',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRODOM 10 (Wallace)'
);

-- line #12606
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRODOM MM 10 (Wallace)',
	'Domperidone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRODOM MM 10 (Wallace)'
);

-- line #12607
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRODOM 1 (Wallace)',
	'Domperidone',
	'SUSP',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRODOM 1 (Wallace)'
);

-- line #12608
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRODOM 5 (Wallace)',
	'Domperidone',
	'SUS',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRODOM 5 (Wallace)'
);

-- line #12609
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRODOM 10 (Wallace)',
	'Domperidone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRODOM 10 (Wallace)'
);

-- line #12610
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROMODON 5 (Makers)',
	'Domperidone',
	'DT',
	gm.nullify_empty_string('5')::numeric,
	'mg/5 ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROMODON 5 (Makers)'
);

-- line #12611
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'R DOM 1 (Regent)',
	'Domperidone',
	'SUS',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'R DOM 1 (Regent)'
);

-- line #12612
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'R DOM 10 (Regent)',
	'Domperidone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'R DOM 10 (Regent)'
);

-- line #12613
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIDOM 5 (Baroque)',
	'Domperidone',
	'SUS',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIDOM 5 (Baroque)'
);

-- line #12614
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIDOM 10 (Baroque)',
	'Domperidone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIDOM 10 (Baroque)'
);

-- line #12615
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIO 10 (Dallas Ph.)',
	'Domperidone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIO 10 (Dallas Ph.)'
);

-- line #12616
-- ignoring line: field [strength_1] not numeric: >>>10M<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10M', u'strength_2': u'', u'substance': u'Donepezil', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALZIDOC', u'strength_3': u'', u'company': u'Lupin', u'unit': u'mg'}

-- line #12617
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZIDOC 5 (Lupin)',
	'Donepezil',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZIDOC 5 (Lupin)'
);

-- line #12618
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZIL 23 (Intas)',
	'Donepezil',
	'SR TAB',
	gm.nullify_empty_string('23')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZIL 23 (Intas)'
);

-- line #12619
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZIL 5 (Intas)',
	'Donepezil',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZIL 5 (Intas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZIL 10 (Intas)',
	'Donepezil',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZIL 10 (Intas)'
);

-- line #12620
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMAZIL 10 (Emcure)',
	'Donepezil',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMAZIL 10 (Emcure)'
);

-- line #12621
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMAZIL 5 (Emcure)',
	'Donepezil',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMAZIL 5 (Emcure)'
);

-- line #12622
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARICEP 5 (EISAI)',
	'Donepezil',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARICEP 5 (EISAI)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARICEP 10 (EISAI)',
	'Donepezil',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARICEP 10 (EISAI)'
);

-- line #12623
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPZIL 5 (PSYCOREM)',
	'Donepezil',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPZIL 5 (PSYCOREM)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPZIL 10 (PSYCOREM)',
	'Donepezil',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPZIL 10 (PSYCOREM)'
);

-- line #12624
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DNP 5 (SHINE PH.)',
	'Donepezil',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DNP 5 (SHINE PH.)'
);

-- line #12625
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DONAZ 10 (Glenmark)',
	'DONEPEZIL',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DONAZ 10 (Glenmark)'
);

-- line #12626
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DONAZ 5 (Glenmark)',
	'DONEPEZIL',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DONAZ 5 (Glenmark)'
);

-- line #12627
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DONECEPT 5 (Protec)',
	'Donepezil',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DONECEPT 5 (Protec)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DONECEPT 10 (Protec)',
	'Donepezil',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DONECEPT 10 (Protec)'
);

-- line #12628
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DONEP 10 (Alkem)',
	'Donepezil',
	'OD TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DONEP 10 (Alkem)'
);

-- line #12629
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DONEP 5 (Alkem)',
	'Donepezil',
	'OD TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DONEP 5 (Alkem)'
);

-- line #12630
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DONEP 5 (Pentacare)',
	'Donepezil',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DONEP 5 (Pentacare)'
);

-- line #12631
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DONEP 5 (Pentacare)',
	'Donepezil',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DONEP 5 (Pentacare)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DONEP 10 (Pentacare)',
	'Donepezil',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DONEP 10 (Pentacare)'
);

-- line #12632
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOPEZIL 5 (Solus)',
	'Donepezil',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOPEZIL 5 (Solus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOPEZIL 10 (Solus)',
	'Donepezil',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOPEZIL 10 (Solus)'
);

-- line #12633
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DORENT 5 (TORRENT)',
	'Donepezil',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DORENT 5 (TORRENT)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DORENT 10 (TORRENT)',
	'Donepezil',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DORENT 10 (TORRENT)'
);

-- line #12634
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEPZIL 10 (MISSION RES.)',
	'Donepezil',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEPZIL 10 (MISSION RES.)'
);

-- line #12635
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEPZIL 5 (MISSION RES.)',
	'Donepezil',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEPZIL 5 (MISSION RES.)'
);

-- line #12636
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOZIL 5 (Mankind MAGNET)',
	'Donepezil',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOZIL 5 (Mankind MAGNET)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOZIL 10 (Mankind MAGNET)',
	'Donepezil',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOZIL 10 (Mankind MAGNET)'
);

-- line #12637
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDIO 200 (SYNER MED.)',
	'Dopamine Hcl.',
	'F.',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDIO 200 (SYNER MED.)'
);

-- line #12638
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMIN 200 (Neon)',
	'Dopamine Hcl.',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMIN 200 (Neon)'
);

-- line #12639
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOPACARD 200 (Csc Ph.)',
	'Dopamine Hcl.',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOPACARD 200 (Csc Ph.)'
);

-- line #12640
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200', u'strength_2': u'', u'substance': u'Dopamine Hcl.', u'always_empty': u'', u'form': u'', u'brand': u'DOPACARD IV', u'strength_3': u'', u'company': u'Nicholas', u'unit': u'mg/5ML'}

-- line #12641
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOPACEF 200 (CH.Bhagat)',
	'Dopamine Hcl.',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOPACEF 200 (CH.Bhagat)'
);

-- line #12642
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOPAMINE 40 (Troikaa)',
	'Dopamine Hcl.',
	'AMP',
	gm.nullify_empty_string('40')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOPAMINE 40 (Troikaa)'
);

-- line #12643
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOPAMINE 200 (Ttk Hc.)',
	'Dopamine Hcl.',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOPAMINE 200 (Ttk Hc.)'
);

-- line #12644
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOPAN 200 (CELON(REVILON))',
	'Dopamine Hcl.',
	'AMP',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOPAN 200 (CELON(REVILON))'
);

-- line #12645
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Dopamine Hcl.', u'always_empty': u'', u'form': u'INJ', u'brand': u'DOPANIS', u'strength_3': u'', u'company': u'NEISS', u'unit': u''}

-- line #12646
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOPAPLUS 200 (Vhb)',
	'Dopamine Hcl.',
	'AMP',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOPAPLUS 200 (Vhb)'
);

-- line #12647
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOPAR 200 (Samarth)',
	'Dopamine Hcl.',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOPAR 200 (Samarth)'
);

-- line #12648
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOPAS 40 (Jackson)',
	'Dopamine Hcl.',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOPAS 40 (Jackson)'
);

-- line #12649
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOPASOL 200 (SG PH.)',
	'Dopamine Hcl.',
	'AMP',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOPASOL 200 (SG PH.)'
);

-- line #12650
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Dopamine Hcl.', u'always_empty': u'', u'form': u'INJ', u'brand': u'DOPAT', u'strength_3': u'', u'company': u'Taurus Lab', u'unit': u''}

-- line #12651
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOPINGA 40 (Inga)',
	'Dopamine Hcl.',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOPINGA 40 (Inga)'
);

-- line #12652
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOPRESS 200 (United Bio.)',
	'Dopamine Hcl.',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOPRESS 200 (United Bio.)'
);

-- line #12653
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLADOP 200 (UNIMARK REM.)',
	'Dopamine Hcl.',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLADOP 200 (UNIMARK REM.)'
);

-- line #12654
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DORIKEM 500 (Alkem)',
	'DORIPENEM',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DORIKEM 500 (Alkem)'
);

-- line #12655
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DORINOSA 500 (Natco Ph.)',
	'DORIPENEM',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DORINOSA 500 (Natco Ph.)'
);

-- line #12656
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DORIPEN 500 (Aristo)',
	'DORIPENEM',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DORIPEN 500 (Aristo)'
);

-- line #12657
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'DORIPENEM', u'always_empty': u'', u'form': u'INJ', u'brand': u'INAREM', u'strength_3': u'', u'company': u'Emcure', u'unit': u''}

-- line #12658
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INAREM 250 (Emcure)',
	'DORIPENEM',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INAREM 250 (Emcure)'
);

-- line #12659
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INAREM 500 (Emcure)',
	'DORIPENEM',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INAREM 500 (Emcure)'
);

-- line #12660
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DORSENZ EYE 2 (SENSES)',
	'DORZOLAMIDE',
	'DROPS',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DORSENZ EYE 2 (SENSES)'
);

-- line #12661
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DORTAS 2 (Intas)',
	'DORZOLAMIDE',
	'EYE DPS',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DORTAS 2 (Intas)'
);

-- line #12662
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DORZOX 20 (Cipla)',
	'DORZOLAMIDE',
	'EYE DPS',
	gm.nullify_empty_string('20')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DORZOX 20 (Cipla)'
);

-- line #12663
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCUDOR 2 (F D C)',
	'DORZOLAMIDE',
	'EYE DPS',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCUDOR 2 (F D C)'
);

-- line #12664
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DO-RE-ME 50 (Intas)',
	'DOSULEPIN',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DO-RE-ME 50 (Intas)'
);

-- line #12665
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELATE 25 (Crescent Th.)',
	'DOSULEPIN',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELATE 25 (Crescent Th.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELATE 50 (Crescent Th.)',
	'DOSULEPIN',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELATE 50 (Crescent Th.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELATE 75 (Crescent Th.)',
	'DOSULEPIN',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELATE 75 (Crescent Th.)'
);

-- line #12666
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PINDEP 10 (Orchid Hc.)',
	'DOSULEPIN',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PINDEP 10 (Orchid Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PINDEP 25 (Orchid Hc.)',
	'DOSULEPIN',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PINDEP 25 (Orchid Hc.)'
);

-- line #12667
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PINDEP 50 (Orchid Hc.)',
	'DOSULEPIN',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PINDEP 50 (Orchid Hc.)'
);

-- line #12668
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROTHEO 25 (Theo Ph.)',
	'DOSULEPIN',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROTHEO 25 (Theo Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROTHEO 75 (Theo Ph.)',
	'DOSULEPIN',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROTHEO 75 (Theo Ph.)'
);

-- line #12669
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARPIN 25 (Rkg)',
	'Dothiepin Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARPIN 25 (Rkg)'
);

-- line #12670
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARPIN 25 (Rpg Life)',
	'Dothiepin Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARPIN 25 (Rpg Life)'
);

-- line #12671
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARPIN 75 (Rpg Life)',
	'Dothiepin Hcl.',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARPIN 75 (Rpg Life)'
);

-- line #12672
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPNOC 25 (MOVA PH.)',
	'Dothiepin Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPNOC 25 (MOVA PH.)'
);

-- line #12673
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPNOC 50 (MOVA PH.)',
	'Dothiepin Hcl.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPNOC 50 (MOVA PH.)'
);

-- line #12674
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPNOC 75 (MOVA PH.)',
	'Dothiepin Hcl.',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPNOC 75 (MOVA PH.)'
);

-- line #12675
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOPIN 25 (Ind-Swift)',
	'Dothiepin Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOPIN 25 (Ind-Swift)'
);

-- line #12676
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOPIN 75 (Ind-Swift)',
	'Dothiepin Hcl.',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOPIN 75 (Ind-Swift)'
);

-- line #12677
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DORE-ME 25 (Intas)',
	'Dothiepin Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DORE-ME 25 (Intas)'
);

-- line #12678
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DORE-ME 75 (Intas)',
	'Dothiepin Hcl.',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DORE-ME 75 (Intas)'
);

-- line #12679
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOTHEX 25 (Triton Hc.)',
	'Dothiepin Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOTHEX 25 (Triton Hc.)'
);

-- line #12680
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOTHEX 75 (Triton Hc.)',
	'Dothiepin Hcl.',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOTHEX 75 (Triton Hc.)'
);

-- line #12681
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOTHIDEP 25 (Tripada Hc.)',
	'Dothiepin Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOTHIDEP 25 (Tripada Hc.)'
);

-- line #12682
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOTHIDEP 75 (Tripada Hc.)',
	'Dothiepin Hcl.',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOTHIDEP 75 (Tripada Hc.)'
);

-- line #12683
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOTHIN 25 (Reliance)',
	'Dothiepin Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOTHIN 25 (Reliance)'
);

-- line #12684
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOTHIN 75 (Reliance)',
	'Dothiepin Hcl.',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOTHIN 75 (Reliance)'
);

-- line #12685
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOTHIP 25 (Synapse)',
	'Dothiepin Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOTHIP 25 (Synapse)'
);

-- line #12686
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOTHIP 50 (Synapse)',
	'Dothiepin Hcl.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOTHIP 50 (Synapse)'
);

-- line #12687
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOTHIP 75 (Synapse)',
	'Dothiepin Hcl.',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOTHIP 75 (Synapse)'
);

-- line #12688
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOTHITAB 25 (PSYCOREM)',
	'Dothiepin Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOTHITAB 25 (PSYCOREM)'
);

-- line #12689
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOTHITAB 50 (PSYCOREM)',
	'Dothiepin Hcl.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOTHITAB 50 (PSYCOREM)'
);

-- line #12690
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOTHITAB 75 (PSYCOREM)',
	'Dothiepin Hcl.',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOTHITAB 75 (PSYCOREM)'
);

-- line #12691
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOTH 100 (Mano)',
	'Dothiepin Hcl.',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOTH 100 (Mano)'
);

-- line #12692
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOTH 10 (Mano)',
	'Dothiepin Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOTH 10 (Mano)'
);

-- line #12693
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOTH 150 (Mano)',
	'Dothiepin Hcl.',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOTH 150 (Mano)'
);

-- line #12694
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOTH 25 (Mano)',
	'Dothiepin Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOTH 25 (Mano)'
);

-- line #12695
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOTH 50 (Mano)',
	'Dothiepin Hcl.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOTH 50 (Mano)'
);

-- line #12696
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOTH 75 (Mano)',
	'Dothiepin Hcl.',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOTH 75 (Mano)'
);

-- line #12697
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOTIN 25 (TASMED)',
	'Dothiepin Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOTIN 25 (TASMED)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOTIN 50 (TASMED)',
	'Dothiepin Hcl.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOTIN 50 (TASMED)'
);

-- line #12698
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOTIN 50 (TASMED)',
	'Dothiepin Hcl.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOTIN 50 (TASMED)'
);

-- line #12699
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOTIN 75 (TASMED)',
	'Dothiepin Hcl.',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOTIN 75 (TASMED)'
);

-- line #12700
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXODEP 25 (Sun)',
	'Dothiepin Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXODEP 25 (Sun)'
);

-- line #12701
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXODEP 75 (Sun)',
	'Dothiepin Hcl.',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXODEP 75 (Sun)'
);

-- line #12702
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OTHIPEN 25 (OREVA DARMO.)',
	'Dothiepin Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OTHIPEN 25 (OREVA DARMO.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OTHIPEN 75 (OREVA DARMO.)',
	'Dothiepin Hcl.',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OTHIPEN 75 (OREVA DARMO.)'
);

-- line #12703
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROTHIADEN 25 (ABBOTT)',
	'Dothiepin Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROTHIADEN 25 (ABBOTT)'
);

-- line #12704
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROTHIADEN 50 (ABBOTT)',
	'Dothiepin Hcl.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROTHIADEN 50 (ABBOTT)'
);

-- line #12705
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROTHIADEN 75 (ABBOTT)',
	'Dothiepin Hcl.',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROTHIADEN 75 (ABBOTT)'
);

-- line #12706
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAROPRAM 20 (Khandelwal)',
	'DOXAPRAM',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAROPRAM 20 (Khandelwal)'
);

-- line #12707
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXAPRAM 20 (Khandelwal)',
	'Doxapram',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXAPRAM 20 (Khandelwal)'
);

-- line #12708
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALFAZOSIN 1 (Aurobindo)',
	'Doxazosin',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALFAZOSIN 1 (Aurobindo)'
);

-- line #12709
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALFAZOSIN 2 (Aurobindo)',
	'Doxazosin',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALFAZOSIN 2 (Aurobindo)'
);

-- line #12710
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXACARD 1 (Cipla)',
	'Doxazosin',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXACARD 1 (Cipla)'
);

-- line #12711
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXACARD 2 (Cipla)',
	'Doxazosin',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXACARD 2 (Cipla)'
);

-- line #12712
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXACARD 4 (Cipla)',
	'Doxazosin',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXACARD 4 (Cipla)'
);

-- line #12713
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXAPRESS 1 (Cardicare)',
	'Doxazosin',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXAPRESS 1 (Cardicare)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXAPRESS 2 (Cardicare)',
	'Doxazosin',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXAPRESS 2 (Cardicare)'
);

-- line #12714
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DURACARD 1 (Sun)',
	'Doxazosin',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DURACARD 1 (Sun)'
);

-- line #12715
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DURACARD 2 (Sun)',
	'Doxazosin',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DURACARD 2 (Sun)'
);

-- line #12716
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DURACARD 4 (Sun)',
	'Doxazosin',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DURACARD 4 (Sun)'
);

-- line #12717
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DURATEN 1 (Servetus)',
	'Doxazosin',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DURATEN 1 (Servetus)'
);

-- line #12718
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DURATEN 2 (Servetus)',
	'Doxazosin',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DURATEN 2 (Servetus)'
);

-- line #12719
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXEDEP 25 (LA DRUG)',
	'Doxepin Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXEDEP 25 (LA DRUG)'
);

-- line #12720
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXEDEP 75 (LA DRUG)',
	'Doxepin Hcl.',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXEDEP 75 (LA DRUG)'
);

-- line #12721
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXETAR 10 (Torrent)',
	'Doxepin Hcl.',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXETAR 10 (Torrent)'
);

-- line #12722
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXETAR 25 (Torrent)',
	'Doxepin Hcl.',
	'CAP',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXETAR 25 (Torrent)'
);

-- line #12723
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXETAR 75 (Torrent)',
	'Doxepin Hcl.',
	'F. CAP',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXETAR 75 (Torrent)'
);

-- line #12724
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXIN 10 (Intas)',
	'Doxepin Hcl.',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXIN 10 (Intas)'
);

-- line #12725
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXIN 25 (Intas)',
	'Doxepin Hcl.',
	'CAP',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXIN 25 (Intas)'
);

-- line #12726
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXIN 75 (Intas)',
	'Doxepin Hcl.',
	'CAP',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXIN 75 (Intas)'
);

-- line #12727
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXYRIL 25 (Reliance)',
	'Doxepin Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXYRIL 25 (Reliance)'
);

-- line #12728
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXIPEACE 10 (GSK)',
	'Doxepin Hcl.',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXIPEACE 10 (GSK)'
);

-- line #12729
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXIPEACE 25 (GSK)',
	'Doxepin Hcl.',
	'CAP',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXIPEACE 25 (GSK)'
);

-- line #12730
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXIPEACE 75 (GSK)',
	'Doxepin Hcl.',
	'CAP',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXIPEACE 75 (GSK)'
);

-- line #12731
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOCTADERM 5 (Croslands)',
	'Doxepin Hcl.',
	'CRM',
	gm.nullify_empty_string('5')::numeric,
	'%W/W(+BENZYL ALCOHOL 1'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOCTADERM 5 (Croslands)'
);

-- line #12732
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PSYCHOPIN 25 (Rkg)',
	'Doxepin Hcl.',
	'CAP',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PSYCHOPIN 25 (Rkg)'
);

-- line #12733
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2.5MCG', u'strength_2': u'', u'substance': u'DOXERCALCIFEROL', u'always_empty': u'', u'form': u'', u'brand': u'REDISPAR MCG', u'strength_3': u'', u'company': u"Dr.Reddy''S", u'unit': u''}

-- line #12734
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.5MCG', u'strength_2': u'', u'substance': u'DOXERCALCIFEROL', u'always_empty': u'', u'form': u'', u'brand': u'REDISPAR O5MCG', u'strength_3': u'', u'company': u"Dr.Reddy''S", u'unit': u''}

-- line #12735
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARCIDOX 200 (Sun)',
	'DOXIFLURIDINE',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARCIDOX 200 (Sun)'
);

-- line #12736
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXELDOX 400 (STAUNCH)',
	'DOXOFYLLINE',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXELDOX 400 (STAUNCH)'
);

-- line #12737
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'DOXOFYLLINE', u'always_empty': u'', u'form': u'TAB', u'brand': u'AXLEDOX', u'strength_3': u'', u'company': u'STAUNCH', u'unit': u''}

-- line #12738
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'DOXOFYLLINE', u'always_empty': u'', u'form': u'TAB', u'brand': u'BEFREE', u'strength_3': u'', u'company': u'Wockhardt', u'unit': u''}

-- line #12739
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BESTOFYLINE 100 (Bestochem)',
	'DOXOFYLLINE',
	'SYP',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BESTOFYLINE 100 (Bestochem)'
);

-- line #12740
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BESTOFYLINE 400 (Bestochem)',
	'DOXOFYLLINE',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BESTOFYLINE 400 (Bestochem)'
);

-- line #12741
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIDFREE 100 (Wockhardt)',
	'DOXOFYLLINE',
	'SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIDFREE 100 (Wockhardt)'
);

-- line #12742
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CODOFYLINE 100 (A.F.D.)',
	'DOXOFYLLINE',
	'SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CODOFYLINE 100 (A.F.D.)'
);

-- line #12743
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CODOFYLINE 400 (A.F.D.)',
	'DOXOFYLLINE',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CODOFYLINE 400 (A.F.D.)'
);

-- line #12744
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'D-FYLIN 400 (Cipla)',
	'DOXOFYLLINE',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'D-FYLIN 400 (Cipla)'
);

-- line #12745
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOFASMA 400 (TASMED)',
	'DOXOFYLLINE',
	'OD TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOFASMA 400 (TASMED)'
);

-- line #12746
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOFASMA 800 (TASMED)',
	'DOXOFYLLINE',
	'OD TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOFASMA 800 (TASMED)'
);

-- line #12747
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXFIL 400 (SHINCE)',
	'DOXOFYLLINE',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXFIL 400 (SHINCE)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXFIL 800 (SHINCE)',
	'DOXOFYLLINE',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXFIL 800 (SHINCE)'
);

-- line #12748
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXFREE 100 (Unichem)',
	'DOXOFYLLINE',
	'SYRUP',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXFREE 100 (Unichem)'
);

-- line #12749
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'400', u'strength_2': u'', u'substance': u'DOXOFYLLINE', u'always_empty': u'', u'form': u'', u'brand': u'DOXFREE', u'strength_3': u'', u'company': u'Unichem', u'unit': u'mg'}

-- line #12750
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'400', u'strength_2': u'', u'substance': u'DOXOFYLLINE', u'always_empty': u'', u'form': u'', u'brand': u'DOXIBA', u'strength_3': u'', u'company': u'F D C', u'unit': u'mg'}

-- line #12751
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXIBA 100 (F D C)',
	'DOXOFYLLINE',
	'SYRUP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXIBA 100 (F D C)'
);

-- line #12752
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXIFLO 800 (Lupin)',
	'DOXOFYLLINE',
	'OD',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXIFLO 800 (Lupin)'
);

-- line #12753
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXIFLO 100 (Lupin)',
	'DOXOFYLLINE',
	'SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXIFLO 100 (Lupin)'
);

-- line #12754
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXIFLO 400 (LUPIN)',
	'DOXOFYLLINE',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXIFLO 400 (LUPIN)'
);

-- line #12755
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXMA 400 (HANBURYS)',
	'DOXOFYLLINE',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXMA 400 (HANBURYS)'
);

-- line #12756
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXOBID 100 (DR. REDDY''S)',
	'DOXOFYLLINE',
	'SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXOBID 100 (DR. REDDY''S)'
);

-- line #12757
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXOBID 400 (Dr.Reddy''S)',
	'DOXOFYLLINE',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXOBID 400 (Dr.Reddy''S)'
);

-- line #12758
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXOBID 400 (DR. REDDY''S)',
	'DOXOFYLLINE',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXOBID 400 (DR. REDDY''S)'
);

-- line #12759
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXOBRON 800 (Intra(INVISION))',
	'DOXOFYLLINE',
	'SR TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXOBRON 800 (Intra(INVISION))'
);

-- line #12760
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXOBRON 100 (Intra(INVISION))',
	'DOXOFYLLINE',
	'SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXOBRON 100 (Intra(INVISION))'
);

-- line #12761
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXOBRON 400 (Intra(INVISION))',
	'DOXOFYLLINE',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXOBRON 400 (Intra(INVISION))'
);

-- line #12762
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXOLIN 100 (German R.)',
	'DOXOFYLLINE',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXOLIN 100 (German R.)'
);

-- line #12763
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXOLIN 400 (Cadila Hc.)',
	'DOXOFYLLINE',
	'OD TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXOLIN 400 (Cadila Hc.)'
);

-- line #12764
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXOLIN 800 (German R.)',
	'DOXOFYLLINE',
	'OD TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXOLIN 800 (German R.)'
);

-- line #12765
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXOLIN 100 (German R.)',
	'DOXOFYLLINE',
	'SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg(ETHANOL 0.4ML)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXOLIN 100 (German R.)'
);

-- line #12766
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXOLIN 400 (German R.)',
	'DOXOFYLLINE',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXOLIN 400 (German R.)'
);

-- line #12767
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXOMAX 800 (Aristo)',
	'DOXOFYLLINE',
	'SR TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXOMAX 800 (Aristo)'
);

-- line #12768
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXOMAX 100 (Aristo)',
	'DOXOFYLLINE',
	'SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXOMAX 100 (Aristo)'
);

-- line #12769
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXOMAX 400 (Aristo)',
	'DOXOFYLLINE',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXOMAX 400 (Aristo)'
);

-- line #12770
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXOMOX 400 (Aristo)',
	'DOXOFYLLINE',
	'SR TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXOMOX 400 (Aristo)'
);

-- line #12771
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXOPHYL 400 (Franco I.)',
	'DOXOFYLLINE',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXOPHYL 400 (Franco I.)'
);

-- line #12772
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXORIL 100 (Macleods)',
	'DOXOFYLLINE',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXORIL 100 (Macleods)'
);

-- line #12773
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXORIL 400 (Macleods)',
	'DOXOFYLLINE',
	'OD TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXORIL 400 (Macleods)'
);

-- line #12774
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXORIL 800 (Macleods)',
	'DOXOFYLLINE',
	'OD TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXORIL 800 (Macleods)'
);

-- line #12775
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXORIL 100 (Macleods)',
	'DOXOFYLLINE',
	'SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXORIL 100 (Macleods)'
);

-- line #12776
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXORIL 200 (Macleods)',
	'DOXOFYLLINE',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXORIL 200 (Macleods)'
);

-- line #12777
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXORIL 400 (Macleods)',
	'DOXOFYLLINE',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXORIL 400 (Macleods)'
);

-- line #12778
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXOSUBH 400 (SUBHREK PH.)',
	'DOXOFYLLINE',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXOSUBH 400 (SUBHREK PH.)'
);

-- line #12779
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXOTEC 100 (Cipla)',
	'DOXOFYLLINE',
	'SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXOTEC 100 (Cipla)'
);

-- line #12780
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXOTEC 400 (Cipla)',
	'DOXOFYLLINE',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXOTEC 400 (Cipla)'
);

-- line #12781
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXOVENT 100 (MAJESTA)',
	'DOXOFYLLINE',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXOVENT 100 (MAJESTA)'
);

-- line #12782
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXOVENT 100 (Glenmark)',
	'DOXOFYLLINE',
	'SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXOVENT 100 (Glenmark)'
);

-- line #12783
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXOVENT 400 (Glenmark)',
	'DOXOFYLLINE',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXOVENT 400 (Glenmark)'
);

-- line #12784
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXYLIN 400 (Active Hc.)',
	'DOXOFYLLINE',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXYLIN 400 (Active Hc.)'
);

-- line #12785
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DXP 400 (ORION BIOTECH.)',
	'DOXOFYLLINE',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DXP 400 (ORION BIOTECH.)'
);

-- line #12786
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FREEFIL 800 (Fourrts)',
	'DOXOFYLLINE',
	'OD TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FREEFIL 800 (Fourrts)'
);

-- line #12787
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FREEFIL 100 (Fourrts)',
	'DOXOFYLLINE',
	'SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FREEFIL 100 (Fourrts)'
);

-- line #12788
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FREEFIL 400 (Fourrts)',
	'DOXOFYLLINE',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FREEFIL 400 (Fourrts)'
);

-- line #12789
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FREEWAY 400 (Panacea)',
	'DOXOFYLLINE',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FREEWAY 400 (Panacea)'
);

-- line #12790
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FYCON 400 (WISCON)',
	'DOXOFYLLINE',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FYCON 400 (WISCON)'
);

-- line #12791
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUNAIR 400 (GENESIS)',
	'DOXOFYLLINE',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUNAIR 400 (GENESIS)'
);

-- line #12792
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUNGFYL 400 (Yash Ph.)',
	'DOXOFYLLINE',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUNGFYL 400 (Yash Ph.)'
);

-- line #12793
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUCOSMA 400 (AZINE HC.)',
	'DOXOFYLLINE',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'800(SR)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUCOSMA 400 (AZINE HC.)'
);

-- line #12794
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXYPUR 400 (Mars)',
	'DOXOFYLLINE',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXYPUR 400 (Mars)'
);

-- line #12795
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHYLLIN 100 (RND LAB)',
	'DOXOFYLLINE',
	'SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHYLLIN 100 (RND LAB)'
);

-- line #12796
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHYLLIN 400 (RND LAB)',
	'DOXOFYLLINE',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'800(SR)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHYLLIN 400 (RND LAB)'
);

-- line #12797
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PULMODOX 800 (Ttk Hc.)',
	'DOXOFYLLINE',
	'SR TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PULMODOX 800 (Ttk Hc.)'
);

-- line #12798
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PULMODOX 400 (Ttk Hc.)',
	'DOXOFYLLINE',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PULMODOX 400 (Ttk Hc.)'
);

-- line #12799
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADRIAMYCIN 10 (Pharmacia)',
	'Doxorubicin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADRIAMYCIN 10 (Pharmacia)'
);

-- line #12800
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADRIAMYCIN 50 (Pharmacia)',
	'Doxorubicin',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADRIAMYCIN 50 (Pharmacia)'
);

-- line #12801
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADRIM 10 (Dabur Ph.)',
	'Doxorubicin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADRIM 10 (Dabur Ph.)'
);

-- line #12802
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADRIM 50 (Dabur Ph.)',
	'Doxorubicin',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADRIM 50 (Dabur Ph.)'
);

-- line #12803
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADROSAL 10 (Vhb)',
	'Doxorubicin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADROSAL 10 (Vhb)'
);

-- line #12804
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADROSAL 50 (Vhb)',
	'Doxorubicin',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADROSAL 50 (Vhb)'
);

-- line #12805
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADVADOX 2 (SUPER SPE.)',
	'Doxorubicin',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADVADOX 2 (SUPER SPE.)'
);

-- line #12806
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMDOXO 10 (AMRONCO)',
	'Doxorubicin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMDOXO 10 (AMRONCO)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMDOXO 50 (AMRONCO)',
	'Doxorubicin',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMDOXO 50 (AMRONCO)'
);

-- line #12807
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CADRIA 10 (Cadila)',
	'Doxorubicin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CADRIA 10 (Cadila)'
);

-- line #12808
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CADRIA 50 (Cadila)',
	'Doxorubicin',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CADRIA 50 (Cadila)'
);

-- line #12809
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CADRIA-L 20 (Cadila Ph.)',
	'Doxorubicin',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg(PEGYLATED LIPOSOMAL DOXORUBICIN)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CADRIA-L 20 (Cadila Ph.)'
);

-- line #12810
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDIA 10 (ZYDUS CADILA)',
	'Doxorubicin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDIA 10 (ZYDUS CADILA)'
);

-- line #12811
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDIA 50 (ZYDUS CADILA)',
	'Doxorubicin',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDIA 50 (ZYDUS CADILA)'
);

-- line #12812
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOBICIN 10 (CH.Bhagat)',
	'Doxorubicin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOBICIN 10 (CH.Bhagat)'
);

-- line #12813
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOBICIN 50 (CH.Bhagat)',
	'Doxorubicin',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOBICIN 50 (CH.Bhagat)'
);

-- line #12814
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOBIXIN 10 (German R.)',
	'Doxorubicin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOBIXIN 10 (German R.)'
);

-- line #12815
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOBIXIN 50 (German R.)',
	'Doxorubicin',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOBIXIN 50 (German R.)'
);

-- line #12816
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXILYD 10 (CELON(VIVILON))',
	'Doxorubicin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'50'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXILYD 10 (CELON(VIVILON))'
);

-- line #12817
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXOBIN 10 (Biological E.)',
	'Doxorubicin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXOBIN 10 (Biological E.)'
);

-- line #12818
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXOBIN 50 (Biological E.)',
	'Doxorubicin',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXOBIN 50 (Biological E.)'
);

-- line #12819
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXOCARE 10 (Criticare)',
	'Doxorubicin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXOCARE 10 (Criticare)'
);

-- line #12820
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXOCARE 50 (Criticare)',
	'Doxorubicin',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/25ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXOCARE 50 (Criticare)'
);

-- line #12821
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXOFACT 10 (ZEN LIFE)',
	'Doxorubicin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXOFACT 10 (ZEN LIFE)'
);

-- line #12822
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXOFACT 50 (ZEN LIFE)',
	'Doxorubicin',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXOFACT 50 (ZEN LIFE)'
);

-- line #12823
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXOLEM 10 (Elder)',
	'Doxorubicin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXOLEM 10 (Elder)'
);

-- line #12824
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXOLEM 50 (Elder)',
	'Doxorubicin',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXOLEM 50 (Elder)'
);

-- line #12825
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXOMED 10 (Cadila Hc.)',
	'Doxorubicin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXOMED 10 (Cadila Hc.)'
);

-- line #12826
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXOMED 50 (Cadila Hc.)',
	'Doxorubicin',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXOMED 50 (Cadila Hc.)'
);

-- line #12827
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXOPAR 10 (Parenteral)',
	'Doxorubicin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg(LYOPHILIZED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXOPAR 10 (Parenteral)'
);

-- line #12828
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXOPAR 50 (Parenteral)',
	'Doxorubicin',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg(LYOPHILIZED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXOPAR 50 (Parenteral)'
);

-- line #12829
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXOREX 10 (Samarth)',
	'Doxorubicin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXOREX 10 (Samarth)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXOREX 50 (Samarth)',
	'Doxorubicin',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXOREX 50 (Samarth)'
);

-- line #12830
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXORUBICIN 10 (DR. REDDY''S)',
	'Doxorubicin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg(METHYL PARABEN 1'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXORUBICIN 10 (DR. REDDY''S)'
);

-- line #12831
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXORUBICIN 50 (DR. REDDY''S)',
	'Doxorubicin',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXORUBICIN 50 (DR. REDDY''S)'
);

-- line #12832
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXORUBICIN 10 (Khandelwal)',
	'Doxorubicin',
	'VIAL',
	gm.nullify_empty_string('10')::numeric,
	'50'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXORUBICIN 10 (Khandelwal)'
);

-- line #12833
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXORUBIN 10 (Biochem)',
	'Doxorubicin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXORUBIN 10 (Biochem)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXORUBIN 50 (Biochem)',
	'Doxorubicin',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXORUBIN 50 (Biochem)'
);

-- line #12834
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXORUBIN 10 (Khandelwal)',
	'Doxorubicin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXORUBIN 10 (Khandelwal)'
);

-- line #12835
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXORUBIN 50 (Khandelwal)',
	'Doxorubicin',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXORUBIN 50 (Khandelwal)'
);

-- line #12836
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXOTERO 10 (HETERO HC.)',
	'Doxorubicin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXOTERO 10 (HETERO HC.)'
);

-- line #12837
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXOTERO 50 (HETERO HC.)',
	'Doxorubicin',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXOTERO 50 (HETERO HC.)'
);

-- line #12838
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXUTEC 10 (United Bio.)',
	'Doxorubicin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXUTEC 10 (United Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXUTEC 50 (United Bio.)',
	'Doxorubicin',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXUTEC 50 (United Bio.)'
);

-- line #12839
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'(LIPOSOME)', u'strength_2': u'', u'substance': u'Doxorubicin', u'always_empty': u'', u'form': u'INJ', u'brand': u'DRIX', u'strength_3': u'', u'company': u'Wockhardt', u'unit': u''}

-- line #12840
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUXOCIN 10 (Biochem)',
	'Doxorubicin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUXOCIN 10 (Biochem)'
);

-- line #12841
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUXOCIN 50 (Biochem)',
	'Doxorubicin',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUXOCIN 50 (Biochem)'
);

-- line #12842
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENODOX 10 (GENESIS ORG.)',
	'Doxorubicin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENODOX 10 (GENESIS ORG.)'
);

-- line #12843
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENODOX 50 (GENESIS ORG.)',
	'Doxorubicin',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENODOX 50 (GENESIS ORG.)'
);

-- line #12844
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KLASINOMYCIN 20 (Khandelwal)',
	'Doxorubicin',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KLASINOMYCIN 20 (Khandelwal)'
);

-- line #12845
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPODOX 2 (SUN)',
	'Doxorubicin',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPODOX 2 (SUN)'
);

-- line #12846
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2', u'strength_2': u'', u'substance': u'Doxorubicin', u'always_empty': u'', u'form': u'', u'brand': u'LIPODOX', u'strength_3': u'', u'company': u'Sun', u'unit': u'mg/ML'}

-- line #12847
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYPHIDOX 10 (Cytomed(Alkem))',
	'Doxorubicin',
	'VIAL',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYPHIDOX 10 (Cytomed(Alkem))'
);

-- line #12848
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYPHIDOX 50 (Cytomed(Alkem))',
	'Doxorubicin',
	'VIAL',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYPHIDOX 50 (Cytomed(Alkem))'
);

-- line #12849
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYPORUBICIN 20 (Khandelwal)',
	'Doxorubicin',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYPORUBICIN 20 (Khandelwal)'
);

-- line #12850
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAPRODOX 10 (MIRACALUS)',
	'Doxorubicin',
	'VIAL',
	gm.nullify_empty_string('10')::numeric,
	'50'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAPRODOX 10 (MIRACALUS)'
);

-- line #12851
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NISDOXO 10 (NEISS)',
	'Doxorubicin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NISDOXO 10 (NEISS)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NISDOXO 50 (NEISS)',
	'Doxorubicin',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NISDOXO 50 (NEISS)'
);

-- line #12852
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONCODOX 10 (Cipla)',
	'Doxorubicin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONCODOX 10 (Cipla)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONCODOX 50 (Cipla)',
	'Doxorubicin',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONCODOX 50 (Cipla)'
);

-- line #12853
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONCODRIA 10 (Sun)',
	'Doxorubicin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONCODRIA 10 (Sun)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONCODRIA 50 (Sun)',
	'Doxorubicin',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONCODRIA 50 (Sun)'
);

-- line #12854
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AKEM 100 (Medoz Ph.)',
	'Doxycycline',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg(HYCLATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AKEM 100 (Medoz Ph.)'
);

-- line #12855
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVIDOX 100 (Avalanche)',
	'Doxycycline',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVIDOX 100 (Avalanche)'
);

-- line #12856
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BESTODOX 100 (Bestochem)',
	'Doxycycline',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BESTODOX 100 (Bestochem)'
);

-- line #12857
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIDOX 100 (Ajanta Ph.)',
	'Doxycycline',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIDOX 100 (Ajanta Ph.)'
);

-- line #12858
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIODOXI 100 (Biochem)',
	'Doxycycline',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIODOXI 100 (Biochem)'
);

-- line #12859
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIODOXI 100 (Biochem)',
	'Doxycycline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIODOXI 100 (Biochem)'
);

-- line #12860
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CADOXY 100 (Zydus Cadila(Mm))',
	'Doxycycline',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CADOXY 100 (Zydus Cadila(Mm))'
);

-- line #12861
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEEDOX 100 (Shalaks)',
	'Doxycycline',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEEDOX 100 (Shalaks)'
);

-- line #12862
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEEDOXY 100 (Bipl(Radico Lab))',
	'Doxycycline',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEEDOXY 100 (Bipl(Radico Lab))'
);

-- line #12863
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHEMEDOX 100 (Chemo D.)',
	'Doxycycline',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHEMEDOX 100 (Chemo D.)'
);

-- line #12864
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHEMEDOX-HT 100 (Chemo D.)',
	'Doxycycline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHEMEDOX-HT 100 (Chemo D.)'
);

-- line #12865
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CODOX 100 (Comed)',
	'Doxycycline',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CODOX 100 (Comed)'
);

-- line #12866
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORDOX 100 (Corona)',
	'Doxycycline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORDOX 100 (Corona)'
);

-- line #12867
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUREDOX 100 (Logos)',
	'Doxycycline',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUREDOX 100 (Logos)'
);

-- line #12868
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUREDOX 100 (Logos)',
	'DoxycyclinE',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg(HYCLATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUREDOX 100 (Logos)'
);

-- line #12869
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEDOXYN 100 (Dwd)',
	'Doxycycline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEDOXYN 100 (Dwd)'
);

-- line #12870
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DELINE 100 (Alde Medi.)',
	'Doxycycline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DELINE 100 (Alde Medi.)'
);

-- line #12871
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DISDOX 100 (Chemo Bio.)',
	'Doxycycline',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DISDOX 100 (Chemo Bio.)'
);

-- line #12872
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DMT 100 (Alde Medi.)',
	'Doxycycline',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DMT 100 (Alde Medi.)'
);

-- line #12873
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOBID 100 (Chemech)',
	'Doxycycline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOBID 100 (Chemech)'
);

-- line #12874
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DORK 100 (Lanark)',
	'Doxycycline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DORK 100 (Lanark)'
);

-- line #12875
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXAL 100 (Sayona)',
	'Doxycycline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXAL 100 (Sayona)'
);

-- line #12876
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXAP 100 (Dynamic)',
	'Doxycycline',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXAP 100 (Dynamic)'
);

-- line #12877
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXEC 100 (Interpharm)',
	'Doxycycline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg(MONOHYD.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXEC 100 (Interpharm)'
);

-- line #12878
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXICIP 100 (Cipla)',
	'Doxycycline',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXICIP 100 (Cipla)'
);

-- line #12879
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXICIP 10 (Cipla)',
	'Doxycycline',
	'DPS',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXICIP 10 (Cipla)'
);

-- line #12880
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXICIP 100 (Cipla)',
	'Doxycycline',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXICIP 100 (Cipla)'
);

-- line #12881
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXICIP 100 (Cipla)',
	'Doxycycline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXICIP 100 (Cipla)'
);

-- line #12882
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXID 100 (Biostrass)',
	'Doxycycline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXID 100 (Biostrass)'
);

-- line #12883
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXIFEM 100 (Fem care)',
	'Doxycycline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXIFEM 100 (Fem care)'
);

-- line #12884
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXINA 100 (Centaur)',
	'Doxycycline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXINA 100 (Centaur)'
);

-- line #12885
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXIN 100 (Samson)',
	'Doxycycline',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg(HCL.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXIN 100 (Samson)'
);

-- line #12886
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXITAB 100 (PSYCOREM)',
	'Doxycycline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXITAB 100 (PSYCOREM)'
);

-- line #12887
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOX 100 (Skymax)',
	'Doxycycline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg(HYCLATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOX 100 (Skymax)'
);

-- line #12888
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXT 100 (Dr.Reddy''S)',
	'Doxycycline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXT 100 (Dr.Reddy''S)'
);

-- line #12889
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXT 100 (DR. REDDY''S)',
	'Doxycycline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXT 100 (DR. REDDY''S)'
);

-- line #12890
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXT 50 (Dr.Reddy''S)',
	'Doxycycline',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXT 50 (Dr.Reddy''S)'
);

-- line #12891
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXY-1 100 (U S V)',
	'Doxycycline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXY-1 100 (U S V)'
);

-- line #12892
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXY-1 200 (U S V)',
	'Doxycycline',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXY-1 200 (U S V)'
);

-- line #12893
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXY-1 50 (U S V)',
	'Doxycycline',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXY-1 50 (U S V)'
);

-- line #12894
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXYAT 100 (Atoz Ph.)',
	'Doxycycline',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXYAT 100 (Atoz Ph.)'
);

-- line #12895
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXYBITE 100 (Biogenetic)',
	'Doxycycline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXYBITE 100 (Biogenetic)'
);

-- line #12896
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXYCAP 100 (Mcneil & ARGUS)',
	'Doxycycline',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXYCAP 100 (Mcneil & ARGUS)'
);

-- line #12897
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXYCIN 100 (Growell)',
	'Doxycycline',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXYCIN 100 (Growell)'
);

-- line #12898
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXYCLIN 100 (Inga)',
	'Doxycycline',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXYCLIN 100 (Inga)'
);

-- line #12899
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXYCYCLINE 100 (HETERO HC.)',
	'Doxycycline',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXYCYCLINE 100 (HETERO HC.)'
);

-- line #12900
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXY-D 100 (Dial Ph.)',
	'Doxycycline',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXY-D 100 (Dial Ph.)'
);

-- line #12901
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXYLAB 100 (Laborate)',
	'Doxycycline',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXYLAB 100 (Laborate)'
);

-- line #12902
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXYLEB 100 (Leben)',
	'Doxycycline',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXYLEB 100 (Leben)'
);

-- line #12903
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXYLIV-100 100 (Alive)',
	'Doxycycline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXYLIV-100 100 (Alive)'
);

-- line #12904
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXYLLION 100 (Stallion)',
	'Doxycycline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXYLLION 100 (Stallion)'
);

-- line #12905
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXYNAC 100 (Nac Int.)',
	'Doxycycline',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXYNAC 100 (Nac Int.)'
);

-- line #12906
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXYNATE 100 (Atoz Ph.)',
	'Doxycycline',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXYNATE 100 (Atoz Ph.)'
);

-- line #12907
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXYNOR 100 (Norris Med.)',
	'Doxycycline',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXYNOR 100 (Norris Med.)'
);

-- line #12908
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXYN 100 (Active Hc.)',
	'Doxycycline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXYN 100 (Active Hc.)'
);

-- line #12909
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXYPAL-DR 100 (Jagsonpal)',
	'Doxycycline',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXYPAL-DR 100 (Jagsonpal)'
);

-- line #12910
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXYREK-DR 100 (Rekvina)',
	'Doxycycline',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg(HYCLATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXYREK-DR 100 (Rekvina)'
);

-- line #12911
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXYSAIN 100 (Sain Med.)',
	'Doxycycline',
	'CAP/TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXYSAIN 100 (Sain Med.)'
);

-- line #12912
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXYTOP 100 (Overseas Hc.)',
	'Doxycycline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg(HYCLATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXYTOP 100 (Overseas Hc.)'
);

-- line #12913
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOXYZED 100 (Zota)',
	'Doxycycline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOXYZED 100 (Zota)'
);

-- line #12914
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DURADOX 100 (INTERMED)',
	'Doxycycline',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DURADOX 100 (INTERMED)'
);

-- line #12915
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DX-100 100 (Arbro Ph.)',
	'Doxycycline',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DX-100 100 (Arbro Ph.)'
);

-- line #12916
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DX-24 100 (Vilco)',
	'Doxycycline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DX-24 100 (Vilco)'
);

-- line #12917
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DXN 100 (Parasol)',
	'Doxycycline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DXN 100 (Parasol)'
);

-- line #12918
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'E-DOX 100 (EAST WEST)',
	'Doxycycline',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'E-DOX 100 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'E-DOX 200 (EAST WEST)',
	'Doxycycline',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'E-DOX 200 (EAST WEST)'
);

-- line #12919
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'E-DOX 100 (EAST WEST)',
	'Doxycycline',
	'DT TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'E-DOX 100 (EAST WEST)'
);

-- line #12920
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EFFIDOX 100 (Kim Lab)',
	'Doxycycline',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EFFIDOX 100 (Kim Lab)'
);

-- line #12921
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELDOX 100 (Elysium)',
	'Doxycycline',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELDOX 100 (Elysium)'
);

-- line #12922
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMDOX 100 (MADHAV BIO.)',
	'Doxycycline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMDOX 100 (MADHAV BIO.)'
);

-- line #12923
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMIDOX 100 (Calibar Ph.)',
	'Doxycycline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg(MONOHYDR.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMIDOX 100 (Calibar Ph.)'
);

-- line #12924
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEEOX 100 (Cadila Ph.)',
	'Doxycycline',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEEOX 100 (Cadila Ph.)'
);

-- line #12925
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GINADOX 100 (Pharmacia)',
	'Doxycycline',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GINADOX 100 (Pharmacia)'
);

-- line #12926
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IDOXY 100 (Ikon Rem)',
	'Doxycycline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IDOXY 100 (Ikon Rem)'
);

-- line #12927
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDOX 100 (Indian R.)',
	'Doxycycline',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDOX 100 (Indian R.)'
);

-- line #12928
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDOX 100 (Indu D.)',
	'Doxycycline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDOX 100 (Indu D.)'
);

-- line #12929
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEDOX 100 (CHEMO HC.)',
	'Doxycycline',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEDOX 100 (CHEMO HC.)'
);

-- line #12930
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100 (HYCLATE)', u'strength_2': u'', u'substance': u'Doxycycline', u'always_empty': u'', u'form': u'CAP', u'brand': u'LAA', u'strength_3': u'', u'company': u'Bombay T.', u'unit': u''}

-- line #12931
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAA 100 (Bombay T.)',
	'Doxycycline',
	'CAP/TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg(HYCLATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAA 100 (Bombay T.)'
);

-- line #12932
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANDOX 100 (Hygeia Ph.)',
	'Doxycycline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANDOX 100 (Hygeia Ph.)'
);

-- line #12933
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LENTECLIN 100 (Aristo)',
	'Doxycycline',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LENTECLIN 100 (Aristo)'
);

-- line #12934
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LTDOX 100 (Lancer)',
	'Doxycycline',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg(HYCLATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LTDOX 100 (Lancer)'
);

-- line #12935
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUPIDOX 100 (LUPIN)',
	'Doxycycline',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUPIDOX 100 (LUPIN)'
);

-- line #12936
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUPIN 100 (Aristo)',
	'Doxycycline',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUPIN 100 (Aristo)'
);

-- line #12937
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYDOX 100 (HETERO HC.)',
	'Doxycycline',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYDOX 100 (HETERO HC.)'
);

-- line #12938
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYTEDOX 100 (Lancer)',
	'Doxycycline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYTEDOX 100 (Lancer)'
);

-- line #12939
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAGLINE 100 (Magnus Bio.)',
	'Doxycycline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAGLINE 100 (Magnus Bio.)'
);

-- line #12940
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MARTIDOX-M 100 (Walter B.)',
	'Doxycycline',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MARTIDOX-M 100 (Walter B.)'
);

-- line #12941
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MARTIDOX-M 200 (Walter B.)',
	'Doxycycline',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MARTIDOX-M 200 (Walter B.)'
);

-- line #12942
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'M-DOX 100 (Intra Lab)',
	'Doxycycline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'M-DOX 100 (Intra Lab)'
);

-- line #12943
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDIDOX 100 (Medo Chem)',
	'Doxycycline',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDIDOX 100 (Medo Chem)'
);

-- line #12944
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDOXY 100 (Medico)',
	'Doxycycline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDOXY 100 (Medico)'
);

-- line #12945
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDOXY 100 (Mediline)',
	'Doxycycline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDOXY 100 (Mediline)'
);

-- line #12946
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGADOX 200 (Hitech Form.)',
	'Doxycycline',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGADOX 200 (Hitech Form.)'
);

-- line #12947
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICRODOX-DR 100 (Micro Labs)',
	'Doxycycline',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICRODOX-DR 100 (Micro Labs)'
);

-- line #12948
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICRODOX 100 (Micro Labs)',
	'Doxycycline',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICRODOX 100 (Micro Labs)'
);

-- line #12949
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICRODOX 100 (Micro Labs)',
	'Doxycycline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICRODOX 100 (Micro Labs)'
);

-- line #12950
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MINICYCLINE 100 (Shreya)',
	'Doxycycline',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MINICYCLINE 100 (Shreya)'
);

-- line #12951
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MINICYCLINE 25 (Shreya)',
	'Doxycycline',
	'D.SYR',
	gm.nullify_empty_string('25')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MINICYCLINE 25 (Shreya)'
);

-- line #12952
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MINICYCLINE 50 (Shreya)',
	'Doxycycline',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MINICYCLINE 50 (Shreya)'
);

-- line #12953
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MODAX 100 (Marc Lab)',
	'Doxycycline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MODAX 100 (Marc Lab)'
);

-- line #12954
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONODOX 100 (Uniroyal)',
	'Doxycycline',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONODOX 100 (Uniroyal)'
);

-- line #12955
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONODOX 100 (Lancer)',
	'Doxycycline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONODOX 100 (Lancer)'
);

-- line #12956
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAB 100 (Bennet Ph.)',
	'Doxycycline',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAB 100 (Bennet Ph.)'
);

-- line #12957
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEE 100 (Depone)',
	'Doxycycline',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg(MONOHYDR.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEE 100 (Depone)'
);

-- line #12958
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEE 100 (Depone)',
	'Doxycycline',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg(MONOHYDR.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEE 100 (Depone)'
);

-- line #12959
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOIN 100 (Nordic Ph.)',
	'Doxycycline',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOIN 100 (Nordic Ph.)'
);

-- line #12960
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVADOX 100 (Maneesh)',
	'Doxycycline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVADOX 100 (Maneesh)'
);

-- line #12961
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUDOXY 100 (Nulife)',
	'Doxycycline',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUDOXY 100 (Nulife)'
);

-- line #12962
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODCLIN 100 (Olcare)',
	'Doxycycline',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODCLIN 100 (Olcare)'
);

-- line #12963
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXYLIN 100 (AIMCO PH.)',
	'Doxycycline',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXYLIN 100 (AIMCO PH.)'
);

-- line #12964
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXYLIN 100 (AIMCO PH.)',
	'Doxycycline',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXYLIN 100 (AIMCO PH.)'
);

-- line #12965
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIODEX 100 (Pioneer Ph.)',
	'Doxycycline',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIODEX 100 (Pioneer Ph.)'
);

-- line #12966
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLIDOX 100 (Vostok)',
	'Doxycycline',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLIDOX 100 (Vostok)'
);

-- line #12967
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYDOX 100 (Pifer Ph.)',
	'Doxycycline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYDOX 100 (Pifer Ph.)'
);

-- line #12968
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAPIDOXYN 100 (Galpha)',
	'Doxycycline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAPIDOXYN 100 (Galpha)'
);

-- line #12969
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'R-DOX 100 (Ronak Lab.)',
	'Doxycycline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'R-DOX 100 (Ronak Lab.)'
);

-- line #12970
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'R-DOXY 100 (Reliance)',
	'Doxycycline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'R-DOXY 100 (Reliance)'
);

-- line #12971
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELIDOX 100 (Relish)',
	'Doxycycline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELIDOX 100 (Relish)'
);

-- line #12972
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REVIDOX 100 (Macleods)',
	'Doxycycline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REVIDOX 100 (Macleods)'
);

-- line #12973
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FRESHE 10 (Que Ph.)',
	'Doxylamine Succinate',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FRESHE 10 (Que Ph.)'
);

-- line #12974
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARTAMIN 150 (VHB)',
	'D-Penicillamine',
	'CAP (CARDION)',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARTAMIN 150 (VHB)'
);

-- line #12975
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARTAMIN 250 (VHB)',
	'D-Penicillamine',
	'CAP (CARDION)',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARTAMIN 250 (VHB)'
);

-- line #12976
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARTAMIN 150 (CH.Bhagat)',
	'D-Penicillamine',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARTAMIN 150 (CH.Bhagat)'
);

-- line #12977
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARTAMIN 250 (CH.Bhagat)',
	'D-Penicillamine',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARTAMIN 250 (CH.Bhagat)'
);

-- line #12978
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CILAMIN 250 (Panacea)',
	'D-Penicillamine',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CILAMIN 250 (Panacea)'
);

-- line #12979
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CILAMIN 250 (Panacea)',
	'D-Penicillamine',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CILAMIN 250 (Panacea)'
);

-- line #12980
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DISTAMIN 250 (Samarth)',
	'D-Penicillamine',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DISTAMIN 250 (Samarth)'
);

-- line #12981
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALUDROX 610 (Wyeth)',
	'Dried Alum.Hydrox.Gel',
	'GEL',
	gm.nullify_empty_string('610')::numeric,
	'mg/10ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALUDROX 610 (Wyeth)'
);

-- line #12982
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALUDROX 840 (Wyeth)',
	'Dried Alum.Hydrox.Gel',
	'TAB',
	gm.nullify_empty_string('840')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALUDROX 840 (Wyeth)'
);

-- line #12983
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIZICUM 200 (TAJ PH.)',
	'Dried Alum.Hydrox.Gel',
	'GEL',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIZICUM 200 (TAJ PH.)'
);

-- line #12984
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Dried Alum.Hydrox.Gel', u'always_empty': u'', u'form': u'SUS', u'brand': u'DIZICUM', u'strength_3': u'', u'company': u'TAJ PH.', u'unit': u''}

-- line #12985
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIZICUM 300 (TAJ PH.)',
	'Dried Alum.Hydrox.Gel',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIZICUM 300 (TAJ PH.)'
);

-- line #12986
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Dried Alum.Hydrox.Gel', u'always_empty': u'', u'form': u'GEL', u'brand': u'HEGEL MPS', u'strength_3': u'', u'company': u'Healthgaurd', u'unit': u''}

-- line #12987
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMNICID 300 (Cipla)',
	'Dried Alum.Hydrox.Gel',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMNICID 300 (Cipla)'
);

-- line #12988
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'DRIED FACTOR VIII FRACTION', u'always_empty': u'', u'form': u'VIAL', u'brand': u'HEMOREL-A', u'strength_3': u'', u'company': u'Reliance Life', u'unit': u''}

-- line #12989
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MULTAQ 400 (SANOFI SYN.)',
	'DRONEDARONE',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MULTAQ 400 (SANOFI SYN.)'
);

-- line #12990
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROPEROL 2.5 (Troikaa)',
	'Droperidol',
	'INJ',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROPEROL 2.5 (Troikaa)'
);

-- line #12991
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ABDROT 40 (Captab)',
	'Drotaverine Hcl.',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ABDROT 40 (Captab)'
);

-- line #12992
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ABDROT 80 (Captab)',
	'Drotaverine Hcl.',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ABDROT 80 (Captab)'
);

-- line #12993
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROTANIC 20 (Alkem)',
	'Drotaverine Hcl.(ABSOLUTE ALCHOHOL IP 80% W/V)',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROTANIC 20 (Alkem)'
);

-- line #12994
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADRO 80 (ROSE LABS)',
	'Drotaverine Hcl.',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADRO 80 (ROSE LABS)'
);

-- line #12995
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVACAN 20 (ARGON)',
	'Drotaverine Hcl.',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg/1ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVACAN 20 (ARGON)'
);

-- line #12996
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVACAN 80 (Khandelwal)',
	'Drotaverine Hcl.',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVACAN 80 (Khandelwal)'
);

-- line #12997
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BARALGAN-D 40 (Aventis)',
	'Drotaverine Hcl.',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BARALGAN-D 40 (Aventis)'
);

-- line #12998
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BARALGAN-D 40 (Aventis)',
	'Drotaverine Hcl.',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BARALGAN-D 40 (Aventis)'
);

-- line #12999
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BARALGAN-D 80 (Aventis)',
	'Drotaverine Hcl.',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BARALGAN-D 80 (Aventis)'
);

-- line #13000
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYCLOFOS 40 (Indoco Rem.)',
	'Drotaverine Hcl.',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYCLOFOS 40 (Indoco Rem.)'
);

-- line #13001
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYPDROT 40 (Cyper Ph.)',
	'Drotaverine Hcl.',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYPDROT 40 (Cyper Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYPDROT 80 (Cyper Ph.)',
	'Drotaverine Hcl.',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYPDROT 80 (Cyper Ph.)'
);

-- line #13002
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DETRIM 20 (Dwd)',
	'Drotaverine Hcl.',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DETRIM 20 (Dwd)'
);

-- line #13003
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DORTSIL 40 (PSYCOREM)',
	'Drotaverine Hcl.',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DORTSIL 40 (PSYCOREM)'
);

-- line #13004
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DORTSIL 80 (PSYCOREM)',
	'Drotaverine Hcl.',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DORTSIL 80 (PSYCOREM)'
);

-- line #13005
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DORVET 40 (Taurus Lab)',
	'Drotaverine Hcl.',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DORVET 40 (Taurus Lab)'
);

-- line #13006
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOTACID 80 (Biomax Lab)',
	'Drotaverine Hcl.',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOTACID 80 (Biomax Lab)'
);

-- line #13007
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOTACID 80 (Biomax Lab)',
	'Drotaverine Hcl.',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOTACID 80 (Biomax Lab)'
);

-- line #13008
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOTARIN 40 (Elder)',
	'Drotaverine Hcl.',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOTARIN 40 (Elder)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOTARIN 80 (Elder)',
	'Drotaverine Hcl.',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOTARIN 80 (Elder)'
);

-- line #13009
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOTRA 20 (Emcure)',
	'Drotaverine Hcl.',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOTRA 20 (Emcure)'
);

-- line #13010
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Drotaverine Hcl.', u'always_empty': u'', u'form': u'AMP', u'brand': u'DOVERIN', u'strength_3': u'', u'company': u'Intas', u'unit': u''}

-- line #13011
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOVERIN 40 (Intas)',
	'Drotaverine Hcl.',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg/80'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOVERIN 40 (Intas)'
);

-- line #13012
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOZEE 40 (Zee Lab)',
	'Drotaverine Hcl.',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOZEE 40 (Zee Lab)'
);

-- line #13013
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOZEE 40 (Zee Lab)',
	'Drotaverine Hcl.',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOZEE 40 (Zee Lab)'
);

-- line #13014
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROMAC 40 (TRUMAC)',
	'Drotaverine Hcl.',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROMAC 40 (TRUMAC)'
);

-- line #13015
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROMIS 80 (TASMED)',
	'Drotaverine Hcl.',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROMIS 80 (TASMED)'
);

-- line #13016
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROMITIN 40 (AXYZEN LIFE)',
	'Drotaverine Hcl.',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROMITIN 40 (AXYZEN LIFE)'
);

-- line #13017
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROPAIN 80 (ETHIX HC.)',
	'Drotaverine Hcl.',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROPAIN 80 (ETHIX HC.)'
);

-- line #13018
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROTASPA 40 (Shreya)',
	'Drotaverine Hcl.',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROTASPA 40 (Shreya)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROTASPA 80 (Shreya)',
	'Drotaverine Hcl.',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROTASPA 80 (Shreya)'
);

-- line #13019
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROT 80 (Mapra)',
	'Drotaverine Hcl.',
	'DS TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROT 80 (Mapra)'
);

-- line #13020
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROTIKIND 80 (LIFESTAR)',
	'Drotaverine Hcl.',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROTIKIND 80 (LIFESTAR)'
);

-- line #13021
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROTIN 80 (Walter B.)',
	'Drotaverine Hcl.',
	'DS INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROTIN 80 (Walter B.)'
);

-- line #13022
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROTIN 80 (Walter B.)',
	'Drotaverine Hcl.',
	'DS TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROTIN 80 (Walter B.)'
);

-- line #13023
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROTIN 40 (Walter B.)',
	'Drotaverine Hcl.',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROTIN 40 (Walter B.)'
);

-- line #13024
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROT 40 (Mapra)',
	'Drotaverine Hcl.',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROT 40 (Mapra)'
);

-- line #13025
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROTIN 40 (Walter B.)',
	'Drotaverine Hcl.',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROTIN 40 (Walter B.)'
);

-- line #13026
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROTRIX 80 (Cadex Lab)',
	'Drotaverine Hcl.',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROTRIX 80 (Cadex Lab)'
);

-- line #13027
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROT 40 (Mapra)',
	'Drotaverine Hcl.',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROT 40 (Mapra)'
);

-- line #13028
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROTY 20 (Overseas Hc.)',
	'Drotaverine Hcl.',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROTY 20 (Overseas Hc.)'
);

-- line #13029
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROTY 40 (OVERSEAS MED.)',
	'Drotaverine Hcl.',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROTY 40 (OVERSEAS MED.)'
);

-- line #13030
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROTY 80 (OVERSEAS MED.)',
	'Drotaverine Hcl.',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROTY 80 (OVERSEAS MED.)'
);

-- line #13031
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROVERA 40 (Svizera)',
	'Drotaverine Hcl.',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROVERA 40 (Svizera)'
);

-- line #13032
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROVERA 40 (SVIZERA HC.)',
	'Drotaverine Hcl.',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROVERA 40 (SVIZERA HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROVERA 80 (SVIZERA HC.)',
	'Drotaverine Hcl.',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROVERA 80 (SVIZERA HC.)'
);

-- line #13033
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROVET 20 (Taurus Lab)',
	'Drotaverine Hcl.',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROVET 20 (Taurus Lab)'
);

-- line #13034
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROVET 40 (Taurus Lab)',
	'Drotaverine Hcl.',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROVET 40 (Taurus Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROVET 80 (Taurus Lab)',
	'Drotaverine Hcl.',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROVET 80 (Taurus Lab)'
);

-- line #13035
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROV 20 (Uni-Sank.)',
	'Drotaverine Hcl.',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROV 20 (Uni-Sank.)'
);

-- line #13036
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROVIT 40 (Prohealth)',
	'Drotaverine Hcl.',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROVIT 40 (Prohealth)'
);

-- line #13037
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DURASPAS 40 (Ultramark)',
	'Drotaverine Hcl.',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg/2ML(8.0'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DURASPAS 40 (Ultramark)'
);

-- line #13038
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DURASPAS 80 (Ultramark)',
	'Drotaverine Hcl.',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DURASPAS 80 (Ultramark)'
);

-- line #13039
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUTORA 40 (ORION BIOTECH.)',
	'Drotaverine Hcl.',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUTORA 40 (ORION BIOTECH.)'
);

-- line #13040
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DVN 40 (Overseas Hc.)',
	'Drotaverine Hcl.',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DVN 40 (Overseas Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DVN 80 (Overseas Hc.)',
	'Drotaverine Hcl.',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DVN 80 (Overseas Hc.)'
);

-- line #13041
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELDROT 80 (Captab)',
	'Drotaverine Hcl.',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELDROT 80 (Captab)'
);

-- line #13042
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPIVERIN 40 (Ttk Hc.)',
	'Drotaverine Hcl.',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPIVERIN 40 (Ttk Hc.)'
);

-- line #13043
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INORINE 40 (Ind-Swift)',
	'Drotaverine Hcl.',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INORINE 40 (Ind-Swift)'
);

-- line #13044
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INORINE 40 (IND-SWIFT)',
	'DROTAVERINE HCL.',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INORINE 40 (IND-SWIFT)'
);

-- line #13045
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INORINE 80 (Ind-Swift)',
	'Drotaverine Hcl.',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INORINE 80 (Ind-Swift)'
);

-- line #13046
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MS SPA 80 (Astrum Hc.)',
	'Drotaverine Hcl.',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MS SPA 80 (Astrum Hc.)'
);

-- line #13047
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'DRUG FREE ANTI INFLAMMATORY DEVICE', u'always_empty': u'', u'form': u'', u'brand': u'ACCTI-PATCH (BACK PAIN)', u'strength_3': u'', u'company': u'Piramal Hc.', u'unit': u''}

-- line #13048
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'DRUG FREE ANTI INFLAMMATORY DEVICE', u'always_empty': u'', u'form': u'', u'brand': u'ACCTI-PATCH (FOOT PAIN)', u'strength_3': u'', u'company': u'Piramal Hc.', u'unit': u''}

-- line #13049
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'DRUG FREE ANTI INFLAMMATORY DEVICE', u'always_empty': u'', u'form': u'', u'brand': u'ACCTI-PATCH (KNEE PAIN)', u'strength_3': u'', u'company': u'Piramal Hc.', u'unit': u''}

-- line #13050
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'DRUG FREE ANTI INFLAMMATORY DEVICE', u'always_empty': u'', u'form': u'', u'brand': u'ACCTI-PATCH (WRIST PAIN)', u'strength_3': u'', u'company': u'Piramal Hc.', u'unit': u''}

-- line #13051
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'2-DEP 40 (Mano)',
	'DULOXETINE',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '2-DEP 40 (Mano)'
);

-- line #13052
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'2-DEP 20 (Mano Ph.)',
	'DULOXETINE',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '2-DEP 20 (Mano Ph.)'
);

-- line #13053
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'2-DEP 30 (Mano Ph.)',
	'DULOXETINE',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '2-DEP 30 (Mano Ph.)'
);

-- line #13054
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CENDU 20 (CENTRA(USV))',
	'DULOXETINE',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CENDU 20 (CENTRA(USV))'
);

-- line #13055
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CENDU 30 (CENTRA(USV))',
	'DULOXETINE',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CENDU 30 (CENTRA(USV))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CENDU 40 (CENTRA(USV))',
	'DULOXETINE',
	'CAP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CENDU 40 (CENTRA(USV))'
);

-- line #13056
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CENDU 60 (CENTRA(USV))',
	'DULOXETINE',
	'CAP',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CENDU 60 (CENTRA(USV))'
);

-- line #13057
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DELL 20 (OREVA DARMO.)',
	'DULOXETINE',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DELL 20 (OREVA DARMO.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DELL 30 (OREVA DARMO.)',
	'DULOXETINE',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DELL 30 (OREVA DARMO.)'
);

-- line #13058
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DELOK 20 (Nicholas)',
	'DULOXETINE',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DELOK 20 (Nicholas)'
);

-- line #13059
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DELOK 30 (Nicholas)',
	'DULOXETINE',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DELOK 30 (Nicholas)'
);

-- line #13060
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DELOK 60 (Nicholas)',
	'DULOXETINE',
	'CAP',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DELOK 60 (Nicholas)'
);

-- line #13061
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DELOK 40 (Piramal Hc.)',
	'DULOXETINE',
	'CAP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DELOK 40 (Piramal Hc.)'
);

-- line #13062
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DENEURONE 20 (Otsira)',
	'DULOXETINE',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DENEURONE 20 (Otsira)'
);

-- line #13063
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DENEURONE 30 (Otsira)',
	'DULOXETINE',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DENEURONE 30 (Otsira)'
);

-- line #13064
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DENEURONE 60 (Otsira)',
	'DULOXETINE',
	'CAP',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DENEURONE 60 (Otsira)'
);

-- line #13065
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUELVE 20 (Zydus Bio.)',
	'DULOXETINE',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUELVE 20 (Zydus Bio.)'
);

-- line #13066
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUELVE 40 (Zydus Bio.)',
	'DULOXETINE',
	'CAP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUELVE 40 (Zydus Bio.)'
);

-- line #13067
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DULANE 20 (Sun)',
	'DULOXETINE',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DULANE 20 (Sun)'
);

-- line #13068
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DULANE 30 (Sun)',
	'DULOXETINE',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DULANE 30 (Sun)'
);

-- line #13069
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DULANE 40 (Sun)',
	'DULOXETINE',
	'CAP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DULANE 40 (Sun)'
);

-- line #13070
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DULANE 60 (Sun)',
	'DULOXETINE',
	'CAP',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DULANE 60 (Sun)'
);

-- line #13071
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DULETIN-40 40 (Ranbaxy)',
	'DULOXETINE',
	'CAP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DULETIN-40 40 (Ranbaxy)'
);

-- line #13072
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DULETIN 20 (Ranbaxy)',
	'DULOXETINE',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg(DR)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DULETIN 20 (Ranbaxy)'
);

-- line #13073
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DULIFE 20 (F D C)',
	'DULOXETINE',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DULIFE 20 (F D C)'
);

-- line #13074
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DULIFE 30 (F D C)',
	'DULOXETINE',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DULIFE 30 (F D C)'
);

-- line #13075
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DULOJOY 20 (Torrent)',
	'DULOXETINE',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DULOJOY 20 (Torrent)'
);

-- line #13076
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DULOJOY 30 (Torrent)',
	'DULOXETINE',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DULOJOY 30 (Torrent)'
);

-- line #13077
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'DULOXETINE', u'always_empty': u'', u'form': u'', u'brand': u'DULOMED-20', u'strength_3': u'', u'company': u'MEDIFORECE', u'unit': u'mg'}

-- line #13078
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DULOMED 20 (MEDIEZ)',
	'DULOXETINE',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DULOMED 20 (MEDIEZ)'
);

-- line #13079
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DULOT 20 (Lupin)',
	'DULOXETINE',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DULOT 20 (Lupin)'
);

-- line #13080
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DULOT 30 (Lupin)',
	'DULOXETINE',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DULOT 30 (Lupin)'
);

-- line #13081
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DULOT 40 (Lupin)',
	'DULOXETINE',
	'CAP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DULOT 40 (Lupin)'
);

-- line #13082
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DULOTRAC 20 (MINOVA(PSYCHONOVA))',
	'DULOXETINE',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DULOTRAC 20 (MINOVA(PSYCHONOVA))'
);

-- line #13083
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DULX 20 (Aarpik Ph.)',
	'DULOXETINE',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DULX 20 (Aarpik Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DULX 30 (Aarpik Ph.)',
	'DULOXETINE',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DULX 30 (Aarpik Ph.)'
);

-- line #13084
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DULX 40 (Aarpik Ph.)',
	'DULOXETINE',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DULX 40 (Aarpik Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DULX 60 (Aarpik Ph.)',
	'DULOXETINE',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DULX 60 (Aarpik Ph.)'
);

-- line #13085
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUMORE 20 (Lupin)',
	'DULOXETINE',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUMORE 20 (Lupin)'
);

-- line #13086
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUMORE 30 (Lupin)',
	'DULOXETINE',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUMORE 30 (Lupin)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUMORE 60 (Lupin)',
	'DULOXETINE',
	'CAP',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUMORE 60 (Lupin)'
);

-- line #13087
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUPACT 20 (Wockhardt)',
	'DULOXETINE',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUPACT 20 (Wockhardt)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUPACT 30 (Wockhardt)',
	'DULOXETINE',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUPACT 30 (Wockhardt)'
);

-- line #13088
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUPACT 60 (Wockhardt)',
	'DULOXETINE',
	'CAP',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUPACT 60 (Wockhardt)'
);

-- line #13089
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DURAPAIN 30 (ANNANT(NPIL))',
	'DULOXETINE',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DURAPAIN 30 (ANNANT(NPIL))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DURAPAIN 60 (ANNANT(NPIL))',
	'DULOXETINE',
	'CAP',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DURAPAIN 60 (ANNANT(NPIL))'
);

-- line #13090
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DURAPAIN 20 (Nicholas)',
	'DULOXETINE',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DURAPAIN 20 (Nicholas)'
);

-- line #13091
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUREEP 20 (Pentacare)',
	'DULOXETINE',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUREEP 20 (Pentacare)'
);

-- line #13092
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUREEP 30 (Pentacare)',
	'DULOXETINE',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUREEP 30 (Pentacare)'
);

-- line #13093
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUTIN 20 (Solus)',
	'DULOXETINE',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUTIN 20 (Solus)'
);

-- line #13094
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUTIN 30 (Solus)',
	'DULOXETINE',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUTIN 30 (Solus)'
);

-- line #13095
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUTIN 60 (Solus)',
	'DULOXETINE',
	'CAP',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUTIN 60 (Solus)'
);

-- line #13096
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUVANTA 60 (ALTIMA (INTAS))',
	'DULOXETINE',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUVANTA 60 (ALTIMA (INTAS))'
);

-- line #13097
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUXEL 20 (Tripada Hc.)',
	'DULOXETINE',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUXEL 20 (Tripada Hc.)'
);

-- line #13098
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUXEL 30 (Tripada Hc.)',
	'DULOXETINE',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUXEL 30 (Tripada Hc.)'
);

-- line #13099
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUXET 20 (Unichem)',
	'DULOXETINE',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUXET 20 (Unichem)'
);

-- line #13100
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUXET 30 (Unichem)',
	'DULOXETINE',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUXET 30 (Unichem)'
);

-- line #13101
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUXET 40 (UNICHEM)',
	'DULOXETINE',
	'CAP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUXET 40 (UNICHEM)'
);

-- line #13102
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUXET-M 20 (Neu-Foreva)',
	'DULOXETINE',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUXET-M 20 (Neu-Foreva)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUXET-M 30 (Neu-Foreva)',
	'DULOXETINE',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUXET-M 30 (Neu-Foreva)'
);

-- line #13103
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUZELA 20 (Sun)',
	'DULOXETINE',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUZELA 20 (Sun)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUZELA 30 (Sun)',
	'DULOXETINE',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUZELA 30 (Sun)'
);

-- line #13104
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUZELA 40 (Sun)',
	'DULOXETINE',
	'CAP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUZELA 40 (Sun)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUZELA 60 (Sun)',
	'DULOXETINE',
	'CAP',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUZELA 60 (Sun)'
);

-- line #13105
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'DULOXETINE', u'always_empty': u'', u'form': u'', u'brand': u'NAXDU', u'strength_3': u'', u'company': u'ANAX LS.', u'unit': u'mg'}

-- line #13106
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUDEP 20 (Mankind MAGNET)',
	'DULOXETINE',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUDEP 20 (Mankind MAGNET)'
);

-- line #13107
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUDEP 30 (Mankind MAGNET)',
	'DULOXETINE',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUDEP 30 (Mankind MAGNET)'
);

-- line #13108
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUDEP 40 (Mankind MAGNET)',
	'DULOXETINE',
	'CAP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUDEP 40 (Mankind MAGNET)'
);

-- line #13109
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUROSTAR 30 (LIFESTAR)',
	'DULOXETINE',
	'DX CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUROSTAR 30 (LIFESTAR)'
);

-- line #13110
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUCEPT 0.5 (Lupin)',
	'DUTASTERIDE',
	'CAP',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUCEPT 0.5 (Lupin)'
);

-- line #13111
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUPECIA 0.5 (Cipla)',
	'DUTASTERIDE',
	'CAP',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUPECIA 0.5 (Cipla)'
);

-- line #13112
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUPROST 0.5 (Cipla)',
	'DUTASTERIDE',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUPROST 0.5 (Cipla)'
);

-- line #13113
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DURIZE 0.5 (Sun)',
	'DUTASTERIDE',
	'CAP',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DURIZE 0.5 (Sun)'
);

-- line #13114
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUTAID 0.5 (Zydus Bio.)',
	'DUTASTERIDE',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUTAID 0.5 (Zydus Bio.)'
);

-- line #13115
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUTAS 0.5 (Dr.Reddy''S)',
	'DUTASTERIDE',
	'CAP',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUTAS 0.5 (Dr.Reddy''S)'
);

-- line #13116
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FINABALD 1 (EAST WEST)',
	'DUTASTERIDE',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FINABALD 1 (EAST WEST)'
);

-- line #13117
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FINABALD 2.5 (EAST WEST)',
	'DUTASTERIDE',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FINABALD 2.5 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FINABALD 5 (EAST WEST)',
	'DUTASTERIDE',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FINABALD 5 (EAST WEST)'
);

-- line #13118
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'D-JOY 10 (Alembic)',
	'Dydrogesterone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'D-JOY 10 (Alembic)'
);

-- line #13119
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUPHASTON 10 (Solvay Ph.)',
	'Dydrogesterone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUPHASTON 10 (Solvay Ph.)'
);

-- line #13120
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENTASURE 10 (Mankind)',
	'Dydrogesterone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENTASURE 10 (Mankind)'
);

-- line #13121
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JIGEST 10 (Uni-Sank.)',
	'Dydrogesterone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JIGEST 10 (Uni-Sank.)'
);

-- line #13122
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EBASIL 10 (Solvay Ph.)',
	'Ebastine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EBASIL 10 (Solvay Ph.)'
);

-- line #13123
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EBASIL 20 (Solvay Ph.)',
	'Ebastine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EBASIL 20 (Solvay Ph.)'
);

-- line #13124
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EBAST 10 (Micro Labs)',
	'Ebastine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EBAST 10 (Micro Labs)'
);

-- line #13125
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EBAST 20 (Micro Labs)',
	'Ebastine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EBAST 20 (Micro Labs)'
);

-- line #13126
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EBAST 5 (Micro Labs)',
	'Ebastine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EBAST 5 (Micro Labs)'
);

-- line #13127
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EBAY 10 (Bal Ph.)',
	'Ebastine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EBAY 10 (Bal Ph.)'
);

-- line #13128
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EROSTIN 10 (Eros Ph.)',
	'EBASTINE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EROSTIN 10 (Eros Ph.)'
);

-- line #13129
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EROSTIN 20 (Eros Ph.)',
	'EBASTINE',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EROSTIN 20 (Eros Ph.)'
);

-- line #13130
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EBERNET 10 (Dr.Reddy''S)',
	'EBERCONAZOLE NITRATE',
	'CRM',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EBERNET 10 (Dr.Reddy''S)'
);

-- line #13131
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ECANOL VAGINAL 150 (Nicholas)',
	'Econazole Nit.',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ECANOL VAGINAL 150 (Nicholas)'
);

-- line #13132
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ECODERM 1 (Brown & B.)',
	'Econazole Nit.',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ECODERM 1 (Brown & B.)'
);

-- line #13133
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARAVON 1.5 (SUN)',
	'EDARAVONE',
	'AMP',
	gm.nullify_empty_string('1.5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARAVON 1.5 (SUN)'
);

-- line #13134
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAREVON 1.5 (Ranbaxy)',
	'EDARAVONE',
	'INJ',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAREVON 1.5 (Ranbaxy)'
);

-- line #13135
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EDAKEM 1.5 (Alkem)',
	'EDARAVONE',
	'INJ',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EDAKEM 1.5 (Alkem)'
);

-- line #13136
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EDARABID 1.5 (Intas)',
	'EDARAVONE',
	'INJ',
	gm.nullify_empty_string('1.5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EDARABID 1.5 (Intas)'
);

-- line #13137
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EDASTAR 1.5 (Lupin)',
	'EDARAVONE',
	'INJ',
	gm.nullify_empty_string('1.5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EDASTAR 1.5 (Lupin)'
);

-- line #13138
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EDAVON 1.5 (Torrent)',
	'EDARAVONE',
	'INJ',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EDAVON 1.5 (Torrent)'
);

-- line #13139
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EDINOVA 1.5 (Ipca)',
	'EDARAVONE',
	'INJ',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EDINOVA 1.5 (Ipca)'
);

-- line #13140
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EDVO 2.5 (Unichem)',
	'EDARAVONE',
	'INJ',
	gm.nullify_empty_string('2.5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EDVO 2.5 (Unichem)'
);

-- line #13141
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EZYCUT 1.5 (Zydus N.S.)',
	'EDARAVONE',
	'INJ',
	gm.nullify_empty_string('1.5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EZYCUT 1.5 (Zydus N.S.)'
);

-- line #13142
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NURAVON 1.5 (Piramal Hc.)',
	'EDARAVONE',
	'INJ',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NURAVON 1.5 (Piramal Hc.)'
);

-- line #13143
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EFAVIR 200 (Cipla)',
	'Efavirenz',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EFAVIR 200 (Cipla)'
);

-- line #13144
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EFAVIR 600 (Cipla)',
	'Efavirenz',
	'CAP',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EFAVIR 600 (Cipla)'
);

-- line #13145
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EF 200 (Mcneil & ARGUS)',
	'Efavirenz',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EF 200 (Mcneil & ARGUS)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EF 600 (Mcneil & ARGUS)',
	'Efavirenz',
	'CAP',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EF 600 (Mcneil & ARGUS)'
);

-- line #13146
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EFCURE ORAL 30 (Emcure)',
	'Efavirenz',
	'SOL',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EFCURE ORAL 30 (Emcure)'
);

-- line #13147
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EFCURE 200 (Emcure)',
	'Efavirenz',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EFCURE 200 (Emcure)'
);

-- line #13148
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EFFAHOPE 600 (Macleods)',
	'Efavirenz',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EFFAHOPE 600 (Macleods)'
);

-- line #13149
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EFFERVEN 200 (Ranbaxy)',
	'Efavirenz',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EFFERVEN 200 (Ranbaxy)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EFFERVEN 600 (Ranbaxy)',
	'Efavirenz',
	'CAP',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EFFERVEN 600 (Ranbaxy)'
);

-- line #13150
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESTIVA 200 (HETERO HC.)',
	'Efavirenz',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESTIVA 200 (HETERO HC.)'
);

-- line #13151
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESTIVA 600 (HETERO HC.)',
	'Efavirenz',
	'CAP',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESTIVA 600 (HETERO HC.)'
);

-- line #13152
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESTIVA 600 (HETERO HC.)',
	'Efavirenz',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESTIVA 600 (HETERO HC.)'
);

-- line #13153
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EVIRENZ 200 (Cytomed(Alkem))',
	'Efavirenz',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EVIRENZ 200 (Cytomed(Alkem))'
);

-- line #13154
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EVIRENZ 600 (Cytomed(Alkem))',
	'Efavirenz',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EVIRENZ 600 (Cytomed(Alkem))'
);

-- line #13155
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RETROCARE 600 (CHEMO HC.)',
	'Efavirenz',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RETROCARE 600 (CHEMO HC.)'
);

-- line #13156
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REVENZ 600 (Sain Med.)',
	'Efavirenz',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REVENZ 600 (Sain Med.)'
);

-- line #13157
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELYN 13.9 (Ajanta Ph.)',
	'EFFLORNITHINE HCL.',
	'TUBE',
	gm.nullify_empty_string('13.9')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELYN 13.9 (Ajanta Ph.)'
);

-- line #13158
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'13,9', u'strength_2': u'', u'substance': u'EFLORNTHIN', u'always_empty': u'', u'form': u'', u'brand': u'EFINTHIN', u'strength_3': u'', u'company': u'Liva Hc.', u'unit': u'%'}

-- line #13159
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APCAL 150 (Ajanta Ph.)',
	'Elemental Calcium',
	'SYR',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APCAL 150 (Ajanta Ph.)'
);

-- line #13160
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BONANSA 200 (WANBURY)',
	'Elemental Calcium',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BONANSA 200 (WANBURY)'
);

-- line #13161
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BUILD CAL 1120 (Cadila)',
	'Elemental Calcium',
	'TAB',
	gm.nullify_empty_string('1120')::numeric,
	'mg(CALCIUM ASPARTATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BUILD CAL 1120 (Cadila)'
);

-- line #13162
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALISTER 500 (TRIDENT PH.)',
	'Elemental Calcium',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALISTER 500 (TRIDENT PH.)'
);

-- line #13163
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALKARIAA 150 (Alkem)',
	'Elemental Calcium',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALKARIAA 150 (Alkem)'
);

-- line #13164
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALKARIAA 300 (Alkem)',
	'Elemental Calcium',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALKARIAA 300 (Alkem)'
);

-- line #13165
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EZORB 146 (Overseas)',
	'Elemental Calcium',
	'DS TAB',
	gm.nullify_empty_string('146')::numeric,
	'mg(CALCIUM ASPARTATE ANHYD.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EZORB 146 (Overseas)'
);

-- line #13166
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EZORB 73 (Overseas)',
	'Elemental Calcium',
	'TAB',
	gm.nullify_empty_string('73')::numeric,
	'mg(CALCIUM ASPARTATE ANHYD.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EZORB 73 (Overseas)'
);

-- line #13167
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FACTOCAL 500 (Wanbury)',
	'Elemental Calcium',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FACTOCAL 500 (Wanbury)'
);

-- line #13168
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACZORB 146 (Macleods)',
	'Elemental Calcium',
	'F.',
	gm.nullify_empty_string('146')::numeric,
	'mg(CAL. ASPARTATE 1120'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACZORB 146 (Macleods)'
);

-- line #13169
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACZORB 75 (Macleods)',
	'Elemental Calcium',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg(CAL. ASPARTATE 560'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACZORB 75 (Macleods)'
);

-- line #13170
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200', u'strength_2': u'', u'substance': u'Elemental Calcium', u'always_empty': u'', u'form': u'', u'brand': u'NIKOTRIOL', u'strength_3': u'', u'company': u'ERIS LIFE', u'unit': u'mg(CAL.CIT.)'}

-- line #13171
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EFECIENT 62.5 (Panacea)',
	'Elemental Iron',
	'AMP',
	gm.nullify_empty_string('62.5')::numeric,
	'mg/5ML(SOD.FERRIC GLUCONATE COMP.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EFECIENT 62.5 (Panacea)'
);

-- line #13172
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENCICARB 50 (EMCURE)',
	'Elemental Iron',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg(FERRIC CARBOXY MALTOSE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENCICARB 50 (EMCURE)'
);

-- line #13173
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENCICARB 50 (EMCURE)',
	'Elemental Iron',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg(FERRIC CARBOXY MALTOSE);ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENCICARB 50 (EMCURE)'
);

-- line #13174
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERANTA 12.5 (AXERA)',
	'Elemental Iron',
	'INJ',
	gm.nullify_empty_string('12.5')::numeric,
	'mg(SOD.FERRIC GLUCONATE COMPL. IN SUCROSE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERANTA 12.5 (AXERA)'
);

-- line #13175
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERIKIND-S 100 (LIFESTAR)',
	'Elemental Iron',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERIKIND-S 100 (LIFESTAR)'
);

-- line #13176
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'AS IRON', u'strength_2': u'', u'substance': u'Elemental Iron', u'always_empty': u'', u'form': u'AMP', u'brand': u'FERISE', u'strength_3': u'', u'company': u'Intas', u'unit': u''}

-- line #13177
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERRY 50 (MODHIKE)',
	'Elemental Iron',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERRY 50 (MODHIKE)'
);

-- line #13178
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEMFER 100 (Alkem)',
	'Elemental Iron',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEMFER 100 (Alkem)'
);

-- line #13179
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RICHAR 100 (Alembic)',
	'Elemental Iron',
	'XT INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg(DILUTE IN 9.0'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RICHAR 100 (Alembic)'
);

-- line #13180
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REVOLADE 25 (GSK)',
	'ELTROMBOPAG',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg(ELTROMBOPAG FREE ACID)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REVOLADE 25 (GSK)'
);

-- line #13181
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REVOLADE 50 (GSK)',
	'ELTROMBOPAG',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg(ELTROMBOPAG FREE ACID)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REVOLADE 50 (GSK)'
);

-- line #13182
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEBRYL 25 (Gsk)',
	'Embramine Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEBRYL 25 (Gsk)'
);

-- line #13183
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACEPRIL 2.5 (Saga Lab)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACEPRIL 2.5 (Saga Lab)'
);

-- line #13184
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACEPRIL 5 (Saga Lab)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACEPRIL 5 (Saga Lab)'
);

-- line #13185
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANZE 5 (Zee Lab)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANZE 5 (Zee Lab)'
);

-- line #13186
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BQL 10 (Zydus Cadila)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BQL 10 (Zydus Cadila)'
);

-- line #13187
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BQL 2.5 (Zydus Cadila)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BQL 2.5 (Zydus Cadila)'
);

-- line #13188
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BQL 5 (Zydus Cadila)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BQL 5 (Zydus Cadila)'
);

-- line #13189
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANAPRIL 2.5 (Zydus Cadila)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANAPRIL 2.5 (Zydus Cadila)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANAPRIL 5 (Zydus Cadila)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANAPRIL 5 (Zydus Cadila)'
);

-- line #13190
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANVAS 2.5 (Zydus Cadila)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANVAS 2.5 (Zydus Cadila)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANVAS 5 (Zydus Cadila)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANVAS 5 (Zydus Cadila)'
);

-- line #13191
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDITAB 10 (Walter B.)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDITAB 10 (Walter B.)'
);

-- line #13192
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDITAB 2.5 (Walter B.)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDITAB 2.5 (Walter B.)'
);

-- line #13193
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDITAB 5 (Walter B.)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDITAB 5 (Walter B.)'
);

-- line #13194
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONVERTEN 10 (Khandelwal)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONVERTEN 10 (Khandelwal)'
);

-- line #13195
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONVERTEN 2.5 (Khandelwal)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONVERTEN 2.5 (Khandelwal)'
);

-- line #13196
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONVERTEN 5 (Khandelwal)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONVERTEN 5 (Khandelwal)'
);

-- line #13197
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILPRIL 5 (Ind-Swift)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILPRIL 5 (Ind-Swift)'
);

-- line #13198
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILVAS 10 (Cipla)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILVAS 10 (Cipla)'
);

-- line #13199
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILVAS 2.5 (Cipla)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILVAS 2.5 (Cipla)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILVAS 5 (Cipla)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILVAS 5 (Cipla)'
);

-- line #13200
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EL 10 (Sunij)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EL 10 (Sunij)'
);

-- line #13201
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EL 2.5 (Sunij)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'5'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EL 2.5 (Sunij)'
);

-- line #13202
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EL 2.5 (Sunij)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EL 2.5 (Sunij)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EL 5 (Sunij)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EL 5 (Sunij)'
);

-- line #13203
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENACE 10 (Piramal Hc.)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENACE 10 (Piramal Hc.)'
);

-- line #13204
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENACE 2.5 (Piramal Hc.)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENACE 2.5 (Piramal Hc.)'
);

-- line #13205
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENACE 5 (Piramal Hc.)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENACE 5 (Piramal Hc.)'
);

-- line #13206
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENALAP 10 (Mapra)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENALAP 10 (Mapra)'
);

-- line #13207
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENALAP 2.5 (Mapra)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENALAP 2.5 (Mapra)'
);

-- line #13208
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENALAP 5 (Mapra)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENALAP 5 (Mapra)'
);

-- line #13209
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENALCYP-5 5 (Cyper Ph.)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENALCYP-5 5 (Cyper Ph.)'
);

-- line #13210
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENAL 10 (EAST WEST)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENAL 10 (EAST WEST)'
);

-- line #13211
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENAL 2.5 (EAST WEST)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENAL 2.5 (EAST WEST)'
);

-- line #13212
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENAL 5 (EAST WEST)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENAL 5 (EAST WEST)'
);

-- line #13213
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENAMATE 2.5 (Glenmark)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENAMATE 2.5 (Glenmark)'
);

-- line #13214
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENAMATE 5 (Glenmark)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENAMATE 5 (Glenmark)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENAMATE 10 (Glenmark)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENAMATE 10 (Glenmark)'
);

-- line #13215
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENAM 10 (Dr.Reddy''S)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENAM 10 (Dr.Reddy''S)'
);

-- line #13216
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENAM 2.5 (Dr.Reddy''S)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENAM 2.5 (Dr.Reddy''S)'
);

-- line #13217
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENAM 5 (Dr.Reddy''S)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENAM 5 (Dr.Reddy''S)'
);

-- line #13218
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENAPRIL 10 (Intas)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENAPRIL 10 (Intas)'
);

-- line #13219
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENAPRIL 20 (Intas)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENAPRIL 20 (Intas)'
);

-- line #13220
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENAPRIL 2.5 (Intas)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENAPRIL 2.5 (Intas)'
);

-- line #13221
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENAPRIL 5 (Intas)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENAPRIL 5 (Intas)'
);

-- line #13222
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENAP 10 (Camlin)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENAP 10 (Camlin)'
);

-- line #13223
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENAP 2.5 (Camlin)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENAP 2.5 (Camlin)'
);

-- line #13224
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENAP 5 (Camlin)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENAP 5 (Camlin)'
);

-- line #13225
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENA 10 (Stadmed)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENA 10 (Stadmed)'
);

-- line #13226
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENA 5 (Stadmed)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENA 5 (Stadmed)'
);

-- line #13227
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENATEN 10 (Globus)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENATEN 10 (Globus)'
);

-- line #13228
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENATEN 2.5 (Globus)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENATEN 2.5 (Globus)'
);

-- line #13229
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENATEN 5 (Globus)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENATEN 5 (Globus)'
);

-- line #13230
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENCARDIL 10 (VAZOKARE)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENCARDIL 10 (VAZOKARE)'
);

-- line #13231
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENCARDIL 2.5 (VAZOKARE)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENCARDIL 2.5 (VAZOKARE)'
);

-- line #13232
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENCARDIL 5 (VAZOKARE)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENCARDIL 5 (VAZOKARE)'
);

-- line #13233
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENLACARD 10 (Intra Lab)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENLACARD 10 (Intra Lab)'
);

-- line #13234
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENLACARD 2.5 (Intra Lab)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENLACARD 2.5 (Intra Lab)'
);

-- line #13235
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENLACARD 5 (Intra Lab)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENLACARD 5 (Intra Lab)'
);

-- line #13236
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENLOW 5 (Lincoln)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENLOW 5 (Lincoln)'
);

-- line #13237
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENPRIL 10 (Wockhardt)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENPRIL 10 (Wockhardt)'
);

-- line #13238
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENPRIL 2.5 (Wockhardt)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENPRIL 2.5 (Wockhardt)'
);

-- line #13239
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENPRIL 5 (Wockhardt)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENPRIL 5 (Wockhardt)'
);

-- line #13240
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENSTAL 20 (Stallion)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENSTAL 20 (Stallion)'
);

-- line #13241
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENTP 10 (Taurus Lab)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENTP 10 (Taurus Lab)'
);

-- line #13242
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENTP 2.5 (Taurus Lab)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENTP 2.5 (Taurus Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENTP 5 (Taurus Lab)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENTP 5 (Taurus Lab)'
);

-- line #13243
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENVAS 1.25 (Cadila Ph.)',
	'Enalapril',
	'INJ',
	gm.nullify_empty_string('1.25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENVAS 1.25 (Cadila Ph.)'
);

-- line #13244
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENVAS 10 (Cadila Ph.)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENVAS 10 (Cadila Ph.)'
);

-- line #13245
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENVAS 20 (Cadila Ph.)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENVAS 20 (Cadila Ph.)'
);

-- line #13246
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENVAS 2.5 (Cadila Ph.)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENVAS 2.5 (Cadila Ph.)'
);

-- line #13247
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENVAS 5 (Cadila Ph.)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENVAS 5 (Cadila Ph.)'
);

-- line #13248
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPM 10 (GRANDIX)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPM 10 (GRANDIX)'
);

-- line #13249
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPM 2.5 (GRANDIX)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPM 2.5 (GRANDIX)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPM 5 (GRANDIX)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPM 5 (GRANDIX)'
);

-- line #13250
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPRIL 10 (Mano)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPRIL 10 (Mano)'
);

-- line #13251
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'E-PRIL 10 (MANO)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'E-PRIL 10 (MANO)'
);

-- line #13252
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPRIL 2.5 (Mano)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPRIL 2.5 (Mano)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPRIL 5 (Mano)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPRIL 5 (Mano)'
);

-- line #13253
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'E-PRIL 2.5 (MANO)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'E-PRIL 2.5 (MANO)'
);

-- line #13254
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'E-PRIL 5 (MANO)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'E-PRIL 5 (MANO)'
);

-- line #13255
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPRIL 10 (Sain Med.)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPRIL 10 (Sain Med.)'
);

-- line #13256
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPRIL 2.5 (Sain Med.)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPRIL 2.5 (Sain Med.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPRIL 5 (Sain Med.)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPRIL 5 (Sain Med.)'
);

-- line #13257
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FRIBIT 2.5 (Olcare)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FRIBIT 2.5 (Olcare)'
);

-- line #13258
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FRIBIT 5 (Olcare)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FRIBIT 5 (Olcare)'
);

-- line #13259
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYTROL 10 (Sun)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYTROL 10 (Sun)'
);

-- line #13260
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYTROL 2.5 (Sun)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYTROL 2.5 (Sun)'
);

-- line #13261
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYTROL 5 (Sun)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYTROL 5 (Sun)'
);

-- line #13262
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INVORIL 10 (Stancare)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INVORIL 10 (Stancare)'
);

-- line #13263
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INVORIL 2.5 (Stancare)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INVORIL 2.5 (Stancare)'
);

-- line #13264
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INVORIL 5 (Stancare)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INVORIL 5 (Stancare)'
);

-- line #13265
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUPINACE 2.5 (LUPIN)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUPINACE 2.5 (LUPIN)'
);

-- line #13266
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUPINACE 5 (LUPIN)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUPINACE 5 (LUPIN)'
);

-- line #13267
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MINIPRIL 10 (Alembic)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MINIPRIL 10 (Alembic)'
);

-- line #13268
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MINIPRIL 2.5 (Alembic)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MINIPRIL 2.5 (Alembic)'
);

-- line #13269
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MINIPRIL 5 (Alembic)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MINIPRIL 5 (Alembic)'
);

-- line #13270
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYOACE 10 (Merck)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYOACE 10 (Merck)'
);

-- line #13271
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYOACE 2.5 (Merck)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYOACE 2.5 (Merck)'
);

-- line #13272
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYOACE 5 (Merck)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYOACE 5 (Merck)'
);

-- line #13273
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEWACE 10 (MAX)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEWACE 10 (MAX)'
);

-- line #13274
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEWACE 2.5 (MAX)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEWACE 2.5 (MAX)'
);

-- line #13275
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEWACE 5 (MAX)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEWACE 5 (MAX)'
);

-- line #13276
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORMACE 10 (Unisearch)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORMACE 10 (Unisearch)'
);

-- line #13277
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORMACE 2.5 (Unisearch)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORMACE 2.5 (Unisearch)'
);

-- line #13278
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORMACE 5 (Unisearch)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORMACE 5 (Unisearch)'
);

-- line #13279
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NURIL 10 (U S V)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NURIL 10 (U S V)'
);

-- line #13280
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NURIL 2.5 (U S V)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NURIL 2.5 (U S V)'
);

-- line #13281
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NURIL 5 (U S V)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NURIL 5 (U S V)'
);

-- line #13282
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OREN 10 (Natco Ph.)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OREN 10 (Natco Ph.)'
);

-- line #13283
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OREN 20 (Natco Ph.)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OREN 20 (Natco Ph.)'
);

-- line #13284
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OREN 2.5 (Natco Ph.)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OREN 2.5 (Natco Ph.)'
);

-- line #13285
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OREN 5 (Natco Ph.)',
	'Enalapril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OREN 5 (Natco Ph.)'
);

-- line #13286
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMIHART 2.5 (Mankind)',
	'Enalapril',
	'CAP',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMIHART 2.5 (Mankind)'
);

-- line #13287
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMIHART 5 (Mankind)',
	'Enalapril',
	'CAP',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMIHART 5 (Mankind)'
);

-- line #13288
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'ENBUCRILATE', u'always_empty': u'', u'form': u'AMP', u'brand': u'GESIKA', u'strength_3': u'', u'company': u'REEVAX', u'unit': u''}

-- line #13289
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'ENBUCRILATE', u'always_empty': u'', u'form': u'KIT', u'brand': u'GESIKA', u'strength_3': u'', u'company': u'REEVAX', u'unit': u''}

-- line #13290
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'ENERGY POWDER', u'always_empty': u'', u'form': u'POW', u'brand': u'FIZZ', u'strength_3': u'', u'company': u'R.B.REM.', u'unit': u''}

-- line #13291
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANGIONOX 20 (German R.)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANGIONOX 20 (German R.)'
);

-- line #13292
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANGIONOX 40 (German R.)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANGIONOX 40 (German R.)'
);

-- line #13293
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANGIONOX 60 (German R.)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANGIONOX 60 (German R.)'
);

-- line #13294
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLEXANE 20 (Sanofi Aventis)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLEXANE 20 (Sanofi Aventis)'
);

-- line #13295
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLEXANE 40 (Sanofi Aventis)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLEXANE 40 (Sanofi Aventis)'
);

-- line #13296
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLEXANE 60 (Sanofi Aventis)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLEXANE 60 (Sanofi Aventis)'
);

-- line #13297
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLEXANE 80 (Sanofi Aventis)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLEXANE 80 (Sanofi Aventis)'
);

-- line #13298
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUTENOX 20 (Gland Ph.)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUTENOX 20 (Gland Ph.)'
);

-- line #13299
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUTENOX 40 (Gland Ph.)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUTENOX 40 (Gland Ph.)'
);

-- line #13300
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUTENOX 60 (Gland Ph.)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUTENOX 60 (Gland Ph.)'
);

-- line #13301
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUTENOX 80 (Gland Ph.)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUTENOX 80 (Gland Ph.)'
);

-- line #13302
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYNALIX PFS 20 (Biocon)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg/0.2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYNALIX PFS 20 (Biocon)'
);

-- line #13303
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYNALIX PFS 40 (Biocon)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg/0.4ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYNALIX PFS 40 (Biocon)'
);

-- line #13304
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYNALIX PFS 60 (Biocon)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg/0.6ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYNALIX PFS 60 (Biocon)'
);

-- line #13305
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENAXATROY 40 (Troikaa)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg/0.4ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENAXATROY 40 (Troikaa)'
);

-- line #13306
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENCLEX 40 (Cipla)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg(EQ. TO 4000IU ANTI-XA ACTIVITY)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENCLEX 40 (Cipla)'
);

-- line #13307
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENCLEX 60 (Cipla)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg(EQ. TO 6000IU ANTI-XA ACTIVITY)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENCLEX 60 (Cipla)'
);

-- line #13308
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENOXACERE 20 (Ipca)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg/0.2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENOXACERE 20 (Ipca)'
);

-- line #13309
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENOXACERE 40 (Ipca)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg/0.4ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENOXACERE 40 (Ipca)'
);

-- line #13310
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENOXACERE 60 (Ipca)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg/0.6ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENOXACERE 60 (Ipca)'
);

-- line #13311
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENOXARIN 40 (ZUVENTUS)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg/0.4ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENOXARIN 40 (ZUVENTUS)'
);

-- line #13312
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENOXARIN 60 (ZUVENTUS)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg/0.6ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENOXARIN 60 (ZUVENTUS)'
);

-- line #13313
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENOXATROY 60 (Troikaa)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg/0.6ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENOXATROY 60 (Troikaa)'
);

-- line #13314
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'ENOXAPARIN', u'always_empty': u'', u'form': u'', u'brand': u'ENOXEL PFS', u'strength_3': u'', u'company': u'CELON(REVILON)', u'unit': u'mg/0.2ML'}

-- line #13315
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40', u'strength_2': u'', u'substance': u'ENOXAPARIN', u'always_empty': u'', u'form': u'', u'brand': u'ENOXEL PFS', u'strength_3': u'', u'company': u'CELON(REVILON)', u'unit': u'mg/0.4ML'}

-- line #13316
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'60', u'strength_2': u'', u'substance': u'ENOXAPARIN', u'always_empty': u'', u'form': u'', u'brand': u'ENOXEL PFS', u'strength_3': u'', u'company': u'CELON(REVILON)', u'unit': u'mg/0.6ML'}

-- line #13317
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENOXION 20 (Neon)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg/0.2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENOXION 20 (Neon)'
);

-- line #13318
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENOXION 40 (Neon)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg/0.4ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENOXION 40 (Neon)'
);

-- line #13319
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENOXION 60 (Neon)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg/0.6ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENOXION 60 (Neon)'
);

-- line #13320
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENOXION 80 (Neon)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg/0.8ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENOXION 80 (Neon)'
);

-- line #13321
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENOXSAVE 20 (ERIS LIFE)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENOXSAVE 20 (ERIS LIFE)'
);

-- line #13322
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENOXSAVE 40 (ERIS LIFE)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENOXSAVE 40 (ERIS LIFE)'
);

-- line #13323
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENOXSAVE 60 (ERIS LIFE)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENOXSAVE 60 (ERIS LIFE)'
);

-- line #13324
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXHEP 40 (Emcure)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXHEP 40 (Emcure)'
);

-- line #13325
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXHEP 60 (Emcure)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXHEP 60 (Emcure)'
);

-- line #13326
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FACILOC 20 (Cadila Ph.)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FACILOC 20 (Cadila Ph.)'
);

-- line #13327
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FACILOC 40 (Cadila Ph.)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FACILOC 40 (Cadila Ph.)'
);

-- line #13328
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FACILOC 60 (Cadila Ph.)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FACILOC 60 (Cadila Ph.)'
);

-- line #13329
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FACILOC 80 (Cadila Ph.)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FACILOC 80 (Cadila Ph.)'
);

-- line #13330
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOTHIN 20 (Ranbaxy)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg/0.2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOTHIN 20 (Ranbaxy)'
);

-- line #13331
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOTHIN 40 (Ranbaxy)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg/0.4ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOTHIN 40 (Ranbaxy)'
);

-- line #13332
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOTHIN 60 (Ranbaxy)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg/0.6ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOTHIN 60 (Ranbaxy)'
);

-- line #13333
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'ENOXAPARIN', u'always_empty': u'', u'form': u'', u'brand': u'GREFAC PFS', u'strength_3': u'', u'company': u"Dr. Reddy''S", u'unit': u'mg'}

-- line #13334
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40', u'strength_2': u'', u'substance': u'ENOXAPARIN', u'always_empty': u'', u'form': u'', u'brand': u'GREFAC PFS', u'strength_3': u'', u'company': u"Dr. Reddy''S", u'unit': u'mg'}

-- line #13335
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'60', u'strength_2': u'', u'substance': u'ENOXAPARIN', u'always_empty': u'', u'form': u'', u'brand': u'GREFAC PFS', u'strength_3': u'', u'company': u"Dr. Reddy''S", u'unit': u'mg'}

-- line #13336
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40', u'strength_2': u'60', u'substance': u'ENOXAPARIN', u'always_empty': u'', u'form': u'', u'brand': u'HEPANOX PFS', u'strength_3': u'', u'company': u'MINOVA', u'unit': u'mg'}

-- line #13337
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDENOX 40 (NUCLEUS)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDENOX 40 (NUCLEUS)'
);

-- line #13338
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDENOX 60 (NUCLEUS)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDENOX 60 (NUCLEUS)'
);

-- line #13339
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INNOPARIN 40 (INNOVA LIFESCI.)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg(LOW MOLECULAR WEIGHT HEPARIN)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INNOPARIN 40 (INNOVA LIFESCI.)'
);

-- line #13340
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INNOPARIN 60 (INNOVA LIFESCI.)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg(LOW MOLECULAR WEIGHT HEPARIN)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INNOPARIN 60 (INNOVA LIFESCI.)'
);

-- line #13341
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPOXANE 40 (UNI-SANKYO)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg/0.4ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPOXANE 40 (UNI-SANKYO)'
);

-- line #13342
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPOXANE 60 (UNI-SANKYO)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg/0.6ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPOXANE 60 (UNI-SANKYO)'
);

-- line #13343
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40', u'strength_2': u'', u'substance': u'ENOXAPARIN', u'always_empty': u'', u'form': u'', u'brand': u'LIVEX PFS', u'strength_3': u'', u'company': u'EXCELLA', u'unit': u'mg'}

-- line #13344
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'60', u'strength_2': u'', u'substance': u'ENOXAPARIN', u'always_empty': u'', u'form': u'', u'brand': u'LIVEX PFS', u'strength_3': u'', u'company': u'EXCELLA', u'unit': u'mg'}

-- line #13345
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LMWX 20 (Piramal Hc.)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LMWX 20 (Piramal Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LMWX 40 (Piramal Hc.)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LMWX 40 (Piramal Hc.)'
);

-- line #13346
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LMWX 60 (Piramal Hc.)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LMWX 60 (Piramal Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LMWX 80 (Piramal Hc.)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LMWX 80 (Piramal Hc.)'
);

-- line #13347
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOMOH 40 (EMCURE)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOMOH 40 (EMCURE)'
);

-- line #13348
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOMOH 60 (EMCURE)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOMOH 60 (EMCURE)'
);

-- line #13349
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOMOH 80 (Emcure)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOMOH 80 (Emcure)'
);

-- line #13350
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOMONOX 40 (NEISS)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOMONOX 40 (NEISS)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOMONOX 60 (NEISS)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOMONOX 60 (NEISS)'
);

-- line #13351
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'ENOXAPARIN', u'always_empty': u'', u'form': u'INJ', u'brand': u'LOMORIN NX', u'strength_3': u'', u'company': u'Vhb', u'unit': u''}

-- line #13352
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LONOPIN 20 (Bharat S.)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LONOPIN 20 (Bharat S.)'
);

-- line #13353
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LONOPIN 40 (Bharat S.)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LONOPIN 40 (Bharat S.)'
);

-- line #13354
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LONOPIN 60 (Bharat S.)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LONOPIN 60 (Bharat S.)'
);

-- line #13355
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOWCAP 40 (SAMARTH LIFE)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg/0.4ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOWCAP 40 (SAMARTH LIFE)'
);

-- line #13356
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOWCAP 60 (SAMARTH LIFE)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg/0.6ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOWCAP 60 (SAMARTH LIFE)'
);

-- line #13357
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'ENOXAPARIN', u'always_empty': u'', u'form': u'', u'brand': u'LUPENOX', u'strength_3': u'', u'company': u'Lupin', u'unit': u'mg'}

-- line #13358
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40', u'strength_2': u'', u'substance': u'ENOXAPARIN', u'always_empty': u'', u'form': u'', u'brand': u'LUPENOX', u'strength_3': u'', u'company': u'Lupin', u'unit': u'mg'}

-- line #13359
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'60', u'strength_2': u'', u'substance': u'ENOXAPARIN', u'always_empty': u'', u'form': u'', u'brand': u'LUPENOX', u'strength_3': u'', u'company': u'Lupin', u'unit': u'mg'}

-- line #13360
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40', u'strength_2': u'', u'substance': u'ENOXAPARIN', u'always_empty': u'', u'form': u'', u'brand': u'MACPARIN', u'strength_3': u'', u'company': u'Macleods', u'unit': u'mg'}

-- line #13361
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'60', u'strength_2': u'', u'substance': u'ENOXAPARIN', u'always_empty': u'', u'form': u'', u'brand': u'MACPARIN', u'strength_3': u'', u'company': u'Macleods', u'unit': u'mg'}

-- line #13362
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'ENOXAPARIN', u'always_empty': u'', u'form': u'INJ', u'brand': u'MAXIPARINE', u'strength_3': u'', u'company': u'CH.Bhagat', u'unit': u''}

-- line #13363
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'ENOXAPARIN', u'always_empty': u'', u'form': u'', u'brand': u'MAZPARINE PFS', u'strength_3': u'', u'company': u'CH.Bhagat', u'unit': u'mg/0.2ML'}

-- line #13364
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40', u'strength_2': u'', u'substance': u'ENOXAPARIN', u'always_empty': u'', u'form': u'', u'brand': u'MAZPARINE PFS', u'strength_3': u'', u'company': u'CH.Bhagat', u'unit': u'mg/0.4ML'}

-- line #13365
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'60', u'strength_2': u'', u'substance': u'ENOXAPARIN', u'always_empty': u'', u'form': u'', u'brand': u'MAZPARINE PFS', u'strength_3': u'', u'company': u'CH.Bhagat', u'unit': u'mg/0.6ML'}

-- line #13366
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'80', u'strength_2': u'', u'substance': u'ENOXAPARIN', u'always_empty': u'', u'form': u'', u'brand': u'MAZPARINE PFS', u'strength_3': u'', u'company': u'CH.Bhagat', u'unit': u'mg/0.8ML'}

-- line #13367
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40', u'strength_2': u'60', u'substance': u'ENOXAPARIN', u'always_empty': u'', u'form': u'', u'brand': u'MEGAPARIN PFS', u'strength_3': u'', u'company': u'VENUS REM.', u'unit': u'mg'}

-- line #13368
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOXAPARIN 40 (UNITED BIO.)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOXAPARIN 40 (UNITED BIO.)'
);

-- line #13369
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOXAPARIN 60 (UNITED BIO.)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOXAPARIN 60 (UNITED BIO.)'
);

-- line #13370
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOXPRIN 40 (Ajanta Ph.)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOXPRIN 40 (Ajanta Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOXPRIN 60 (Ajanta Ph.)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOXPRIN 60 (Ajanta Ph.)'
);

-- line #13371
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40', u'strength_2': u'', u'substance': u'ENOXAPARIN', u'always_empty': u'', u'form': u'', u'brand': u'OXPRIN-40', u'strength_3': u'', u'company': u'Micro Labs', u'unit': u'mg'}

-- line #13372
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'60', u'strength_2': u'', u'substance': u'ENOXAPARIN', u'always_empty': u'', u'form': u'', u'brand': u'OXPRIN-60', u'strength_3': u'', u'company': u'Micro Labs', u'unit': u'mg'}

-- line #13373
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40', u'strength_2': u'', u'substance': u'ENOXAPARIN', u'always_empty': u'', u'form': u'', u'brand': u'QUALINOX ML', u'strength_3': u'', u'company': u'Lupin', u'unit': u'mg'}

-- line #13374
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'60', u'strength_2': u'', u'substance': u'ENOXAPARIN', u'always_empty': u'', u'form': u'', u'brand': u'QUALINOX ML', u'strength_3': u'', u'company': u'Lupin', u'unit': u'mg'}

-- line #13375
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RENOXA 20 (UNIMARK REM.)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg/0.2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RENOXA 20 (UNIMARK REM.)'
);

-- line #13376
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RENOXA 40 (UNIMARK REM.)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg/0.4ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RENOXA 40 (UNIMARK REM.)'
);

-- line #13377
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RENOXA 60 (UNIMARK REM.)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg/0.6ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RENOXA 60 (UNIMARK REM.)'
);

-- line #13378
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RENOXA 80 (UNIMARK REM.)',
	'ENOXAPARIN',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg/0.8ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RENOXA 80 (UNIMARK REM.)'
);

-- line #13379
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,5', u'strength_2': u'', u'substance': u'ENTACAVIR', u'always_empty': u'', u'form': u'', u'brand': u'ENTECA GM', u'strength_3': u'', u'company': u'Ranbaxy', u'unit': u'mg'}

-- line #13380
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1', u'strength_2': u'', u'substance': u'ENTACAVIR', u'always_empty': u'', u'form': u'', u'brand': u'ENTECA', u'strength_3': u'', u'company': u'Ranbaxy', u'unit': u'mg'}

-- line #13381
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,5', u'strength_2': u'', u'substance': u'ENTECAVIR', u'always_empty': u'', u'form': u'', u'brand': u"ENTALIV ''S", u'strength_3': u'', u'company': u"Dr.Reddy''S", u'unit': u'mg'}

-- line #13382
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENTAVIR 0.5 (Cipla)',
	'ENTECAVIR',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENTAVIR 0.5 (Cipla)'
);

-- line #13383
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENTAVIR 1 (Cipla)',
	'ENTECAVIR',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENTAVIR 1 (Cipla)'
);

-- line #13384
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENTEHEP 0.5 (Zydus Cadila)',
	'ENTECAVIR',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENTEHEP 0.5 (Zydus Cadila)'
);

-- line #13385
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1', u'strength_2': u'', u'substance': u'ENTECAVIR', u'always_empty': u'', u'form': u'', u'brand': u'ENTEHEP', u'strength_3': u'', u'company': u'Zydus Cadila', u'unit': u'mg'}

-- line #13386
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALDONIAL 50 (Zydus Med.)',
	'EPALRESTAT',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALDONIAL 50 (Zydus Med.)'
);

-- line #13387
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALDORACE 50 (Ranbaxy)',
	'EPALRESTAT',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALDORACE 50 (Ranbaxy)'
);

-- line #13388
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALRISTA 50 (Macleods)',
	'EPALRESTAT',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALRISTA 50 (Macleods)'
);

-- line #13389
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARISTAT 50 (Macleods)',
	'EPALRESTAT',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARISTAT 50 (Macleods)'
);

-- line #13390
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPAREL-50 50 (Micro Labs)',
	'EPALRESTAT',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPAREL-50 50 (Micro Labs)'
);

-- line #13391
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENZORIL 50 (Bergen)',
	'EPERISONE HCL.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENZORIL 50 (Bergen)'
);

-- line #13392
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPRY 50 (Unichem)',
	'EPERISONE HCL.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPRY 50 (Unichem)'
);

-- line #13393
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYOSONE 50 (Macleods)',
	'EPERISONE HCL.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYOSONE 50 (Macleods)'
);

-- line #13394
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAPISONE 50 (NICHOLAS ZES.)',
	'EPERISONE HCL.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAPISONE 50 (NICHOLAS ZES.)'
);

-- line #13395
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EFIPRES 30 (Neon)',
	'EPHEDRINE HCL.',
	'INJ',
	gm.nullify_empty_string('30')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EFIPRES 30 (Neon)'
);

-- line #13396
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELESTAT 0.05 (Allergan)',
	'EPINASTINE',
	'EYE DPS',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELESTAT 0.05 (Allergan)'
);

-- line #13397
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'4-EPPEDO 10 (MIRACALUS)',
	'EPIRUBICIN',
	'VIAL',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '4-EPPEDO 10 (MIRACALUS)'
);

-- line #13398
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'4-EPPEDO 50 (MIRACALUS)',
	'EPIRUBICIN',
	'VIAL',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '4-EPPEDO 50 (MIRACALUS)'
);

-- line #13399
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALRUBICIN 100 (Cytomed(Alkem))',
	'EPIRUBICIN',
	'V',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALRUBICIN 100 (Cytomed(Alkem))'
);

-- line #13400
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALRUBICIN 10 (Cytomed(Alkem))',
	'EPIRUBICIN',
	'VIAL',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALRUBICIN 10 (Cytomed(Alkem))'
);

-- line #13401
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALRUBICIN 50 (Cytomed(Alkem))',
	'EPIRUBICIN',
	'VIAL',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALRUBICIN 50 (Cytomed(Alkem))'
);

-- line #13402
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIORUBIN 10 (Biochem)',
	'EPIRUBICIN',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIORUBIN 10 (Biochem)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIORUBIN 50 (Biochem)',
	'EPIRUBICIN',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIORUBIN 50 (Biochem)'
);

-- line #13403
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPICHLOR 10 (Khandelwal)',
	'EPIRUBICIN',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPICHLOR 10 (Khandelwal)'
);

-- line #13404
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPICHLOR 50 (Khandelwal)',
	'EPIRUBICIN',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPICHLOR 50 (Khandelwal)'
);

-- line #13405
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPIDOX 10 (Samarth LIFE)',
	'EPIRUBICIN',
	'VIAL',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPIDOX 10 (Samarth LIFE)'
);

-- line #13406
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPIDOX 50 (Samarth LIFE)',
	'EPIRUBICIN',
	'VIAL',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPIDOX 50 (Samarth LIFE)'
);

-- line #13407
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10', u'strength_2': u'', u'substance': u'EPIRUBICIN', u'always_empty': u'', u'form': u'', u'brand': u'EPIRUBICIN', u'strength_3': u'', u'company': u"Dr.Reddy''S", u'unit': u'mg'}

-- line #13408
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50', u'strength_2': u'', u'substance': u'EPIRUBICIN', u'always_empty': u'', u'form': u'', u'brand': u'EPIRUBICIN', u'strength_3': u'', u'company': u"Dr.Reddy''S", u'unit': u'mg'}

-- line #13409
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPIRUBITEC 10 (United Bio.)',
	'EPIRUBICIN',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPIRUBITEC 10 (United Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPIRUBITEC 50 (United Bio.)',
	'EPIRUBICIN',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPIRUBITEC 50 (United Bio.)'
);

-- line #13410
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPITHRA 10 (Glenmark)',
	'EPIRUBICIN',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPITHRA 10 (Glenmark)'
);

-- line #13411
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPITHRA 50 (Glenmark)',
	'EPIRUBICIN',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPITHRA 50 (Glenmark)'
);

-- line #13412
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPITHRA 100 (ONKOS(GLENMARK))',
	'EPIRUBICIN',
	'VIAL',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPITHRA 100 (ONKOS(GLENMARK))'
);

-- line #13413
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPRICIN 100 (Shantha Bio.)',
	'EPIRUBICIN',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPRICIN 100 (Shantha Bio.)'
);

-- line #13414
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPRICIN 10 (Shantha Bio.)',
	'EPIRUBICIN',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPRICIN 10 (Shantha Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPRICIN 50 (Shantha Bio.)',
	'EPIRUBICIN',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPRICIN 50 (Shantha Bio.)'
);

-- line #13415
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPRIPAR 1000 (Parenteral)',
	'EPIRUBICIN',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPRIPAR 1000 (Parenteral)'
);

-- line #13416
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPRIPAR 50 (Parenteral)',
	'EPIRUBICIN',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPRIPAR 50 (Parenteral)'
);

-- line #13417
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERUBIN 10 (Rpg Life)',
	'EPIRUBICIN',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERUBIN 10 (Rpg Life)'
);

-- line #13418
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERUBIN 50 (Rpg Life)',
	'EPIRUBICIN',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERUBIN 50 (Rpg Life)'
);

-- line #13419
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FARMORUBICIN 10 (Pharmacia)',
	'Epirubicin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FARMORUBICIN 10 (Pharmacia)'
);

-- line #13420
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FARMORUBICIN 50 (Pharmacia)',
	'Epirubicin',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FARMORUBICIN 50 (Pharmacia)'
);

-- line #13421
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPLECARD 25 (Cadila Ph.)',
	'EPLERENONE',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPLECARD 25 (Cadila Ph.)'
);

-- line #13422
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPLECARD 50 (Cadila Ph.)',
	'EPLERENONE',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPLECARD 50 (Cadila Ph.)'
);

-- line #13423
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPLERAN 25 (Unichem)',
	'EPLERENONE',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPLERAN 25 (Unichem)'
);

-- line #13424
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPTUS 25 (Glenmark)',
	'EPLERENONE',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPTUS 25 (Glenmark)'
);

-- line #13425
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPTUS 50 (Glenmark)',
	'EPLERENONE',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPTUS 50 (Glenmark)'
);

-- line #13426
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXINIA 25 (Rpg Life)',
	'EPLERENONE',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXINIA 25 (Rpg Life)'
);

-- line #13427
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXINIA 50 (Rpg Life)',
	'EPLERENONE',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXINIA 50 (Rpg Life)'
);

-- line #13428
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLANEP 25 (Lupin)',
	'EPLERENONE',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLANEP 25 (Lupin)'
);

-- line #13429
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANTIGRILIN 20 (Samarth)',
	'EPTIFIBATIDE',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANTIGRILIN 20 (Samarth)'
);

-- line #13430
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANTIGRILIN 75 (Samarth)',
	'EPTIFIBATIDE',
	'INJ',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANTIGRILIN 75 (Samarth)'
);

-- line #13431
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOTIDE 20 (Biocon)',
	'EPTIFIBATIDE',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg/10ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOTIDE 20 (Biocon)'
);

-- line #13432
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOTIDE 75 (Biocon)',
	'EPTIFIBATIDE',
	'INJ',
	gm.nullify_empty_string('75')::numeric,
	'mg/100ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOTIDE 75 (Biocon)'
);

-- line #13433
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COROMAX 2 (U S V)',
	'EPTIFIBATIDE',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COROMAX 2 (U S V)'
);

-- line #13434
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COROMAX 75 (U S V)',
	'EPTIFIBATIDE',
	'INJ',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COROMAX 75 (U S V)'
);

-- line #13435
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPTIBA 20 (Intas)',
	'EPTIFIBATIDE',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPTIBA 20 (Intas)'
);

-- line #13436
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPTIBA 75 (Intas)',
	'EPTIFIBATIDE',
	'INJ',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPTIBA 75 (Intas)'
);

-- line #13437
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPTIBLOC 20 (Gland Ph.)',
	'EPTIFIBATIDE',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg/10ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPTIBLOC 20 (Gland Ph.)'
);

-- line #13438
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPTIBLOC 75 (Gland Ph.)',
	'EPTIFIBATIDE',
	'INJ',
	gm.nullify_empty_string('75')::numeric,
	'mg/100ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPTIBLOC 75 (Gland Ph.)'
);

-- line #13439
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPTICARD 20 (UNIMARK REM.)',
	'EPTIFIBATIDE',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPTICARD 20 (UNIMARK REM.)'
);

-- line #13440
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPTIDE 20 (Ranbaxy)',
	'EPTIFIBATIDE',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPTIDE 20 (Ranbaxy)'
);

-- line #13441
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPTIDE 75 (Ranbaxy)',
	'EPTIFIBATIDE',
	'INJ',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPTIDE 75 (Ranbaxy)'
);

-- line #13442
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPTIFAB 20 (Piramal Hc.)',
	'EPTIFIBATIDE',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPTIFAB 20 (Piramal Hc.)'
);

-- line #13443
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPTIFAB 75 (Piramal Hc.)',
	'EPTIFIBATIDE',
	'INJ',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPTIFAB 75 (Piramal Hc.)'
);

-- line #13444
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLETA BOLUS 2 (Lupin)',
	'EPTIFIBATIDE',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLETA BOLUS 2 (Lupin)'
);

-- line #13445
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLETA 0.75 (Lupin)',
	'EPTIFIBATIDE',
	'INFUSION',
	gm.nullify_empty_string('0.75')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLETA 0.75 (Lupin)'
);

-- line #13446
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTIFLO ML 0.75 (Cipla)',
	'EPTIFIBATIDE',
	'INJ',
	gm.nullify_empty_string('0.75')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTIFLO ML 0.75 (Cipla)'
);

-- line #13447
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTIFLO ML 2 (Cipla)',
	'EPTIFIBATIDE',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTIFLO ML 2 (Cipla)'
);

-- line #13448
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERDOZET 300 (Glenmark)',
	'ERDOSTEINE',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERDOZET 300 (Glenmark)'
);

-- line #13449
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERDOZET 175 (MAJESTA(GLENMARK DIV.))',
	'ERDOSTEINE',
	'SUS',
	gm.nullify_empty_string('175')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERDOZET 175 (MAJESTA(GLENMARK DIV.))'
);

-- line #13450
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERGOTAB 270 (Jagsonpal)',
	'Ergot Preparation',
	'F. CAP',
	gm.nullify_empty_string('270')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERGOTAB 270 (Jagsonpal)'
);

-- line #13451
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERGOTAB 150 (Jagsonpal)',
	'Ergot Preparation',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERGOTAB 150 (Jagsonpal)'
);

-- line #13452
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELCURE 150 (Emcure)',
	'ERLOTINIB',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELCURE 150 (Emcure)'
);

-- line #13453
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'ERLOTINIB', u'always_empty': u'', u'form': u'CAP', u'brand': u'ERLONAT', u'strength_3': u'', u'company': u'Natco', u'unit': u''}

-- line #13454
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERLONAT 150 (Natco)',
	'ERLOTINIB',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERLONAT 150 (Natco)'
);

-- line #13455
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'ERLOTINIB', u'always_empty': u'', u'form': u'', u'brand': u'ERLOPAR-150', u'strength_3': u'', u'company': u'Parenteral', u'unit': u''}

-- line #13456
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERLOSTAR 150 (Lupin)',
	'ERLOTINIB',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERLOSTAR 150 (Lupin)'
);

-- line #13457
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERLOTIB 150 (Intas)',
	'ERLOTINIB',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERLOTIB 150 (Intas)'
);

-- line #13458
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'ERTAPENEM', u'always_empty': u'', u'form': u'', u'brand': u'E-PEN', u'strength_3': u'', u'company': u'INNOVA LIFESCI.', u'unit': u''}

-- line #13459
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.0G', u'strength_2': u'', u'substance': u'ERTAPENEM', u'always_empty': u'', u'form': u'INJ', u'brand': u'ERTACRIT GM', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #13460
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'ERTAPENEM', u'always_empty': u'', u'form': u'', u'brand': u'ERTALYM GM', u'strength_3': u'', u'company': u'LYKA LABS', u'unit': u''}

-- line #13461
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.0G', u'strength_2': u'', u'substance': u'ERTAPENEM', u'always_empty': u'', u'form': u'VIAL', u'brand': u'ERTAMAC', u'strength_3': u'', u'company': u'Macleods', u'unit': u''}

-- line #13462
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.0G', u'strength_2': u'', u'substance': u'ERTAPENEM', u'always_empty': u'', u'form': u'', u'brand': u'ERTAZEN', u'strength_3': u'', u'company': u'UNIMARK REM.', u'unit': u''}

-- line #13463
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'ERTAPENEM', u'always_empty': u'', u'form': u'INJ', u'brand': u'ERTEM', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #13464
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1GM', u'strength_2': u'', u'substance': u'ERTAPENEM', u'always_empty': u'', u'form': u'INJ', u'brand': u'FORSTAL GM', u'strength_3': u'', u'company': u'ZYPHARS PH.', u'unit': u''}

-- line #13465
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.0G', u'strength_2': u'', u'substance': u'ERTAPENEM', u'always_empty': u'', u'form': u'INJ', u'brand': u'GERTA GM', u'strength_3': u'', u'company': u'German R.', u'unit': u''}

-- line #13466
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.0G', u'strength_2': u'', u'substance': u'ERTAPENEM', u'always_empty': u'', u'form': u'INJ', u'brand': u'INVANZ', u'strength_3': u'', u'company': u'MSD', u'unit': u''}

-- line #13467
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACNEDERM 2 (Abbott)',
	'Erythromycin',
	'LOT',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACNEDERM 2 (Abbott)'
);

-- line #13468
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACNEDERM 2 (Abbott)',
	'Erythromycin',
	'OINT',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACNEDERM 2 (Abbott)'
);

-- line #13469
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Erythromycin', u'always_empty': u'', u'form': u'CRM', u'brand': u'ACNELAK', u'strength_3': u'', u'company': u'Shalaks', u'unit': u''}

-- line #13470
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACNESOL 4 (Systopic)',
	'Erythromycin',
	'GEL',
	gm.nullify_empty_string('4')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACNESOL 4 (Systopic)'
);

-- line #13471
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACNESOL 2 (Systopic)',
	'Erythromycin',
	'LOT',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACNESOL 2 (Systopic)'
);

-- line #13472
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACNET 3 (Amideep)',
	'Erythromycin',
	'CRM',
	gm.nullify_empty_string('3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACNET 3 (Amideep)'
);

-- line #13473
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALTHROCIN 100 (Alembic)',
	'Erythromycin',
	'CHEW TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALTHROCIN 100 (Alembic)'
);

-- line #13474
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALTHROCIN 100 (Alembic)',
	'Erythromycin',
	'DPS',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALTHROCIN 100 (Alembic)'
);

-- line #13475
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALTHROCIN 250 (Alembic)',
	'Erythromycin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALTHROCIN 250 (Alembic)'
);

-- line #13476
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALTHROCIN 125 (Alembic)',
	'Erythromycin',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALTHROCIN 125 (Alembic)'
);

-- line #13477
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALTHROCIN 125 (Alembic)',
	'Erythromycin',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALTHROCIN 125 (Alembic)'
);

-- line #13478
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALTHROCIN 250 (Alembic)',
	'Erythromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALTHROCIN 250 (Alembic)'
);

-- line #13479
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALTHROCIN 500 (Alembic)',
	'Erythromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALTHROCIN 500 (Alembic)'
);

-- line #13480
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARITOMYCIN 250 (Cadila Ph.)',
	'Erythromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARITOMYCIN 250 (Cadila Ph.)'
);

-- line #13481
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARITOMYCIN 500 (Cadila Ph.)',
	'Erythromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARITOMYCIN 500 (Cadila Ph.)'
);

-- line #13482
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EB-333 333 (WOMB LAB.)',
	'Erythromycin',
	'TAB',
	gm.nullify_empty_string('333')::numeric,
	'mg(BASE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EB-333 333 (WOMB LAB.)'
);

-- line #13483
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EES 400 (Pharmacia)',
	'Erythromycin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg(ETHYL SUCCINATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EES 400 (Pharmacia)'
);

-- line #13484
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250', u'strength_2': u'', u'substance': u'Erythromycin', u'always_empty': u'', u'form': u'', u'brand': u'E-FAST', u'strength_3': u'', u'company': u'SEQUEL PH.', u'unit': u'mg'}

-- line #13485
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELUCIN 1 (Ind-Swift)',
	'Erythromycin',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELUCIN 1 (Ind-Swift)'
);

-- line #13486
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERICURE 125 (Hind.Trust)',
	'Erythromycin',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERICURE 125 (Hind.Trust)'
);

-- line #13487
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERICURE 250 (Hind.Trust)',
	'Erythromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERICURE 250 (Hind.Trust)'
);

-- line #13488
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EROLCID 250 (Pharmacia)',
	'Erythromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EROLCID 250 (Pharmacia)'
);

-- line #13489
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EROMED 4 (Comed)',
	'Erythromycin',
	'GEL',
	gm.nullify_empty_string('4')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EROMED 4 (Comed)'
);

-- line #13490
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EROMED 125 (Comed)',
	'Erythromycin',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EROMED 125 (Comed)'
);

-- line #13491
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EROMED 333 (Comed)',
	'Erythromycin',
	'TAB',
	gm.nullify_empty_string('333')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EROMED 333 (Comed)'
);

-- line #13492
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2', u'strength_2': u'', u'substance': u'Erythromycin', u'always_empty': u'', u'form': u'', u'brand': u'EROMED TOPSOL', u'strength_3': u'', u'company': u'Comed', u'unit': u'%W/V'}

-- line #13493
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERYACNE-4 4 (Encube Eth.)',
	'Erythromycin',
	'GEL',
	gm.nullify_empty_string('4')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERYACNE-4 4 (Encube Eth.)'
);

-- line #13494
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERYACNE 4 (Galderma)',
	'Erythromycin',
	'GEL',
	gm.nullify_empty_string('4')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERYACNE 4 (Galderma)'
);

-- line #13495
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERYCIN 125 (Cipla)',
	'Erythromycin',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERYCIN 125 (Cipla)'
);

-- line #13496
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERYCIN 250 (Cipla)',
	'Erythromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERYCIN 250 (Cipla)'
);

-- line #13497
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERYCIN 500 (Cipla)',
	'Erythromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERYCIN 500 (Cipla)'
);

-- line #13498
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERYCIP 250 (Cipla)',
	'Erythromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERYCIP 250 (Cipla)'
);

-- line #13499
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERYNATE 100 (Hal)',
	'Erythromycin',
	'SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERYNATE 100 (Hal)'
);

-- line #13500
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERYPAL 100 (Jagsonpal)',
	'Erythromycin',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERYPAL 100 (Jagsonpal)'
);

-- line #13501
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERYPAL 250 (Jagsonpal)',
	'Erythromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERYPAL 250 (Jagsonpal)'
);

-- line #13502
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERYPSIN 250 (Dr.Reddy''S)',
	'Erythromycin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERYPSIN 250 (Dr.Reddy''S)'
);

-- line #13503
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERYSAFE 250 (U S V)',
	'Erythromycin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg(AS BASE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERYSAFE 250 (U S V)'
);

-- line #13504
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERYSPANS 250 (Dr.Reddy''S)',
	'Erythromycin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg E.C.PELLETS'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERYSPANS 250 (Dr.Reddy''S)'
);

-- line #13505
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERYSTER 250 (Hal)',
	'Erythromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERYSTER 250 (Hal)'
);

-- line #13506
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERYSTER 500 (Hal)',
	'Erythromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERYSTER 500 (Hal)'
);

-- line #13507
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERYTHROKEM 125 (Alkem)',
	'Erythromycin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERYTHROKEM 125 (Alkem)'
);

-- line #13508
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERYTHROKEM 250 (Alkem)',
	'Erythromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERYTHROKEM 250 (Alkem)'
);

-- line #13509
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERYTHROKEM 500 (Alkem)',
	'Erythromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERYTHROKEM 500 (Alkem)'
);

-- line #13510
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERYTHROLAR 250 (Lark Lab)',
	'Erythromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERYTHROLAR 250 (Lark Lab)'
);

-- line #13511
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERYTHROLAR 500 (Lark Lab)',
	'Erythromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERYTHROLAR 500 (Lark Lab)'
);

-- line #13512
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERYTOP 3 (U S V)',
	'Erythromycin',
	'CRM',
	gm.nullify_empty_string('3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERYTOP 3 (U S V)'
);

-- line #13513
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERYTOP 3 (U S V)',
	'Erythromycin',
	'LOT',
	gm.nullify_empty_string('3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERYTOP 3 (U S V)'
);

-- line #13514
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESTOCIN 5 (SUNWAYS)',
	'Erythromycin',
	'DPS',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESTOCIN 5 (SUNWAYS)'
);

-- line #13515
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITAMYCIN PAED 125 (VERITAZ)',
	'Erythromycin Estolate',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITAMYCIN PAED 125 (VERITAZ)'
);

-- line #13516
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITAMYCIN 250 (VERITAZ)',
	'Erythromycin Estolate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITAMYCIN 250 (VERITAZ)'
);

-- line #13517
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYNORYL KID/250 100 (Dial Ph.)',
	'Erythromycin Estolate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYNORYL KID/250 100 (Dial Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYNORYL KID/250 250 (Dial Ph.)',
	'Erythromycin Estolate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYNORYL KID/250 250 (Dial Ph.)'
);

-- line #13518
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EB-333 333 (Sysmed)',
	'Erythromycin Estolate',
	'TAB',
	gm.nullify_empty_string('333')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EB-333 333 (Sysmed)'
);

-- line #13519
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELTOCIN 500 (Ipca)',
	'Erythromycin Estolate',
	'DS TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELTOCIN 500 (Ipca)'
);

-- line #13520
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELTOCIN 125 (Ipca)',
	'Erythromycin Estolate',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELTOCIN 125 (Ipca)'
);

-- line #13521
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELTOCIN 125 (Ipca)',
	'Erythromycin Estolate',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELTOCIN 125 (Ipca)'
);

-- line #13522
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELTOCIN 250 (Ipca)',
	'Erythromycin Estolate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELTOCIN 250 (Ipca)'
);

-- line #13523
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELUCIN 125 (Ind-Swift)',
	'Erythromycin Estolate',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELUCIN 125 (Ind-Swift)'
);

-- line #13524
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELUCIN 333 (Ind-Swift)',
	'Erythromycin Estolate',
	'TAB',
	gm.nullify_empty_string('333')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELUCIN 333 (Ind-Swift)'
);

-- line #13525
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMYCIN 100 (Themis)',
	'Erythromycin Estolate',
	'D.SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMYCIN 100 (Themis)'
);

-- line #13526
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'E-MYCIN 100 (Themis)',
	'Erythromycin Estolate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'E-MYCIN 100 (Themis)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'E-MYCIN 250 (Themis)',
	'Erythromycin Estolate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'E-MYCIN 250 (Themis)'
);

-- line #13527
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EROATE 125 (Lupin)',
	'Erythromycin Estolate',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EROATE 125 (Lupin)'
);

-- line #13528
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EROATE 125 (Lupin)',
	'Erythromycin Estolate',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EROATE 125 (Lupin)'
);

-- line #13529
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EROATE 250 (Lupin)',
	'Erythromycin Estolate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EROATE 250 (Lupin)'
);

-- line #13530
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EROATE 500 (Lupin)',
	'Erythromycin Estolate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EROATE 500 (Lupin)'
);

-- line #13531
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EROKID 125 (Abbott)',
	'Erythromycin Estolate',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EROKID 125 (Abbott)'
);

-- line #13532
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EROMA -E 250 (Finecure)',
	'Erythromycin Estolate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EROMA -E 250 (Finecure)'
);

-- line #13533
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EROTECH 250 (Yash Ph.)',
	'Erythromycin Estolate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EROTECH 250 (Yash Ph.)'
);

-- line #13534
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EROTECH 500 (Yash Ph.)',
	'Erythromycin Estolate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EROTECH 500 (Yash Ph.)'
);

-- line #13535
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERTOMA 250 (Vega Lab)',
	'Erythromycin Estolate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERTOMA 250 (Vega Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERTOMA 500 (Vega Lab)',
	'Erythromycin Estolate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERTOMA 500 (Vega Lab)'
);

-- line #13536
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERYBEST 125 (Blue Cross)',
	'Erythromycin Estolate',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERYBEST 125 (Blue Cross)'
);

-- line #13537
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERYBEST 250 (Blue Cross)',
	'Erythromycin Estolate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERYBEST 250 (Blue Cross)'
);

-- line #13538
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERYMAN 125 (Maan)',
	'Erythromycin Estolate',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERYMAN 125 (Maan)'
);

-- line #13539
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERYMAN 250 (Maan)',
	'Erythromycin Estolate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERYMAN 250 (Maan)'
);

-- line #13540
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERYMAN 500 (Maan)',
	'Erythromycin Estolate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERYMAN 500 (Maan)'
);

-- line #13541
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERYMER 125 (Mercury)',
	'Erythromycin Estolate',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERYMER 125 (Mercury)'
);

-- line #13542
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERYMER 250 (Mercury)',
	'Erythromycin Estolate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERYMER 250 (Mercury)'
);

-- line #13543
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERYSTOL 250 (AIMCO PH.)',
	'Erythromycin Estolate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERYSTOL 250 (AIMCO PH.)'
);

-- line #13544
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERYTHROMYCIN 100 (Dopson Ph.)',
	'Erythromycin Estolate',
	'D.SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERYTHROMYCIN 100 (Dopson Ph.)'
);

-- line #13545
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESTOMYCIN 250 (Kosha Lab.)',
	'Erythromycin Estolate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESTOMYCIN 250 (Kosha Lab.)'
);

-- line #13546
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESTORIM 250 (TALENT LAB.)',
	'Erythromycin Estolate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESTORIM 250 (TALENT LAB.)'
);

-- line #13547
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETOMIN 125 (Sun)',
	'Erythromycin Estolate',
	'DPS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETOMIN 125 (Sun)'
);

-- line #13548
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETOMIN 125 (Sun)',
	'Erythromycin Estolate',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETOMIN 125 (Sun)'
);

-- line #13549
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETOMIN 250 (Sun)',
	'Erythromycin Estolate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETOMIN 250 (Sun)'
);

-- line #13550
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETOMIN 500 (Sun)',
	'Erythromycin Estolate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETOMIN 500 (Sun)'
);

-- line #13551
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDERYTH 125 (Indoco Rem.)',
	'Erythromycin Estolate',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDERYTH 125 (Indoco Rem.)'
);

-- line #13552
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDERYTH 250 (Indoco Rem.)',
	'Erythromycin Estolate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDERYTH 250 (Indoco Rem.)'
);

-- line #13553
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REKCIN 125 (Rekvina)',
	'Erythromycin Estolate',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REKCIN 125 (Rekvina)'
);

-- line #13554
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REKCIN 250 (Rekvina)',
	'Erythromycin Estolate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REKCIN 250 (Rekvina)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REKCIN 333 (Rekvina)',
	'Erythromycin Estolate',
	'TAB',
	gm.nullify_empty_string('333')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REKCIN 333 (Rekvina)'
);

-- line #13555
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELITHROCIN 125 (Reliance)',
	'Erythromycin Estolate',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELITHROCIN 125 (Reliance)'
);

-- line #13556
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELITHROCIN 250 (Reliance)',
	'Erythromycin Estolate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELITHROCIN 250 (Reliance)'
);

-- line #13557
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RETORIN 125 (Svizera)',
	'Erythromycin Estolate',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RETORIN 125 (Svizera)'
);

-- line #13558
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RETORIN 250 (Svizera)',
	'Erythromycin Estolate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RETORIN 250 (Svizera)'
);

-- line #13559
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RETORIN 500 (Svizera)',
	'Erythromycin Estolate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RETORIN 500 (Svizera)'
);

-- line #13560
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESTORIM 3 (TALENT LAB.)',
	'Erythromycin',
	'CRM',
	gm.nullify_empty_string('3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESTORIM 3 (TALENT LAB.)'
);

-- line #13561
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EYSPANS 250 (Dr.Reddy''S)',
	'Erythromycin',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg(AS BASE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EYSPANS 250 (Dr.Reddy''S)'
);

-- line #13562
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GERY 3 (Geno Ph.)',
	'Erythromycin',
	'OINT',
	gm.nullify_empty_string('3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GERY 3 (Geno Ph.)'
);

-- line #13563
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MERYTH 250 (MODHIKE)',
	'Erythromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MERYTH 250 (MODHIKE)'
);

-- line #13564
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OKAMYCIN 3 (Cipla)',
	'Erythromycin',
	'CRM',
	gm.nullify_empty_string('3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OKAMYCIN 3 (Cipla)'
);

-- line #13565
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESTOMYCIN 250 (Astrazeneca)',
	'Erythromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESTOMYCIN 250 (Astrazeneca)'
);

-- line #13566
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALTHROX 100 (Cadila Ph.)',
	'Erythromycin Stearate',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALTHROX 100 (Cadila Ph.)'
);

-- line #13567
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALTHROX 250 (Cadila Ph.)',
	'Erythromycin Stearate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALTHROX 250 (Cadila Ph.)'
);

-- line #13568
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMTHROCIN 125 (Nicholas)',
	'Erythromycin Stearate',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMTHROCIN 125 (Nicholas)'
);

-- line #13569
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMTHROCIN 250 (Nicholas)',
	'Erythromycin Stearate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMTHROCIN 250 (Nicholas)'
);

-- line #13570
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERASE 250 (Ind-Swift)',
	'Erythromycin Stearate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERASE 250 (Ind-Swift)'
);

-- line #13571
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERYTHROCIN 100 (Abbott)',
	'Erythromycin Stearate',
	'DPS',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERYTHROCIN 100 (Abbott)'
);

-- line #13572
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERYTHROCIN FT 100 (Abbott)',
	'Erythromycin Stearate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERYTHROCIN FT 100 (Abbott)'
);

-- line #13573
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERYTHROCIN FT 250 (Abbott)',
	'Erythromycin Stearate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERYTHROCIN FT 250 (Abbott)'
);

-- line #13574
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERYTHROCIN FT 500 (Abbott)',
	'Erythromycin Stearate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERYTHROCIN FT 500 (Abbott)'
);

-- line #13575
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERYTHROCIN 400 (Abbott)',
	'Erythromycin Stearate',
	'GRAN',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERYTHROCIN 400 (Abbott)'
);

-- line #13576
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERYTHROCIN 125 (Abbott)',
	'Erythromycin Stearate',
	'GRAN/SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERYTHROCIN 125 (Abbott)'
);

-- line #13577
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERYTHRO 250 (AIMCO PH.)',
	'Erythromycin Stearate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERYTHRO 250 (AIMCO PH.)'
);

-- line #13578
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETROCIN 100 (Dolphin)',
	'Erythromycin Stearate',
	'D.SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETROCIN 100 (Dolphin)'
);

-- line #13579
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETROCIN 250 (Dolphin)',
	'Erythromycin Stearate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETROCIN 250 (Dolphin)'
);

-- line #13580
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'B-LIFT 3 (Wockhardt)',
	'ESAPEPTIDE B',
	'EYE CONTOUR GEL',
	gm.nullify_empty_string('3')::numeric,
	'%(PHYTALURONATE MICRO-COLLAGEN TM)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'B-LIFT 3 (Wockhardt)'
);

-- line #13581
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'B-LIFT HIM ACTIVE 7 (Wockhardt)',
	'ESAPEPTIDE B',
	'GEL',
	gm.nullify_empty_string('7')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'B-LIFT HIM ACTIVE 7 (Wockhardt)'
);

-- line #13582
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1,5', u'strength_2': u'', u'substance': u'ESARAVONE', u'always_empty': u'', u'form': u'', u'brand': u'FRASEDA', u'strength_3': u'', u'company': u'Ucb India', u'unit': u'mg'}

-- line #13583
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALWEL 5 (Zuventus)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALWEL 5 (Zuventus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALWEL 10 (Zuventus)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALWEL 10 (Zuventus)'
);

-- line #13584
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMBULAX-AD 10 (Unimarck)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMBULAX-AD 10 (Unimarck)'
);

-- line #13585
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMBULAX-AD 5 (Unimarck)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMBULAX-AD 5 (Unimarck)'
);

-- line #13586
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARTICALM 10 (CADILA)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARTICALM 10 (CADILA)'
);

-- line #13587
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARTICALM 20 (CADILA)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARTICALM 20 (CADILA)'
);

-- line #13588
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASTAL 10 (STADCHEM)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASTAL 10 (STADCHEM)'
);

-- line #13589
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BEECITAL ES 10 (Biocin Hc.)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BEECITAL ES 10 (Biocin Hc.)'
);

-- line #13590
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELEXA 10 (Cyril Ph.)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELEXA 10 (Cyril Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELEXA 20 (Cyril Ph.)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELEXA 20 (Cyril Ph.)'
);

-- line #13591
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CENSPRAM 10 (CENTRA(USV))',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CENSPRAM 10 (CENTRA(USV))'
);

-- line #13592
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CENSPRAM 20 (CENTRA(USV))',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CENSPRAM 20 (CENTRA(USV))'
);

-- line #13593
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CENSPRAM 5 (CENTRA(USV))',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CENSPRAM 5 (CENTRA(USV))'
);

-- line #13594
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CILENTRA 10 (Ranbaxy)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'20'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CILENTRA 10 (Ranbaxy)'
);

-- line #13595
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CILENTRA 5 (Ranbaxy)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CILENTRA 5 (Ranbaxy)'
);

-- line #13596
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPAMS 20 (TASMED)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPAMS 20 (TASMED)'
);

-- line #13597
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPAMS 5 (TASMED)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPAMS 5 (TASMED)'
);

-- line #13598
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPLRALEX 5 (Lundbeck)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg (OXALATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPLRALEX 5 (Lundbeck)'
);

-- line #13599
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPRALEX 10 (Lundbeck)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPRALEX 10 (Lundbeck)'
);

-- line #13600
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPRALEX 5 (Lundbeck)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPRALEX 5 (Lundbeck)'
);

-- line #13601
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITALOP-S 10 (Rpg Life)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITALOP-S 10 (Rpg Life)'
);

-- line #13602
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITALOP-S 20 (Rpg Life)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITALOP-S 20 (Rpg Life)'
);

-- line #13603
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITALOP-S 5 (Rpg Life)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITALOP-S 5 (Rpg Life)'
);

-- line #13604
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITA-S 5 (Crescent Th.)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITA-S 5 (Crescent Th.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITA-S 10 (Crescent Th.)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITA-S 10 (Crescent Th.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITA-S 20 (Crescent Th.)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITA-S 20 (Crescent Th.)'
);

-- line #13605
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITEL 20 (Mankind MAGNET)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITEL 20 (Mankind MAGNET)'
);

-- line #13606
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITEL 5 (Mankind MAGNET)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITEL 5 (Mankind MAGNET)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITEL 10 (Mankind MAGNET)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITEL 10 (Mankind MAGNET)'
);

-- line #13607
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITOFAST 10 (Glenmark)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITOFAST 10 (Glenmark)'
);

-- line #13608
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITOFAST 20 (Glenmark)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITOFAST 20 (Glenmark)'
);

-- line #13609
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITOFAST 5 (Glenmark)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITOFAST 5 (Glenmark)'
);

-- line #13610
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10', u'strength_2': u'', u'substance': u'Escitalopram', u'always_empty': u'', u'form': u'', u'brand': u'CITRAM-S', u'strength_3': u'', u'company': u'MEDIFORECE', u'unit': u'mg'}

-- line #13611
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10', u'strength_2': u'', u'substance': u'Escitalopram', u'always_empty': u'', u'form': u'', u'brand': u'COXITO S', u'strength_3': u'', u'company': u'KIVI HC.', u'unit': u'mg'}

-- line #13612
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5', u'strength_2': u'', u'substance': u'Escitalopram', u'always_empty': u'', u'form': u'', u'brand': u'COXITO S', u'strength_3': u'', u'company': u'KIVI HC.', u'unit': u'mg'}

-- line #13613
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-PRAM-S 10 (Neu-Foreva)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-PRAM-S 10 (Neu-Foreva)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-PRAM-S 20 (Neu-Foreva)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-PRAM-S 20 (Neu-Foreva)'
);

-- line #13614
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-PRAM-S 5 (Neu-Foreva)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-PRAM-S 5 (Neu-Foreva)'
);

-- line #13615
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPLAM-S 10 (Discovery M.)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPLAM-S 10 (Discovery M.)'
);

-- line #13616
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPTUNE 5 (BARODA)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPTUNE 5 (BARODA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPTUNE 10 (BARODA)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPTUNE 10 (BARODA)'
);

-- line #13617
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ECITALOP 10 (EAST WEST)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ECITALOP 10 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ECITALOP 20 (EAST WEST)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ECITALOP 20 (EAST WEST)'
);

-- line #13618
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ECIT 10 (TALENT LAB.)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ECIT 10 (TALENT LAB.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ECIT 20 (TALENT LAB.)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ECIT 20 (TALENT LAB.)'
);

-- line #13619
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELCIT 10 (Elite Ph.)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELCIT 10 (Elite Ph.)'
);

-- line #13620
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELCIT 20 (Elite Ph.)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELCIT 20 (Elite Ph.)'
);

-- line #13621
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELCIT 5 (Elite Ph.)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELCIT 5 (Elite Ph.)'
);

-- line #13622
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESCAPE-10 10 (STRIVE PH.)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESCAPE-10 10 (STRIVE PH.)'
);

-- line #13623
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESCI 10 (ROSE LABS)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESCI 10 (ROSE LABS)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESCI 20 (ROSE LABS)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESCI 20 (ROSE LABS)'
);

-- line #13624
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESCITAPAX 10 (Relience Form.)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESCITAPAX 10 (Relience Form.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESCITAPAX 20 (Relience Form.)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESCITAPAX 20 (Relience Form.)'
);

-- line #13625
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESCITRAC 10 (MINOVA(PSYCHONOVA))',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESCITRAC 10 (MINOVA(PSYCHONOVA))'
);

-- line #13626
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESDEP 10 (Nicholas)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESDEP 10 (Nicholas)'
);

-- line #13627
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESDEP 20 (Nicholas)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESDEP 20 (Nicholas)'
);

-- line #13628
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESDEP 5 (Nicholas)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESDEP 5 (Nicholas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESDEP 10 (Nicholas)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESDEP 10 (Nicholas)'
);

-- line #13629
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESDEP 5 (Nicholas)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESDEP 5 (Nicholas)'
);

-- line #13630
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESFANCY 10 (AAMORB(ST. MORISON))',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESFANCY 10 (AAMORB(ST. MORISON))'
);

-- line #13631
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESITA 10 (NAVNIDHI LIFE)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESITA 10 (NAVNIDHI LIFE)'
);

-- line #13632
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESITO CURE 10 (AVITECH)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESITO CURE 10 (AVITECH)'
);

-- line #13633
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESITOR 10 (LA DRUG)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESITOR 10 (LA DRUG)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESITOR 20 (LA DRUG)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESITOR 20 (LA DRUG)'
);

-- line #13634
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESITOR 5 (LA DRUG)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESITOR 5 (LA DRUG)'
);

-- line #13635
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10', u'strength_2': u'', u'substance': u'Escitalopram', u'always_empty': u'', u'form': u'', u'brand': u'ESNAX', u'strength_3': u'', u'company': u'ANAX LS.', u'unit': u'mg'}

-- line #13636
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'Escitalopram', u'always_empty': u'', u'form': u'', u'brand': u'ESNAX', u'strength_3': u'', u'company': u'ANAX LS.', u'unit': u'mg'}

-- line #13637
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESOK 10 (Unichem)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESOK 10 (Unichem)'
);

-- line #13638
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESOK 20 (Unichem)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESOK 20 (Unichem)'
);

-- line #13639
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESOK 5 (Unichem)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESOK 5 (Unichem)'
);

-- line #13640
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESPAM 10 (Triton Hc.)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESPAM 10 (Triton Hc.)'
);

-- line #13641
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESPAM 20 (Triton Hc.)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESPAM 20 (Triton Hc.)'
);

-- line #13642
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESTA 10 (D.D. PH.)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESTA 10 (D.D. PH.)'
);

-- line #13643
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESTEEM 10 (Crystal Ph.)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESTEEM 10 (Crystal Ph.)'
);

-- line #13644
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESTILO 5 (ALPHA TH.)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESTILO 5 (ALPHA TH.)'
);

-- line #13645
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESTILO 5 (Theo Ph.)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESTILO 5 (Theo Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESTILO 10 (Theo Ph.)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESTILO 10 (Theo Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESTILO 20 (Theo Ph.)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESTILO 20 (Theo Ph.)'
);

-- line #13646
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESTODEP-10 10 (BCC HC.)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESTODEP-10 10 (BCC HC.)'
);

-- line #13647
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESTODEP-5 5 (BCC HC.)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESTODEP-5 5 (BCC HC.)'
);

-- line #13648
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESTOMINE 10 (PSYCOREM)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESTOMINE 10 (PSYCOREM)'
);

-- line #13649
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESTOMINE 20 (PSYCOREM)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESTOMINE 20 (PSYCOREM)'
);

-- line #13650
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESTOMINE 5 (PSYCOREM)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESTOMINE 5 (PSYCOREM)'
);

-- line #13651
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETILOPRAM-10 10 (Macleods)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETILOPRAM-10 10 (Macleods)'
);

-- line #13652
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETILOPRAM-5 5 (Macleods)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETILOPRAM-5 5 (Macleods)'
);

-- line #13653
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXCITA 5 (Elder)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXCITA 5 (Elder)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXCITA 10 (Elder)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXCITA 10 (Elder)'
);

-- line #13654
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EZEEPAM 10 (ERIS LIFE)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EZEEPAM 10 (ERIS LIFE)'
);

-- line #13655
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EZEEPAM 20 (ERIS LIFE)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EZEEPAM 20 (ERIS LIFE)'
);

-- line #13656
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EZEEPAM 5 (ERIS LIFE)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EZEEPAM 5 (ERIS LIFE)'
);

-- line #13657
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FELIZ-S 10 (Torrent)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FELIZ-S 10 (Torrent)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FELIZ-S 20 (Torrent)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FELIZ-S 20 (Torrent)'
);

-- line #13658
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FELIZ-S 5 (Torrent)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FELIZ-S 5 (Torrent)'
);

-- line #13659
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIRSITO 10 (Zydus N.S.)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIRSITO 10 (Zydus N.S.)'
);

-- line #13660
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIRSITO 20 (Zydus N.S.)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIRSITO 20 (Zydus N.S.)'
);

-- line #13661
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIRSITO 5 (Zydus N.S.)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIRSITO 5 (Zydus N.S.)'
);

-- line #13662
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FREEDIP 10 (HBC LIFESCIENCE)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FREEDIP 10 (HBC LIFESCIENCE)'
);

-- line #13663
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GALOP 10 (Emcure)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GALOP 10 (Emcure)'
);

-- line #13664
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GALOP 5 (Emcure)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GALOP 5 (Emcure)'
);

-- line #13665
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GERIPRAM 10 (GERRYSUN PH.)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GERIPRAM 10 (GERRYSUN PH.)'
);

-- line #13666
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JOLIVEL 10 (Torrent)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JOLIVEL 10 (Torrent)'
);

-- line #13667
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JOLIVEL 20 (Torrent)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JOLIVEL 20 (Torrent)'
);

-- line #13668
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JOLIVEL 5 (Torrent)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JOLIVEL 5 (Torrent)'
);

-- line #13669
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Escitalopram', u'always_empty': u'', u'form': u'TAB', u'brand': u'JOPRAM', u'strength_3': u'', u'company': u"D.R.John''S", u'unit': u''}

-- line #13670
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEWCITA 10 (ALKEM)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEWCITA 10 (ALKEM)'
);

-- line #13671
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEWCITA 20 (ALKEM)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEWCITA 20 (ALKEM)'
);

-- line #13672
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEWCITA 5 (ALKEM)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEWCITA 5 (ALKEM)'
);

-- line #13673
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEXITO 20 (Sun)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEXITO 20 (Sun)'
);

-- line #13674
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEXITO 5 (Sun)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEXITO 5 (Sun)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEXITO 10 (Sun)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEXITO 10 (Sun)'
);

-- line #13675
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRACIDEP-S 10 (Aarpik Ph.)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'20'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRACIDEP-S 10 (Aarpik Ph.)'
);

-- line #13676
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRASILEX 10 (MOLEKULE)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRASILEX 10 (MOLEKULE)'
);

-- line #13677
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRASILEX 20 (MOLEKULE)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRASILEX 20 (MOLEKULE)'
);

-- line #13678
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRASILEX 5 (MOLEKULE)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRASILEX 5 (MOLEKULE)'
);

-- line #13679
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIDEP-S 10 (MOVA PH.)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIDEP-S 10 (MOVA PH.)'
);

-- line #13680
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIDEP-S 20 (MOVA PH.)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIDEP-S 20 (MOVA PH.)'
);

-- line #13681
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RECITA 10 (Ipca)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RECITA 10 (Ipca)'
);

-- line #13682
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RECITA 20 (Ipca)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RECITA 20 (Ipca)'
);

-- line #13683
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RECITA 5 (Ipca)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RECITA 5 (Ipca)'
);

-- line #13684
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REXIPRA 20 (Intas)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REXIPRA 20 (Intas)'
);

-- line #13685
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REXIPRA 5 (Intas)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REXIPRA 5 (Intas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REXIPRA 10 (Intas)',
	'Escitalopram',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REXIPRA 10 (Intas)'
);

-- line #13686
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESLICAR 400 (EMCURE)',
	'ESLICARBAZEPINE',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESLICAR 400 (EMCURE)'
);

-- line #13687
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESLICAR 800 (EMCURE)',
	'ESLICARBAZEPINE',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESLICAR 800 (EMCURE)'
);

-- line #13688
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESLIFY 400 (Torrent)',
	'ESLICARBAZEPINE',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESLIFY 400 (Torrent)'
);

-- line #13689
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESLIFY 800 (Torrent)',
	'ESLICARBAZEPINE',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESLIFY 800 (Torrent)'
);

-- line #13690
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDESMO 100 (SG PH.)',
	'ESMOLOL',
	'VIAL',
	gm.nullify_empty_string('100')::numeric,
	'mg/10ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDESMO 100 (SG PH.)'
);

-- line #13691
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'ESMOLOL', u'always_empty': u'', u'form': u'INJ', u'brand': u'ESMOCARD', u'strength_3': u'', u'company': u'Troikaa', u'unit': u''}

-- line #13692
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESOCARD 100 (Samarth)',
	'Esmolol',
	'V',
	gm.nullify_empty_string('100')::numeric,
	'mg/10ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESOCARD 100 (Samarth)'
);

-- line #13693
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MINIBLOCK 2500 (U S V)',
	'Esmolol',
	'V/AMP',
	gm.nullify_empty_string('2500')::numeric,
	'mg/10ML/100'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MINIBLOCK 2500 (U S V)'
);

-- line #13694
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOTACH 10 (Neon)',
	'ESMOLOL',
	'V',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOTACH 10 (Neon)'
);

-- line #13695
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CESO 20 (Comed)',
	'Esomeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg(MAG. TRIHYDRT.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CESO 20 (Comed)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CESO 40 (Comed)',
	'Esomeprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg(MAG. TRIHYDRT.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CESO 40 (Comed)'
);

-- line #13696
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'Esomeprazole', u'always_empty': u'', u'form': u'', u'brand': u'EROZ FAST', u'strength_3': u'', u'company': u'Glenmark', u'unit': u'mg(WITH SOD.BICARB. AS BUFFER)'}

-- line #13697
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40', u'strength_2': u'', u'substance': u'Esomeprazole', u'always_empty': u'', u'form': u'', u'brand': u'EROZ FAST', u'strength_3': u'', u'company': u'Glenmark', u'unit': u'mg(WITH SOD.BICARB. AS BUFFER)'}

-- line #13698
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ES CARE 40 (Comed)',
	'Esomeprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ES CARE 40 (Comed)'
);

-- line #13699
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESKIMO 20 (Themis Med.)',
	'Esomeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESKIMO 20 (Themis Med.)'
);

-- line #13700
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESKIMO 40 (Themis Med.)',
	'Esomeprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESKIMO 40 (Themis Med.)'
);

-- line #13701
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESMOCAR 20 (MEDISYS)',
	'Esomeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESMOCAR 20 (MEDISYS)'
);

-- line #13702
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESOCOOL 20 (P C INDIA)',
	'Esomeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESOCOOL 20 (P C INDIA)'
);

-- line #13703
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESOCOOL 40 (P C INDIA)',
	'Esomeprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESOCOOL 40 (P C INDIA)'
);

-- line #13704
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ES 20 (Nicholas)',
	'Esomeprazole',
	'OD TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ES 20 (Nicholas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ES 40 (Nicholas)',
	'Esomeprazole',
	'OD TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ES 40 (Nicholas)'
);

-- line #13705
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESOFAG 20 (Micro Labs)',
	'Esomeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESOFAG 20 (Micro Labs)'
);

-- line #13706
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESOFAG 40 (Micro Labs)',
	'Esomeprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESOFAG 40 (Micro Labs)'
);

-- line #13707
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESOFLO 20 (Intra Lab)',
	'Esomeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESOFLO 20 (Intra Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESOFLO 40 (Intra Lab)',
	'Esomeprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESOFLO 40 (Intra Lab)'
);

-- line #13708
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESOKEM 20 (ALKEM)',
	'Esomeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESOKEM 20 (ALKEM)'
);

-- line #13709
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESOKEM 40 (ALKEM)',
	'Esomeprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESOKEM 40 (ALKEM)'
);

-- line #13710
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESOMAC 20 (Cipla)',
	'Esomeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESOMAC 20 (Cipla)'
);

-- line #13711
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESOMAC 40 (Cipla)',
	'Esomeprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESOMAC 40 (Cipla)'
);

-- line #13712
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESOMEZOLE 40 (MODHIKE)',
	'Esomeprazole',
	'CAP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESOMEZOLE 40 (MODHIKE)'
);

-- line #13713
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESOPRZ 40 (ZYPHARS PH.)',
	'Esomeprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESOPRZ 40 (ZYPHARS PH.)'
);

-- line #13714
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'Esomeprazole', u'always_empty': u'', u'form': u'', u'brand': u'ESOPRZ', u'strength_3': u'', u'company': u'ZYPHARS PH.', u'unit': u'mg'}

-- line #13715
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40', u'strength_2': u'', u'substance': u'Esomeprazole', u'always_empty': u'', u'form': u'', u'brand': u'ESOPRZ', u'strength_3': u'', u'company': u'ZYPHARS PH.', u'unit': u'mg'}

-- line #13716
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESOREST 20 (Centaur)',
	'Esomeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESOREST 20 (Centaur)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESOREST 40 (Centaur)',
	'Esomeprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESOREST 40 (Centaur)'
);

-- line #13717
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESOTRAX 20 (Cadila Ph.)',
	'Esomeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESOTRAX 20 (Cadila Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESOTRAX 40 (Cadila Ph.)',
	'Esomeprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESOTRAX 40 (Cadila Ph.)'
);

-- line #13718
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESOZEN 40 (UNIMARK REM.)',
	'Esomeprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESOZEN 40 (UNIMARK REM.)'
);

-- line #13719
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESOZ 40 (Glenmark)',
	'Esomeprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESOZ 40 (Glenmark)'
);

-- line #13720
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESOZ 20 (Glenmark)',
	'Esomeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESOZ 20 (Glenmark)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESOZ 40 (Glenmark)',
	'Esomeprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESOZ 40 (Glenmark)'
);

-- line #13721
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESPRA 20 (Zydus Cadila)',
	'Esomeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESPRA 20 (Zydus Cadila)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESPRA 40 (Zydus Cadila)',
	'Esomeprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESPRA 40 (Zydus Cadila)'
);

-- line #13722
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESTAB 20 (Indoco Rem.)',
	'Esomeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESTAB 20 (Indoco Rem.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESTAB 40 (Indoco Rem.)',
	'Esomeprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESTAB 40 (Indoco Rem.)'
);

-- line #13723
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INNOTOP ES 40 (INNOVA LIFESCI.)',
	'Esomeprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INNOTOP ES 40 (INNOVA LIFESCI.)'
);

-- line #13724
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IZRA 20 (Unichem)',
	'Esomeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IZRA 20 (Unichem)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IZRA 40 (Unichem)',
	'Esomeprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IZRA 40 (Unichem)'
);

-- line #13725
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IZRA 40 (Unichem)',
	'Esomeprazole',
	'VIAL',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IZRA 40 (Unichem)'
);

-- line #13726
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEXIUM-40 40 (Systopic)',
	'Esomeprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEXIUM-40 40 (Systopic)'
);

-- line #13727
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40', u'strength_2': u'', u'substance': u'Esomeprazole', u'always_empty': u'', u'form': u'', u'brand': u'NEKSIUM IV', u'strength_3': u'', u'company': u'Astrazeneca', u'unit': u'mg'}

-- line #13728
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEKSIUM 20 (Astrazeneca)',
	'Esomeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEKSIUM 20 (Astrazeneca)'
);

-- line #13729
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEKSIUM 40 (Astrazeneca)',
	'Esomeprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEKSIUM 40 (Astrazeneca)'
);

-- line #13730
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEXPRO FAST 20 (TORRENT)',
	'Esomeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEXPRO FAST 20 (TORRENT)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEXPRO FAST 40 (TORRENT)',
	'Esomeprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEXPRO FAST 40 (TORRENT)'
);

-- line #13731
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40', u'strength_2': u'', u'substance': u'Esomeprazole', u'always_empty': u'', u'form': u'', u'brand': u'NEXPRO IV', u'strength_3': u'', u'company': u'Torrent', u'unit': u'mg'}

-- line #13732
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEXPRO 20 (Torrent)',
	'Esomeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEXPRO 20 (Torrent)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEXPRO 40 (Torrent)',
	'Esomeprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEXPRO 40 (Torrent)'
);

-- line #13733
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NULOC 20 (Bergen)',
	'Esomeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NULOC 20 (Bergen)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NULOC 40 (Bergen)',
	'Esomeprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NULOC 40 (Bergen)'
);

-- line #13734
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMIPURE 40 (Mankind)',
	'Esomeprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMIPURE 40 (Mankind)'
);

-- line #13735
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RACIPER 40 (Ranbaxy)',
	'Esomeprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RACIPER 40 (Ranbaxy)'
);

-- line #13736
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RACIPER 40 (Ranbaxy)',
	'Esomeprazole',
	'SF',
	gm.nullify_empty_string('40')::numeric,
	'mg(WITH SOD.BICARB.AS BUFFER)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RACIPER 40 (Ranbaxy)'
);

-- line #13737
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RACIPER 20 (Ranbaxy)',
	'Esomeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RACIPER 20 (Ranbaxy)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RACIPER 40 (Ranbaxy)',
	'Esomeprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RACIPER 40 (Ranbaxy)'
);

-- line #13738
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVIGEL 0.1 (Win Medicare)',
	'Estradiol',
	'GEL',
	gm.nullify_empty_string('0.1')::numeric,
	'% W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVIGEL 0.1 (Win Medicare)'
);

-- line #13739
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Estradiol', u'always_empty': u'', u'form': u'SAC', u'brand': u'DIVIGEL', u'strength_3': u'', u'company': u'Win-Medicare', u'unit': u''}

-- line #13740
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'E2 35 (Sun)',
	'Estradiol',
	'GEL',
	gm.nullify_empty_string('35')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'E2 35 (Sun)'
);

-- line #13741
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'E-D VAL-2 2 (Svizera)',
	'Estradiol',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg(VALERATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'E-D VAL-2 2 (Svizera)'
);

-- line #13742
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,375', u'strength_2': u'', u'substance': u'Estradiol', u'always_empty': u'', u'form': u'', u'brand': u'ESTASPRAY', u'strength_3': u'', u'company': u'Cipla', u'unit': u'mg(ABSOLUTE ALCOHOL CONT 77.23'}

-- line #13743
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1,5', u'strength_2': u'', u'substance': u'Estradiol', u'always_empty': u'', u'form': u'', u'brand': u'ESTRADERM MX PATCH', u'strength_3': u'', u'company': u'Novartis', u'unit': u'mg'}

-- line #13744
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EVADIOL 2 (Intas)',
	'Estradiol',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg(VALERATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EVADIOL 2 (Intas)'
);

-- line #13745
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2.5MCG', u'strength_2': u'', u'substance': u'estradiol', u'always_empty': u'', u'form': u'TAB', u'brand': u'E VAG', u'strength_3': u'', u'company': u'SUN', u'unit': u''}

-- line #13746
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EVALON 1 (Infar)',
	'Estradiol',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'mg/G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EVALON 1 (Infar)'
);

-- line #13747
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EVATONE-1 1 (Serum Int.)',
	'Estradiol',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg (VALERATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EVATONE-1 1 (Serum Int.)'
);

-- line #13748
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EVATONE-2 2 (Serum Int.)',
	'Estradiol',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg (VALERATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EVATONE-2 2 (Serum Int.)'
);

-- line #13749
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EVYA 2 (WEST COAST)',
	'Estradiol',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg (VALERATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EVYA 2 (WEST COAST)'
);

-- line #13750
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROGYNOVA 1 (German R.)',
	'Estradiol',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg(VALERATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROGYNOVA 1 (German R.)'
);

-- line #13751
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROGYNOVA 2 (German R.)',
	'Estradiol',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg(VALERATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROGYNOVA 2 (German R.)'
);

-- line #13752
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESTRAMIN 140 (Samarth)',
	'ESTRAMUSTINE',
	'CAP',
	gm.nullify_empty_string('140')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESTRAMIN 140 (Samarth)'
);

-- line #13753
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BEXOMER 1 (J. & J.)',
	'ESZOPICLONE',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BEXOMER 1 (J. & J.)'
);

-- line #13754
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BEXOMER 2 (J. & J.)',
	'ESZOPICLONE',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BEXOMER 2 (J. & J.)'
);

-- line #13755
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESENTRA 1 (Intas)',
	'ESZOPICLONE',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESENTRA 1 (Intas)'
);

-- line #13756
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESENTRA 2 (Intas)',
	'ESZOPICLONE',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESENTRA 2 (Intas)'
);

-- line #13757
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESENTRA 3 (Intas)',
	'ESZOPICLONE',
	'TAB',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESENTRA 3 (Intas)'
);

-- line #13758
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FULNITE 1 (SUN)',
	'ESZOPICLONE',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FULNITE 1 (SUN)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FULNITE 2 (SUN)',
	'ESZOPICLONE',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FULNITE 2 (SUN)'
);

-- line #13759
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JUSTSLEEP 1 (Emcure)',
	'ESZOPICLONE',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JUSTSLEEP 1 (Emcure)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JUSTSLEEP 2 (Emcure)',
	'ESZOPICLONE',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JUSTSLEEP 2 (Emcure)'
);

-- line #13760
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JUSTSLEEP 3 (Emcure)',
	'ESZOPICLONE',
	'TAB',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JUSTSLEEP 3 (Emcure)'
);

-- line #13761
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENBREL 25 (Wyeth)',
	'ETANERCEPT',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/0.5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENBREL 25 (Wyeth)'
);

-- line #13762
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENBREL 50 (Wyeth)',
	'ETANERCEPT',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENBREL 50 (Wyeth)'
);

-- line #13763
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENBROL 25 (TAJ PH.)',
	'ETANERCEPT',
	'VIAL',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENBROL 25 (TAJ PH.)'
);

-- line #13764
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GOLDAR 3 (Zydus Cadila)',
	'ETANERCEPT',
	'TAB',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GOLDAR 3 (Zydus Cadila)'
);

-- line #13765
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ABORCIN 1 (Samarth)',
	'Ethacridine Lactate',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ABORCIN 1 (Samarth)'
);

-- line #13766
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ABORTIL 1 (Troikaa)',
	'Ethacridine Lactate',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ABORTIL 1 (Troikaa)'
);

-- line #13767
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMCREDIL 1 (Neu-Foreva)',
	'Ethacridine Lactate',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMCREDIL 1 (Neu-Foreva)'
);

-- line #13768
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMTIPIN 1 (Ophthal R.)',
	'Ethacridine Lactate',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMTIPIN 1 (Ophthal R.)'
);

-- line #13769
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDUCIN 1 (Noir)',
	'Ethacridine Lactate',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDUCIN 1 (Noir)'
);

-- line #13770
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LACTARINE 1 (Intracin)',
	'Ethacridine Lactate',
	'VIAL',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LACTARINE 1 (Intracin)'
);

-- line #13771
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBUTOL 200 (Alkem)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBUTOL 200 (Alkem)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBUTOL 400 (Alkem)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBUTOL 400 (Alkem)'
);

-- line #13772
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBUTOL 800 (Alkem)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBUTOL 800 (Alkem)'
);

-- line #13773
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMITOL 800 (AIMCO PH.)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMITOL 800 (AIMCO PH.)'
);

-- line #13774
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANACOX-E 800 (Ajanta Ph.)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANACOX-E 800 (Ajanta Ph.)'
);

-- line #13775
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANBUTOL 800 (PSYCOREM)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANBUTOL 800 (PSYCOREM)'
);

-- line #13776
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ethambutol', u'always_empty': u'', u'form': u'TAB', u'brand': u'CAVIBUTOL', u'strength_3': u'', u'company': u'Merind', u'unit': u''}

-- line #13777
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAVIBUTOL 200 (Merind)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAVIBUTOL 200 (Merind)'
);

-- line #13778
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAVIBUTOL 400 (Merind)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAVIBUTOL 400 (Merind)'
);

-- line #13779
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAVIBUTOL 600 (Merind)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAVIBUTOL 600 (Merind)'
);

-- line #13780
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAVIBUTOL 800 (Merind)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAVIBUTOL 800 (Merind)'
);

-- line #13781
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COLBUTOL 800 (Ind-Swift)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COLBUTOL 800 (Ind-Swift)'
);

-- line #13782
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ethambutol', u'always_empty': u'', u'form': u'TAB', u'brand': u'COMBUTOL', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #13783
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COMBUTOL 200 (Lupin)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COMBUTOL 200 (Lupin)'
);

-- line #13784
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COMBUTOL 400 (Lupin)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COMBUTOL 400 (Lupin)'
);

-- line #13785
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COMBUTOL 600 (Lupin)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COMBUTOL 600 (Lupin)'
);

-- line #13786
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COMBUTOL 800 (Lupin)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COMBUTOL 800 (Lupin)'
);

-- line #13787
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ethambutol', u'always_empty': u'', u'form': u'TAB', u'brand': u'CONCOX', u'strength_3': u'', u'company': u'Concept', u'unit': u''}

-- line #13788
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONCOX 800 (Concept)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONCOX 800 (Concept)'
);

-- line #13789
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COXUTOL 400 (Stadmed)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COXUTOL 400 (Stadmed)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COXUTOL 800 (Stadmed)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COXUTOL 800 (Stadmed)'
);

-- line #13790
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYBITOL 800 (Dynamic)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYBITOL 800 (Dynamic)'
);

-- line #13791
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EBUTOL 400 (Novartis)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EBUTOL 400 (Novartis)'
);

-- line #13792
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EBUTOL 800 (Novartis)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EBUTOL 800 (Novartis)'
);

-- line #13793
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ethambutol', u'always_empty': u'', u'form': u'TAB', u'brand': u'ECOX', u'strength_3': u'', u'company': u'Macleods', u'unit': u''}

-- line #13794
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ECOX 800 (Macleods)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ECOX 800 (Macleods)'
);

-- line #13795
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMIBUTOL 800 (Emil Ph.)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMIBUTOL 800 (Emil Ph.)'
);

-- line #13796
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMTB 800 (Emcure)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMTB 800 (Emcure)'
);

-- line #13797
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHAMOL 800 (Auroma Life)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHAMOL 800 (Auroma Life)'
);

-- line #13798
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHOX 800 (TALENT LAB.)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHOX 800 (TALENT LAB.)'
);

-- line #13799
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHRIK 800 (Lanark)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHRIK 800 (Lanark)'
);

-- line #13800
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETIBI 200 (Pharmed)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETIBI 200 (Pharmed)'
);

-- line #13801
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETIBI 400 (Pharmed)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETIBI 400 (Pharmed)'
);

-- line #13802
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAIRBUTOL 800 (Medico)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAIRBUTOL 800 (Medico)'
);

-- line #13803
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IBUTOL 800 (LUSTRE)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IBUTOL 800 (LUSTRE)'
);

-- line #13804
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISOTOL 800 (Zee Lab)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISOTOL 800 (Zee Lab)'
);

-- line #13805
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'J-BUTOL 400 (Jaywin)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'J-BUTOL 400 (Jaywin)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'J-BUTOL 600 (Jaywin)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'J-BUTOL 600 (Jaywin)'
);

-- line #13806
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'J-BUTOL 800 (Jaywin)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'J-BUTOL 800 (Jaywin)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'J-BUTOL 1000 (Jaywin)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'J-BUTOL 1000 (Jaywin)'
);

-- line #13807
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KOKBUTOL 800 (Dial Ph.)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KOKBUTOL 800 (Dial Ph.)'
);

-- line #13808
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ethambutol', u'always_empty': u'', u'form': u'TAB', u'brand': u'KOXI', u'strength_3': u'', u'company': u'Shreya', u'unit': u''}

-- line #13809
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KOXI 400 (Shreya)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KOXI 400 (Shreya)'
);

-- line #13810
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KOXI 600 (Shreya)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KOXI 600 (Shreya)'
);

-- line #13811
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KOXI 800 (Shreya)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KOXI 800 (Shreya)'
);

-- line #13812
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ethambutol', u'always_empty': u'', u'form': u'TAB', u'brand': u'KOXYLAR', u'strength_3': u'', u'company': u'Lark Lab', u'unit': u''}

-- line #13813
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KOXYLAR 200 (Lark Lab)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KOXYLAR 200 (Lark Lab)'
);

-- line #13814
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KOXYLAR 400 (Lark Lab)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KOXYLAR 400 (Lark Lab)'
);

-- line #13815
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KOXYLAR 600 (Lark Lab)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KOXYLAR 600 (Lark Lab)'
);

-- line #13816
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KOXYLAR 800 (Lark Lab)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KOXYLAR 800 (Lark Lab)'
);

-- line #13817
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIFEBUTOL 600 (Life Line)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIFEBUTOL 600 (Life Line)'
);

-- line #13818
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIFEBUTOL 800 (Life Line)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIFEBUTOL 800 (Life Line)'
);

-- line #13819
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LY BUTOL 400 (HETERO HC.)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LY BUTOL 400 (HETERO HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LY BUTOL 800 (HETERO HC.)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LY BUTOL 800 (HETERO HC.)'
);

-- line #13820
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYNABUTOL 800 (Lancer)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYNABUTOL 800 (Lancer)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYNABUTOL 1000 (Lancer)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYNABUTOL 1000 (Lancer)'
);

-- line #13821
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANBUTOL 400 (Maan)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANBUTOL 400 (Maan)'
);

-- line #13822
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANBUTOL 600 (Maan)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANBUTOL 600 (Maan)'
);

-- line #13823
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANBUTOL 800 (Maan)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANBUTOL 800 (Maan)'
);

-- line #13824
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MARCOBUTOL 1000 (Marc Lab)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MARCOBUTOL 1000 (Marc Lab)'
);

-- line #13825
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MARCOBUTOL 400 (Marc Lab)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MARCOBUTOL 400 (Marc Lab)'
);

-- line #13826
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MARCOBUTOL 800 (Marc Lab)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MARCOBUTOL 800 (Marc Lab)'
);

-- line #13827
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MITT 800 (Orison Ph.)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MITT 800 (Orison Ph.)'
);

-- line #13828
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYAMBUTOL 200 (Wyeth)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYAMBUTOL 200 (Wyeth)'
);

-- line #13829
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYAMBUTOL 400 (Wyeth)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYAMBUTOL 400 (Wyeth)'
);

-- line #13830
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYAMBUTOL 800 (Wyeth)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYAMBUTOL 800 (Wyeth)'
);

-- line #13831
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCOBACK 800 (Cipla)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCOBACK 800 (Cipla)'
);

-- line #13832
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ethambutol', u'always_empty': u'', u'form': u'CAP', u'brand': u'MYCOBUTOL', u'strength_3': u'', u'company': u'Le Sante', u'unit': u''}

-- line #13833
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCOBUTOL 200 (Le Sante)',
	'Ethambutol',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCOBUTOL 200 (Le Sante)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCOBUTOL 400 (Le Sante)',
	'Ethambutol',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCOBUTOL 400 (Le Sante)'
);

-- line #13834
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCOBUTOL 600 (Le Sante)',
	'Ethambutol',
	'CAP',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCOBUTOL 600 (Le Sante)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCOBUTOL 800 (Le Sante)',
	'Ethambutol',
	'CAP',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCOBUTOL 800 (Le Sante)'
);

-- line #13835
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCOBUTOL 1000 (Le Sante)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCOBUTOL 1000 (Le Sante)'
);

-- line #13836
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCOBUTOL 200 (Le Sante)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCOBUTOL 200 (Le Sante)'
);

-- line #13837
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCOBUTOL 400 (Le Sante)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCOBUTOL 400 (Le Sante)'
);

-- line #13838
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCOBUTOL 600 (Le Sante)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCOBUTOL 600 (Le Sante)'
);

-- line #13839
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCOBUTOL 800 (Le Sante)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCOBUTOL 800 (Le Sante)'
);

-- line #13840
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ethambutol', u'always_empty': u'', u'form': u'TAB', u'brand': u'MYCOSTAT', u'strength_3': u'', u'company': u'Overseas Hc.', u'unit': u''}

-- line #13841
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCOSTAT 800 (Overseas Hc.)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCOSTAT 800 (Overseas Hc.)'
);

-- line #13842
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCOXOL 800 (Unicure)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCOXOL 800 (Unicure)'
);

-- line #13843
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCOX 800 (Olcare)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCOX 800 (Olcare)'
);

-- line #13844
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PALBUTOL 800 (Patson)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PALBUTOL 800 (Patson)'
);

-- line #13845
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PDR-825 825 (Maneesh)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('825')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PDR-825 825 (Maneesh)'
);

-- line #13846
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHARBUTOL 800 (PHARMIN)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHARBUTOL 800 (PHARMIN)'
);

-- line #13847
-- ignoring line: field [strength_1] not numeric: >>>1G<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'800', u'substance': u'Ethambutol', u'always_empty': u'', u'form': u'TAB', u'brand': u'RADIBUTOL G/800', u'strength_3': u'', u'company': u'Radicura', u'unit': u'mg'}

-- line #13848
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RETHAM 800 (FORTUNE HC.)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RETHAM 800 (FORTUNE HC.)'
);

-- line #13849
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RICOBUTOL 800 (Aquila)',
	'Ethambutol',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RICOBUTOL 800 (Aquila)'
);

-- line #13850
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'2 PIN 125 (Mefro Ph.)',
	'Ethamsylate',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '2 PIN 125 (Mefro Ph.)'
);

-- line #13851
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALSTAT 250 (Albert D.)',
	'Ethamsylate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALSTAT 250 (Albert D.)'
);

-- line #13852
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALSTAT 250 (Albert D.)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALSTAT 250 (Albert D.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALSTAT 500 (Albert D.)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALSTAT 500 (Albert D.)'
);

-- line #13853
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AROCLOT 250 (ARLOP PH.)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AROCLOT 250 (ARLOP PH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AROCLOT 500 (ARLOP PH.)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AROCLOT 500 (ARLOP PH.)'
);

-- line #13854
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLOC 250 (Finecure)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLOC 250 (Finecure)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLOC 500 (Finecure)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLOC 500 (Finecure)'
);

-- line #13855
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BOTROSTAT 250 (Juggat)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BOTROSTAT 250 (Juggat)'
);

-- line #13856
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAPICARE 250 (Evacare)',
	'Ethamsylate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAPICARE 250 (Evacare)'
);

-- line #13857
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAPICARE 250 (Evacare)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAPICARE 250 (Evacare)'
);

-- line #13858
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAPICARE 500 (Evacare)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAPICARE 500 (Evacare)'
);

-- line #13859
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAPILYTE 250 (Corona)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAPILYTE 250 (Corona)'
);

-- line #13860
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAPSTAT 250 (Hygeia Ph.)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAPSTAT 250 (Hygeia Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAPSTAT 500 (Hygeia Ph.)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAPSTAT 500 (Hygeia Ph.)'
);

-- line #13861
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOTAWIN 250 (Bestochem)',
	'Ethamsylate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOTAWIN 250 (Bestochem)'
);

-- line #13862
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOTAWIN 250 (Bestochem)',
	'Ethamsylate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOTAWIN 250 (Bestochem)'
);

-- line #13863
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOTAWIN 250 (Bestochem)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOTAWIN 250 (Bestochem)'
);

-- line #13864
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOTAWIN 500 (Bestochem)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOTAWIN 500 (Bestochem)'
);

-- line #13865
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COSKLOT 250 (Cfl Ph.)',
	'Ethamsylate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COSKLOT 250 (Cfl Ph.)'
);

-- line #13866
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COSKLOT 250 (Cfl Ph.)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COSKLOT 250 (Cfl Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COSKLOT 500 (Cfl Ph.)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COSKLOT 500 (Cfl Ph.)'
);

-- line #13867
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-SYLATE 250 (Corona)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-SYLATE 250 (Corona)'
);

-- line #13868
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CULOC 500 (Cubit Hc.)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CULOC 500 (Cubit Hc.)'
);

-- line #13869
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICYNENE 125 (Dr.Reddy''S)',
	'Ethamsylate',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICYNENE 125 (Dr.Reddy''S)'
);

-- line #13870
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICYNENE 250 (Dr.Reddy''S)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICYNENE 250 (Dr.Reddy''S)'
);

-- line #13871
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICYNENE 500 (Dr.Reddy''S)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICYNENE 500 (Dr.Reddy''S)'
);

-- line #13872
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DISYLATE 250 (Osper)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DISYLATE 250 (Osper)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DISYLATE 500 (Osper)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DISYLATE 500 (Osper)'
);

-- line #13873
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'D-SYLATE 125 (DIVINE LAB.)',
	'Ethamsylate',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'D-SYLATE 125 (DIVINE LAB.)'
);

-- line #13874
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EISI 250 (Indica)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EISI 250 (Indica)'
);

-- line #13875
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EISI 500 (Indica)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EISI 500 (Indica)'
);

-- line #13876
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EITH 500 (Chemo Bio.)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EITH 500 (Chemo Bio.)'
);

-- line #13877
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EKLOT 250 (Kontest)',
	'Ethamsylate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EKLOT 250 (Kontest)'
);

-- line #13878
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EKLOT 250 (Kontest)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EKLOT 250 (Kontest)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EKLOT 500 (Kontest)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EKLOT 500 (Kontest)'
);

-- line #13879
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELATE 250 (CHEMO HC.)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELATE 250 (CHEMO HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELATE 500 (CHEMO HC.)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELATE 500 (CHEMO HC.)'
);

-- line #13880
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMSIL 250 (Shalman)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMSIL 250 (Shalman)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMSIL 500 (Shalman)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMSIL 500 (Shalman)'
);

-- line #13881
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENSTAC 125 (Biocin Hc.)',
	'Ethamsylate',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENSTAC 125 (Biocin Hc.)'
);

-- line #13882
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESELIN 125 (Svizera)',
	'Ethamsylate',
	'AMP',
	gm.nullify_empty_string('125')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESELIN 125 (Svizera)'
);

-- line #13883
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESELIN 250 (Svizera)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESELIN 250 (Svizera)'
);

-- line #13884
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESELIN 500 (Svizera)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESELIN 500 (Svizera)'
);

-- line #13885
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESYLATE 250 (Jackson)',
	'Ethamsylate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESYLATE 250 (Jackson)'
);

-- line #13886
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETAM 125 (D.P.P.L.)',
	'Ethamsylate',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETAM 125 (D.P.P.L.)'
);

-- line #13887
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETAM 250 (Panjon)',
	'Ethamsylate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETAM 250 (Panjon)'
);

-- line #13888
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETAM 250 (D.P.P.L.)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETAM 250 (D.P.P.L.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETAM 500 (D.P.P.L.)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETAM 500 (D.P.P.L.)'
);

-- line #13889
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETAM 250 (Panjon)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETAM 250 (Panjon)'
);

-- line #13890
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETEX 250 (Rapross)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETEX 250 (Rapross)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETEX 500 (Rapross)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETEX 500 (Rapross)'
);

-- line #13891
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETEX-T 250 (Rapross)',
	'Ethamsylate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETEX-T 250 (Rapross)'
);

-- line #13892
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHACID 125 (Stadmed)',
	'Ethamsylate',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHACID 125 (Stadmed)'
);

-- line #13893
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHACID 250 (Stadmed)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHACID 250 (Stadmed)'
);

-- line #13894
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHACID 500 (Stadmed)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHACID 500 (Stadmed)'
);

-- line #13895
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHAFY 250 (Sanify)',
	'Ethamsylate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHAFY 250 (Sanify)'
);

-- line #13896
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHAFY 500 (Sanify)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHAFY 500 (Sanify)'
);

-- line #13897
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHAKLOT 250 (Cosme Hc.)',
	'Ethamsylate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHAKLOT 250 (Cosme Hc.)'
);

-- line #13898
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHAKLOT 250 (Cosme Hc.)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHAKLOT 250 (Cosme Hc.)'
);

-- line #13899
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHAKLOT 500 (Cosme Hc.)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHAKLOT 500 (Cosme Hc.)'
);

-- line #13900
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHAMCIP 250 (Cipla)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHAMCIP 250 (Cipla)'
);

-- line #13901
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHAMCIP 500 (Cipla)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHAMCIP 500 (Cipla)'
);

-- line #13902
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHAMS 125 (Chemech)',
	'Ethamsylate',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHAMS 125 (Chemech)'
);

-- line #13903
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHAMS 250 (Chemech)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHAMS 250 (Chemech)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHAMS 500 (Chemech)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHAMS 500 (Chemech)'
);

-- line #13904
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHAMSTAT 125 (Indi Ph.)',
	'Ethamsylate',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHAMSTAT 125 (Indi Ph.)'
);

-- line #13905
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHAMSTAT 250 (Indi Ph.)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHAMSTAT 250 (Indi Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHAMSTAT 500 (Indi Ph.)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHAMSTAT 500 (Indi Ph.)'
);

-- line #13906
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHAREN 250 (Warren)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHAREN 250 (Warren)'
);

-- line #13907
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHAREN 500 (Warren)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHAREN 500 (Warren)'
);

-- line #13908
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHAS 250 (Mark)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHAS 250 (Mark)'
);

-- line #13909
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHAS 500 (Mark)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHAS 500 (Mark)'
);

-- line #13910
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHASYL 250 (F D C)',
	'Ethamsylate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHASYL 250 (F D C)'
);

-- line #13911
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHASYL 250 (F D C)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHASYL 250 (F D C)'
);

-- line #13912
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHASYL 500 (F D C)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHASYL 500 (F D C)'
);

-- line #13913
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHOLATE 250 (EAST WEST)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHOLATE 250 (EAST WEST)'
);

-- line #13914
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHOLATE 500 (EAST WEST)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHOLATE 500 (EAST WEST)'
);

-- line #13915
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHOSTIC 125 (Intracin)',
	'Ethamsylate',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHOSTIC 125 (Intracin)'
);

-- line #13916
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHYLATE 250 (Life Med.)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHYLATE 250 (Life Med.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHYLATE 500 (Life Med.)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHYLATE 500 (Life Med.)'
);

-- line #13917
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETOSYS 125 (Systopic)',
	'Ethamsylate',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETOSYS 125 (Systopic)'
);

-- line #13918
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUSTAL 125 (Cachet)',
	'Ethamsylate',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUSTAL 125 (Cachet)'
);

-- line #13919
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUSTAL 250 (Cachet)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUSTAL 250 (Cachet)'
);

-- line #13920
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUSTAL 500 (Cachet)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUSTAL 500 (Cachet)'
);

-- line #13921
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EVA CLOT 250 (RADHE BIO.)',
	'Ethamsylate',
	'TAB/INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EVA CLOT 250 (RADHE BIO.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EVA CLOT 250 (RADHE BIO.)',
	'Ethamsylate',
	'TAB/INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EVA CLOT 250 (RADHE BIO.)'
);

-- line #13922
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Ethamsylate', u'always_empty': u'', u'form': u'INJ', u'brand': u'FINCYLATE', u'strength_3': u'', u'company': u'Finesse Ph.', u'unit': u''}

-- line #13923
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOBAN 500 (Geno Ph.)',
	'Ethamsylate',
	'F. TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOBAN 500 (Geno Ph.)'
);

-- line #13924
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOBAN 250 (Geno Ph.)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOBAN 250 (Geno Ph.)'
);

-- line #13925
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRASYL 250 (Graf Lab.)',
	'Ethamsylate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRASYL 250 (Graf Lab.)'
);

-- line #13926
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRASYL 250 (Graf Lab.)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRASYL 250 (Graf Lab.)'
);

-- line #13927
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRASYL 500 (Graf Lab.)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRASYL 500 (Graf Lab.)'
);

-- line #13928
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HAEMOCI 250 (Ochoa)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HAEMOCI 250 (Ochoa)'
);

-- line #13929
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HAEMOCI 500 (Ochoa)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HAEMOCI 500 (Ochoa)'
);

-- line #13930
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HAEMOFF 250 (Merit Org.)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HAEMOFF 250 (Merit Org.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HAEMOFF 500 (Merit Org.)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HAEMOFF 500 (Merit Org.)'
);

-- line #13931
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HAEMOSYLATE 250 (Lark Lab)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HAEMOSYLATE 250 (Lark Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HAEMOSYLATE 500 (Lark Lab)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HAEMOSYLATE 500 (Lark Lab)'
);

-- line #13932
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HAEMTROL 250 (Patson)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HAEMTROL 250 (Patson)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HAEMTROL 500 (Patson)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HAEMTROL 500 (Patson)'
);

-- line #13933
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HAMODAM 250 (HALEDEW)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HAMODAM 250 (HALEDEW)'
);

-- line #13934
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEMOCLOT 250 (ETHIX HC.)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEMOCLOT 250 (ETHIX HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEMOCLOT 500 (ETHIX HC.)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEMOCLOT 500 (ETHIX HC.)'
);

-- line #13935
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEMODIL 250 (Dial Ph.)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEMODIL 250 (Dial Ph.)'
);

-- line #13936
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEMOLATE 250 (Micro Nova)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEMOLATE 250 (Micro Nova)'
);

-- line #13937
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEMOLATE 500 (Micro Nova)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEMOLATE 500 (Micro Nova)'
);

-- line #13938
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEMOSTAT 125 (Meridian)',
	'Ethamsylate',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEMOSTAT 125 (Meridian)'
);

-- line #13939
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEMOSTAT 250 (Meridian)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEMOSTAT 250 (Meridian)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEMOSTAT 500 (Meridian)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEMOSTAT 500 (Meridian)'
);

-- line #13940
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEMOSYLATE 250 (Lark Lab)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEMOSYLATE 250 (Lark Lab)'
);

-- line #13941
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEMOSYLATE 500 (Lark Lab)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEMOSYLATE 500 (Lark Lab)'
);

-- line #13942
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEMOZEN 250 (Aglowmed)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEMOZEN 250 (Aglowmed)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEMOZEN 500 (Aglowmed)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEMOZEN 500 (Aglowmed)'
);

-- line #13943
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEMSTAT 250 (Aglowmed)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEMSTAT 250 (Aglowmed)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEMSTAT 500 (Aglowmed)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEMSTAT 500 (Aglowmed)'
);

-- line #13944
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEMSYL 125 (Indoco Rem.)',
	'Ethamsylate',
	'AMP',
	gm.nullify_empty_string('125')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEMSYL 125 (Indoco Rem.)'
);

-- line #13945
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEMSYL 250 (Indoco Rem.)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEMSYL 250 (Indoco Rem.)'
);

-- line #13946
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEMSYL 500 (Indoco Rem.)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEMSYL 500 (Indoco Rem.)'
);

-- line #13947
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIMOLAN 250 (Kapl)',
	'Ethamsylate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIMOLAN 250 (Kapl)'
);

-- line #13948
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIMOLAN 250 (Kapl)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIMOLAN 250 (Kapl)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIMOLAN 500 (Kapl)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIMOLAN 500 (Kapl)'
);

-- line #13949
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'H STAT 250 (Obsurge)',
	'Ethamsylate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'H STAT 250 (Obsurge)'
);

-- line #13950
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'H STAT 250 (Obsurge)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'H STAT 250 (Obsurge)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'H STAT 500 (Obsurge)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'H STAT 500 (Obsurge)'
);

-- line #13951
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'H STAT 250 (Obsurge)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'H STAT 250 (Obsurge)'
);

-- line #13952
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'H STAT 500 (Obsurge)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'H STAT 500 (Obsurge)'
);

-- line #13953
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'H STAT 250 (PSYCOREM)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'H STAT 250 (PSYCOREM)'
);

-- line #13954
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'H STAT 500 (PSYCOREM)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'H STAT 500 (PSYCOREM)'
);

-- line #13955
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEXILET 125 (Cadex Lab)',
	'Ethamsylate',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEXILET 125 (Cadex Lab)'
);

-- line #13956
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KLOT 250 (Skymax)',
	'Ethamsylate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KLOT 250 (Skymax)'
);

-- line #13957
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KLOT 250 (Skymax)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KLOT 250 (Skymax)'
);

-- line #13958
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KLOT 500 (Skymax)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KLOT 500 (Skymax)'
);

-- line #13959
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KSTAT 125 (Mercury)',
	'Ethamsylate',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KSTAT 125 (Mercury)'
);

-- line #13960
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KSTAT 250 (Mercury)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KSTAT 250 (Mercury)'
);

-- line #13961
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KSTAT 500 (Mercury)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KSTAT 500 (Mercury)'
);

-- line #13962
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LATE 250 (VENSAT)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LATE 250 (VENSAT)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LATE 500 (VENSAT)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LATE 500 (VENSAT)'
);

-- line #13963
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDISTAT 250 (Comed)',
	'Ethamsylate',
	'AMP',
	gm.nullify_empty_string('250')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDISTAT 250 (Comed)'
);

-- line #13964
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDISTAT 250 (Comed)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDISTAT 250 (Comed)'
);

-- line #13965
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDISTAT 500 (Comed)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDISTAT 500 (Comed)'
);

-- line #13966
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MESY 125 (Medoz Ph.)',
	'Ethamsylate',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MESY 125 (Medoz Ph.)'
);

-- line #13967
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MESY 250 (Medoz Ph.)',
	'Ethamsylate',
	'TAB/F TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MESY 250 (Medoz Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MESY 500 (Medoz Ph.)',
	'Ethamsylate',
	'TAB/F TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MESY 500 (Medoz Ph.)'
);

-- line #13968
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'M STAT 250 (Mercury)',
	'Ethamsylate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'M STAT 250 (Mercury)'
);

-- line #13969
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'M STAT 250 (Mercury)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'M STAT 250 (Mercury)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'M STAT 500 (Mercury)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'M STAT 500 (Mercury)'
);

-- line #13970
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOFLO 250 (Global Med.)',
	'Ethamsylate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOFLO 250 (Global Med.)'
);

-- line #13971
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOFLO 250 (Global Med.)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOFLO 250 (Global Med.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOFLO 500 (Global Med.)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOFLO 500 (Global Med.)'
);

-- line #13972
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIFSTAT 250 (Pifer Ph.)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIFSTAT 250 (Pifer Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIFSTAT 500 (Pifer Ph.)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIFSTAT 500 (Pifer Ph.)'
);

-- line #13973
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROSYN 250 (Allure Rem.)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROSYN 250 (Allure Rem.)'
);

-- line #13974
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROSYN 500 (Allure Rem.)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROSYN 500 (Allure Rem.)'
);

-- line #13975
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RADISTAT 125 (Radicura)',
	'Ethamsylate',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RADISTAT 125 (Radicura)'
);

-- line #13976
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RADISTAT 250 (Radicura)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RADISTAT 250 (Radicura)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RADISTAT 500 (Radicura)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RADISTAT 500 (Radicura)'
);

-- line #13977
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RC-NOVA 250 (Acron Ph.)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RC-NOVA 250 (Acron Ph.)'
);

-- line #13978
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RC-NOVA 500 (Acron Ph.)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RC-NOVA 500 (Acron Ph.)'
);

-- line #13979
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REVICI-E 250 (Kee Ph.)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REVICI-E 250 (Kee Ph.)'
);

-- line #13980
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REVICI-E 500 (Kee Ph.)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REVICI-E 500 (Kee Ph.)'
);

-- line #13981
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REVISTAT 250 (Intra Lab)',
	'Ethamsylate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REVISTAT 250 (Intra Lab)'
);

-- line #13982
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REVISTAT 250 (Intra Lab)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REVISTAT 250 (Intra Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REVISTAT 500 (Intra Lab)',
	'Ethamsylate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REVISTAT 500 (Intra Lab)'
);

-- line #13983
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHANOLAMINE OLEATE 5 (Samarth)',
	'Ethanolamine Oleate',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHANOLAMINE OLEATE 5 (Samarth)'
);

-- line #13984
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,01', u'strength_2': u'', u'substance': u'Ethinyl Oestradiol', u'always_empty': u'', u'form': u'', u'brand': u'ETHINORM-E', u'strength_3': u'', u'company': u'Bennet Ph.', u'unit': u'mg'}

-- line #13985
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYNORAL 0.01 (Infar)',
	'Ethinyl Oestradiol',
	'TAB',
	gm.nullify_empty_string('0.01')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYNORAL 0.01 (Infar)'
);

-- line #13986
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYNORAL 0.05 (Infar)',
	'Ethinyl Oestradiol',
	'TAB',
	gm.nullify_empty_string('0.05')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYNORAL 0.05 (Infar)'
);

-- line #13987
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYNORAL 1 (Infar)',
	'Ethinyl Oestradiol',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYNORAL 1 (Infar)'
);

-- line #13988
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NC NORM-E 0.01 (Unicure)',
	'Ethinyl Oestradiol',
	'TAB',
	gm.nullify_empty_string('0.01')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NC NORM-E 0.01 (Unicure)'
);

-- line #13989
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'ETHINYLESTRADIOL PH. EUR', u'strength_2': u'', u'substance': u'Ethinyloestradiol', u'always_empty': u'', u'form': u'', u'brand': u'NUVARING', u'strength_3': u'', u'company': u'Organon', u'unit': u'ETONOGESTREL CONTRACEPTIVE VAGINAL RING/DEVICE'}

-- line #13990
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROGYNON-C 0.02 (German R.)',
	'Ethinyl Oestradiol',
	'TAB',
	gm.nullify_empty_string('0.02')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROGYNON-C 0.02 (German R.)'
);

-- line #13991
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENAMIDE 250 (SG PH.)',
	'Ethionamide',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENAMIDE 250 (SG PH.)'
);

-- line #13992
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHIDE 250 (Lupin)',
	'Ethionamide',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHIDE 250 (Lupin)'
);

-- line #13993
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHIMAX 250 (Overseas Hc.)',
	'Ethionamide',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHIMAX 250 (Overseas Hc.)'
);

-- line #13994
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHIOBIN 250 (Medispan)',
	'Ethionamide',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHIOBIN 250 (Medispan)'
);

-- line #13995
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHIOCID 250 (Themis)',
	'Ethionamide',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHIOCID 250 (Themis)'
);

-- line #13996
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHIOKOX 250 (Radicura)',
	'Ethionamide',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHIOKOX 250 (Radicura)'
);

-- line #13997
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHIONAM 250 (CH.Bhagat)',
	'Ethionamide',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHIONAM 250 (CH.Bhagat)'
);

-- line #13998
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHIOZ 250 (Medoz Ph.)',
	'Ethionamide',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHIOZ 250 (Medoz Ph.)'
);

-- line #13999
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHOMID 250 (Macleods)',
	'Ethionamide',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHOMID 250 (Macleods)'
);

-- line #14000
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETOMIDE 250 (Vhb)',
	'Ethionamide',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETOMIDE 250 (Vhb)'
);

-- line #14001
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETUMIDE 250 (Vhb)',
	'Ethionamide',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETUMIDE 250 (Vhb)'
);

-- line #14002
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MDTHIDE 250 (Maneesh)',
	'Ethionamide',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MDTHIDE 250 (Maneesh)'
);

-- line #14003
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MD THIDE 250 (Maneesh)',
	'Ethionamide',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MD THIDE 250 (Maneesh)'
);

-- line #14004
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCOTUF 250 (Le Sante)',
	'Ethionamide',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCOTUF 250 (Le Sante)'
);

-- line #14005
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYOBID 250 (Panacea)',
	'Ethionamide',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYOBID 250 (Panacea)'
);

-- line #14006
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Ethylmorphine Hcl.', u'always_empty': u'', u'form': u'TAB', u'brand': u'COPHEDRIN-E', u'strength_3': u'', u'company': u'Acron Ph.', u'unit': u''}

-- line #14007
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIONINDON 16 (Zydus Cadila)',
	'Ethylmorphine Hcl.',
	'TAB',
	gm.nullify_empty_string('16')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIONINDON 16 (Zydus Cadila)'
);

-- line #14008
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESKAP-E 16 (Kosha Lab.)',
	'Ethylmorphine Hcl.',
	'TAB',
	gm.nullify_empty_string('16')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESKAP-E 16 (Kosha Lab.)'
);

-- line #14009
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DISONATE 200 (Samarth)',
	'Etidronate Disodium',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DISONATE 200 (Samarth)'
);

-- line #14010
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETIFEM 200 (Fem care)',
	'Etidronate',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETIFEM 200 (Fem care)'
);

-- line #14011
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETAZAM 0.5 (Torrent)',
	'ETIZOLAM',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETAZAM 0.5 (Torrent)'
);

-- line #14012
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETAZAM 1 (Torrent)',
	'ETIZOLAM',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETAZAM 1 (Torrent)'
);

-- line #14013
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETILAAM 0.25 (Intas)',
	'ETIZOLAM',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETILAAM 0.25 (Intas)'
);

-- line #14014
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETILAAM 0.5 (Intas)',
	'ETIZOLAM',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETILAAM 0.5 (Intas)'
);

-- line #14015
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETILAAM 1 (Intas)',
	'ETIZOLAM',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETILAAM 1 (Intas)'
);

-- line #14016
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETIREST 0.5 (Sun)',
	'ETIZOLAM',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETIREST 0.5 (Sun)'
);

-- line #14017
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETIREST 1 (Sun)',
	'ETIZOLAM',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETIREST 1 (Sun)'
);

-- line #14018
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1', u'strength_2': u'', u'substance': u'ETIZOLAM', u'always_empty': u'', u'form': u'', u'brand': u'ETIZOLA', u'strength_3': u'', u'company': u'Macleods', u'unit': u'mg'}

-- line #14019
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETIZOLA 0.5 (Macleods)',
	'ETIZOLAM',
	'MD TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETIZOLA 0.5 (Macleods)'
);

-- line #14020
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETIZOLA 0.25 (Macleods)',
	'ETIZOLAM',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETIZOLA 0.25 (Macleods)'
);

-- line #14021
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETIZOLA 0.5 (Macleods)',
	'ETIZOLAM',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETIZOLA 0.5 (Macleods)'
);

-- line #14022
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAM ET-1 1 (Tasmed)',
	'ETIZOLAM',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAM ET-1 1 (Tasmed)'
);

-- line #14023
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAM-ET 0.5 (Tasmed)',
	'ETIZOLAM',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAM-ET 0.5 (Tasmed)'
);

-- line #14024
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACZOLAM 0.5 (Macleods)',
	'ETIZOLAM',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACZOLAM 0.5 (Macleods)'
);

-- line #14025
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EDOL 300 (Lupin)',
	'ETODOLAC',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EDOL 300 (Lupin)'
);

-- line #14026
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EDOL 400 (Lupin)',
	'ETODOLAC',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EDOL 400 (Lupin)'
);

-- line #14027
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EDOL 600 (Lupin)',
	'ETODOLAC',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EDOL 600 (Lupin)'
);

-- line #14028
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETOFREE 300 (Lupin)',
	'ETODOLAC',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETOFREE 300 (Lupin)'
);

-- line #14029
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETOFREE 400 (Lupin)',
	'ETODOLAC',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETOFREE 400 (Lupin)'
);

-- line #14030
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETOFREE 600 (Lupin)',
	'ETODOLAC',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETOFREE 600 (Lupin)'
);

-- line #14031
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETOGESIC 600 (Zydus A.)',
	'ETODOLAC',
	'ER TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETOGESIC 600 (Zydus A.)'
);

-- line #14032
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETOGESIC 400 (Zydus A.)',
	'ETODOLAC',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETOGESIC 400 (Zydus A.)'
);

-- line #14033
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETOLIFE 600 (Torrent)',
	'ETODOLAC',
	'ER TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETOLIFE 600 (Torrent)'
);

-- line #14034
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETOLIFE 400 (Torrent)',
	'ETODOLAC',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETOLIFE 400 (Torrent)'
);

-- line #14035
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETOLOR 200 (Intra Lab)',
	'ETODOLAC',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETOLOR 200 (Intra Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETOLOR 300 (Intra Lab)',
	'ETODOLAC',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETOLOR 300 (Intra Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETOLOR 400 (Intra Lab)',
	'ETODOLAC',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETOLOR 400 (Intra Lab)'
);

-- line #14036
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETOMAX 400 (Ipca)',
	'ETODOLAC',
	'ER TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETOMAX 400 (Ipca)'
);

-- line #14037
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETOMAX 600 (Ipca)',
	'ETODOLAC',
	'ER TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETOMAX 600 (Ipca)'
);

-- line #14038
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETOMAX 400 (Ipca)',
	'ETODOLAC',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETOMAX 400 (Ipca)'
);

-- line #14039
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETOSAFE 600 (OSTEOLIFE)',
	'ETODOLAC',
	'ER TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETOSAFE 600 (OSTEOLIFE)'
);

-- line #14040
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETOVA 400 (Ipca)',
	'ETODOLAC',
	'ER TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETOVA 400 (Ipca)'
);

-- line #14041
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETOVA 600 (Ipca)',
	'ETODOLAC',
	'ER TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETOVA 600 (Ipca)'
);

-- line #14042
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETOVA 200 (Ipca)',
	'ETODOLAC',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETOVA 200 (Ipca)'
);

-- line #14043
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETOVA 300 (Ipca)',
	'ETODOLAC',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETOVA 300 (Ipca)'
);

-- line #14044
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETOVA 400 (Ipca)',
	'ETODOLAC',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETOVA 400 (Ipca)'
);

-- line #14045
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETURA 400 (Dr.Reddy''S)',
	'ETODOLAC',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETURA 400 (Dr.Reddy''S)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETURA 500 (Dr.Reddy''S)',
	'ETODOLAC',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETURA 500 (Dr.Reddy''S)'
);

-- line #14046
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FREEUP 600 (Universal)',
	'ETODOLAC',
	'ER TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FREEUP 600 (Universal)'
);

-- line #14047
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FREEUP 400 (Universal)',
	'ETODOLAC',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FREEUP 400 (Universal)'
);

-- line #14048
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROXYM 200 (Emcure)',
	'ETODOLAC',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROXYM 200 (Emcure)'
);

-- line #14049
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROXYM 300 (Emcure)',
	'ETODOLAC',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROXYM 300 (Emcure)'
);

-- line #14050
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTITOP 100 (Khandelwal)',
	'Etoposide',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTITOP 100 (Khandelwal)'
);

-- line #14051
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTITOP 50 (Khandelwal)',
	'Etoposide',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTITOP 50 (Khandelwal)'
);

-- line #14052
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTITOP 100 (Khandelwal)',
	'Etoposide',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTITOP 100 (Khandelwal)'
);

-- line #14053
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BEPOSID 100 (Biological E.)',
	'Etoposide',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BEPOSID 100 (Biological E.)'
);

-- line #14054
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100', u'strength_2': u'5ML', u'substance': u'Etoposide', u'always_empty': u'', u'form': u'INJ', u'brand': u'BIOPOSIDE', u'strength_3': u'', u'company': u'Biochem', u'unit': u''}

-- line #14055
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYTOP 100 (Intas)',
	'Etoposide',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYTOP 100 (Intas)'
);

-- line #14056
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYTOSID 100 (AMRONCO)',
	'Etoposide',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYTOSID 100 (AMRONCO)'
);

-- line #14057
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPOSED 100 (Natco Ph.)',
	'Etoposide',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPOSED 100 (Natco Ph.)'
);

-- line #14058
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESIDE 50 (VHB)',
	'Etoposide',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESIDE 50 (VHB)'
);

-- line #14059
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHOPUL 100 (Vhb)',
	'Etoposide',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHOPUL 100 (Vhb)'
);

-- line #14060
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETOCID 50 (Cipla)',
	'Etoposide',
	'CAP/V',
	gm.nullify_empty_string('50')::numeric,
	'mg/NA'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETOCID 50 (Cipla)'
);

-- line #14061
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETOLON 50 (CELON)',
	'Etoposide',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETOLON 50 (CELON)'
);

-- line #14062
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETOLON 100 (CELON)',
	'Etoposide',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETOLON 100 (CELON)'
);

-- line #14063
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETONIS 100 (NEISS)',
	'Etoposide',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETONIS 100 (NEISS)'
);

-- line #14064
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETOPOSIDE 100 (CH.Bhagat)',
	'Etoposide',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETOPOSIDE 100 (CH.Bhagat)'
);

-- line #14065
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETOPOSIDE 50 (CH.Bhagat)',
	'Etoposide',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETOPOSIDE 50 (CH.Bhagat)'
);

-- line #14066
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETOPOSIDE 100 (Pharmacia)',
	'Etoposide',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETOPOSIDE 100 (Pharmacia)'
);

-- line #14067
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETOSID 50 (Cipla)',
	'Etoposide',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETOSID 50 (Cipla)'
);

-- line #14068
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETOSID 100 (Cipla)',
	'Etoposide',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETOSID 100 (Cipla)'
);

-- line #14069
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FYTOP 100 (Cytomed(Alkem))',
	'Etoposide',
	'VIAL',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FYTOP 100 (Cytomed(Alkem))'
);

-- line #14070
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FYTOSID 20 (Dabur Ph.)',
	'Etoposide',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FYTOSID 20 (Dabur Ph.)'
);

-- line #14071
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LASTET 100 (Khandelwal)',
	'Etoposide',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LASTET 100 (Khandelwal)'
);

-- line #14072
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LASTET 25 (Khandelwal)',
	'Etoposide',
	'CAP',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LASTET 25 (Khandelwal)'
);

-- line #14073
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LASTET 50 (Khandelwal)',
	'Etoposide',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LASTET 50 (Khandelwal)'
);

-- line #14074
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LASTET 100 (Khandelwal)',
	'Etoposide',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LASTET 100 (Khandelwal)'
);

-- line #14075
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONCOSID 50 (United Bio.)',
	'Etoposide',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONCOSID 50 (United Bio.)'
);

-- line #14076
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONCOSID 100 (United Bio.)',
	'Etoposide',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONCOSID 100 (United Bio.)'
);

-- line #14077
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PELTASOL 100 (Khandelwal)',
	'Etoposide',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PELTASOL 100 (Khandelwal)'
);

-- line #14078
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Etoposide', u'always_empty': u'', u'form': u'VIAL', u'brand': u'PLACID', u'strength_3': u'', u'company': u'Samarth', u'unit': u''}

-- line #14079
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50', u'strength_2': u'100;ML', u'substance': u'Etoposide', u'always_empty': u'', u'form': u'CAP', u'brand': u'POSID', u'strength_3': u'', u'company': u'Cadila Ph.', u'unit': u''}

-- line #14080
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POSID 100 (Cadila)',
	'Etoposide',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POSID 100 (Cadila)'
);

-- line #14081
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COXET 60 (ANTHUS)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COXET 60 (ANTHUS)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COXET 90 (ANTHUS)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COXET 90 (ANTHUS)'
);

-- line #14082
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COXWAVE 60 (CHEMO HC.)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COXWAVE 60 (CHEMO HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COXWAVE 90 (CHEMO HC.)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COXWAVE 90 (CHEMO HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COXWAVE 120 (CHEMO HC.)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COXWAVE 120 (CHEMO HC.)'
);

-- line #14083
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DORICOX 90 (CONDOR(EDRIC))',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DORICOX 90 (CONDOR(EDRIC))'
);

-- line #14084
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EBOV 120 (Glenmark)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EBOV 120 (Glenmark)'
);

-- line #14085
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EBOV 60 (Glenmark)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EBOV 60 (Glenmark)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EBOV 90 (Glenmark)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EBOV 90 (Glenmark)'
);

-- line #14086
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELEX 90 (ROSE LABS)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELEX 90 (ROSE LABS)'
);

-- line #14087
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EROFICA 120 (Micro Labs)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EROFICA 120 (Micro Labs)'
);

-- line #14088
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EROFICA 60 (Micro Labs)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EROFICA 60 (Micro Labs)'
);

-- line #14089
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EROFICA 90 (Micro Labs)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EROFICA 90 (Micro Labs)'
);

-- line #14090
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETERON 120 (Cfl Ph.)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETERON 120 (Cfl Ph.)'
);

-- line #14091
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETERON 60 (Cfl Ph.)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETERON 60 (Cfl Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETERON 90 (Cfl Ph.)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETERON 90 (Cfl Ph.)'
);

-- line #14092
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETICOX 30 (EAST WEST)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETICOX 30 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETICOX 60 (EAST WEST)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETICOX 60 (EAST WEST)'
);

-- line #14093
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETICOX 90 (EAST WEST)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETICOX 90 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETICOX 120 (EAST WEST)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETICOX 120 (EAST WEST)'
);

-- line #14094
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETOCOX 120 (Aristo)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETOCOX 120 (Aristo)'
);

-- line #14095
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETOCOX 60 (Aristo)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETOCOX 60 (Aristo)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETOCOX 90 (Aristo)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETOCOX 90 (Aristo)'
);

-- line #14096
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETODY 120 (Nicholas)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETODY 120 (Nicholas)'
);

-- line #14097
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETODY 60 (Nicholas)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETODY 60 (Nicholas)'
);

-- line #14098
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETODY 90 (Nicholas)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETODY 90 (Nicholas)'
);

-- line #14099
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETOFAN 120 (EMAR)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETOFAN 120 (EMAR)'
);

-- line #14100
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETOJET 90 (Themis Med.)',
	'ETORICOXIB',
	'INJ',
	gm.nullify_empty_string('90')::numeric,
	'mg(+TCL-S 101)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETOJET 90 (Themis Med.)'
);

-- line #14101
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETOM 60 (Intra Lab)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETOM 60 (Intra Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETOM 120 (Intra Lab)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETOM 120 (Intra Lab)'
);

-- line #14102
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETOM 90 (Intra Lab)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETOM 90 (Intra Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETOM 120 (Intra Lab)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETOM 120 (Intra Lab)'
);

-- line #14103
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETORIB 90 (WOMB LAB.)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETORIB 90 (WOMB LAB.)'
);

-- line #14104
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETORICA 120 (Eros Ph.)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETORICA 120 (Eros Ph.)'
);

-- line #14105
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETORICA 60 (Eros Ph.)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETORICA 60 (Eros Ph.)'
);

-- line #14106
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETORICA 90 (Eros Ph.)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETORICA 90 (Eros Ph.)'
);

-- line #14107
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETOSAID 120 (Macleods)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETOSAID 120 (Macleods)'
);

-- line #14108
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETOSHINE 120 (Sun)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETOSHINE 120 (Sun)'
);

-- line #14109
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETOSHINE 60 (Sun)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETOSHINE 60 (Sun)'
);

-- line #14110
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETOSHINE 90 (Sun)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETOSHINE 90 (Sun)'
);

-- line #14111
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETOXIB 120 (Unichem)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETOXIB 120 (Unichem)'
);

-- line #14112
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETOXIB 60 (Unichem)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETOXIB 60 (Unichem)'
);

-- line #14113
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETOXIB 90 (Unichem)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETOXIB 90 (Unichem)'
);

-- line #14114
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETOZOX 120 (Cipla)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETOZOX 120 (Cipla)'
);

-- line #14115
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETOZOX 60 (Cipla)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETOZOX 60 (Cipla)'
);

-- line #14116
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETOZOX 90 (Cipla)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETOZOX 90 (Cipla)'
);

-- line #14117
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETRIK 120 (Alembic)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETRIK 120 (Alembic)'
);

-- line #14118
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETRIK 60 (Alembic)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETRIK 60 (Alembic)'
);

-- line #14119
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETRIK 90 (Alembic)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETRIK 90 (Alembic)'
);

-- line #14120
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETROBAX 120 (Rexcel)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETROBAX 120 (Rexcel)'
);

-- line #14121
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETROBAX 60 (Rexcel)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETROBAX 60 (Rexcel)'
);

-- line #14122
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETROBAX 90 (Rexcel)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETROBAX 90 (Rexcel)'
);

-- line #14123
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETRO 90 (ALLENGE)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETRO 90 (ALLENGE)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETRO 120 (ALLENGE)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETRO 120 (ALLENGE)'
);

-- line #14124
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EZACT 120 (Sun)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EZACT 120 (Sun)'
);

-- line #14125
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EZACT 60 (Sun)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EZACT 60 (Sun)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EZACT 90 (Sun)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EZACT 90 (Sun)'
);

-- line #14126
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HICOX 90 (Systopic)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HICOX 90 (Systopic)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HICOX 120 (Systopic)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HICOX 120 (Systopic)'
);

-- line #14127
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIRETO 60 (ST.MORRISON)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIRETO 60 (ST.MORRISON)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIRETO 90 (ST.MORRISON)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIRETO 90 (ST.MORRISON)'
);

-- line #14128
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IXIDOL 90 (BIOMAX BIO.)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IXIDOL 90 (BIOMAX BIO.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IXIDOL 120 (BIOMAX BIO.)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IXIDOL 120 (BIOMAX BIO.)'
);

-- line #14129
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KINGCOX 120 (Irm Ph.)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KINGCOX 120 (Irm Ph.)'
);

-- line #14130
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KINGCOX 60 (Irm Ph.)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KINGCOX 60 (Irm Ph.)'
);

-- line #14131
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KINGCOX 90 (Irm Ph.)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KINGCOX 90 (Irm Ph.)'
);

-- line #14132
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KRESTOS 120 (Majesta)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KRESTOS 120 (Majesta)'
);

-- line #14133
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KRESTOS 60 (Majesta)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KRESTOS 60 (Majesta)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KRESTOS 90 (Majesta)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KRESTOS 90 (Majesta)'
);

-- line #14134
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KRETOS 120 (Glenmark)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KRETOS 120 (Glenmark)'
);

-- line #14135
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KRETOS 60 (Glenmark)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'90'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KRETOS 60 (Glenmark)'
);

-- line #14136
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'L-KON 60 (LAKSUN)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'L-KON 60 (LAKSUN)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'L-KON 90 (LAKSUN)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'L-KON 90 (LAKSUN)'
);

-- line #14137
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'M-KON 60 (MADHAV BIO.)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'M-KON 60 (MADHAV BIO.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'M-KON 90 (MADHAV BIO.)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'M-KON 90 (MADHAV BIO.)'
);

-- line #14138
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'ETORICOXIB', u'always_empty': u'', u'form': u'GEL', u'brand': u'NUCOXIA', u'strength_3': u'', u'company': u'Zydus Cadila', u'unit': u''}

-- line #14139
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUCOXIA 90 (Cadila Hc.)',
	'ETORICOXIB',
	'INJ',
	gm.nullify_empty_string('90')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUCOXIA 90 (Cadila Hc.)'
);

-- line #14140
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUCOXIA 120 (Zydus Cadila)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUCOXIA 120 (Zydus Cadila)'
);

-- line #14141
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUCOXIA 60 (Zydus Cadila)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUCOXIA 60 (Zydus Cadila)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUCOXIA 90 (Zydus Cadila)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUCOXIA 90 (Zydus Cadila)'
);

-- line #14142
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUREETO 120 (Intas)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUREETO 120 (Intas)'
);

-- line #14143
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUREETO 60 (Intas)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUREETO 60 (Intas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUREETO 90 (Intas)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUREETO 90 (Intas)'
);

-- line #14144
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RETOZ 120 (DR. REDDY''S)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RETOZ 120 (DR. REDDY''S)'
);

-- line #14145
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RETOZ 60 (Dr.Reddy''S)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RETOZ 60 (Dr.Reddy''S)'
);

-- line #14146
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RETOZ 90 (Dr.Reddy''S)',
	'ETORICOXIB',
	'TAB',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RETOZ 90 (Dr.Reddy''S)'
);

-- line #14147
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANTESS 500 (Wockhardt)',
	'Evening Primrose Oil',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANTESS 500 (Wockhardt)'
);

-- line #14148
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CODESOFT EPO 1000 (Indchemie)',
	'Evening Primrose Oil',
	'CAP',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CODESOFT EPO 1000 (Indchemie)'
);

-- line #14149
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EDGE-P 500 (Elder)',
	'Evening Primrose Oil',
	'SG CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg(EXCP.MIXED TOCOPHEROL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EDGE-P 500 (Elder)'
);

-- line #14150
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIMOSA 100 (Universal)',
	'Evening Primrose Oil',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIMOSA 100 (Universal)'
);

-- line #14151
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIMOSA 1000 (Universal)',
	'Evening Primrose Oil',
	'SG CAP',
	gm.nullify_empty_string('1000')::numeric,
	'500'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIMOSA 1000 (Universal)'
);

-- line #14152
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REPUFA 100 (Royal Lab)',
	'Evening Primrose Oil',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REPUFA 100 (Royal Lab)'
);

-- line #14153
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REPUFA 500 (Royal Lab)',
	'Evening Primrose Oil',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REPUFA 500 (Royal Lab)'
);

-- line #14154
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000', u'strength_2': u'', u'substance': u'Evening Primrose Oil', u'always_empty': u'', u'form': u'', u'brand': u'REPUFA', u'strength_3': u'', u'company': u'Royal', u'unit': u'mg'}

-- line #14155
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,25', u'strength_2': u'', u'substance': u'EVEROLIMUS', u'always_empty': u'', u'form': u'', u'brand': u'ADVACAN', u'strength_3': u'', u'company': u'Biocon', u'unit': u'mg'}

-- line #14156
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,5', u'strength_2': u'', u'substance': u'EVEROLIMUS', u'always_empty': u'', u'form': u'', u'brand': u'ADVACAN', u'strength_3': u'', u'company': u'Biocon', u'unit': u'mg'}

-- line #14157
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EVERGRAF 0.25 (Panacea)',
	'EVEROLIMUS',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EVERGRAF 0.25 (Panacea)'
);

-- line #14158
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EVERGRAF 0.5 (Panacea)',
	'EVEROLIMUS',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EVERGRAF 0.5 (Panacea)'
);

-- line #14159
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10', u'strength_2': u'', u'substance': u'EVEROLIMUS', u'always_empty': u'', u'form': u'', u'brand': u'EVERTOR', u'strength_3': u'', u'company': u'Biocon', u'unit': u'mg'}

-- line #14160
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5', u'strength_2': u'', u'substance': u'EVEROLIMUS', u'always_empty': u'', u'form': u'', u'brand': u'EVERTOR', u'strength_3': u'', u'company': u'Biocon', u'unit': u'mg'}

-- line #14161
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXMASIN 25 (Sun)',
	'EXEMESTANE',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXMASIN 25 (Sun)'
);

-- line #14162
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10MCG( MANNITOL', u'strength_2': u'', u'substance': u'EXENATIDE', u'always_empty': u'', u'form': u'', u'brand': u'BYETTA PEN LED PEN', u'strength_3': u'', u'company': u'Eli Lilly', u'unit': u'GLACIAL ACETIC ACID'}

-- line #14163
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5MCG( MANNITOL', u'strength_2': u'', u'substance': u'EXENATIDE', u'always_empty': u'', u'form': u'', u'brand': u'BYETTA PEN LED PEN', u'strength_3': u'', u'company': u'Eli Lilly', u'unit': u'GLACIAL ACETIC ACID'}

-- line #14164
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250MCG', u'strength_2': u'ML', u'substance': u'EXENATIDE', u'always_empty': u'', u'form': u'INJ', u'brand': u'EXAPRIDE', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #14165
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5MCG(MULTIDOSE VIAL', u'strength_2': u'', u'substance': u'EXENATIDE', u'always_empty': u'', u'form': u'', u'brand': u'INCRENAT MCG', u'strength_3': u'', u'company': u'Natco', u'unit': u'M-CRESOL 0.2'}

-- line #14166
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EZEDOC 10 (Lupin)',
	'EZETIMIBE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EZEDOC 10 (Lupin)'
);

-- line #14167
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EZEE 10 (HETERO HC.)',
	'EZETIMIBE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EZEE 10 (HETERO HC.)'
);

-- line #14168
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EZENTIA 10 (Sun)',
	'EZETIMIBE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EZENTIA 10 (Sun)'
);

-- line #14169
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EZERAEM 10 (SAFE MED(MSN))',
	'EZETIMIBE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EZERAEM 10 (SAFE MED(MSN))'
);

-- line #14170
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EZETIB 10 (Unisearch)',
	'EZETIMIBE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EZETIB 10 (Unisearch)'
);

-- line #14171
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EZET 10 (Carsyon)',
	'EZETIMIBE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EZET 10 (Carsyon)'
);

-- line #14172
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EZIBLOC 10 (Cadila Ph.)',
	'EZETIMIBE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EZIBLOC 10 (Cadila Ph.)'
);

-- line #14173
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EZTA 10 (Zydus Cadila)',
	'EZETIMIBE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EZTA 10 (Zydus Cadila)'
);

-- line #14174
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EZZICAD 10 (Healtheon)',
	'EZETIMIBE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EZZICAD 10 (Healtheon)'
);

-- line #14175
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPEZET 10 (Piramal Hc.)',
	'EZETIMIBE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPEZET 10 (Piramal Hc.)'
);

-- line #14176
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIBE 10 (Troikaa)',
	'EZETIMIBE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIBE 10 (Troikaa)'
);

-- line #14177
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FABULAS 120 (Intas)',
	'FABUXOSTAT',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FABULAS 120 (Intas)'
);

-- line #14178
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FABULAS 80 (Intas)',
	'FABUXOSTAT',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FABULAS 80 (Intas)'
);

-- line #14179
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250IU.', u'strength_2': u'', u'substance': u'Factor Viii Conc.', u'always_empty': u'', u'form': u'VIAL', u'brand': u'FANDHI', u'strength_3': u'', u'company': u'GRIFOLS', u'unit': u''}

-- line #14180
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250', u'strength_2': u'500', u'substance': u'Factor Viii Conc.', u'always_empty': u'', u'form': u'INJ', u'brand': u'MONOCLATE-P', u'strength_3': u'1000 IU', u'company': u'Zydus Cadila', u'unit': u''}

-- line #14181
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAMCIMAC 250 (Macleods)',
	'FAMCICLOVIR',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAMCIMAC 250 (Macleods)'
);

-- line #14182
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAMCIMAC 500 (Macleods)',
	'FAMCICLOVIR',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAMCIMAC 500 (Macleods)'
);

-- line #14183
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAMTREX 250 (Cipla)',
	'FAMCICLOVIR',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAMTREX 250 (Cipla)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAMTREX 500 (Cipla)',
	'FAMCICLOVIR',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAMTREX 500 (Cipla)'
);

-- line #14184
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICROVIR 250 (Micro Labs)',
	'FAMCICLOVIR',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICROVIR 250 (Micro Labs)'
);

-- line #14185
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICROVIR 500 (Micro Labs)',
	'FAMCICLOVIR',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICROVIR 500 (Micro Labs)'
);

-- line #14186
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENVIR 250 (HETERO HC.)',
	'FAMCICLOVIR',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENVIR 250 (HETERO HC.)'
);

-- line #14187
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENVIR 500 (HETERO HC.)',
	'FAMCICLOVIR',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENVIR 500 (HETERO HC.)'
);

-- line #14188
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACIDEF 20 (Chemo D.)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACIDEF 20 (Chemo D.)'
);

-- line #14189
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACILO 20 (Wanbury)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACILO 20 (Wanbury)'
);

-- line #14190
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACILO 40 (Wanbury)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACILO 40 (Wanbury)'
);

-- line #14191
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACIPEP 20 (Kramer)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACIPEP 20 (Kramer)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACIPEP 40 (Kramer)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACIPEP 40 (Kramer)'
);

-- line #14192
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACREDIN 20 (Nicholas)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACREDIN 20 (Nicholas)'
);

-- line #14193
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACREDIN 40 (Nicholas)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACREDIN 40 (Nicholas)'
);

-- line #14194
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACREDIN 20 (SPPL)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACREDIN 20 (SPPL)'
);

-- line #14195
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACREDIN 40 (SPPL)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACREDIN 40 (SPPL)'
);

-- line #14196
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AUTIDINE 20 (Aurobindo)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AUTIDINE 20 (Aurobindo)'
);

-- line #14197
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AUTIDINE 40 (Aurobindo)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AUTIDINE 40 (Aurobindo)'
);

-- line #14198
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLOCACID 20 (Ipca)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLOCACID 20 (Ipca)'
);

-- line #14199
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLOCACID 40 (Ipca)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLOCACID 40 (Ipca)'
);

-- line #14200
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FACID AC 10 (Intas)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FACID AC 10 (Intas)'
);

-- line #14201
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FACID 20 (Intas)',
	'Famotidine',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FACID 20 (Intas)'
);

-- line #14202
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FACID 20 (Intas)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FACID 20 (Intas)'
);

-- line #14203
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FACID 40 (Intas)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FACID 40 (Intas)'
);

-- line #14204
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FADINE 20 (Aristo)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FADINE 20 (Aristo)'
);

-- line #14205
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FADINE 40 (Aristo)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FADINE 40 (Aristo)'
);

-- line #14206
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FALTIDIN 20 (Alkem)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FALTIDIN 20 (Alkem)'
);

-- line #14207
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FALTIDIN 40 (Alkem)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FALTIDIN 40 (Alkem)'
);

-- line #14208
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAMALDIN 20 (Medico)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAMALDIN 20 (Medico)'
);

-- line #14209
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAMALDIN 40 (Medico)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAMALDIN 40 (Medico)'
);

-- line #14210
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAMCARE 20 (Olcare)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAMCARE 20 (Olcare)'
);

-- line #14211
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAMCARE 40 (Olcare)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAMCARE 40 (Olcare)'
);

-- line #14212
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAMDO 40 (SHINE PH.)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAMDO 40 (SHINE PH.)'
);

-- line #14213
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAM H2 20 (Ozone Ph.)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAM H2 20 (Ozone Ph.)'
);

-- line #14214
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAM H2 40 (Ozone Ph.)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAM H2 40 (Ozone Ph.)'
);

-- line #14215
-- ignoring line: field [strength_1] not numeric: >>>10(+CALCIUM CARBONATE 800<<<
-- {u'list_of_values_of_unknown_fields': [u' mg)', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10(+CALCIUM CARBONATE 800', u'strength_2': u'', u'substance': u'Famotidine', u'always_empty': u'', u'form': u'TAB', u'brand': u'FAMOCHEW', u'strength_3': u'', u'company': u'DELVIN', u'unit': u'mg'}

-- line #14216
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAMOCID 20 (Sun)',
	'Famotidine',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAMOCID 20 (Sun)'
);

-- line #14217
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAMOCID 20 (Sun)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAMOCID 20 (Sun)'
);

-- line #14218
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAMOCID 40 (Sun)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAMOCID 40 (Sun)'
);

-- line #14219
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAMODIN 20 (Cadila Ph.)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAMODIN 20 (Cadila Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAMODIN 40 (Cadila Ph.)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAMODIN 40 (Cadila Ph.)'
);

-- line #14220
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAMOFAST 20 (F D C)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAMOFAST 20 (F D C)'
);

-- line #14221
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAMOFAST 40 (F D C)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAMOFAST 40 (F D C)'
);

-- line #14222
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAMOKAN 20 (Kansas Lab)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAMOKAN 20 (Kansas Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAMOKAN 40 (Kansas Lab)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAMOKAN 40 (Kansas Lab)'
);

-- line #14223
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAMONITE 20 (Zydus Cadila)',
	'Famotidine',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAMONITE 20 (Zydus Cadila)'
);

-- line #14224
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAMONITE 20 (Zydus Cadila)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAMONITE 20 (Zydus Cadila)'
);

-- line #14225
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAMONITE 40 (Zydus Cadila)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAMONITE 40 (Zydus Cadila)'
);

-- line #14226
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAMOPRIL 20 (Zydus Cadila)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAMOPRIL 20 (Zydus Cadila)'
);

-- line #14227
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAMOPRIL 40 (Zydus Cadila)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAMOPRIL 40 (Zydus Cadila)'
);

-- line #14228
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAMORILA 20 (Glenmark)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAMORILA 20 (Glenmark)'
);

-- line #14229
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAMORILA 40 (Glenmark)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAMORILA 40 (Glenmark)'
);

-- line #14230
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAMOTIN 20 (U S V)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAMOTIN 20 (U S V)'
);

-- line #14231
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAMOTIN 40 (U S V)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAMOTIN 40 (U S V)'
);

-- line #14232
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAMOT 40 (Shinto Org.)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAMOT 40 (Shinto Org.)'
);

-- line #14233
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAMOT 20 (Trio Rem.)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAMOT 20 (Trio Rem.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAMOT 40 (Trio Rem.)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAMOT 40 (Trio Rem.)'
);

-- line #14234
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAMOWAL 20 (Wallace)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAMOWAL 20 (Wallace)'
);

-- line #14235
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAMOWAL 40 (Wallace)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAMOWAL 40 (Wallace)'
);

-- line #14236
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAMPEP 20 (Seagull)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAMPEP 20 (Seagull)'
);

-- line #14237
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAMPEP 40 (Seagull)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAMPEP 40 (Seagull)'
);

-- line #14238
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAMTAC 20 (Nicholas)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAMTAC 20 (Nicholas)'
);

-- line #14239
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAMTAC 40 (Nicholas)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAMTAC 40 (Nicholas)'
);

-- line #14240
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAMTAC 20 (Piramal Hc.)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAMTAC 20 (Piramal Hc.)'
);

-- line #14241
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAMTAC 40 (Piramal Hc.)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAMTAC 40 (Piramal Hc.)'
);

-- line #14242
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAMTIN 20 (Finecure)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAMTIN 20 (Finecure)'
);

-- line #14243
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAMTIN 40 (Finecure)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAMTIN 40 (Finecure)'
);

-- line #14244
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEBCID 20 (Brown & B.)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEBCID 20 (Brown & B.)'
);

-- line #14245
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEBCID 40 (Brown & B.)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEBCID 40 (Brown & B.)'
);

-- line #14246
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEMIDIN 10 (TAJ PH.)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEMIDIN 10 (TAJ PH.)'
);

-- line #14247
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEMIDIN 20 (TAJ PH.)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEMIDIN 20 (TAJ PH.)'
);

-- line #14248
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEMIDIN 30 (TAJ PH.)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEMIDIN 30 (TAJ PH.)'
);

-- line #14249
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEMIDIN 20 (TAJ PH.)',
	'Famotidine',
	'VIAL',
	gm.nullify_empty_string('20')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEMIDIN 20 (TAJ PH.)'
);

-- line #14250
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEMOACT 20 (Active Hc.)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEMOACT 20 (Active Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEMOACT 40 (Active Hc.)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEMOACT 40 (Active Hc.)'
);

-- line #14251
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FM 20 (Caplet Ind.)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FM 20 (Caplet Ind.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FM 40 (Caplet Ind.)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FM 40 (Caplet Ind.)'
);

-- line #14252
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FONTAIN 40 (Chemo D.)',
	'Famotidine',
	'F. TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FONTAIN 40 (Chemo D.)'
);

-- line #14253
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUDONE 20 (Wockhardt)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUDONE 20 (Wockhardt)'
);

-- line #14254
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUDONE 40 (Wockhardt)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUDONE 40 (Wockhardt)'
);

-- line #14255
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NILACID 20 (Dial Ph.)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NILACID 20 (Dial Ph.)'
);

-- line #14256
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOCTIN 20 (P C INDIA)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOCTIN 20 (P C INDIA)'
);

-- line #14257
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOCTIN 40 (P C INDIA)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOCTIN 40 (P C INDIA)'
);

-- line #14258
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORFAM 20 (Medicamen)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORFAM 20 (Medicamen)'
);

-- line #14259
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORFAM 40 (Medicamen)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORFAM 40 (Medicamen)'
);

-- line #14260
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEPDIN 20 (Overseas Hc.)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEPDIN 20 (Overseas Hc.)'
);

-- line #14261
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEPDIN 40 (Overseas Hc.)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEPDIN 40 (Overseas Hc.)'
);

-- line #14262
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEPGARD FPRTE 40 (Shreya)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEPGARD FPRTE 40 (Shreya)'
);

-- line #14263
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEPGARD 20 (Shreya)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEPGARD 20 (Shreya)'
);

-- line #14264
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POLYFAM 10 (Somatico)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg(IN CALC'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POLYFAM 10 (Somatico)'
);

-- line #14265
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RECID 20 (Active Hc.)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RECID 20 (Active Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RECID 40 (Active Hc.)',
	'Famotidine',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RECID 40 (Active Hc.)'
);

-- line #14266
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPENAM-O 200 (Alembic)',
	'FAROPENEM',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPENAM-O 200 (Alembic)'
);

-- line #14267
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUONEM 300 (ALIDAC(CORZA))',
	'FAROPENEM',
	'ER TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUONEM 300 (ALIDAC(CORZA))'
);

-- line #14268
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUONEM 200 (Zydus A.)',
	'FAROPENEM',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUONEM 200 (Zydus A.)'
);

-- line #14269
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FARONEM 150 (Ranbaxy)',
	'FAROPENEM',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FARONEM 150 (Ranbaxy)'
);

-- line #14270
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FARONEM 200 (Ranbaxy)',
	'FAROPENEM',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FARONEM 200 (Ranbaxy)'
);

-- line #14271
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAROZET 150 (INTEGRACE (GLENMARK))',
	'FAROPENEM',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAROZET 150 (INTEGRACE (GLENMARK))'
);

-- line #14272
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAROZET 200 (INTEGRACE (GLENMARK))',
	'FAROPENEM',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAROZET 200 (INTEGRACE (GLENMARK))'
);

-- line #14273
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORPENEM 200 (Macleods)',
	'FAROPENEM',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORPENEM 200 (Macleods)'
);

-- line #14274
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EBUXO 120 (Ipca)',
	'FEBUXOSTAT',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EBUXO 120 (Ipca)'
);

-- line #14275
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EBUXO 40 (Ipca)',
	'FEBUXOSTAT',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EBUXO 40 (Ipca)'
);

-- line #14276
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EBUXO 80 (Ipca)',
	'FEBUXOSTAT',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EBUXO 80 (Ipca)'
);

-- line #14277
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40', u'strength_2': u'', u'substance': u'FEBUXOSTAT', u'always_empty': u'', u'form': u'', u'brand': u"ENDEAVOUR''S FURIC", u'strength_3': u'', u'company': u'Lupin', u'unit': u'mg'}

-- line #14278
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FABULAS 40 (Intas)',
	'FEBUXOSTAT',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FABULAS 40 (Intas)'
);

-- line #14279
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FABUZEST 40 (Unisearch)',
	'FEBUXOSTAT',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FABUZEST 40 (Unisearch)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FABUZEST 80 (Unisearch)',
	'FEBUXOSTAT',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FABUZEST 80 (Unisearch)'
);

-- line #14280
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FADVIC-40 40 (Emcure)',
	'FEBUXOSTAT',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FADVIC-40 40 (Emcure)'
);

-- line #14281
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FADVIC-80 80 (Emcure)',
	'FEBUXOSTAT',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FADVIC-80 80 (Emcure)'
);

-- line #14282
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEBOXA 40 (Ranbaxy)',
	'FEBUXOSTAT',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEBOXA 40 (Ranbaxy)'
);

-- line #14283
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEBUCIP 40 (Cipla)',
	'FEBUXOSTAT',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEBUCIP 40 (Cipla)'
);

-- line #14284
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEBUCIP 80 (Cipla)',
	'FEBUXOSTAT',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEBUCIP 80 (Cipla)'
);

-- line #14285
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEBUGET 40 (SUN)',
	'FEBUXOSTAT',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEBUGET 40 (SUN)'
);

-- line #14286
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEBUGET 80 (SUN)',
	'FEBUXOSTAT',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEBUGET 80 (SUN)'
);

-- line #14287
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEBUGOOD 120 (Unisearch)',
	'FEBUXOSTAT',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEBUGOOD 120 (Unisearch)'
);

-- line #14288
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEBUGOOD 40 (Unisearch)',
	'FEBUXOSTAT',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEBUGOOD 40 (Unisearch)'
);

-- line #14289
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEBUGOOD 80 (Unisearch)',
	'FEBUXOSTAT',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEBUGOOD 80 (Unisearch)'
);

-- line #14290
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEBUMAC-40 40 (Macleods)',
	'FEBUXOSTAT',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEBUMAC-40 40 (Macleods)'
);

-- line #14291
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEBUMAC 80 (Macleods)',
	'FEBUXOSTAT',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEBUMAC 80 (Macleods)'
);

-- line #14292
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEBURIC 40 (AIMIRON)',
	'FEBUXOSTAT',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEBURIC 40 (AIMIRON)'
);

-- line #14293
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEBURIC 40 (ALMIRON)',
	'FEBUXOSTAT',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEBURIC 40 (ALMIRON)'
);

-- line #14294
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEBURIC 80 (ALMIRON)',
	'FEBUXOSTAT',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEBURIC 80 (ALMIRON)'
);

-- line #14295
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEBUSTAT 120 (Piramal Hc.)',
	'FEBUXOSTAT',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEBUSTAT 120 (Piramal Hc.)'
);

-- line #14296
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEBUSTAT 40 (Piramal Hc.)',
	'FEBUXOSTAT',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEBUSTAT 40 (Piramal Hc.)'
);

-- line #14297
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEBUSTAT 80 (Piramal Hc.)',
	'FEBUXOSTAT',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEBUSTAT 80 (Piramal Hc.)'
);

-- line #14298
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEBUTAZ 40 (Sun)',
	'FEBUXOSTAT',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEBUTAZ 40 (Sun)'
);

-- line #14299
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEBUTROY 40 (Troikaa)',
	'FEBUXOSTAT',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEBUTROY 40 (Troikaa)'
);

-- line #14300
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEBUTROY 80 (Troikaa)',
	'FEBUXOSTAT',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEBUTROY 80 (Troikaa)'
);

-- line #14301
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEBUXOR 120 (Intas)',
	'FEBUXOSTAT',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEBUXOR 120 (Intas)'
);

-- line #14302
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEBUXOR 40 (Intas)',
	'FEBUXOSTAT',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEBUXOR 40 (Intas)'
);

-- line #14303
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEBUXOR 80 (Intas)',
	'FEBUXOSTAT',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEBUXOR 80 (Intas)'
);

-- line #14304
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEBUZEX 40 (Ajanta Ph.)',
	'FEBUXOSTAT',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEBUZEX 40 (Ajanta Ph.)'
);

-- line #14305
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEBUZEX 80 (Ajanta Ph.)',
	'FEBUXOSTAT',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEBUZEX 80 (Ajanta Ph.)'
);

-- line #14306
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FRBUTAZ 80 (Sun)',
	'FEBUXOSTAT',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FRBUTAZ 80 (Sun)'
);

-- line #14307
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FURIC 40 (Ar-Ex Labs.)',
	'FEBUXOSTAT',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FURIC 40 (Ar-Ex Labs.)'
);

-- line #14308
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FURIC 80 (Ar-Ex Labs.)',
	'FEBUXOSTAT',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FURIC 80 (Ar-Ex Labs.)'
);

-- line #14309
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GOUSTAT 40 (Alembic)',
	'FEBUXOSTAT',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GOUSTAT 40 (Alembic)'
);

-- line #14310
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GOUSTAT 80 (Alembic)',
	'FEBUXOSTAT',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GOUSTAT 80 (Alembic)'
);

-- line #14311
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FELOGARD 10 (Cipla)',
	'Felodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FELOGARD 10 (Cipla)'
);

-- line #14312
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FELOGARD 2.5 (Cipla)',
	'Felodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FELOGARD 2.5 (Cipla)'
);

-- line #14313
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FELOGARD 5 (Cipla)',
	'Felodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FELOGARD 5 (Cipla)'
);

-- line #14314
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLENDIL 10 (Astrazeneca)',
	'Felodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLENDIL 10 (Astrazeneca)'
);

-- line #14315
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLENDIL 2.5 (Astrazeneca)',
	'Felodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLENDIL 2.5 (Astrazeneca)'
);

-- line #14316
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLENDIL 5 (Astrazeneca)',
	'Felodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLENDIL 5 (Astrazeneca)'
);

-- line #14317
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RENEDIL 10 (Sanofi Aventis)',
	'Felodipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RENEDIL 10 (Sanofi Aventis)'
);

-- line #14318
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RENEDIL 2.5 (Sanofi Aventis)',
	'Felodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RENEDIL 2.5 (Sanofi Aventis)'
);

-- line #14319
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RENEDIL 5 (Sanofi Aventis)',
	'Felodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RENEDIL 5 (Sanofi Aventis)'
);

-- line #14320
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3', u'strength_2': u'', u'substance': u'FENBENDAZOLE', u'always_empty': u'', u'form': u'', u'brand': u'FENDIKIND-3', u'strength_3': u'', u'company': u'Mankind', u'unit': u'mg'}

-- line #14321
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1,5', u'strength_2': u'', u'substance': u'FENBENDAZOLE', u'always_empty': u'', u'form': u'', u'brand': u'FENDIKIND', u'strength_3': u'', u'company': u'Mankind', u'unit': u'mg'}

-- line #14322
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLABOLIN 40 (Wockhardt)',
	'Fenfluramine',
	'CAP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLABOLIN 40 (Wockhardt)'
);

-- line #14323
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLABOLIN 20 (Wockhardt)',
	'Fenfluramine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLABOLIN 20 (Wockhardt)'
);

-- line #14324
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FENACOR 200 (TAJ PH.)',
	'Fenofibrate',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FENACOR 200 (TAJ PH.)'
);

-- line #14325
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FENACOR 160 (TAJ PH.)',
	'Fenofibrate',
	'FC TAB',
	gm.nullify_empty_string('160')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FENACOR 160 (TAJ PH.)'
);

-- line #14326
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FENOBATE 200 (EAST WEST)',
	'Fenofibrate',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FENOBATE 200 (EAST WEST)'
);

-- line #14327
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FENOBATE 67 (EAST WEST)',
	'Fenofibrate',
	'CAP',
	gm.nullify_empty_string('67')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FENOBATE 67 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FENOBATE 160 (EAST WEST)',
	'Fenofibrate',
	'CAP',
	gm.nullify_empty_string('160')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FENOBATE 160 (EAST WEST)'
);

-- line #14328
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FENOCOR 200 (Ordain Hc.)',
	'Fenofibrate',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FENOCOR 200 (Ordain Hc.)'
);

-- line #14329
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FENOCOR 67 (Ordain Hc.)',
	'Fenofibrate',
	'CAP',
	gm.nullify_empty_string('67')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FENOCOR 67 (Ordain Hc.)'
);

-- line #14330
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'105', u'strength_2': u'', u'substance': u'Fenofibrate', u'always_empty': u'', u'form': u'', u'brand': u'FENOFIBRIC', u'strength_3': u'', u'company': u'DELVIN', u'unit': u'mg(FENOFIBRIC ACID)'}

-- line #14331
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'35', u'strength_2': u'', u'substance': u'Fenofibrate', u'always_empty': u'', u'form': u'', u'brand': u'FENOFIBRIC', u'strength_3': u'', u'company': u'DELVIN', u'unit': u'mg(FENOFIBRIC ACID)'}

-- line #14332
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FENOLIP 200 (Cipla)',
	'Fenofibrate',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FENOLIP 200 (Cipla)'
);

-- line #14333
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FENOLIP 145 (Cipla)',
	'Fenofibrate',
	'TAB',
	gm.nullify_empty_string('145')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FENOLIP 145 (Cipla)'
);

-- line #14334
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FENOLIP 160 (Cipla)',
	'Fenofibrate',
	'TAB',
	gm.nullify_empty_string('160')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FENOLIP 160 (Cipla)'
);

-- line #14335
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIBRAL 200 (Cardicare)',
	'Fenofibrate',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIBRAL 200 (Cardicare)'
);

-- line #14336
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIBRATE 200 (AVINASH)',
	'Fenofibrate',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIBRATE 200 (AVINASH)'
);

-- line #14337
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FINATE 200 (Franco I.)',
	'Fenofibrate',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FINATE 200 (Franco I.)'
);

-- line #14338
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FINATE 160 (Franco I.)',
	'Fenofibrate',
	'TAB',
	gm.nullify_empty_string('160')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FINATE 160 (Franco I.)'
);

-- line #14339
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPICARD 200 (U S V)',
	'Fenofibrate',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPICARD 200 (U S V)'
);

-- line #14340
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPICARD 160 (U S V)',
	'Fenofibrate',
	'TAB',
	gm.nullify_empty_string('160')::numeric,
	'200'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPICARD 160 (U S V)'
);

-- line #14341
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOTGL-200 200 (GRANDIX)',
	'Fenofibrate',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg(MICRONISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOTGL-200 200 (GRANDIX)'
);

-- line #14342
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100MCG', u'strength_2': u'H', u'substance': u'Fentanyl', u'always_empty': u'', u'form': u'INJ', u'brand': u'DUROGESIC', u'strength_3': u'', u'company': u'J.&J.', u'unit': u''}

-- line #14343
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'25MCG', u'strength_2': u'H', u'substance': u'Fentanyl', u'always_empty': u'', u'form': u'INJ', u'brand': u'DUROGESIC', u'strength_3': u'', u'company': u'J.&J.', u'unit': u''}

-- line #14344
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50MCG', u'strength_2': u'H', u'substance': u'Fentanyl', u'always_empty': u'', u'form': u'INJ', u'brand': u'DUROGESIC', u'strength_3': u'', u'company': u'J.&J.', u'unit': u''}

-- line #14345
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50MCG', u'strength_2': u'ML', u'substance': u'Fentanyl', u'always_empty': u'', u'form': u'AMP', u'brand': u'FENDROP', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #14346
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50MCG', u'strength_2': u'ML', u'substance': u'Fentanyl', u'always_empty': u'', u'form': u'INJ', u'brand': u'FENILATE', u'strength_3': u'', u'company': u'Svizera', u'unit': u''}

-- line #14347
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50MCG', u'strength_2': u'ML', u'substance': u'Fentanyl', u'always_empty': u'', u'form': u'INJ', u'brand': u'FENSTUD', u'strength_3': u'', u'company': u'Rusan Hc', u'unit': u''}

-- line #14348
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50U.G', u'strength_2': u'ML', u'substance': u'Fentanyl', u'always_empty': u'', u'form': u'INJ', u'brand': u'FENT', u'strength_3': u'', u'company': u'Neon', u'unit': u''}

-- line #14349
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERACEP 1 (SYSTOPIC)',
	'Feracrylum',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERACEP 1 (SYSTOPIC)'
);

-- line #14350
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERASEP 1 (Systopic)',
	'Feracrylum',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERASEP 1 (Systopic)'
);

-- line #14351
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEMOLOK 1 (Themis)',
	'Feracrylum',
	'AMP',
	gm.nullify_empty_string('1')::numeric,
	'%(STERILE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEMOLOK 1 (Themis)'
);

-- line #14352
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEMOLOK 1 (Themis)',
	'Feracrylum',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%(STERILE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEMOLOK 1 (Themis)'
);

-- line #14353
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUONEM 150 (Zydus A.)',
	'FEROPENEM',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUONEM 150 (Zydus A.)'
);

-- line #14354
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAROBACT 200 (Cipla)',
	'FEROPENEM',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAROBACT 200 (Cipla)'
);

-- line #14355
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILKIRON 25 (Mercury)',
	'Ferrous Aminoacetosulphate',
	'DROPS',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILKIRON 25 (Mercury)'
);

-- line #14356
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALOHA 10 (INDOCO(SPADE))',
	'FERROUS ASCORBATE',
	'XT DPS',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALOHA 10 (INDOCO(SPADE))'
);

-- line #14357
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'FERROUS ASCORBATE', u'always_empty': u'', u'form': u'XT ML', u'brand': u'CORBET', u'strength_3': u'', u'company': u'SINSAN PH.', u'unit': u''}

-- line #14358
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERROUS FUMARATE 200 (J & J DeChane)',
	'Ferrous Fumarate',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERROUS FUMARATE 200 (J & J DeChane)'
);

-- line #14359
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERINOVA 20 (Lupin)',
	'Ferrous Glycine Sulph.',
	'DPS',
	gm.nullify_empty_string('20')::numeric,
	'mg;ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERINOVA 20 (Lupin)'
);

-- line #14360
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'FE SUCROSE', u'always_empty': u'', u'form': u'INJ', u'brand': u'HEMILIFT', u'strength_3': u'', u'company': u'Ranbaxy S.Sp.', u'unit': u''}

-- line #14361
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADIFEX 120 (Dermatak)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADIFEX 120 (Dermatak)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADIFEX 180 (Dermatak)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('180')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADIFEX 180 (Dermatak)'
);

-- line #14362
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALAFEX 120 (Mefro Ph.)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALAFEX 120 (Mefro Ph.)'
);

-- line #14363
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALAFEX 180 (Mefro Ph.)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('180')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALAFEX 180 (Mefro Ph.)'
);

-- line #14364
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALERNEX 120 (Dabur Ph.)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALERNEX 120 (Dabur Ph.)'
);

-- line #14365
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALERNEX 180 (Dabur Ph.)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('180')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALERNEX 180 (Dabur Ph.)'
);

-- line #14366
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALERT 120 (Alkem)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALERT 120 (Alkem)'
);

-- line #14367
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALERT 180 (Alkem)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('180')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALERT 180 (Alkem)'
);

-- line #14368
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALFEXO 120 (Ind-Swift)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALFEXO 120 (Ind-Swift)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALFEXO 180 (Ind-Swift)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('180')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALFEXO 180 (Ind-Swift)'
);

-- line #14369
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALLEFAST 120 (STERLING)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALLEFAST 120 (STERLING)'
);

-- line #14370
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALLEFAST 180 (STERLING)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('180')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALLEFAST 180 (STERLING)'
);

-- line #14371
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALLEGIX 120 (Intas)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALLEGIX 120 (Intas)'
);

-- line #14372
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALLEGIX 180 (Intas)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('180')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALLEGIX 180 (Intas)'
);

-- line #14373
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALLEGRA 30 (AVENTIS)',
	'Fexofenadine Hydrochloride',
	'SUS',
	gm.nullify_empty_string('30')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALLEGRA 30 (AVENTIS)'
);

-- line #14374
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALLEGRA 30 (SANOFI AV.)',
	'Fexofenadine Hydrochloride',
	'SUS',
	gm.nullify_empty_string('30')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALLEGRA 30 (SANOFI AV.)'
);

-- line #14375
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALLEGRA 120 (Sanofi Aventis)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALLEGRA 120 (Sanofi Aventis)'
);

-- line #14376
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALLEGRA 180 (Sanofi Aventis)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('180')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALLEGRA 180 (Sanofi Aventis)'
);

-- line #14377
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALLEGRA 30 (Sanofi Aventis)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALLEGRA 30 (Sanofi Aventis)'
);

-- line #14378
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'120', u'strength_2': u'', u'substance': u'Fexofenadine Hydrochloride', u'always_empty': u'', u'form': u'', u'brand': u'ALLERFEX', u'strength_3': u'', u'company': u'Unichem', u'unit': u'mg'}

-- line #14379
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'180', u'strength_2': u'', u'substance': u'Fexofenadine Hydrochloride', u'always_empty': u'', u'form': u'', u'brand': u'ALLERFEX', u'strength_3': u'', u'company': u'Unichem', u'unit': u'mg'}

-- line #14380
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALLERGO 120 (AGIO PH.)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALLERGO 120 (AGIO PH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALLERGO 180 (AGIO PH.)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('180')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALLERGO 180 (AGIO PH.)'
);

-- line #14381
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALLOFEX 120 (Merind)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALLOFEX 120 (Merind)'
);

-- line #14382
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALLOFEX 180 (Merind)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('180')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALLOFEX 180 (Merind)'
);

-- line #14383
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALTIVA 120 (Ranbaxy)',
	'Fexofenadine Hydrochloride',
	'FC TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALTIVA 120 (Ranbaxy)'
);

-- line #14384
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALTIVA 180 (Ranbaxy)',
	'Fexofenadine Hydrochloride',
	'FC TAB',
	gm.nullify_empty_string('180')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALTIVA 180 (Ranbaxy)'
);

-- line #14385
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALTIVA 30 (Ranbaxy)',
	'Fexofenadine Hydrochloride',
	'FC TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALTIVA 30 (Ranbaxy)'
);

-- line #14386
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALTIVA 60 (Ranbaxy)',
	'Fexofenadine Hydrochloride',
	'FC TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALTIVA 60 (Ranbaxy)'
);

-- line #14387
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALTIVA 60 (Ranbaxy)',
	'Fexofenadine Hydrochloride',
	'SUS',
	gm.nullify_empty_string('60')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALTIVA 60 (Ranbaxy)'
);

-- line #14388
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CURIFEX 120 (Morepen)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CURIFEX 120 (Morepen)'
);

-- line #14389
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CURIFEX 60 (Morepen)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CURIFEX 60 (Morepen)'
);

-- line #14390
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EFFECTIN 120 (TWILIGHT LIT.)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EFFECTIN 120 (TWILIGHT LIT.)'
);

-- line #14391
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EFFECTIN 180 (TWILIGHT LIT.)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('180')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EFFECTIN 180 (TWILIGHT LIT.)'
);

-- line #14392
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAX-120 120 (Mdc Ph.)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAX-120 120 (Mdc Ph.)'
);

-- line #14393
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEGIX 120 (G.Nine Form.)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEGIX 120 (G.Nine Form.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEGIX 180 (G.Nine Form.)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('180')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEGIX 180 (G.Nine Form.)'
);

-- line #14394
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEGRA 120 (Comed)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEGRA 120 (Comed)'
);

-- line #14395
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEGRA 180 (Comed)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('180')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEGRA 180 (Comed)'
);

-- line #14396
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEXAMIN 180 (Indilina Ph.)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('180')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEXAMIN 180 (Indilina Ph.)'
);

-- line #14397
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEXIDINE 60 (Ind-Swift)',
	'Fexofenadine Hydrochloride',
	'DT',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEXIDINE 60 (Ind-Swift)'
);

-- line #14398
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEXIDINE 30 (Ind-Swift)',
	'Fexofenadine Hydrochloride',
	'SUS',
	gm.nullify_empty_string('30')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEXIDINE 30 (Ind-Swift)'
);

-- line #14399
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEXIDINE 120 (Ind-Swift)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEXIDINE 120 (Ind-Swift)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEXIDINE 180 (Ind-Swift)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('180')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEXIDINE 180 (Ind-Swift)'
);

-- line #14400
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEXIGRA 120 (Cipla)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEXIGRA 120 (Cipla)'
);

-- line #14401
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEXIGRA 180 (Cipla)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('180')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEXIGRA 180 (Cipla)'
);

-- line #14402
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEXOCET 180 (KIVI LABS)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('180')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEXOCET 180 (KIVI LABS)'
);

-- line #14403
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEXODINE 120 (Cipla)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEXODINE 120 (Cipla)'
);

-- line #14404
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEXODINE 120 (Olcare)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEXODINE 120 (Olcare)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEXODINE 180 (Olcare)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('180')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEXODINE 180 (Olcare)'
);

-- line #14405
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEXOFAST 120 (Micro Labs)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEXOFAST 120 (Micro Labs)'
);

-- line #14406
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEXOFAST 180 (Micro Labs)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('180')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEXOFAST 180 (Micro Labs)'
);

-- line #14407
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEXOFEN 120 (Aristo)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEXOFEN 120 (Aristo)'
);

-- line #14408
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEXOFEN 180 (Aristo)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('180')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEXOFEN 180 (Aristo)'
);

-- line #14409
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEXOHIT 120 (AXYZEN LIFE)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEXOHIT 120 (AXYZEN LIFE)'
);

-- line #14410
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEXONA 120 (HETERO HC.)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEXONA 120 (HETERO HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEXONA 180 (HETERO HC.)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('180')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEXONA 180 (HETERO HC.)'
);

-- line #14411
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEXOQUIT 120 (Finecure)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEXOQUIT 120 (Finecure)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEXOQUIT 180 (Finecure)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('180')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEXOQUIT 180 (Finecure)'
);

-- line #14412
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEXOTAB 180 (Royal Lab)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('180')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEXOTAB 180 (Royal Lab)'
);

-- line #14413
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEXO 120 (Torrent)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEXO 120 (Torrent)'
);

-- line #14414
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEXO 180 (Torrent)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('180')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEXO 180 (Torrent)'
);

-- line #14415
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEXOTROL 120 (Sun)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEXOTROL 120 (Sun)'
);

-- line #14416
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEXOTROL 180 (Sun)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('180')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEXOTROL 180 (Sun)'
);

-- line #14417
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEXOT 120 (Taurus Lab)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEXOT 120 (Taurus Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEXOT 180 (Taurus Lab)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('180')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEXOT 180 (Taurus Lab)'
);

-- line #14418
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEXOVA 120 (Ipca)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEXOVA 120 (Ipca)'
);

-- line #14419
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEXOVA 180 (Ipca)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('180')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEXOVA 180 (Ipca)'
);

-- line #14420
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEXTRAL 120 (Indchemie)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEXTRAL 120 (Indchemie)'
);

-- line #14421
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEXTRAL 180 (Indchemie)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('180')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEXTRAL 180 (Indchemie)'
);

-- line #14422
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEXY 30 (Lupin)',
	'Fexofenadine Hydrochloride',
	'SUS',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEXY 30 (Lupin)'
);

-- line #14423
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEXY 120 (Lupin)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEXY 120 (Lupin)'
);

-- line #14424
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEXY 180 (Lupin)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('180')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEXY 180 (Lupin)'
);

-- line #14425
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G-FEX 120 (G.R. Lab)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G-FEX 120 (G.R. Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G-FEX 180 (G.R. Lab)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('180')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G-FEX 180 (G.R. Lab)'
);

-- line #14426
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HISTAFREE-120 120 (Mankind)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HISTAFREE-120 120 (Mankind)'
);

-- line #14427
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HISTAGRA 120 (Khandelwal)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HISTAGRA 120 (Khandelwal)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HISTAGRA 180 (Khandelwal)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('180')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HISTAGRA 180 (Khandelwal)'
);

-- line #14428
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HISTALOC 120 (Aglowmed)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HISTALOC 120 (Aglowmed)'
);

-- line #14429
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODIFEX 120 (Biochem)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODIFEX 120 (Biochem)'
);

-- line #14430
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODIFEX 180 (Biochem)',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('180')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODIFEX 180 (Biochem)'
);

-- line #14431
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OREGRA 120 (RISHAB(OROCHEM))',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OREGRA 120 (RISHAB(OROCHEM))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OREGRA 180 (RISHAB(OROCHEM))',
	'Fexofenadine Hydrochloride',
	'TAB',
	gm.nullify_empty_string('180')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OREGRA 180 (RISHAB(OROCHEM))'
);

-- line #14432
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'FILGRASTIM', u'always_empty': u'', u'form': u'VIAL', u'brand': u'COLSTIM', u'strength_3': u'', u'company': u'Zydus Bio.', u'unit': u''}

-- line #14433
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'300MCG', u'strength_2': u'', u'substance': u'FILGRASTIM', u'always_empty': u'', u'form': u'INJ', u'brand': u'CYTOGRAF MCG', u'strength_3': u'', u'company': u'ZYPHARS PH.', u'unit': u''}

-- line #14434
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'150MCG(R-HUGMCSF GRANULOCYTE COLONY SIMULATING FACTOR)', u'strength_2': u'', u'substance': u'FILGRASTIM', u'always_empty': u'', u'form': u'VIAL', u'brand': u'EMGRAST-M', u'strength_3': u'', u'company': u'Emcure', u'unit': u''}

-- line #14435
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'300MCG(R-HUGMCSF GRANULOCYTE COLONY SIMULATING FACTOR)', u'strength_2': u'', u'substance': u'FILGRASTIM', u'always_empty': u'', u'form': u'VIAL', u'brand': u'EMGRAST-M', u'strength_3': u'', u'company': u'Emcure', u'unit': u''}

-- line #14436
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'300MCG', u'strength_2': u'', u'substance': u'FILGRASTIM', u'always_empty': u'', u'form': u'INJ', u'brand': u'FILCAD', u'strength_3': u'', u'company': u'Cadila Ph.', u'unit': u''}

-- line #14437
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'300MCG', u'strength_2': u'', u'substance': u'FILGRASTIM', u'always_empty': u'', u'form': u'SYRINGE', u'brand': u'FILGEN', u'strength_3': u'', u'company': u'CH.Bhagat', u'unit': u''}

-- line #14438
-- ignoring line: field [strength_1] not numeric: >>>300MCG(RECOMBINANT HUMAN GRANULOCYTE COLONY SIMULATING FACTOR (G-CSF) INJ<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'300MCG(RECOMBINANT HUMAN GRANULOCYTE COLONY SIMULATING FACTOR (G-CSF) INJ', u'strength_2': u'', u'substance': u'FILGRASTIM', u'always_empty': u'', u'form': u'INJ', u'brand': u'FILGRASTIM MCG', u'strength_3': u'', u'company': u'Khandelwal', u'unit': u'FILGRASTIM 300MCG INJ)'}

-- line #14439
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'300MCG(G-CSF)', u'strength_2': u'', u'substance': u'FILGRASTIM', u'always_empty': u'', u'form': u'INJ', u'brand': u'GRAFEEL', u'strength_3': u'', u'company': u"Dr.Reddy''S", u'unit': u''}

-- line #14440
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'300MCG', u'strength_2': u'ML', u'substance': u'FILGRASTIM', u'always_empty': u'', u'form': u'VIAL', u'brand': u'GRAFEEL PFS', u'strength_3': u'', u'company': u"DR. REDDY''S", u'unit': u''}

-- line #14441
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'300MCG', u'strength_2': u'', u'substance': u'FILGRASTIM', u'always_empty': u'', u'form': u'INJ', u'brand': u'GRASIPAR', u'strength_3': u'', u'company': u'Parenteral', u'unit': u''}

-- line #14442
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'300MCG(R HUMAN GRANULOCYTE COLONY STIMULATING FACTOR)', u'strength_2': u'', u'substance': u'FILGRASTIM', u'always_empty': u'', u'form': u'INJ', u'brand': u'IRIL', u'strength_3': u'', u'company': u'Gufic Bio.', u'unit': u''}

-- line #14443
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u' %', u'TWEEN 80 0.004 ', u' %', u'', u'', u'', u'', u'', u''], u'strength_1': u'300MCG OF RECOMBINANT GRANULOCYTE COLONY STIMULATING FACTOR(R-HUG-CSF)', u'strength_2': u'', u'substance': u'FILGRASTIM', u'always_empty': u'', u'form': u'', u'brand': u'LUPIFIL FILGRASTIM', u'strength_3': u'', u'company': u'Lupin', u'unit': u'ACETIC ACID SOLUTION ACETATE BUFFER 10MM'}

-- line #14444
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'480MCG', u'strength_2': u'', u'substance': u'FILGRASTIM', u'always_empty': u'', u'form': u'INJ', u'brand': u'NEUKINE MCG', u'strength_3': u'', u'company': u'Intas', u'unit': u''}

-- line #14445
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'150MCG', u'strength_2': u'', u'substance': u'FILGRASTIM', u'always_empty': u'', u'form': u'VIAL', u'brand': u'NEUKINE MCG', u'strength_3': u'', u'company': u'Intas', u'unit': u''}

-- line #14446
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEUPEG 6 (INTAS)',
	'FILGRASTIM',
	'INJ',
	gm.nullify_empty_string('6')::numeric,
	'mg(PEG FILGRASTIM)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEUPEG 6 (INTAS)'
);

-- line #14447
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEGASTA 6 (INTAS BIO.)',
	'FILGRASTIM',
	'VIAL',
	gm.nullify_empty_string('6')::numeric,
	'mg(PEG FILGRASTIM)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEGASTA 6 (INTAS BIO.)'
);

-- line #14448
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEG GRAFEEL 6 (Dr.Reddy''S)',
	'FILGRASTIM',
	'INJ',
	gm.nullify_empty_string('6')::numeric,
	'mg(PEG-GCSF AB+)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEG GRAFEEL 6 (Dr.Reddy''S)'
);

-- line #14449
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEGLAST 6 (Zuventus)',
	'FILGRASTIM',
	'INJ',
	gm.nullify_empty_string('6')::numeric,
	'mg(PEG FILGRASTIM)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEGLAST 6 (Zuventus)'
);

-- line #14450
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'300MCG', u'strength_2': u'', u'substance': u'FILGRASTIM', u'always_empty': u'', u'form': u'INJ', u'brand': u'RELIGRAST', u'strength_3': u'', u'company': u'RELIANCE BIO.', u'unit': u''}

-- line #14451
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FINABOLD 1 (EAST WEST)',
	'Finasteride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FINABOLD 1 (EAST WEST)'
);

-- line #14452
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FINARA 5 (Dr.Reddy''S)',
	'Finasteride',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FINARA 5 (Dr.Reddy''S)'
);

-- line #14453
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FINAST 5 (Dr.Reddy''S)',
	'Finasteride',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FINAST 5 (Dr.Reddy''S)'
);

-- line #14454
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FINAX 1 (Dr.Reddy''S)',
	'Finasteride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FINAX 1 (Dr.Reddy''S)'
);

-- line #14455
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FINCAR 5 (Cipla)',
	'Finasteride',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FINCAR 5 (Cipla)'
);

-- line #14456
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FINCEPT 5 (Lupin)',
	'Finasteride',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FINCEPT 5 (Lupin)'
);

-- line #14457
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FINCOVER 1 (Micro Labs)',
	'Finasteride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FINCOVER 1 (Micro Labs)'
);

-- line #14458
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FINPECIA 1 (Cipla)',
	'Finasteride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FINPECIA 1 (Cipla)'
);

-- line #14459
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FINTRIDE 5 (Kopran)',
	'Finasteride',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FINTRIDE 5 (Kopran)'
);

-- line #14460
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FISTIDE 5 (Samarth)',
	'Finasteride',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FISTIDE 5 (Samarth)'
);

-- line #14461
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Finasteride', u'always_empty': u'', u'form': u'TAB', u'brand': u'GROWVITA-1', u'strength_3': u'', u'company': u'West Coast', u'unit': u''}

-- line #14462
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAFLON 500 (Serdia)',
	'Flavonoids',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg(MICRONIS.PURF.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAFLON 500 (Serdia)'
);

-- line #14463
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLAVATE 200 (Overseas Hc.)',
	'Flavoxate',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLAVATE 200 (Overseas Hc.)'
);

-- line #14464
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLAVORIDE 200 (Obsurge)',
	'Flavoxate',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLAVORIDE 200 (Obsurge)'
);

-- line #14465
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLAVOSPAS 200 (Elder)',
	'Flavoxate',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLAVOSPAS 200 (Elder)'
);

-- line #14466
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLAVOTARY 200 (Votary Lab)',
	'Flavoxate',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLAVOTARY 200 (Votary Lab)'
);

-- line #14467
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLAVOTROL 200 (ASTRA PH.)',
	'Flavoxate',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLAVOTROL 200 (ASTRA PH.)'
);

-- line #14468
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLAVOXATE 200 (Elder)',
	'Flavoxate',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLAVOXATE 200 (Elder)'
);

-- line #14469
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HERFLAV 200 (Torrent)',
	'Flavoxate',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HERFLAV 200 (Torrent)'
);

-- line #14470
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELAX URO 200 (Ar-Ex Labs.)',
	'Flavoxate',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELAX URO 200 (Ar-Ex Labs.)'
);

-- line #14471
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200', u'strength_2': u'', u'substance': u'Flavoxate', u'always_empty': u'', u'form': u'', u'brand': u'R-FLAVO', u'strength_3': u'', u'company': u'Royal', u'unit': u'mg'}

-- line #14472
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERTI FLAX 1000 (Alkem)',
	'FLAXSEED OIL',
	'SG CAP',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERTI FLAX 1000 (Alkem)'
);

-- line #14473
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000MCG', u'strength_2': u'', u'substance': u'FLAXSEED OIL', u'always_empty': u'', u'form': u'', u'brand': u'OXYFLAX GLOBAL', u'strength_3': u'', u'company': u'Deccan', u'unit': u''}

-- line #14474
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500', u'strength_2': u'', u'substance': u'FLAXSEED OIL', u'always_empty': u'', u'form': u'', u'brand': u'OXYFLAX NANO', u'strength_3': u'', u'company': u'Deccan', u'unit': u'mg(PROCESSED)'}

-- line #14475
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOURE STAIN 4 (Bell Ph.)',
	'Flouescein Sod.',
	'STRIP',
	gm.nullify_empty_string('4')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOURE STAIN 4 (Bell Ph.)'
);

-- line #14476
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOFLOX 250 (Neon)',
	'FLUCLOXACILLIN',
	'CAP/INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOFLOX 250 (Neon)'
);

-- line #14477
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADCON 150 (Admac Ph.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADCON 150 (Admac Ph.)'
);

-- line #14478
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADECON 150 (Swiss Ph.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADECON 150 (Swiss Ph.)'
);

-- line #14479
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AF-150 150 (Systopic)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AF-150 150 (Systopic)'
);

-- line #14480
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AF-400 400 (Systopic)',
	'Fluconazole',
	'DT',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AF-400 400 (Systopic)'
);

-- line #14481
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AF 150 (Systopic)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AF 150 (Systopic)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AF 400 (Systopic)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AF 400 (Systopic)'
);

-- line #14482
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AGLOCON 150 (Aglowmed)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AGLOCON 150 (Aglowmed)'
);

-- line #14483
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBICAN 150 (HAMPS BIO)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBICAN 150 (HAMPS BIO)'
);

-- line #14484
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALFA 150 (VENSAT)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALFA 150 (VENSAT)'
);

-- line #14485
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALFUCOZ 100 (Alembic)',
	'Fluconazole',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALFUCOZ 100 (Alembic)'
);

-- line #14486
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALFUCOZ 150 (Alembic)',
	'Fluconazole',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALFUCOZ 150 (Alembic)'
);

-- line #14487
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALFUCOZ 200 (Alembic)',
	'Fluconazole',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALFUCOZ 200 (Alembic)'
);

-- line #14488
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALFUCOZ 50 (Alembic)',
	'Fluconazole',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALFUCOZ 50 (Alembic)'
);

-- line #14489
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANTICAN-O 150 (BARODA)',
	'Fluconazole',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANTICAN-O 150 (BARODA)'
);

-- line #14490
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANTOL 150 (Mercury Hc.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANTOL 150 (Mercury Hc.)'
);

-- line #14491
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AQNAZOLE 150 (Aquila)',
	'Fluconazole',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AQNAZOLE 150 (Aquila)'
);

-- line #14492
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATCAN 200 (Atopic Lab.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATCAN 200 (Atopic Lab.)'
);

-- line #14493
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVIFLU 150 (Avalanche)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVIFLU 150 (Avalanche)'
);

-- line #14494
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZEZOLE 150 (ABLAZE HC)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZEZOLE 150 (ABLAZE HC)'
);

-- line #14495
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'B-CON 200 (Biomax Bio.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'B-CON 200 (Biomax Bio.)'
);

-- line #14496
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIKAMEZ 150 (Chemo D.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIKAMEZ 150 (Chemo D.)'
);

-- line #14497
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BISFLU 150 (Globus)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BISFLU 150 (Globus)'
);

-- line #14498
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANCAP 150 (Ind-Swift)',
	'Fluconazole',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANCAP 150 (Ind-Swift)'
);

-- line #14499
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANCAP 50 (Ind-Swift)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANCAP 50 (Ind-Swift)'
);

-- line #14500
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANDIGYL 100 (Marc Lab)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANDIGYL 100 (Marc Lab)'
);

-- line #14501
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANDIGYL 150 (Marc Lab)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANDIGYL 150 (Marc Lab)'
);

-- line #14502
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANDIGYL 200 (Marc Lab)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANDIGYL 200 (Marc Lab)'
);

-- line #14503
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANDIGYL 50 (Marc Lab)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANDIGYL 50 (Marc Lab)'
);

-- line #14504
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANDIL 150 (Healthgaurd)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANDIL 150 (Healthgaurd)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANDIL 200 (Healthgaurd)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANDIL 200 (Healthgaurd)'
);

-- line #14505
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANDIL 50 (Healthgaurd)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANDIL 50 (Healthgaurd)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANDIL 100 (Healthgaurd)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANDIL 100 (Healthgaurd)'
);

-- line #14506
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANDINA 150 (SHRI SWAMI)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANDINA 150 (SHRI SWAMI)'
);

-- line #14507
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANDI 150 (Rhombus)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANDI 150 (Rhombus)'
);

-- line #14508
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANDIZOLE 150 (Bioguard Org.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANDIZOLE 150 (Bioguard Org.)'
);

-- line #14509
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANFREE 150 (Chem+Med)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANFREE 150 (Chem+Med)'
);

-- line #14510
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200', u'strength_2': u'', u'substance': u'Fluconazole', u'always_empty': u'', u'form': u'', u'brand': u'CANZOL IV', u'strength_3': u'', u'company': u'MEDIMARK', u'unit': u'mg'}

-- line #14511
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAZOLE 150 (Synokem)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAZOLE 150 (Synokem)'
);

-- line #14512
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOZOLE 150 (PSYCOREM)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOZOLE 150 (PSYCOREM)'
);

-- line #14513
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONCIZE 150 (Indoco Rem.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONCIZE 150 (Indoco Rem.)'
);

-- line #14514
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONCIZE 50 (Indoco Rem.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONCIZE 50 (Indoco Rem.)'
);

-- line #14515
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONFLU 150 (East India)',
	'Fluconazole',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONFLU 150 (East India)'
);

-- line #14516
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONFLU 200 (East India)',
	'Fluconazole',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONFLU 200 (East India)'
);

-- line #14517
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONFLU 0.3 (East India)',
	'Fluconazole',
	'EYE DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONFLU 0.3 (East India)'
);

-- line #14518
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DERMUS 150 (Malcom Ph.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DERMUS 150 (Malcom Ph.)'
);

-- line #14519
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'E-FLU 150 (MARLINE BIO.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'E-FLU 150 (MARLINE BIO.)'
);

-- line #14520
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMBIZOL 150 (UMBILICAL PH.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMBIZOL 150 (UMBILICAL PH.)'
);

-- line #14521
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENDIDA 150 (Strassenburg)',
	'Fluconazole',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENDIDA 150 (Strassenburg)'
);

-- line #14522
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESLU 150 (Briskon)',
	'Fluconazole',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESLU 150 (Briskon)'
);

-- line #14523
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FABIZOL 2 (UNIKARE)',
	'Fluconazole',
	'POW',
	gm.nullify_empty_string('2')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FABIZOL 2 (UNIKARE)'
);

-- line #14524
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FABIZOL 150 (UNIKARE)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FABIZOL 150 (UNIKARE)'
);

-- line #14525
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FABIZOL 400 (UNIKARE)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FABIZOL 400 (UNIKARE)'
);

-- line #14526
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Fluconazole', u'always_empty': u'', u'form': u'TAB', u'brand': u'FC CURE', u'strength_3': u'', u'company': u'CURE N CURE', u'unit': u''}

-- line #14527
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'F-CON 150 (Lupin)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'F-CON 150 (Lupin)'
);

-- line #14528
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'F-CON 50 (Lupin)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'F-CON 50 (Lupin)'
);

-- line #14529
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FISCON 150 (Novagen Ph.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FISCON 150 (Novagen Ph.)'
);

-- line #14530
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FITZY 150 (CHEMO HC.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FITZY 150 (CHEMO HC.)'
);

-- line #14531
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIXIT 150 (Chemo Bio.)',
	'Fluconazole',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIXIT 150 (Chemo Bio.)'
);

-- line #14532
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIXIT 150 (Finecure)',
	'Fluconazole',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIXIT 150 (Finecure)'
);

-- line #14533
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLAG 150 (Runa Ph.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLAG 150 (Runa Ph.)'
);

-- line #14534
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOROXAN 150 (Khandelwal)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOROXAN 150 (Khandelwal)'
);

-- line #14535
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUACT 150 (Active Hc.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUACT 150 (Active Hc.)'
);

-- line #14536
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUBIT 150 (Cubit Hc.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUBIT 150 (Cubit Hc.)'
);

-- line #14537
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUC-150 150 (AIMCO PH.)',
	'Fluconazole',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUC-150 150 (AIMCO PH.)'
);

-- line #14538
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUCAGEN 150 (BIOGEN PH.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUCAGEN 150 (BIOGEN PH.)'
);

-- line #14539
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUCAL 150 (Arvind Lab.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUCAL 150 (Arvind Lab.)'
);

-- line #14540
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUCALUP 50 (Lupin)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'/50'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUCALUP 50 (Lupin)'
);

-- line #14541
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUCAN 100 (Bombay T.)',
	'Fluconazole',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUCAN 100 (Bombay T.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUCAN 200 (Bombay T.)',
	'Fluconazole',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUCAN 200 (Bombay T.)'
);

-- line #14542
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUCAN 150 (Bombay T.)',
	'Fluconazole',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUCAN 150 (Bombay T.)'
);

-- line #14543
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUCAN 50 (Bombay T.)',
	'Fluconazole',
	'KT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUCAN 50 (Bombay T.)'
);

-- line #14544
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUCANOL 150 (Olcare)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUCANOL 150 (Olcare)'
);

-- line #14545
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUCANOL 50 (Olcare)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUCANOL 50 (Olcare)'
);

-- line #14546
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUCARE 150 (UNITED LIFE)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUCARE 150 (UNITED LIFE)'
);

-- line #14547
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUCAZ 150 (AGIO PH.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUCAZ 150 (AGIO PH.)'
);

-- line #14548
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUCAZ 200 (AGIO PH.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUCAZ 200 (AGIO PH.)'
);

-- line #14549
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUC 0.3 (Ophthal R.)',
	'Fluconazole',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUC 0.3 (Ophthal R.)'
);

-- line #14550
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUCESS 150 (Sandoz)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUCESS 150 (Sandoz)'
);

-- line #14551
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUCOAT 150 (Atoz Ph.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUCOAT 150 (Atoz Ph.)'
);

-- line #14552
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUCO 150 (Allure Rem.)',
	'Fluconazole',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUCO 150 (Allure Rem.)'
);

-- line #14553
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUCO 50 (Allure Rem.)',
	'Fluconazole',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUCO 50 (Allure Rem.)'
);

-- line #14554
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUCOLE 150 (Kim Lab)',
	'Fluconazole',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUCOLE 150 (Kim Lab)'
);

-- line #14555
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUCOLE 50 (Kim Lab)',
	'Fluconazole',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUCOLE 50 (Kim Lab)'
);

-- line #14556
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUCOMA 150 (Auroma Life)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUCOMA 150 (Auroma Life)'
);

-- line #14557
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUCOMET 0.3 (Milmet)',
	'Fluconazole',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUCOMET 0.3 (Milmet)'
);

-- line #14558
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUCOM 150 (Om Bio.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUCOM 150 (Om Bio.)'
);

-- line #14559
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUCONA 50 (Hamax Ph.)',
	'Fluconazole',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUCONA 50 (Hamax Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUCONA 150 (Hamax Ph.)',
	'Fluconazole',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUCONA 150 (Hamax Ph.)'
);

-- line #14560
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUCONA 150 (Calibar Ph.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUCONA 150 (Calibar Ph.)'
);

-- line #14561
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUCONORM 150 (Life Line)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUCONORM 150 (Life Line)'
);

-- line #14562
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUCOPAN 150 (PANTHER PH.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUCOPAN 150 (PANTHER PH.)'
);

-- line #14563
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUCORIC 150 (Euphoric)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUCORIC 150 (Euphoric)'
);

-- line #14564
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'15G', u'strength_2': u'GEL', u'substance': u'Fluconazole', u'always_empty': u'', u'form': u'GEL', u'brand': u'FLUCOS', u'strength_3': u'', u'company': u'Cosme Hc.', u'unit': u''}

-- line #14565
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUCOSIDE 150 (SYNTRO HC.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUCOSIDE 150 (SYNTRO HC.)'
);

-- line #14566
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUCOSIDE 200 (SYNTRO HC.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUCOSIDE 200 (SYNTRO HC.)'
);

-- line #14567
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUCOS 0.5 (COSME HEALTH)',
	'Fluconazole',
	'POW',
	gm.nullify_empty_string('0.5')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUCOS 0.5 (COSME HEALTH)'
);

-- line #14568
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUCOS 150 (Cosme Hc.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUCOS 150 (Cosme Hc.)'
);

-- line #14569
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUCOS 200 (Cosme Hc.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUCOS 200 (Cosme Hc.)'
);

-- line #14570
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUCOS 50 (Cosme Hc.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUCOS 50 (Cosme Hc.)'
);

-- line #14571
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUCO 150 (AERO LIFE)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUCO 150 (AERO LIFE)'
);

-- line #14572
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUCOTRAP 150 (Siesta)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUCOTRAP 150 (Siesta)'
);

-- line #14573
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUCOVAR 150 (Zota Hc.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUCOVAR 150 (Zota Hc.)'
);

-- line #14574
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUCOZED 150 (Zota Ph.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUCOZED 150 (Zota Ph.)'
);

-- line #14575
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUCUR 150 (Secure)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUCUR 150 (Secure)'
);

-- line #14576
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUDAR 50 (TWILIGHT LIT.)',
	'Fluconazole',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUDAR 50 (TWILIGHT LIT.)'
);

-- line #14577
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUDAR 150 (TWILIGHT LIT.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUDAR 150 (TWILIGHT LIT.)'
);

-- line #14578
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUDIA 150 (MINOVA)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUDIA 150 (MINOVA)'
);

-- line #14579
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUFRESH 150 (SMART LAB.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUFRESH 150 (SMART LAB.)'
);

-- line #14580
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUFUNG 50 (EAST WEST)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUFUNG 50 (EAST WEST)'
);

-- line #14581
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUGEN 150 (Antigen Hc.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUGEN 150 (Antigen Hc.)'
);

-- line #14582
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUKA 2 (Cipla)',
	'Fluconazole',
	'INF',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUKA 2 (Cipla)'
);

-- line #14583
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUKA 150 (Cipla)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUKA 150 (Cipla)'
);

-- line #14584
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUMAX 100 (Zydus Cadila)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUMAX 100 (Zydus Cadila)'
);

-- line #14585
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUMED 100 (Zydus Cadila)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUMED 100 (Zydus Cadila)'
);

-- line #14586
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUMED 150 (Zydus Cadila)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUMED 150 (Zydus Cadila)'
);

-- line #14587
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUMED 50 (Zydus Cadila)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUMED 50 (Zydus Cadila)'
);

-- line #14588
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUMIT 150 (ADMIT)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUMIT 150 (ADMIT)'
);

-- line #14589
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUNA 150 (Medoz Ph.)',
	'Fluconazole',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUNA 150 (Medoz Ph.)'
);

-- line #14590
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUNAC 150 (Nac Int.)',
	'Fluconazole',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUNAC 150 (Nac Int.)'
);

-- line #14591
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUNA 150 (MODHIKE)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUNA 150 (MODHIKE)'
);

-- line #14592
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUNEC 150 (National)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUNEC 150 (National)'
);

-- line #14593
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUNEC 150 (NORTECH REM.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUNEC 150 (NORTECH REM.)'
);

-- line #14594
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUNEM 150 (NEMI PH.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUNEM 150 (NEMI PH.)'
);

-- line #14595
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUNOVA 50 (Zuventus)',
	'Fluconazole',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUNOVA 50 (Zuventus)'
);

-- line #14596
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUNOVA 0.3 (Zuventus)',
	'Fluconazole',
	'EYE DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUNOVA 0.3 (Zuventus)'
);

-- line #14597
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUNOVA 150 (Zuventus)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUNOVA 150 (Zuventus)'
);

-- line #14598
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUNOVA 200 (Zuventus)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUNOVA 200 (Zuventus)'
);

-- line #14599
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUOL 150 (Moraceae)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUOL 150 (Moraceae)'
);

-- line #14600
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUPAX 150 (Bipl(Radico Lab))',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUPAX 150 (Bipl(Radico Lab))'
);

-- line #14601
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUREL 150 (Allure Rem.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUREL 150 (Allure Rem.)'
);

-- line #14602
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUSCANE 150 (SALVO HC.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUSCANE 150 (SALVO HC.)'
);

-- line #14603
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUSON 150 (Patson)',
	'Fluconazole',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUSON 150 (Patson)'
);

-- line #14604
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUSTAR 150 (SIFAM PH.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUSTAR 150 (SIFAM PH.)'
);

-- line #14605
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUSTA 150 (Stalwart)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUSTA 150 (Stalwart)'
);

-- line #14606
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUSTATE 150 (Sayona)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUSTATE 150 (Sayona)'
);

-- line #14607
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUSYST 150 (Reliance)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUSYST 150 (Reliance)'
);

-- line #14608
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUTAS 150 (Intas)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUTAS 150 (Intas)'
);

-- line #14609
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUTAUR 150 (Taurus Lab)',
	'Fluconazole',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUTAUR 150 (Taurus Lab)'
);

-- line #14610
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUTAUR 0.3 (Taurus Lab)',
	'Fluconazole',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUTAUR 0.3 (Taurus Lab)'
);

-- line #14611
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUTEC 150 (Tripada BIO.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUTEC 150 (Tripada BIO.)'
);

-- line #14612
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUTEK 150 (Zetek Ph.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUTEK 150 (Zetek Ph.)'
);

-- line #14613
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUTROX 150 (Dabur Ph.)',
	'Fluconazole',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUTROX 150 (Dabur Ph.)'
);

-- line #14614
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUTROX 50 (Dabur Ph.)',
	'Fluconazole',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUTROX 50 (Dabur Ph.)'
);

-- line #14615
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUWAYZ 150 (INNOWAYZ PH.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUWAYZ 150 (INNOWAYZ PH.)'
);

-- line #14616
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUZA-150 150 (Jarson Ph.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUZA-150 150 (Jarson Ph.)'
);

-- line #14617
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUZAN 150 (Green Cross)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUZAN 150 (Green Cross)'
);

-- line #14618
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUZED 150 (Dial Ph.)',
	'Fluconazole',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUZED 150 (Dial Ph.)'
);

-- line #14619
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUZEET 150 (Sanify)',
	'Fluconazole',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUZEET 150 (Sanify)'
);

-- line #14620
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUZIDE 150 (Concept)',
	'Fluconazole',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUZIDE 150 (Concept)'
);

-- line #14621
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUZIDE 50 (Concept)',
	'Fluconazole',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUZIDE 50 (Concept)'
);

-- line #14622
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUZIDE 100 (Concept)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUZIDE 100 (Concept)'
);

-- line #14623
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUZOLE 150 (Intra Lab)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUZOLE 150 (Intra Lab)'
);

-- line #14624
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Fluconazole', u'always_empty': u'', u'form': u'TAB', u'brand': u'FLUZOL -', u'strength_3': u'', u'company': u'NIVCA', u'unit': u''}

-- line #14625
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUZOL 150 (NIVCA)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUZOL 150 (NIVCA)'
);

-- line #14626
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUZON 100 (Le Sante)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUZON 100 (Le Sante)'
);

-- line #14627
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUZON 150 (Le Sante)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUZON 150 (Le Sante)'
);

-- line #14628
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUZON 200 (Le Sante)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUZON 200 (Le Sante)'
);

-- line #14629
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUZON 50 (Le Sante)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUZON 50 (Le Sante)'
);

-- line #14630
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUZ 150 (Remedy)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUZ 150 (Remedy)'
);

-- line #14631
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLYCON 150 (Radix Bio.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLYCON 150 (Radix Bio.)'
);

-- line #14632
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOFLU 150 (Forgo Ph.)',
	'Fluconazole',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOFLU 150 (Forgo Ph.)'
);

-- line #14633
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLE 150 (Pharma Drugs)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLE 150 (Pharma Drugs)'
);

-- line #14634
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLE 100 (Unison)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLE 100 (Unison)'
);

-- line #14635
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLE 150 (Unison)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLE 150 (Unison)'
);

-- line #14636
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORCAN 150 (Cipla)',
	'Fluconazole',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORCAN 150 (Cipla)'
);

-- line #14637
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORCAN 200 (Cipla)',
	'Fluconazole',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORCAN 200 (Cipla)'
);

-- line #14638
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORCAN 50 (Cipla)',
	'Fluconazole',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORCAN 50 (Cipla)'
);

-- line #14639
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORCAN 100 (Cipla)',
	'Fluconazole',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORCAN 100 (Cipla)'
);

-- line #14640
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORCAN 2 (Cipla)',
	'Fluconazole',
	'INF',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORCAN 2 (Cipla)'
);

-- line #14641
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'150', u'strength_2': u'', u'substance': u'Fluconazole', u'always_empty': u'', u'form': u'', u'brand': u'FORCON-150', u'strength_3': u'', u'company': u'FORAM BIO.', u'unit': u'mg'}

-- line #14642
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOREBID 150 (PHARMA P.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOREBID 150 (PHARMA P.)'
);

-- line #14643
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUCOGAL 150 (Medizone)',
	'Fluconazole',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUCOGAL 150 (Medizone)'
);

-- line #14644
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUGNARD 50 (Finecure)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUGNARD 50 (Finecure)'
);

-- line #14645
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUMYCIN 150 (Pfizer)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUMYCIN 150 (Pfizer)'
);

-- line #14646
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNASIS 150 (Nestor)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNASIS 150 (Nestor)'
);

-- line #14647
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNAZOLE 150 (Elfin Ph.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNAZOLE 150 (Elfin Ph.)'
);

-- line #14648
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNE 150 (Glow derma)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNE 150 (Glow derma)'
);

-- line #14649
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNGAL-F 150 (Inga)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNGAL-F 150 (Inga)'
);

-- line #14650
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNGAL-F 200 (Inga)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNGAL-F 200 (Inga)'
);

-- line #14651
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNGAL-F 50 (Inga)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNGAL-F 50 (Inga)'
);

-- line #14652
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNGAL 150 (Sanjeevani Bio.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNGAL 150 (Sanjeevani Bio.)'
);

-- line #14653
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNGARD 100 (Finecure)',
	'Fluconazole',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNGARD 100 (Finecure)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNGARD 150 (Finecure)',
	'Fluconazole',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNGARD 150 (Finecure)'
);

-- line #14654
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNGARD 200 (Finecure)',
	'Fluconazole',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNGARD 200 (Finecure)'
);

-- line #14655
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNGAZOL 150 (Osper)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNGAZOL 150 (Osper)'
);

-- line #14656
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNGDOR 150 (Candor Bio.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNGDOR 150 (Candor Bio.)'
);

-- line #14657
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNGIBAN 200 (Medopharm)',
	'Fluconazole',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNGIBAN 200 (Medopharm)'
);

-- line #14658
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNGIBAN 50 (Medopharm)',
	'Fluconazole',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNGIBAN 50 (Medopharm)'
);

-- line #14659
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNGIBAN 50 (Medopharm)',
	'Fluconazole',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNGIBAN 50 (Medopharm)'
);

-- line #14660
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNGIBAN 150 (Medopharm)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNGIBAN 150 (Medopharm)'
);

-- line #14661
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNGICARE 150 (Lancer)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNGICARE 150 (Lancer)'
);

-- line #14662
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNGICIP 150 (Cipla)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNGICIP 150 (Cipla)'
);

-- line #14663
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNGICON 0.3 (Micro V.)',
	'Fluconazole',
	'EYE DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNGICON 0.3 (Micro V.)'
);

-- line #14664
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNGICON 150 (Micro Nova)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNGICON 150 (Micro Nova)'
);

-- line #14665
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNGID-50 50 (Bestochem)',
	'Fluconazole',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNGID-50 50 (Bestochem)'
);

-- line #14666
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNGID 150 (Bestochem)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNGID 150 (Bestochem)'
);

-- line #14667
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNGINA 150 (Micro Labs)',
	'Fluconazole',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNGINA 150 (Micro Labs)'
);

-- line #14668
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNGINIL 150 (Stallion)',
	'Fluconazole',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNGINIL 150 (Stallion)'
);

-- line #14669
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNGINIL 150 (Mdc Ph.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNGINIL 150 (Mdc Ph.)'
);

-- line #14670
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNGIN 50 (Dppl)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNGIN 50 (Dppl)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNGIN 150 (Dppl)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNGIN 150 (Dppl)'
);

-- line #14671
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNGIRID 150 (Klm Ph.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNGIRID 150 (Klm Ph.)'
);

-- line #14672
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNGISAN-F 150 (Sresan Ph.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNGISAN-F 150 (Sresan Ph.)'
);

-- line #14673
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNGISTAT 150 (Group Ph.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNGISTAT 150 (Group Ph.)'
);

-- line #14674
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNGNO 150 (Dallas Ph.)',
	'Fluconazole',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNGNO 150 (Dallas Ph.)'
);

-- line #14675
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNGO 150 (ORION BIOTECH.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNGO 150 (ORION BIOTECH.)'
);

-- line #14676
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNNIE 50 (INVISION(INFALIFE))',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNNIE 50 (INVISION(INFALIFE))'
);

-- line #14677
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNSPOR 150 (Dwd)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNSPOR 150 (Dwd)'
);

-- line #14678
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUSPIN 150 (Cerspin)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUSPIN 150 (Cerspin)'
);

-- line #14679
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUSYS 50 (Liva Hc.)',
	'Fluconazole',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUSYS 50 (Liva Hc.)'
);

-- line #14680
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUSYS 150 (Liva Hc.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUSYS 150 (Liva Hc.)'
);

-- line #14681
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUSYS 200 (Liva Hc.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUSYS 200 (Liva Hc.)'
);

-- line #14682
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUTIZA 150 (Morepen)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUTIZA 150 (Morepen)'
);

-- line #14683
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUTIZA 200 (Morepen)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUTIZA 200 (Morepen)'
);

-- line #14684
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUTIZA 50 (Morepen)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUTIZA 50 (Morepen)'
);

-- line #14685
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUZEN 150 (AXEN PH.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUZEN 150 (AXEN PH.)'
);

-- line #14686
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUZOL 150 (Franklin)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUZOL 150 (Franklin)'
);

-- line #14687
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FY 150 (Brooks Ph.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FY 150 (Brooks Ph.)'
);

-- line #14688
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FZ-50/150 50 (Brawn Lab)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FZ-50/150 50 (Brawn Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FZ-50/150 150 (Brawn Lab)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FZ-50/150 150 (Brawn Lab)'
);

-- line #14689
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'F-ZOL 50 (Dynamic)',
	'Fluconazole',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'F-ZOL 50 (Dynamic)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'F-ZOL 150 (Dynamic)',
	'Fluconazole',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'F-ZOL 150 (Dynamic)'
);

-- line #14690
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'F-ZOLE 150 (CITIZEN LAB.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'F-ZOLE 150 (CITIZEN LAB.)'
);

-- line #14691
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'F-ZOLE 150 (ETHIX HC.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'F-ZOLE 150 (ETHIX HC.)'
);

-- line #14692
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLENFLU 150 (Glenmark)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLENFLU 150 (Glenmark)'
);

-- line #14693
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GOCAN 150 (Genx Ph.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GOCAN 150 (Genx Ph.)'
);

-- line #14694
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HILZOL 150 (HIND. LATEX)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HILZOL 150 (HIND. LATEX)'
);

-- line #14695
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HINZOLE 150 (PERK PH.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HINZOLE 150 (PERK PH.)'
);

-- line #14696
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JP CON 150 (J.P. HC.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JP CON 150 (J.P. HC.)'
);

-- line #14697
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JP CON 150 (J.P.LIFE)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JP CON 150 (J.P.LIFE)'
);

-- line #14698
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JUCAN 150 (D.R.John''S)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JUCAN 150 (D.R.John''S)'
);

-- line #14699
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'K-FLU 150 (KPL LIFE)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'K-FLU 150 (KPL LIFE)'
);

-- line #14700
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KOZOLE 50 (Brawn Lab)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KOZOLE 50 (Brawn Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KOZOLE 150 (Brawn Lab)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KOZOLE 150 (Brawn Lab)'
);

-- line #14701
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEOCAN DUSTING 0.5 (LEOLIFE)',
	'Fluconazole',
	'POW',
	gm.nullify_empty_string('0.5')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEOCAN DUSTING 0.5 (LEOLIFE)'
);

-- line #14702
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIDO 200 (D.R.John''S)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIDO 200 (D.R.John''S)'
);

-- line #14703
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIDO 50 (D.R.John''S)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIDO 50 (D.R.John''S)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIDO 150 (D.R.John''S)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIDO 150 (D.R.John''S)'
);

-- line #14704
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LODO 150 (D.R.John''S)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LODO 150 (D.R.John''S)'
);

-- line #14705
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOGICAN 50 (Win-Medicare)',
	'Fluconazole',
	'CAP/TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOGICAN 50 (Win-Medicare)'
);

-- line #14706
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOGICAN 100 (Win-Medicare)',
	'Fluconazole',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOGICAN 100 (Win-Medicare)'
);

-- line #14707
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOGICAN 150 (Win-Medicare)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOGICAN 150 (Win-Medicare)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOGICAN 200 (Win-Medicare)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOGICAN 200 (Win-Medicare)'
);

-- line #14708
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MENIN 150 (Shinto Org.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MENIN 150 (Shinto Org.)'
);

-- line #14709
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MERICAM 150 (Merit Org.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MERICAM 150 (Merit Org.)'
);

-- line #14710
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'M-FLUK 150 (MADHAV BIO.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'M-FLUK 150 (MADHAV BIO.)'
);

-- line #14711
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOCAN 150 (Southsourne)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOCAN 150 (Southsourne)'
);

-- line #14712
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCOCIN 0.3 (VICTOR REM.)',
	'Fluconazole',
	'E/E DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCOCIN 0.3 (VICTOR REM.)'
);

-- line #14713
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCONAZ 150 (Baroque)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCONAZ 150 (Baroque)'
);

-- line #14714
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCONORM-F 150 (Pil)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCONORM-F 150 (Pil)'
);

-- line #14715
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCOREST 150 (Zydus Cadila)',
	'Fluconazole',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCOREST 150 (Zydus Cadila)'
);

-- line #14716
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCOREST 200 (Zydus Cadila)',
	'Fluconazole',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCOREST 200 (Zydus Cadila)'
);

-- line #14717
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCOREST 50 (Zydus Cadila)',
	'Fluconazole',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCOREST 50 (Zydus Cadila)'
);

-- line #14718
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCOSURE 150 (LUPINOVA)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCOSURE 150 (LUPINOVA)'
);

-- line #14719
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYZOLE 150 (Admac (CADMA))',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYZOLE 150 (Admac (CADMA))'
);

-- line #14720
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOCAN 150 (Royal Lab)',
	'Fluconazole',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOCAN 150 (Royal Lab)'
);

-- line #14721
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOCON 150 (ACTO)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOCON 150 (ACTO)'
);

-- line #14722
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEWCAN 150 (Dr.Arvind Shah''S)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEWCAN 150 (Dr.Arvind Shah''S)'
);

-- line #14723
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIPCAN 200 (Ipca)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIPCAN 200 (Ipca)'
);

-- line #14724
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIPCAN 50 (Ipca)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIPCAN 50 (Ipca)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIPCAN 150 (Ipca)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIPCAN 150 (Ipca)'
);

-- line #14725
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOCAN 150 (Prochem)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOCAN 150 (Prochem)'
);

-- line #14726
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NO FUNG 150 (Mamta Ph.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NO FUNG 150 (Mamta Ph.)'
);

-- line #14727
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NTFUNG 150 (KIVI LABS)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NTFUNG 150 (KIVI LABS)'
);

-- line #14728
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUFLUCON 50 (Nulife)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUFLUCON 50 (Nulife)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUFLUCON 150 (Nulife)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUFLUCON 150 (Nulife)'
);

-- line #14729
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUFORCE 150 (Mankind)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUFORCE 150 (Mankind)'
);

-- line #14730
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUFORCE 200 (Mankind)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUFORCE 200 (Mankind)'
);

-- line #14731
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUFORCE 400 (Mankind)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUFORCE 400 (Mankind)'
);

-- line #14732
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCAN-150 150 (G.Nine Form.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCAN-150 150 (G.Nine Form.)'
);

-- line #14733
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODCAN 150 (PRISM LIFESCI.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODCAN 150 (PRISM LIFESCI.)'
);

-- line #14734
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODCAN 200 (PRISM LIFESCI.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODCAN 200 (PRISM LIFESCI.)'
);

-- line #14735
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODCAN 50 (PRISM LIFESCI.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODCAN 50 (PRISM LIFESCI.)'
);

-- line #14736
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODICON 150 (Rapross)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODICON 150 (Rapross)'
);

-- line #14737
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONECAN 150 (Wallace)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONECAN 150 (Wallace)'
);

-- line #14738
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONECAN 200 (Wallace)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONECAN 200 (Wallace)'
);

-- line #14739
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONECAN 50 (Wallace)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONECAN 50 (Wallace)'
);

-- line #14740
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OROCAN 150 (Raddison Hc.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OROCAN 150 (Raddison Hc.)'
);

-- line #14741
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXYZOLE 150 (AXYZEN LIFE)',
	'Fluconazole',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXYZOLE 150 (AXYZEN LIFE)'
);

-- line #14742
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q CAN 150 (Que Ph.)',
	'Fluconazole',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q CAN 150 (Que Ph.)'
);

-- line #14743
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q CAN 200 (Que Ph.)',
	'Fluconazole',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q CAN 200 (Que Ph.)'
);

-- line #14744
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q CAN 50 (Que Ph.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q CAN 50 (Que Ph.)'
);

-- line #14745
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REFUSE 150 (FORTUNE HC.)',
	'Fluconazole',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REFUSE 150 (FORTUNE HC.)'
);

-- line #14746
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REZOLE 150 (Regen Int.)',
	'Fluconazole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REZOLE 150 (Regen Int.)'
);

-- line #14747
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUDACEL 50 (CELON(VIVILON))',
	'Fludarabine',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUDACEL 50 (CELON(VIVILON))'
);

-- line #14748
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUDACEL 10 (CELON(VIVILON))',
	'Fludarabine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUDACEL 10 (CELON(VIVILON))'
);

-- line #14749
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUDAPHOS 10 (Bharat S.)',
	'Fludarabine',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUDAPHOS 10 (Bharat S.)'
);

-- line #14750
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUDAPHOS 50 (Bharat S.)',
	'Fludarabine',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUDAPHOS 50 (Bharat S.)'
);

-- line #14751
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUDARA 50 (German R.)',
	'Fludarabine',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUDARA 50 (German R.)'
);

-- line #14752
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUDARA ORAL 10 (German R.)',
	'Fludarabine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUDARA ORAL 10 (German R.)'
);

-- line #14753
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUDARIN 50 (Intas)',
	'Fludarabine',
	'VIAL',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUDARIN 50 (Intas)'
);

-- line #14754
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100MCG', u'strength_2': u'', u'substance': u'Fludrocortisone', u'always_empty': u'', u'form': u'TAB', u'brand': u'FLORICOT', u'strength_3': u'', u'company': u'Samarth', u'unit': u''}

-- line #14755
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Fludrocortisone', u'always_empty': u'', u'form': u'TAB', u'brand': u'MINOCORT', u'strength_3': u'', u'company': u'Troikaa', u'unit': u''}

-- line #14756
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOGRAN 10 (Chemo Bio.)',
	'Flunarizine',
	'F. TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOGRAN 10 (Chemo Bio.)'
);

-- line #14757
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EFIGRAINE 10 (MOLEKULE)',
	'Flunarizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EFIGRAINE 10 (MOLEKULE)'
);

-- line #14758
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EFIGRAINE 5 (MOLEKULE)',
	'Flunarizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EFIGRAINE 5 (MOLEKULE)'
);

-- line #14759
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FINE 10 (BARODA)',
	'Flunarizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FINE 10 (BARODA)'
);

-- line #14760
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FINE 5 (BARODA)',
	'Flunarizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FINE 5 (BARODA)'
);

-- line #14761
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUBERY 10 (HANBURYS)',
	'Flunarizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUBERY 10 (HANBURYS)'
);

-- line #14762
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUDRIN 5 (Sunrise Rem.)',
	'Flunarizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUDRIN 5 (Sunrise Rem.)'
);

-- line #14763
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUGRAINE 10 (Mano)',
	'Flunarizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUGRAINE 10 (Mano)'
);

-- line #14764
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUGRAINE 5 (Mano)',
	'Flunarizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUGRAINE 5 (Mano)'
);

-- line #14765
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUMIG 10 (NAVNIDHI LIFE)',
	'Flunarizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUMIG 10 (NAVNIDHI LIFE)'
);

-- line #14766
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUMIG 5 (TALENT LAB.)',
	'Flunarizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUMIG 5 (TALENT LAB.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUMIG 10 (TALENT LAB.)',
	'Flunarizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUMIG 10 (TALENT LAB.)'
);

-- line #14767
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUNAREST 10 (SENSES)',
	'Flunarizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUNAREST 10 (SENSES)'
);

-- line #14768
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUNARIN 10 (F D C)',
	'Flunarizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUNARIN 10 (F D C)'
);

-- line #14769
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUNARIN 5 (F D C)',
	'Flunarizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUNARIN 5 (F D C)'
);

-- line #14770
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUNATRAC 5 (MINOVA(PSYCHONOVA))',
	'Flunarizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUNATRAC 5 (MINOVA(PSYCHONOVA))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUNATRAC 10 (MINOVA(PSYCHONOVA))',
	'Flunarizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUNATRAC 10 (MINOVA(PSYCHONOVA))'
);

-- line #14771
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUNER 5 (Geno Ph.)',
	'Flunarizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg(IN BETA CYCLODEXT.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUNER 5 (Geno Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUNER 10 (Geno Ph.)',
	'Flunarizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg(IN BETA CYCLODEXT.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUNER 10 (Geno Ph.)'
);

-- line #14772
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLURY 5 (EAST WEST)',
	'Flunarizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLURY 5 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLURY 10 (EAST WEST)',
	'Flunarizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLURY 10 (EAST WEST)'
);

-- line #14773
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUVERT 5 (EAST WEST)',
	'Flunarizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUVERT 5 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUVERT 10 (EAST WEST)',
	'Flunarizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUVERT 10 (EAST WEST)'
);

-- line #14774
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUZINE 10 (TASMED)',
	'Flunarizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUZINE 10 (TASMED)'
);

-- line #14775
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUZINE 5 (TASMED)',
	'Flunarizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUZINE 5 (TASMED)'
);

-- line #14776
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUZ 5 (EAST WEST)',
	'Flunarizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUZ 5 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUZ 10 (EAST WEST)',
	'Flunarizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUZ 10 (EAST WEST)'
);

-- line #14777
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'F-ZINE 5 (Vgr Bio.)',
	'Flunarizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'F-ZINE 5 (Vgr Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'F-ZINE 10 (Vgr Bio.)',
	'Flunarizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'F-ZINE 10 (Vgr Bio.)'
);

-- line #14778
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRATON 10 (TRITON(CALYX))',
	'Flunarizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRATON 10 (TRITON(CALYX))'
);

-- line #14779
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRATON 5 (TRITON(CALYX))',
	'Flunarizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRATON 5 (TRITON(CALYX))'
);

-- line #14780
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10', u'strength_2': u'', u'substance': u'Flunarizine', u'always_empty': u'', u'form': u'', u'brand': u'GRENIL-F', u'strength_3': u'', u'company': u'Kapl', u'unit': u'mg'}

-- line #14781
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5', u'strength_2': u'', u'substance': u'Flunarizine', u'always_empty': u'', u'form': u'', u'brand': u'GRENIL-F', u'strength_3': u'', u'company': u'Kapl', u'unit': u'mg'}

-- line #14782
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MGR 5 (Inga)',
	'Flunarizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MGR 5 (Inga)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MGR 10 (Inga)',
	'Flunarizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MGR 10 (Inga)'
);

-- line #14783
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIGARID 10 (Cipla)',
	'Flunarizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIGARID 10 (Cipla)'
);

-- line #14784
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIGARID 5 (Cipla)',
	'Flunarizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIGARID 5 (Cipla)'
);

-- line #14785
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIGAZIN 10 (Morepen)',
	'Flunarizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIGAZIN 10 (Morepen)'
);

-- line #14786
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIGAZIN 5 (Morepen)',
	'Flunarizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIGAZIN 5 (Morepen)'
);

-- line #14787
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIGON 10 (Le Sante)',
	'Flunarizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIGON 10 (Le Sante)'
);

-- line #14788
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIGON 5 (Le Sante)',
	'Flunarizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIGON 5 (Le Sante)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIGON 10 (Le Sante)',
	'Flunarizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIGON 10 (Le Sante)'
);

-- line #14789
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIGRANEX 5 (Intas)',
	'Flunarizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIGRANEX 5 (Intas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIGRANEX 10 (Intas)',
	'Flunarizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIGRANEX 10 (Intas)'
);

-- line #14790
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIGRECURE 5 (Sterkem Ph.)',
	'Flunarizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'10'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIGRECURE 5 (Sterkem Ph.)'
);

-- line #14791
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIGRID 5 (Crescent Th.)',
	'Flunarizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIGRID 5 (Crescent Th.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIGRID 10 (Crescent Th.)',
	'Flunarizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIGRID 10 (Crescent Th.)'
);

-- line #14792
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NARIZ 10 (Sante V.)',
	'Flunarizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NARIZ 10 (Sante V.)'
);

-- line #14793
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NARIZ 5 (Sante V.)',
	'Flunarizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NARIZ 5 (Sante V.)'
);

-- line #14794
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NARZINE 10 (PSYCOREM)',
	'Flunarizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NARZINE 10 (PSYCOREM)'
);

-- line #14795
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NARZINE 5 (PSYCOREM)',
	'Flunarizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NARZINE 5 (PSYCOREM)'
);

-- line #14796
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10', u'strength_2': u'', u'substance': u'Flunarizine', u'always_empty': u'', u'form': u'', u'brand': u'NOMIGAN', u'strength_3': u'', u'company': u'KIVI HC.', u'unit': u'mg'}

-- line #14797
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOMIGRAIN 10 (Torrent)',
	'Flunarizine',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOMIGRAIN 10 (Torrent)'
);

-- line #14798
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOMIGRAIN 5 (Torrent)',
	'Flunarizine',
	'CAP',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOMIGRAIN 5 (Torrent)'
);

-- line #14799
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROFIGRAN 5 (Pentacare)',
	'Flunarizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROFIGRAN 5 (Pentacare)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROFIGRAN 10 (Pentacare)',
	'Flunarizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROFIGRAN 10 (Pentacare)'
);

-- line #14800
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUTI 0.025 (Euphoric)',
	'Fluocinolone Acetonide',
	'CRM',
	gm.nullify_empty_string('0.025')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUTI 0.025 (Euphoric)'
);

-- line #14801
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMDERM 0.025 (Emcure)',
	'Fluocinolone Acetonide',
	'CRM',
	gm.nullify_empty_string('0.025')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMDERM 0.025 (Emcure)'
);

-- line #14802
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUCIN 0.025 (AGIO PH.)',
	'Fluocinolone Acetonide',
	'CRM',
	gm.nullify_empty_string('0.025')::numeric,
	'%W/W/G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUCIN 0.025 (AGIO PH.)'
);

-- line #14803
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUCOCIN 0.025 (Micro Labs)',
	'Fluocinolone Acetonide',
	'OINT',
	gm.nullify_empty_string('0.025')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUCOCIN 0.025 (Micro Labs)'
);

-- line #14804
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUCORT 0.025 (Gracewell)',
	'Fluocinolone Acetonide',
	'CRM',
	gm.nullify_empty_string('0.025')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUCORT 0.025 (Gracewell)'
);

-- line #14805
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUCORT 0.025 (Gracewell)',
	'Fluocinolone Acetonide',
	'GEL',
	gm.nullify_empty_string('0.025')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUCORT 0.025 (Gracewell)'
);

-- line #14806
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUCORT-H 0.1 (Gracewell)',
	'Fluocinolone Acetonide',
	'OINT',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUCORT-H 0.1 (Gracewell)'
);

-- line #14807
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUCORT 0.01 (Gracewell)',
	'Fluocinolone Acetonide',
	'LOT',
	gm.nullify_empty_string('0.01')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUCORT 0.01 (Gracewell)'
);

-- line #14808
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUCORT 0.025 (Gracewell)',
	'Fluocinolone Acetonide',
	'LOT',
	gm.nullify_empty_string('0.025')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUCORT 0.025 (Gracewell)'
);

-- line #14809
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUCORT 0.025 (Gracewell)',
	'Fluocinolone Acetonide',
	'OINT',
	gm.nullify_empty_string('0.025')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUCORT 0.025 (Gracewell)'
);

-- line #14810
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUSION 0.025 (AGIO PH.)',
	'Fluocinolone Acetonide',
	'CRM',
	gm.nullify_empty_string('0.025')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUSION 0.025 (AGIO PH.)'
);

-- line #14811
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUCI 0.025 (Ranbaxy)',
	'Fluocinolone Acetonide',
	'CRM',
	gm.nullify_empty_string('0.025')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUCI 0.025 (Ranbaxy)'
);

-- line #14812
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUORE STAIN 4 (Bell Ph.)',
	'Fluorescein Sod.',
	'STRIPS',
	gm.nullify_empty_string('4')::numeric,
	'% AS OPHTHAL.APPLICATOR'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUORE STAIN 4 (Bell Ph.)'
);

-- line #14813
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLURESIN 600 (Samarth)',
	'Fluorescein Sod.',
	'INJ',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLURESIN 600 (Samarth)'
);

-- line #14814
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIFLACE 0.1 (Alembic)',
	'Fluorometholone',
	'DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIFLACE 0.1 (Alembic)'
);

-- line #14815
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'E-FLO 1 (Entod Ph.)',
	'Fluorometholone',
	'EYE DPS',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'E-FLO 1 (Entod Ph.)'
);

-- line #14816
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAA 0.1 (BALAJI PH.)',
	'Fluorometholone',
	'EYE DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAA 0.1 (BALAJI PH.)'
);

-- line #14817
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLAREX OPTHALM 0.1 (Alcon Lab)',
	'Fluorometholone',
	'SOL',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLAREX OPTHALM 0.1 (Alcon Lab)'
);

-- line #14818
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLI 0.1 (SENSES)',
	'Fluorometholone',
	'DROPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLI 0.1 (SENSES)'
);

-- line #14819
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOMEX 0.1 (Cipla)',
	'Fluorometholone',
	'EYE DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOMEX 0.1 (Cipla)'
);

-- line #14820
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOMON 0.1 (F D C)',
	'Fluorometholone',
	'EYE DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOMON 0.1 (F D C)'
);

-- line #14821
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOSEF 1 (Sun)',
	'Fluorometholone',
	'EYE DPS',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOSEF 1 (Sun)'
);

-- line #14822
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUMACE 0.1 (Micro Labs)',
	'Fluorometholone',
	'EYE DROP',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUMACE 0.1 (Micro Labs)'
);

-- line #14823
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLURISONE 0.1 (Micro V.)',
	'Fluorometholone',
	'EYE DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%/0.25'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLURISONE 0.1 (Micro V.)'
);

-- line #14824
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLURISONE 0.1 (Micro Labs)',
	'Fluorometholone',
	'EYE OINT',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLURISONE 0.1 (Micro Labs)'
);

-- line #14825
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUROCOT 0.1 (Appasamy)',
	'Fluorometholone',
	'EYE DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUROCOT 0.1 (Appasamy)'
);

-- line #14826
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLURO 0.1 (DREAM PH.)',
	'Fluorometholone',
	'SOL',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLURO 0.1 (DREAM PH.)'
);

-- line #14827
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LON 0.1 (Pharmtak)',
	'Fluorometholone',
	'VIAL',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LON 0.1 (Pharmtak)'
);

-- line #14828
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLORAC 50 (Cadila Ph.)',
	'Fluorouracil',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLORAC 50 (Cadila Ph.)'
);

-- line #14829
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KUCIL 250 (Khandelwal)',
	'Fluorouracil',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KUCIL 250 (Khandelwal)'
);

-- line #14830
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KUCIL 500 (Khandelwal)',
	'Fluorouracil',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KUCIL 500 (Khandelwal)'
);

-- line #14831
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONCOURCIL 250 (SUN)',
	'Fluorouracil',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONCOURCIL 250 (SUN)'
);

-- line #14832
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AFZOT 20 (Pifer Ph.)',
	'Fluoxetine Hcl.',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AFZOT 20 (Pifer Ph.)'
);

-- line #14833
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARKADEP 20 (Rkg)',
	'Fluoxetine Hcl.',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARKADEP 20 (Rkg)'
);

-- line #14834
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BAROZAC 10 (BARODA)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'20'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BAROZAC 10 (BARODA)'
);

-- line #14835
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOXITINE 20 (Rhombus)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOXITINE 20 (Rhombus)'
);

-- line #14836
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CADDY 20 (Cyril Ph.)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CADDY 20 (Cyril Ph.)'
);

-- line #14837
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CADFLO 20 (Zydus Cadila(Mm))',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CADFLO 20 (Zydus Cadila(Mm))'
);

-- line #14838
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COOL 20 (Shinto Org.)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COOL 20 (Shinto Org.)'
);

-- line #14839
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DALTIN 20 (Dallas Ph.)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DALTIN 20 (Dallas Ph.)'
);

-- line #14840
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAWNEX 20 (Micro Labs)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAWNEX 20 (Micro Labs)'
);

-- line #14841
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEDEP 20 (S P Ph.)',
	'Fluoxetine Hcl.',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEDEP 20 (S P Ph.)'
);

-- line #14842
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPCURE 20 (Patson)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPCURE 20 (Patson)'
);

-- line #14843
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPEXTINE 20 (Paras Lab)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPEXTINE 20 (Paras Lab)'
);

-- line #14844
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPFLU 20 (Royal)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPFLU 20 (Royal)'
);

-- line #14845
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPLOID 10 (NOVARTIS)',
	'Fluoxetine Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPLOID 10 (NOVARTIS)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPLOID 20 (NOVARTIS)',
	'Fluoxetine Hcl.',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPLOID 20 (NOVARTIS)'
);

-- line #14846
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPOXIT 20 (Olcare)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPOXIT 20 (Olcare)'
);

-- line #14847
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPTEN 20 (PSYCOREM)',
	'Fluoxetine Hcl.',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPTEN 20 (PSYCOREM)'
);

-- line #14848
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPZAC 20 (Cipla)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'40'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPZAC 20 (Cipla)'
);

-- line #14849
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EASY 20 (Medo Chem)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EASY 20 (Medo Chem)'
);

-- line #14850
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELEMOD 20 (Lancer)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELEMOD 20 (Lancer)'
);

-- line #14851
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENDEP 20 (Numarck Ph.)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENDEP 20 (Numarck Ph.)'
);

-- line #14852
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXITEN 20 (Synokem)',
	'Fluoxetine Hcl.',
	'SUS',
	gm.nullify_empty_string('20')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXITEN 20 (Synokem)'
);

-- line #14853
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXITEN 20 (Synokem)',
	'Fluoxetine Hcl.',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXITEN 20 (Synokem)'
);

-- line #14854
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXTROZEN 20 (Arbro Ph.)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXTROZEN 20 (Arbro Ph.)'
);

-- line #14855
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FADEP 20 (Winsome Lab)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FADEP 20 (Winsome Lab)'
);

-- line #14856
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAXTIN 20 (Ind-Swift)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAXTIN 20 (Ind-Swift)'
);

-- line #14857
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOOD 10 (K.C. Lab)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOOD 10 (K.C. Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOOD 20 (K.C. Lab)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOOD 20 (K.C. Lab)'
);

-- line #14858
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXETIN 20 (Waves Bio.)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXETIN 20 (Waves Bio.)'
);

-- line #14859
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLU 20 (Sbeed Hc.)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLU 20 (Sbeed Hc.)'
);

-- line #14860
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUCHEM 20 (Chemo Bio.)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUCHEM 20 (Chemo Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUCHEM 60 (Chemo Bio.)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUCHEM 60 (Chemo Bio.)'
);

-- line #14861
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUDAC 10 (Cadila Ph.)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUDAC 10 (Cadila Ph.)'
);

-- line #14862
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUDAC 20 (Cadila Ph.)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUDAC 20 (Cadila Ph.)'
);

-- line #14863
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUDAC 60 (Cadila Ph.)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUDAC 60 (Cadila Ph.)'
);

-- line #14864
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUDAC 20 (Cadila Ph.)',
	'Fluoxetine Hcl.',
	'SUS',
	gm.nullify_empty_string('20')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUDAC 20 (Cadila Ph.)'
);

-- line #14865
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUDAWN 20 (Synchro)',
	'Fluoxetine Hcl.',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUDAWN 20 (Synchro)'
);

-- line #14866
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUDEN 20 (STADCHEM)',
	'Fluoxetine Hcl.',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUDEN 20 (STADCHEM)'
);

-- line #14867
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUDEP 10 (EAST WEST)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'20'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUDEP 10 (EAST WEST)'
);

-- line #14868
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUDEP 60 (EAST WEST)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUDEP 60 (EAST WEST)'
);

-- line #14869
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUEX 20 (Group Ph.)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUEX 20 (Group Ph.)'
);

-- line #14870
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUFRAN 20 (Unique)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUFRAN 20 (Unique)'
);

-- line #14871
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUGEN 20 (LA DRUG)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUGEN 20 (LA DRUG)'
);

-- line #14872
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'Fluoxetine Hcl.', u'always_empty': u'', u'form': u'', u'brand': u'FLUMAN', u'strength_3': u'', u'company': u'ROSE LABS', u'unit': u'mg'}

-- line #14873
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUMOD 20 (SHINE PH.)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUMOD 20 (SHINE PH.)'
);

-- line #14874
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUNAT 10 (Solares (Sun))',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUNAT 10 (Solares (Sun))'
);

-- line #14875
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUNAT 20 (Solares (Sun))',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUNAT 20 (Solares (Sun))'
);

-- line #14876
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUNIL 10 (Intas)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUNIL 10 (Intas)'
);

-- line #14877
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUNIL 20 (Intas)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUNIL 20 (Intas)'
);

-- line #14878
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUNIL 40 (Intas)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUNIL 40 (Intas)'
);

-- line #14879
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUNIL 60 (Intas)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUNIL 60 (Intas)'
);

-- line #14880
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUNIL 20 (Intas)',
	'Fluoxetine Hcl.',
	'SYR',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUNIL 20 (Intas)'
);

-- line #14881
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLURAN 20 (Runa Ph.)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLURAN 20 (Runa Ph.)'
);

-- line #14882
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLURON 20 (Kamron)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLURON 20 (Kamron)'
);

-- line #14883
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUTAL 20 (TALENT LAB.)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUTAL 20 (TALENT LAB.)'
);

-- line #14884
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUTEX 20 (Emil Ph.)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUTEX 20 (Emil Ph.)'
);

-- line #14885
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUTIN 20 (EAST WEST)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUTIN 20 (EAST WEST)'
);

-- line #14886
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUTIN 20 (Elfin Ph.)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUTIN 20 (Elfin Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUTIN 60 (Elfin Ph.)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUTIN 60 (Elfin Ph.)'
);

-- line #14887
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUTINE 20 (Dial Ph.)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUTINE 20 (Dial Ph.)'
);

-- line #14888
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUTINE 10 (Reliance)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUTINE 10 (Reliance)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUTINE 20 (Reliance)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUTINE 20 (Reliance)'
);

-- line #14889
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUTINOL 20 (Sun)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUTINOL 20 (Sun)'
);

-- line #14890
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUTOP-DR 90 (Crescent Th.)',
	'Fluoxetine Hcl.',
	'TAB',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUTOP-DR 90 (Crescent Th.)'
);

-- line #14891
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUTOP 10 (Crescent Th.)',
	'Fluoxetine Hcl.',
	'LA TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUTOP 10 (Crescent Th.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUTOP 20 (Crescent Th.)',
	'Fluoxetine Hcl.',
	'LA TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUTOP 20 (Crescent Th.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUTOP 40 (Crescent Th.)',
	'Fluoxetine Hcl.',
	'LA TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUTOP 40 (Crescent Th.)'
);

-- line #14892
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUTRAC 20 (MINOVA(PSYCHONOVA))',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUTRAC 20 (MINOVA(PSYCHONOVA))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUTRAC 60 (MINOVA(PSYCHONOVA))',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUTRAC 60 (MINOVA(PSYCHONOVA))'
);

-- line #14893
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUTRIC 20 (Chemo D.)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUTRIC 20 (Chemo D.)'
);

-- line #14894
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUXAL 20 (Albert D.)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUXAL 20 (Albert D.)'
);

-- line #14895
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUX 20 (Aarpik Ph.)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUX 20 (Aarpik Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUX 40 (Aarpik Ph.)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUX 40 (Aarpik Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUX 60 (Aarpik Ph.)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUX 60 (Aarpik Ph.)'
);

-- line #14896
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUX 20 (Sain Med.)',
	'Fluoxetine Hcl.',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUX 20 (Sain Med.)'
);

-- line #14897
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUZE 20 (Zee Lab)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUZE 20 (Zee Lab)'
);

-- line #14898
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRILOC 20 (D.R.John''S)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRILOC 20 (D.R.John''S)'
);

-- line #14899
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HT-20 20 (GENESIS)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HT-20 20 (GENESIS)'
);

-- line #14900
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOFTIL 20 (Nicholas)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOFTIL 20 (Nicholas)'
);

-- line #14901
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOFTIL 20 (Piramal Hc.)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOFTIL 20 (Piramal Hc.)'
);

-- line #14902
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'Fluoxetine Hcl.', u'always_empty': u'', u'form': u'', u'brand': u'MEDIDEP', u'strength_3': u'', u'company': u'MEDIFORECE', u'unit': u'mg'}

-- line #14903
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MENTOL 10 (Marc Lab)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MENTOL 10 (Marc Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MENTOL 20 (Marc Lab)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MENTOL 20 (Marc Lab)'
);

-- line #14904
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MENTOL 40 (Marc Lab)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MENTOL 40 (Marc Lab)'
);

-- line #14905
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOC 10 (Mano)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOC 10 (Mano)'
);

-- line #14906
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOC 20 (Mano)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOC 20 (Mano)'
);

-- line #14907
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUZAC 10 (Protec)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUZAC 10 (Protec)'
);

-- line #14908
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUZAC 20 (Protec)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUZAC 20 (Protec)'
);

-- line #14909
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXEDEP 20 (Torrent)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXEDEP 20 (Torrent)'
);

-- line #14910
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAXIT 10 (OREVA DARMO.)',
	'Fluoxetine Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAXIT 10 (OREVA DARMO.)'
);

-- line #14911
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERSONA 20 (Yash Ph.)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERSONA 20 (Yash Ph.)'
);

-- line #14912
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLATIN 10 (Merind)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLATIN 10 (Merind)'
);

-- line #14913
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLATIN 20 (Merind)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLATIN 20 (Merind)'
);

-- line #14914
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRODAC 20 (Rpg Life)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRODAC 20 (Rpg Life)'
);

-- line #14915
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRODEP 10 (Sun)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRODEP 10 (Sun)'
);

-- line #14916
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRODEP 20 (Sun)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRODEP 20 (Sun)'
);

-- line #14917
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRODEP 60 (Sun)',
	'Fluoxetine Hcl.',
	'CAP',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRODEP 60 (Sun)'
);

-- line #14918
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRODEP 20 (Sun)',
	'Fluoxetine Hcl.',
	'SUS',
	gm.nullify_empty_string('20')::numeric,
	'mg/5 ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRODEP 20 (Sun)'
);

-- line #14919
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRONIL 20 (Pil)',
	'Fluoxetine Hcl.',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRONIL 20 (Pil)'
);

-- line #14920
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUANXOL DEPOT 1 (Lundbeck)',
	'Flupenthixol',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUANXOL DEPOT 1 (Lundbeck)'
);

-- line #14921
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUANXOL DEPOT 2 (Lundbeck)',
	'Flupenthixol',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUANXOL DEPOT 2 (Lundbeck)'
);

-- line #14922
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUANXOL 0.5 (Lundbeck)',
	'Flupenthixol',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUANXOL 0.5 (Lundbeck)'
);

-- line #14923
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUANXOL 1 (Lundbeck)',
	'Flupenthixol',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUANXOL 1 (Lundbeck)'
);

-- line #14924
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUANXOL 3 (Lundbeck)',
	'Flupenthixol',
	'TAB',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUANXOL 3 (Lundbeck)'
);

-- line #14925
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUPEN 0.5 (EAST WEST)',
	'Flupenthixol',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUPEN 0.5 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUPEN 1 (EAST WEST)',
	'Flupenthixol',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUPEN 1 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUPEN 3 (EAST WEST)',
	'Flupenthixol',
	'TAB',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUPEN 3 (EAST WEST)'
);

-- line #14926
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUPEXOL 0.5 (Tripada Hc.)',
	'Flupenthixol',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUPEXOL 0.5 (Tripada Hc.)'
);

-- line #14927
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUANXOL DEPOT 20 (Lundbeck)',
	'Flupentixol',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUANXOL DEPOT 20 (Lundbeck)'
);

-- line #14928
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUANXOL DEPOT 40 (Lundbeck)',
	'Flupentixol',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUANXOL DEPOT 40 (Lundbeck)'
);

-- line #14929
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANATENSOL DECANOATE 25 (Nicholas)',
	'Fluphenazine',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANATENSOL DECANOATE 25 (Nicholas)'
);

-- line #14930
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANATENSOL 1 (Nicholas)',
	'Fluphenazine',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANATENSOL 1 (Nicholas)'
);

-- line #14931
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUDECAN 25 (Svizera)',
	'Fluphenazine',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUDECAN 25 (Svizera)'
);

-- line #14932
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FPZ 25 (Triton Hc.)',
	'Fluphenazine',
	'AMP',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FPZ 25 (Triton Hc.)'
);

-- line #14933
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'F-TENSIL 25 (Reliance)',
	'Fluphenazine',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'F-TENSIL 25 (Reliance)'
);

-- line #14934
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROLINATE 25 (Sun)',
	'Fluphenazine',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROLINATE 25 (Sun)'
);

-- line #14935
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KATADOL 100 (Lupin)',
	'FLUPIRTINE',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KATADOL 100 (Lupin)'
);

-- line #14936
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUPIRTIN 100 (Lupin)',
	'FLUPIRTINE',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUPIRTIN 100 (Lupin)'
);

-- line #14937
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RETENSE 100 (SUN)',
	'FLUPIRTINE',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RETENSE 100 (SUN)'
);

-- line #14938
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLURACAP 15 (Pil)',
	'Flurazepam Hcl.',
	'CAP',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLURACAP 15 (Pil)'
);

-- line #14939
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLURAZ 15 (SYNAPSE)',
	'Flurazepam Hcl.',
	'CAP',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLURAZ 15 (SYNAPSE)'
);

-- line #14940
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NINDRAL 10 (Torrent)',
	'Flurazepam Hcl.',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NINDRAL 10 (Torrent)'
);

-- line #14941
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NINDRAL 5 (Torrent)',
	'Flurazepam Hcl.',
	'CAP',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NINDRAL 5 (Torrent)'
);

-- line #14942
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AFLUR 0.03 (Appasamy)',
	'Flurbiprofen',
	'EYE DPS',
	gm.nullify_empty_string('0.03')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AFLUR 0.03 (Appasamy)'
);

-- line #14943
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARFLUR 200 (F D C)',
	'Flurbiprofen',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARFLUR 200 (F D C)'
);

-- line #14944
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARFLUR 100 (F D C)',
	'Flurbiprofen',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARFLUR 100 (F D C)'
);

-- line #14945
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARFLUR 50 (F D C)',
	'Flurbiprofen',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARFLUR 50 (F D C)'
);

-- line #14946
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRUFEN 5 (Abbott)',
	'Flurbiprofen',
	'GEL',
	gm.nullify_empty_string('5')::numeric,
	'% W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRUFEN 5 (Abbott)'
);

-- line #14947
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRUGEL 5 (Abbott)',
	'Flurbiprofen',
	'GEL',
	gm.nullify_empty_string('5')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRUGEL 5 (Abbott)'
);

-- line #14948
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EYFLUR 0.03 (Radix Bio.)',
	'Flurbiprofen',
	'EYE DPS',
	gm.nullify_empty_string('0.03')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EYFLUR 0.03 (Radix Bio.)'
);

-- line #14949
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FBN 0.03 (Micro V.)',
	'Flurbiprofen',
	'EYE DPS',
	gm.nullify_empty_string('0.03')::numeric,
	'% SOD'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FBN 0.03 (Micro V.)'
);

-- line #14950
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUB 0.03 (Ophthal R.)',
	'Flurbiprofen',
	'DPS',
	gm.nullify_empty_string('0.03')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUB 0.03 (Ophthal R.)'
);

-- line #14951
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUBIFEN 0.03 (Sunways)',
	'Flurbiprofen',
	'EYE DPS',
	gm.nullify_empty_string('0.03')::numeric,
	'%(SOD.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUBIFEN 0.03 (Sunways)'
);

-- line #14952
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUDROP 0.03 (Yash Vision)',
	'Flurbiprofen',
	'EYE DPS',
	gm.nullify_empty_string('0.03')::numeric,
	'%(SOD.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUDROP 0.03 (Yash Vision)'
);

-- line #14953
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUFEN 0.03 (Parenteral)',
	'Flurbiprofen',
	'DPS',
	gm.nullify_empty_string('0.03')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUFEN 0.03 (Parenteral)'
);

-- line #14954
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLURBIN 0.3 (Optho Rem.)',
	'Flurbiprofen',
	'EYE DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V SOD'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLURBIN 0.3 (Optho Rem.)'
);

-- line #14955
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUROFEN 100 (Sanofi Aventis)',
	'Flurbiprofen',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUROFEN 100 (Sanofi Aventis)'
);

-- line #14956
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100', u'strength_2': u'', u'substance': u'Flurbiprofen', u'always_empty': u'', u'form': u'', u'brand': u'FROBEN FR (GRAN)', u'strength_3': u'', u'company': u'ABBOTT', u'unit': u'mg/SAC.'}

-- line #14957
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FROBEN 5 (ABBOTT)',
	'Flurbiprofen',
	'GEL',
	gm.nullify_empty_string('5')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FROBEN 5 (ABBOTT)'
);

-- line #14958
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FROBEN 200 (ABBOTT)',
	'Flurbiprofen',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FROBEN 200 (ABBOTT)'
);

-- line #14959
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FROBEN 100 (ABBOTT)',
	'Flurbiprofen',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FROBEN 100 (ABBOTT)'
);

-- line #14960
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Flurbiprofen', u'always_empty': u'', u'form': u'EYE DPS', u'brand': u'IFLUR', u'strength_3': u'', u'company': u'IVA REM.', u'unit': u''}

-- line #14961
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDOFLUR 0.3 (Indo-Reh Ph.)',
	'Flurbiprofen',
	'EYE DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDOFLUR 0.3 (Indo-Reh Ph.)'
);

-- line #14962
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORPHEN 0.03 (Ind-Swift)',
	'Flurbiprofen',
	'EYE DPS',
	gm.nullify_empty_string('0.03')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORPHEN 0.03 (Ind-Swift)'
);

-- line #14963
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDIFEN 0.03 (MEDITRINA PH.)',
	'Flurbiprofen',
	'EYE DPS',
	gm.nullify_empty_string('0.03')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDIFEN 0.03 (MEDITRINA PH.)'
);

-- line #14964
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCUFLUR 0.03 (F D C)',
	'Flurbiprofen',
	'DPS',
	gm.nullify_empty_string('0.03')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCUFLUR 0.03 (F D C)'
);

-- line #14965
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'WITH PHENYLMERCURIC NITRATE & H.P.M.C.', u'strength_2': u'', u'substance': u'Flurbiprofen', u'always_empty': u'', u'form': u'DROPS', u'brand': u'OCUPAIN EYE', u'strength_3': u'', u'company': u'DIVINE LAB.', u'unit': u''}

-- line #14966
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPTIFEN 0.03 (Ind-Swift)',
	'Flurbiprofen',
	'EYE DPS',
	gm.nullify_empty_string('0.03')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPTIFEN 0.03 (Ind-Swift)'
);

-- line #14967
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPTIFLUR 0.03 (Intra Lab)',
	'Flurbiprofen',
	'E/E DPS',
	gm.nullify_empty_string('0.03')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPTIFLUR 0.03 (Intra Lab)'
);

-- line #14968
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXIBER 0.03 (Zee Lab)',
	'Flurbiprofen',
	'EYE DPS',
	gm.nullify_empty_string('0.03')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXIBER 0.03 (Zee Lab)'
);

-- line #14969
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYTOMID-250 250 (Cipla)',
	'Flutamide',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYTOMID-250 250 (Cipla)'
);

-- line #14970
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROGENIL 250 (Fulford)',
	'Flutamide',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROGENIL 250 (Fulford)'
);

-- line #14971
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUTACARE 250 (Criticare)',
	'Flutamide',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUTACARE 250 (Criticare)'
);

-- line #14972
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUTAM 250 (CH.Bhagat)',
	'Flutamide',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUTAM 250 (CH.Bhagat)'
);

-- line #14973
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUTIDE 250 (Samarth)',
	'Flutamide',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUTIDE 250 (Samarth)'
);

-- line #14974
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'27.5MCG(FUROATE)', u'strength_2': u'', u'substance': u'Fluticasone', u'always_empty': u'', u'form': u'', u'brand': u'EZICAS F(120 METERED DOSES)', u'strength_3': u'', u'company': u'Intas', u'unit': u''}

-- line #14975
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50MCG', u'strength_2': u'DOSE', u'substance': u'Fluticasone', u'always_empty': u'', u'form': u'', u'brand': u'FLUTIFLO', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #14976
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'27.5MCG(FUROATE)', u'strength_2': u'', u'substance': u'Fluticasone', u'always_empty': u'', u'form': u'NASAL SPRAY', u'brand': u'FURASPRAY', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #14977
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EFNASE 0.05 (Ranbaxy)',
	'Fluticasone Prop.',
	'NASAL SPRAY',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EFNASE 0.05 (Ranbaxy)'
);

-- line #14978
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50MCG', u'strength_2': u'', u'substance': u'Fluticasone Prop.', u'always_empty': u'', u'form': u'PACK', u'brand': u'EZICAS', u'strength_3': u'', u'company': u'Intas', u'unit': u''}

-- line #14979
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLAT 0.05 (Sunways)',
	'Fluticasone Prop.',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLAT 0.05 (Sunways)'
);

-- line #14980
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50', u'strength_2': u'125MCG', u'substance': u'Fluticasone Prop.', u'always_empty': u'', u'form': u'', u'brand': u'FLOEASE INH', u'strength_3': u'', u'company': u'Solares (Sun)', u'unit': u''}

-- line #14981
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'125MCG', u'strength_2': u'', u'substance': u'Fluticasone Prop.', u'always_empty': u'', u'form': u'', u'brand': u'FLOHALE INH', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #14982
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'25MCG', u'strength_2': u'', u'substance': u'Fluticasone Prop.', u'always_empty': u'', u'form': u'', u'brand': u'FLOHALE INH', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #14983
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50MCG', u'strength_2': u'', u'substance': u'Fluticasone Prop.', u'always_empty': u'', u'form': u'', u'brand': u'FLOHALE INH', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #14984
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,5', u'strength_2': u'2', u'substance': u'Fluticasone Prop.', u'always_empty': u'', u'form': u'', u'brand': u'FLOHALE REPSULE INH', u'strength_3': u'', u'company': u'Cipla', u'unit': u'mg'}

-- line #14985
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50', u'strength_2': u'100', u'substance': u'Fluticasone Prop.', u'always_empty': u'', u'form': u'ROTACAPS', u'brand': u'FLOHALE', u'strength_3': u'250MCG', u'company': u'Cipla', u'unit': u''}

-- line #14986
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50MCG', u'strength_2': u'100MCG', u'substance': u'Fluticasone Prop.', u'always_empty': u'', u'form': u'ROTACAPS', u'brand': u'FLOHALE', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #14987
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50MCG', u'strength_2': u'DOSE', u'substance': u'Fluticasone Prop.', u'always_empty': u'', u'form': u'SPRAY', u'brand': u'FLOMIST', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #14988
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUSTER 0.05 (EAST WEST)',
	'Fluticasone Prop.',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUSTER 0.05 (EAST WEST)'
);

-- line #14989
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Fluticasone Prop.', u'always_empty': u'', u'form': u'CRM', u'brand': u'FLUTEC', u'strength_3': u'', u'company': u'Dermocare', u'unit': u''}

-- line #14990
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUTE 0.05 (Genix Ph.)',
	'Fluticasone Prop.',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUTE 0.05 (Genix Ph.)'
);

-- line #14991
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUTICARE 0.05 (HETERO HC.)',
	'Fluticasone Prop.',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUTICARE 0.05 (HETERO HC.)'
);

-- line #14992
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUTICARE 0.05 (HETERO HC.)',
	'Fluticasone Prop.',
	'LOT',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUTICARE 0.05 (HETERO HC.)'
);

-- line #14993
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUTICARE 0.005 (HETERO HC.)',
	'Fluticasone Prop.',
	'OINT',
	gm.nullify_empty_string('0.005')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUTICARE 0.005 (HETERO HC.)'
);

-- line #14994
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUTICONE-FT 0.055 (German R.)',
	'Fluticasone Prop.',
	'NASAL SPRAY',
	gm.nullify_empty_string('0.055')::numeric,
	'%W/W(BENZALKONIUM CHL.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUTICONE-FT 0.055 (German R.)'
);

-- line #14995
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100MCG', u'strength_2': u'DOSE', u'substance': u'Fluticasone Prop.', u'always_empty': u'', u'form': u'NASAL SPRAY', u'brand': u'FLUTICONE', u'strength_3': u'', u'company': u'German R.', u'unit': u''}

-- line #14996
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUTIN 0.05 (Sunways)',
	'Fluticasone Prop.',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUTIN 0.05 (Sunways)'
);

-- line #14997
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUTIVATE 0.05 (Gsk)',
	'Fluticasone Prop.',
	'CRM/OINT',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUTIVATE 0.05 (Gsk)'
);

-- line #14998
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUTIVATE *-E 0.05 (Gsk)',
	'Fluticasone Prop.',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/WMICRONISED'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUTIVATE *-E 0.05 (Gsk)'
);

-- line #14999
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUTIVATE 0.05 (Gsk)',
	'Fluticasone Prop.',
	'LOT',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUTIVATE 0.05 (Gsk)'
);

-- line #15000
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUTIVATE 0.005 (GSK)',
	'Fluticasone Prop.',
	'OINT',
	gm.nullify_empty_string('0.005')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUTIVATE 0.005 (GSK)'
);

-- line #15001
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUTOPIC 0.005 (Systopic)',
	'Fluticasone Prop.',
	'OINT',
	gm.nullify_empty_string('0.005')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUTOPIC 0.005 (Systopic)'
);

-- line #15002
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUTICA 0.005 (Ochoa)',
	'Fluticasone Prop.',
	'CRM',
	gm.nullify_empty_string('0.005')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUTICA 0.005 (Ochoa)'
);

-- line #15003
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Fluticasone Prop.', u'always_empty': u'', u'form': u'LOT', u'brand': u'LUTICA', u'strength_3': u'', u'company': u'Ochoa', u'unit': u''}

-- line #15004
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUTICA 0.05 (Ranbaxy)',
	'Fluticasone Prop.',
	'LOT',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUTICA 0.05 (Ranbaxy)'
);

-- line #15005
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUTICA 0.005 (Ochoa)',
	'Fluticasone Prop.',
	'OINT',
	gm.nullify_empty_string('0.005')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUTICA 0.005 (Ochoa)'
);

-- line #15006
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUTICA 0.005 (Ranbaxy)',
	'Fluticasone Prop.',
	'OINT',
	gm.nullify_empty_string('0.005')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUTICA 0.005 (Ranbaxy)'
);

-- line #15007
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOLIDERM 0.05 (Gsk)',
	'Fluticasone Prop.',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOLIDERM 0.05 (Gsk)'
);

-- line #15008
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50MCG', u'strength_2': u'', u'substance': u'Fluticasone Prop.', u'always_empty': u'', u'form': u'', u'brand': u'NASICURE', u'strength_3': u'', u'company': u'Merck', u'unit': u''}

-- line #15009
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,05', u'strength_2': u'', u'substance': u'Fluticasone Prop.', u'always_empty': u'', u'form': u'', u'brand': u'NASOCOM', u'strength_3': u'', u'company': u"Dr. Reddy''S", u'unit': u'%(BENZALKONIUM CHL. 0.25'}

-- line #15010
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,05', u'strength_2': u'', u'substance': u'Fluticasone Prop.', u'always_empty': u'', u'form': u'', u'brand': u'NAZOMAC-F', u'strength_3': u'', u'company': u'Macleods', u'unit': u'%W/V'}

-- line #15011
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEZAFLO 0.05 (Sun)',
	'Fluticasone Prop.',
	'NASAL SPRAY',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEZAFLO 0.05 (Sun)'
);

-- line #15012
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OTRIVIN-C 0.05 (Novartis)',
	'Fluticasone Prop.',
	'SPRAY',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OTRIVIN-C 0.05 (Novartis)'
);

-- line #15013
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RHINOFIT 0.01 (Entod Ph.)',
	'Fluticasone Prop.',
	'NASAL SPRAY',
	gm.nullify_empty_string('0.01')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RHINOFIT 0.01 (Entod Ph.)'
);

-- line #15014
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'PR', u'strength_2': u'', u'substance': u'FLUVASTATIN SODIUM', u'always_empty': u'', u'form': u'XL', u'brand': u'LESCOL', u'strength_3': u'', u'company': u'Novartis', u'unit': u''}

-- line #15015
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUVATOR 100 (Torrent)',
	'Fluvoxamine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUVATOR 100 (Torrent)'
);

-- line #15016
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUVATOR 50 (Torrent)',
	'Fluvoxamine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUVATOR 50 (Torrent)'
);

-- line #15017
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUVOXIN 100 (Sun)',
	'Fluvoxamine',
	'CR',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUVOXIN 100 (Sun)'
);

-- line #15018
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUVOXIN 50 (SUN)',
	'Fluvoxamine',
	'CR TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg ER'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUVOXIN 50 (SUN)'
);

-- line #15019
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUVOXIN 100 (Sun)',
	'Fluvoxamine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUVOXIN 100 (Sun)'
);

-- line #15020
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUVOXIN 50 (Sun)',
	'Fluvoxamine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUVOXIN 50 (Sun)'
);

-- line #15021
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUXAM 50 (Tripada)',
	'Fluvoxamine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUXAM 50 (Tripada)'
);

-- line #15022
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FREXT 100 (Intas)',
	'Fluvoxamine',
	'CR',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FREXT 100 (Intas)'
);

-- line #15023
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FREXT 100 (Intas)',
	'Fluvoxamine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FREXT 100 (Intas)'
);

-- line #15024
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FREXT 50 (Intas)',
	'Fluvoxamine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FREXT 50 (Intas)'
);

-- line #15025
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PSYVOXIN 50 (PSYCOREM)',
	'Fluvoxamine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'100'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PSYVOXIN 50 (PSYCOREM)'
);

-- line #15026
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REVILIFE 50 (Abbott)',
	'Fluvoxamine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'100'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REVILIFE 50 (Abbott)'
);

-- line #15027
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AQUAFOL 5 (Serve Ph.)',
	'Folic Acid',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AQUAFOL 5 (Serve Ph.)'
);

-- line #15028
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASFOLI 5 (YASHTRA HEALTH)',
	'FOLIC ACID',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASFOLI 5 (YASHTRA HEALTH)'
);

-- line #15029
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'B-9 5 (Juggat)',
	'FOLIC ACID',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'B-9 5 (Juggat)'
);

-- line #15030
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOFOL 5 (Arbro Ph.)',
	'Folic Acid',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOFOL 5 (Arbro Ph.)'
);

-- line #15031
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELFOL 5 (XCEL LABS)',
	'FOLIC ACID',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELFOL 5 (XCEL LABS)'
);

-- line #15032
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-FOL 5 (CORONA)',
	'FOLIC ACID',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-FOL 5 (CORONA)'
);

-- line #15033
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUFOL 5 (Cubit Hc.)',
	'FOLIC ACID',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUFOL 5 (Cubit Hc.)'
);

-- line #15034
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EF 5 (ROSE LABS)',
	'FOLIC ACID',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EF 5 (ROSE LABS)'
);

-- line #15035
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMFOLIC 1 (EMCURE PH.)',
	'Folic Acid',
	'DPS',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMFOLIC 1 (EMCURE PH.)'
);

-- line #15036
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMFOLIC 1 (Emcure)',
	'Folic Acid',
	'SYR',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMFOLIC 1 (Emcure)'
);

-- line #15037
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EVA FOL 5 (RADHE BIO.)',
	'FOLIC ACID',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EVA FOL 5 (RADHE BIO.)'
);

-- line #15038
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FACITAB 5 (Kapl)',
	'Folic Acid',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FACITAB 5 (Kapl)'
);

-- line #15039
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FA 5 (Satven And Mer.)',
	'Folic Acid',
	'OD TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FA 5 (Satven And Mer.)'
);

-- line #15040
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEDORA 5 (Ornate Lab)',
	'Folic Acid',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEDORA 5 (Ornate Lab)'
);

-- line #15041
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FH-12 5 (Bestochem)',
	'Folic Acid',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FH-12 5 (Bestochem)'
);

-- line #15042
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FH-12 5 (Bestochem)',
	'FOLIC ACID',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FH-12 5 (Bestochem)'
);

-- line #15043
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOLICA 10 (RND LAB)',
	'FOLIC ACID',
	'OD TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOLICA 10 (RND LAB)'
);

-- line #15044
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'FOLIC ACID', u'always_empty': u'', u'form': u'TAB', u'brand': u'FLOMET', u'strength_3': u'', u'company': u'Nouveau', u'unit': u''}

-- line #15045
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLORET 5 (SPECTRUM HC.)',
	'Folic Acid',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLORET 5 (SPECTRUM HC.)'
);

-- line #15046
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOL-5 5 (Zydus Cadila)',
	'Folic Acid',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOL-5 5 (Zydus Cadila)'
);

-- line #15047
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5', u'strength_2': u'', u'substance': u'FOLIC ACID', u'always_empty': u'', u'form': u'', u'brand': u'FOL-8', u'strength_3': u'', u'company': u'KHLOROPHYLLS BIO.', u'unit': u'mg'}

-- line #15048
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLACIN 5 (Mars)',
	'Folic Acid',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLACIN 5 (Mars)'
);

-- line #15049
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLAID 5 (STERLING)',
	'FOLIC ACID',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLAID 5 (STERLING)'
);

-- line #15050
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLAT-5 5 (Atoz Ph.)',
	'Folic Acid',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLAT-5 5 (Atoz Ph.)'
);

-- line #15051
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLBIN-5 5 (Parasol)',
	'Folic Acid',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLBIN-5 5 (Parasol)'
);

-- line #15052
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLBIT 5 (DEWCARE)',
	'FOLIC ACID',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLBIT 5 (DEWCARE)'
);

-- line #15053
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOL-B 5 (EAST WEST)',
	'FOLIC ACID',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOL-B 5 (EAST WEST)'
);

-- line #15054
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLDIVIT 5 (Cadila Ph.)',
	'Folic Acid',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLDIVIT 5 (Cadila Ph.)'
);

-- line #15055
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLERA 5 (Svizera)',
	'FOLIC ACID',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLERA 5 (Svizera)'
);

-- line #15056
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLET 5 (Centaur)',
	'Folic Acid',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLET 5 (Centaur)'
);

-- line #15057
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLFIT 1 (Eros Ph.)',
	'Folic Acid',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLFIT 1 (Eros Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLFIT 5 (Eros Ph.)',
	'Folic Acid',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLFIT 5 (Eros Ph.)'
);

-- line #15058
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLI-5 5 (Medicamen)',
	'Folic Acid',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLI-5 5 (Medicamen)'
);

-- line #15059
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLIB-5 5 (Que Ph.)',
	'Folic Acid',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLIB-5 5 (Que Ph.)'
);

-- line #15060
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLIBID-F 10 (Speciality Med.)',
	'Folic Acid',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLIBID-F 10 (Speciality Med.)'
);

-- line #15061
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLIBID 5 (Speciality Med.)',
	'Folic Acid',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLIBID 5 (Speciality Med.)'
);

-- line #15062
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLIB 5 (Bio-Drug)',
	'Folic Acid',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLIB 5 (Bio-Drug)'
);

-- line #15063
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLIDAY 5 (Intra(INVISION))',
	'FOLIC ACID',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLIDAY 5 (Intra(INVISION))'
);

-- line #15064
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLIDEF 5 (CITIZEN LAB.)',
	'Folic Acid',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLIDEF 5 (CITIZEN LAB.)'
);

-- line #15065
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLIDEN 5 (Fourrts)',
	'Folic Acid',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLIDEN 5 (Fourrts)'
);

-- line #15066
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLIGEN 5 (BIOGEN PH.)',
	'FOLIC ACID',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLIGEN 5 (BIOGEN PH.)'
);

-- line #15067
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLIK 10 (Synokem)',
	'Folic Acid',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLIK 10 (Synokem)'
);

-- line #15068
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLIK 5 (Synokem)',
	'Folic Acid',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLIK 5 (Synokem)'
);

-- line #15069
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLIMAC 5 (Ikon Rem)',
	'FOLIC ACID',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLIMAC 5 (Ikon Rem)'
);

-- line #15070
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLIMET 5 (Merit Org.)',
	'Folic Acid',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLIMET 5 (Merit Org.)'
);

-- line #15071
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLIMOM 5 (WISCON)',
	'FOLIC ACID',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLIMOM 5 (WISCON)'
);

-- line #15072
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLIMUST 5 (LIFESTAR)',
	'FOLIC ACID',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLIMUST 5 (LIFESTAR)'
);

-- line #15073
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLINAL 5 (Alembic)',
	'Folic Acid',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLINAL 5 (Alembic)'
);

-- line #15074
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLIREX 5 (Shalman)',
	'Folic Acid',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLIREX 5 (Shalman)'
);

-- line #15075
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLIRON 5 (Ronak Lab.)',
	'Folic Acid',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLIRON 5 (Ronak Lab.)'
);

-- line #15076
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLISTAR 5 (Triton Hc.)',
	'FOLIC ACID',
	'TAB`',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLISTAR 5 (Triton Hc.)'
);

-- line #15077
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLITAB 5 (Chem+Med)',
	'Folic Acid',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLITAB 5 (Chem+Med)'
);

-- line #15078
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLITAB 5 (Mercury)',
	'Folic Acid',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLITAB 5 (Mercury)'
);

-- line #15079
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLIUM-F 10 (Speciality Med.)',
	'Folic Acid',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLIUM-F 10 (Speciality Med.)'
);

-- line #15080
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLIUM 5 (Speciality Med.)',
	'Folic Acid',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLIUM 5 (Speciality Med.)'
);

-- line #15081
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLIX 5 (Merril Ph.)',
	'Folic Acid',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLIX 5 (Merril Ph.)'
);

-- line #15082
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLIX 5 (Stallion)',
	'Folic Acid',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLIX 5 (Stallion)'
);

-- line #15083
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLIZ 5 (ALPHA TH.)',
	'FOLIC ACID',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLIZ 5 (ALPHA TH.)'
);

-- line #15084
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLIZ 5 (ZEDR)',
	'FOLIC ACID',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLIZ 5 (ZEDR)'
);

-- line #15085
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLNEU 50 (Cadila Ph.)',
	'Folic Acid',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLNEU 50 (Cadila Ph.)'
);

-- line #15086
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLSON 5 (Aglowmed)',
	'Folic Acid',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLSON 5 (Aglowmed)'
);

-- line #15087
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLSON 5 (Aglowmed)',
	'FOLIC ACID',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLSON 5 (Aglowmed)'
);

-- line #15088
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLSTAR 5 (SIFAM PH.)',
	'FOLIC ACID',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLSTAR 5 (SIFAM PH.)'
);

-- line #15089
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLUP 5 (AUGMENT REM.)',
	'FOLIC ACID',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLUP 5 (AUGMENT REM.)'
);

-- line #15090
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLVIN 5 (Calibar Ph.)',
	'Folic Acid',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLVIN 5 (Calibar Ph.)'
);

-- line #15091
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLVITE 5 (Wyeth)',
	'Folic Acid',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLVITE 5 (Wyeth)'
);

-- line #15092
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLWIN 10 (Phytochem)',
	'Folic Acid',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLWIN 10 (Phytochem)'
);

-- line #15093
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLYA-5 5 (Chemo D.)',
	'Folic Acid',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLYA-5 5 (Chemo D.)'
);

-- line #15094
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORON 5 (Neuron Ph.)',
	'FOLIC ACID',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORON 5 (Neuron Ph.)'
);

-- line #15095
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'F-SOIN 5 (SOIN PH.)',
	'Folic Acid',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'F-SOIN 5 (SOIN PH.)'
);

-- line #15096
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FTOL 5 (MADHAV BIO.)',
	'FOLIC ACID',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FTOL 5 (MADHAV BIO.)'
);

-- line #15097
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'F-V 5 (VIVA LAB.)',
	'FOLIC ACID',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'F-V 5 (VIVA LAB.)'
);

-- line #15098
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G-FOLVIN-5 5 (Shrinivas)',
	'Folic Acid',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G-FOLVIN-5 5 (Shrinivas)'
);

-- line #15099
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLOBIN 5 (PSYCOREM)',
	'FOLIC ACID',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLOBIN 5 (PSYCOREM)'
);

-- line #15100
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GOODVIT 5 (Overseas Hc.)',
	'FOLIC ACID',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GOODVIT 5 (Overseas Hc.)'
);

-- line #15101
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INGAFOL 5 (Inga)',
	'Folic Acid',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INGAFOL 5 (Inga)'
);

-- line #15102
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'J-FOL 5 (J.P. HC.)',
	'Folic Acid',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'J-FOL 5 (J.P. HC.)'
);

-- line #15103
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'J FOL 5 (J.P.LIFE)',
	'FOLIC ACID',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'J FOL 5 (J.P.LIFE)'
);

-- line #15104
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIK 10 (Siomond)',
	'Folic Acid',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIK 10 (Siomond)'
);

-- line #15105
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOMFOL-5 5 (Rapross)',
	'Folic Acid',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOMFOL-5 5 (Rapross)'
);

-- line #15106
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYFOL 5 (Theo Ph.)',
	'FOLIC ACID',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYFOL 5 (Theo Ph.)'
);

-- line #15107
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEEDY PLUS 5 (SYNER MED.)',
	'FOLIC ACID',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEEDY PLUS 5 (SYNER MED.)'
);

-- line #15108
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOFOL 5 (Neon)',
	'FOLIC ACID',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOFOL 5 (Neon)'
);

-- line #15109
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NICOFER-F 5 (Piramal Hc.)',
	'FOLIC ACID',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NICOFER-F 5 (Piramal Hc.)'
);

-- line #15110
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUTRILIC 5 (Chemech)',
	'FOLIC ACID',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUTRILIC 5 (Chemech)'
);

-- line #15111
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLIC-5 5 (Ozone Ph.)',
	'Folic Acid',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLIC-5 5 (Ozone Ph.)'
);

-- line #15112
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLICAHIL 5 (HIND. LATEX)',
	'FOLIC ACID',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLICAHIL 5 (HIND. LATEX)'
);

-- line #15113
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREFOL-5 5 (Intra Lab)',
	'FOLIC ACID',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREFOL-5 5 (Intra Lab)'
);

-- line #15114
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REFOL 5 (Austere)',
	'FOLIC ACID',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REFOL 5 (Austere)'
);

-- line #15115
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARIXTRA 2.5 (Gsk)',
	'FONDAPARINUX SODIUM',
	'INJ',
	gm.nullify_empty_string('2.5')::numeric,
	'mg/0.5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARIXTRA 2.5 (Gsk)'
);

-- line #15116
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Formalin', u'always_empty': u'', u'form': u'TOOTH PASTE', u'brand': u'DENTOFORM', u'strength_3': u'', u'company': u'Group Ph.', u'unit': u''}

-- line #15117
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'12MCG', u'strength_2': u'', u'substance': u'Formeterol Fumarate', u'always_empty': u'', u'form': u'CAP', u'brand': u'FORATEC', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #15118
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'12MCG', u'strength_2': u'D.', u'substance': u'Formoterol Fumarate', u'always_empty': u'', u'form': u'', u'brand': u'DERIFORM INH', u'strength_3': u'', u'company': u'German R.', u'unit': u''}

-- line #15119
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1MCG', u'strength_2': u'EACH', u'substance': u'Formoterol Fumarate', u'always_empty': u'', u'form': u'RESPICAPS', u'brand': u'DERIFORM', u'strength_3': u'', u'company': u'German R.', u'unit': u''}

-- line #15120
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'12MCG', u'strength_2': u'', u'substance': u'Formoterol Fumarate', u'always_empty': u'', u'form': u'INHALER', u'brand': u'FORATEC', u'strength_3': u'', u'company': u'Protec', u'unit': u''}

-- line #15121
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'12MCG', u'strength_2': u'', u'substance': u'Formoterol Fumarate', u'always_empty': u'', u'form': u'ROTACAPS', u'brand': u'FORATEC', u'strength_3': u'', u'company': u'Protec', u'unit': u''}

-- line #15122
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HONVAN 60 (German R.)',
	'Fosfestrol',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HONVAN 60 (German R.)'
);

-- line #15123
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HONVAN 120 (German R.)',
	'Fosfestrol',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HONVAN 120 (German R.)'
);

-- line #15124
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOSINACE 10 (Cipla)',
	'Fosinopril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOSINACE 10 (Cipla)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOSINACE 20 (Cipla)',
	'Fosinopril',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOSINACE 20 (Cipla)'
);

-- line #15125
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOVAS 10 (Cadila Ph.)',
	'FOSINOPRIL',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOVAS 10 (Cadila Ph.)'
);

-- line #15126
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOVAS 20 (Cadila Ph.)',
	'FOSINOPRIL',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOVAS 20 (Cadila Ph.)'
);

-- line #15127
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEROFOS 150 (Gland Ph.)',
	'FOSPHENYTOIN SODIUM',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEROFOS 150 (Gland Ph.)'
);

-- line #15128
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEROFOS 750 (Gland Ph.)',
	'FOSPHENYTOIN SODIUM',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEROFOS 750 (Gland Ph.)'
);

-- line #15129
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOSENTIN 75 (SUN)',
	'FOSPHENYTOIN SODIUM',
	'INJ',
	gm.nullify_empty_string('75')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOSENTIN 75 (SUN)'
);

-- line #15130
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOSOLIN 75 (Zydus N.S.)',
	'FOSPHENYTOIN SODIUM',
	'INJ',
	gm.nullify_empty_string('75')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOSOLIN 75 (Zydus N.S.)'
);

-- line #15131
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'FOSPHENYTOIN SODIUM', u'always_empty': u'', u'form': u'INJ', u'brand': u'FOSPHEN', u'strength_3': u'', u'company': u'Intas', u'unit': u''}

-- line #15132
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FRADE 1 (Gufic Bio.)',
	'Framycetin',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FRADE 1 (Gufic Bio.)'
);

-- line #15133
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISMIGEN 50 (Lupin)',
	'FREEZE DRIED BACTERIAL LYSATE',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISMIGEN 50 (Lupin)'
);

-- line #15134
-- ignoring line: field [strength_1] not numeric: >>>0.1G(CONSISTING OF GLUTAMIC ACID<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.1G(CONSISTING OF GLUTAMIC ACID', u'strength_2': u'', u'substance': u'FRESH HUMAN PLACENTA TOTAL NITROGEN', u'always_empty': u'', u'form': u'CRM', u'brand': u'PLACENTREX', u'strength_3': u'', u'company': u'Albert D.', u'unit': u'LEUCINE AND LYSINE)'}

-- line #15135
-- ignoring line: field [strength_1] not numeric: >>>0.1G(NOT MORE THEN 0.25<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.1G(NOT MORE THEN 0.25', u'strength_2': u'', u'substance': u'FRESH HUMAN PLACENTA TOTAL NITROGEN', u'always_empty': u'', u'form': u'GEL', u'brand': u'PLACENTREX', u'strength_3': u'', u'company': u'Albert D.', u'unit': u'%W/W)'}

-- line #15136
-- ignoring line: field [strength_1] not numeric: >>>0.1G(NOT MORE THEN 0.25<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.1G(NOT MORE THEN 0.25', u'strength_2': u'', u'substance': u'FRESH HUMAN PLACENTA TOTAL NITROGEN', u'always_empty': u'', u'form': u'GEL', u'brand': u'PLACENTREX-V', u'strength_3': u'', u'company': u'Albert D.', u'unit': u'%W/W)'}

-- line #15137
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FRU 20 (Ind-Swift)',
	'Frusemide',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FRU 20 (Ind-Swift)'
);

-- line #15138
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FRUSENEX 100 (Geno Ph.)',
	'Frusemide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FRUSENEX 100 (Geno Ph.)'
);

-- line #15139
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FRUSENEX 40 (Geno Ph.)',
	'Frusemide',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FRUSENEX 40 (Geno Ph.)'
);

-- line #15140
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FRUSIM 10 (CH.Bhagat)',
	'Frusemide',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FRUSIM 10 (CH.Bhagat)'
);

-- line #15141
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FRUSIX 20 (Cipla)',
	'Frusemide',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FRUSIX 20 (Cipla)'
);

-- line #15142
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUROPED 300 (Samarth)',
	'Frusemide',
	'SOL',
	gm.nullify_empty_string('300')::numeric,
	'mg/30ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUROPED 300 (Samarth)'
);

-- line #15143
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LASIX HIGH DOSE 250 (Sanofi Aventis)',
	'Frusemide',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/25ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LASIX HIGH DOSE 250 (Sanofi Aventis)'
);

-- line #15144
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LASIX 10 (Sanofi Aventis)',
	'Frusemide',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LASIX 10 (Sanofi Aventis)'
);

-- line #15145
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LASIX 40 (Sanofi Aventis)',
	'Frusemide',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LASIX 40 (Sanofi Aventis)'
);

-- line #15146
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LASIX 500 (Sanofi Aventis)',
	'Frusemide',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LASIX 500 (Sanofi Aventis)'
);

-- line #15147
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAXIS 10 (Sanofi Aventis)',
	'Frusemide',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAXIS 10 (Sanofi Aventis)'
);

-- line #15148
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FASLODEX 250 (Astrazeneca)',
	'FULVESTRANT',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg (IN 5ML. SOL. ETHANOL 96'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FASLODEX 250 (Astrazeneca)'
);

-- line #15149
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AQUADIL-P 31.25 (Gufic Bio.)',
	'Fungal Diastase',
	'DROPS',
	gm.nullify_empty_string('31.25')::numeric,
	'mg(ALPHA AMYLASE)+CARMINATIVE OIL'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AQUADIL-P 31.25 (Gufic Bio.)'
);

-- line #15150
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Fungal Diastase', u'always_empty': u'', u'form': u'SYR', u'brand': u'LAXZYME', u'strength_3': u'', u'company': u'Helax Hc.', u'unit': u''}

-- line #15151
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUROXONE 25 (Gsk)',
	'Furazolidone',
	'SUS',
	gm.nullify_empty_string('25')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUROXONE 25 (Gsk)'
);

-- line #15152
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUROXONE 100 (Gsk)',
	'Furazolidone',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUROXONE 100 (Gsk)'
);

-- line #15153
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENCENTIN 100 (EAST WEST)',
	'Gabapentin',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENCENTIN 100 (EAST WEST)'
);

-- line #15154
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENCENTIN 300 (EAST WEST)',
	'Gabapentin',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENCENTIN 300 (EAST WEST)'
);

-- line #15155
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENCENTIN 400 (EAST WEST)',
	'Gabapentin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENCENTIN 400 (EAST WEST)'
);

-- line #15156
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GABACAP 100 (Cadila Hc.)',
	'Gabapentin',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GABACAP 100 (Cadila Hc.)'
);

-- line #15157
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GABA 300 (HANBURYS)',
	'Gabapentin',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GABA 300 (HANBURYS)'
);

-- line #15158
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GABATIN 400 (Neon)',
	'Gabapentin',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GABATIN 400 (Neon)'
);

-- line #15159
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GABATOR 100 (Torrent)',
	'Gabapentin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GABATOR 100 (Torrent)'
);

-- line #15160
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GABATOR 300 (Torrent)',
	'Gabapentin',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GABATOR 300 (Torrent)'
);

-- line #15161
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GABATOR 400 (Torrent)',
	'Gabapentin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GABATOR 400 (Torrent)'
);

-- line #15162
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENTIN 100 (PSYCOREM)',
	'Gabapentin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENTIN 100 (PSYCOREM)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENTIN 300 (PSYCOREM)',
	'Gabapentin',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENTIN 300 (PSYCOREM)'
);

-- line #15163
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENTIN 400 (PSYCOREM)',
	'Gabapentin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENTIN 400 (PSYCOREM)'
);

-- line #15164
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEUPENT 450 (Solus)',
	'Gabapentin',
	'AF CAP',
	gm.nullify_empty_string('450')::numeric,
	'mg(SR)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEUPENT 450 (Solus)'
);

-- line #15165
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEUPENT 600 (Solus)',
	'Gabapentin',
	'AF CAP',
	gm.nullify_empty_string('600')::numeric,
	'mg(SR)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEUPENT 600 (Solus)'
);

-- line #15166
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEUPENT 900 (Solus)',
	'Gabapentin',
	'AF CAP',
	gm.nullify_empty_string('900')::numeric,
	'mg(SR)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEUPENT 900 (Solus)'
);

-- line #15167
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEURONTIN 300 (PFIZER)',
	'Gabapentin',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEURONTIN 300 (PFIZER)'
);

-- line #15168
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEURONTIN 400 (PFIZER)',
	'Gabapentin',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEURONTIN 400 (PFIZER)'
);

-- line #15169
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'300', u'strength_2': u'', u'substance': u'Gabapentin', u'always_empty': u'', u'form': u'', u'brand': u'REJUNATE', u'strength_3': u'', u'company': u'MOLEKULE', u'unit': u'mg'}

-- line #15170
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REJURON 300 (MOLEKULE)',
	'Gabapentin',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REJURON 300 (MOLEKULE)'
);

-- line #15171
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAGNEVIST 469 (German R.)',
	'GADOPENTETIC ACID DIMEGLUMINE SALT',
	'V10',
	gm.nullify_empty_string('469')::numeric,
	'mg(IN AQ. SOL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAGNEVIST 469 (German R.)'
);

-- line #15172
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAGNEVIST 469 (German R.)',
	'GADOPENTETIC ACID DIMEGLUMINE SALT',
	'V20',
	gm.nullify_empty_string('469')::numeric,
	'mg(IN AQ. SOL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAGNEVIST 469 (German R.)'
);

-- line #15173
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GALAMER 8 (SUN)',
	'GALANTAMIN',
	'OD TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg ER'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GALAMER 8 (SUN)'
);

-- line #15174
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GALAMER 4 (Sun)',
	'GALANTAMIN HBR',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GALAMER 4 (Sun)'
);

-- line #15175
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BEXARID 1 (Shalaks)',
	'Gamma Benzene Hexachloride',
	'LOT',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BEXARID 1 (Shalaks)'
);

-- line #15176
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Gamma Benzene Hexachloride', u'always_empty': u'', u'form': u'SOAP', u'brand': u'DERMISOL', u'strength_3': u'', u'company': u'NIVCA', u'unit': u''}

-- line #15177
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GAB 1 (Gufic Bio.)',
	'Gamma Benzene Hexachloride',
	'LOT',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GAB 1 (Gufic Bio.)'
);

-- line #15178
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GAB 1 (Gufic Bio.)',
	'Gamma Benzene Hexachloride',
	'OINT',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GAB 1 (Gufic Bio.)'
);

-- line #15179
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GAMADERM 1 (Vilco)',
	'Gamma Benzene Hexachloride',
	'LOT',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GAMADERM 1 (Vilco)'
);

-- line #15180
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GAMALICE 1 (Nulife)',
	'Gamma Benzene Hexachloride',
	'LOT',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GAMALICE 1 (Nulife)'
);

-- line #15181
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GAMARIC 1 (Euphoric)',
	'Gamma Benzene Hexachloride',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GAMARIC 1 (Euphoric)'
);

-- line #15182
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GAMARIC 1 (Euphoric)',
	'Gamma Benzene Hexachloride',
	'LOT',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GAMARIC 1 (Euphoric)'
);

-- line #15183
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GAMASCAB 1 (Nulife)',
	'Gamma Benzene Hexachloride',
	'LOT (5 LIT)',
	gm.nullify_empty_string('1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GAMASCAB 1 (Nulife)'
);

-- line #15184
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GAMASCAB 1 (Nulife)',
	'Gamma Benzene Hexachloride',
	'LOT',
	gm.nullify_empty_string('1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GAMASCAB 1 (Nulife)'
);

-- line #15185
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GAMMACARE 1 (Karlin)',
	'Gamma Benzene Hexachloride',
	'LOT',
	gm.nullify_empty_string('1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GAMMACARE 1 (Karlin)'
);

-- line #15186
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GBHC 1 (Shalaks)',
	'Gamma Benzene Hexachloride',
	'LOT',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GBHC 1 (Shalaks)'
);

-- line #15187
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLSCAB 1 (Olcare)',
	'Gamma Benzene Hexachloride',
	'LOT',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLSCAB 1 (Olcare)'
);

-- line #15188
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLSCAB 1 (Olcare)',
	'Gamma Benzene Hexachloride',
	'SOAP',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLSCAB 1 (Olcare)'
);

-- line #15189
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEDISCAB 1 (Indica)',
	'Gamma Benzene Hexachloride',
	'LOT',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEDISCAB 1 (Indica)'
);

-- line #15190
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROSCAB 1 (ADMIT)',
	'Gamma Benzene Hexachloride',
	'LOT',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROSCAB 1 (ADMIT)'
);

-- line #15191
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINOCID 120 (Mano Ph.)',
	'Gamma Linolenic Acid',
	'CAP',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINOCID 120 (Mano Ph.)'
);

-- line #15192
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GANGUARD 250 (RANBAXY (S.S.))',
	'GANCICLOVIR',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GANGUARD 250 (RANBAXY (S.S.))'
);

-- line #15193
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GANGUARD 500 (RANBAXY (S.S.))',
	'GANCICLOVIR',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GANGUARD 500 (RANBAXY (S.S.))'
);

-- line #15194
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GANGUARD 500 (RANBAXY (S.S.))',
	'GANCICLOVIR',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GANGUARD 500 (RANBAXY (S.S.))'
);

-- line #15195
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GAVIR 500 (United Bio.)',
	'GANCICLOVIR',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GAVIR 500 (United Bio.)'
);

-- line #15196
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GONARELIX 0.25 (Sun)',
	'GANIRELIX',
	'INJ',
	gm.nullify_empty_string('0.25')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GONARELIX 0.25 (Sun)'
);

-- line #15197
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPLA''S GARLIC OIL 0.625 (Cipla)',
	'GARLIC OIL',
	'CAP',
	gm.nullify_empty_string('0.625')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPLA''S GARLIC OIL 0.625 (Cipla)'
);

-- line #15198
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GARLEE 0.6 (Ind-Swift)',
	'Garlic Oil',
	'CAP',
	gm.nullify_empty_string('0.6')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GARLEE 0.6 (Ind-Swift)'
);

-- line #15199
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,25', u'strength_2': u'', u'substance': u'Garlic Oil', u'always_empty': u'', u'form': u'', u'brand': u'GARLIC PEARLS', u'strength_3': u'', u'company': u'Ranbaxy Cv', u'unit': u'%W/W'}

-- line #15200
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10000I.U.', u'strength_2': u'', u'substance': u'GAS GANGRENE ANTITOXIN', u'always_empty': u'', u'form': u'INJ', u'brand': u'AGGS IU', u'strength_3': u'', u'company': u'Bharat S.', u'unit': u''}

-- line #15201
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'GAS GANGRENE ANTITOXIN', u'always_empty': u'', u'form': u'INJ', u'brand': u'GAS GANGRENE ANTITOXIN', u'strength_3': u'', u'company': u'Haffkine', u'unit': u''}

-- line #15202
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'400', u'strength_2': u'', u'substance': u'Gatifloxacin', u'always_empty': u'', u'form': u'', u'brand': u'3A-GAT ALU-ALU', u'strength_3': u'', u'company': u'3A PHARMA.', u'unit': u'mg'}

-- line #15203
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'3A-GAT 400 (3A PHARMA.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '3A-GAT 400 (3A PHARMA.)'
);

-- line #15204
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADGAT 400 (Admac Ph.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADGAT 400 (Admac Ph.)'
);

-- line #15205
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALGAT 200 (Bergen)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALGAT 200 (Bergen)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALGAT 400 (Bergen)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALGAT 400 (Bergen)'
);

-- line #15206
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARMFLOX 200 (Armour Rem.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARMFLOX 200 (Armour Rem.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARMFLOX 400 (Armour Rem.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARMFLOX 400 (Armour Rem.)'
);

-- line #15207
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVIGAT 100 (Avalanche)',
	'Gatifloxacin',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVIGAT 100 (Avalanche)'
);

-- line #15208
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVIGAT 400 (Avalanche)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVIGAT 400 (Avalanche)'
);

-- line #15209
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Gatifloxacin', u'always_empty': u'', u'form': u'EAR/EYE DPS', u'brand': u'AXGAT', u'strength_3': u'', u'company': u'AXYZEN LIFE', u'unit': u''}

-- line #15210
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOGAT 200 (Biochem)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOGAT 200 (Biochem)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOGAT 400 (Biochem)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOGAT 400 (Biochem)'
);

-- line #15211
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRIGAT 200 (Briskon)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRIGAT 200 (Briskon)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRIGAT 400 (Briskon)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRIGAT 400 (Briskon)'
);

-- line #15212
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-GAT 200 (INVISION(INFALIFE))',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-GAT 200 (INVISION(INFALIFE))'
);

-- line #15213
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUGAT 200 (Cubit Hc.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUGAT 200 (Cubit Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUGAT 400 (Cubit Hc.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUGAT 400 (Cubit Hc.)'
);

-- line #15214
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DASIKON 10 (Neon)',
	'Gatifloxacin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DASIKON 10 (Neon)'
);

-- line #15215
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIOGET 400 (Divine Life)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIOGET 400 (Divine Life)'
);

-- line #15216
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ECOGAT-BCD 200 (Torrent)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ECOGAT-BCD 200 (Torrent)'
);

-- line #15217
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ECOGAT-BCD 400 (Torrent)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ECOGAT-BCD 400 (Torrent)'
);

-- line #15218
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ECOGAT 200 (Torrent)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ECOGAT 200 (Torrent)'
);

-- line #15219
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ECOGAT 400 (Torrent)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ECOGAT 400 (Torrent)'
);

-- line #15220
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'E-GATI 400 (MARLINE BIO.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'E-GATI 400 (MARLINE BIO.)'
);

-- line #15221
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENGATT 0.3 (Entod Ph.)',
	'Gatifloxacin',
	'EYE DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENGATT 0.3 (Entod Ph.)'
);

-- line #15222
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXAGT 200 (Alembic)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXAGT 200 (Alembic)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXAGT 400 (Alembic)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXAGT 400 (Alembic)'
);

-- line #15223
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOGAT 400 (TWILIGHT LIT.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOGAT 400 (TWILIGHT LIT.)'
);

-- line #15224
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXGAT EYE 0.3 (Jawa Ph.)',
	'Gatifloxacin',
	'DROPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXGAT EYE 0.3 (Jawa Ph.)'
);

-- line #15225
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXGAT 0.3 (Jawa Ph.)',
	'Gatifloxacin',
	'EYE OINT',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXGAT 0.3 (Jawa Ph.)'
);

-- line #15226
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXIGAT 200 (Medley)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXIGAT 200 (Medley)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXIGAT 400 (Medley)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXIGAT 400 (Medley)'
);

-- line #15227
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOTY 400 (Biocin Hc.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOTY 400 (Biocin Hc.)'
);

-- line #15228
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FYGAT 400 (Phytochem)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FYGAT 400 (Phytochem)'
);

-- line #15229
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G2K 200 (Biological E.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G2K 200 (Biological E.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G2K 400 (Biological E.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G2K 400 (Biological E.)'
);

-- line #15230
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GABEE 200 (DR. ALSON)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GABEE 200 (DR. ALSON)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GABEE 400 (DR. ALSON)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GABEE 400 (DR. ALSON)'
);

-- line #15231
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GAITY 10 (Dr.Reddy''S)',
	'Gatifloxacin',
	'INF',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GAITY 10 (Dr.Reddy''S)'
);

-- line #15232
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GAITY 200 (Dr.Reddy''S)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GAITY 200 (Dr.Reddy''S)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GAITY 400 (Dr.Reddy''S)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GAITY 400 (Dr.Reddy''S)'
);

-- line #15233
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GARIMORE 100 (Moraceae)',
	'Gatifloxacin',
	'SUSP',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GARIMORE 100 (Moraceae)'
);

-- line #15234
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATE 0.3 (Ajanta Ph.)',
	'Gatifloxacin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATE 0.3 (Ajanta Ph.)'
);

-- line #15235
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATE-HS EYE 5 (Ajanta Ph.)',
	'Gatifloxacin',
	'DROPS',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATE-HS EYE 5 (Ajanta Ph.)'
);

-- line #15236
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATE 200 (Ajanta Ph.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATE 200 (Ajanta Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATE 400 (Ajanta Ph.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATE 400 (Ajanta Ph.)'
);

-- line #15237
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATIA 200 (Ravian)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATIA 200 (Ravian)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATIA 400 (Ravian)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATIA 400 (Ravian)'
);

-- line #15238
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATIBA 200 (ACTO)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATIBA 200 (ACTO)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATIBA 400 (ACTO)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATIBA 400 (ACTO)'
);

-- line #15239
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATIBLU 0.3 (Lupin)',
	'Gatifloxacin',
	'EYE DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATIBLU 0.3 (Lupin)'
);

-- line #15240
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATICAD 400 (Admac (CADMA))',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATICAD 400 (Admac (CADMA))'
);

-- line #15241
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATICARE 400 (Azime Hc.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATICARE 400 (Azime Hc.)'
);

-- line #15242
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATICAS 400 (CASCA)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATICAS 400 (CASCA)'
);

-- line #15243
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATICA 200 (Indica)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATICA 200 (Indica)'
);

-- line #15244
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATICA 400 (Indica)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATICA 400 (Indica)'
);

-- line #15245
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATICIN 0.3 (Aristo)',
	'Gatifloxacin',
	'EYE DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATICIN 0.3 (Aristo)'
);

-- line #15246
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATICIN 10 (Aristo)',
	'Gatifloxacin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATICIN 10 (Aristo)'
);

-- line #15247
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATICIN 200 (Aristo)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATICIN 200 (Aristo)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATICIN 400 (Aristo)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATICIN 400 (Aristo)'
);

-- line #15248
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATIER 400 (Arbro Ph.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATIER 400 (Arbro Ph.)'
);

-- line #15249
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATIFAST 400 (Chemo Bio.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATIFAST 400 (Chemo Bio.)'
);

-- line #15250
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Gatifloxacin', u'always_empty': u'', u'form': u'EYE DPS', u'brand': u'GATIFAX', u'strength_3': u'', u'company': u'Optho Rem.', u'unit': u''}

-- line #15251
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATIFECT 400 (Wockhardt)',
	'Gatifloxacin',
	'INFUSION',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATIFECT 400 (Wockhardt)'
);

-- line #15252
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATIFECT 200 (Wockhardt)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATIFECT 200 (Wockhardt)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATIFECT 400 (Wockhardt)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATIFECT 400 (Wockhardt)'
);

-- line #15253
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATIFIN 400 (Elfin Ph.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATIFIN 400 (Elfin Ph.)'
);

-- line #15254
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATIFIX 200 (Dallas Ph.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATIFIX 200 (Dallas Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATIFIX 400 (Dallas Ph.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATIFIX 400 (Dallas Ph.)'
);

-- line #15255
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATIF 200 (UNISEARCH HC.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATIF 200 (UNISEARCH HC.)'
);

-- line #15256
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATIF 400 (UNISEARCH HC.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATIF 400 (UNISEARCH HC.)'
);

-- line #15257
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATIGO 200 (Intra Lab)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATIGO 200 (Intra Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATIGO 400 (Intra Lab)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATIGO 400 (Intra Lab)'
);

-- line #15258
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATIGRAM 200 (Eros Ph.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATIGRAM 200 (Eros Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATIGRAM 400 (Eros Ph.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATIGRAM 400 (Eros Ph.)'
);

-- line #15259
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATIKIND 0.3 (LIFESTAR)',
	'Gatifloxacin',
	'EYE DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATIKIND 0.3 (LIFESTAR)'
);

-- line #15260
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATIKIND 200 (Mankind)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATIKIND 200 (Mankind)'
);

-- line #15261
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATIKIND 400 (Mankind)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATIKIND 400 (Mankind)'
);

-- line #15262
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATILAX 400 (Helax Hc.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATILAX 400 (Helax Hc.)'
);

-- line #15263
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATILEX 200 (Lexus)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATILEX 200 (Lexus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATILEX 400 (Lexus)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATILEX 400 (Lexus)'
);

-- line #15264
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATILINK 200 (Lincoln)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATILINK 200 (Lincoln)'
);

-- line #15265
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATILINK 400 (Lincoln)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATILINK 400 (Lincoln)'
);

-- line #15266
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATILOB 400 (Graf Lab.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATILOB 400 (Graf Lab.)'
);

-- line #15267
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATILOX CONC 10 (Sun)',
	'Gatifloxacin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATILOX CONC 10 (Sun)'
);

-- line #15268
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATILOX 3 (Sun)',
	'Gatifloxacin',
	'DPS',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATILOX 3 (Sun)'
);

-- line #15269
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATILOX 400 (Solares (Sun))',
	'Gatifloxacin',
	'INJ',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATILOX 400 (Solares (Sun))'
);

-- line #15270
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2', u'strength_2': u'', u'substance': u'Gatifloxacin', u'always_empty': u'', u'form': u'', u'brand': u'GATILOX IVINF', u'strength_3': u'', u'company': u'Sun', u'unit': u'mg/ML'}

-- line #15271
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATILOX 200 (Sun)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATILOX 200 (Sun)'
);

-- line #15272
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATILOX 400 (Sun)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATILOX 400 (Sun)'
);

-- line #15273
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATIMAC 200 (Macleods)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATIMAC 200 (Macleods)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATIMAC 400 (Macleods)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATIMAC 400 (Macleods)'
);

-- line #15274
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATIMAL 400 (Malar Hc.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATIMAL 400 (Malar Hc.)'
);

-- line #15275
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATIMA 200 (Medoz Ph.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATIMA 200 (Medoz Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATIMA 400 (Medoz Ph.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATIMA 400 (Medoz Ph.)'
);

-- line #15276
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATIMORE 400 (Moraceae)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATIMORE 400 (Moraceae)'
);

-- line #15277
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATINA 400 (Sayona)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATINA 400 (Sayona)'
);

-- line #15278
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATINEX 400 (Nestor)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATINEX 400 (Nestor)'
);

-- line #15279
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATIN 200 (EAST WEST)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATIN 200 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATIN 400 (EAST WEST)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATIN 400 (EAST WEST)'
);

-- line #15280
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATIPAN 400 (Panjon)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATIPAN 400 (Panjon)'
);

-- line #15281
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATIPEN 400 (Panjon)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATIPEN 400 (Panjon)'
);

-- line #15282
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATIQUIN 0.3 (Cipla)',
	'Gatifloxacin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATIQUIN 0.3 (Cipla)'
);

-- line #15283
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATIQUIN 400 (Cipla)',
	'Gatifloxacin',
	'INF',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATIQUIN 400 (Cipla)'
);

-- line #15284
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATIQUIN 200 (Cipla)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATIQUIN 200 (Cipla)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATIQUIN 400 (Cipla)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATIQUIN 400 (Cipla)'
);

-- line #15285
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATIRIC 400 (Euphoric)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATIRIC 400 (Euphoric)'
);

-- line #15286
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATIRISE 200 (Sunrise Rem.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATIRISE 200 (Sunrise Rem.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATIRISE 400 (Sunrise Rem.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATIRISE 400 (Sunrise Rem.)'
);

-- line #15287
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATIROL 200 (PHARMATECH)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATIROL 200 (PHARMATECH)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATIROL 400 (PHARMATECH)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATIROL 400 (PHARMATECH)'
);

-- line #15288
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATISAN 400 (SANCHEZ LAB.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATISAN 400 (SANCHEZ LAB.)'
);

-- line #15289
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATISPAN 200 (Lupin)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATISPAN 200 (Lupin)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATISPAN 400 (Lupin)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATISPAN 400 (Lupin)'
);

-- line #15290
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATIS 200 (Cosmas Ph.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATIS 200 (Cosmas Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATIS 400 (Cosmas Ph.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATIS 400 (Cosmas Ph.)'
);

-- line #15291
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATISTAC 400 (Atoz Ph.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATISTAC 400 (Atoz Ph.)'
);

-- line #15292
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATISTAL 400 (Stallion)',
	'Gatifloxacin',
	'INF',
	gm.nullify_empty_string('400')::numeric,
	'mg/200ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATISTAL 400 (Stallion)'
);

-- line #15293
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATISTAL 200 (Stallion)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATISTAL 200 (Stallion)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATISTAL 400 (Stallion)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATISTAL 400 (Stallion)'
);

-- line #15294
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATISTAR 400 (SIFAM PH.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATISTAR 400 (SIFAM PH.)'
);

-- line #15295
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATITOON 200 (Liva Hc.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATITOON 200 (Liva Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATITOON 400 (Liva Hc.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATITOON 400 (Liva Hc.)'
);

-- line #15296
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATITRUST 0.3 (CENTAUR PH.)',
	'Gatifloxacin',
	'EYE DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATITRUST 0.3 (CENTAUR PH.)'
);

-- line #15297
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATIVAR 400 (Zota Ph.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATIVAR 400 (Zota Ph.)'
);

-- line #15298
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATIVA 400 (Aronex Life)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATIVA 400 (Aronex Life)'
);

-- line #15299
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATIVON 400 (Kinedex Hc.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATIVON 400 (Kinedex Hc.)'
);

-- line #15300
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATIWIZ 200 (Wisdom Ph.)',
	'Gatifloxacin',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATIWIZ 200 (Wisdom Ph.)'
);

-- line #15301
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATIWIZ 400 (Wisdom Ph.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATIWIZ 400 (Wisdom Ph.)'
);

-- line #15302
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATIX 400 (Intra(INVISION))',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATIX 400 (Intra(INVISION))'
);

-- line #15303
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATIX 200 (INVISION)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATIX 200 (INVISION)'
);

-- line #15304
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATIZED 400 (Zota Ph.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATIZED 400 (Zota Ph.)'
);

-- line #15305
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATIZEN 200 (ALKEM)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATIZEN 200 (ALKEM)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATIZEN 400 (ALKEM)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATIZEN 400 (ALKEM)'
);

-- line #15306
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATIZ 400 (Ritz Ph.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATIZ 400 (Ritz Ph.)'
);

-- line #15307
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATLAK 400 (LAKSUN)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATLAK 400 (LAKSUN)'
);

-- line #15308
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATLAND 200 (L & V PH.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATLAND 200 (L & V PH.)'
);

-- line #15309
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATLAND 400 (L & V PH.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATLAND 400 (L & V PH.)'
);

-- line #15310
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATMOR 400 (ST.MORRISON)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATMOR 400 (ST.MORRISON)'
);

-- line #15311
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATOMED 200 (Aglowmed)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATOMED 200 (Aglowmed)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATOMED 400 (Aglowmed)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATOMED 400 (Aglowmed)'
);

-- line #15312
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATOR 400 (Zuventus)',
	'Gatifloxacin',
	'INJ',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATOR 400 (Zuventus)'
);

-- line #15313
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATOR 200 (Zuventus)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATOR 200 (Zuventus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATOR 400 (Zuventus)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATOR 400 (Zuventus)'
);

-- line #15314
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATO 200 (Ravian)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATO 200 (Ravian)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATO 400 (Ravian)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATO 400 (Ravian)'
);

-- line #15315
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATOX 200 (Rpg Life)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATOX 200 (Rpg Life)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATOX 400 (Rpg Life)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATOX 400 (Rpg Life)'
);

-- line #15316
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATRI 2 (Nicholas)',
	'Gatifloxacin',
	'INF',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATRI 2 (Nicholas)'
);

-- line #15317
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I', u'strength_2': u'', u'substance': u'Gatifloxacin', u'always_empty': u'', u'form': u'SUS', u'brand': u'GATRI', u'strength_3': u'', u'company': u'Nicholas', u'unit': u''}

-- line #15318
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATRI 200 (Nicholas)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATRI 200 (Nicholas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATRI 400 (Nicholas)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATRI 400 (Nicholas)'
);

-- line #15319
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATRIX 400 (Metrix Hc.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATRIX 400 (Metrix Hc.)'
);

-- line #15320
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATSUN 0.3 (Sunways)',
	'Gatifloxacin',
	'OINT',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATSUN 0.3 (Sunways)'
);

-- line #15321
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATT 0.3 (Le Sante)',
	'Gatifloxacin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATT 0.3 (Le Sante)'
);

-- line #15322
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATTO 400 (Sanjeevani Bio.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATTO 400 (Sanjeevani Bio.)'
);

-- line #15323
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATT 200 (Le Sante)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATT 200 (Le Sante)'
);

-- line #15324
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATT 400 (Le Sante)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATT 400 (Le Sante)'
);

-- line #15325
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATVEN 0.3 (VENSAT)',
	'Gatifloxacin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATVEN 0.3 (VENSAT)'
);

-- line #15326
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATVEN 200 (VENSAT)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATVEN 200 (VENSAT)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATVEN 400 (VENSAT)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATVEN 400 (VENSAT)'
);

-- line #15327
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GATYMAL 400 (Malar Hc.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GATYMAL 400 (Malar Hc.)'
);

-- line #15328
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G-CEBRAN 200 (Blue Cross)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G-CEBRAN 200 (Blue Cross)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G-CEBRAN 400 (Blue Cross)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G-CEBRAN 400 (Blue Cross)'
);

-- line #15329
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GETFLOX 200 (Finecure)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GETFLOX 200 (Finecure)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GETFLOX 400 (Finecure)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GETFLOX 400 (Finecure)'
);

-- line #15330
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GETOLI 0.3 (Zee Lab)',
	'Gatifloxacin',
	'EYE DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GETOLI 0.3 (Zee Lab)'
);

-- line #15331
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GETOLI 400 (Zee Lab)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GETOLI 400 (Zee Lab)'
);

-- line #15332
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GETWIN 400 (Jaywin)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GETWIN 400 (Jaywin)'
);

-- line #15333
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GFC 0.3 (Pharmtak)',
	'Gatifloxacin',
	'EYE DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GFC 0.3 (Pharmtak)'
);

-- line #15334
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GFLOTAS 0.3 (Intas)',
	'Gatifloxacin',
	'EYE DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GFLOTAS 0.3 (Intas)'
);

-- line #15335
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G-FLOX 200 (Jackson)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G-FLOX 200 (Jackson)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G-FLOX 400 (Jackson)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G-FLOX 400 (Jackson)'
);

-- line #15336
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GF-QUIN 200 (Nexus)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GF-QUIN 200 (Nexus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GF-QUIN 400 (Nexus)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GF-QUIN 400 (Nexus)'
);

-- line #15337
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GF 200 (Unique)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GF 200 (Unique)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GF 400 (Unique)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GF 400 (Unique)'
);

-- line #15338
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GIFLEXCIN 200 (Bombay T.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GIFLEXCIN 200 (Bombay T.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GIFLEXCIN 400 (Bombay T.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GIFLEXCIN 400 (Bombay T.)'
);

-- line #15339
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GIFTUM 200 (Winsome Lab)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GIFTUM 200 (Winsome Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GIFTUM 400 (Winsome Lab)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GIFTUM 400 (Winsome Lab)'
);

-- line #15340
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G-KEP 400 (Kepsee)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G-KEP 400 (Kepsee)'
);

-- line #15341
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GOLTI 400 (Kwik Hc.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GOLTI 400 (Kwik Hc.)'
);

-- line #15342
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GOR-400 400 (Corona)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GOR-400 400 (Corona)'
);

-- line #15343
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G-QUIN 200 (Helios Ph.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G-QUIN 200 (Helios Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G-QUIN 400 (Helios Ph.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G-QUIN 400 (Helios Ph.)'
);

-- line #15344
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRACEGAT 200 (CHEMO HC.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRACEGAT 200 (CHEMO HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRACEGAT 400 (CHEMO HC.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRACEGAT 400 (CHEMO HC.)'
);

-- line #15345
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRANAZ 200 (Indchemie)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRANAZ 200 (Indchemie)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRANAZ 400 (Indchemie)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRANAZ 400 (Indchemie)'
);

-- line #15346
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRES 2 (Nicholas)',
	'Gatifloxacin',
	'INF',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRES 2 (Nicholas)'
);

-- line #15347
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRES 200 (Nicholas)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRES 200 (Nicholas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRES 400 (Nicholas)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRES 400 (Nicholas)'
);

-- line #15348
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GTFLOX 400 (Indu D.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GTFLOX 400 (Indu D.)'
);

-- line #15349
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GULF 400 (Siomond)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GULF 400 (Siomond)'
);

-- line #15350
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GUTS 0.3 (Ind-Swift)',
	'Gatifloxacin',
	'EYE DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GUTS 0.3 (Ind-Swift)'
);

-- line #15351
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GUTS 100 (Ind-Swift)',
	'Gatifloxacin',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/150ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GUTS 100 (Ind-Swift)'
);

-- line #15352
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GUTS 200 (Ind-Swift)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GUTS 200 (Ind-Swift)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GUTS 400 (Ind-Swift)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GUTS 400 (Ind-Swift)'
);

-- line #15353
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GUTTS 0.3 (Ind-Swift)',
	'Gatifloxacin',
	'EYE DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%V/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GUTTS 0.3 (Ind-Swift)'
);

-- line #15354
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GUTTS 100 (Ind-Swift)',
	'Gatifloxacin',
	'SUSP',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GUTTS 100 (Ind-Swift)'
);

-- line #15355
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Gatifloxacin', u'always_empty': u'', u'form': u'EYE DPS', u'brand': u'GYLPH', u'strength_3': u'', u'company': u'Globus', u'unit': u''}

-- line #15356
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'I-GATE 0.3 (VISION PH.)',
	'Gatifloxacin',
	'EYE DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'I-GATE 0.3 (VISION PH.)'
);

-- line #15357
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTRAGAT 200 (Intra Lab)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTRAGAT 200 (Intra Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTRAGAT 400 (Intra Lab)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTRAGAT 400 (Intra Lab)'
);

-- line #15358
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Gatifloxacin', u'always_empty': u'', u'form': u'', u'brand': u'KETOMAR', u'strength_3': u'', u'company': u'Allergan', u'unit': u''}

-- line #15359
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LGS 200 (Shrinivas)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LGS 200 (Shrinivas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LGS 400 (Shrinivas)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LGS 400 (Shrinivas)'
);

-- line #15360
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUGAT 0.3 (LUCO HC.)',
	'Gatifloxacin',
	'EYE DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUGAT 0.3 (LUCO HC.)'
);

-- line #15361
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYFLOX 200 (HETERO HC.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYFLOX 200 (HETERO HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYFLOX 400 (HETERO HC.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYFLOX 400 (HETERO HC.)'
);

-- line #15362
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICROGAT 0.3 (Micro V.)',
	'Gatifloxacin',
	'EYE DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICROGAT 0.3 (Micro V.)'
);

-- line #15363
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICROGAT 0.3 (Micro Labs)',
	'Gatifloxacin',
	'EYE OINT',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICROGAT 0.3 (Micro Labs)'
);

-- line #15364
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICROGAT 200 (Micro Nova)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICROGAT 200 (Micro Nova)'
);

-- line #15365
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICROGAT 400 (Micro Nova)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICROGAT 400 (Micro Nova)'
);

-- line #15366
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'400', u'strength_2': u'', u'substance': u'Gatifloxacin', u'always_empty': u'', u'form': u'', u'brand': u'MYGAT IV', u'strength_3': u'', u'company': u'Panacea', u'unit': u'mg/200ML'}

-- line #15367
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYGAT 200 (Panacea)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYGAT 200 (Panacea)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYGAT 400 (Panacea)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYGAT 400 (Panacea)'
);

-- line #15368
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITGAT 400 (Nitin Ph.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITGAT 400 (Nitin Ph.)'
);

-- line #15369
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCUGATE 0.3 (Yash Ph.)',
	'Gatifloxacin',
	'EYE ONIT',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCUGATE 0.3 (Yash Ph.)'
);

-- line #15370
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OVIGAT 400 (Zedip Form.)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OVIGAT 400 (Zedip Form.)'
);

-- line #15371
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Gatifloxacin', u'always_empty': u'', u'form': u'DPS', u'brand': u'OXIGAT', u'strength_3': u'', u'company': u'Indoco Rem.', u'unit': u''}

-- line #15372
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXIGAT 0.3 (Warren)',
	'Gatifloxacin',
	'EYE DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXIGAT 0.3 (Warren)'
);

-- line #15373
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POWERGAT 200 (Khandelwal)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POWERGAT 200 (Khandelwal)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POWERGAT 400 (Khandelwal)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POWERGAT 400 (Khandelwal)'
);

-- line #15374
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRAGATI 250 (Olcare)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRAGATI 250 (Olcare)'
);

-- line #15375
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRAGATI 500 (Olcare)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRAGATI 500 (Olcare)'
);

-- line #15376
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,3', u'strength_2': u'', u'substance': u'Gatifloxacin', u'always_empty': u'', u'form': u'', u'brand': u'Q4DPS', u'strength_3': u'', u'company': u'Appasamy', u'unit': u'%'}

-- line #15377
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q GAT 200 (Cipla)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q GAT 200 (Cipla)'
);

-- line #15378
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q GAT 400 (Cipla)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q GAT 400 (Cipla)'
);

-- line #15379
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUGAT 400 (Baroque)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUGAT 400 (Baroque)'
);

-- line #15380
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUZAR 200 (Emcure)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUZAR 200 (Emcure)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUZAR 400 (Emcure)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUZAR 400 (Emcure)'
);

-- line #15381
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAGACIN 2 (Stancare)',
	'Gatifloxacin',
	'INF',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAGACIN 2 (Stancare)'
);

-- line #15382
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAGACIN 200 (Stancare)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAGACIN 200 (Stancare)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAGACIN 400 (Stancare)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAGACIN 400 (Stancare)'
);

-- line #15383
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REGAT 200 (Kopran)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REGAT 200 (Kopran)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REGAT 400 (Kopran)',
	'Gatifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REGAT 400 (Kopran)'
);

-- line #15384
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250', u'strength_2': u'', u'substance': u'GEFITINIB', u'always_empty': u'', u'form': u'', u'brand': u'CHEMOFIT', u'strength_3': u'', u'company': u'Rpg Life', u'unit': u'mg'}

-- line #15385
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMFIB 250 (Emcure)',
	'GEFITINIB',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMFIB 250 (Emcure)'
);

-- line #15386
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPIGEFF 250 (UTTARA BIO.)',
	'GEFITINIB',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPIGEFF 250 (UTTARA BIO.)'
);

-- line #15387
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250', u'strength_2': u'', u'substance': u'GEFITINIB', u'always_empty': u'', u'form': u'', u'brand': u'GEFFON', u'strength_3': u'', u'company': u'ZYDUS ONC.', u'unit': u'mg'}

-- line #15388
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEFFY 250 (Intas)',
	'GEFITINIB',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEFFY 250 (Intas)'
);

-- line #15389
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEFICAD 250 (Cadila Ph.)',
	'GEFITINIB',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEFICAD 250 (Cadila Ph.)'
);

-- line #15390
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250', u'strength_2': u'', u'substance': u'GEFITINIB', u'always_empty': u'', u'form': u'', u'brand': u'GEFITERO', u'strength_3': u'', u'company': u'HETERO HC.', u'unit': u'mg'}

-- line #15391
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEFITINIB 250 (Khandelwal)',
	'GEFITINIB',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEFITINIB 250 (Khandelwal)'
);

-- line #15392
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEFTIB 250 (ONKOS(GLENMARK))',
	'GEFITINIB',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEFTIB 250 (ONKOS(GLENMARK))'
);

-- line #15393
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEFTIPAR 250 (Parentral)',
	'GEFITINIB',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEFTIPAR 250 (Parentral)'
);

-- line #15394
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEFTITRUST 250 (Panacea)',
	'GEFITINIB',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEFTITRUST 250 (Panacea)'
);

-- line #15395
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IRESSA 250 (Astrazeneca)',
	'GEGITINIB',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IRESSA 250 (Astrazeneca)'
);

-- line #15396
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1GM', u'strength_2': u'', u'substance': u'Gemcitabine Hcl.', u'always_empty': u'', u'form': u'VIAL', u'brand': u'ABINGEM', u'strength_3': u'', u'company': u'MIRACALUS', u'unit': u''}

-- line #15397
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ABINGEM 200 (MIRACALUS)',
	'Gemcitabine Hcl.',
	'VIAL',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ABINGEM 200 (MIRACALUS)'
);

-- line #15398
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMGEM 200 (AMRONCO)',
	'Gemcitabine Hcl.',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg/1G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMGEM 200 (AMRONCO)'
);

-- line #15399
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOGEM 200 (United Bio.)',
	'Gemcitabine Hcl.',
	'VIAL',
	gm.nullify_empty_string('200')::numeric,
	'mg/1G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOGEM 200 (United Bio.)'
);

-- line #15400
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Gemcitabine Hcl.', u'always_empty': u'', u'form': u'VIAL', u'brand': u'CELGEM', u'strength_3': u'', u'company': u'Cytomed(Alkem)', u'unit': u''}

-- line #15401
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELGEM 200 (Cytomed(Alkem))',
	'Gemcitabine Hcl.',
	'VIAL',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELGEM 200 (Cytomed(Alkem))'
);

-- line #15402
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELZAR 200 (CELON(VIVILON))',
	'Gemcitabine Hcl.',
	'VIAL',
	gm.nullify_empty_string('200')::numeric,
	'1000'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELZAR 200 (CELON(VIVILON))'
);

-- line #15403
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Gemcitabine Hcl.', u'always_empty': u'', u'form': u'VIAL', u'brand': u'CYTOGEM', u'strength_3': u'', u'company': u"Dr.Reddy''S", u'unit': u''}

-- line #15404
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYTOGEM 200 (Dr.Reddy''S)',
	'Gemcitabine Hcl.',
	'VIAL',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYTOGEM 200 (Dr.Reddy''S)'
);

-- line #15405
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Gemcitabine Hcl.', u'always_empty': u'', u'form': u'VIAL', u'brand': u'EMCITABEN GM', u'strength_3': u'', u'company': u'Rpg Life', u'unit': u''}

-- line #15406
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMCITABEN 200 (Rpg Life)',
	'Gemcitabine Hcl.',
	'VIAL',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMCITABEN 200 (Rpg Life)'
);

-- line #15407
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Gemcitabine Hcl.', u'always_empty': u'', u'form': u'INJ', u'brand': u'GEMACTA', u'strength_3': u'', u'company': u'Macleods', u'unit': u''}

-- line #15408
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEMACTA 200 (Macleods)',
	'Gemcitabine Hcl.',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEMACTA 200 (Macleods)'
);

-- line #15409
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEMBIN 200 (Biochem)',
	'Gemcitabine Hcl.',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEMBIN 200 (Biochem)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEMBIN 1000 (Biochem)',
	'Gemcitabine Hcl.',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEMBIN 1000 (Biochem)'
);

-- line #15410
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Gemcitabine Hcl.', u'always_empty': u'', u'form': u'INJ', u'brand': u'GEMCIMINE', u'strength_3': u'', u'company': u'ZEN LIFE', u'unit': u''}

-- line #15411
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEMCIMINE 200 (ZEN LIFE)',
	'Gemcitabine Hcl.',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEMCIMINE 200 (ZEN LIFE)'
);

-- line #15412
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEMCITAPAR 1000 (Parenteral)',
	'Gemcitabine Hcl.',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg(LYOPHILIZED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEMCITAPAR 1000 (Parenteral)'
);

-- line #15413
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEMCITAPAR 200 (Parenteral)',
	'Gemcitabine Hcl.',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg(LYOPHILIZED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEMCITAPAR 200 (Parenteral)'
);

-- line #15414
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Gemcitabine Hcl.', u'always_empty': u'', u'form': u'INJ', u'brand': u'GEMCITE', u'strength_3': u'', u'company': u'Eli Lilly', u'unit': u''}

-- line #15415
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEMCITE 200 (Eli Lilly)',
	'Gemcitabine Hcl.',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEMCITE 200 (Eli Lilly)'
);

-- line #15416
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Gemcitabine Hcl.', u'always_empty': u'', u'form': u'INJ', u'brand': u'GEMNAT GM', u'strength_3': u'', u'company': u'Natco Ph.', u'unit': u''}

-- line #15417
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Gemcitabine Hcl.', u'always_empty': u'', u'form': u'INJ', u'brand': u'GEMPOWER GM', u'strength_3': u'', u'company': u'Khandelwal', u'unit': u''}

-- line #15418
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Gemcitabine Hcl.', u'always_empty': u'', u'form': u'INJ', u'brand': u'GEMPOWER', u'strength_3': u'', u'company': u'Khandelwal', u'unit': u''}

-- line #15419
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEMPOWER 200 (Khandelwal)',
	'Gemcitabine Hcl.',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEMPOWER 200 (Khandelwal)'
);

-- line #15420
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEMSPERA 1000 (Indoco Rem.)',
	'Gemcitabine Hcl.',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEMSPERA 1000 (Indoco Rem.)'
);

-- line #15421
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEMSPERA 1400 (Indoco Rem.)',
	'Gemcitabine Hcl.',
	'INJ',
	gm.nullify_empty_string('1400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEMSPERA 1400 (Indoco Rem.)'
);

-- line #15422
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEMSPERA 200 (Indoco Rem.)',
	'Gemcitabine Hcl.',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEMSPERA 200 (Indoco Rem.)'
);

-- line #15423
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEMTAZ 200 (Sun)',
	'Gemcitabine Hcl.',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEMTAZ 200 (Sun)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEMTAZ 1000 (Sun)',
	'Gemcitabine Hcl.',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEMTAZ 1000 (Sun)'
);

-- line #15424
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Gemcitabine Hcl.', u'always_empty': u'', u'form': u'INJ', u'brand': u'GEMTERO', u'strength_3': u'', u'company': u'HETERO HC.', u'unit': u''}

-- line #15425
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEMTERO 200 (HETERO HC.)',
	'Gemcitabine Hcl.',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEMTERO 200 (HETERO HC.)'
);

-- line #15426
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEMTRUST 1000 (Panacea)',
	'Gemcitabine Hcl.',
	'VIAL',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEMTRUST 1000 (Panacea)'
);

-- line #15427
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEMTRUST 200 (Panacea)',
	'Gemcitabine Hcl.',
	'VIAL',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEMTRUST 200 (Panacea)'
);

-- line #15428
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1400', u'strength_2': u'', u'substance': u'Gemcitabine Hcl.', u'always_empty': u'', u'form': u'', u'brand': u'GENSPERA', u'strength_3': u'', u'company': u'Indoco Rem.', u'unit': u'mg'}

-- line #15429
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Gemcitabine Hcl.', u'always_empty': u'', u'form': u'INJ', u'brand': u'LIFOGEM', u'strength_3': u'', u'company': u'Samarth', u'unit': u''}

-- line #15430
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIFOGEM 200 (Samarth)',
	'Gemcitabine Hcl.',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIFOGEM 200 (Samarth)'
);

-- line #15431
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONCOGEM 200 (Cipla)',
	'Gemcitabine Hcl.',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONCOGEM 200 (Cipla)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONCOGEM 1000 (Cipla)',
	'Gemcitabine Hcl.',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONCOGEM 1000 (Cipla)'
);

-- line #15432
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEMPAR 300 (Zydus Cadila)',
	'Gemfibrozil',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEMPAR 300 (Zydus Cadila)'
);

-- line #15433
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPIGEM 300 (Tide)',
	'Gemfibrozil',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPIGEM 300 (Tide)'
);

-- line #15434
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPIZYL 300 (Piramal Hc.)',
	'Gemfibrozil',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPIZYL 300 (Piramal Hc.)'
);

-- line #15435
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOPID 300 (PFIZER)',
	'Gemfibrozil',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOPID 300 (PFIZER)'
);

-- line #15436
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOPID 900 (PFIZER)',
	'Gemfibrozil',
	'OD TAB',
	gm.nullify_empty_string('900')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOPID 900 (PFIZER)'
);

-- line #15437
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOPID 600 (PFIZER)',
	'Gemfibrozil',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOPID 600 (PFIZER)'
);

-- line #15438
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSTEROL 300 (Gufic Bio.)',
	'Gemfibrozil',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSTEROL 300 (Gufic Bio.)'
);

-- line #15439
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORMOLIP 300 (Sun)',
	'Gemfibrozil',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORMOLIP 300 (Sun)'
);

-- line #15440
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EGL 320 (Cipla)',
	'GEMIFLOXACIN',
	'TAB',
	gm.nullify_empty_string('320')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EGL 320 (Cipla)'
);

-- line #15441
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXIGEM 320 (Medley)',
	'GEMIFLOXACIN',
	'TAB',
	gm.nullify_empty_string('320')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXIGEM 320 (Medley)'
);

-- line #15442
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GAMETOP 320 (SOLITAIRE(RADIX))',
	'GEMIFLOXACIN',
	'TAB',
	gm.nullify_empty_string('320')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GAMETOP 320 (SOLITAIRE(RADIX))'
);

-- line #15443
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GAMIBIT 325 (Cubit Hc.)',
	'GEMIFLOXACIN',
	'TAB',
	gm.nullify_empty_string('325')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GAMIBIT 325 (Cubit Hc.)'
);

-- line #15444
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GAMIORI 320 (ORION BIOTECH.)',
	'GEMIFLOXACIN',
	'TAB',
	gm.nullify_empty_string('320')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GAMIORI 320 (ORION BIOTECH.)'
);

-- line #15445
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G-CIN 320 (Lupin)',
	'GEMIFLOXACIN',
	'TAB',
	gm.nullify_empty_string('320')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G-CIN 320 (Lupin)'
);

-- line #15446
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'GEMIFLOXACIN', u'always_empty': u'', u'form': u'TAB', u'brand': u'G CIN', u'strength_3': u'', u'company': u'LUPIN', u'unit': u''}

-- line #15447
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEMBAX 320 (PHARMA(RANBAXY))',
	'GEMIFLOXACIN',
	'INJ',
	gm.nullify_empty_string('320')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEMBAX 320 (PHARMA(RANBAXY))'
);

-- line #15448
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEMBAX 320 (Ranbaxy)',
	'GEMIFLOXACIN',
	'TAB',
	gm.nullify_empty_string('320')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEMBAX 320 (Ranbaxy)'
);

-- line #15449
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEMEXIN 320 (Zuventus)',
	'GEMIFLOXACIN',
	'TAB',
	gm.nullify_empty_string('320')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEMEXIN 320 (Zuventus)'
);

-- line #15450
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEMEZ 320 (Glenmark)',
	'GEMIFLOXACIN',
	'TAB',
	gm.nullify_empty_string('320')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEMEZ 320 (Glenmark)'
);

-- line #15451
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEMIBID 320 (INVISION)',
	'GEMIFLOXACIN',
	'TAB',
	gm.nullify_empty_string('320')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEMIBID 320 (INVISION)'
);

-- line #15452
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEMICARE 320 (Alembic)',
	'GEMIFLOXACIN',
	'TAB',
	gm.nullify_empty_string('320')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEMICARE 320 (Alembic)'
);

-- line #15453
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEMIDEC 320 (DAKSH)',
	'GEMIFLOXACIN',
	'TAB',
	gm.nullify_empty_string('320')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEMIDEC 320 (DAKSH)'
);

-- line #15454
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEMIFIX 320 (Intra Lab)',
	'GEMIFLOXACIN',
	'TAB',
	gm.nullify_empty_string('320')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEMIFIX 320 (Intra Lab)'
);

-- line #15455
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEMIF 320 (HETERO HC.)',
	'GEMIFLOXACIN',
	'TAB',
	gm.nullify_empty_string('320')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEMIF 320 (HETERO HC.)'
);

-- line #15456
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEMIMAC 320 (Macleods)',
	'GEMIFLOXACIN',
	'TAB',
	gm.nullify_empty_string('320')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEMIMAC 320 (Macleods)'
);

-- line #15457
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEMINEX 320 (Macleods)',
	'GEMIFLOXACIN',
	'TAB',
	gm.nullify_empty_string('320')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEMINEX 320 (Macleods)'
);

-- line #15458
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEMIQUIN 320 (Aristo)',
	'GEMIFLOXACIN',
	'TAB',
	gm.nullify_empty_string('320')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEMIQUIN 320 (Aristo)'
);

-- line #15459
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEMISTAR 320 (Torrent)',
	'GEMIFLOXACIN',
	'TAB',
	gm.nullify_empty_string('320')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEMISTAR 320 (Torrent)'
);

-- line #15460
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEMITAB 320 (Micro Labs)',
	'GEMIFLOXACIN',
	'TAB',
	gm.nullify_empty_string('320')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEMITAB 320 (Micro Labs)'
);

-- line #15461
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEMONE 320 (Dr.Reddy''S)',
	'GEMIFLOXACIN',
	'TAB',
	gm.nullify_empty_string('320')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEMONE 320 (Dr.Reddy''S)'
);

-- line #15462
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEMSHARP 320 (Indoco Rem.)',
	'GEMIFLOXACIN',
	'TAB',
	gm.nullify_empty_string('320')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEMSHARP 320 (Indoco Rem.)'
);

-- line #15463
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEMVEN 320 (VENSAT)',
	'GEMIFLOXACIN',
	'TAB',
	gm.nullify_empty_string('320')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEMVEN 320 (VENSAT)'
);

-- line #15464
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'GEMIFLOXACIN', u'always_empty': u'', u'form': u'TAB', u'brand': u'GEX', u'strength_3': u'', u'company': u'TALENT LAB.', u'unit': u''}

-- line #15465
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'320', u'strength_2': u'', u'substance': u'GEMIFLOXACIN', u'always_empty': u'', u'form': u'', u'brand': u'G-FLOREN', u'strength_3': u'', u'company': u'Indoco Rem.', u'unit': u'mg'}

-- line #15466
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GINI 320 (Unichem)',
	'GEMIFLOXACIN',
	'TAB',
	gm.nullify_empty_string('320')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GINI 320 (Unichem)'
);

-- line #15467
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GQ 320 (Zydus Cadila)',
	'GEMIFLOXACIN',
	'TAB',
	gm.nullify_empty_string('320')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GQ 320 (Zydus Cadila)'
);

-- line #15468
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRAPTOR 320 (AAMORB)',
	'GEMIFLOXACIN',
	'TAB',
	gm.nullify_empty_string('320')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRAPTOR 320 (AAMORB)'
);

-- line #15469
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTIGEM 320 (Ipca)',
	'GEMIFLOXACIN',
	'TAB',
	gm.nullify_empty_string('320')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTIGEM 320 (Ipca)'
);

-- line #15470
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LE-GAMI 325 (Lexus)',
	'GEMIFLOXACIN',
	'TAB',
	gm.nullify_empty_string('325')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LE-GAMI 325 (Lexus)'
);

-- line #15471
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINHEXT 320 (AVENTIS PH.)',
	'GEMIFLOXACIN',
	'TAB',
	gm.nullify_empty_string('320')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINHEXT 320 (AVENTIS PH.)'
);

-- line #15472
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVROCIN 80 (Shinto Org.)',
	'Gentamicin',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVROCIN 80 (Shinto Org.)'
);

-- line #15473
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACTIGEN 0.3 (F D C)',
	'Gentamicin',
	'E/E DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V(SULPH.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACTIGEN 0.3 (F D C)'
);

-- line #15474
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Gentamicin', u'always_empty': u'', u'form': u'EYE DPS', u'brand': u'BEGENTA', u'strength_3': u'', u'company': u'Brooks Ph.', u'unit': u''}

-- line #15475
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Gentamicin', u'always_empty': u'', u'form': u'INJ', u'brand': u'BEGENTA', u'strength_3': u'', u'company': u'Brooks Ph.', u'unit': u''}

-- line #15476
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOGARACIN 10 (Biochem)',
	'Gentamicin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOGARACIN 10 (Biochem)'
);

-- line #15477
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOGARACIN 40 (Biochem)',
	'Gentamicin',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOGARACIN 40 (Biochem)'
);

-- line #15478
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOGARACIN 40 (Biochem)',
	'Gentamicin',
	'VIAL',
	gm.nullify_empty_string('40')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOGARACIN 40 (Biochem)'
);

-- line #15479
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVIMYCIN 40 (DIVINE LAB.)',
	'Gentamicin',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVIMYCIN 40 (DIVINE LAB.)'
);

-- line #15480
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMUGENT 0.3 (Emcure)',
	'Gentamicin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMUGENT 0.3 (Emcure)'
);

-- line #15481
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GARAMAX 80 (Admac Ph.)',
	'Gentamicin',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GARAMAX 80 (Admac Ph.)'
);

-- line #15482
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GARAMYCIN 20 (Fulford)',
	'Gentamicin',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GARAMYCIN 20 (Fulford)'
);

-- line #15483
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GARAMYCIN 60 (Fulford)',
	'Gentamicin',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GARAMYCIN 60 (Fulford)'
);

-- line #15484
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GARAMYCIN 80 (Fulford)',
	'Gentamicin',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GARAMYCIN 80 (Fulford)'
);

-- line #15485
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GARASOL 40 (Jawa Ph.)',
	'Gentamicin',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GARASOL 40 (Jawa Ph.)'
);

-- line #15486
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEM 0.3 (MADHAV BIO.)',
	'Gentamicin',
	'E/E DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEM 0.3 (MADHAV BIO.)'
);

-- line #15487
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEM 80 (MADHAV BIO.)',
	'Gentamicin',
	'VIAL',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEM 80 (MADHAV BIO.)'
);

-- line #15488
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENCIN 0.3 (Dynamic)',
	'Gentamicin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENCIN 0.3 (Dynamic)'
);

-- line #15489
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENCIN 80 (Eg Ph.)',
	'Gentamicin',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENCIN 80 (Eg Ph.)'
);

-- line #15490
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENKA 40 (Cadila Ph.)',
	'Gentamicin',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENKA 40 (Cadila Ph.)'
);

-- line #15491
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENKA 40 (Cadila Ph.)',
	'Gentamicin',
	'VIAL',
	gm.nullify_empty_string('40')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENKA 40 (Cadila Ph.)'
);

-- line #15492
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Gentamicin', u'always_empty': u'', u'form': u'INJ', u'brand': u'GENKIND', u'strength_3': u'', u'company': u'Elfin Ph.', u'unit': u''}

-- line #15493
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Gentamicin', u'always_empty': u'', u'form': u'DROP', u'brand': u'GENMAX', u'strength_3': u'', u'company': u'NIVCA', u'unit': u''}

-- line #15494
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENMIN 0.3 (Milmet)',
	'Gentamicin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENMIN 0.3 (Milmet)'
);

-- line #15495
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENSAT 80 (VENSAT)',
	'Gentamicin',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENSAT 80 (VENSAT)'
);

-- line #15496
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENSAT 80 (VENSAT)',
	'Gentamicin',
	'VIAL',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENSAT 80 (VENSAT)'
);

-- line #15497
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENSTER 0.3 (Sterfil)',
	'Gentamicin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENSTER 0.3 (Sterfil)'
);

-- line #15498
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENSTER 40 (Sterfil)',
	'Gentamicin',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENSTER 40 (Sterfil)'
);

-- line #15499
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENTACIP 40 (Cipla)',
	'Gentamicin',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENTACIP 40 (Cipla)'
);

-- line #15500
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENTACT 80 (DATLA)',
	'Gentamicin',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENTACT 80 (DATLA)'
);

-- line #15501
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENTA-G 80 (Graf Lab.)',
	'Gentamicin',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENTA-G 80 (Graf Lab.)'
);

-- line #15502
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Gentamicin', u'always_empty': u'', u'form': u'CRM', u'brand': u'GENTAMICIN', u'strength_3': u'', u'company': u'HETERO HC.', u'unit': u''}

-- line #15503
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENTAMICIN 80 (Biochem)',
	'Gentamicin',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENTAMICIN 80 (Biochem)'
);

-- line #15504
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENTAMICIN 80 (Claris L.)',
	'Gentamicin',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENTAMICIN 80 (Claris L.)'
);

-- line #15505
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENTAMICIN 40 (Dopson Ph.)',
	'Gentamicin',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENTAMICIN 40 (Dopson Ph.)'
);

-- line #15506
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENTAMICIN 80 (Stadmed)',
	'Gentamicin',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENTAMICIN 80 (Stadmed)'
);

-- line #15507
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENTAMICIN SULPHATE 40 (SHREYA)',
	'Gentamicin',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENTAMICIN SULPHATE 40 (SHREYA)'
);

-- line #15508
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENTAMICIN 240 (Fulford)',
	'Gentamicin',
	'V',
	gm.nullify_empty_string('240')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENTAMICIN 240 (Fulford)'
);

-- line #15509
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENTAMICIN 80 (Fulford)',
	'Gentamicin',
	'V',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENTAMICIN 80 (Fulford)'
);

-- line #15510
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENTANAC 40 (Stanford)',
	'Gentamicin',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENTANAC 40 (Stanford)'
);

-- line #15511
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Gentamicin', u'always_empty': u'', u'form': u'INJ', u'brand': u'GENTASOL', u'strength_3': u'', u'company': u'SANCHEZ LAB.', u'unit': u''}

-- line #15512
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Gentamicin', u'always_empty': u'', u'form': u'CRM', u'brand': u'GENTASPAN', u'strength_3': u'', u'company': u'Biostrass', u'unit': u''}

-- line #15513
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENTASPORIN 10 (P C INDIA)',
	'Gentamicin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENTASPORIN 10 (P C INDIA)'
);

-- line #15514
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENTASPORIN 40 (P C INDIA)',
	'Gentamicin',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENTASPORIN 40 (P C INDIA)'
);

-- line #15515
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENTA SWIFT 0.3 (Ind-Swift)',
	'Gentamicin',
	'E/E DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENTA SWIFT 0.3 (Ind-Swift)'
);

-- line #15516
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENTA SWIFT 80 (Ind-Swift)',
	'Gentamicin',
	'V',
	gm.nullify_empty_string('80')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENTA SWIFT 80 (Ind-Swift)'
);

-- line #15517
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENTATE 0.3 (Parenteral)',
	'Gentamicin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENTATE 0.3 (Parenteral)'
);

-- line #15518
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENTICYN 20 (Nicholas)',
	'Gentamicin',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENTICYN 20 (Nicholas)'
);

-- line #15519
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENTICYN 40 (Nicholas)',
	'Gentamicin',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENTICYN 40 (Nicholas)'
);

-- line #15520
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENTINA 0.3 (Bal Ph.)',
	'Gentamicin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENTINA 0.3 (Bal Ph.)'
);

-- line #15521
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Gentamicin', u'always_empty': u'', u'form': u'INJ', u'brand': u'GENTO', u'strength_3': u'', u'company': u'Sienna Form.', u'unit': u''}

-- line #15522
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENTOMARC 40 (Marc Lab)',
	'Gentamicin',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg/V.'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENTOMARC 40 (Marc Lab)'
);

-- line #15523
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENTY 40 (Jagsonpal)',
	'Gentamicin',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENTY 40 (Jagsonpal)'
);

-- line #15524
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENTYRIC 0.3 (Euphoric)',
	'Gentamicin',
	'E/E DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENTYRIC 0.3 (Euphoric)'
);

-- line #15525
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENTYRIC 40 (Euphoric)',
	'Gentamicin',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENTYRIC 40 (Euphoric)'
);

-- line #15526
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENTYRIC 80 (Euphoric)',
	'Gentamicin',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENTYRIC 80 (Euphoric)'
);

-- line #15527
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GERAMIN 0.3 (Ophthal R.)',
	'Gentamicin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GERAMIN 0.3 (Ophthal R.)'
);

-- line #15528
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GERAMIN 80 (Ophthal R.)',
	'Gentamicin',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GERAMIN 80 (Ophthal R.)'
);

-- line #15529
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GETCIN 80 (Solitaire)',
	'Gentamicin',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GETCIN 80 (Solitaire)'
);

-- line #15530
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G 20 (Kee Ph.)',
	'Gentamicin',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G 20 (Kee Ph.)'
);

-- line #15531
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G 80 (Kee Ph.)',
	'Gentamicin',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G 80 (Kee Ph.)'
);

-- line #15532
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GMI 20 (Ravian)',
	'Gentamicin',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GMI 20 (Ravian)'
);

-- line #15533
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GMI 80 (Ravian)',
	'Gentamicin',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GMI 80 (Ravian)'
);

-- line #15534
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G-MYCIN 40 (P C INDIA)',
	'Gentamicin',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G-MYCIN 40 (P C INDIA)'
);

-- line #15535
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G-MYCIN PAED 10 (Bpl Ph.)',
	'Gentamicin',
	'V',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G-MYCIN PAED 10 (Bpl Ph.)'
);

-- line #15536
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G-MYCIN-P 10 (P C INDIA)',
	'Gentamicin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G-MYCIN-P 10 (P C INDIA)'
);

-- line #15537
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G-MYCIN 40 (Bpl Ph.)',
	'Gentamicin',
	'V(6/20)',
	gm.nullify_empty_string('40')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G-MYCIN 40 (Bpl Ph.)'
);

-- line #15538
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G-MYCIN 40 (Bpl Ph.)',
	'Gentamicin',
	'V',
	gm.nullify_empty_string('40')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G-MYCIN 40 (Bpl Ph.)'
);

-- line #15539
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GROMYCIN 80 (Growell)',
	'Gentamicin',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GROMYCIN 80 (Growell)'
);

-- line #15540
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INGEN 80 (Intra(INVISION))',
	'Gentamicin',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INGEN 80 (Intra(INVISION))'
);

-- line #15541
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INGEN 40 (INVISION)',
	'Gentamicin',
	'VIAL',
	gm.nullify_empty_string('40')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INGEN 40 (INVISION)'
);

-- line #15542
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTRAGEN 0.3 (Intra Lab)',
	'Gentamicin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%(+HPMC)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTRAGEN 0.3 (Intra Lab)'
);

-- line #15543
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTRAGEN 40 (Intra Lab)',
	'Gentamicin',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTRAGEN 40 (Intra Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTRAGEN 80 (Intra Lab)',
	'Gentamicin',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTRAGEN 80 (Intra Lab)'
);

-- line #15544
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LARAMYCIN 40 (HETERO HC.)',
	'Gentamicin',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LARAMYCIN 40 (HETERO HC.)'
);

-- line #15545
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MERIGENTA 0.3 (Mercury)',
	'Gentamicin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MERIGENTA 0.3 (Mercury)'
);

-- line #15546
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MERIGENTA 20 (Mercury)',
	'Gentamicin',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MERIGENTA 20 (Mercury)'
);

-- line #15547
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MERIGENTA 50 (Mercury)',
	'Gentamicin',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MERIGENTA 50 (Mercury)'
);

-- line #15548
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MERIGENTA 80 (Mercury)',
	'Gentamicin',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MERIGENTA 80 (Mercury)'
);

-- line #15549
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICROGEN 80 (Phytochem)',
	'Gentamicin',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICROGEN 80 (Phytochem)'
);

-- line #15550
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCIN 40 (Neon)',
	'Gentamicin',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCIN 40 (Neon)'
);

-- line #15551
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIMICIN 20 (Hal)',
	'Gentamicin',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIMICIN 20 (Hal)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIMICIN 80 (Hal)',
	'Gentamicin',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIMICIN 80 (Hal)'
);

-- line #15552
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROGEN 0.3 (Prohealth)',
	'Gentamicin',
	'E/E DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROGEN 0.3 (Prohealth)'
);

-- line #15553
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RADIX-G 80 (Radix Bio.)',
	'Gentamicin',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RADIX-G 80 (Radix Bio.)'
);

-- line #15554
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIFOBACIN 40 (Andre)',
	'Gentamicin',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIFOBACIN 40 (Andre)'
);

-- line #15555
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BEGENTA 80 (Pfiscar Ind.)',
	'Gentamicin Sulph.',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BEGENTA 80 (Pfiscar Ind.)'
);

-- line #15556
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIGEN 80 (B.M.Ph.)',
	'Gentamicin Sulph.',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIGEN 80 (B.M.Ph.)'
);

-- line #15557
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEN 80 (Mac)',
	'Gentamicin Sulph.',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEN 80 (Mac)'
);

-- line #15558
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEN PAED 20 (Mac)',
	'Gentamicin Sulph.',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEN PAED 20 (Mac)'
);

-- line #15559
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENTACT 80 (Elysium)',
	'Gentamicin Sulph.',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENTACT 80 (Elysium)'
);

-- line #15560
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENTAMIDE 0.3 (Sunways)',
	'Gentamicin Sulph.',
	'E/E DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENTAMIDE 0.3 (Sunways)'
);

-- line #15561
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENTARIL 80 (Alkem)',
	'Gentamicin Sulph.',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENTARIL 80 (Alkem)'
);

-- line #15562
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENTRINE 0.5 (Indiana O.)',
	'Gentamicin Sulph.',
	'E/E DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENTRINE 0.5 (Indiana O.)'
);

-- line #15563
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENTRINE 0.5 (Indiana O.)',
	'Gentamicin Sulph.',
	'EYE OINT',
	gm.nullify_empty_string('0.5')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENTRINE 0.5 (Indiana O.)'
);

-- line #15564
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KARGEN 0.1 (Karlin)',
	'Gentamicin Sulph.',
	'OINT',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KARGEN 0.1 (Karlin)'
);

-- line #15565
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYRAMYCIN 0.3 (HETERO HC.)',
	'Gentamicin Sulph.',
	'E/E DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYRAMYCIN 0.3 (HETERO HC.)'
);

-- line #15566
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYRAMYCIN 40 (HETERO HC.)',
	'Gentamicin Sulph.',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYRAMYCIN 40 (HETERO HC.)'
);

-- line #15567
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYRAMYCIN TOPICAL 0.1 (HETERO HC.)',
	'Gentamicin Sulph.',
	'CRM',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYRAMYCIN TOPICAL 0.1 (HETERO HC.)'
);

-- line #15568
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MERIGENTA 0.1 (Mercury)',
	'Gentamicin Sulph.',
	'CRM',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MERIGENTA 0.1 (Mercury)'
);

-- line #15569
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUGENTA 40 (Indus)',
	'Gentamicin Sulph.',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUGENTA 40 (Indus)'
);

-- line #15570
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIMICIN 0.3 (Hal)',
	'Gentamicin Sulph.',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIMICIN 0.3 (Hal)'
);

-- line #15571
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELDEGENTA 40 (Elder)',
	'Gentamycin',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg (SULPH.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELDEGENTA 40 (Elder)'
);

-- line #15572
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORGENT-80 80 (Norris Med.)',
	'Gentamycin',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORGENT-80 80 (Norris Med.)'
);

-- line #15573
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BILOVAS 40 (German R.)',
	'Ginkgo Biloba',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BILOVAS 40 (German R.)'
);

-- line #15574
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CERESTAR 60 (Solus)',
	'Ginkgo Biloba',
	'CAP',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CERESTAR 60 (Solus)'
);

-- line #15575
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVON 40 (Zee Lab)',
	'Ginkgo Biloba Extract',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg(DRIED EXT.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVON 40 (Zee Lab)'
);

-- line #15576
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIL-B 50 (BIONOVA)',
	'Ginkgo Biloba Extract',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg(WITH VIT.B)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIL-B 50 (BIONOVA)'
);

-- line #15577
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIO-LOBA 50 (INTRA(INVENTURE))',
	'Ginkgo Biloba Extract',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'50'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIO-LOBA 50 (INTRA(INVENTURE))'
);

-- line #15578
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GINKOBA 40 (Micro Nova)',
	'Ginkgo Biloba Extract',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GINKOBA 40 (Micro Nova)'
);

-- line #15579
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GINKOCER 40 (Solus)',
	'Ginkgo Biloba Extract',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GINKOCER 40 (Solus)'
);

-- line #15580
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GINVAS 40 (Cfl Ph.)',
	'Ginkgo Biloba Extract',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GINVAS 40 (Cfl Ph.)'
);

-- line #15581
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GERITISIN 40 (F D C)',
	'Ginkgo Biloba',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GERITISIN 40 (F D C)'
);

-- line #15582
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GINSEC 250 (Solvay Ph.)',
	'Ginseng',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GINSEC 250 (Solvay Ph.)'
);

-- line #15583
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GINSEC 500 (Solvay Ph.)',
	'Ginseng',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GINSEC 500 (Solvay Ph.)'
);

-- line #15584
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLENSENG-500 500 (Glenmark)',
	'Ginseng',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLENSENG-500 500 (Glenmark)'
);

-- line #15585
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLENSENG 667 (Glenmark)',
	'Ginseng',
	'TONIC',
	gm.nullify_empty_string('667')::numeric,
	'mg(POWDER)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLENSENG 667 (Glenmark)'
);

-- line #15586
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JENSHENG 250 (Biological E.)',
	'Ginseng',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JENSHENG 250 (Biological E.)'
);

-- line #15587
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLATIRA 20 (Cipla)',
	'GLATIRAMER ACETATE',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLATIRA 20 (Cipla)'
);

-- line #15588
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AFDIEX 2.5 (Cadila Ph.)',
	'Glibenclamide',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AFDIEX 2.5 (Cadila Ph.)'
);

-- line #15589
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AFDIEX 5 (Cadila Ph.)',
	'Glibenclamide',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AFDIEX 5 (Cadila Ph.)'
);

-- line #15590
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETANASE 5 (Zydus Med.)',
	'Glibenclamide',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETANASE 5 (Zydus Med.)'
);

-- line #15591
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIONIL 5 (Cadila Hc.)',
	'Glibenclamide',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIONIL 5 (Cadila Hc.)'
);

-- line #15592
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-MIDE 5 (Corona)',
	'Glibenclamide',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-MIDE 5 (Corona)'
);

-- line #15593
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CODICA SEMI/5 2.5 (Nicholas)',
	'Glibenclamide',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CODICA SEMI/5 2.5 (Nicholas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CODICA SEMI/5 5 (Nicholas)',
	'Glibenclamide',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CODICA SEMI/5 5 (Nicholas)'
);

-- line #15594
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAONIL SEMI/5 2.5 (Sanofi Aventis)',
	'Glibenclamide',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAONIL SEMI/5 2.5 (Sanofi Aventis)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAONIL SEMI/5 5 (Sanofi Aventis)',
	'Glibenclamide',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAONIL SEMI/5 5 (Sanofi Aventis)'
);

-- line #15595
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'D-CON 10 (GRANDIX)',
	'Glibenclamide',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'D-CON 10 (GRANDIX)'
);

-- line #15596
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'D-CON 2.5 (GRANDIX)',
	'Glibenclamide',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'D-CON 2.5 (GRANDIX)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'D-CON 5 (GRANDIX)',
	'Glibenclamide',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'D-CON 5 (GRANDIX)'
);

-- line #15597
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIABETNIL 5 (Inga)',
	'Glibenclamide',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIABETNIL 5 (Inga)'
);

-- line #15598
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIALIN 5 (Stallion)',
	'Glibenclamide',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIALIN 5 (Stallion)'
);

-- line #15599
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIALONG 5 (Armour Rem.)',
	'Glibenclamide',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIALONG 5 (Armour Rem.)'
);

-- line #15600
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIOLIN 5 (Lincoln)',
	'Glibenclamide',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIOLIN 5 (Lincoln)'
);

-- line #15601
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUGLUCON SEMI/5 2.5 (Nicholas)',
	'Glibenclamide',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUGLUCON SEMI/5 2.5 (Nicholas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUGLUCON SEMI/5 5 (Nicholas)',
	'Glibenclamide',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUGLUCON SEMI/5 5 (Nicholas)'
);

-- line #15602
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GALCO 5 (Neon)',
	'Glibenclamide',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GALCO 5 (Neon)'
);

-- line #15603
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLCO 5 (Neon)',
	'Glibenclamide',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLCO 5 (Neon)'
);

-- line #15604
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIBET 5 (Cfl Ph.)',
	'Glibenclamide',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIBET 5 (Cfl Ph.)'
);

-- line #15605
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLINIL 5 (Cipla)',
	'Glibenclamide',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLINIL 5 (Cipla)'
);

-- line #15606
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUCONIL 5 (Bal Ph.)',
	'Glibenclamide',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUCONIL 5 (Bal Ph.)'
);

-- line #15607
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUCOSAFE 2.5 (Sun)',
	'Glibenclamide',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUCOSAFE 2.5 (Sun)'
);

-- line #15608
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUCOSAFE 5 (Sun)',
	'Glibenclamide',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUCOSAFE 5 (Sun)'
);

-- line #15609
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUNIL 2.5 (Medopharm)',
	'Glibenclamide',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUNIL 2.5 (Medopharm)'
);

-- line #15610
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUNIL 5 (Medopharm)',
	'Glibenclamide',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUNIL 5 (Medopharm)'
);

-- line #15611
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYBORAL SEMI/5 2.5 (U S V)',
	'Glibenclamide',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYBORAL SEMI/5 2.5 (U S V)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYBORAL SEMI/5 5 (U S V)',
	'Glibenclamide',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYBORAL SEMI/5 5 (U S V)'
);

-- line #15612
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYBOVIN 1.25 (Otsira)',
	'Glibenclamide',
	'TAB',
	gm.nullify_empty_string('1.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYBOVIN 1.25 (Otsira)'
);

-- line #15613
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYBOVIN 2.5 (Otsira)',
	'Glibenclamide',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYBOVIN 2.5 (Otsira)'
);

-- line #15614
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYBOVIN 5 (Otsira)',
	'Glibenclamide',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYBOVIN 5 (Otsira)'
);

-- line #15615
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G-NIL 1.25 (Mano)',
	'Glibenclamide',
	'TAB',
	gm.nullify_empty_string('1.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G-NIL 1.25 (Mano)'
);

-- line #15616
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G-NIL 2.5 (Mano)',
	'Glibenclamide',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G-NIL 2.5 (Mano)'
);

-- line #15617
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G-NIL 5 (Mano)',
	'Glibenclamide',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G-NIL 5 (Mano)'
);

-- line #15618
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZUKON 30 (Torrent)',
	'Gliclazide',
	'MR TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg(MR)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZUKON 30 (Torrent)'
);

-- line #15619
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZUKON 80 (Torrent)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZUKON 80 (Torrent)'
);

-- line #15620
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CGCRON 30 (CMGBT)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CGCRON 30 (CMGBT)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CGCRON 60 (CMGBT)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CGCRON 60 (CMGBT)'
);

-- line #15621
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLAZINDE 80 (Shinto Org.)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLAZINDE 80 (Shinto Org.)'
);

-- line #15622
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLAZIN 80 (Chemo Bio.)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLAZIN 80 (Chemo Bio.)'
);

-- line #15623
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLAZ 30 (Franco I.)',
	'Gliclazide',
	'OD TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLAZ 30 (Franco I.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLAZ 60 (Franco I.)',
	'Gliclazide',
	'OD TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLAZ 60 (Franco I.)'
);

-- line #15624
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COMZID 40 (Comed)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COMZID 40 (Comed)'
);

-- line #15625
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COMZID 80 (Comed)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COMZID 80 (Comed)'
);

-- line #15626
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'D CLIC 40 (GRANDIX)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'D CLIC 40 (GRANDIX)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'D CLIC 80 (GRANDIX)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'D CLIC 80 (GRANDIX)'
);

-- line #15627
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEBIT 80 (Tnt Life)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEBIT 80 (Tnt Life)'
);

-- line #15628
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIABEND 30 (Bal Ph.)',
	'Gliclazide',
	'MR TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIABEND 30 (Bal Ph.)'
);

-- line #15629
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIABEND 60 (Bal Ph.)',
	'Gliclazide',
	'MR TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIABEND 60 (Bal Ph.)'
);

-- line #15630
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIABEND 40 (Bal Ph.)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIABEND 40 (Bal Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIABEND 80 (Bal Ph.)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIABEND 80 (Bal Ph.)'
);

-- line #15631
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIABENT 40 (Bal Ph.)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIABENT 40 (Bal Ph.)'
);

-- line #15632
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIAGLI 40 (ORDAIN HC.)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIAGLI 40 (ORDAIN HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIAGLI 80 (ORDAIN HC.)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIAGLI 80 (ORDAIN HC.)'
);

-- line #15633
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIAMICRON 30 (Serdia)',
	'Gliclazide',
	'MR TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIAMICRON 30 (Serdia)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIAMICRON 60 (Serdia)',
	'Gliclazide',
	'MR TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIAMICRON 60 (Serdia)'
);

-- line #15634
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIAMICRON 80 (Serdia)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIAMICRON 80 (Serdia)'
);

-- line #15635
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIAMICRON 60 (Serdia)',
	'Gliclazide',
	'XR TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIAMICRON 60 (Serdia)'
);

-- line #15636
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIANORM 30 (Carsyon)',
	'Gliclazide',
	'OD TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIANORM 30 (Carsyon)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIANORM 60 (Carsyon)',
	'Gliclazide',
	'OD TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIANORM 60 (Carsyon)'
);

-- line #15637
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIANORM 40 (Carsyon)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIANORM 40 (Carsyon)'
);

-- line #15638
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIANORM 80 (Carsyon)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIANORM 80 (Carsyon)'
);

-- line #15639
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIAOB 80 (GENESIS)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIAOB 80 (GENESIS)'
);

-- line #15640
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIASAFE 80 (Rpg Life)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIASAFE 80 (Rpg Life)'
);

-- line #15641
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIATROL 80 (Argus)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIATROL 80 (Argus)'
);

-- line #15642
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIAZIDE 80 (Inga)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIAZIDE 80 (Inga)'
);

-- line #15643
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIZIDE 80 (Radicura)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIZIDE 80 (Radicura)'
);

-- line #15644
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIZID 80 (Sain Med.)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIZID 80 (Sain Med.)'
);

-- line #15645
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUCLIDE 40 (Alkem)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUCLIDE 40 (Alkem)'
);

-- line #15646
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUCLIDE 80 (Alkem)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUCLIDE 80 (Alkem)'
);

-- line #15647
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORDIB 30 (WISCON)',
	'Gliclazide',
	'MR TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORDIB 30 (WISCON)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORDIB 60 (WISCON)',
	'Gliclazide',
	'MR TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORDIB 60 (WISCON)'
);

-- line #15648
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORDIB 80 (WISCON)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORDIB 80 (WISCON)'
);

-- line #15649
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GILED 40 (Alde Medi.)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GILED 40 (Alde Medi.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GILED 80 (Alde Medi.)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GILED 80 (Alde Medi.)'
);

-- line #15650
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLATIX 40 (Intra(INVISION))',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLATIX 40 (Intra(INVISION))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLATIX 80 (Intra(INVISION))',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLATIX 80 (Intra(INVISION))'
);

-- line #15651
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLICAN 80 (Candor Bio.)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLICAN 80 (Candor Bio.)'
);

-- line #15652
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLICET 80 (Prochem)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLICET 80 (Prochem)'
);

-- line #15653
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLICLAFIN 80 (QCHECK)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLICLAFIN 80 (QCHECK)'
);

-- line #15654
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLICLAN 80 (Fourrts)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLICLAN 80 (Fourrts)'
);

-- line #15655
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLICLA 40 (Mano)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLICLA 40 (Mano)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLICLA 60 (Mano)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLICLA 60 (Mano)'
);

-- line #15656
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLICLA 80 (Mano)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLICLA 80 (Mano)'
);

-- line #15657
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLICLAZ 80 (Khandelwal)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLICLAZ 80 (Khandelwal)'
);

-- line #15658
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLICOL 80 (Olcare)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLICOL 80 (Olcare)'
);

-- line #15659
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLICRON 80 (Cipla)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLICRON 80 (Cipla)'
);

-- line #15660
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIC 40 (EAST WEST)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'80'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIC 40 (EAST WEST)'
);

-- line #15661
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIDIET 80 (Win-Medicare)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIDIET 80 (Win-Medicare)'
);

-- line #15662
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLISAFE 80 (Indu D.)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLISAFE 80 (Indu D.)'
);

-- line #15663
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLITAL 40 (TALENT LAB.)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'80'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLITAL 40 (TALENT LAB.)'
);

-- line #15664
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLITYX 40 (TRITON(CALYX))',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLITYX 40 (TRITON(CALYX))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLITYX 80 (TRITON(CALYX))',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLITYX 80 (TRITON(CALYX))'
);

-- line #15665
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIVA 40 (MOVA PH.)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIVA 40 (MOVA PH.)'
);

-- line #15666
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIVA 80 (MOVA PH.)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIVA 80 (MOVA PH.)'
);

-- line #15667
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIX 30 (Indi Ph.)',
	'Gliclazide',
	'MR TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIX 30 (Indi Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIX 60 (Indi Ph.)',
	'Gliclazide',
	'MR TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIX 60 (Indi Ph.)'
);

-- line #15668
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIX 40 (Indi Ph.)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIX 40 (Indi Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIX 80 (Indi Ph.)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIX 80 (Indi Ph.)'
);

-- line #15669
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIZA 80 (Stadmed)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIZA 80 (Stadmed)'
);

-- line #15670
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIZED 80 (Zota Ph.)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIZED 80 (Zota Ph.)'
);

-- line #15671
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIZID 30 (Panacea)',
	'Gliclazide',
	'MR TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIZID 30 (Panacea)'
);

-- line #15672
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIZID 60 (Panacea)',
	'Gliclazide',
	'MR TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIZID 60 (Panacea)'
);

-- line #15673
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIZID 40 (Panacea)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIZID 40 (Panacea)'
);

-- line #15674
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIZID 80 (Panacea)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIZID 80 (Panacea)'
);

-- line #15675
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUCOACT 40 (Active Hc.)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUCOACT 40 (Active Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUCOACT 80 (Active Hc.)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUCOACT 80 (Active Hc.)'
);

-- line #15676
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUCOFIT 30 (R.B.)',
	'Gliclazide',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg(CR)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUCOFIT 30 (R.B.)'
);

-- line #15677
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUCOFIT 40 (R.B.)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUCOFIT 40 (R.B.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUCOFIT 80 (R.B.)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUCOFIT 80 (R.B.)'
);

-- line #15678
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUCOZID 80 (Medley)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUCOZID 80 (Medley)'
);

-- line #15679
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLURIB 40 (SPPL)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLURIB 40 (SPPL)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLURIB 80 (SPPL)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLURIB 80 (SPPL)'
);

-- line #15680
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUTIDE 40 (Lupin)',
	'Gliclazide',
	'CR CAP',
	gm.nullify_empty_string('40')::numeric,
	'80'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUTIDE 40 (Lupin)'
);

-- line #15681
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUTIDE 30 (Lupin)',
	'Gliclazide',
	'CR TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUTIDE 30 (Lupin)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUTIDE 60 (Lupin)',
	'Gliclazide',
	'CR TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUTIDE 60 (Lupin)'
);

-- line #15682
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYCHEK 30 (Indoco Rem.)',
	'Gliclazide',
	'OD TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg(MR)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYCHEK 30 (Indoco Rem.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYCHEK 60 (Indoco Rem.)',
	'Gliclazide',
	'OD TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg(MR)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYCHEK 60 (Indoco Rem.)'
);

-- line #15683
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYCHEK 40 (Indoco Rem.)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYCHEK 40 (Indoco Rem.)'
);

-- line #15684
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYCHEK 80 (Indoco Rem.)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYCHEK 80 (Indoco Rem.)'
);

-- line #15685
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYCIGON SEMI/80 40 (Aristo)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYCIGON SEMI/80 40 (Aristo)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYCIGON SEMI/80 80 (Aristo)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYCIGON SEMI/80 80 (Aristo)'
);

-- line #15686
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYCINORM 30 (Ipca)',
	'Gliclazide',
	'OD TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYCINORM 30 (Ipca)'
);

-- line #15687
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYCINORM 60 (Ipca)',
	'Gliclazide',
	'OD TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYCINORM 60 (Ipca)'
);

-- line #15688
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYCINORM 40 (Ipca)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYCINORM 40 (Ipca)'
);

-- line #15689
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYCINORM 80 (Ipca)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYCINORM 80 (Ipca)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYCINORM 160 (Ipca)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('160')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYCINORM 160 (Ipca)'
);

-- line #15690
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYCOR 80 (U S V)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYCOR 80 (U S V)'
);

-- line #15691
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'80', u'strength_2': u'', u'substance': u'Gliclazide', u'always_empty': u'', u'form': u'', u'brand': u'GLYCOSEF', u'strength_3': u'', u'company': u'HAMPS BIO', u'unit': u'mg'}

-- line #15692
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYFIX 80 (Saga Lab)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYFIX 80 (Saga Lab)'
);

-- line #15693
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYGARD 80 (Protec)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYGARD 80 (Protec)'
);

-- line #15694
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYKIND 80 (Mankind)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYKIND 80 (Mankind)'
);

-- line #15695
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYLOC 40 (Cadila Ph.)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYLOC 40 (Cadila Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYLOC 80 (Cadila Ph.)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYLOC 80 (Cadila Ph.)'
);

-- line #15696
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYNEED 40 (Reliance)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYNEED 40 (Reliance)'
);

-- line #15697
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYNEED 80 (Reliance)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYNEED 80 (Reliance)'
);

-- line #15698
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYNOL 40 (Marc Lab)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYNOL 40 (Marc Lab)'
);

-- line #15699
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYNOL 80 (Marc Lab)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYNOL 80 (Marc Lab)'
);

-- line #15700
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYRED 41.6 (Novartis)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('41.6')::numeric,
	'mg(+ LAC. & QS)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYRED 41.6 (Novartis)'
);

-- line #15701
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYRED 82 (Novartis)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('82')::numeric,
	'mg(+LAC. & QS)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYRED 82 (Novartis)'
);

-- line #15702
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYRED 40 (NOVARTIS(SANDOZ))',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYRED 40 (NOVARTIS(SANDOZ))'
);

-- line #15703
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYRED 80 (NOVARTIS(SANDOZ))',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYRED 80 (NOVARTIS(SANDOZ))'
);

-- line #15704
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYSISS 30 (AKESISS)',
	'Gliclazide',
	'MR TAB',
	gm.nullify_empty_string('30')::numeric,
	'60'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYSISS 30 (AKESISS)'
);

-- line #15705
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYSUL 40 (Lark Lab)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYSUL 40 (Lark Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYSUL 80 (Lark Lab)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYSUL 80 (Lark Lab)'
);

-- line #15706
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYTAS-80 80 (TASMED)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYTAS-80 80 (TASMED)'
);

-- line #15707
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYZEE 80 (Zee Lab)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYZEE 80 (Zee Lab)'
);

-- line #15708
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLZ 40 (Alembic)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLZ 40 (Alembic)'
);

-- line #15709
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLZ 80 (Alembic)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLZ 80 (Alembic)'
);

-- line #15710
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GUDIET 80 (Modi Mundi)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GUDIET 80 (Modi Mundi)'
);

-- line #15711
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTRAGLY 40 (Intra Lab)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTRAGLY 40 (Intra Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTRAGLY 80 (Intra Lab)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTRAGLY 80 (Intra Lab)'
);

-- line #15712
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JOSIDE 80 (D.R.John''S)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JOSIDE 80 (D.R.John''S)'
);

-- line #15713
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JOZIDE 80 (D.R.John''S)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JOZIDE 80 (D.R.John''S)'
);

-- line #15714
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIZ 40 (Dey''S)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIZ 40 (Dey''S)'
);

-- line #15715
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIZ 80 (Dey''S)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIZ 80 (Dey''S)'
);

-- line #15716
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYCAZID 80 (Jagsonpal)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYCAZID 80 (Jagsonpal)'
);

-- line #15717
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGLYDE 80 (Chemo Bio.)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGLYDE 80 (Chemo Bio.)'
);

-- line #15718
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUZIDE-M 80 (Intas)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUZIDE-M 80 (Intas)'
);

-- line #15719
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUZIDE 40 (Intas)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUZIDE 40 (Intas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUZIDE 80 (Intas)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUZIDE 80 (Intas)'
);

-- line #15720
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUZIDE 30 (Intas)',
	'Gliclazide',
	'XL TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUZIDE 30 (Intas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUZIDE 60 (Intas)',
	'Gliclazide',
	'XL TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUZIDE 60 (Intas)'
);

-- line #15721
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PDGIDE 80 (Pharma Drugs)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PDGIDE 80 (Pharma Drugs)'
);

-- line #15722
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RECLIDE 30 (Dr.Reddy''S)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RECLIDE 30 (Dr.Reddy''S)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RECLIDE 60 (Dr.Reddy''S)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RECLIDE 60 (Dr.Reddy''S)'
);

-- line #15723
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RECLIDE 40 (Dr.Reddy''S)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RECLIDE 40 (Dr.Reddy''S)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RECLIDE 80 (Dr.Reddy''S)',
	'Gliclazide',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RECLIDE 80 (Dr.Reddy''S)'
);

-- line #15724
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADRIDE 1 (GRANDIX)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg (MICRONISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADRIDE 1 (GRANDIX)'
);

-- line #15725
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADRIDE 2 (GRANDIX)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg (MICRONISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADRIDE 2 (GRANDIX)'
);

-- line #15726
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADRIDE 4 (GRANDIX)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg (MICRONISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADRIDE 4 (GRANDIX)'
);

-- line #15727
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMARYL 1 (Sanofi Aventis)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMARYL 1 (Sanofi Aventis)'
);

-- line #15728
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMARYL 2 (Sanofi Aventis)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMARYL 2 (Sanofi Aventis)'
);

-- line #15729
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMARYL 3 (Sanofi Aventis)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMARYL 3 (Sanofi Aventis)'
);

-- line #15730
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASORIDE 1 (AS PHARMA)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASORIDE 1 (AS PHARMA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASORIDE 2 (AS PHARMA)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASORIDE 2 (AS PHARMA)'
);

-- line #15731
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASORIDE 3 (AS PHARMA)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASORIDE 3 (AS PHARMA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASORIDE 4 (AS PHARMA)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASORIDE 4 (AS PHARMA)'
);

-- line #15732
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXYLIM 1 (AXYZEN LIFE)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXYLIM 1 (AXYZEN LIFE)'
);

-- line #15733
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXYLIM 2 (AXYZEN LIFE)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXYLIM 2 (AXYZEN LIFE)'
);

-- line #15734
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZULIX 1 (Torrent)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZULIX 1 (Torrent)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZULIX 2 (Torrent)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZULIX 2 (Torrent)'
);

-- line #15735
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZULIX 3 (Torrent)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZULIX 3 (Torrent)'
);

-- line #15736
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZULIX 4 (Torrent)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZULIX 4 (Torrent)'
);

-- line #15737
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETAGLIM 1 (Panacea)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETAGLIM 1 (Panacea)'
);

-- line #15738
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETAGLIM 2 (Panacea)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETAGLIM 2 (Panacea)'
);

-- line #15739
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETAGLIM 3 (Panacea)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETAGLIM 3 (Panacea)'
);

-- line #15740
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETAGLIM 4 (Panacea)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETAGLIM 4 (Panacea)'
);

-- line #15741
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLISTO 1 (Biocon)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLISTO 1 (Biocon)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLISTO 2 (Biocon)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLISTO 2 (Biocon)'
);

-- line #15742
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLISTO 4 (Biocon)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLISTO 4 (Biocon)'
);

-- line #15743
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLISTO 4 (BIOCON LTD.)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLISTO 4 (BIOCON LTD.)'
);

-- line #15744
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAPRIL 1 (Captab)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAPRIL 1 (Captab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAPRIL 2 (Captab)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAPRIL 2 (Captab)'
);

-- line #15745
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CGRYL 1 (CMGBT)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CGRYL 1 (CMGBT)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CGRYL 2 (CMGBT)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CGRYL 2 (CMGBT)'
);

-- line #15746
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHEMPRIDE 1 (Chemech)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHEMPRIDE 1 (Chemech)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHEMPRIDE 2 (Chemech)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHEMPRIDE 2 (Chemech)'
);

-- line #15747
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONPRIDE 1 (CONCERTINA)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONPRIDE 1 (CONCERTINA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONPRIDE 2 (CONCERTINA)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONPRIDE 2 (CONCERTINA)'
);

-- line #15748
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAORIDE 1 (AZINE HC.)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAORIDE 1 (AZINE HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAORIDE 2 (AZINE HC.)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAORIDE 2 (AZINE HC.)'
);

-- line #15749
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAORYL 1 (J. B. Chem.)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAORYL 1 (J. B. Chem.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAORYL 2 (J. B. Chem.)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAORYL 2 (J. B. Chem.)'
);

-- line #15750
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIAGLIM 1 (Biochem)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIAGLIM 1 (Biochem)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIAGLIM 2 (Biochem)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIAGLIM 2 (Biochem)'
);

-- line #15751
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIAPRIDE 1 (Micro Labs)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIAPRIDE 1 (Micro Labs)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIAPRIDE 2 (Micro Labs)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIAPRIDE 2 (Micro Labs)'
);

-- line #15752
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIAPRIDE 4 (Micro Labs)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIAPRIDE 4 (Micro Labs)'
);

-- line #15753
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIASWICH 1 (Jagsonpal)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIASWICH 1 (Jagsonpal)'
);

-- line #15754
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIASWICH 2 (Jagsonpal)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIASWICH 2 (Jagsonpal)'
);

-- line #15755
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIBIGLIM 1 (Novartis)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIBIGLIM 1 (Novartis)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIBIGLIM 2 (Novartis)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIBIGLIM 2 (Novartis)'
);

-- line #15756
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIBIGLIM 15 (NOVARTIS(SANDOZ))',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIBIGLIM 15 (NOVARTIS(SANDOZ))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIBIGLIM 30 (NOVARTIS(SANDOZ))',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIBIGLIM 30 (NOVARTIS(SANDOZ))'
);

-- line #15757
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIPRIDE 2 (DAKSH)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIPRIDE 2 (DAKSH)'
);

-- line #15758
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMPERIDE 1 (Emcure)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMPERIDE 1 (Emcure)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMPERIDE 2 (Emcure)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMPERIDE 2 (Emcure)'
);

-- line #15759
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUGLIM 1 (Zydus Cadila)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUGLIM 1 (Zydus Cadila)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUGLIM 2 (Zydus Cadila)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUGLIM 2 (Zydus Cadila)'
);

-- line #15760
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUGLIM 4 (Zydus Cadila)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUGLIM 4 (Zydus Cadila)'
);

-- line #15761
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLEXIGLIM 0.5 (Unichem)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLEXIGLIM 0.5 (Unichem)'
);

-- line #15762
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLEXIGLIM 1 (Unichem)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLEXIGLIM 1 (Unichem)'
);

-- line #15763
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLEXIGLIM 2 (Unichem)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLEXIGLIM 2 (Unichem)'
);

-- line #15764
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLEXIGLIM 3 (Unichem)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLEXIGLIM 3 (Unichem)'
);

-- line #15765
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLEXIGLIM 4 (Unichem)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLEXIGLIM 4 (Unichem)'
);

-- line #15766
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GADZ 1 (AAMORB(XEENA))',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GADZ 1 (AAMORB(XEENA))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GADZ 2 (AAMORB(XEENA))',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GADZ 2 (AAMORB(XEENA))'
);

-- line #15767
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEMINOR 1 (Macleods)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEMINOR 1 (Macleods)'
);

-- line #15768
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEMINOR 2 (Macleods)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEMINOR 2 (Macleods)'
);

-- line #15769
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEPRIDE 1 (Medley)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEPRIDE 1 (Medley)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEPRIDE 2 (Medley)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEPRIDE 2 (Medley)'
);

-- line #15770
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEPRIDE 1 (Medley)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEPRIDE 1 (Medley)'
);

-- line #15771
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEPRIDE 2 (Medley)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEPRIDE 2 (Medley)'
);

-- line #15772
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEPRIDE 3 (Medley)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEPRIDE 3 (Medley)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEPRIDE 4 (Medley)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEPRIDE 4 (Medley)'
);

-- line #15773
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GITAE 1 (D.R.John''S)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GITAE 1 (D.R.John''S)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GITAE 2 (D.R.John''S)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GITAE 2 (D.R.John''S)'
);

-- line #15774
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GIVOV 1 (Zee Lab)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GIVOV 1 (Zee Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GIVOV 2 (Zee Lab)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GIVOV 2 (Zee Lab)'
);

-- line #15775
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLADOR 1 (Lupin)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLADOR 1 (Lupin)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLADOR 2 (Lupin)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLADOR 2 (Lupin)'
);

-- line #15776
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLADOR 3 (Lupin)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLADOR 3 (Lupin)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLADOR 4 (Lupin)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLADOR 4 (Lupin)'
);

-- line #15777
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLAMOR 1 (Intra(INVISION))',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLAMOR 1 (Intra(INVISION))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLAMOR 2 (Intra(INVISION))',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLAMOR 2 (Intra(INVISION))'
);

-- line #15778
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLEAM 1 (Franco I.)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLEAM 1 (Franco I.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLEAM 2 (Franco I.)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLEAM 2 (Franco I.)'
);

-- line #15779
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Glimepiride', u'always_empty': u'', u'form': u'', u'brand': u'GLEMEFINE', u'strength_3': u'', u'company': u'NEO CC.', u'unit': u''}

-- line #15780
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIFIX 1 (Argus)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIFIX 1 (Argus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIFIX 2 (Argus)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIFIX 2 (Argus)'
);

-- line #15781
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIM-1 1 (WEST COAST)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIM-1 1 (WEST COAST)'
);

-- line #15782
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIM-2 2 (WEST COAST)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIM-2 2 (WEST COAST)'
);

-- line #15783
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMCARE 1 (QCHECK)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMCARE 1 (QCHECK)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMCARE 2 (QCHECK)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMCARE 2 (QCHECK)'
);

-- line #15784
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMCHEK 1 (Khandelwal)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMCHEK 1 (Khandelwal)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMCHEK 2 (Khandelwal)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMCHEK 2 (Khandelwal)'
);

-- line #15785
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMCIP 1 (Cipla)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMCIP 1 (Cipla)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMCIP 2 (Cipla)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMCIP 2 (Cipla)'
);

-- line #15786
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMCOM 1 (Comed)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMCOM 1 (Comed)'
);

-- line #15787
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMCOM 2 (Comed)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMCOM 2 (Comed)'
);

-- line #15788
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMER 1 (Nicholas)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMER 1 (Nicholas)'
);

-- line #15789
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMER 2 (Nicholas)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMER 2 (Nicholas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMER 3 (Nicholas)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMER 3 (Nicholas)'
);

-- line #15790
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMESTAR-3 3 (Mankind)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMESTAR-3 3 (Mankind)'
);

-- line #15791
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMESTAR-4 4 (Mankind)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMESTAR-4 4 (Mankind)'
);

-- line #15792
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMESTAR 1 (Mankind)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMESTAR 1 (Mankind)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMESTAR 2 (Mankind)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMESTAR 2 (Mankind)'
);

-- line #15793
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMETOP 1 (Rpg Life)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMETOP 1 (Rpg Life)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMETOP 2 (Rpg Life)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMETOP 2 (Rpg Life)'
);

-- line #15794
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMFIRST 1 (SINSAN PH.)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMFIRST 1 (SINSAN PH.)'
);

-- line #15795
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMFIRST 2 (SINSAN PH.)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMFIRST 2 (SINSAN PH.)'
);

-- line #15796
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMFIRST 3 (SINSAN PH.)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMFIRST 3 (SINSAN PH.)'
);

-- line #15797
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMFIRST 4 (SINSAN PH.)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMFIRST 4 (SINSAN PH.)'
);

-- line #15798
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMICURE 1 (HBC LIFESCIENCE)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMICURE 1 (HBC LIFESCIENCE)'
);

-- line #15799
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMICURE 2 (HBC LIFESCIENCE)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMICURE 2 (HBC LIFESCIENCE)'
);

-- line #15800
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMIDOT 1 (TRITON(CALYX))',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMIDOT 1 (TRITON(CALYX))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMIDOT 2 (TRITON(CALYX))',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMIDOT 2 (TRITON(CALYX))'
);

-- line #15801
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMID 1 (ANTHUS)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMID 1 (ANTHUS)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMID 2 (ANTHUS)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMID 2 (ANTHUS)'
);

-- line #15802
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMID 4 (ANTHUS)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMID 4 (ANTHUS)'
);

-- line #15803
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMIFIX 1 (AKESISS)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMIFIX 1 (AKESISS)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMIFIX 2 (AKESISS)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMIFIX 2 (AKESISS)'
);

-- line #15804
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMIPREX 1 (Otsira)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMIPREX 1 (Otsira)'
);

-- line #15805
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMIPREX 2 (Otsira)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMIPREX 2 (Otsira)'
);

-- line #15806
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMIPREX 4 (Otsira)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMIPREX 4 (Otsira)'
);

-- line #15807
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1', u'strength_2': u'', u'substance': u'Glimepiride', u'always_empty': u'', u'form': u'', u'brand': u'GLIMIPULSE-1', u'strength_3': u'', u'company': u'HAMPS BIO', u'unit': u'mg'}

-- line #15808
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMISAVE 1 (ERIS LIFE)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMISAVE 1 (ERIS LIFE)'
);

-- line #15809
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMISAVE 2 (ERIS LIFE)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMISAVE 2 (ERIS LIFE)'
);

-- line #15810
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMISAVE 4 (ERIS LIFE)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMISAVE 4 (ERIS LIFE)'
);

-- line #15811
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMITAB 1 (Centaur)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMITAB 1 (Centaur)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMITAB 2 (Centaur)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMITAB 2 (Centaur)'
);

-- line #15812
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMKAP-4 4 (Kapl)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMKAP-4 4 (Kapl)'
);

-- line #15813
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMKAP 1 (Kapl)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMKAP 1 (Kapl)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMKAP 2 (Kapl)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMKAP 2 (Kapl)'
);

-- line #15814
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMPID 1 (Ranbaxy Cv)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMPID 1 (Ranbaxy Cv)'
);

-- line #15815
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMPID 2 (Ranbaxy Cv)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMPID 2 (Ranbaxy Cv)'
);

-- line #15816
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMPID 4 (Ranbaxy Cv)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMPID 4 (Ranbaxy Cv)'
);

-- line #15817
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMPIL 1 (Pil)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMPIL 1 (Pil)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMPIL 2 (Pil)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMPIL 2 (Pil)'
);

-- line #15818
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMSER 1 (Alembic)',
	'Glimepiride',
	'CAP',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMSER 1 (Alembic)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMSER 2 (Alembic)',
	'Glimepiride',
	'CAP',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMSER 2 (Alembic)'
);

-- line #15819
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMSITE 1 (AVENTIS PH.)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMSITE 1 (AVENTIS PH.)'
);

-- line #15820
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMSITE 2 (AVENTIS PH.)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMSITE 2 (AVENTIS PH.)'
);

-- line #15821
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMTES 1 (MOVA PH.)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMTES 1 (MOVA PH.)'
);

-- line #15822
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMTES 2 (MOVA PH.)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMTES 2 (MOVA PH.)'
);

-- line #15823
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMTIDE 1 (Mano)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMTIDE 1 (Mano)'
);

-- line #15824
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMTIDE 2 (Mano)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMTIDE 2 (Mano)'
);

-- line #15825
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMTIDE 4 (Mano)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMTIDE 4 (Mano)'
);

-- line #15826
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMULIN 1 (Healtheon)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMULIN 1 (Healtheon)'
);

-- line #15827
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMULIN 2 (Healtheon)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMULIN 2 (Healtheon)'
);

-- line #15828
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMULIN 3 (Healtheon)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMULIN 3 (Healtheon)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMULIN 4 (Healtheon)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMULIN 4 (Healtheon)'
);

-- line #15829
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMY 1 (Dr.Reddy''S)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMY 1 (Dr.Reddy''S)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMY 2 (Dr.Reddy''S)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMY 2 (Dr.Reddy''S)'
);

-- line #15830
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMY 3 (Dr.Reddy''S)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMY 3 (Dr.Reddy''S)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMY 4 (Dr.Reddy''S)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMY 4 (Dr.Reddy''S)'
);

-- line #15831
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMZ 1 (Wallace)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMZ 1 (Wallace)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIMZ 2 (Wallace)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIMZ 2 (Wallace)'
);

-- line #15832
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLINIDD 1 (Evacare)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLINIDD 1 (Evacare)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLINIDD 2 (Evacare)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLINIDD 2 (Evacare)'
);

-- line #15833
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLINORM 1 (TALENT LAB.)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLINORM 1 (TALENT LAB.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLINORM 2 (TALENT LAB.)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLINORM 2 (TALENT LAB.)'
);

-- line #15834
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLISEN-3 3 (Alembic)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLISEN-3 3 (Alembic)'
);

-- line #15835
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLISEN-4 4 (Alembic)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLISEN-4 4 (Alembic)'
);

-- line #15836
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLISTA 1 (CADILA)',
	'Glimepiride',
	'OD TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLISTA 1 (CADILA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLISTA 2 (CADILA)',
	'Glimepiride',
	'OD TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLISTA 2 (CADILA)'
);

-- line #15837
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLI 1 (Ordain Hc.)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLI 1 (Ordain Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLI 2 (Ordain Hc.)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLI 2 (Ordain Hc.)'
);

-- line #15838
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLITZ-1 1 (BEATZ LIFESCI.)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLITZ-1 1 (BEATZ LIFESCI.)'
);

-- line #15839
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLP 1 (Intra Lab)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLP 1 (Intra Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLP 2 (Intra Lab)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLP 2 (Intra Lab)'
);

-- line #15840
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUCODEX 2 (Mdc Ph.)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUCODEX 2 (Mdc Ph.)'
);

-- line #15841
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUCORYL 1 (Alkem)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUCORYL 1 (Alkem)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUCORYL 2 (Alkem)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUCORYL 2 (Alkem)'
);

-- line #15842
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUCUT 1 (Overseas Hc.)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUCUT 1 (Overseas Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUCUT 2 (Overseas Hc.)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUCUT 2 (Overseas Hc.)'
);

-- line #15843
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUCUT 3 (Overseas Hc.)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUCUT 3 (Overseas Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUCUT 4 (Overseas Hc.)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUCUT 4 (Overseas Hc.)'
);

-- line #15844
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYCIRID 1 (Indi Ph.)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYCIRID 1 (Indi Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYCIRID 2 (Indi Ph.)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYCIRID 2 (Indi Ph.)'
);

-- line #15845
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYFIX 1 (Argus)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYFIX 1 (Argus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYFIX 2 (Argus)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYFIX 2 (Argus)'
);

-- line #15846
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1', u'strength_2': u'', u'substance': u'Glimepiride', u'always_empty': u'', u'form': u'', u'brand': u'GLYMERLY', u'strength_3': u'', u'company': u'INNOVA LIFESCI.', u'unit': u'mg'}

-- line #15847
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2', u'strength_2': u'', u'substance': u'Glimepiride', u'always_empty': u'', u'form': u'', u'brand': u'GLYMERLY', u'strength_3': u'', u'company': u'INNOVA LIFESCI.', u'unit': u'mg'}

-- line #15848
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYPAR 1 (Ind-Swift)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYPAR 1 (Ind-Swift)'
);

-- line #15849
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYPAR 2 (Ind-Swift)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYPAR 2 (Ind-Swift)'
);

-- line #15850
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYPRIDE 1 (Sun)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYPRIDE 1 (Sun)'
);

-- line #15851
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYPRIDE 2 (Sun)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYPRIDE 2 (Sun)'
);

-- line #15852
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYPRIDE 4 (Sun)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYPRIDE 4 (Sun)'
);

-- line #15853
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GMR 1 (SIGNOVA)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GMR 1 (SIGNOVA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GMR 2 (SIGNOVA)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GMR 2 (SIGNOVA)'
);

-- line #15854
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GP 1 (U S V)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GP 1 (U S V)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GP 2 (U S V)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GP 2 (U S V)'
);

-- line #15855
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRIDE 1 (EAST WEST)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRIDE 1 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRIDE 2 (EAST WEST)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRIDE 2 (EAST WEST)'
);

-- line #15856
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRIDE 3 (EAST WEST)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRIDE 3 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRIDE 4 (EAST WEST)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRIDE 4 (EAST WEST)'
);

-- line #15857
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ILET 1 (SAFE MED(MSN))',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ILET 1 (SAFE MED(MSN))'
);

-- line #15858
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ILET 2 (SAFE MED(MSN))',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ILET 2 (SAFE MED(MSN))'
);

-- line #15859
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMEDIAB 1 (Pfizer)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMEDIAB 1 (Pfizer)'
);

-- line #15860
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMEDIAB 2 (Pfizer)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMEDIAB 2 (Pfizer)'
);

-- line #15861
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISRYL 1 (Systopic)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISRYL 1 (Systopic)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISRYL 2 (Systopic)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISRYL 2 (Systopic)'
);

-- line #15862
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KARMELITUS 1 (Cadila Ph.)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KARMELITUS 1 (Cadila Ph.)'
);

-- line #15863
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KARMELITUS 2 (Cadila Ph.)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KARMELITUS 2 (Cadila Ph.)'
);

-- line #15864
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'K-GLIM 1 (Blue Cross)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'K-GLIM 1 (Blue Cross)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'K-GLIM 2 (Blue Cross)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'K-GLIM 2 (Blue Cross)'
);

-- line #15865
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LERIDE 1 (TABLETS I.)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LERIDE 1 (TABLETS I.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LERIDE 2 (TABLETS I.)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LERIDE 2 (TABLETS I.)'
);

-- line #15866
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIMER 1 (SHINE PH.)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIMER 1 (SHINE PH.)'
);

-- line #15867
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEPUSULIN 1 (NEISS)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEPUSULIN 1 (NEISS)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEPUSULIN 2 (NEISS)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEPUSULIN 2 (NEISS)'
);

-- line #15868
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYPRIDE 2 (Meridian)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYPRIDE 2 (Meridian)'
);

-- line #15869
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NABAL 1 (Win-Medicare)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NABAL 1 (Win-Medicare)'
);

-- line #15870
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NABAL 2 (Win-Medicare)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NABAL 2 (Win-Medicare)'
);

-- line #15871
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORMALGLICE-1 1 (BIENSTAR)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORMALGLICE-1 1 (BIENSTAR)'
);

-- line #15872
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORMALGLICE-2 2 (BIENSTAR)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORMALGLICE-2 2 (BIENSTAR)'
);

-- line #15873
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVARIDE 1 (Radicura)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVARIDE 1 (Radicura)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVARIDE 2 (Radicura)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVARIDE 2 (Radicura)'
);

-- line #15874
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVARIDE 3 (Radicura)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVARIDE 3 (Radicura)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVARIDE 4 (Radicura)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVARIDE 4 (Radicura)'
);

-- line #15875
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODIGLIM 1 (ZINNIA)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODIGLIM 1 (ZINNIA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODIGLIM 2 (ZINNIA)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODIGLIM 2 (ZINNIA)'
);

-- line #15876
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OZOPRIDE 1 (Ozone Sp.)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OZOPRIDE 1 (Ozone Sp.)'
);

-- line #15877
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OZOPRIDE 2 (Ozone Sp.)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OZOPRIDE 2 (Ozone Sp.)'
);

-- line #15878
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRICHEK 1 (Indoco Rem.)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRICHEK 1 (Indoco Rem.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRICHEK 2 (Indoco Rem.)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRICHEK 2 (Indoco Rem.)'
);

-- line #15879
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRICHEK 4 (Indoco Rem.)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRICHEK 4 (Indoco Rem.)'
);

-- line #15880
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIDES 1 (Kopran)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIDES 1 (Kopran)'
);

-- line #15881
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIDES 2 (Kopran)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIDES 2 (Kopran)'
);

-- line #15882
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIDES 4 (Kopran)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIDES 4 (Kopran)'
);

-- line #15883
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRYMIA 1 (Chemo Bio.)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRYMIA 1 (Chemo Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRYMIA 2 (Chemo Bio.)',
	'Glimepiride',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRYMIA 2 (Chemo Bio.)'
);

-- line #15884
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BI-MIOTIC 10 (Nucron Ph.)',
	'Glipizide',
	'DPS',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BI-MIOTIC 10 (Nucron Ph.)'
);

-- line #15885
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIMODE 5 (Nucron Ph.)',
	'Glipizide',
	'SR TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIMODE 5 (Nucron Ph.)'
);

-- line #15886
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'D-GLIP 2.5 (GRANDIX)',
	'Glipizide',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'D-GLIP 2.5 (GRANDIX)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'D-GLIP 5 (GRANDIX)',
	'Glipizide',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'D-GLIP 5 (GRANDIX)'
);

-- line #15887
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIACON 5 (Bal Ph.)',
	'Glipizide',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIACON 5 (Bal Ph.)'
);

-- line #15888
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIAGLIP 5 (Cipla)',
	'Glipizide',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIAGLIP 5 (Cipla)'
);

-- line #15889
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIBIZIDE 5 (Micro Labs)',
	'Glipizide',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'10'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIBIZIDE 5 (Micro Labs)'
);

-- line #15890
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EFGY 5 (Biocin Hc.)',
	'Glipizide',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EFGY 5 (Biocin Hc.)'
);

-- line #15891
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EGLY 5 (Cadex Lab)',
	'Glipizide',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EGLY 5 (Cadex Lab)'
);

-- line #15892
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLEZ-10 10 (Genetica)',
	'Glipizide',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLEZ-10 10 (Genetica)'
);

-- line #15893
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLEZ-25 2.5 (Genetica)',
	'Glipizide',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLEZ-25 2.5 (Genetica)'
);

-- line #15894
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLEZ-5 5 (Genetica)',
	'Glipizide',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLEZ-5 5 (Genetica)'
);

-- line #15895
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLEZ-75 7.5 (Genetica)',
	'Glipizide',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLEZ-75 7.5 (Genetica)'
);

-- line #15896
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIBETIC 5 (LA DRUG)',
	'Glipizide',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIBETIC 5 (LA DRUG)'
);

-- line #15897
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIBETIC 5 (LA PHARMA)',
	'Glipizide',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIBETIC 5 (LA PHARMA)'
);

-- line #15898
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIDE 5 (Franco I.)',
	'Glipizide',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIDE 5 (Franco I.)'
);

-- line #15899
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIPICONTIN 10 (Modi Mundi)',
	'Glipizide',
	'CR TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIPICONTIN 10 (Modi Mundi)'
);

-- line #15900
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIPICONTIN 5 (Modi Mundi)',
	'Glipizide',
	'CR TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIPICONTIN 5 (Modi Mundi)'
);

-- line #15901
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIPIXOR 5 (Rpg Life)',
	'Glipizide',
	'SR TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIPIXOR 5 (Rpg Life)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIPIXOR 10 (Rpg Life)',
	'Glipizide',
	'SR TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIPIXOR 10 (Rpg Life)'
);

-- line #15902
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIPIZED 5 (Zota Ph.)',
	'Glipizide',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIPIZED 5 (Zota Ph.)'
);

-- line #15903
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIP 2.5 (EAST WEST)',
	'Glipizide',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIP 2.5 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIP 5 (EAST WEST)',
	'Glipizide',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIP 5 (EAST WEST)'
);

-- line #15904
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIP 5 (Sain Med.)',
	'Glipizide',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'10'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIP 5 (Sain Med.)'
);

-- line #15905
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIPY-5 5 (Alembic)',
	'Glipizide',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIPY-5 5 (Alembic)'
);

-- line #15906
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUCOLIP 5 (Wallace)',
	'Glipizide',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUCOLIP 5 (Wallace)'
);

-- line #15907
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUCONIL 5 (Mark)',
	'Glipizide',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUCONIL 5 (Mark)'
);

-- line #15908
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUCOTROL 5 (Jenburkt)',
	'Glipizide',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUCOTROL 5 (Jenburkt)'
);

-- line #15909
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYCIND 5 (Indu D.)',
	'Glipizide',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYCIND 5 (Indu D.)'
);

-- line #15910
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYDAL 5 (Dallas Ph.)',
	'Glipizide',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYDAL 5 (Dallas Ph.)'
);

-- line #15911
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYLIN 5 (Lincoln)',
	'Glipizide',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYLIN 5 (Lincoln)'
);

-- line #15912
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYNASE (SEMI) 2.5 (U S V)',
	'Glipizide',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYNASE (SEMI) 2.5 (U S V)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYNASE (SEMI) 5 (U S V)',
	'Glipizide',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYNASE (SEMI) 5 (U S V)'
);

-- line #15913
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYNASE 10 (U S V)',
	'Glipizide',
	'XL TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYNASE 10 (U S V)'
);

-- line #15914
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYNASE 5 (U S V)',
	'Glipizide',
	'XL TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYNASE 5 (U S V)'
);

-- line #15915
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYSIN 2.5 (Marc Lab)',
	'Glipizide',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYSIN 2.5 (Marc Lab)'
);

-- line #15916
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYSIN 5 (Marc Lab)',
	'Glipizide',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYSIN 5 (Marc Lab)'
);

-- line #15917
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYSON 5 (Unison)',
	'Glipizide',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYSON 5 (Unison)'
);

-- line #15918
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYTOP 10 (Rpg Life)',
	'Glipizide',
	'SR TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYTOP 10 (Rpg Life)'
);

-- line #15919
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYTOP 2.5 (Rpg Life)',
	'Glipizide',
	'SR TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYTOP 2.5 (Rpg Life)'
);

-- line #15920
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYTOP 5 (Rpg Life)',
	'Glipizide',
	'SR TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYTOP 5 (Rpg Life)'
);

-- line #15921
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYZIP 5 (Stadmed)',
	'Glipizide',
	'CR TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYZIP 5 (Stadmed)'
);

-- line #15922
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYZIP 2.5 (Stadmed)',
	'Glipizide',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYZIP 2.5 (Stadmed)'
);

-- line #15923
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYZIP 5 (Stadmed)',
	'Glipizide',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYZIP 5 (Stadmed)'
);

-- line #15924
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GODDE 5 (Zee Lab)',
	'Glipizide',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GODDE 5 (Zee Lab)'
);

-- line #15925
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GPZIDE 5 (Ronak Lab.)',
	'Glipizide',
	'TAB`',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GPZIDE 5 (Ronak Lab.)'
);

-- line #15926
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GTROL 10 (Mano)',
	'Glipizide',
	'SR TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GTROL 10 (Mano)'
);

-- line #15927
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GTROL 5 (Mano)',
	'Glipizide',
	'SR TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GTROL 5 (Mano)'
);

-- line #15928
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G-TROL 10 (Orchid Hc.)',
	'Glipizide',
	'SR TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G-TROL 10 (Orchid Hc.)'
);

-- line #15929
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GTROL 10 (Mano)',
	'Glipizide',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GTROL 10 (Mano)'
);

-- line #15930
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GTROL 2.5 (Mano)',
	'Glipizide',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GTROL 2.5 (Mano)'
);

-- line #15931
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GTROL 5 (Mano)',
	'Glipizide',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GTROL 5 (Mano)'
);

-- line #15932
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GTROL 7.5 (Mano)',
	'Glipizide',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GTROL 7.5 (Mano)'
);

-- line #15933
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G-TROL 2.5 (Orchid Hc.)',
	'Glipizide',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G-TROL 2.5 (Orchid Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G-TROL 5 (Orchid Hc.)',
	'Glipizide',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G-TROL 5 (Orchid Hc.)'
);

-- line #15934
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIBIZ 5 (Baroque)',
	'Glipizide',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIBIZ 5 (Baroque)'
);

-- line #15935
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPI 2.5 (Dey''S)',
	'Glipizide',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPI 2.5 (Dey''S)'
);

-- line #15936
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPI 5 (Dey''S)',
	'Glipizide',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPI 5 (Dey''S)'
);

-- line #15937
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'M-DIAB 2.5 (Dominion)',
	'Glipizide',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'M-DIAB 2.5 (Dominion)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'M-DIAB 5 (Dominion)',
	'Glipizide',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'M-DIAB 5 (Dominion)'
);

-- line #15938
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'GLOBULINE COUPLED WITH HISTAMINE DIHYDROCHLORIDE', u'always_empty': u'', u'form': u'INJ', u'brand': u'HISTAGLOB', u'strength_3': u'', u'company': u'Bharat S.', u'unit': u''}

-- line #15939
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1', u'strength_2': u'', u'substance': u'Glucagon', u'always_empty': u'', u'form': u'', u'brand': u'GLUCAGEN HYPOKIT', u'strength_3': u'', u'company': u'Novo Nordisk', u'unit': u'mg/ML'}

-- line #15940
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUCAGON 1 (Abbott)',
	'Glucagon',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUCAGON 1 (Abbott)'
);

-- line #15941
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUCAGON 1 (Torrent)',
	'Glucagon',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML(HCL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUCAGON 1 (Torrent)'
);

-- line #15942
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIETMANN 500 (Zydus Med.)',
	'Glucomannan',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIETMANN 500 (Zydus Med.)'
);

-- line #15943
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.2G', u'strength_2': u'', u'substance': u'Glucomannan', u'always_empty': u'', u'form': u'', u'brand': u'DIETMANN FLAPOWDER', u'strength_3': u'', u'company': u'Cadila Hc.', u'unit': u''}

-- line #15944
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.2G', u'strength_2': u'', u'substance': u'Glucomannan', u'always_empty': u'', u'form': u'SAC', u'brand': u'DIETMANN', u'strength_3': u'', u'company': u'Zydus Med.', u'unit': u''}

-- line #15945
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REOSTIN 1500 (MEDREICH SAI.)',
	'GLUCOSAMINE',
	'TAB',
	gm.nullify_empty_string('1500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REOSTIN 1500 (MEDREICH SAI.)'
);

-- line #15946
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REOSTIN 750 (MEDREICH SAI.)',
	'GLUCOSAMINE',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REOSTIN 750 (MEDREICH SAI.)'
);

-- line #15947
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARTICA 750 (Ind-Swift)',
	'Glucosamine Sulph.',
	'CAP',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARTICA 750 (Ind-Swift)'
);

-- line #15948
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARTIEL 500 (Obsurge)',
	'Glucosamine Sulph.',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARTIEL 500 (Obsurge)'
);

-- line #15949
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARTIGEN-1 1500 (Pharmed)',
	'Glucosamine Sulph.',
	'SAC',
	gm.nullify_empty_string('1500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARTIGEN-1 1500 (Pharmed)'
);

-- line #15950
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARTIGEN 500 (Pharmed)',
	'Glucosamine Sulph.',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARTIGEN 500 (Pharmed)'
);

-- line #15951
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARTIGEN 500 (Pharmed)',
	'Glucosamine Sulph.',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARTIGEN 500 (Pharmed)'
);

-- line #15952
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'#NAME?', u'strength_2': u'', u'substance': u'Glucosamine Sulph.', u'always_empty': u'', u'form': u'SR TAB', u'brand': u'CARTILAMINE', u'strength_3': u'', u'company': u'Troikaa', u'unit': u''}

-- line #15953
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARTILAMINE 500 (Troikaa)',
	'Glucosamine Sulph.',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARTILAMINE 500 (Troikaa)'
);

-- line #15954
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLEXTRA 1500 (Elder)',
	'Glucosamine Sulph.',
	'SAC',
	gm.nullify_empty_string('1500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLEXTRA 1500 (Elder)'
);

-- line #15955
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLEXTRA 500 (Elder)',
	'Glucosamine Sulph.',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLEXTRA 500 (Elder)'
);

-- line #15956
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUCART 500 (Jagdale)',
	'Glucosamine Sulph.',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUCART 500 (Jagdale)'
);

-- line #15957
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUCOSAM 500 (EAST WEST)',
	'Glucosamine Sulph.',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUCOSAM 500 (EAST WEST)'
);

-- line #15958
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUSAMIN 500 (Sterkem Ph.)',
	'Glucosamine Sulph.',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUSAMIN 500 (Sterkem Ph.)'
);

-- line #15959
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Glucosamine Sulph.', u'always_empty': u'', u'form': u'CAP', u'brand': u'GVC', u'strength_3': u'', u'company': u'Fem care', u'unit': u''}

-- line #15960
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JOINTACE 1500 (Meyer Org.)',
	'Glucosamine Sulph.',
	'OD TAB',
	gm.nullify_empty_string('1500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JOINTACE 1500 (Meyer Org.)'
);

-- line #15961
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JOINTS DIET 500 (Stanford)',
	'Glucosamine Sulph.',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JOINTS DIET 500 (Stanford)'
);

-- line #15962
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIGAFEM 500 (Fem care)',
	'Glucosamine Sulph.',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIGAFEM 500 (Fem care)'
);

-- line #15963
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUBRIJOINT 1500 (Wallace)',
	'Glucosamine Sulph.',
	'OD TAB',
	gm.nullify_empty_string('1500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUBRIJOINT 1500 (Wallace)'
);

-- line #15964
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUBRIJOINT 500 (Wallace)',
	'Glucosamine Sulph.',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUBRIJOINT 500 (Wallace)'
);

-- line #15965
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUBRIJOINT 750 (Wallace)',
	'Glucosamine Sulph.',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUBRIJOINT 750 (Wallace)'
);

-- line #15966
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORTHOACE 500 (Guj. Liq.)',
	'Glucosamine Sulph.',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg(POT CHL.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORTHOACE 500 (Guj. Liq.)'
);

-- line #15967
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSICARE 1000 (Systopic)',
	'Glucosamine Sulph.',
	'DS TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSICARE 1000 (Systopic)'
);

-- line #15968
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RE CART 750 (Cachet)',
	'Glucosamine Sulph.',
	'CAP',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RE CART 750 (Cachet)'
);

-- line #15969
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Glucosamine Sulph.', u'always_empty': u'', u'form': u'SUS', u'brand': u'RE CART PLUS', u'strength_3': u'', u'company': u'Cachet', u'unit': u''}

-- line #15970
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Glucosamine Sulph.', u'always_empty': u'', u'form': u'TAB', u'brand': u'RECART PLUS', u'strength_3': u'', u'company': u'Cachet', u'unit': u''}

-- line #15971
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RECART 750 (Cachet)',
	'Glucosamine Sulph.',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RECART 750 (Cachet)'
);

-- line #15972
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIDEX-7 2 (J.&J.)',
	'Glutaraldehyde',
	'SOL',
	gm.nullify_empty_string('2')::numeric,
	'%W/V(ALKALINE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIDEX-7 2 (J.&J.)'
);

-- line #15973
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIDEX -L 2 (J.&J.)',
	'Glutaraldehyde',
	'SOL',
	gm.nullify_empty_string('2')::numeric,
	'%W/V(ALKALINE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIDEX -L 2 (J.&J.)'
);

-- line #15974
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIDEX-L 2 (J.&J.)',
	'Glutaraldehyde',
	'SOL',
	gm.nullify_empty_string('2')::numeric,
	'%W/V(ALKALINE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIDEX-L 2 (J.&J.)'
);

-- line #15975
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUTIHYDE 2.45 (Nicholas)',
	'Glutaraldehyde',
	'SOL',
	gm.nullify_empty_string('2.45')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUTIHYDE 2.45 (Nicholas)'
);

-- line #15976
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUTIHYDE 2 (Nicholas)',
	'Glutaraldehyde',
	'SOL',
	gm.nullify_empty_string('2')::numeric,
	'%W/V(ALKALINE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUTIHYDE 2 (Nicholas)'
);

-- line #15977
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUTON 600 (Indo French)',
	'GLUTATHIONE',
	'INJ',
	gm.nullify_empty_string('600')::numeric,
	'mg(L)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUTON 600 (Indo French)'
);

-- line #15978
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INCYTO 50 (Wanbury)',
	'GLUTATHIONE',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg(REDUCED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INCYTO 50 (Wanbury)'
);

-- line #15979
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADONIA 15 (Unimarck)',
	'Glycerine',
	'CRM',
	gm.nullify_empty_string('15')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADONIA 15 (Unimarck)'
);

-- line #15980
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AQUASOFT 15 (Ajanta Ph.)',
	'Glycerine',
	'CRM',
	gm.nullify_empty_string('15')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AQUASOFT 15 (Ajanta Ph.)'
);

-- line #15981
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AUQASOFT 15 (Ajanta Ph.)',
	'Glycerine',
	'CRM',
	gm.nullify_empty_string('15')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AUQASOFT 15 (Ajanta Ph.)'
);

-- line #15982
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUTINORM 10 (IPCA LAB.)',
	'GLYCERINE',
	'LOT',
	gm.nullify_empty_string('10')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUTINORM 10 (IPCA LAB.)'
);

-- line #15983
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENSI ATM 15 (Dermocare)',
	'Glycerine',
	'CRM',
	gm.nullify_empty_string('15')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENSI ATM 15 (Dermocare)'
);

-- line #15984
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Glycerine', u'always_empty': u'', u'form': u'', u'brand': u'GLOSSY BAR', u'strength_3': u'', u'company': u'Mahavir Ent.', u'unit': u''}

-- line #15985
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'WITH BLEND OF VITAMINS ANTIOXIDANT', u'strength_2': u'', u'substance': u'Glycerine', u'always_empty': u'', u'form': u'SOAP', u'brand': u'GLYMED', u'strength_3': u'', u'company': u'MED MANOR', u'unit': u''}

-- line #15986
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUBRIFEM 14.5 (Cipla)',
	'GLYCEROL',
	'GEL',
	gm.nullify_empty_string('14.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUBRIFEM 14.5 (Cipla)'
);

-- line #15987
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITROGESIC 0.2 (Troikaa)',
	'Glyceryl Nitrate Soln./Glyceryl Trinitrate',
	'OINT',
	gm.nullify_empty_string('0.2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITROGESIC 0.2 (Troikaa)'
);

-- line #15988
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANGISED 0.5 (Gsk)',
	'Glyceryl Trinitrate',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANGISED 0.5 (Gsk)'
);

-- line #15989
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GTN 0.4 (Medley)',
	'Glyceryl Trinitrate',
	'SPRAY PEN',
	gm.nullify_empty_string('0.4')::numeric,
	'mg/1 PUFF'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GTN 0.4 (Medley)'
);

-- line #15990
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITRODAY 2.5 (Intra(INVISION))',
	'Glyceryl Trinitrate',
	'CR CAP',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITRODAY 2.5 (Intra(INVISION))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITRODAY 6.4 (Intra(INVISION))',
	'Glyceryl Trinitrate',
	'CR CAP',
	gm.nullify_empty_string('6.4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITRODAY 6.4 (Intra(INVISION))'
);

-- line #15991
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANGISPAN TR 2.5 (U S V)',
	'Glyceryl Trinitrate(Nitroglycerine)',
	'CAP',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANGISPAN TR 2.5 (U S V)'
);

-- line #15992
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANGISPAN TR 6.5 (U S V)',
	'Glyceryl Trinitrate(Nitroglycerine)',
	'CAP',
	gm.nullify_empty_string('6.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANGISPAN TR 6.5 (U S V)'
);

-- line #15993
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2,5', u'strength_2': u'', u'substance': u'Glyceryl Trinitrate(Nitroglycerine)', u'always_empty': u'', u'form': u'', u'brand': u'ANGISTAT', u'strength_3': u'', u'company': u'Ranbaxy', u'unit': u'mg(DILUTED)'}

-- line #15994
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'6,5', u'strength_2': u'', u'substance': u'Glyceryl Trinitrate(Nitroglycerine)', u'always_empty': u'', u'form': u'', u'brand': u'ANGISTAT', u'strength_3': u'', u'company': u'Ranbaxy', u'unit': u'mg(DILUTED)'}

-- line #15995
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANGITRO 25 (UNIMARK REM.)',
	'Glyceryl Trinitrate(Nitroglycerine)',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/5ML(NITROGLYCERINE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANGITRO 25 (UNIMARK REM.)'
);

-- line #15996
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANGITRO 50 (UNIMARK REM.)',
	'Glyceryl Trinitrate(Nitroglycerine)',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/10ML(NITROGLYCERINE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANGITRO 50 (UNIMARK REM.)'
);

-- line #15997
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'65MET.DOSE', u'strength_2': u'', u'substance': u'Glyceryl Trinitrate(Nitroglycerine)', u'always_empty': u'', u'form': u'', u'brand': u'GTN PEN', u'strength_3': u'', u'company': u'Medley', u'unit': u''}

-- line #15998
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GTN SORBITRATE 0.5 (Nicholas)',
	'Glyceryl Trinitrate(Nitroglycerine)',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GTN SORBITRATE 0.5 (Nicholas)'
);

-- line #15999
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GTN 0.4 (VAZOKARE)',
	'Glyceryl Trinitrate(Nitroglycerine)',
	'SPRAY',
	gm.nullify_empty_string('0.4')::numeric,
	'mg/DOSE'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GTN 0.4 (VAZOKARE)'
);

-- line #16000
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILLISROL 5 (Khandelwal)',
	'Glyceryl Trinitrate(Nitroglycerine)',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg/10ML(NITROGLYCERINE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILLISROL 5 (Khandelwal)'
);

-- line #16001
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYOCARE 25 (Criticare)',
	'Glyceryl Trinitrate(Nitroglycerine)',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYOCARE 25 (Criticare)'
);

-- line #16002
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYONIT 5 (Troikaa)',
	'Glyceryl Trinitrate(Nitroglycerine)',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYONIT 5 (Troikaa)'
);

-- line #16003
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,5', u'strength_2': u'', u'substance': u'Glyceryl Trinitrate(Nitroglycerine)', u'always_empty': u'', u'form': u'', u'brand': u'MYONIT-INSTA', u'strength_3': u'', u'company': u'Troikaa', u'unit': u'mg(NITROGLYCERINE)'}

-- line #16004
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYOVIN 2 (Cadila Ph.)',
	'Glyceryl Trinitrate(Nitroglycerine)',
	'OINT',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYOVIN 2 (Cadila Ph.)'
);

-- line #16005
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NGLONG 2.5 (Novartis)',
	'Glyceryl Trinitrate(Nitroglycerine)',
	'CAP',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NGLONG 2.5 (Novartis)'
);

-- line #16006
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NGLONG 6.5 (Novartis)',
	'Glyceryl Trinitrate(Nitroglycerine)',
	'CAP',
	gm.nullify_empty_string('6.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NGLONG 6.5 (Novartis)'
);

-- line #16007
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIG 25 (Vhb)',
	'Glyceryl Trinitrate(Nitroglycerine)',
	'AMP',
	gm.nullify_empty_string('25')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIG 25 (Vhb)'
);

-- line #16008
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIG 50 (Vhb)',
	'Glyceryl Trinitrate(Nitroglycerine)',
	'AMP',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIG 50 (Vhb)'
);

-- line #16009
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIG 5 (Neon)',
	'Glyceryl Trinitrate(Nitroglycerine)',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIG 5 (Neon)'
);

-- line #16010
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITROCIN 25 (Samarth)',
	'Glyceryl Trinitrate(Nitroglycerine)',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITROCIN 25 (Samarth)'
);

-- line #16011
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITROCIN 50 (Samarth)',
	'Glyceryl Trinitrate(Nitroglycerine)',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITROCIN 50 (Samarth)'
);

-- line #16012
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITROCONTIN 2.6 (Modi Mundi)',
	'Glyceryl Trinitrate(Nitroglycerine)',
	'CR TAB',
	gm.nullify_empty_string('2.6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITROCONTIN 2.6 (Modi Mundi)'
);

-- line #16013
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITROCONTIN 6.4 (Modi Mundi)',
	'Glyceryl Trinitrate(Nitroglycerine)',
	'CR TAB',
	gm.nullify_empty_string('6.4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITROCONTIN 6.4 (Modi Mundi)'
);

-- line #16014
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITROCURE 25 (Panacea)',
	'Glyceryl Trinitrate(Nitroglycerine)',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITROCURE 25 (Panacea)'
);

-- line #16015
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10', u'strength_2': u'', u'substance': u'Glyceryl Trinitrate(Nitroglycerine)', u'always_empty': u'', u'form': u'', u'brand': u'NITRODERM TTS PATCH', u'strength_3': u'', u'company': u'Novartis', u'unit': u'mg'}

-- line #16016
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5', u'strength_2': u'', u'substance': u'Glyceryl Trinitrate(Nitroglycerine)', u'always_empty': u'', u'form': u'', u'brand': u'NITRODERM TTS PATCH', u'strength_3': u'', u'company': u'Novartis', u'unit': u'mg'}

-- line #16017
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITROGLYN 25 (United Bio.)',
	'Glyceryl Trinitrate(Nitroglycerine)',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITROGLYN 25 (United Bio.)'
);

-- line #16018
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITROGLYN 50 (United Bio.)',
	'Glyceryl Trinitrate(Nitroglycerine)',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITROGLYN 50 (United Bio.)'
);

-- line #16019
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITROJECT 5 (Sun)',
	'Glyceryl Trinitrate(Nitroglycerine)',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML(NITROGLYCERINE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITROJECT 5 (Sun)'
);

-- line #16020
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITROLIFE 2.6 (Life Med.)',
	'Glyceryl Trinitrate(Nitroglycerine)',
	'CR TAB',
	gm.nullify_empty_string('2.6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITROLIFE 2.6 (Life Med.)'
);

-- line #16021
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITROLIFE 6.4 (Life Med.)',
	'Glyceryl Trinitrate(Nitroglycerine)',
	'CR TAB',
	gm.nullify_empty_string('6.4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITROLIFE 6.4 (Life Med.)'
);

-- line #16022
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITROLINGUAL 0.4 (Modi Mundi)',
	'Glyceryl Trinitrate(Nitroglycerine)',
	'SPRAY',
	gm.nullify_empty_string('0.4')::numeric,
	'mg/1 PUFF'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITROLINGUAL 0.4 (Modi Mundi)'
);

-- line #16023
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITROLONG-26 2.6 (Mankind)',
	'Glyceryl Trinitrate(Nitroglycerine)',
	'TAB',
	gm.nullify_empty_string('2.6')::numeric,
	'mg (DILUTED NITROGLYCERIN)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITROLONG-26 2.6 (Mankind)'
);

-- line #16024
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITROLONG-64 6.4 (Mankind)',
	'Glyceryl Trinitrate(Nitroglycerine)',
	'TAB',
	gm.nullify_empty_string('6.4')::numeric,
	'mg(DILUTED NITROGLYCERIN)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITROLONG-64 6.4 (Mankind)'
);

-- line #16025
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITROMINT 2.6 (Vhb)',
	'Glyceryl Trinitrate(Nitroglycerine)',
	'TAB',
	gm.nullify_empty_string('2.6')::numeric,
	'mg(NITROGLYCERINE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITROMINT 2.6 (Vhb)'
);

-- line #16026
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITROPLUS 5 (Neon)',
	'Glyceryl Trinitrate(Nitroglycerine)',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITROPLUS 5 (Neon)'
);

-- line #16027
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITROSOL 25 (SG PH.)',
	'Glyceryl Trinitrate(Nitroglycerine)',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITROSOL 25 (SG PH.)'
);

-- line #16028
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITROSOL 50 (SG PH.)',
	'Glyceryl Trinitrate(Nitroglycerine)',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/10ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITROSOL 50 (SG PH.)'
);

-- line #16029
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITROVIR 25 (CH.Bhagat)',
	'Glyceryl Trinitrate(Nitroglycerine)',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITROVIR 25 (CH.Bhagat)'
);

-- line #16030
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITROVIR 50 (CH.Bhagat)',
	'Glyceryl Trinitrate(Nitroglycerine)',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITROVIR 50 (CH.Bhagat)'
);

-- line #16031
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLCONTIN 2.6 (Olcare)',
	'Glyceryl Trinitrate(Nitroglycerine)',
	'CR TAB',
	gm.nullify_empty_string('2.6')::numeric,
	'mg/6.4'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLCONTIN 2.6 (Olcare)'
);

-- line #16032
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.5G', u'strength_2': u'100ML', u'substance': u'GLYCINE', u'always_empty': u'', u'form': u'SOL2000', u'brand': u'GLYCINE IRRIGATION', u'strength_3': u'', u'company': u'Parenteral', u'unit': u''}

-- line #16033
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.5G', u'strength_2': u'100ML', u'substance': u'GLYCINE', u'always_empty': u'', u'form': u'SOL3000', u'brand': u'GLYCINE IRRIGATION', u'strength_3': u'', u'company': u'Parenteral', u'unit': u''}

-- line #16034
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.5G', u'strength_2': u'100ML', u'substance': u'GLYCINE', u'always_empty': u'', u'form': u'SOL', u'brand': u'GLYCINE IRRIGATION', u'strength_3': u'', u'company': u'Parenteral', u'unit': u''}

-- line #16035
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'GLYCINE', u'always_empty': u'', u'form': u'SOL', u'brand': u'GLYCINE', u'strength_3': u'', u'company': u'Claris L.', u'unit': u''}

-- line #16036
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACZEE ALPHA 8 (OREVA DARMO.)',
	'Glycolic Acid',
	'LOT',
	gm.nullify_empty_string('8')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACZEE ALPHA 8 (OREVA DARMO.)'
);

-- line #16037
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Glycolic Acid', u'always_empty': u'', u'form': u'LIQ', u'brand': u'COSPEEL', u'strength_3': u'', u'company': u'LIVA HC.', u'unit': u''}

-- line #16038
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'AQUA', u'strength_2': u'', u'substance': u'Glycolic Acid', u'always_empty': u'', u'form': u'', u'brand': u'COSPEEL', u'strength_3': u'', u'company': u'Liva Hc.', u'unit': u''}

-- line #16039
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'125W', u'strength_2': u'W', u'substance': u'Glycolic Acid', u'always_empty': u'', u'form': u'', u'brand': u'DECROMA CREME %', u'strength_3': u'', u'company': u'Ranbaxy', u'unit': u''}

-- line #16040
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'6', u'strength_2': u'', u'substance': u'Glycolic Acid', u'always_empty': u'', u'form': u'', u'brand': u'DECROMA CREME %', u'strength_3': u'', u'company': u'Ranbaxy', u'unit': u'%W/W'}

-- line #16041
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYAHA 10 (Shalaks)',
	'Glycolic Acid',
	'LOT',
	gm.nullify_empty_string('10')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYAHA 10 (Shalaks)'
);

-- line #16042
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYAHA-VIT 10 (Shalaks)',
	'Glycolic Acid',
	'LOT',
	gm.nullify_empty_string('10')::numeric,
	'%(+VIT.A PALMITATE 2'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYAHA-VIT 10 (Shalaks)'
);

-- line #16043
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYCO-6 6 (Micro Labs)',
	'Glycolic Acid',
	'CRM',
	gm.nullify_empty_string('6')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYCO-6 6 (Micro Labs)'
);

-- line #16044
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYCO-A 12 (Micro Labs)',
	'Glycolic Acid',
	'CRM',
	gm.nullify_empty_string('12')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYCO-A 12 (Micro Labs)'
);

-- line #16045
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYCOVIRA 12 (Alkem)',
	'Glycolic Acid',
	'CRM',
	gm.nullify_empty_string('12')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYCOVIRA 12 (Alkem)'
);

-- line #16046
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYLAK 70 (Shalaks)',
	'Glycolic Acid',
	'SOL',
	gm.nullify_empty_string('70')::numeric,
	'% IP'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYLAK 70 (Shalaks)'
);

-- line #16047
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GOLIC 6 (PSYCOREM)',
	'Glycolic Acid',
	'CRM',
	gm.nullify_empty_string('6')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GOLIC 6 (PSYCOREM)'
);

-- line #16048
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GOLIC-D 12 (PSYCOREM)',
	'Glycolic Acid',
	'CRM',
	gm.nullify_empty_string('12')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GOLIC-D 12 (PSYCOREM)'
);

-- line #16049
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAMOLATE 0.2 (Destin Lab)',
	'Glycopyrrolate',
	'INJ',
	gm.nullify_empty_string('0.2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAMOLATE 0.2 (Destin Lab)'
);

-- line #16050
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLATE 0.2 (German R.)',
	'Glycopyrrolate',
	'INJ',
	gm.nullify_empty_string('0.2')::numeric,
	'mg(+BENZYL ALCOHOL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLATE 0.2 (German R.)'
);

-- line #16051
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYCO-P 0.2 (Khandelwal)',
	'Glycopyrrolate',
	'INJ',
	gm.nullify_empty_string('0.2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYCO-P 0.2 (Khandelwal)'
);

-- line #16052
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYCOPYROLATE INJ USP (10 0.2 (Troikaa)',
	'Glycopyrrolate',
	'VIAL)',
	gm.nullify_empty_string('0.2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYCOPYROLATE INJ USP (10 0.2 (Troikaa)'
);

-- line #16053
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYCOPYROLATE INJ USP (1 0.2 (Troikaa)',
	'Glycopyrrolate',
	'AMP)',
	gm.nullify_empty_string('0.2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYCOPYROLATE INJ USP (1 0.2 (Troikaa)'
);

-- line #16054
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYPROLATE 0.2 (CH.Bhagat)',
	'Glycopyrrolate',
	'INJ',
	gm.nullify_empty_string('0.2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYPROLATE 0.2 (CH.Bhagat)'
);

-- line #16055
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LICOLATE 0.2 (Samarth)',
	'Glycopyrrolate',
	'INJ',
	gm.nullify_empty_string('0.2')::numeric,
	'mg/1ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LICOLATE 0.2 (Samarth)'
);

-- line #16056
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYCOLATE 0.2 (BIOMIICRON)',
	'Glycopyrrolate',
	'AMP',
	gm.nullify_empty_string('0.2')::numeric,
	'mg/ML(GLYCOPYRRONIUM BR.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYCOLATE 0.2 (BIOMIICRON)'
);

-- line #16057
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYROLATE 0.2 (Neon)',
	'Glycopyrrolate',
	'AMP',
	gm.nullify_empty_string('0.2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYROLATE 0.2 (Neon)'
);

-- line #16058
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYROLIN 0.2 (CELON(REVILON))',
	'Glycopyrrolate',
	'AMP',
	gm.nullify_empty_string('0.2')::numeric,
	'mg(GLYCOPYRRONIUM BR.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYROLIN 0.2 (CELON(REVILON))'
);

-- line #16059
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYROLIN 2 (CELON(REVILON))',
	'Glycopyrrolate',
	'VIAL',
	gm.nullify_empty_string('2')::numeric,
	'mg(GLYCOPYRRONIUM BR.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYROLIN 2 (CELON(REVILON))'
);

-- line #16060
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYRONIUM 0.2 (Csc Ph.)',
	'Glycopyrrolate',
	'INJ',
	gm.nullify_empty_string('0.2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYRONIUM 0.2 (Csc Ph.)'
);

-- line #16061
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'150IU.', u'strength_2': u'', u'substance': u'Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'FOLICULIN IU', u'strength_3': u'', u'company': u'Bharat S.', u'unit': u''}

-- line #16062
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75IU.', u'strength_2': u'', u'substance': u'Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'FOLICULIN IU', u'strength_3': u'', u'company': u'Bharat S.', u'unit': u''}

-- line #16063
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u' mg)', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'UROFOLLITROPI(FSH)BP 150IU(+ MANNITOL 12', u'strength_2': u'', u'substance': u'Gonadotrophin F.S.H./Urofollitrophin', u'always_empty': u'', u'form': u'', u'brand': u'EEMA FSH', u'strength_3': u'', u'company': u'Corona', u'unit': u'POTASSIUM DIHYDROGEN ORTHOPHOSPHATE BP 0.46'}

-- line #16064
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u' mg)', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'UROFOLLITROPI(FSH)BP 75IU(+ MANNITOL 12', u'strength_2': u'', u'substance': u'Gonadotrophin F.S.H./Urofollitrophin', u'always_empty': u'', u'form': u'', u'brand': u'EEMA FSH', u'strength_3': u'', u'company': u'Corona', u'unit': u'POTASSIUM DIHYDROGEN ORTHOPHOSPHATE 0.46'}

-- line #16065
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75IU.', u'strength_2': u'150IU.', u'substance': u'Gonadotrophin F.S.H./Urofollitrophin', u'always_empty': u'', u'form': u'VIAL', u'brand': u'ENDOGEN', u'strength_3': u'', u'company': u'Uni-Sank.', u'unit': u''}

-- line #16066
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'150IU.', u'strength_2': u'', u'substance': u'Gonadotrophin F.S.H./Urofollitrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'FERGONAD-F', u'strength_3': u'', u'company': u'FERON LS', u'unit': u''}

-- line #16067
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75IU.', u'strength_2': u'', u'substance': u'Gonadotrophin F.S.H./Urofollitrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'FERGONAD-F', u'strength_3': u'', u'company': u'FERON LS', u'unit': u''}

-- line #16068
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'150IU.(UROFOLLITROPHIN)', u'strength_2': u'', u'substance': u'Gonadotrophin F.S.H./Urofollitrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'FHSCUTE', u'strength_3': u'', u'company': u'ACE PH.', u'unit': u''}

-- line #16069
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75IU.UROFOLLITROPHIN)', u'strength_2': u'', u'substance': u'Gonadotrophin F.S.H./Urofollitrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'FHSCUTE', u'strength_3': u'', u'company': u'ACE PH.', u'unit': u''}

-- line #16070
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'150I.U.', u'strength_2': u'', u'substance': u'Gonadotrophin F.S.H./Urofollitrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'FOLIGEM', u'strength_3': u'', u'company': u'German Life', u'unit': u''}

-- line #16071
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75IU.', u'strength_2': u'', u'substance': u'Gonadotrophin F.S.H./Urofollitrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'FOLIGEM', u'strength_3': u'', u'company': u'German Life', u'unit': u''}

-- line #16072
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75IU.', u'strength_2': u'150IU.', u'substance': u'Gonadotrophin F.S.H./Urofollitrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'FOLIGEST', u'strength_3': u'', u'company': u'Walter B.', u'unit': u''}

-- line #16073
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75IU.', u'strength_2': u'', u'substance': u'Gonadotrophin F.S.H./Urofollitrophin', u'always_empty': u'', u'form': u'VIAL', u'brand': u'FOLLIMON', u'strength_3': u'', u'company': u'Biochem', u'unit': u''}

-- line #16074
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'150IU.', u'strength_2': u'', u'substance': u'Gonadotrophin F.S.H./Urofollitrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'FOLLIOVA IU', u'strength_3': u'', u'company': u'Uni-Sank.', u'unit': u''}

-- line #16075
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75IU.', u'strength_2': u'', u'substance': u'Gonadotrophin F.S.H./Urofollitrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'FOLLIOVA IU', u'strength_3': u'', u'company': u'Uni-Sank.', u'unit': u''}

-- line #16076
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75', u'strength_2': u'150;I.U.', u'substance': u'Gonadotrophin F.S.H./Urofollitrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'FOLLOKON', u'strength_3': u'', u'company': u'BIOSENA', u'unit': u''}

-- line #16077
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75IU.', u'strength_2': u'', u'substance': u'Gonadotrophin F.S.H./Urofollitrophin', u'always_empty': u'', u'form': u'VIAL', u'brand': u'FOSTINE', u'strength_3': u'', u'company': u'Zydus Bio.', u'unit': u''}

-- line #16078
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75', u'strength_2': u'150;IU.', u'substance': u'Gonadotrophin F.S.H./Urofollitrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'FSH-SP', u'strength_3': u'', u'company': u'Samarth', u'unit': u''}

-- line #16079
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1200IU.(RECOMBINANT FSH)', u'strength_2': u'', u'substance': u'Gonadotrophin F.S.H./Urofollitrophin', u'always_empty': u'', u'form': u'AMP', u'brand': u'GONAL-F', u'strength_3': u'', u'company': u'Serum Inst.', u'unit': u''}

-- line #16080
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'37,5', u'strength_2': u'75 IU.(RECOMBINANT FSH)', u'substance': u'Gonadotrophin F.S.H./Urofollitrophin', u'always_empty': u'', u'form': u'AMP', u'brand': u'GONAL-F', u'strength_3': u'', u'company': u'Serum Inst.', u'unit': u''}

-- line #16081
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75IU.', u'strength_2': u'', u'substance': u'Gonadotrophin F.S.H./Urofollitrophin', u'always_empty': u'', u'form': u'AMP', u'brand': u'GONAL-F FBM', u'strength_3': u'', u'company': u'Serum Inst.', u'unit': u''}

-- line #16082
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1200IU.', u'strength_2': u'', u'substance': u'Gonadotrophin F.S.H./Urofollitrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'GONAL-F FBM', u'strength_3': u'', u'company': u'Serum Inst.', u'unit': u''}

-- line #16083
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'450IU.', u'strength_2': u'', u'substance': u'Gonadotrophin F.S.H./Urofollitrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'GONAL-F FBM', u'strength_3': u'', u'company': u'Serum Inst.', u'unit': u''}

-- line #16084
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'300IU. RECOMBNANT F S H', u'strength_2': u'', u'substance': u'Gonadotrophin F.S.H./Urofollitrophin', u'always_empty': u'', u'form': u'', u'brand': u'GONAL-F IU PEN', u'strength_3': u'', u'company': u'Serum Inst.', u'unit': u''}

-- line #16085
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'150IU.', u'strength_2': u'', u'substance': u'Gonadotrophin F.S.H./Urofollitrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'INDUCENT IU', u'strength_3': u'', u'company': u'Alkem', u'unit': u''}

-- line #16086
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75IU.', u'strength_2': u'', u'substance': u'Gonadotrophin F.S.H./Urofollitrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'INDUCENT IU', u'strength_3': u'', u'company': u'Alkem', u'unit': u''}

-- line #16087
-- ignoring line: field [strength_1] not numeric: >>>150IU.(HIGHLY UROFOLITROPINE)+ MANNTIOL 10<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'150IU.(HIGHLY UROFOLITROPINE)+ MANNTIOL 10', u'strength_2': u'', u'substance': u'Gonadotrophin F.S.H./Urofollitrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'INTAS FSH', u'strength_3': u'', u'company': u'INTAS', u'unit': u'mg'}

-- line #16088
-- ignoring line: field [strength_1] not numeric: >>>75IU.(HIGHLY UROFOLITROPINE)+ MANNTIOL 10<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75IU.(HIGHLY UROFOLITROPINE)+ MANNTIOL 10', u'strength_2': u'', u'substance': u'Gonadotrophin F.S.H./Urofollitrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'INTAS FSH', u'strength_3': u'', u'company': u'INTAS', u'unit': u'mg'}

-- line #16089
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75IU', u'strength_2': u'', u'substance': u'Gonadotrophin F.S.H./Urofollitrophin', u'always_empty': u'', u'form': u'VIAL', u'brand': u'LG FOLLIMON', u'strength_3': u'', u'company': u'Lglsi', u'unit': u''}

-- line #16090
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'150IU.', u'strength_2': u'', u'substance': u'Gonadotrophin F.S.H./Urofollitrophin', u'always_empty': u'', u'form': u'AMP', u'brand': u'LUPI-FSH', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #16091
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75IU.', u'strength_2': u'', u'substance': u'Gonadotrophin F.S.H./Urofollitrophin', u'always_empty': u'', u'form': u'AMP', u'brand': u'LUPI-FSH', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #16092
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75IU.', u'strength_2': u'', u'substance': u'Gonadotrophin F.S.H./Urofollitrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'MATERNA FSH', u'strength_3': u'', u'company': u'Emcure', u'unit': u''}

-- line #16093
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Gonadotrophin F.S.H./Urofollitrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'MATERNA HMG', u'strength_3': u'', u'company': u'Emcure', u'unit': u''}

-- line #16094
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'150IU. (HUMAN MENOPAUSAL GON.)', u'strength_2': u'', u'substance': u'Gonadotrophin F.S.H./Urofollitrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'MENONYS IU', u'strength_3': u'', u'company': u'Uni-Sank.', u'unit': u''}

-- line #16095
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75IU. (HUMAN MENOPAUSAL GON.)', u'strength_2': u'', u'substance': u'Gonadotrophin F.S.H./Urofollitrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'MENONYS IU', u'strength_3': u'', u'company': u'Uni-Sank.', u'unit': u''}

-- line #16096
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'150IU.', u'strength_2': u'', u'substance': u'Gonadotrophin F.S.H./Urofollitrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'NEOGENTIN', u'strength_3': u'', u'company': u'Svizera', u'unit': u''}

-- line #16097
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75IU.', u'strength_2': u'', u'substance': u'Gonadotrophin F.S.H./Urofollitrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'NEOGENTIN', u'strength_3': u'', u'company': u'Svizera', u'unit': u''}

-- line #16098
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'150IU.(RECOMBINANT FSH)', u'strength_2': u'', u'substance': u'Gonadotrophin F.S.H./Urofollitrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'NEWMON-R', u'strength_3': u'', u'company': u'LG LIFE', u'unit': u''}

-- line #16099
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75IU.(RECOMBINANT FSH)', u'strength_2': u'', u'substance': u'Gonadotrophin F.S.H./Urofollitrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'NEWMON-R', u'strength_3': u'', u'company': u'LG LIFE', u'unit': u''}

-- line #16100
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75', u'strength_2': u'150;IU', u'substance': u'Gonadotrophin F.S.H./Urofollitrophin', u'always_empty': u'', u'form': u'VIAL', u'brand': u'NISFOLLIC', u'strength_3': u'', u'company': u'NEISS', u'unit': u''}

-- line #16101
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75', u'strength_2': u'150 IU.', u'substance': u'Gonadotrophin F.S.H./Urofollitrophin', u'always_empty': u'', u'form': u'VIAL', u'brand': u'OVIMEN', u'strength_3': u'', u'company': u'Life Med.', u'unit': u''}

-- line #16102
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'150I.U.', u'strength_2': u'', u'substance': u'Gonadotrophin F.S.H./Urofollitrophin', u'always_empty': u'', u'form': u'HP INJ', u'brand': u'OVUFOL', u'strength_3': u'', u'company': u'Vhb', u'unit': u''}

-- line #16103
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75IU.', u'strength_2': u'', u'substance': u'Gonadotrophin F.S.H./Urofollitrophin', u'always_empty': u'', u'form': u'HP INJ', u'brand': u'OVUFOL', u'strength_3': u'', u'company': u'Vhb', u'unit': u''}

-- line #16104
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75', u'strength_2': u'150;I.U.', u'substance': u'Gonadotrophin F.S.H./Urofollitrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'PROFERTI-F', u'strength_3': u'', u'company': u'CH.Bhagat', u'unit': u''}

-- line #16105
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75', u'strength_2': u'150;IU.(FSH)', u'substance': u'Gonadotrophin F.S.H./Urofollitrophin', u'always_empty': u'', u'form': u'AMP', u'brand': u'PUREGON', u'strength_3': u'', u'company': u'Solvay Ph.', u'unit': u''}

-- line #16106
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50', u'strength_2': u'100;IU.(FSH)', u'substance': u'Gonadotrophin F.S.H./Urofollitrophin', u'always_empty': u'', u'form': u'AMP', u'brand': u'RECAGON', u'strength_3': u'', u'company': u'Infar', u'unit': u''}

-- line #16107
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMERGRAN-3 3 (Biochem)',
	'Granisetron Hcl.',
	'INJ',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMERGRAN-3 3 (Biochem)'
);

-- line #16108
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRANDEM 1 (Aristo)',
	'Granisetron Hcl.',
	'AMP',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRANDEM 1 (Aristo)'
);

-- line #16109
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRANDEM 1 (Aristo)',
	'Granisetron Hcl.',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRANDEM 1 (Aristo)'
);

-- line #16110
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRANDEM 1 (Aristo)',
	'Granisetron Hcl.',
	'SYR',
	gm.nullify_empty_string('1')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRANDEM 1 (Aristo)'
);

-- line #16111
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRANDEM 1 (Aristo)',
	'Granisetron Hcl.',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRANDEM 1 (Aristo)'
);

-- line #16112
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRANEXA 1 (Macleods)',
	'Granisetron Hcl.',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRANEXA 1 (Macleods)'
);

-- line #16113
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRANEXA 1 (Macleods)',
	'Granisetron Hcl.',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRANEXA 1 (Macleods)'
);

-- line #16114
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRANICIP 1 (Cipla)',
	'Granisetron Hcl.',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRANICIP 1 (Cipla)'
);

-- line #16115
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRANICIP 1 (Cipla)',
	'Granisetron Hcl.',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRANICIP 1 (Cipla)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRANICIP 2 (Cipla)',
	'Granisetron Hcl.',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRANICIP 2 (Cipla)'
);

-- line #16116
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRANIFORCE 1 (Mankind)',
	'Granisetron Hcl.',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRANIFORCE 1 (Mankind)'
);

-- line #16117
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRANIFORCE 1 (Mankind)',
	'Granisetron Hcl.',
	'MD TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRANIFORCE 1 (Mankind)'
);

-- line #16118
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRANIFORCE 1 (Mankind)',
	'Granisetron Hcl.',
	'SYR',
	gm.nullify_empty_string('1')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRANIFORCE 1 (Mankind)'
);

-- line #16119
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRANIFORCE 1 (Mankind)',
	'Granisetron Hcl.',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRANIFORCE 1 (Mankind)'
);

-- line #16120
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRANISET 1 (Sun)',
	'Granisetron Hcl.',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRANISET 1 (Sun)'
);

-- line #16121
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRANISET 1 (Sun)',
	'Granisetron Hcl.',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRANISET 1 (Sun)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRANISET 2 (Sun)',
	'Granisetron Hcl.',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRANISET 2 (Sun)'
);

-- line #16122
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRANISET 2 (Sun)',
	'Granisetron Hcl.',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRANISET 2 (Sun)'
);

-- line #16123
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRANISOL 1 (Intra Lab)',
	'Granisetron Hcl.',
	'TAB/SYR',
	gm.nullify_empty_string('1')::numeric,
	'mg/1'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRANISOL 1 (Intra Lab)'
);

-- line #16124
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRANITERO 3 (HETERO HC.)',
	'Granisetron Hcl.',
	'INJ',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRANITERO 3 (HETERO HC.)'
);

-- line #16125
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'300IU.(R-HUMAN)', u'strength_2': u'', u'substance': u'GRANULOCYTE COLONY SIMULATING FACTOR', u'always_empty': u'', u'form': u'INJ', u'brand': u'ITACT', u'strength_3': u'', u'company': u'Zuventus', u'unit': u''}

-- line #16126
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AFVIN 250 (Rhombic)',
	'Griseofulvin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AFVIN 250 (Rhombic)'
);

-- line #16127
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DERMOFULVIN 500 (Lincoln)',
	'Griseofulvin',
	'F. TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DERMOFULVIN 500 (Lincoln)'
);

-- line #16128
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DERMOFULVIN 250 (Lincoln)',
	'Griseofulvin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DERMOFULVIN 250 (Lincoln)'
);

-- line #16129
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DERMONORM 250 (Gsk)',
	'Griseofulvin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DERMONORM 250 (Gsk)'
);

-- line #16130
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DERMONORM 500 (Gsk)',
	'Griseofulvin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DERMONORM 500 (Gsk)'
);

-- line #16131
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUVIN -F 250 (Bombay T.)',
	'Griseofulvin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUVIN -F 250 (Bombay T.)'
);

-- line #16132
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUVIN 125 (Bombay T.)',
	'Griseofulvin',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUVIN 125 (Bombay T.)'
);

-- line #16133
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUVIN 500 (Bombay T.)',
	'Griseofulvin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUVIN 500 (Bombay T.)'
);

-- line #16134
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FULVIN-M 125 (Medopharm)',
	'Griseofulvin',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FULVIN-M 125 (Medopharm)'
);

-- line #16135
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FULVIN-M 250 (Medopharm)',
	'Griseofulvin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FULVIN-M 250 (Medopharm)'
);

-- line #16136
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FULVIN-M 500 (Medopharm)',
	'Griseofulvin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FULVIN-M 500 (Medopharm)'
);

-- line #16137
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FULVIN 250 (Dermatak)',
	'Griseofulvin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FULVIN 250 (Dermatak)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FULVIN 500 (Dermatak)',
	'Griseofulvin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FULVIN 500 (Dermatak)'
);

-- line #16138
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNGAL 125 (Inga)',
	'Griseofulvin',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNGAL 125 (Inga)'
);

-- line #16139
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNGAL 500 (Inga)',
	'Griseofulvin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNGAL 500 (Inga)'
);

-- line #16140
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNGICOR 250 (Corona)',
	'Griseofulvin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNGICOR 250 (Corona)'
);

-- line #16141
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNGIVIN 125 (Euphoric)',
	'Griseofulvin',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNGIVIN 125 (Euphoric)'
);

-- line #16142
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNGIVIN 250 (Euphoric)',
	'Griseofulvin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNGIVIN 250 (Euphoric)'
);

-- line #16143
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNGIVIN 375 (Euphoric)',
	'Griseofulvin',
	'TAB',
	gm.nullify_empty_string('375')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNGIVIN 375 (Euphoric)'
);

-- line #16144
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNGONIL-F 250 (Dial Ph.)',
	'Griseofulvin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNGONIL-F 250 (Dial Ph.)'
);

-- line #16145
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEOVIN 125 (Shalaks)',
	'Griseofulvin',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEOVIN 125 (Shalaks)'
);

-- line #16146
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEOVIN 250 (Shalaks)',
	'Griseofulvin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEOVIN 250 (Shalaks)'
);

-- line #16147
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRASO 125 (Dynamic)',
	'Griseofulvin',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRASO 125 (Dynamic)'
);

-- line #16148
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRASO 250 (Dynamic)',
	'Griseofulvin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRASO 250 (Dynamic)'
);

-- line #16149
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRIDERM 125 (EAST WEST)',
	'Griseofulvin',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRIDERM 125 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRIDERM 250 (EAST WEST)',
	'Griseofulvin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRIDERM 250 (EAST WEST)'
);

-- line #16150
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRIDERM 375 (EAST WEST)',
	'Griseofulvin',
	'TAB',
	gm.nullify_empty_string('375')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRIDERM 375 (EAST WEST)'
);

-- line #16151
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRIFULVIN 250 (Taurus Lab)',
	'Griseofulvin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRIFULVIN 250 (Taurus Lab)'
);

-- line #16152
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRISACTIN 250 (Cfl Ph.)',
	'Griseofulvin',
	'F. TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRISACTIN 250 (Cfl Ph.)'
);

-- line #16153
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRISEODERM 250 (TWILIGHT LIT.)',
	'Griseofulvin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRISEODERM 250 (TWILIGHT LIT.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRISEODERM 375 (TWILIGHT LIT.)',
	'Griseofulvin',
	'TAB',
	gm.nullify_empty_string('375')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRISEODERM 375 (TWILIGHT LIT.)'
);

-- line #16154
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRIS-O-D 250 (Dr.Reddy''S)',
	'Griseofulvin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRIS-O-D 250 (Dr.Reddy''S)'
);

-- line #16155
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRIS 375 (Dr.Reddy''S)',
	'Griseofulvin',
	'OD TAB',
	gm.nullify_empty_string('375')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRIS 375 (Dr.Reddy''S)'
);

-- line #16156
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRIS 375 (Dr.Reddy''S)',
	'Griseofulvin',
	'OD TAB',
	gm.nullify_empty_string('375')::numeric,
	'mg(U M)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRIS 375 (Dr.Reddy''S)'
);

-- line #16157
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRISOMAN 250 (Maan)',
	'Griseofulvin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRISOMAN 250 (Maan)'
);

-- line #16158
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRISOMED 500 (Comed)',
	'Griseofulvin',
	'F. TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRISOMED 500 (Comed)'
);

-- line #16159
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRISOMED 250 (Comed)',
	'Griseofulvin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRISOMED 250 (Comed)'
);

-- line #16160
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRISOMED 375 (Comed)',
	'Griseofulvin',
	'TAB',
	gm.nullify_empty_string('375')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRISOMED 375 (Comed)'
);

-- line #16161
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRISONORM 250 (Micro V.)',
	'Griseofulvin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRISONORM 250 (Micro V.)'
);

-- line #16162
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRISORAL 250 (Bal Ph.)',
	'Griseofulvin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRISORAL 250 (Bal Ph.)'
);

-- line #16163
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRISORAL 375 (Bal Ph.)',
	'Griseofulvin',
	'TAB',
	gm.nullify_empty_string('375')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRISORAL 375 (Bal Ph.)'
);

-- line #16164
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRISOVIN-FP 250 (Gsk)',
	'Griseofulvin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRISOVIN-FP 250 (Gsk)'
);

-- line #16165
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRISOVIN-FP 500 (Gsk)',
	'Griseofulvin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRISOVIN-FP 500 (Gsk)'
);

-- line #16166
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IDIFULVIN 125 (Idpl)',
	'Griseofulvin',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IDIFULVIN 125 (Idpl)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IDIFULVIN 250 (Idpl)',
	'Griseofulvin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IDIFULVIN 250 (Idpl)'
);

-- line #16167
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICROFULVIN 250 (PSYCOREM)',
	'Griseofulvin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICROFULVIN 250 (PSYCOREM)'
);

-- line #16168
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCONORM 250 (Pil)',
	'Griseofulvin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCONORM 250 (Pil)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCONORM 500 (Pil)',
	'Griseofulvin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCONORM 500 (Pil)'
);

-- line #16169
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUFULVIN 125 (Nulife)',
	'Griseofulvin',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUFULVIN 125 (Nulife)'
);

-- line #16170
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUFULVIN 250 (Nulife)',
	'Griseofulvin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUFULVIN 250 (Nulife)'
);

-- line #16171
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'GROUPS A & C POLYSACCHARIDE MENINGOCOCCAL VACCINE (LYPHOLIZED PREPARATION) 50MCG FROM EACH GROUP', u'always_empty': u'', u'form': u'INJ', u'brand': u'MENCEVAX-A & C', u'strength_3': u'', u'company': u'Gsk', u'unit': u''}

-- line #16172
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BARKEIT 200 (Uni-Sank.)',
	'Guaiphenesin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BARKEIT 200 (Uni-Sank.)'
);

-- line #16173
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5G', u'strength_2': u'', u'substance': u'Guargum', u'always_empty': u'', u'form': u'SAC', u'brand': u'CARBOTARD', u'strength_3': u'', u'company': u'Juggat', u'unit': u''}

-- line #16174
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GUGLIP 25 (Cipla)',
	'Gugulipid',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GUGLIP 25 (Cipla)'
);

-- line #16175
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'(ISOLATED FROM BOTHROPS ATROX OR JARARACA)', u'strength_2': u'', u'substance': u'HAEMOCOAGULASE', u'always_empty': u'', u'form': u'F. TOPICAL SOL', u'brand': u'BOTROCLOT', u'strength_3': u'', u'company': u'Juggat', u'unit': u''}

-- line #16176
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'(ISOLATED FROM BOTHROPS ATROX OR BOTHROX JARARACA)', u'strength_2': u'', u'substance': u'HAEMOCOAGULASE', u'always_empty': u'', u'form': u'SOL', u'brand': u'BOTROCLOT', u'strength_3': u'', u'company': u'Juggat', u'unit': u''}

-- line #16177
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1CU', u'strength_2': u'ML(BOTROPASE)', u'substance': u'HAEMOCOAGULASE', u'always_empty': u'', u'form': u'INJ', u'brand': u'BOTROPASE', u'strength_3': u'', u'company': u'Juggat', u'unit': u''}

-- line #16178
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1 CU', u'strength_2': u'ML', u'substance': u'HAEMOCOAGULASE', u'always_empty': u'', u'form': u'INJ', u'brand': u'COLASE', u'strength_3': u'', u'company': u'Samarth', u'unit': u''}

-- line #16179
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1U.', u'strength_2': u'', u'substance': u'HAEMOCOAGULASE', u'always_empty': u'', u'form': u'INJ', u'brand': u'REPTILASE', u'strength_3': u'', u'company': u'Troikaa', u'unit': u''}

-- line #16180
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1MCG', u'strength_2': u'ML(<)', u'substance': u'HAEMOPHILUS b CONJUGATE VACCINE', u'always_empty': u'', u'form': u'INJ', u'brand': u'ACT-HIB', u'strength_3': u'', u'company': u'Biological E.', u'unit': u''}

-- line #16181
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'DILUENT', u'strength_2': u'', u'substance': u'HAEMOPHILUS b CONJUGATE VACCINE', u'always_empty': u'', u'form': u'', u'brand': u'ACT-HIB MULTIPACK', u'strength_3': u'', u'company': u'Aventis Pas.', u'unit': u''}

-- line #16182
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'CONJUGATE OF PRP AND TETANUS ANTIGEN', u'strength_2': u'', u'substance': u'HAEMOPHILUS b CONJUGATE VACCINE', u'always_empty': u'', u'form': u'INJ', u'brand': u'HIBERIX', u'strength_3': u'', u'company': u'Gsk', u'unit': u''}

-- line #16183
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'HAEMOPHILUS b CONJUGATE VACCINE', u'always_empty': u'', u'form': u'VAC', u'brand': u'HIBEST', u'strength_3': u'', u'company': u'Aventis Pas.', u'unit': u''}

-- line #16184
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'HAEMOPHILUS b CONJUGATE VACCINE', u'always_empty': u'', u'form': u'VAC', u'brand': u'HIB-MULTIPACK', u'strength_3': u'', u'company': u'Aventis Pas.', u'unit': u''}

-- line #16185
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'HAEMOPHILIUS TYPE B CONJUGATE POLIMYELITIS VACCINE', u'strength_2': u'', u'substance': u'HAEMOPHILUS b CONJUGATE VACCINE', u'always_empty': u'', u'form': u'', u'brand': u'NOVO HIB', u'strength_3': u'', u'company': u'Chiron Pan.', u'unit': u''}

-- line #16186
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.(WITH TETANUS TOXOID)', u'strength_2': u'', u'substance': u'HAEMOPHILUS b CONJUGATE VACCINE', u'always_empty': u'', u'form': u'INJ', u'brand': u'PEDA HIB', u'strength_3': u'', u'company': u'Biomed', u'unit': u''}

-- line #16187
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORTILATE 0.1 (Micro Labs)',
	'Halcinonide',
	'OINT',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORTILATE 0.1 (Micro Labs)'
);

-- line #16188
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALOG 0.1 (Nicholas)',
	'Halcinonide',
	'CRM',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALOG 0.1 (Nicholas)'
);

-- line #16189
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALOBET 0.05 (AJANTA PH.)',
	'HALOBETASOL PROPIONATE',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALOBET 0.05 (AJANTA PH.)'
);

-- line #16190
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALOBET 0.05 (Ajanta Ph.)',
	'HALOBETASOL PROPIONATE',
	'OINT',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALOBET 0.05 (Ajanta Ph.)'
);

-- line #16191
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALODERM 0.05 (Micro Labs)',
	'HALOBETASOL PROPIONATE',
	'LOT',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALODERM 0.05 (Micro Labs)'
);

-- line #16192
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALODERM 0.05 (Micro Labs)',
	'HALOBETASOL PROPIONATE',
	'OINT',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALODERM 0.05 (Micro Labs)'
);

-- line #16193
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALONOVA 0.5 (Torrent)',
	'HALOBETASOL PROPIONATE',
	'CRM',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALONOVA 0.5 (Torrent)'
);

-- line #16194
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALOREX 0.05 (Indi Ph.)',
	'HALOBETASOL PROPIONATE',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALOREX 0.05 (Indi Ph.)'
);

-- line #16195
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALOSOL 0.05 (Alkem)',
	'HALOBETASOL PROPIONATE',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALOSOL 0.05 (Alkem)'
);

-- line #16196
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'HALOBETASOL PROPIONATE', u'always_empty': u'', u'form': u'', u'brand': u'HALOSTAR', u'strength_3': u'', u'company': u'Liva Hc.', u'unit': u''}

-- line #16197
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALOTOP 0.05 (Ipca)',
	'HALOBETASOL PROPIONATE',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALOTOP 0.05 (Ipca)'
);

-- line #16198
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALOTOP 0.05 (Ipca)',
	'HALOBETASOL PROPIONATE',
	'LOT',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALOTOP 0.05 (Ipca)'
);

-- line #16199
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALOVATE 0.05 (Glenmark)',
	'HALOBETASOL PROPIONATE',
	'CRM/OINT',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALOVATE 0.05 (Glenmark)'
);

-- line #16200
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALOVATE 0.05 (Gracewell)',
	'HALOBETASOL PROPIONATE',
	'CRM/OINT',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALOVATE 0.05 (Gracewell)'
);

-- line #16201
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALOX 0.05 (Ranbaxy)',
	'HALOBETASOL PROPIONATE',
	'CRM/OINT',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALOX 0.05 (Ranbaxy)'
);

-- line #16202
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALOX 0.05 (Ranbaxy)',
	'HALOBETASOL PROPIONATE',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALOX 0.05 (Ranbaxy)'
);

-- line #16203
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALOX ES 0.05 (Ranbaxy)',
	'HALOBETASOL PROPIONATE',
	'OINT',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALOX ES 0.05 (Ranbaxy)'
);

-- line #16204
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALOX 0.05 (Ranbaxy)',
	'HALOBETASOL PROPIONATE',
	'LOT',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALOX 0.05 (Ranbaxy)'
);

-- line #16205
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HELACT 0.05 (KIVI LABS)',
	'HALOBETASOL PROPIONATE',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HELACT 0.05 (KIVI LABS)'
);

-- line #16206
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'HALOBETASOL PROPIONATE', u'always_empty': u'', u'form': u'CRM', u'brand': u'HEXDERM', u'strength_3': u'', u'company': u'OMNI LIFE', u'unit': u''}

-- line #16207
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'HALOBETASOL PROPIONATE', u'always_empty': u'', u'form': u'CRM', u'brand': u'HOBS', u'strength_3': u'', u'company': u'AAMORB(SIOUX)', u'unit': u''}

-- line #16208
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HTROID 0.05 (Themis Med.)',
	'HALOBETASOL PROPIONATE',
	'GEL',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HTROID 0.05 (Themis Med.)'
);

-- line #16209
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXECARE 0.5 (DR. REDDY''S)',
	'HALOMETASONE',
	'CRM',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXECARE 0.5 (DR. REDDY''S)'
);

-- line #16210
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENZYDOL-P O25/15 0.25 (LA DRUG)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENZYDOL-P O25/15 0.25 (LA DRUG)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENZYDOL-P O25/15 1.5 (LA DRUG)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENZYDOL-P O25/15 1.5 (LA DRUG)'
);

-- line #16211
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENZYDOL-P 10 (LA DRUG)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENZYDOL-P 10 (LA DRUG)'
);

-- line #16212
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENZYDOL-P 5 (LA DRUG)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENZYDOL-P 5 (LA DRUG)'
);

-- line #16213
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRAIN-REST 5 (Ind-Swift)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRAIN-REST 5 (Ind-Swift)'
);

-- line #16214
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIZOREN 2 (Stadmed)',
	'Haloperidol',
	'LIQ',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIZOREN 2 (Stadmed)'
);

-- line #16215
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIZOREN 10 (Stadmed)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIZOREN 10 (Stadmed)'
);

-- line #16216
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIZOREN 1.5 (Stadmed)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIZOREN 1.5 (Stadmed)'
);

-- line #16217
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIZOREN 5 (Stadmed)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIZOREN 5 (Stadmed)'
);

-- line #16218
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPIDOL 2 (Torrent)',
	'Haloperidol',
	'DPS',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPIDOL 2 (Torrent)'
);

-- line #16219
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPIDOL 50 (Torrent)',
	'Haloperidol',
	'LA INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPIDOL 50 (Torrent)'
);

-- line #16220
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPIDOL 0.25 (Torrent)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPIDOL 0.25 (Torrent)'
);

-- line #16221
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPIDOL 10 (Torrent)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPIDOL 10 (Torrent)'
);

-- line #16222
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPIDOL 1.5 (Torrent)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPIDOL 1.5 (Torrent)'
);

-- line #16223
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPIDOL 5 (Torrent)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPIDOL 5 (Torrent)'
);

-- line #16224
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALDOL 0.25 (EAST WEST)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALDOL 0.25 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALDOL 0.5 (EAST WEST)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALDOL 0.5 (EAST WEST)'
);

-- line #16225
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALDOL 1.5 (EAST WEST)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALDOL 1.5 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALDOL 2.5 (EAST WEST)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALDOL 2.5 (EAST WEST)'
);

-- line #16226
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALDOL 5 (EAST WEST)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALDOL 5 (EAST WEST)'
);

-- line #16227
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALIDACE 0.25 (BARODA)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALIDACE 0.25 (BARODA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALIDACE 1.5 (BARODA)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALIDACE 1.5 (BARODA)'
);

-- line #16228
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALIDACE 20 (BARODA)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALIDACE 20 (BARODA)'
);

-- line #16229
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALIDACE 5 (BARODA)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALIDACE 5 (BARODA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALIDACE 10 (BARODA)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALIDACE 10 (BARODA)'
);

-- line #16230
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALIDOL 0.25 (GSK)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALIDOL 0.25 (GSK)'
);

-- line #16231
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALIDOL 1.5 (GSK)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALIDOL 1.5 (GSK)'
);

-- line #16232
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALIDOL 5 (GSK)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALIDOL 5 (GSK)'
);

-- line #16233
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALOBID 0.25 (Crescent Th.)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALOBID 0.25 (Crescent Th.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALOBID 1.5 (Crescent Th.)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALOBID 1.5 (Crescent Th.)'
);

-- line #16234
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALOBID 5 (Crescent Th.)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALOBID 5 (Crescent Th.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALOBID 10 (Crescent Th.)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALOBID 10 (Crescent Th.)'
);

-- line #16235
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALO 5 (OREVA DARMO.)',
	'Haloperidol',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALO 5 (OREVA DARMO.)'
);

-- line #16236
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALOPACE 0.25 (Pil)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALOPACE 0.25 (Pil)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALOPACE 1.5 (Pil)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALOPACE 1.5 (Pil)'
);

-- line #16237
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALOPACE 5 (Pil)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALOPACE 5 (Pil)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALOPACE 10 (Pil)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALOPACE 10 (Pil)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALOPACE 20 (Pil)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALOPACE 20 (Pil)'
);

-- line #16238
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALOPIDOL 10 (Ethnor)',
	'Haloperidol',
	'DPS',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALOPIDOL 10 (Ethnor)'
);

-- line #16239
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALOPIDOL 5 (Ethnor)',
	'Haloperidol',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALOPIDOL 5 (Ethnor)'
);

-- line #16240
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALOPIDOL 2 (Ethnor)',
	'Haloperidol',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALOPIDOL 2 (Ethnor)'
);

-- line #16241
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALOPIDOL 10 (Ethnor)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALOPIDOL 10 (Ethnor)'
);

-- line #16242
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALOPIDOL 20 (Ethnor)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALOPIDOL 20 (Ethnor)'
);

-- line #16243
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALOPIDOL 2 (Ethnor)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALOPIDOL 2 (Ethnor)'
);

-- line #16244
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALOPIDOL 5 (Ethnor)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALOPIDOL 5 (Ethnor)'
);

-- line #16245
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALOP 5 (Tripada Hc.)',
	'Haloperidol',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALOP 5 (Tripada Hc.)'
);

-- line #16246
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALOTON 10 (Triton Hc.)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALOTON 10 (Triton Hc.)'
);

-- line #16247
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALOTON 2.5 (Triton Hc.)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALOTON 2.5 (Triton Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALOTON 5 (Triton Hc.)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALOTON 5 (Triton Hc.)'
);

-- line #16248
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALOTON 5 (Triton Hc.)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALOTON 5 (Triton Hc.)'
);

-- line #16249
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1,5', u'strength_2': u'', u'substance': u'Haloperidol', u'always_empty': u'', u'form': u'', u'brand': u'HALOTON', u'strength_3': u'', u'company': u'Triton Hc.', u'unit': u'mg'}

-- line #16250
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALOWEL 10 (Taurus Lab)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALOWEL 10 (Taurus Lab)'
);

-- line #16251
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALOXEL 0.25 (S P Ph.)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALOXEL 0.25 (S P Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALOXEL 1.5 (S P Ph.)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALOXEL 1.5 (S P Ph.)'
);

-- line #16252
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALOXEL 5 (S P Ph.)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALOXEL 5 (S P Ph.)'
);

-- line #16253
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HAPDOL 5 (Rkg)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HAPDOL 5 (Rkg)'
);

-- line #16254
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HARIDOL 1.5 (RECOUPE)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HARIDOL 1.5 (RECOUPE)'
);

-- line #16255
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HARIDOL 5 (RECOUPE)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HARIDOL 5 (RECOUPE)'
);

-- line #16256
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Haloperidol', u'always_empty': u'', u'form': u'LA INJ', u'brand': u'HDOT', u'strength_3': u'', u'company': u'TALENT LAB.', u'unit': u''}

-- line #16257
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HELINASE 0.25 (TASMED)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HELINASE 0.25 (TASMED)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HELINASE 1.5 (TASMED)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HELINASE 1.5 (TASMED)'
);

-- line #16258
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HELINASE 5 (TASMED)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HELINASE 5 (TASMED)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HELINASE 10 (TASMED)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HELINASE 10 (TASMED)'
);

-- line #16259
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEXIDOL15 1.5 (Torrent)',
	'HALOPERIDOL',
	'TAB',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEXIDOL15 1.5 (Torrent)'
);

-- line #16260
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEXIDOL 10 (Torrent)',
	'HALOPERIDOL',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEXIDOL 10 (Torrent)'
);

-- line #16261
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEXIDOL 5 (Torrent)',
	'HALOPERIDOL',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEXIDOL 5 (Torrent)'
);

-- line #16262
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LARENASE 0.25 (LA DRUG)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LARENASE 0.25 (LA DRUG)'
);

-- line #16263
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LARENASE 10 (LA DRUG)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LARENASE 10 (LA DRUG)'
);

-- line #16264
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LARENASE 1.5 (LA DRUG)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LARENASE 1.5 (LA DRUG)'
);

-- line #16265
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LARENASE 20 (LA DRUG)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LARENASE 20 (LA DRUG)'
);

-- line #16266
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LARENASE 5 (LA DRUG)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LARENASE 5 (LA DRUG)'
);

-- line #16267
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANONACE 0.25 (Mano)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANONACE 0.25 (Mano)'
);

-- line #16268
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANONACE 10 (Mano)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANONACE 10 (Mano)'
);

-- line #16269
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANONACE 20 (Mano)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANONACE 20 (Mano)'
);

-- line #16270
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANONACE 5 (Mano)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANONACE 5 (Mano)'
);

-- line #16271
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MINDOL 5 (Synapse)',
	'Haloperidol',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MINDOL 5 (Synapse)'
);

-- line #16272
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MINDOL 10 (Synapse)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MINDOL 10 (Synapse)'
);

-- line #16273
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MINDOL 5 (Synapse)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MINDOL 5 (Synapse)'
);

-- line #16274
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MINDWEL 1.5 (Ajanta Ph.)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MINDWEL 1.5 (Ajanta Ph.)'
);

-- line #16275
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MINDWEL 5 (Ajanta Ph.)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MINDWEL 5 (Ajanta Ph.)'
);

-- line #16276
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEDOL 5 (SHINE PH.)',
	'Haloperidol',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEDOL 5 (SHINE PH.)'
);

-- line #16277
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEDOL 1.5 (SHINE PH.)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEDOL 1.5 (SHINE PH.)'
);

-- line #16278
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPREX 0.25 (PSYCOREM)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPREX 0.25 (PSYCOREM)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPREX 1.5 (PSYCOREM)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPREX 1.5 (PSYCOREM)'
);

-- line #16279
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPREX 20 (PSYCOREM)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPREX 20 (PSYCOREM)'
);

-- line #16280
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPREX 5 (PSYCOREM)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPREX 5 (PSYCOREM)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPREX 10 (PSYCOREM)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPREX 10 (PSYCOREM)'
);

-- line #16281
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELINASE 5 (Reliance)',
	'Haloperidol',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELINASE 5 (Reliance)'
);

-- line #16282
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELINASE 2.5 (Reliance)',
	'Haloperidol',
	'KID TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELINASE 2.5 (Reliance)'
);

-- line #16283
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELINASE 50 (Reliance)',
	'Haloperidol',
	'LA INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELINASE 50 (Reliance)'
);

-- line #16284
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELINASE 0.25 (Reliance)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELINASE 0.25 (Reliance)'
);

-- line #16285
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELINASE 10 (Reliance)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELINASE 10 (Reliance)'
);

-- line #16286
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELINASE 1.5 (Reliance)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELINASE 1.5 (Reliance)'
);

-- line #16287
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELINASE 5 (Reliance)',
	'Haloperidol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELINASE 5 (Reliance)'
);

-- line #16288
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Halothane', u'always_empty': u'', u'form': u'', u'brand': u'FLUOTHANE INHALATION', u'strength_3': u'', u'company': u'Nicholas', u'unit': u''}

-- line #16289
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Halothane', u'always_empty': u'', u'form': u'', u'brand': u'HALOTHANE', u'strength_3': u'', u'company': u'RAMAN & WEIL', u'unit': u''}

-- line #16290
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Halothane', u'always_empty': u'', u'form': u'LIQ', u'brand': u'HYPNOTHANE', u'strength_3': u'', u'company': u'Neon', u'unit': u''}

-- line #16291
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'400000U.', u'strength_2': u'', u'substance': u'Hamycin', u'always_empty': u'', u'form': u'', u'brand': u'HAMYCIN ,000U OVULES', u'strength_3': u'', u'company': u'Hal', u'unit': u''}

-- line #16292
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200000U', u'strength_2': u'ML', u'substance': u'Hamycin', u'always_empty': u'', u'form': u'SUS', u'brand': u'HAMYCIN', u'strength_3': u'', u'company': u'Hal', u'unit': u''}

-- line #16293
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200IU', u'strength_2': u'GM', u'substance': u'Heparin', u'always_empty': u'', u'form': u'GEL', u'brand': u'BEPARINE', u'strength_3': u'', u'company': u'Biological E.', u'unit': u''}

-- line #16294
-- ignoring line: field [strength_1] not numeric: >>>1000IU<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000IU', u'strength_2': u'', u'substance': u'Heparin', u'always_empty': u'', u'form': u'INJ', u'brand': u'BEPARINE IU', u'strength_3': u'', u'company': u'Biological E.', u'unit': u'(0.15'}

-- line #16295
-- ignoring line: field [strength_1] not numeric: >>>5000IU<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU', u'strength_2': u'', u'substance': u'Heparin', u'always_empty': u'', u'form': u'INJ', u'brand': u'BEPARINE IU', u'strength_3': u'', u'company': u'Biological E.', u'unit': u'(0.15'}

-- line #16296
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10I.U.', u'strength_2': u'', u'substance': u'Heparin', u'always_empty': u'', u'form': u'LF INJ', u'brand': u'BEPARINE', u'strength_3': u'', u'company': u'Biological E.', u'unit': u''}

-- line #16297
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'25000IU', u'strength_2': u'5ML', u'substance': u'Heparin', u'always_empty': u'', u'form': u'VIAL', u'brand': u'BEPRIN', u'strength_3': u'', u'company': u'TAJ PH.', u'unit': u''}

-- line #16298
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50000IU', u'strength_2': u'10ML', u'substance': u'Heparin', u'always_empty': u'', u'form': u'VIAL', u'brand': u'BEPRIN', u'strength_3': u'', u'company': u'TAJ PH.', u'unit': u''}

-- line #16299
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500IU', u'strength_2': u'5ML', u'substance': u'Heparin', u'always_empty': u'', u'form': u'VIAL', u'brand': u'BEPRIN', u'strength_3': u'', u'company': u'TAJ PH.', u'unit': u''}

-- line #16300
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'25000IU.', u'strength_2': u'', u'substance': u'Heparin', u'always_empty': u'', u'form': u'INJ', u'brand': u'BLOCKASOL', u'strength_3': u'', u'company': u'SG PH.', u'unit': u''}

-- line #16301
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU.', u'strength_2': u'', u'substance': u'Heparin', u'always_empty': u'', u'form': u'INJ', u'brand': u'BLOCKASOL', u'strength_3': u'', u'company': u'SG PH.', u'unit': u''}

-- line #16302
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2500', u'strength_2': u'5000;IU', u'substance': u'Heparin', u'always_empty': u'', u'form': u'INJ', u'brand': u'CAPRIN', u'strength_3': u'5ML(SOD.)', u'company': u'Samarth', u'unit': u''}

-- line #16303
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'25000IU(SOD.)', u'strength_2': u'', u'substance': u'Heparin', u'always_empty': u'', u'form': u'INJ', u'brand': u'CAPRIN IU', u'strength_3': u'', u'company': u'Samarth', u'unit': u''}

-- line #16304
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU', u'strength_2': u'25000IU', u'substance': u'Heparin', u'always_empty': u'', u'form': u'VIAL', u'brand': u'CELPARIN', u'strength_3': u'', u'company': u'CELON(REVILON)', u'unit': u''}

-- line #16305
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10000IU.', u'strength_2': u'10ML', u'substance': u'Heparin', u'always_empty': u'', u'form': u'INJ', u'brand': u'DALTEHEP', u'strength_3': u'', u'company': u'Gland Ph.', u'unit': u''}

-- line #16306
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2500IU.', u'strength_2': u'', u'substance': u'Heparin', u'always_empty': u'', u'form': u'INJ', u'brand': u'DALTEHEP', u'strength_3': u'', u'company': u'Gland Ph.', u'unit': u''}

-- line #16307
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU.', u'strength_2': u'', u'substance': u'Heparin', u'always_empty': u'', u'form': u'INJ', u'brand': u'DALTEHEP', u'strength_3': u'', u'company': u'Gland Ph.', u'unit': u''}

-- line #16308
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000IU', u'strength_2': u'5000IU', u'substance': u'Heparin', u'always_empty': u'', u'form': u'INJ', u'brand': u'DECLOT', u'strength_3': u'', u'company': u'Zydus Cadila', u'unit': u''}

-- line #16309
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'25000IU(SOD.)', u'strength_2': u'', u'substance': u'Heparin', u'always_empty': u'', u'form': u'INJ', u'brand': u'HEPACARD', u'strength_3': u'', u'company': u'Csc Ph.', u'unit': u''}

-- line #16310
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU(SOD.)', u'strength_2': u'', u'substance': u'Heparin', u'always_empty': u'', u'form': u'INJ', u'brand': u'HEPACARD IU', u'strength_3': u'', u'company': u'Csc Ph.', u'unit': u''}

-- line #16311
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000I.U.', u'strength_2': u'ML(SOD.)', u'substance': u'Heparin', u'always_empty': u'', u'form': u'V', u'brand': u'HEPAREN', u'strength_3': u'', u'company': u'Claris L.', u'unit': u''}

-- line #16312
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000I.U.', u'strength_2': u'ML(SOD.)', u'substance': u'Heparin', u'always_empty': u'', u'form': u'V', u'brand': u'HEPAREN', u'strength_3': u'', u'company': u'Claris L.', u'unit': u''}

-- line #16313
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000IU', u'strength_2': u'ML', u'substance': u'Heparin', u'always_empty': u'', u'form': u'INJ', u'brand': u'HEPARINE IU', u'strength_3': u'', u'company': u'Biological E.', u'unit': u''}

-- line #16314
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU', u'strength_2': u'ML', u'substance': u'Heparin', u'always_empty': u'', u'form': u'INJ', u'brand': u'HEPARINE IU', u'strength_3': u'', u'company': u'Biological E.', u'unit': u''}

-- line #16315
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU.', u'strength_2': u'', u'substance': u'Heparin', u'always_empty': u'', u'form': u'INJ', u'brand': u'HEPARIN', u'strength_3': u'', u'company': u'Gland Ph.', u'unit': u''}

-- line #16316
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'25000IU(SOD.)', u'strength_2': u'', u'substance': u'Heparin', u'always_empty': u'', u'form': u'INJ', u'brand': u'HEPARIN SODIUM', u'strength_3': u'', u'company': u'CH.Bhagat', u'unit': u''}

-- line #16317
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU(SOD.)', u'strength_2': u'', u'substance': u'Heparin', u'always_empty': u'', u'form': u'INJ', u'brand': u'HEPARIN SODIUM', u'strength_3': u'', u'company': u'CH.Bhagat', u'unit': u''}

-- line #16318
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU', u'strength_2': u'', u'substance': u'Heparin', u'always_empty': u'', u'form': u'V', u'brand': u'HEPARIN', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #16319
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250IU', u'strength_2': u'G(SOD.)', u'substance': u'Heparin', u'always_empty': u'', u'form': u'GEL', u'brand': u'HEPGEL', u'strength_3': u'', u'company': u'Gland Ph.', u'unit': u''}

-- line #16320
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000', u'strength_2': u'25000;I.U.(SOD.)', u'substance': u'Heparin', u'always_empty': u'', u'form': u'INJ', u'brand': u'HEP', u'strength_3': u'', u'company': u'Gland Ph.', u'unit': u''}

-- line #16321
-- ignoring line: field [strength_1] not numeric: >>>10IU.(0.9<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10IU.(0.9', u'strength_2': u'', u'substance': u'Heparin', u'always_empty': u'', u'form': u'INJ', u'brand': u'HEPLOCK', u'strength_3': u'', u'company': u'Gland Ph.', u'unit': u'%SOD.CHL.+0.95'}

-- line #16322
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'25000I.U.', u'strength_2': u'', u'substance': u'Heparin', u'always_empty': u'', u'form': u'V', u'brand': u'INHEP', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #16323
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000IU', u'strength_2': u'', u'substance': u'Heparin', u'always_empty': u'', u'form': u'INJ', u'brand': u'KEPARIN', u'strength_3': u'', u'company': u'Neon', u'unit': u''}

-- line #16324
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'25000IU', u'strength_2': u'5ML(SOD.)', u'substance': u'Heparin', u'always_empty': u'', u'form': u'INJ', u'brand': u'KEPARIN', u'strength_3': u'', u'company': u'Vhb', u'unit': u''}

-- line #16325
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU', u'strength_2': u'5ML(SOD.)', u'substance': u'Heparin', u'always_empty': u'', u'form': u'INJ', u'brand': u'KEPARIN', u'strength_3': u'', u'company': u'Vhb', u'unit': u''}

-- line #16326
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10IU', u'strength_2': u'ML', u'substance': u'Heparin', u'always_empty': u'', u'form': u'VIAL', u'brand': u'LINE FLUSH', u'strength_3': u'', u'company': u'CMGBT', u'unit': u''}

-- line #16327
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000I.U.', u'strength_2': u'5000I.U. (SOLN.)', u'substance': u'Heparin', u'always_empty': u'', u'form': u'VIAL', u'brand': u'NUPARIN', u'strength_3': u'', u'company': u'Troikaa', u'unit': u''}

-- line #16328
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU', u'strength_2': u'25000IU', u'substance': u'Heparin', u'always_empty': u'', u'form': u'INJ', u'brand': u'REPARIN', u'strength_3': u'', u'company': u'ROSE LABS', u'unit': u''}

-- line #16329
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'HEPATITIS A VACCINE', u'always_empty': u'', u'form': u'INJ', u'brand': u'AVAXIM', u'strength_3': u'', u'company': u'Aventis Pas.', u'unit': u''}

-- line #16330
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'HEPATITIS A VACCINE', u'always_empty': u'', u'form': u'', u'brand': u'AVAXIM-U PAED', u'strength_3': u'', u'company': u'Aventis Pas.', u'unit': u''}

-- line #16331
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Hepatitis A Vaccine', u'always_empty': u'', u'form': u'INJ', u'brand': u'HAVRIX-U', u'strength_3': u'', u'company': u'Gsk', u'unit': u''}

-- line #16332
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100IU.', u'strength_2': u'', u'substance': u'Hepatitis B Immunoglobulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'HEBABIG IU', u'strength_3': u'', u'company': u'Vhb', u'unit': u''}

-- line #16333
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200IU.', u'strength_2': u'', u'substance': u'Hepatitis B Immunoglobulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'HEBABIG IU', u'strength_3': u'', u'company': u'Vhb', u'unit': u''}

-- line #16334
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100IU', u'strength_2': u'0.5ML', u'substance': u'Hepatitis B Immunoglobulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'HEPABIG', u'strength_3': u'', u'company': u'Vhb', u'unit': u''}

-- line #16335
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200IU', u'strength_2': u'ML', u'substance': u'Hepatitis B Immunoglobulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'HEPABIG', u'strength_3': u'', u'company': u'Vhb', u'unit': u''}

-- line #16336
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100IU', u'strength_2': u'', u'substance': u'Hepatitis B Immunoglobulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'HEPAGLOB IU', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #16337
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200IU.', u'strength_2': u'', u'substance': u'Hepatitis B Immunoglobulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'HEPAGLOB IU', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #16338
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100IU.', u'strength_2': u'', u'substance': u'Hepatitis B Immunoglobulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'HEP-B IU', u'strength_3': u'', u'company': u'Synergy D.', u'unit': u''}

-- line #16339
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200IU.', u'strength_2': u'', u'substance': u'Hepatitis B Immunoglobulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'HEP-B IU', u'strength_3': u'', u'company': u'Synergy D.', u'unit': u''}

-- line #16340
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10MCG', u'strength_2': u'', u'substance': u'Hepatitis B Vaccine', u'always_empty': u'', u'form': u'INJ', u'brand': u'BEVAC MCG', u'strength_3': u'', u'company': u'Biological E.', u'unit': u''}

-- line #16341
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20MCG', u'strength_2': u'', u'substance': u'Hepatitis B Vaccine', u'always_empty': u'', u'form': u'INJ', u'brand': u'BEVAC MCG', u'strength_3': u'', u'company': u'Biological E.', u'unit': u''}

-- line #16342
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Hepatitis B Vaccine', u'always_empty': u'', u'form': u'V', u'brand': u'BEVAC MULTIDOSE', u'strength_3': u'', u'company': u'Biological E.', u'unit': u''}

-- line #16343
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10MCG', u'strength_2': u'', u'substance': u'Hepatitis B Vaccine', u'always_empty': u'', u'form': u'INJ', u'brand': u'BIOVAC-B MCG', u'strength_3': u'', u'company': u'Wockhardt', u'unit': u''}

-- line #16344
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20MCG', u'strength_2': u'', u'substance': u'Hepatitis B Vaccine', u'always_empty': u'', u'form': u'INJ', u'brand': u'BIOVAC-B MCG', u'strength_3': u'', u'company': u'Wockhardt', u'unit': u''}

-- line #16345
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100MCG', u'strength_2': u'', u'substance': u'Hepatitis B Vaccine', u'always_empty': u'', u'form': u'V', u'brand': u'BIOVAC-B MULTIDOSE', u'strength_3': u'', u'company': u'Wockhardt', u'unit': u''}

-- line #16346
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10MCG', u'strength_2': u'', u'substance': u'Hepatitis B Vaccine', u'always_empty': u'', u'form': u'INJ', u'brand': u'ENGERIX-B MCG', u'strength_3': u'', u'company': u'Gsk', u'unit': u''}

-- line #16347
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20MCG', u'strength_2': u'', u'substance': u'Hepatitis B Vaccine', u'always_empty': u'', u'form': u'INJ', u'brand': u'ENGERIX-B MCG', u'strength_3': u'', u'company': u'Gsk', u'unit': u''}

-- line #16348
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Hepatitis B Vaccine', u'always_empty': u'', u'form': u'V', u'brand': u'ENGERIX-B MULTIDOSE', u'strength_3': u'', u'company': u'Gsk', u'unit': u''}

-- line #16349
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10MCG', u'strength_2': u'', u'substance': u'Hepatitis B Vaccine', u'always_empty': u'', u'form': u'INJ', u'brand': u'ENIVAC HB MCG', u'strength_3': u'', u'company': u'Panacea', u'unit': u''}

-- line #16350
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20MCG', u'strength_2': u'', u'substance': u'Hepatitis B Vaccine', u'always_empty': u'', u'form': u'INJ', u'brand': u'ENIVAC HB MCG', u'strength_3': u'', u'company': u'Panacea', u'unit': u''}

-- line #16351
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200MCG', u'strength_2': u'', u'substance': u'Hepatitis B Vaccine', u'always_empty': u'', u'form': u'V', u'brand': u'ENIVAC HB MULTIDOSE', u'strength_3': u'', u'company': u'Panacea', u'unit': u''}

-- line #16352
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.5MCG', u'strength_2': u'0.5ML', u'substance': u'Hepatitis B Vaccine', u'always_empty': u'', u'form': u'', u'brand': u'ENIVAC-HB (PEAD)', u'strength_3': u'', u'company': u'Panacea', u'unit': u''}

-- line #16353
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10MCG', u'strength_2': u'', u'substance': u'Hepatitis B Vaccine', u'always_empty': u'', u'form': u'', u'brand': u'ENIVAC-HB SAFSY', u'strength_3': u'', u'company': u'Panacea', u'unit': u''}

-- line #16354
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20MCG', u'strength_2': u'', u'substance': u'Hepatitis B Vaccine', u'always_empty': u'', u'form': u'', u'brand': u'ENIVAC-HB SAFSY', u'strength_3': u'', u'company': u'Panacea', u'unit': u''}

-- line #16355
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10MCG', u'strength_2': u'', u'substance': u'Hepatitis B Vaccine', u'always_empty': u'', u'form': u'INJ', u'brand': u'GENEVAC-B MCG', u'strength_3': u'', u'company': u'Serum Inst.', u'unit': u''}

-- line #16356
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20MCG', u'strength_2': u'', u'substance': u'Hepatitis B Vaccine', u'always_empty': u'', u'form': u'INJ', u'brand': u'GENEVAC-B MCG', u'strength_3': u'', u'company': u'Serum Inst.', u'unit': u''}

-- line #16357
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20MCG', u'strength_2': u'', u'substance': u'Hepatitis B Vaccine', u'always_empty': u'', u'form': u'V', u'brand': u'GENEVAC-B MCG', u'strength_3': u'', u'company': u'Serum Inst.', u'unit': u''}

-- line #16358
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20MCG', u'strength_2': u'ML', u'substance': u'Hepatitis B Vaccine', u'always_empty': u'', u'form': u'V', u'brand': u'GENEVAC-B MCG', u'strength_3': u'', u'company': u'Serum Inst.', u'unit': u''}

-- line #16359
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10MCG', u'strength_2': u'', u'substance': u'Hepatitis B Vaccine', u'always_empty': u'', u'form': u'VAC MCG INJ', u'brand': u'HB', u'strength_3': u'', u'company': u'Zydus', u'unit': u''}

-- line #16360
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20MCG', u'strength_2': u'', u'substance': u'Hepatitis B Vaccine', u'always_empty': u'', u'form': u'VAC MCG INJ', u'brand': u'HB', u'strength_3': u'', u'company': u'Zydus', u'unit': u''}

-- line #16361
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20MCG', u'strength_2': u'', u'substance': u'Hepatitis B Vaccine', u'always_empty': u'', u'form': u'VAC MULTIDOSE V', u'brand': u'HB', u'strength_3': u'', u'company': u'Zydus', u'unit': u''}

-- line #16362
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3MCG', u'strength_2': u'', u'substance': u'Hepatitis B Vaccine', u'always_empty': u'', u'form': u'INJ', u'brand': u'HEPACCINE-B', u'strength_3': u'', u'company': u'Alkem', u'unit': u''}

-- line #16363
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100MCG', u'strength_2': u'', u'substance': u'Hepatitis B Vaccine', u'always_empty': u'', u'form': u'INJ', u'brand': u'HEPAGEN-PLUS MCG', u'strength_3': u'', u'company': u'Vhb', u'unit': u''}

-- line #16364
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10MCG', u'strength_2': u'', u'substance': u'Hepatitis B Vaccine', u'always_empty': u'', u'form': u'INJ', u'brand': u'HEPAGEN-PLUS MCG', u'strength_3': u'', u'company': u'Vhb', u'unit': u''}

-- line #16365
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200MCG', u'strength_2': u'', u'substance': u'Hepatitis B Vaccine', u'always_empty': u'', u'form': u'INJ', u'brand': u'HEPAGEN-PLUS MCG', u'strength_3': u'', u'company': u'Vhb', u'unit': u''}

-- line #16366
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20MCG', u'strength_2': u'', u'substance': u'Hepatitis B Vaccine', u'always_empty': u'', u'form': u'INJ', u'brand': u'HEPAGEN-PLUS MCG', u'strength_3': u'', u'company': u'Vhb', u'unit': u''}

-- line #16367
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10MCG', u'strength_2': u'', u'substance': u'Hepatitis B Vaccine', u'always_empty': u'', u'form': u'INJ', u'brand': u'HEPASHIELD MCG', u'strength_3': u'', u'company': u'Pfizer', u'unit': u''}

-- line #16368
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20MCG', u'strength_2': u'', u'substance': u'Hepatitis B Vaccine', u'always_empty': u'', u'form': u'INJ', u'brand': u'HEPASHIELD MCG', u'strength_3': u'', u'company': u'Pfizer', u'unit': u''}

-- line #16369
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20MCG', u'strength_2': u'ML', u'substance': u'Hepatitis B Vaccine', u'always_empty': u'', u'form': u'V', u'brand': u'HEPASHIELD MCG', u'strength_3': u'', u'company': u'Pfizer', u'unit': u''}

-- line #16370
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100MCG', u'strength_2': u'', u'substance': u'Hepatitis B Vaccine', u'always_empty': u'', u'form': u'INJ', u'brand': u'HEPAVAX-B MCG', u'strength_3': u'', u'company': u'Vhb', u'unit': u''}

-- line #16371
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10MCG', u'strength_2': u'', u'substance': u'Hepatitis B Vaccine', u'always_empty': u'', u'form': u'INJ', u'brand': u'HEPAVAX-B MCG', u'strength_3': u'', u'company': u'Vhb', u'unit': u''}

-- line #16372
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20MCG', u'strength_2': u'', u'substance': u'Hepatitis B Vaccine', u'always_empty': u'', u'form': u'INJ', u'brand': u'HEPAVAX-B MCG', u'strength_3': u'', u'company': u'Vhb', u'unit': u''}

-- line #16373
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5MCG', u'strength_2': u'', u'substance': u'Hepatitis B Vaccine', u'always_empty': u'', u'form': u'INJ', u'brand': u'HEPAVAX-B MCG', u'strength_3': u'', u'company': u'Vhb', u'unit': u''}

-- line #16374
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20MCG', u'strength_2': u'', u'substance': u'Hepatitis B Vaccine', u'always_empty': u'', u'form': u'INJ', u'brand': u'HEPPACINE-B', u'strength_3': u'', u'company': u'Bharat S.', u'unit': u''}

-- line #16375
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20MCG', u'strength_2': u'ML(PURIFIED HBSAG)', u'substance': u'Hepatitis B Vaccine', u'always_empty': u'', u'form': u'', u'brand': u'HIVAC-B', u'strength_3': u'', u'company': u'HIND. LATEX', u'unit': u''}

-- line #16376
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'HEPATITIS B SURFACE ANTIGEN PROTEIN 20MCG', u'strength_2': u'ML AND 10MCG', u'substance': u'Hepatitis B Vaccine', u'always_empty': u'', u'form': u'INJ', u'brand': u'INVAC-B', u'strength_3': u'0.5ML', u'company': u'INTAS', u'unit': u''}

-- line #16377
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10MCG', u'strength_2': u'', u'substance': u'Hepatitis B Vaccine', u'always_empty': u'', u'form': u'VACCINE', u'brand': u'LG EUVAX-B', u'strength_3': u'', u'company': u'Lglsi', u'unit': u''}

-- line #16378
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100MCG', u'strength_2': u'', u'substance': u'Hepatitis B Vaccine', u'always_empty': u'', u'form': u'VACC', u'brand': u'LG EUVAX-B', u'strength_3': u'', u'company': u'Lglsi', u'unit': u''}

-- line #16379
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200MCG', u'strength_2': u'', u'substance': u'Hepatitis B Vaccine', u'always_empty': u'', u'form': u'VACC', u'brand': u'LG EUVAX-B', u'strength_3': u'', u'company': u'Lglsi', u'unit': u''}

-- line #16380
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20MCG', u'strength_2': u'', u'substance': u'Hepatitis B Vaccine', u'always_empty': u'', u'form': u'VACC', u'brand': u'LG EUVAX-B', u'strength_3': u'', u'company': u'Lglsi', u'unit': u''}

-- line #16381
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Hepatitis B Vaccine', u'always_empty': u'', u'form': u'INJ', u'brand': u'REVAC-B', u'strength_3': u'', u'company': u'Intas', u'unit': u''}

-- line #16382
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Hepatitis B Vaccine', u'always_empty': u'', u'form': u'INJ', u'brand': u'REVACE -B', u'strength_3': u'', u'company': u'Bharat Bio.', u'unit': u''}

-- line #16383
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Hepatitis B Vaccine', u'always_empty': u'', u'form': u'V', u'brand': u'REVACE -B', u'strength_3': u'', u'company': u'Bharat Bio.', u'unit': u''}

-- line #16384
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIRHES 6 (NIRLIFE HEALTH)',
	'HETASTARCH',
	'INJ',
	gm.nullify_empty_string('6')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIRHES 6 (NIRLIFE HEALTH)'
);

-- line #16385
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIRHES 6 (NIRLIFE HEALTH)',
	'HETASTARCH',
	'INJ',
	gm.nullify_empty_string('6')::numeric,
	'%/10'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIRHES 6 (NIRLIFE HEALTH)'
);

-- line #16386
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BELL HOMATROPINE 1 (Bell Ph.)',
	'Homatropine',
	'EYE DPS',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BELL HOMATROPINE 1 (Bell Ph.)'
);

-- line #16387
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BELL HOMATROPINE 2 (Bell Ph.)',
	'Homatropine',
	'F. DPS',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BELL HOMATROPINE 2 (Bell Ph.)'
);

-- line #16388
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I', u'strength_2': u'', u'substance': u'Home ovulation test', u'always_empty': u'', u'form': u'', u'brand': u'CLEARPLAN TEST', u'strength_3': u'', u'company': u'J.&J.', u'unit': u''}

-- line #16389
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBA % 20 (Life Med.)',
	'Human Albumin',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBA % 20 (Life Med.)'
);

-- line #16390
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBUBET 20 (BIOCON LTD.)',
	'Human Albumin',
	'VIAL',
	gm.nullify_empty_string('20')::numeric,
	'%(HUMAN SERUM ALBUMIN)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBUBET 20 (BIOCON LTD.)'
);

-- line #16391
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBUCEL 20 (INTAS)',
	'Human Albumin',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBUCEL 20 (INTAS)'
);

-- line #16392
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBUDAC % 20 (Zydus A.)',
	'Human Albumin',
	'INJ(100)',
	gm.nullify_empty_string('20')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBUDAC % 20 (Zydus A.)'
);

-- line #16393
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBUDAC % 20 (Zydus A.)',
	'Human Albumin',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBUDAC % 20 (Zydus A.)'
);

-- line #16394
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBUMED 5 (Medispan)',
	'Human Albumin',
	'INF',
	gm.nullify_empty_string('5')::numeric,
	'%/20'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBUMED 5 (Medispan)'
);

-- line #16395
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBUMEON 20 (Zydus Bio.)',
	'Human Albumin',
	'V',
	gm.nullify_empty_string('20')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBUMEON 20 (Zydus Bio.)'
);

-- line #16396
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBUMINA UMANA 20 (Trans Ph.)',
	'Human Albumin',
	'VIAL',
	gm.nullify_empty_string('20')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBUMINA UMANA 20 (Trans Ph.)'
);

-- line #16397
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBUMIN % 20 (Bharat S.)',
	'Human Albumin',
	'INF',
	gm.nullify_empty_string('20')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBUMIN % 20 (Bharat S.)'
);

-- line #16398
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBUPAN 20 (Panacea)',
	'Human Albumin',
	'V',
	gm.nullify_empty_string('20')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBUPAN 20 (Panacea)'
);

-- line #16399
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBUREL % 20 (Reliance Life)',
	'Human Albumin',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBUREL % 20 (Reliance Life)'
);

-- line #16400
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBUREL % 5 (Reliance Life)',
	'Human Albumin',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBUREL % 5 (Reliance Life)'
);

-- line #16401
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HESTAR % 10 (Claris L.)',
	'Human Albumin',
	'INF',
	gm.nullify_empty_string('10')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HESTAR % 10 (Claris L.)'
);

-- line #16402
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HESTAR % 3 (Claris L.)',
	'Human Albumin',
	'INF',
	gm.nullify_empty_string('3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HESTAR % 3 (Claris L.)'
);

-- line #16403
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HESTAR % 6 (Claris L.)',
	'Human Albumin',
	'INF',
	gm.nullify_empty_string('6')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HESTAR % 6 (Claris L.)'
);

-- line #16404
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Human Albumin', u'always_empty': u'', u'form': u'', u'brand': u'HUMAN ALBUMIN', u'strength_3': u'', u'company': u'GRIFOLS', u'unit': u''}

-- line #16405
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HUMAN ALBUMIN 20 (Curewel)',
	'Human Albumin',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HUMAN ALBUMIN 20 (Curewel)'
);

-- line #16406
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HUMIN 20 (Claris L.)',
	'Human Albumin',
	'V',
	gm.nullify_empty_string('20')::numeric,
	'%(10G)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HUMIN 20 (Claris L.)'
);

-- line #16407
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'Human Albumin', u'always_empty': u'', u'form': u'', u'brand': u'HUMIN-V G', u'strength_3': u'', u'company': u'Claris L.', u'unit': u'%(20G)'}

-- line #16408
-- ignoring line: field [strength_1] not numeric: >>>100 UNITS OF BOTULINUM TOXINE TYPE A O.5<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100 UNITS OF BOTULINUM TOXINE TYPE A O.5', u'strength_2': u'', u'substance': u'Human Albumin', u'always_empty': u'', u'form': u'INJ', u'brand': u'NEURONOX', u'strength_3': u'', u'company': u'Ranbaxy', u'unit': u'OF ALBUMIN (HUMAN) 0.9'}

-- line #16409
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'300MCG', u'strength_2': u'', u'substance': u'Human Anti-D Immunoglobulin', u'always_empty': u'', u'form': u'VACCINE', u'brand': u'ANTI-D', u'strength_3': u'', u'company': u'Zydus Cadila', u'unit': u''}

-- line #16410
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'300MCG', u'strength_2': u'', u'substance': u'Human Anti-D Immunoglobulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'IMMUNO-RHO MCG', u'strength_3': u'', u'company': u'United Bio.', u'unit': u''}

-- line #16411
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'300MCG', u'strength_2': u'', u'substance': u'Human Anti-D Immunoglobulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'MATERGAM-P MCG', u'strength_3': u'', u'company': u'Zydus Bio.', u'unit': u''}

-- line #16412
-- ignoring line: field [strength_1] not numeric: >>>IG G ANTI-RHO (D) 50MCG (6<<<
-- {u'list_of_values_of_unknown_fields': [u' mg/ML', u'POLYSORBATE 80 0.01 ', u' % THIMEROSAL 0.003 ', u' %', u'GLYCINE 15 ', u' mg/1ML', u'', u'', u''], u'strength_1': u'IG G ANTI-RHO (D) 50MCG (6', u'strength_2': u'', u'substance': u'Human Anti-D Immunoglobulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'MICRHOGAM UF', u'strength_3': u'', u'company': u'J.&J.', u'unit': u'% +/- 1'}

-- line #16413
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250MCG', u'strength_2': u'', u'substance': u'Human Anti-D Immunoglobulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'PARTOBULIN MCG', u'strength_3': u'', u'company': u'Neu-Foreva', u'unit': u''}

-- line #16414
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1250IU.', u'strength_2': u'', u'substance': u'Human Anti-D Immunoglobulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'PORTOBULLIN', u'strength_3': u'', u'company': u'Neu-Foreva', u'unit': u''}

-- line #16415
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'300MCG', u'strength_2': u'', u'substance': u'Human Anti-D Immunoglobulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'RHESUMAN', u'strength_3': u'', u'company': u'Cadila Hc.', u'unit': u''}

-- line #16416
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'300MCG', u'strength_2': u'2ML', u'substance': u'Human Anti-D Immunoglobulin', u'always_empty': u'', u'form': u'', u'brand': u'RHESUMEN PFS', u'strength_3': u'', u'company': u'Cadila Hc.', u'unit': u''}

-- line #16417
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'150MCG(MONOCLONAL ANTI-D)', u'strength_2': u'', u'substance': u'Human Anti-D Immunoglobulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'RHOCLONE MCG', u'strength_3': u'', u'company': u'Bharat S.', u'unit': u''}

-- line #16418
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'300MCG (MONOCLONAL ANTI-D)', u'strength_2': u'', u'substance': u'Human Anti-D Immunoglobulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'RHOCLONE MCG', u'strength_3': u'', u'company': u'Bharat S.', u'unit': u''}

-- line #16419
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'300MCG', u'strength_2': u'', u'substance': u'Human Anti-D Immunoglobulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'RHOGAM MCG', u'strength_3': u'', u'company': u'J.& J.', u'unit': u''}

-- line #16420
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'V', u'brand': u'CARLOVA', u'strength_3': u'', u'company': u'Cadila Ph.', u'unit': u''}

-- line #16421
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'CHORAGON', u'strength_3': u'', u'company': u'Ferring Ph.', u'unit': u''}

-- line #16422
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'CHORIOLIFE IU', u'strength_3': u'', u'company': u'Life Med.', u'unit': u''}

-- line #16423
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'CHORIOLIFE IU', u'strength_3': u'', u'company': u'Life Med.', u'unit': u''}

-- line #16424
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'CHORIOLIFE IU', u'strength_3': u'', u'company': u'Life Med.', u'unit': u''}

-- line #16425
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'CHORIOLIFE IU', u'strength_3': u'', u'company': u'Life Med.', u'unit': u''}

-- line #16426
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'CHORIOMON IU', u'strength_3': u'', u'company': u'Panacea', u'unit': u''}

-- line #16427
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'CHORIOMON IU', u'strength_3': u'', u'company': u'Panacea', u'unit': u''}

-- line #16428
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'CHORIOTEC', u'strength_3': u'', u'company': u'United Bio.', u'unit': u''}

-- line #16429
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'CHORIOTEC', u'strength_3': u'', u'company': u'United Bio.', u'unit': u''}

-- line #16430
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'CHORIOTEC', u'strength_3': u'', u'company': u'United Bio.', u'unit': u''}

-- line #16431
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'CHORIOTON-INGA', u'strength_3': u'', u'company': u'Inga', u'unit': u''}

-- line #16432
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'CORION IU', u'strength_3': u'', u'company': u'Win-Medicare', u'unit': u''}

-- line #16433
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'CORION IU', u'strength_3': u'', u'company': u'Win-Medicare', u'unit': u''}

-- line #16434
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'CORION IU', u'strength_3': u'', u'company': u'Win-Medicare', u'unit': u''}

-- line #16435
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'CORION IU', u'strength_3': u'', u'company': u'Win-Medicare', u'unit': u''}

-- line #16436
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'CORLOVA', u'strength_3': u'', u'company': u'Cadila', u'unit': u''}

-- line #16437
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'HP INJ', u'brand': u'EEMA', u'strength_3': u'', u'company': u'Corona', u'unit': u''}

-- line #16438
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'HP IU', u'brand': u'EEMA', u'strength_3': u'', u'company': u'Corona', u'unit': u''}

-- line #16439
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2000IU.(HCG)', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'VIAL', u'brand': u'ELGIFT-K', u'strength_3': u'', u'company': u'Lglsi', u'unit': u''}

-- line #16440
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU.(HCG)', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'VIAL', u'brand': u'ELGIFT-K', u'strength_3': u'', u'company': u'Lglsi', u'unit': u''}

-- line #16441
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'FERGONAD-C', u'strength_3': u'', u'company': u'FERON LS', u'unit': u''}

-- line #16442
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'FERGONAD-C', u'strength_3': u'', u'company': u'FERON LS', u'unit': u''}

-- line #16443
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'FERTIGYN IU', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #16444
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'FERTIGYN IU', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #16445
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'FERTIGYN IU', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #16446
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'FERTIGYN IU', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #16447
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'GONOTROP-C IU', u'strength_3': u'', u'company': u'Modi Mundi', u'unit': u''}

-- line #16448
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'GONOTROP-C IU', u'strength_3': u'', u'company': u'Modi Mundi', u'unit': u''}

-- line #16449
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'GONOTROP-C IU', u'strength_3': u'', u'company': u'Modi Mundi', u'unit': u''}

-- line #16450
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'GONOTROP-C IU', u'strength_3': u'', u'company': u'Modi Mundi', u'unit': u''}

-- line #16451
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'HCGCUTE IU', u'strength_3': u'', u'company': u'ACE PH.', u'unit': u''}

-- line #16452
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'HCG-SP', u'strength_3': u'', u'company': u'Samarth', u'unit': u''}

-- line #16453
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'HCG-SP', u'strength_3': u'', u'company': u'Samarth', u'unit': u''}

-- line #16454
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'HCG-SP', u'strength_3': u'', u'company': u'Samarth', u'unit': u''}

-- line #16455
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10000IU', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'HUCHOGON', u'strength_3': u'', u'company': u'BIOSENA', u'unit': u''}

-- line #16456
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'HUCHOGON', u'strength_3': u'', u'company': u'BIOSENA', u'unit': u''}

-- line #16457
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'HUCHOGON', u'strength_3': u'', u'company': u'BIOSENA', u'unit': u''}

-- line #16458
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'HUCOG IU', u'strength_3': u'', u'company': u'Bharat S.', u'unit': u''}

-- line #16459
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'HUCOG IU', u'strength_3': u'', u'company': u'Bharat S.', u'unit': u''}

-- line #16460
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'HUCOG IU', u'strength_3': u'', u'company': u'Bharat S.', u'unit': u''}

-- line #16461
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'VIAL', u'brand': u'HUMUNIS', u'strength_3': u'', u'company': u'NEISS', u'unit': u''}

-- line #16462
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'INTAS HCG', u'strength_3': u'', u'company': u'INTAS', u'unit': u''}

-- line #16463
-- ignoring line: field [strength_1] not numeric: >>>2000IU. +MANNITOL 12<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2000IU. +MANNITOL 12', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'INTAS HCG', u'strength_3': u'', u'company': u'INTAS', u'unit': u'mg'}

-- line #16464
-- ignoring line: field [strength_1] not numeric: >>>5000IU. +MANNITOL 12<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU. +MANNITOL 12', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'INTAS HCG', u'strength_3': u'', u'company': u'INTAS', u'unit': u'mg'}

-- line #16465
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'IVF-C IU', u'strength_3': u'', u'company': u'Biochem', u'unit': u''}

-- line #16466
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'IVF-C IU', u'strength_3': u'', u'company': u'Biochem', u'unit': u''}

-- line #16467
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'HP', u'brand': u'KORAGON', u'strength_3': u'', u'company': u'Ferring Ph.', u'unit': u''}

-- line #16468
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000IU', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'VIAL', u'brand': u'LG IVF-C', u'strength_3': u'', u'company': u'Lglsi', u'unit': u''}

-- line #16469
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'VIAL', u'brand': u'LG IVF-C', u'strength_3': u'', u'company': u'Lglsi', u'unit': u''}

-- line #16470
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'LIFE IU', u'strength_3': u'', u'company': u'Solvay Ph.', u'unit': u''}

-- line #16471
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'LIFE IU', u'strength_3': u'', u'company': u'Solvay Ph.', u'unit': u''}

-- line #16472
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'LIFE IU', u'strength_3': u'', u'company': u'Solvay Ph.', u'unit': u''}

-- line #16473
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'AMP', u'brand': u'LUPI HCG', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #16474
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'AMP', u'brand': u'LUPI HCG', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #16475
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'AMP', u'brand': u'LUPI HCG', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #16476
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10000IU(RECONSTITUTE WITH 2ML OF SODIUM CHLORIDE INJ (0.9', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'', u'brand': u'LUPI HCG (HP)', u'strength_3': u'', u'company': u'Lupin', u'unit': u'% W/V)'}

-- line #16477
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2000IU(RECONSTITUTE WITH 2ML OF SODIUM CHLORIDE INJ (0.9', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'', u'brand': u'LUPI HCG (HP)', u'strength_3': u'', u'company': u'Lupin', u'unit': u'% W/V)'}

-- line #16478
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU(RECONSTITUTE WITH 2ML OF SODIUM CHLORIDE INJ (0.9', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'', u'brand': u'LUPI HCG (HP)', u'strength_3': u'', u'company': u'Lupin', u'unit': u'% W/V)'}

-- line #16479
-- ignoring line: field [strength_1] not numeric: >>>1000IU.(DISODIUM HYDROGEN ORTHOPHOSPHATE IP AS BUFFER<<<
-- {u'list_of_values_of_unknown_fields': [u' %W/V)IP)', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000IU.(DISODIUM HYDROGEN ORTHOPHOSPHATE IP AS BUFFER', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'HP IU', u'brand': u'MATERNA HCG', u'strength_3': u'', u'company': u'Emcure', u'unit': u'SODIUM DIHYDROGEN ORTHOPHOSPHATE IP AS BUFFER'}

-- line #16480
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'MATERNA HCG', u'strength_3': u'', u'company': u'Emcure', u'unit': u''}

-- line #16481
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'MATERNA HCG', u'strength_3': u'', u'company': u'Emcure', u'unit': u''}

-- line #16482
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'ORIGIN', u'strength_3': u'', u'company': u'Uni-Sank.', u'unit': u''}

-- line #16483
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'ORIGIN', u'strength_3': u'', u'company': u'Uni-Sank.', u'unit': u''}

-- line #16484
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'OVIDAC IU', u'strength_3': u'', u'company': u'Zydus Cadila', u'unit': u''}

-- line #16485
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'OVIDAC IU', u'strength_3': u'', u'company': u'Zydus Cadila', u'unit': u''}

-- line #16486
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250MCG(RECOMBINANT HCG)', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'OVIDREL', u'strength_3': u'', u'company': u'Serum Inst.', u'unit': u''}

-- line #16487
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'HP INJ', u'brand': u'OVIFER', u'strength_3': u'', u'company': u'Gufic Bio.', u'unit': u''}

-- line #16488
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'AMP', u'brand': u'OVIGYN IU', u'strength_3': u'', u'company': u'DABUR PH.', u'unit': u''}

-- line #16489
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10000IU', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'OVULATE-C', u'strength_3': u'', u'company': u'Vhb', u'unit': u''}

-- line #16490
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2000IU', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'OVULATE-C', u'strength_3': u'', u'company': u'Vhb', u'unit': u''}

-- line #16491
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'OVULATE-C', u'strength_3': u'', u'company': u'Vhb', u'unit': u''}

-- line #16492
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'HP ,000 INJ', u'brand': u'OVUTRIG', u'strength_3': u'', u'company': u'Vhb', u'unit': u''}

-- line #16493
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'HP INJ', u'brand': u'OVUTRIG', u'strength_3': u'', u'company': u'Vhb', u'unit': u''}

-- line #16494
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'HP INJ', u'brand': u'OVUTRIG', u'strength_3': u'', u'company': u'Vhb', u'unit': u''}

-- line #16495
-- ignoring line: field [strength_1] not numeric: >>>10000IU.(MANITOL 10<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10000IU.(MANITOL 10', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'HP IU', u'brand': u'OVYMAX', u'strength_3': u'', u'company': u'Vhb', u'unit': u'mg)'}

-- line #16496
-- ignoring line: field [strength_1] not numeric: >>>2000IU.(MANITOL 10<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2000IU.(MANITOL 10', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'HP IU', u'brand': u'OVYMAX', u'strength_3': u'', u'company': u'Vhb', u'unit': u'mg)'}

-- line #16497
-- ignoring line: field [strength_1] not numeric: >>>5000IU.(MANITOL 10<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU.(MANITOL 10', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'HP IU', u'brand': u'OVYMAX', u'strength_3': u'', u'company': u'Vhb', u'unit': u'mg)'}

-- line #16498
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'PREGNYL IU', u'strength_3': u'', u'company': u'Infar', u'unit': u''}

-- line #16499
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'PREGNYL IU', u'strength_3': u'', u'company': u'Infar', u'unit': u''}

-- line #16500
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'PROFASI IU', u'strength_3': u'', u'company': u'Serum Inst.', u'unit': u''}

-- line #16501
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'PROFASI IU', u'strength_3': u'', u'company': u'Serum Inst.', u'unit': u''}

-- line #16502
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'PROFASI IU', u'strength_3': u'', u'company': u'Serum Inst.', u'unit': u''}

-- line #16503
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'PROFERTI-C', u'strength_3': u'', u'company': u'CH.Bhagat', u'unit': u''}

-- line #16504
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'PROFERTI-C', u'strength_3': u'', u'company': u'CH.Bhagat', u'unit': u''}

-- line #16505
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'PROFERTI-C', u'strength_3': u'', u'company': u'CH.Bhagat', u'unit': u''}

-- line #16506
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'', u'brand': u'PROFICENT-2000 IU', u'strength_3': u'', u'company': u'Alkem', u'unit': u''}

-- line #16507
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'', u'brand': u'PROFICENT-5000 IU', u'strength_3': u'', u'company': u'Alkem', u'unit': u''}

-- line #16508
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'PROLIGON', u'strength_3': u'', u'company': u'Kee Ph.', u'unit': u''}

-- line #16509
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'PROLIGON', u'strength_3': u'', u'company': u'Kee Ph.', u'unit': u''}

-- line #16510
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'PROVIGIL', u'strength_3': u'', u'company': u'Svizera', u'unit': u''}

-- line #16511
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'PROVIGIL', u'strength_3': u'', u'company': u'Svizera', u'unit': u''}

-- line #16512
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'PROVIGIL', u'strength_3': u'', u'company': u'Svizera', u'unit': u''}

-- line #16513
-- ignoring line: field [strength_1] not numeric: >>>HIGHLY PURIFIED HUMAN CHORIONIC GONADTROPHIN IP 10000 IU<<<
-- {u'list_of_values_of_unknown_fields': [u'POTASSIUM DIHYDROGEN ORTHOPHOSPHATE BP 0.46 ', u' mg', u'DIPOTASSIUM HYDROGEN ORTHOPHOSPHATE BP 0.36  ', u' mg', u'', u'', u'', u'', u''], u'strength_1': u'HIGHLY PURIFIED HUMAN CHORIONIC GONADTROPHIN IP 10000 IU', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'PROVIGIL IU', u'strength_3': u'', u'company': u'Svizera', u'unit': u'MANNITOL IP 12'}

-- line #16514
-- ignoring line: field [strength_1] not numeric: >>>HIGHLY PURIFIED HUMAN CHORIONIC GONADTROPHIN IP 2000 IU<<<
-- {u'list_of_values_of_unknown_fields': [u'POTASSIUM DIHYDROGEN ORTHOPHOSPHATE BP 0.46 ', u' mg', u'DIPOTASSIUM HYDROGEN ORTHOPHOSPHATE BP 0.36  ', u' mg', u'', u'', u'', u'', u''], u'strength_1': u'HIGHLY PURIFIED HUMAN CHORIONIC GONADTROPHIN IP 2000 IU', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'PROVIGIL IU', u'strength_3': u'', u'company': u'Svizera', u'unit': u'MANNITOL IP 12'}

-- line #16515
-- ignoring line: field [strength_1] not numeric: >>>HIGHLY PURIFIED HUMAN CHORIONIC GONADTROPHIN IP 5000 IU<<<
-- {u'list_of_values_of_unknown_fields': [u'POTASSIUM DIHYDROGEN ORTHOPHOSPHATE BP 0.46 ', u' mg', u'DIPOTASSIUM HYDROGEN ORTHOPHOSPHATE BP 0.36  ', u' mg', u'', u'', u'', u'', u''], u'strength_1': u'HIGHLY PURIFIED HUMAN CHORIONIC GONADTROPHIN IP 5000 IU', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'PROVIGIL IU', u'strength_3': u'', u'company': u'Svizera', u'unit': u'MANNITOL IP 12'}

-- line #16516
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2000IU.', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'HP INJ', u'brand': u'PUBERGEN', u'strength_3': u'', u'company': u'Uni-Sank.', u'unit': u''}

-- line #16517
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000IU.(WITH 2ML SOL.AMP.OF ISOTONIC SOD.CHL.SOL.)', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'PUBERGEN IU', u'strength_3': u'', u'company': u'Uni-Sank.', u'unit': u''}

-- line #16518
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2000IU(WITH 2ML SOL.AMP.OF ISOTONIC SOD.CHL.SOL.)', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'PUBERGEN IU', u'strength_3': u'', u'company': u'Uni-Sank.', u'unit': u''}

-- line #16519
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU.(WITH 2ML SOL.AMP.OF ISOTONIC SOD.CHL.SOL.)', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'PUBERGEN IU', u'strength_3': u'', u'company': u'Uni-Sank.', u'unit': u''}

-- line #16520
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10000IU(WITH 2ML SOL.AMP.OF ISOTONIC SOD.CHL.SOL.)', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'', u'brand': u'PUBERGEN IU', u'strength_3': u'', u'company': u'Uni-Sank.', u'unit': u''}

-- line #16521
-- ignoring line: field [strength_1] not numeric: >>>7500IU(+ MANNITOL 12<<<
-- {u'list_of_values_of_unknown_fields': [u'DIPOT.HYDROGEN)', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'7500IU(+ MANNITOL 12', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'PUBERGEN JO IU', u'strength_3': u'', u'company': u'Uni-Sank.', u'unit': u'mg'}

-- line #16522
-- ignoring line: field [strength_1] not numeric: >>>500IU.(+MANNITOL 12<<<
-- {u'list_of_values_of_unknown_fields': [u'DIPOT.HYDROGEN)', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500IU.(+MANNITOL 12', u'strength_2': u'', u'substance': u'Human Chorionic Gonadotrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'PUBERGEN NANO', u'strength_3': u'', u'company': u'Uni-Sank.', u'unit': u'mg'}

-- line #16523
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'HUMAN LG HIGH ANTIBODY CONTENT AGAINST CYTOMEGALOVIRUS LG (LGG) 10%', u'always_empty': u'', u'form': u'AMP', u'brand': u'CYTOTECT', u'strength_3': u'', u'company': u'Paviour Ph.', u'unit': u''}

-- line #16524
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BHARGLOB % 10 (Bharat S.)',
	'Human Normal Immunoglobulin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BHARGLOB % 10 (Bharat S.)'
);

-- line #16525
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BHARGLOB % 16.5 (Bharat S.)',
	'Human Normal Immunoglobulin',
	'INJ',
	gm.nullify_empty_string('16.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BHARGLOB % 16.5 (Bharat S.)'
);

-- line #16526
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.5G', u'strength_2': u'', u'substance': u'Human Normal Immunoglobulin', u'always_empty': u'', u'form': u'VI INJ', u'brand': u'BIAVEN', u'strength_3': u'', u'company': u'Vhb', u'unit': u''}

-- line #16527
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Human Normal Immunoglobulin', u'always_empty': u'', u'form': u'VI INJ', u'brand': u'BIAVEN', u'strength_3': u'', u'company': u'Vhb', u'unit': u''}

-- line #16528
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2.5G', u'strength_2': u'', u'substance': u'Human Normal Immunoglobulin', u'always_empty': u'', u'form': u'VI INJ', u'brand': u'BIAVEN', u'strength_3': u'', u'company': u'Vhb', u'unit': u''}

-- line #16529
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GAMAFINE % 10 (Haffkine)',
	'Human Normal Immunoglobulin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GAMAFINE % 10 (Haffkine)'
);

-- line #16530
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GAMAGLOBIN 16.5 (Zydus A.)',
	'Human Normal Immunoglobulin',
	'INJ',
	gm.nullify_empty_string('16.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GAMAGLOBIN 16.5 (Zydus A.)'
);

-- line #16531
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GAMA-GLOB 6.5 (Zydus A.)',
	'Human Normal Immunoglobulin',
	'INJ',
	gm.nullify_empty_string('6.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GAMA-GLOB 6.5 (Zydus A.)'
);

-- line #16532
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.5G', u'strength_2': u'', u'substance': u'Human Normal Immunoglobulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'GAMMA IV', u'strength_3': u'', u'company': u'Bharat S.', u'unit': u''}

-- line #16533
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2.5G', u'strength_2': u'', u'substance': u'Human Normal Immunoglobulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'GAMMA IV', u'strength_3': u'', u'company': u'Bharat S.', u'unit': u''}

-- line #16534
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5G', u'strength_2': u'', u'substance': u'Human Normal Immunoglobulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'GAMMA IV', u'strength_3': u'', u'company': u'Bharat S.', u'unit': u''}

-- line #16535
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5GM(IMMUNOGLOBULIN G)', u'strength_2': u'', u'substance': u'Human Normal Immunoglobulin', u'always_empty': u'', u'form': u'', u'brand': u'GAMMAVEN', u'strength_3': u'', u'company': u'Intas', u'unit': u''}

-- line #16536
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'HUMAN IMMUNOGLOBULIN', u'strength_2': u'', u'substance': u'Human Normal Immunoglobulin', u'always_empty': u'', u'form': u'VIAL', u'brand': u'GENEXGLOB', u'strength_3': u'', u'company': u'UNIMARK REM.', u'unit': u''}

-- line #16537
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLOBUCEL 5 (CELESTIAL (INTAS))',
	'Human Normal Immunoglobulin',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'% (INTRAVENOUS)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLOBUCEL 5 (CELESTIAL (INTAS))'
);

-- line #16538
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Human Normal Immunoglobulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'IMMUNOREL %', u'strength_3': u'', u'company': u'Reliance Life', u'unit': u''}

-- line #16539
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G(EXTRA PURIF.)', u'strength_2': u'', u'substance': u'Human Normal Immunoglobulin', u'always_empty': u'', u'form': u'', u'brand': u'IVIGLOB EX-V G', u'strength_3': u'', u'company': u'Vhb', u'unit': u''}

-- line #16540
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5G', u'strength_2': u'100ML(EXTRA PURIF.)', u'substance': u'Human Normal Immunoglobulin', u'always_empty': u'', u'form': u'', u'brand': u'IVIGLOB EX-V G', u'strength_3': u'', u'company': u'Vhb', u'unit': u''}

-- line #16541
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.5G(EXTRA PURIF.)', u'strength_2': u'', u'substance': u'Human Normal Immunoglobulin', u'always_empty': u'', u'form': u'EX V', u'brand': u'IVIGLOB', u'strength_3': u'', u'company': u'Vhb', u'unit': u''}

-- line #16542
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.25G', u'strength_2': u'25ML', u'substance': u'Human Normal Immunoglobulin', u'always_empty': u'', u'form': u'V', u'brand': u'IVIGLOB -G', u'strength_3': u'', u'company': u'Vhb', u'unit': u''}

-- line #16543
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2.5G', u'strength_2': u'25ML', u'substance': u'Human Normal Immunoglobulin', u'always_empty': u'', u'form': u'V', u'brand': u'IVIGLOB', u'strength_3': u'', u'company': u'Vhb', u'unit': u''}

-- line #16544
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5G', u'strength_2': u'25ML', u'substance': u'Human Normal Immunoglobulin', u'always_empty': u'', u'form': u'V', u'brand': u'IVIGLOB', u'strength_3': u'', u'company': u'Vhb', u'unit': u''}

-- line #16545
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IVNEX 5 (BIOCON LTD.)',
	'Human Normal Immunoglobulin',
	'VIAL',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IVNEX 5 (BIOCON LTD.)'
);

-- line #16546
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Human Normal Immunoglobulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'OCTAGAM', u'strength_3': u'', u'company': u'Medispan', u'unit': u''}

-- line #16547
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'HYALURONIC ACID SODIUM SALT', u'always_empty': u'', u'form': u'', u'brand': u'HYALGAN', u'strength_3': u'', u'company': u'Lupin', u'unit': u'mg'}

-- line #16548
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IAL SYSTEM 11 (Ranbaxy)',
	'HYALURONIC ACID SODIUM SALT',
	'INJ',
	gm.nullify_empty_string('11')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IAL SYSTEM 11 (Ranbaxy)'
);

-- line #16549
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IAL SYSTEM 20 (Ranbaxy)',
	'HYALURONIC ACID SODIUM SALT',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IAL SYSTEM 20 (Ranbaxy)'
);

-- line #16550
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'HYALURONIC ACID SODIUM SALT', u'always_empty': u'', u'form': u'', u'brand': u'RESTYLANE', u'strength_3': u'', u'company': u"Dr.Reddy''S", u'unit': u'mg/ML(INJ. IMPLANT)'}

-- line #16551
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'HYALURONIC ACID SODIUM SALT', u'always_empty': u'', u'form': u'', u'brand': u'RESTYLANE LIPP', u'strength_3': u'', u'company': u"Dr.Reddy''S", u'unit': u'mg/ML(INJ. IMPLANT)'}

-- line #16552
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'HYALURONIC ACID SODIUM SALT', u'always_empty': u'', u'form': u'', u'brand': u'RESTYLANE PERLANE', u'strength_3': u'', u'company': u"Dr.Reddy''S", u'unit': u'mg/ML(INJ. IMPLANT)'}

-- line #16553
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'HYALURONIC ACID SODIUM SALT', u'always_empty': u'', u'form': u'', u'brand': u'RESTYLANE TOUCH', u'strength_3': u'', u'company': u"Dr.Reddy''S", u'unit': u'mg/ML(INJ. IMPLANT)'}

-- line #16554
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESTYLANE 20 (Dr.Reddy''S)',
	'HYALURONIC ACID SODIUM SALT',
	'VITAL',
	gm.nullify_empty_string('20')::numeric,
	'mg/ML(INJ. IMPLANT)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESTYLANE 20 (Dr.Reddy''S)'
);

-- line #16555
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIO-HYALUR PLUS 14 (Bio-Tech Opth.)',
	'Hyaluronidase',
	'EYE DPS',
	gm.nullify_empty_string('14')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIO-HYALUR PLUS 14 (Bio-Tech Opth.)'
);

-- line #16556
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500IU.', u'strength_2': u'', u'substance': u'Hyaluronidase', u'always_empty': u'', u'form': u'INJ', u'brand': u'FACIDASE', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #16557
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500IU', u'strength_2': u'2ML', u'substance': u'Hyaluronidase', u'always_empty': u'', u'form': u'', u'brand': u'FACIDASE OPTIPEN', u'strength_3': u'', u'company': u'Milmet', u'unit': u''}

-- line #16558
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500IU.', u'strength_2': u'', u'substance': u'Hyaluronidase', u'always_empty': u'', u'form': u'INJ', u'brand': u'HINEX IU', u'strength_3': u'', u'company': u'Samarth LIFE', u'unit': u''}

-- line #16559
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500IU', u'strength_2': u'', u'substance': u'Hyaluronidase', u'always_empty': u'', u'form': u'INJ', u'brand': u'HYALURONIDASE', u'strength_3': u'', u'company': u'CH.Bhagat', u'unit': u''}

-- line #16560
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500IU.', u'strength_2': u'', u'substance': u'Hyaluronidase', u'always_empty': u'', u'form': u'INJ', u'brand': u'HYLORASE', u'strength_3': u'', u'company': u'BIOSENA', u'unit': u''}

-- line #16561
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500IU.', u'strength_2': u'', u'substance': u'Hyaluronidase', u'always_empty': u'', u'form': u'INJ', u'brand': u'HYNIDASE', u'strength_3': u'', u'company': u'Shreya', u'unit': u''}

-- line #16562
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APRESOL 25 (Ordain Hc.)',
	'HYDRALAZINE SULPH.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APRESOL 25 (Ordain Hc.)'
);

-- line #16563
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AQUAZIDE 12.5 (Sun)',
	'Hydrochlorothiazide',
	'TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AQUAZIDE 12.5 (Sun)'
);

-- line #16564
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AQUAZIDE 25 (Sun)',
	'Hydrochlorothiazide',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AQUAZIDE 25 (Sun)'
);

-- line #16565
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BPZIDE 12.5 (Stadmed)',
	'Hydrochlorothiazide',
	'TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BPZIDE 12.5 (Stadmed)'
);

-- line #16566
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BPZIDE 25 (Stadmed)',
	'Hydrochlorothiazide',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BPZIDE 25 (Stadmed)'
);

-- line #16567
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESIDREX 50 (Novartis)',
	'Hydrochlorothiazide',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESIDREX 50 (Novartis)'
);

-- line #16568
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYDRAZIDE 12.5 (Cipla)',
	'Hydrochlorothiazide',
	'TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYDRAZIDE 12.5 (Cipla)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYDRAZIDE 25 (Cipla)',
	'Hydrochlorothiazide',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYDRAZIDE 25 (Cipla)'
);

-- line #16569
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYDRIDE 12.5 (Cardicare)',
	'Hydrochlorothiazide',
	'TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYDRIDE 12.5 (Cardicare)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYDRIDE 25 (Cardicare)',
	'Hydrochlorothiazide',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYDRIDE 25 (Cardicare)'
);

-- line #16570
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYZIDE 12.5 (EAST WEST)',
	'Hydrochlorothiazide',
	'TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYZIDE 12.5 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYZIDE 25 (EAST WEST)',
	'Hydrochlorothiazide',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYZIDE 25 (EAST WEST)'
);

-- line #16571
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KLORZIDE 12.5 (Zydus Bio.)',
	'Hydrochlorothiazide',
	'TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KLORZIDE 12.5 (Zydus Bio.)'
);

-- line #16572
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KLORZIDE 25 (Zydus Bio.)',
	'Hydrochlorothiazide',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KLORZIDE 25 (Zydus Bio.)'
);

-- line #16573
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOCOID LIPO 0.1 (Elder)',
	'Hydrocortisone-17 Butyrate',
	'CRM',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOCOID LIPO 0.1 (Elder)'
);

-- line #16574
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Hydrocortisone-17 Butyrate', u'always_empty': u'', u'form': u'LOT', u'brand': u'LOCOID LIPO', u'strength_3': u'', u'company': u'Elder', u'unit': u''}

-- line #16575
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALLOCORT 1 (Bell Ph.)',
	'Hydrocortisone Acet.',
	'EYE DPS',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALLOCORT 1 (Bell Ph.)'
);

-- line #16576
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORT-H 1 (Neon)',
	'Hydrocortisone Acet.',
	'OINT',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORT-H 1 (Neon)'
);

-- line #16577
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUTISOFT 1 (Ipca)',
	'Hydrocortisone Acet.',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUTISOFT 1 (Ipca)'
);

-- line #16578
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DROCORT 1 (AGIO PH.)',
	'Hydrocortisone Acet.',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DROCORT 1 (AGIO PH.)'
);

-- line #16579
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EFCORLIN 2.5 (Gsk)',
	'Hydrocortisone Acet.',
	'PELLETS',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EFCORLIN 2.5 (Gsk)'
);

-- line #16580
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Hydrocortisone Acet.', u'always_empty': u'', u'form': u'', u'brand': u'ENTOFOAM AEROSOL', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #16581
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10', u'strength_2': u'', u'substance': u'Hydrocortisone Acet.', u'always_empty': u'', u'form': u'', u'brand': u'ENTOFOAM CANISTER', u'strength_3': u'', u'company': u'Cipla', u'unit': u'%W/W'}

-- line #16582
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYCORT 0.5 (Ind-Swift)',
	'Hydrocortisone Acet.',
	'CRM',
	gm.nullify_empty_string('0.5')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYCORT 0.5 (Ind-Swift)'
);

-- line #16583
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYDROCORT 10 (Pfiscar Ind.)',
	'Hydrocortisone Acet.',
	'CRM',
	gm.nullify_empty_string('10')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYDROCORT 10 (Pfiscar Ind.)'
);

-- line #16584
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'25', u'strength_2': u'', u'substance': u'Hydrocortisone Acet.', u'always_empty': u'', u'form': u'', u'brand': u'HYDROCORTISONE ACEINJ', u'strength_3': u'', u'company': u'Sanofi Aventis', u'unit': u'mg(+BENZYL ALCOHOL 0.9'}

-- line #16585
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LACTICARE 1 (Elder)',
	'Hydrocortisone Acet.',
	'HC LOT',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LACTICARE 1 (Elder)'
);

-- line #16586
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LACTICARE 2.5 (Elder)',
	'Hydrocortisone Acet.',
	'HC LOT',
	gm.nullify_empty_string('2.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LACTICARE 2.5 (Elder)'
);

-- line #16587
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Hydrocortisone Acet.', u'always_empty': u'', u'form': u'CRM', u'brand': u'LOCORT', u'strength_3': u'', u'company': u'Ochoa', u'unit': u''}

-- line #16588
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYCOR 1 (Eros Ph.)',
	'Hydrocortisone Acet.',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYCOR 1 (Eros Ph.)'
);

-- line #16589
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EFFICORT LIPHOPHILIC 0.127 (Galderma)',
	'Hydrocortisone',
	'CRM',
	gm.nullify_empty_string('0.127')::numeric,
	'%W/W(ACEPONATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EFFICORT LIPHOPHILIC 0.127 (Galderma)'
);

-- line #16590
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HISONE 20 (Samarth)',
	'Hydrocortisone',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HISONE 20 (Samarth)'
);

-- line #16591
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HISONE 5 (Samarth)',
	'Hydrocortisone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HISONE 5 (Samarth)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HISONE 10 (Samarth)',
	'Hydrocortisone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HISONE 10 (Samarth)'
);

-- line #16592
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYSOFT 0.127 (Ajanta Ph.)',
	'Hydrocortisone',
	'CRM',
	gm.nullify_empty_string('0.127')::numeric,
	'%W/W(ACEPONATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYSOFT 0.127 (Ajanta Ph.)'
);

-- line #16593
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCORT 100 (Solitaire)',
	'Hydrocortisone',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCORT 100 (Solitaire)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCORT 200 (Solitaire)',
	'Hydrocortisone',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCORT 200 (Solitaire)'
);

-- line #16594
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RECORLIN 20 (Chemo Bio.)',
	'Hydrocortisone',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RECORLIN 20 (Chemo Bio.)'
);

-- line #16595
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPCORLIN 100 (Cipla)',
	'Hydrocortisone Sodium Succinate',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPCORLIN 100 (Cipla)'
);

-- line #16596
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORTIS 134 (Dynamic)',
	'Hydrocortisone Sodium Succinate',
	'INJ',
	gm.nullify_empty_string('134')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORTIS 134 (Dynamic)'
);

-- line #16597
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORTISONE 100 (Jackson)',
	'Hydrocortisone Sodium Succinate',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORTISONE 100 (Jackson)'
);

-- line #16598
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORT-S 100 (Neon)',
	'Hydrocortisone Sodium Succinate',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORT-S 100 (Neon)'
);

-- line #16599
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORT-S 200 (Neon)',
	'Hydrocortisone Sodium Succinate',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORT-S 200 (Neon)'
);

-- line #16600
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORT-S 400 (Neon)',
	'Hydrocortisone Sodium Succinate',
	'INJ',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORT-S 400 (Neon)'
);

-- line #16601
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORT-S 100 (Neon)',
	'Hydrocortisone Sodium Succinate',
	'VIAL',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORT-S 100 (Neon)'
);

-- line #16602
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CRISTACORT 100 (Csc Ph.)',
	'Hydrocortisone Sodium Succinate',
	'VIAL',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CRISTACORT 100 (Csc Ph.)'
);

-- line #16603
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EFCORLIN 100 (Gsk)',
	'Hydrocortisone Sodium Succinate',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg(EQ.100'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EFCORLIN 100 (Gsk)'
);

-- line #16604
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HISONE 100 (Samarth)',
	'Hydrocortisone Sodium Succinate',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HISONE 100 (Samarth)'
);

-- line #16605
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYCORT 100 (Ind-Swift)',
	'Hydrocortisone Sodium Succinate',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYCORT 100 (Ind-Swift)'
);

-- line #16606
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYCOSON 100 (Astrazeneca)',
	'Hydrocortisone Sodium Succinate',
	'VIAL',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYCOSON 100 (Astrazeneca)'
);

-- line #16607
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYDROCORTISONE SOD SUCC 100 (HETERO HC.)',
	'Hydrocortisone Sodium Succinate',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYDROCORTISONE SOD SUCC 100 (HETERO HC.)'
);

-- line #16608
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYDROCORTISONE SOD SUCC 100 (Troikaa)',
	'Hydrocortisone Sodium Succinate',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYDROCORTISONE SOD SUCC 100 (Troikaa)'
);

-- line #16609
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYDROLIN 100 (LYKA LABS)',
	'Hydrocortisone Sodium Succinate',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYDROLIN 100 (LYKA LABS)'
);

-- line #16610
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYDROSOD SUCC100 100 (Dopson Ph.)',
	'Hydrocortisone Sodium Succinate',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYDROSOD SUCC100 100 (Dopson Ph.)'
);

-- line #16611
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYDROSODSUCC100 100 (HETERO HC.)',
	'Hydrocortisone Sodium Succinate',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg(EQ.100'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYDROSODSUCC100 100 (HETERO HC.)'
);

-- line #16612
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYDROSODSUCC100 100 (Samarth)',
	'Hydrocortisone Sodium Succinate',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYDROSODSUCC100 100 (Samarth)'
);

-- line #16613
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYDROSODSUCC400 400 (Dopson Ph.)',
	'Hydrocortisone Sodium Succinate',
	'INJ',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYDROSODSUCC400 400 (Dopson Ph.)'
);

-- line #16614
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYDROSODSUCC 200 (Dopson Ph.)',
	'Hydrocortisone Sodium Succinate',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYDROSODSUCC 200 (Dopson Ph.)'
);

-- line #16615
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HY-SONE 100 (P C INDIA)',
	'Hydrocortisone Sodium Succinate',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HY-SONE 100 (P C INDIA)'
);

-- line #16616
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYCORTIN-S 100 (HETERO HC.)',
	'Hydrocortisone Sodium Succinate',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYCORTIN-S 100 (HETERO HC.)'
);

-- line #16617
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYCORTIN-S 200 (HETERO HC.)',
	'Hydrocortisone Sodium Succinate',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYCORTIN-S 200 (HETERO HC.)'
);

-- line #16618
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MULTICORT 100 (CH.Bhagat)',
	'Hydrocortisone Sodium Succinate',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MULTICORT 100 (CH.Bhagat)'
);

-- line #16619
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Hydrocortisone Sodium Succinate', u'always_empty': u'', u'form': u'VIAL', u'brand': u'NISCORT', u'strength_3': u'', u'company': u'NEISS', u'unit': u''}

-- line #16620
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVACORT 100 (Radicura)',
	'Hydrocortisone Sodium Succinate',
	'VIAL',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVACORT 100 (Radicura)'
);

-- line #16621
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIMACORT 100 (Macleods)',
	'Hydrocortisone Sodium Succinate',
	'V',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIMACORT 100 (Macleods)'
);

-- line #16622
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIMACORT 200 (Macleods)',
	'Hydrocortisone Sodium Succinate',
	'V',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIMACORT 200 (Macleods)'
);

-- line #16623
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIMACORT 400 (Macleods)',
	'Hydrocortisone Sodium Succinate',
	'V',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIMACORT 400 (Macleods)'
);

-- line #16624
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RECORLIN 100 (Chemo Bio.)',
	'Hydrocortisone Sodium Succinate',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RECORLIN 100 (Chemo Bio.)'
);

-- line #16625
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLARIPEL PLUS 2 (Elder)',
	'Hydroquinone',
	'CRM',
	gm.nullify_empty_string('2')::numeric,
	'% & SUNSCREENS'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLARIPEL PLUS 2 (Elder)'
);

-- line #16626
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'4', u'strength_2': u'', u'substance': u'HYDROQUINONE', u'always_empty': u'', u'form': u'', u'brand': u'DEPIG-F', u'strength_3': u'', u'company': u'INTERMED', u'unit': u'%'}

-- line #16627
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2', u'strength_2': u'', u'substance': u'HYDROQUINONE', u'always_empty': u'', u'form': u'', u'brand': u'DEPIG', u'strength_3': u'', u'company': u'INTERMED', u'unit': u'%'}

-- line #16628
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESLITE 2 (Elder)',
	'Hydroquinone',
	'CRM',
	gm.nullify_empty_string('2')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESLITE 2 (Elder)'
);

-- line #16629
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUKROMA % 2 (Yash Ph.)',
	'Hydroquinone',
	'CRM',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUKROMA % 2 (Yash Ph.)'
);

-- line #16630
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUKROMA 4 (Yash Ph.)',
	'Hydroquinone',
	'CRM',
	gm.nullify_empty_string('4')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUKROMA 4 (Yash Ph.)'
);

-- line #16631
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAIRQUIN 3 (Karlin)',
	'Hydroquinone',
	'CRM',
	gm.nullify_empty_string('3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAIRQUIN 3 (Karlin)'
);

-- line #16632
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAIRQUIN 5 (Karlin)',
	'Hydroquinone',
	'SOL',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAIRQUIN 5 (Karlin)'
);

-- line #16633
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYDE 3 (Shalaks)',
	'Hydroquinone',
	'CRM',
	gm.nullify_empty_string('3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYDE 3 (Shalaks)'
);

-- line #16634
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Hydroquinone', u'always_empty': u'', u'form': u'SOL', u'brand': u'HYDE', u'strength_3': u'', u'company': u'Shalaks', u'unit': u''}

-- line #16635
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYDRIP % 4 (Tripada BIO.)',
	'Hydroquinone',
	'CRM',
	gm.nullify_empty_string('4')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYDRIP % 4 (Tripada BIO.)'
);

-- line #16636
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELALITE 4 (Nicholas)',
	'Hydroquinone',
	'F. CRM',
	gm.nullify_empty_string('4')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELALITE 4 (Nicholas)'
);

-- line #16637
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELANORM 4 (Unimarck)',
	'Hydroquinone',
	'CRM',
	gm.nullify_empty_string('4')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELANORM 4 (Unimarck)'
);

-- line #16638
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'O-FAIR 2 (ALIVE)',
	'Hydroquinone',
	'CRM',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'O-FAIR 2 (ALIVE)'
);

-- line #16639
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEARL WHITE 2 (OREVA DARMO.)',
	'Hydroquinone',
	'LOT',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEARL WHITE 2 (OREVA DARMO.)'
);

-- line #16640
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PINQUIN 2 (Karlin)',
	'Hydroquinone',
	'CRM',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PINQUIN 2 (Karlin)'
);

-- line #16641
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000MCG', u'strength_2': u'', u'substance': u'HYDROXOCOBALAMIN', u'always_empty': u'', u'form': u'INJ', u'brand': u'HYDROX-12', u'strength_3': u'', u'company': u'Neon', u'unit': u''}

-- line #16642
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYDROCAD 200 (Cadila Ph.)',
	'HYDROXYCHLOROQUINE',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYDROCAD 200 (Cadila Ph.)'
);

-- line #16643
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARTIQUIN 200 (Overseas Hc.)',
	'HYDROXYCHLOROQUINE SULPHATE',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARTIQUIN 200 (Overseas Hc.)'
);

-- line #16644
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HCQS 200 (Ipca)',
	'HYDROXYCHLOROQUINE SULPHATE',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HCQS 200 (Ipca)'
);

-- line #16645
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HCQS 400 (Ipca)',
	'HYDROXYCHLOROQUINE SULPHATE',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HCQS 400 (Ipca)'
);

-- line #16646
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HQTOR 200 (TORRENT)',
	'HYDROXYCHLOROQUINE SULPHATE',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HQTOR 200 (TORRENT)'
);

-- line #16647
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MCQS 200 (MOLEKULE)',
	'HYDROXYCHLOROQUINE SULPHATE',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MCQS 200 (MOLEKULE)'
);

-- line #16648
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORTHOKIND 200 (Mankind)',
	'HYDROXYCHLOROQUINE SULPHATE',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORTHOKIND 200 (Mankind)'
);

-- line #16649
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXCQ 200 (Wallace)',
	'HYDROXYCHLOROQUINE SULPHATE',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXCQ 200 (Wallace)'
);

-- line #16650
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXCQ 400 (Wallace)',
	'HYDROXYCHLOROQUINE SULPHATE',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXCQ 400 (Wallace)'
);

-- line #16651
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QDMRD 200 (Alembic)',
	'HYDROXYCHLOROQUINE SULPHATE',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QDMRD 200 (Alembic)'
);

-- line #16652
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QDMRD 400 (Alembic)',
	'HYDROXYCHLOROQUINE SULPHATE',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QDMRD 400 (Alembic)'
);

-- line #16653
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RA-QUIN 200 (Ranbaxy)',
	'HYDROXYCHLOROQUINE SULPHATE',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RA-QUIN 200 (Ranbaxy)'
);

-- line #16654
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RA-QUIN 400 (Ranbaxy)',
	'HYDROXYCHLOROQUINE SULPHATE',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RA-QUIN 400 (Ranbaxy)'
);

-- line #16655
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'6G(NACL 0.9G)', u'strength_2': u'', u'substance': u'Hydroxyethyl Starch', u'always_empty': u'', u'form': u'INF', u'brand': u'EXPAN', u'strength_3': u'', u'company': u'Claris L.', u'unit': u''}

-- line #16656
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'6', u'strength_2': u'', u'substance': u'Hydroxyethyl Starch', u'always_empty': u'', u'form': u'', u'brand': u'HESTAR-200 % BAGS', u'strength_3': u'', u'company': u'Claris L.', u'unit': u'%'}

-- line #16657
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HESTAR-200 % 6 (Claris L.)',
	'Hydroxyethyl Starch',
	'INF',
	gm.nullify_empty_string('6')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HESTAR-200 % 6 (Claris L.)'
);

-- line #16658
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HESTAR % 10 (Claris L.)',
	'Hydroxyethyl Starch',
	'INF',
	gm.nullify_empty_string('10')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HESTAR % 10 (Claris L.)'
);

-- line #16659
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HESTAR % 3 (Claris L.)',
	'Hydroxyethyl Starch',
	'INF',
	gm.nullify_empty_string('3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HESTAR % 3 (Claris L.)'
);

-- line #16660
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HESTAR 6 (Claris L.)',
	'Hydroxyethyl Starch',
	'INF',
	gm.nullify_empty_string('6')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HESTAR 6 (Claris L.)'
);

-- line #16661
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENTARCH 6 (Claris L.)',
	'Hydroxyethyl Starch',
	'INF',
	gm.nullify_empty_string('6')::numeric,
	'%(NACL 0.9G)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENTARCH 6 (Claris L.)'
);

-- line #16662
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'(130', u'strength_2': u'0.4)6.00GM', u'substance': u'Hydroxyethyl Starch', u'always_empty': u'', u'form': u'', u'brand': u'PLAVOLEX', u'strength_3': u'', u'company': u'Bharat S.', u'unit': u'0.90GM(SOD. CHL.)'}

-- line #16663
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'(200', u'strength_2': u'0.5)6.00GM', u'substance': u'Hydroxyethyl Starch', u'always_empty': u'', u'form': u'', u'brand': u'PLAVOLEX-P', u'strength_3': u'', u'company': u'Bharat S.', u'unit': u'0.90GM(SOD. CHL.)'}

-- line #16664
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXYTEE 250 (AXYZEN LIFE)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXYTEE 250 (AXYZEN LIFE)'
);

-- line #16665
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXYTEE 500 (AXYZEN LIFE)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXYTEE 500 (AXYZEN LIFE)'
);

-- line #16666
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BROXY 250 (Brooks Ph.)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BROXY 250 (Brooks Ph.)'
);

-- line #16667
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECILON 250 (Jackson)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECILON 250 (Jackson)'
);

-- line #16668
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DELTON 250 (Mcneil Ph.)',
	'Hydroxyprogesterone Caproate',
	'DP INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DELTON 250 (Mcneil Ph.)'
);

-- line #16669
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPOVIG 250 (MADHAV BIO.)',
	'Hydroxyprogesterone Caproate',
	'AMP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPOVIG 250 (MADHAV BIO.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPOVIG 500 (MADHAV BIO.)',
	'Hydroxyprogesterone Caproate',
	'AMP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPOVIG 500 (MADHAV BIO.)'
);

-- line #16670
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYNO 250 (Dynamic)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYNO 250 (Dynamic)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYNO 500 (Dynamic)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYNO 500 (Dynamic)'
);

-- line #16671
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ECS DEPOT 250 (Ecstacy)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ECS DEPOT 250 (Ecstacy)'
);

-- line #16672
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FETARON 250 (Ochoa)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FETARON 250 (Ochoa)'
);

-- line #16673
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FETUCARE 250 (Alde Medi.)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FETUCARE 250 (Alde Medi.)'
);

-- line #16674
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FETUGEST 250 (Obsurge)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FETUGEST 250 (Obsurge)'
);

-- line #16675
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FETUGEST 500 (Obsurge)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FETUGEST 500 (Obsurge)'
);

-- line #16676
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FULTERM 250 (Micro Nova)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FULTERM 250 (Micro Nova)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FULTERM 500 (Micro Nova)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FULTERM 500 (Micro Nova)'
);

-- line #16677
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENSTASAFE 250 (Mankind)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENSTASAFE 250 (Mankind)'
);

-- line #16678
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GESTAUR 500 (Taurus Lab)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GESTAUR 500 (Taurus Lab)'
);

-- line #16679
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GESTER 250 (Shinto Org.)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GESTER 250 (Shinto Org.)'
);

-- line #16680
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GESTIMAX 250 (UNIMARK REM.)',
	'Hydroxyprogesterone Caproate',
	'AMP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GESTIMAX 250 (UNIMARK REM.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GESTIMAX 500 (UNIMARK REM.)',
	'Hydroxyprogesterone Caproate',
	'AMP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GESTIMAX 500 (UNIMARK REM.)'
);

-- line #16681
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GESTIMAX 250 (Unimarck)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GESTIMAX 250 (Unimarck)'
);

-- line #16682
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRAVIDIN 250 (Zydus A.)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRAVIDIN 250 (Zydus A.)'
);

-- line #16683
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GYNONYS DEPOT 250 (Uni-Sank.)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GYNONYS DEPOT 250 (Uni-Sank.)'
);

-- line #16684
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HICARE 250 (Logos)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HICARE 250 (Logos)'
);

-- line #16685
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIPROGRES 250 (Global Med.)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIPROGRES 250 (Global Med.)'
);

-- line #16686
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIPROGRESS 250 (Finecure)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIPROGRESS 250 (Finecure)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIPROGRESS 500 (Finecure)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIPROGRESS 500 (Finecure)'
);

-- line #16687
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HPC DEPOT 250 (Bpl Ph.)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HPC DEPOT 250 (Bpl Ph.)'
);

-- line #16688
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HPC DEPOT 500 (Bpl Ph.)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HPC DEPOT 500 (Bpl Ph.)'
);

-- line #16689
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'H-PROGEST 250 (Evacare)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'H-PROGEST 250 (Evacare)'
);

-- line #16690
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYLEX 500 (LEXUS)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYLEX 500 (LEXUS)'
);

-- line #16691
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYPROGEN 250 (Redson)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYPROGEN 250 (Redson)'
);

-- line #16692
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYPROGRES 250 (Finecure)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYPROGRES 250 (Finecure)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYPROGRES 500 (Finecure)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYPROGRES 500 (Finecure)'
);

-- line #16693
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAINTANE 250 (Jagsonpal)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAINTANE 250 (Jagsonpal)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAINTANE 500 (Jagsonpal)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAINTANE 500 (Jagsonpal)'
);

-- line #16694
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALOXY 500 (MALAR)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALOXY 500 (MALAR)'
);

-- line #16695
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAXOGEN DEPOT 250 (Biosmith)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAXOGEN DEPOT 250 (Biosmith)'
);

-- line #16696
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGACARE 250 (Solitaire)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGACARE 250 (Solitaire)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGACARE 500 (Solitaire)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGACARE 500 (Solitaire)'
);

-- line #16697
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METAGESTON DEPOT 250 (Perk Ph.)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METAGESTON DEPOT 250 (Perk Ph.)'
);

-- line #16698
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAPRO 250 (Nac Int.)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAPRO 250 (Nac Int.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAPRO 500 (Nac Int.)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAPRO 500 (Nac Int.)'
);

-- line #16699
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVADEPOT 250 (Radicura)',
	'Hydroxyprogesterone Caproate',
	'AMP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVADEPOT 250 (Radicura)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVADEPOT 500 (Radicura)',
	'Hydroxyprogesterone Caproate',
	'AMP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVADEPOT 500 (Radicura)'
);

-- line #16700
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVAPROGEN DEPOT 250 (Ophthal R.)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVAPROGEN DEPOT 250 (Ophthal R.)'
);

-- line #16701
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVAPROGEN DEPOT 500 (Ophthal R.)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVAPROGEN DEPOT 500 (Ophthal R.)'
);

-- line #16702
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NT-NATAL 250 (Kee Ph.)',
	'Hydroxyprogesterone Caproate',
	'AMP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NT-NATAL 250 (Kee Ph.)'
);

-- line #16703
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NT-NATAL 500 (Kee Ph.)',
	'Hydroxyprogesterone Caproate',
	'AMP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NT-NATAL 500 (Kee Ph.)'
);

-- line #16704
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEE-TONE 250 (Sterkem Ph.)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEE-TONE 250 (Sterkem Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEE-TONE 500 (Sterkem Ph.)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEE-TONE 500 (Sterkem Ph.)'
);

-- line #16705
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGARD 250 (ROSE LABS)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGARD 250 (ROSE LABS)'
);

-- line #16706
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGAT 250 (Atoz Ph.)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGAT 250 (Atoz Ph.)'
);

-- line #16707
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGNEN 250 (Admac Ph.)',
	'Hydroxyprogesterone Caproate',
	'F. INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGNEN 250 (Admac Ph.)'
);

-- line #16708
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGNEN 500 (Admac Ph.)',
	'Hydroxyprogesterone Caproate',
	'F. INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGNEN 500 (Admac Ph.)'
);

-- line #16709
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGOT-D 500 (Biocare Rem.)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGOT-D 500 (Biocare Rem.)'
);

-- line #16710
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGRIN 250 (Phytochem)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGRIN 250 (Phytochem)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGRIN 500 (Phytochem)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGRIN 500 (Phytochem)'
);

-- line #16711
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGSAVE 250 (Oscar Rem.)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGSAVE 250 (Oscar Rem.)'
);

-- line #16712
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGZED 250 (Zota Ph.)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGZED 250 (Zota Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGZED 500 (Zota Ph.)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGZED 500 (Zota Ph.)'
);

-- line #16713
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRODEPOT 250 (Prohealth)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRODEPOT 250 (Prohealth)'
);

-- line #16714
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROEVE DEPOT OO 500 (P C INDIA)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROEVE DEPOT OO 500 (P C INDIA)'
);

-- line #16715
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROGENY 250 (Cosmic Ph.)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROGENY 250 (Cosmic Ph.)'
);

-- line #16716
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROGENY 500 (Cosmic Ph.)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROGENY 500 (Cosmic Ph.)'
);

-- line #16717
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROLIN 250 (Lincoln)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROLIN 250 (Lincoln)'
);

-- line #16718
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROLUSTAR DEPOT 250 (Cadila (GENSTAR))',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROLUSTAR DEPOT 250 (Cadila (GENSTAR))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROLUSTAR DEPOT 500 (Cadila (GENSTAR))',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROLUSTAR DEPOT 500 (Cadila (GENSTAR))'
);

-- line #16719
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROLUTON DEPOT 250 (German R.)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROLUTON DEPOT 250 (German R.)'
);

-- line #16720
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROLUTON DEPOT 500 (German R.)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROLUTON DEPOT 500 (German R.)'
);

-- line #16721
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROPEG 250 (Unimarck)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROPEG 250 (Unimarck)'
);

-- line #16722
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROPEG 500 (Unimarck)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROPEG 500 (Unimarck)'
);

-- line #16723
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROSAFE DEPOT 250 (Om Bio.)',
	'Hydroxyprogesterone Caproate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROSAFE DEPOT 250 (Om Bio.)'
);

-- line #16724
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROVENDEPOT 250 (VENSAT)',
	'Hydroxyprogesterone Caproate',
	'AMP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROVENDEPOT 250 (VENSAT)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROVENDEPOT 500 (VENSAT)',
	'Hydroxyprogesterone Caproate',
	'AMP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROVENDEPOT 500 (VENSAT)'
);

-- line #16725
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GESTER 250 (Shinto Org.)',
	'Hydroxyprogesterone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GESTER 250 (Shinto Org.)'
);

-- line #16726
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GESTER 500 (Shinto Org.)',
	'Hydroxyprogesterone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GESTER 500 (Shinto Org.)'
);

-- line #16727
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANIN 250 (Ind-Swift)',
	'Hydroxyprogesterone Hexanoate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANIN 250 (Ind-Swift)'
);

-- line #16728
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANIN 500 (Ind-Swift)',
	'Hydroxyprogesterone Hexanoate',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANIN 500 (Ind-Swift)'
);

-- line #16729
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CMPH 0.3 (Elder V.)',
	'Hydroxypropyl Methyl Cellulose',
	'EYE DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CMPH 0.3 (Elder V.)'
);

-- line #16730
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Hydroxypropyl Methyl Cellulose', u'always_empty': u'', u'form': u'DROPS', u'brand': u'DIVISOL EYE', u'strength_3': u'', u'company': u'DIVINE LAB.', u'unit': u''}

-- line #16731
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EASILON STERILE 2 (Indiana O.)',
	'Hydroxypropyl Methyl Cellulose',
	'SOL',
	gm.nullify_empty_string('2')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EASILON STERILE 2 (Indiana O.)'
);

-- line #16732
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EYEMIST 0.3 (Sun)',
	'Hydroxypropyl Methyl Cellulose',
	'EYE DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EYEMIST 0.3 (Sun)'
);

-- line #16733
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EYEMIST 0.3 (Sun)',
	'Hydroxypropyl Methyl Cellulose',
	'GEL',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EYEMIST 0.3 (Sun)'
);

-- line #16734
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Hydroxypropyl Methyl Cellulose', u'always_empty': u'', u'form': u'VISC DPS', u'brand': u'EYE', u'strength_3': u'', u'company': u'Bio-Tech Opth.', u'unit': u''}

-- line #16735
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Hydroxypropyl Methyl Cellulose', u'always_empty': u'', u'form': u'VISC PFS DPS', u'brand': u'EYE', u'strength_3': u'', u'company': u'Bio-Tech Opth.', u'unit': u''}

-- line #16736
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Hydroxypropyl Methyl Cellulose', u'always_empty': u'', u'form': u'VISC PLUS PFS DPS', u'brand': u'EYE', u'strength_3': u'', u'company': u'Bio-Tech Opth.', u'unit': u''}

-- line #16737
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EYSOL 0.7 (Milmet)',
	'Hydroxypropyl Methyl Cellulose',
	'DPS',
	gm.nullify_empty_string('0.7')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EYSOL 0.7 (Milmet)'
);

-- line #16738
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GONOSOL 2.5 (Milmet)',
	'Hydroxypropyl Methyl Cellulose',
	'DPS',
	gm.nullify_empty_string('2.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GONOSOL 2.5 (Milmet)'
);

-- line #16739
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'I-COAT 2 (Guardian)',
	'Hydroxypropyl Methyl Cellulose',
	'EYE DPS',
	gm.nullify_empty_string('2')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'I-COAT 2 (Guardian)'
);

-- line #16740
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTAVISC 2 (Intas)',
	'Hydroxypropyl Methyl Cellulose',
	'DPS',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTAVISC 2 (Intas)'
);

-- line #16741
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTAVISC 20 (Intas)',
	'Hydroxypropyl Methyl Cellulose',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg(STERILE ISTONIC)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTAVISC 20 (Intas)'
);

-- line #16742
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTAVISC MV PF 2 (Intas)',
	'Hydroxypropyl Methyl Cellulose',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'%(10'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTAVISC MV PF 2 (Intas)'
);

-- line #16743
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2', u'strength_2': u'', u'substance': u'Hydroxypropyl Methyl Cellulose', u'always_empty': u'', u'form': u'', u'brand': u'INTAVISC MV PPF', u'strength_3': u'', u'company': u'Intas', u'unit': u'%W/V'}

-- line #16744
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTAVISC PPF 2 (Intas)',
	'Hydroxypropyl Methyl Cellulose',
	'SOL',
	gm.nullify_empty_string('2')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTAVISC PPF 2 (Intas)'
);

-- line #16745
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LACRYL % 2 (Entod Ph.)',
	'Hydroxypropyl Methyl Cellulose',
	'DPS',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LACRYL % 2 (Entod Ph.)'
);

-- line #16746
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUBRISOL 2 (Ophthal R.)',
	'Hydroxypropyl Methyl Cellulose',
	'DPS',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUBRISOL 2 (Ophthal R.)'
);

-- line #16747
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOISOL-PFS 2 (F D C)',
	'Hydroxypropyl Methyl Cellulose',
	'V',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOISOL-PFS 2 (F D C)'
);

-- line #16748
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOISOL-R 2 (F D C)',
	'Hydroxypropyl Methyl Cellulose',
	'V',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOISOL-R 2 (F D C)'
);

-- line #16749
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2', u'strength_2': u'', u'substance': u'Hydroxypropyl Methyl Cellulose', u'always_empty': u'', u'form': u'', u'brand': u'OCCU SYSTEM', u'strength_3': u'', u'company': u'Jagsonpal', u'unit': u'%'}

-- line #16750
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELOFOS 1000 (CELON(VIVILON))',
	'Hydroxyurea',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELOFOS 1000 (CELON(VIVILON))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELOFOS 2000 (CELON(VIVILON))',
	'Hydroxyurea',
	'INJ',
	gm.nullify_empty_string('2000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELOFOS 2000 (CELON(VIVILON))'
);

-- line #16751
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELOFOS 500 (CELON(VIVILON))',
	'Hydroxyurea',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELOFOS 500 (CELON(VIVILON))'
);

-- line #16752
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYTODROX 500 (Cipla)',
	'Hydroxyurea',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYTODROX 500 (Cipla)'
);

-- line #16753
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUREA 500 (Samarth)',
	'Hydroxyurea',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUREA 500 (Samarth)'
);

-- line #16754
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENDREA 500 (Vhb)',
	'Hydroxyurea',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENDREA 500 (Vhb)'
);

-- line #16755
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GINDREA 500 (Vhb)',
	'Hydroxyurea',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GINDREA 500 (Vhb)'
);

-- line #16756
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HONDREA 500 (Cytomed(Alkem))',
	'Hydroxyurea',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HONDREA 500 (Cytomed(Alkem))'
);

-- line #16757
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYDAB 500 (Dabur Ph.)',
	'Hydroxyurea',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYDAB 500 (Dabur Ph.)'
);

-- line #16758
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYDRAN 500 (CH.Bhagat)',
	'Hydroxyurea',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYDRAN 500 (CH.Bhagat)'
);

-- line #16759
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYDREA 500 (SPPL)',
	'Hydroxyurea',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYDREA 500 (SPPL)'
);

-- line #16760
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYTAS 500 (Intas)',
	'Hydroxyurea',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYTAS 500 (Intas)'
);

-- line #16761
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEUKOCEL 500 (CELON(VIVILON))',
	'Hydroxyurea',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEUKOCEL 500 (CELON(VIVILON))'
);

-- line #16762
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYELOSTAT 500 (German R.)',
	'Hydroxyurea',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYELOSTAT 500 (German R.)'
);

-- line #16763
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEODREA 500 (Vhb)',
	'Hydroxyurea',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEODREA 500 (Vhb)'
);

-- line #16764
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXYREA 500 (Cadila Ph.)',
	'Hydroxyurea',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXYREA 500 (Cadila Ph.)'
);

-- line #16765
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIBOREA 500 (Khandelwal)',
	'Hydroxyurea',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIBOREA 500 (Khandelwal)'
);

-- line #16766
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANXORAX 10 (INTAS)',
	'Hydroxyzine Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANXORAX 10 (INTAS)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANXORAX 25 (INTAS)',
	'Hydroxyzine Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANXORAX 25 (INTAS)'
);

-- line #16767
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Hydroxyzine Hcl.', u'always_empty': u'', u'form': u'SYR', u'brand': u'ATAMAX', u'strength_3': u'', u'company': u'Biomax Lab', u'unit': u''}

-- line #16768
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATAMAX 10 (Biomax Lab)',
	'Hydroxyzine Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATAMAX 10 (Biomax Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATAMAX 25 (Biomax Lab)',
	'Hydroxyzine Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATAMAX 25 (Biomax Lab)'
);

-- line #16769
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATARAX 6 (Ucb India)',
	'Hydroxyzine Hcl.',
	'DPS',
	gm.nullify_empty_string('6')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATARAX 6 (Ucb India)'
);

-- line #16770
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATARAX 25 (Ucb India)',
	'Hydroxyzine Hcl.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATARAX 25 (Ucb India)'
);

-- line #16771
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATARAX 10 (Ucb India)',
	'Hydroxyzine Hcl.',
	'SYR',
	gm.nullify_empty_string('10')::numeric,
	'mg/5 ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATARAX 10 (Ucb India)'
);

-- line #16772
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATARAX 10 (Ucb India)',
	'Hydroxyzine Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATARAX 10 (Ucb India)'
);

-- line #16773
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATARAX 25 (Ucb India)',
	'Hydroxyzine Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATARAX 25 (Ucb India)'
);

-- line #16774
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZON 6 (Divine Life)',
	'Hydroxyzine Hcl.',
	'DROPS',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZON 6 (Divine Life)'
);

-- line #16775
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELWIN 6 (AXYZEN LIFE)',
	'Hydroxyzine Hcl.',
	'DPS',
	gm.nullify_empty_string('6')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELWIN 6 (AXYZEN LIFE)'
);

-- line #16776
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELWIN 10 (AXYZEN LIFE)',
	'Hydroxyzine Hcl.',
	'SYR',
	gm.nullify_empty_string('10')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELWIN 10 (AXYZEN LIFE)'
);

-- line #16777
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELWIN 10 (AXYZEN LIFE)',
	'Hydroxyzine Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELWIN 10 (AXYZEN LIFE)'
);

-- line #16778
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELWIN 25 (AXYZEN LIFE)',
	'Hydroxyzine Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELWIN 25 (AXYZEN LIFE)'
);

-- line #16779
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HICOPE 6 (LIFESTAR)',
	'Hydroxyzine Hcl.',
	'DPS',
	gm.nullify_empty_string('6')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HICOPE 6 (LIFESTAR)'
);

-- line #16780
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HICOPE 10 (LIFESTAR)',
	'Hydroxyzine Hcl.',
	'SYR',
	gm.nullify_empty_string('10')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HICOPE 10 (LIFESTAR)'
);

-- line #16781
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HICOPE 10 (LIFESTAR)',
	'Hydroxyzine Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HICOPE 10 (LIFESTAR)'
);

-- line #16782
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HICOPE 25 (LIFESTAR)',
	'Hydroxyzine Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HICOPE 25 (LIFESTAR)'
);

-- line #16783
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYDIL 25 (Pil)',
	'Hydroxyzine Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYDIL 25 (Pil)'
);

-- line #16784
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYDROZE 10 (UNIKARE)',
	'Hydroxyzine Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYDROZE 10 (UNIKARE)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYDROZE 25 (UNIKARE)',
	'Hydroxyzine Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYDROZE 25 (UNIKARE)'
);

-- line #16785
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYRAX 10 (Palsons)',
	'Hydroxyzine Hcl.',
	'SYR',
	gm.nullify_empty_string('10')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYRAX 10 (Palsons)'
);

-- line #16786
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYZINE 10 (OREVA DARMO.)',
	'Hydroxyzine Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYZINE 10 (OREVA DARMO.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYZINE 25 (OREVA DARMO.)',
	'Hydroxyzine Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYZINE 25 (OREVA DARMO.)'
);

-- line #16787
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYZIN 25 (Indilina Ph.)',
	'Hydroxyzine Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYZIN 25 (Indilina Ph.)'
);

-- line #16788
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KRUST 25 (BIOSCIENCES)',
	'Hydroxyzine Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KRUST 25 (BIOSCIENCES)'
);

-- line #16789
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIZOD 25 (SHREE BALAJI PH.)',
	'Hydroxyzine Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg(ELTROMBOPAG FREE ACID)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIZOD 25 (SHREE BALAJI PH.)'
);

-- line #16790
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Hydroxyzine Hcl.', u'always_empty': u'', u'form': u'TAB', u'brand': u'NIZOD', u'strength_3': u'', u'company': u'SHREE BALAJI PH.', u'unit': u''}

-- line #16791
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEDIREX 6 (NEO)',
	'Hydroxyzine Hcl.',
	'DPS',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEDIREX 6 (NEO)'
);

-- line #16792
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRUGO 10 (Cosme Hc.)',
	'Hydroxyzine Hcl.',
	'SYR',
	gm.nullify_empty_string('10')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRUGO 10 (Cosme Hc.)'
);

-- line #16793
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRUGO 10 (Cfl Ph.)',
	'Hydroxyzine Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRUGO 10 (Cfl Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRUGO 25 (Cfl Ph.)',
	'Hydroxyzine Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRUGO 25 (Cfl Ph.)'
);

-- line #16794
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRUNIL10 10 (KIVI LABS)',
	'Hydroxyzine Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRUNIL10 10 (KIVI LABS)'
);

-- line #16795
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRUNIL 25 (KIVI LABS)',
	'Hydroxyzine Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRUNIL 25 (KIVI LABS)'
);

-- line #16796
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRU 10 (Yash Ph.)',
	'Hydroxyzine Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRU 10 (Yash Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRU 25 (Yash Ph.)',
	'Hydroxyzine Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRU 25 (Yash Ph.)'
);

-- line #16797
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRV 10 (Yash Ph.)',
	'Hydroxyzine Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRV 10 (Yash Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRV 25 (Yash Ph.)',
	'Hydroxyzine Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRV 25 (Yash Ph.)'
);

-- line #16798
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PSYTRAX 10 (PSYCOREM)',
	'Hydroxyzine Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PSYTRAX 10 (PSYCOREM)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PSYTRAX 25 (PSYCOREM)',
	'Hydroxyzine Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PSYTRAX 25 (PSYCOREM)'
);

-- line #16799
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PUGEN 5 (HALO MEDI.)',
	'Hydroxyzine Hcl.',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PUGEN 5 (HALO MEDI.)'
);

-- line #16800
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BELLOID 20 (Inga)',
	'Hyoscine',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BELLOID 20 (Inga)'
);

-- line #16801
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BELLOID 10 (Inga)',
	'Hyoscine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BELLOID 10 (Inga)'
);

-- line #16802
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BUSCOPAN 20 (German R.)',
	'Hyoscine',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BUSCOPAN 20 (German R.)'
);

-- line #16803
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BUSCOPAN 7.5 (German R.)',
	'Hyoscine',
	'SUPPOS',
	gm.nullify_empty_string('7.5')::numeric,
	'mg/10'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BUSCOPAN 7.5 (German R.)'
);

-- line #16804
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BUSCOPAN 10 (German R.)',
	'Hyoscine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BUSCOPAN 10 (German R.)'
);

-- line #16805
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZESPAN 10 (ABLAZE HC)',
	'Hyoscine Butyl Bromide',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZESPAN 10 (ABLAZE HC)'
);

-- line #16806
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BUSCOMAL 20 (Indus)',
	'Hyoscine Butyl Bromide',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BUSCOMAL 20 (Indus)'
);

-- line #16807
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEXOPAN 20 (Healthgaurd)',
	'Hyoscine Butyl Bromide',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEXOPAN 20 (Healthgaurd)'
);

-- line #16808
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEXOPAN 10 (Healthgaurd)',
	'Hyoscine Butyl Bromide',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEXOPAN 10 (Healthgaurd)'
);

-- line #16809
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HUPAN 10 (ROSE LABS)',
	'Hyoscine Butyl Bromide',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HUPAN 10 (ROSE LABS)'
);

-- line #16810
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYOSPAN 10 (Cipla)',
	'Hyoscine Butyl Bromide',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYOSPAN 10 (Cipla)'
);

-- line #16811
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYOSPAS 20 (Neon)',
	'Hyoscine Butyl Bromide',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYOSPAS 20 (Neon)'
);

-- line #16812
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYSCOPAN 10 (MODHIKE)',
	'Hyoscine Butyl Bromide',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYSCOPAN 10 (MODHIKE)'
);

-- line #16813
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYOSWIFT 20 (Ind-Swift)',
	'Hyoscine',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYOSWIFT 20 (Ind-Swift)'
);

-- line #16814
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYOSWIFT 10 (Ind-Swift)',
	'Hyoscine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYOSWIFT 10 (Ind-Swift)'
);

-- line #16815
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JOVIN 300 (Ind-Swift)',
	'HYPERICUM PERFORATUM EXT',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JOVIN 300 (Ind-Swift)'
);

-- line #16816
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2 L BAG', u'strength_2': u'', u'substance': u'Hyperosmolar kidney perfusion solution for donor kidneys', u'always_empty': u'', u'form': u'SOL', u'brand': u'EUROCOLLINS', u'strength_3': u'', u'company': u'Chemech', u'unit': u''}

-- line #16817
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.3(+BENZALKONIUM CHL.', u'strength_2': u'', u'substance': u'HYPROMELLOSE', u'always_empty': u'', u'form': u'', u'brand': u'ARTIFICIAL TEARS', u'strength_3': u'', u'company': u'Sunways', u'unit': u'0,01'}

-- line #16818
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HP 2 (RENOVA HC.)',
	'HYPROMELLOSE',
	'GEL',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HP 2 (RENOVA HC.)'
);

-- line #16819
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BANDRONE 6 (NATCO PH.)',
	'IBANDRONATE',
	'INJ',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BANDRONE 6 (NATCO PH.)'
);

-- line #16820
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BANDRONE 50 (NATCO PH.)',
	'IBANDRONATE',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BANDRONE 50 (NATCO PH.)'
);

-- line #16821
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BANDRONE 150 (Natco Ph.)',
	'IBANDRONIC ACID',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BANDRONE 150 (Natco Ph.)'
);

-- line #16822
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BONIMET 6 (Intas)',
	'IBANDRONIC ACID',
	'INJ',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BONIMET 6 (Intas)'
);

-- line #16823
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BONVIVA 150 (Elder)',
	'IBANDRONIC ACID',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BONVIVA 150 (Elder)'
);

-- line #16824
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'IBANDRONATE MONOSODIUM MONOHYDRATE', u'strength_2': u'', u'substance': u'IBANDRONIC ACID', u'always_empty': u'', u'form': u'TAB', u'brand': u'FLURISH', u'strength_3': u'', u'company': u"DR. REDDY''S", u'unit': u''}

-- line #16825
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEMIDRO 150 (Alkem)',
	'IBANDRONIC ACID',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEMIDRO 150 (Alkem)'
);

-- line #16826
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IDROFOS 1 (SUN)',
	'IBANDRONIC ACID',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'mg/1ML (CONC.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IDROFOS 1 (SUN)'
);

-- line #16827
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IDROFOS 3 (Sun)',
	'IBANDRONIC ACID',
	'INJ',
	gm.nullify_empty_string('3')::numeric,
	'mg/3ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IDROFOS 3 (Sun)'
);

-- line #16828
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IDROFOS 150 (Sun)',
	'IBANDRONIC ACID',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IDROFOS 150 (Sun)'
);

-- line #16829
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IDROFOS 50 (SUN)',
	'IBANDRONIC ACID',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IDROFOS 50 (SUN)'
);

-- line #16830
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALFAM 400 (Albert D.)',
	'Ibuprofen',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALFAM 400 (Albert D.)'
);

-- line #16831
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALFLAM 400 (Albert D.)',
	'Ibuprofen',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALFLAM 400 (Albert D.)'
);

-- line #16832
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARFEN 100 (Centaur)',
	'Ibuprofen',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARFEN 100 (Centaur)'
);

-- line #16833
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASOLT 400 (Profic)',
	'Ibuprofen',
	'XT TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASOLT 400 (Profic)'
);

-- line #16834
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BESTOGESIC 400 (Bestochem)',
	'Ibuprofen',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BESTOGESIC 400 (Bestochem)'
);

-- line #16835
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BESTOGESIC 600 (Bestochem)',
	'Ibuprofen',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BESTOGESIC 600 (Bestochem)'
);

-- line #16836
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BREN 100 (Kopran)',
	'Ibuprofen',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BREN 100 (Kopran)'
);

-- line #16837
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BREN 200 (Kopran)',
	'Ibuprofen',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BREN 200 (Kopran)'
);

-- line #16838
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BREN 400 (Kopran)',
	'Ibuprofen',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BREN 400 (Kopran)'
);

-- line #16839
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BREN 600 (Kopran)',
	'Ibuprofen',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BREN 600 (Kopran)'
);

-- line #16840
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRUFEN SOFTRA 400 (ABBOTT)',
	'Ibuprofen',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRUFEN SOFTRA 400 (ABBOTT)'
);

-- line #16841
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRUFEN 200 (Abbott)',
	'Ibuprofen',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRUFEN 200 (Abbott)'
);

-- line #16842
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRUFEN 400 (Abbott)',
	'Ibuprofen',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRUFEN 400 (Abbott)'
);

-- line #16843
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRUFEN 600 (Abbott)',
	'Ibuprofen',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRUFEN 600 (Abbott)'
);

-- line #16844
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRUN 400 (Shaimil)',
	'Ibuprofen',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRUN 400 (Shaimil)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRUN 800 (Shaimil)',
	'Ibuprofen',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRUN 800 (Shaimil)'
);

-- line #16845
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPGESIC 200 (Cipla)',
	'Ibuprofen',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPGESIC 200 (Cipla)'
);

-- line #16846
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPGESIC 400 (Cipla)',
	'Ibuprofen',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPGESIC 400 (Cipla)'
);

-- line #16847
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPGESIC 600 (Cipla)',
	'Ibuprofen',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPGESIC 600 (Cipla)'
);

-- line #16848
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEBRILIX 100 (Abbott)',
	'Ibuprofen',
	'SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEBRILIX 100 (Abbott)'
);

-- line #16849
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FENSPAN 300 (Gsk)',
	'Ibuprofen',
	'SR CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FENSPAN 300 (Gsk)'
);

-- line #16850
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FENSPAN 600 (Gsk)',
	'Ibuprofen',
	'SR CAP',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FENSPAN 600 (Gsk)'
);

-- line #16851
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IBRUMAC 125 (Macleods)',
	'Ibuprofen',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IBRUMAC 125 (Macleods)'
);

-- line #16852
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IBRUMAC 400 (Macleods)',
	'Ibuprofen',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IBRUMAC 400 (Macleods)'
);

-- line #16853
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IBUBID 600 (Sun)',
	'Ibuprofen',
	'SR TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IBUBID 600 (Sun)'
);

-- line #16854
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IBUBID TR 300 (Sun)',
	'Ibuprofen',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IBUBID TR 300 (Sun)'
);

-- line #16855
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IBUCON 200 (Concept)',
	'Ibuprofen',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IBUCON 200 (Concept)'
);

-- line #16856
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IBUCON 400 (Concept)',
	'Ibuprofen',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IBUCON 400 (Concept)'
);

-- line #16857
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IBUCON 600 (Concept)',
	'Ibuprofen',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IBUCON 600 (Concept)'
);

-- line #16858
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IBUFLAMAR 200 (Indoco Rem.)',
	'Ibuprofen',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IBUFLAMAR 200 (Indoco Rem.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IBUFLAMAR 400 (Indoco Rem.)',
	'Ibuprofen',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IBUFLAMAR 400 (Indoco Rem.)'
);

-- line #16859
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IBUF 400 (Finecure)',
	'Ibuprofen',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IBUF 400 (Finecure)'
);

-- line #16860
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IBUGESIC 300 (Cipla)',
	'Ibuprofen',
	'SR CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IBUGESIC 300 (Cipla)'
);

-- line #16861
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IBUGESIC 100 (Cipla)',
	'Ibuprofen',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IBUGESIC 100 (Cipla)'
);

-- line #16862
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IBUGESIC 200 (Cipla)',
	'Ibuprofen',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IBUGESIC 200 (Cipla)'
);

-- line #16863
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IBUGESIC 400 (Cipla)',
	'Ibuprofen',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IBUGESIC 400 (Cipla)'
);

-- line #16864
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IBUGESIC 600 (Cipla)',
	'Ibuprofen',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IBUGESIC 600 (Cipla)'
);

-- line #16865
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IBUGIN 200 (Gsk)',
	'Ibuprofen',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IBUGIN 200 (Gsk)'
);

-- line #16866
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IBUGIN 400 (Gsk)',
	'Ibuprofen',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IBUGIN 400 (Gsk)'
);

-- line #16867
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IBULAR 200 (Lark Labs)',
	'Ibuprofen',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IBULAR 200 (Lark Labs)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IBULAR 400 (Lark Labs)',
	'Ibuprofen',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IBULAR 400 (Lark Labs)'
);

-- line #16868
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IBULAR 600 (Lark Labs)',
	'Ibuprofen',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IBULAR 600 (Lark Labs)'
);

-- line #16869
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IBUPAL 200 (Jagsonpal)',
	'Ibuprofen',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IBUPAL 200 (Jagsonpal)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IBUPAL 400 (Jagsonpal)',
	'Ibuprofen',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IBUPAL 400 (Jagsonpal)'
);

-- line #16870
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IBURIN 400 (Unichem)',
	'Ibuprofen',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IBURIN 400 (Unichem)'
);

-- line #16871
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IBURIN 600 (Unichem)',
	'Ibuprofen',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IBURIN 600 (Unichem)'
);

-- line #16872
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IBUSOF 400 (Jagsonpal)',
	'Ibuprofen',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg(SOLUBILISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IBUSOF 400 (Jagsonpal)'
);

-- line #16873
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IBUSPAN 800 (Emcure)',
	'Ibuprofen',
	'SR TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IBUSPAN 800 (Emcure)'
);

-- line #16874
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IBUSYNTH 200 (Astrazeneca)',
	'Ibuprofen',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IBUSYNTH 200 (Astrazeneca)'
);

-- line #16875
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IBUSYNTH 400 (Astrazeneca)',
	'Ibuprofen',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IBUSYNTH 400 (Astrazeneca)'
);

-- line #16876
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INFLAPEN 300 (Gsk)',
	'Ibuprofen',
	'CR CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INFLAPEN 300 (Gsk)'
);

-- line #16877
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTAFEN 200 (Intas)',
	'Ibuprofen',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTAFEN 200 (Intas)'
);

-- line #16878
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTAFEN 400 (Intas)',
	'Ibuprofen',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTAFEN 400 (Intas)'
);

-- line #16879
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISMELIN 100 (Astrazeneca)',
	'Ibuprofen',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISMELIN 100 (Astrazeneca)'
);

-- line #16880
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISMELIN 200 (Astrazeneca)',
	'Ibuprofen',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISMELIN 200 (Astrazeneca)'
);

-- line #16881
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISMELIN 400 (Astrazeneca)',
	'Ibuprofen',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISMELIN 400 (Astrazeneca)'
);

-- line #16882
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISMELIN 600 (Astrazeneca)',
	'Ibuprofen',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISMELIN 600 (Astrazeneca)'
);

-- line #16883
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYBU 200 (Neon)',
	'Ibuprofen',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYBU 200 (Neon)'
);

-- line #16884
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYOFEN 200 (Nulife)',
	'Ibuprofen',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYOFEN 200 (Nulife)'
);

-- line #16885
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYOFEN 400 (Nulife)',
	'Ibuprofen',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYOFEN 400 (Nulife)'
);

-- line #16886
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORSWEL 400 (Zydus Cadila)',
	'Ibuprofen',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORSWEL 400 (Zydus Cadila)'
);

-- line #16887
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUREN 200 (Dabur Ph.)',
	'Ibuprofen',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUREN 200 (Dabur Ph.)'
);

-- line #16888
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUREN 400 (Dabur Ph.)',
	'Ibuprofen',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUREN 400 (Dabur Ph.)'
);

-- line #16889
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREMOBIL 300 (Biological E.)',
	'Ibuprofen',
	'SR CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREMOBIL 300 (Biological E.)'
);

-- line #16890
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREMOBIL 100 (Biological E.)',
	'Ibuprofen',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREMOBIL 100 (Biological E.)'
);

-- line #16891
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'IDEBENONE', u'always_empty': u'', u'form': u'CRM', u'brand': u'CLEONAL', u'strength_3': u'', u'company': u'Liva Hc.', u'unit': u''}

-- line #16892
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IBON 1 (Ajanta Ph.)',
	'IDEBENONE',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IBON 1 (Ajanta Ph.)'
);

-- line #16893
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IDEBEN 45 (Ordain Hc.)',
	'IDEBENONE',
	'CAP',
	gm.nullify_empty_string('45')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IDEBEN 45 (Ordain Hc.)'
);

-- line #16894
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORWAYZ 45 (Intas)',
	'IDEBENONE',
	'TAB',
	gm.nullify_empty_string('45')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORWAYZ 45 (Intas)'
);

-- line #16895
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REVIZE 1 (GRACEWELL)',
	'IDEBENONE',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REVIZE 1 (GRACEWELL)'
);

-- line #16896
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIDINOX 0.1 (Bell Ph.)',
	'Idoxuridine',
	'DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIDINOX 0.1 (Bell Ph.)'
);

-- line #16897
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ifosfamide', u'always_empty': u'', u'form': u'INJ', u'brand': u'HOLOXAN', u'strength_3': u'', u'company': u'German R.', u'unit': u''}

-- line #16898
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ifosfamide', u'always_empty': u'', u'form': u'INJ', u'brand': u'IFEX-M', u'strength_3': u'', u'company': u'Biochem', u'unit': u''}

-- line #16899
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ifosfamide', u'always_empty': u'', u'form': u'INJ', u'brand': u'IFOCIP', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #16900
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1GM', u'strength_2': u'', u'substance': u'Ifosfamide', u'always_empty': u'', u'form': u'INJ', u'brand': u'IFOS', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #16901
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Ifosfamide', u'always_empty': u'', u'form': u'INJ', u'brand': u'IPAMIDE', u'strength_3': u'', u'company': u'Dabur Ph.', u'unit': u''}

-- line #16902
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMATIB ALFA 100 (Cipla)',
	'IMATIBIN MESYLATE',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMATIB ALFA 100 (Cipla)'
);

-- line #16903
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALTANIB 100 (Alkem)',
	'IMATINIB MESYLATE',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALTANIB 100 (Alkem)'
);

-- line #16904
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALTANIB 400 (Alkem)',
	'IMATINIB MESYLATE',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALTANIB 400 (Alkem)'
);

-- line #16905
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELONIB 100 (CELON(VIVILON))',
	'IMATINIB MESYLATE',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELONIB 100 (CELON(VIVILON))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELONIB 400 (CELON(VIVILON))',
	'IMATINIB MESYLATE',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELONIB 400 (CELON(VIVILON))'
);

-- line #16906
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHYLO 375 (Fulford)',
	'IMATINIB MESYLATE',
	'VIAL',
	gm.nullify_empty_string('375')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHYLO 375 (Fulford)'
);

-- line #16907
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMANIB 400 (INTAS BIO.)',
	'IMATINIB MESYLATE',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMANIB 400 (INTAS BIO.)'
);

-- line #16908
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMAT 100 (Biochem)',
	'IMATINIB MESYLATE',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMAT 100 (Biochem)'
);

-- line #16909
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMAT 400 (Biochem)',
	'IMATINIB MESYLATE',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMAT 400 (Biochem)'
);

-- line #16910
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMATERO 100 (HETERO HC.)',
	'IMATINIB MESYLATE',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMATERO 100 (HETERO HC.)'
);

-- line #16911
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMATINATE 100 (Khandelwal)',
	'IMATINIB MESYLATE',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMATINATE 100 (Khandelwal)'
);

-- line #16912
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMATINATE 400 (Khandelwal)',
	'IMATINIB MESYLATE',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMATINATE 400 (Khandelwal)'
);

-- line #16913
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMICAP 100 (DABUR PH.)',
	'IMATINIB MESYLATE',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMICAP 100 (DABUR PH.)'
);

-- line #16914
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100', u'strength_2': u'', u'substance': u'IMATINIB MESYLATE', u'always_empty': u'', u'form': u'', u'brand': u'LEVIN', u'strength_3': u'', u'company': u"Dr. Reddy''S", u'unit': u'mg'}

-- line #16915
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'400', u'strength_2': u'', u'substance': u'IMATINIB MESYLATE', u'always_empty': u'', u'form': u'', u'brand': u'LEVIN', u'strength_3': u'', u'company': u"Dr. Reddy''S", u'unit': u'mg'}

-- line #16916
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUPINIB 100 (Lupin)',
	'IMATINIB MESYLATE',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUPINIB 100 (Lupin)'
);

-- line #16917
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUPINIB 400 (Lupin)',
	'IMATINIB MESYLATE',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUPINIB 400 (Lupin)'
);

-- line #16918
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MESYLONIB 100 (MIRACALUS)',
	'IMATINIB MESYLATE',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MESYLONIB 100 (MIRACALUS)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MESYLONIB 400 (MIRACALUS)',
	'IMATINIB MESYLATE',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MESYLONIB 400 (MIRACALUS)'
);

-- line #16919
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MITINAB 100 (ONKOS(GLENMARK))',
	'IMATINIB MESYLATE',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MITINAB 100 (ONKOS(GLENMARK))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MITINAB 400 (ONKOS(GLENMARK))',
	'IMATINIB MESYLATE',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MITINAB 400 (ONKOS(GLENMARK))'
);

-- line #16920
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RANIDAPRIL 10 (Ranbaxy)',
	'IMIDAPRIL',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RANIDAPRIL 10 (Ranbaxy)'
);

-- line #16921
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RANIDAPRIL 5 (Ranbaxy)',
	'IMIDAPRIL',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RANIDAPRIL 5 (Ranbaxy)'
);

-- line #16922
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANTIDEP 25 (Torrent)',
	'Imipramine',
	'CAP',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANTIDEP 25 (Torrent)'
);

-- line #16923
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANTIDEP 75 (Torrent)',
	'Imipramine',
	'CAP',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANTIDEP 75 (Torrent)'
);

-- line #16924
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANTIPRESS 25 (PSYCOREM)',
	'Imipramine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANTIPRESS 25 (PSYCOREM)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANTIPRESS 50 (PSYCOREM)',
	'Imipramine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANTIPRESS 50 (PSYCOREM)'
);

-- line #16925
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANTIPRESS 75 (PSYCOREM)',
	'Imipramine',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANTIPRESS 75 (PSYCOREM)'
);

-- line #16926
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPRANIL 25 (LA DRUG)',
	'Imipramine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPRANIL 25 (LA DRUG)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPRANIL 75 (LA DRUG)',
	'Imipramine',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPRANIL 75 (LA DRUG)'
);

-- line #16927
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPSIN 25 (Synokem)',
	'Imipramine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPSIN 25 (Synokem)'
);

-- line #16928
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPSIN 50 (Synokem)',
	'Imipramine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPSIN 50 (Synokem)'
);

-- line #16929
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPSOL 25 (Intas)',
	'Imipramine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPSOL 25 (Intas)'
);

-- line #16930
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPSOL 75 (Intas)',
	'Imipramine',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPSOL 75 (Intas)'
);

-- line #16931
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPSONIL 75 (Nicholas)',
	'Imipramine',
	'PM CAP',
	gm.nullify_empty_string('75')::numeric,
	'mg(PAMOA.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPSONIL 75 (Nicholas)'
);

-- line #16932
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPSONIL 25 (Nicholas)',
	'Imipramine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPSONIL 25 (Nicholas)'
);

-- line #16933
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIAMIN 25 (Reliance)',
	'Imipramine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg(HCL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIAMIN 25 (Reliance)'
);

-- line #16934
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIAMIN 75 (Reliance)',
	'Imipramine',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg(HCL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIAMIN 75 (Reliance)'
);

-- line #16935
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELAMIN 25 (BARODA)',
	'Imipramine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'75'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELAMIN 25 (BARODA)'
);

-- line #16936
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELDEP 25 (Pil)',
	'Imipramine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELDEP 25 (Pil)'
);

-- line #16937
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELDEP 50 (Pil)',
	'Imipramine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELDEP 50 (Pil)'
);

-- line #16938
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELDEP 75 (Pil)',
	'Imipramine',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELDEP 75 (Pil)'
);

-- line #16939
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELIDEP 25 (Elite Ph.)',
	'Imipramine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELIDEP 25 (Elite Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELIDEP 75 (Elite Ph.)',
	'Imipramine',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELIDEP 75 (Elite Ph.)'
);

-- line #16940
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMIPRA 25 (Cyril Ph.)',
	'Imipramine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMIPRA 25 (Cyril Ph.)'
);

-- line #16941
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMPRAMINE 75 (Sun)',
	'Imipramine',
	'CAP',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMPRAMINE 75 (Sun)'
);

-- line #16942
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMPRAMINE 25 (Sun)',
	'Imipramine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMPRAMINE 25 (Sun)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMPRAMINE 75 (Sun)',
	'Imipramine',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMPRAMINE 75 (Sun)'
);

-- line #16943
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMPRAMINE 25 (Sun)',
	'Imipramine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMPRAMINE 25 (Sun)'
);

-- line #16944
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMPREL 25 (Svizera)',
	'Imipramine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMPREL 25 (Svizera)'
);

-- line #16945
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANODEP 25 (Orchid Hc.)',
	'Imipramine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANODEP 25 (Orchid Hc.)'
);

-- line #16946
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANODEP 50 (Orchid Hc.)',
	'Imipramine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANODEP 50 (Orchid Hc.)'
);

-- line #16947
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANODEP 75 (Orchid Hc.)',
	'Imipramine',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANODEP 75 (Orchid Hc.)'
);

-- line #16948
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICRODEP 25 (Synapse)',
	'Imipramine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICRODEP 25 (Synapse)'
);

-- line #16949
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOVADEP 50 (MOVA PH.)',
	'Imipramine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOVADEP 50 (MOVA PH.)'
);

-- line #16950
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOVADEP 75 (MOVA PH.)',
	'Imipramine',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOVADEP 75 (MOVA PH.)'
);

-- line #16951
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMIQUAD 5 (Gracewell)',
	'IMIQUIMOD',
	'CRM',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMIQUAD 5 (Gracewell)'
);

-- line #16952
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NILWART 250 (Dr.Reddy''S)',
	'IMIQUIMOD',
	'CRM',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NILWART 250 (Dr.Reddy''S)'
);

-- line #16953
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CGMIDE 1.5 (CMGBT)',
	'Indapamide',
	'TAB',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CGMIDE 1.5 (CMGBT)'
);

-- line #16954
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIURIX 1.5 (Servetus)',
	'Indapamide',
	'SR TAB',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIURIX 1.5 (Servetus)'
);

-- line #16955
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIURIX 2.5 (Servetus)',
	'Indapamide',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIURIX 2.5 (Servetus)'
);

-- line #16956
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVRET 1.5 (NUCRON PH.)',
	'Indapamide',
	'SR TAB',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVRET 1.5 (NUCRON PH.)'
);

-- line #16957
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FANTON 1.5 (WISCON)',
	'Indapamide',
	'SR TAB',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FANTON 1.5 (WISCON)'
);

-- line #16958
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Indapamide', u'always_empty': u'', u'form': u'TAB', u'brand': u'FANTON', u'strength_3': u'', u'company': u'WISCON', u'unit': u''}

-- line #16959
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDACARD 1.5 (Intra Lab)',
	'Indapamide',
	'SR TAB',
	gm.nullify_empty_string('1.5')::numeric,
	'mg S.R.'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDACARD 1.5 (Intra Lab)'
);

-- line #16960
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDAP 1.5 (Mano)',
	'Indapamide',
	'TAB',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDAP 1.5 (Mano)'
);

-- line #16961
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDAP 2.5 (Mano)',
	'Indapamide',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDAP 2.5 (Mano)'
);

-- line #16962
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDICONTIN 1.5 (Modi Mundi)',
	'Indapamide',
	'CAPLETS (CR)',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDICONTIN 1.5 (Modi Mundi)'
);

-- line #16963
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IND 1.5 (CONCERTINA)',
	'Indapamide',
	'SR TAB',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IND 1.5 (CONCERTINA)'
);

-- line #16964
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IN 1.5 (Systopic)',
	'Indapamide',
	'SR TAB',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IN 1.5 (Systopic)'
);

-- line #16965
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IN+SR 1.5 (SYSTOPIC)',
	'Indapamide',
	'TAB',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IN+SR 1.5 (SYSTOPIC)'
);

-- line #16966
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INSURET 1.5 (Life Line)',
	'Indapamide',
	'TAB',
	gm.nullify_empty_string('1.5')::numeric,
	'mg(SR)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INSURET 1.5 (Life Line)'
);

-- line #16967
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INZU 1.5 (Dexter Lab)',
	'Indapamide',
	'SR TAB',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INZU 1.5 (Dexter Lab)'
);

-- line #16968
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NATRILIX 1.5 (Serdia)',
	'Indapamide',
	'SR TAB',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NATRILIX 1.5 (Serdia)'
);

-- line #16969
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NATRILIX 2.5 (Serdia)',
	'Indapamide',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NATRILIX 2.5 (Serdia)'
);

-- line #16970
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERIFER 2.5 (Cardicare)',
	'Indapamide',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERIFER 2.5 (Cardicare)'
);

-- line #16971
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INBEC 400 (Emcure)',
	'Indinavir',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INBEC 400 (Emcure)'
);

-- line #16972
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDEASE 400 (Cytomed(Alkem))',
	'Indinavir',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDEASE 400 (Cytomed(Alkem))'
);

-- line #16973
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDIVAN 400 (Cipla)',
	'Indinavir',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDIVAN 400 (Cipla)'
);

-- line #16974
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDIVIR 400 (Genix Ph.)',
	'Indinavir',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDIVIR 400 (Genix Ph.)'
);

-- line #16975
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'I-VIR 400 (Sain Med.)',
	'Indinavir',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'I-VIR 400 (Sain Med.)'
);

-- line #16976
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARTISID 25 (Sun)',
	'Indomethacin',
	'CAP',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARTISID 25 (Sun)'
);

-- line #16977
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARTISID 50 (Sun)',
	'Indomethacin',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARTISID 50 (Sun)'
);

-- line #16978
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DONICA 25 (Ipca)',
	'Indomethacin',
	'CAP',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DONICA 25 (Ipca)'
);

-- line #16979
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DONICA 75 (Ipca)',
	'Indomethacin',
	'SR CAP',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DONICA 75 (Ipca)'
);

-- line #16980
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUCAIN 25 (Ipca)',
	'Indomethacin',
	'CAP',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUCAIN 25 (Ipca)'
);

-- line #16981
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENDOCIN 75 (N.A.)',
	'Indomethacin',
	'SR CAP',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENDOCIN 75 (N.A.)'
);

-- line #16982
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IDICIN 25 (Idpl)',
	'Indomethacin',
	'CAP',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IDICIN 25 (Idpl)'
);

-- line #16983
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDOCAP 25 (Jagsonpal)',
	'Indomethacin',
	'CAP',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDOCAP 25 (Jagsonpal)'
);

-- line #16984
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDOCAP OPHTH 1 (Jagsonpal)',
	'Indomethacin',
	'DPS',
	gm.nullify_empty_string('1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDOCAP OPHTH 1 (Jagsonpal)'
);

-- line #16985
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDOCAP 75 (Jagsonpal)',
	'Indomethacin',
	'SR CAP',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDOCAP 75 (Jagsonpal)'
);

-- line #16986
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDOCID 75 (Cipla)',
	'Indomethacin',
	'SR CAP',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDOCID 75 (Cipla)'
);

-- line #16987
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDOFLAM 1 (Zydus Cadila)',
	'Indomethacin',
	'DPS',
	gm.nullify_empty_string('1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDOFLAM 1 (Zydus Cadila)'
);

-- line #16988
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDOFLAM TR 25 (Zydus Cadila)',
	'Indomethacin',
	'CAP',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDOFLAM TR 25 (Zydus Cadila)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDOFLAM TR 75 (Zydus Cadila)',
	'Indomethacin',
	'CAP',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDOFLAM TR 75 (Zydus Cadila)'
);

-- line #16989
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDOFLAM TR 75 (Zydus Cadila)',
	'Indomethacin',
	'CAP',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDOFLAM TR 75 (Zydus Cadila)'
);

-- line #16990
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDOMED 100 (Medoz Ph.)',
	'Indomethacin',
	'SR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDOMED 100 (Medoz Ph.)'
);

-- line #16991
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INMECIN 25 (Sterkem Ph.)',
	'Indomethacin',
	'CAP',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INMECIN 25 (Sterkem Ph.)'
);

-- line #16992
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INMECIN 50 (Sterkem Ph.)',
	'Indomethacin',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INMECIN 50 (Sterkem Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INMECIN 75 (Sterkem Ph.)',
	'Indomethacin',
	'CAP',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INMECIN 75 (Sterkem Ph.)'
);

-- line #16993
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INMECIN 1 (Sterkem Ph.)',
	'Indomethacin',
	'E/E DPS',
	gm.nullify_empty_string('1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INMECIN 1 (Sterkem Ph.)'
);

-- line #16994
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INMECIN-R 75 (Sterkem Ph.)',
	'Indomethacin',
	'CAP',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INMECIN-R 75 (Sterkem Ph.)'
);

-- line #16995
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INOCIN 25 (Bombay T.)',
	'Indomethacin',
	'CAP',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INOCIN 25 (Bombay T.)'
);

-- line #16996
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDERREUMOL 100 (Stedman)',
	'Indomethacin',
	'SUPP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDERREUMOL 100 (Stedman)'
);

-- line #16997
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'25NG', u'strength_2': u'', u'substance': u'Indomethacin', u'always_empty': u'', u'form': u'CAP', u'brand': u'MICROCID', u'strength_3': u'', u'company': u'Micro Labs', u'unit': u''}

-- line #16998
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICROCID 75 (Micro Labs)',
	'Indomethacin',
	'SR CAP',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICROCID 75 (Micro Labs)'
);

-- line #16999
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RECTICIN 50 (Bliss)',
	'Indomethacin',
	'SUPPOS',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RECTICIN 50 (Bliss)'
);

-- line #17000
-- ignoring line: field [strength_1] not numeric: >>>A AND B STRAINS EQ TO A<<<
-- {u'list_of_values_of_unknown_fields': [u'B/MALASIA/2506/2004-LIKE STRAIN 15MCG HA', u'OVALBUMIN NOT MORE THAN 1MCG', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'A AND B STRAINS EQ TO A', u'strength_2': u'SOLOMON ISLANDS 3', u'substance': u'INFLUENZA VIRUS VACCINE', u'always_empty': u'', u'form': u'VACCINE', u'brand': u'INFLUVAC', u'strength_3': u'2006 (H1N1) LIKE STRAIN 15MCG HA', u'company': u'Cipla', u'unit': u'A/ WISCINSIN/67/2005(H3N3)'}

-- line #17001
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1', u'strength_2': u'', u'substance': u'INHALATION DEVICE', u'always_empty': u'', u'form': u'', u'brand': u'CID DEVICE', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #17002
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'INHALATION DEVICE', u'always_empty': u'', u'form': u'', u'brand': u'INSTAHALER', u'strength_3': u'', u'company': u'Glenmark', u'unit': u''}

-- line #17003
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'USED FOR ASTHAMA INHALER', u'strength_2': u'', u'substance': u'INHALATION DEVICE', u'always_empty': u'', u'form': u'', u'brand': u'MACHALER', u'strength_3': u'', u'company': u'Macleods', u'unit': u''}

-- line #17004
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1', u'strength_2': u'', u'substance': u'INHALATION DEVICE', u'always_empty': u'', u'form': u'', u'brand': u'OCTAHALER DEVICE', u'strength_3': u'', u'company': u'Ranbaxy', u'unit': u''}

-- line #17005
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'REDIHALER DEVICE FOR DPI CAPASULS', u'strength_2': u'', u'substance': u'INHALATION DEVICE', u'always_empty': u'', u'form': u'', u'brand': u'REDIHALER DEVICE', u'strength_3': u'', u'company': u"Dr.Reddy''S", u'unit': u''}

-- line #17006
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500', u'strength_2': u'', u'substance': u'Inositol', u'always_empty': u'', u'form': u'', u'brand': u'LORISC', u'strength_3': u'', u'company': u'Goodrich', u'unit': u'mg'}

-- line #17007
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MORE HDL 500 (Albatross)',
	'Inositol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MORE HDL 500 (Albatross)'
);

-- line #17008
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'B-D MICRO-FINE IV 40 (Sanofi Aventis)',
	'INSULIN',
	'SYR',
	gm.nullify_empty_string('40')::numeric,
	'80'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'B-D MICRO-FINE IV 40 (Sanofi Aventis)'
);

-- line #17009
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'INSULIN DELIVERY DEVICE', u'always_empty': u'', u'form': u'', u'brand': u'GLARITUS PEN ROYALE', u'strength_3': u'', u'company': u'Wockhardt', u'unit': u''}

-- line #17010
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100IU.', u'strength_2': u'ML (R D N A ORIGIN)', u'substance': u'Insulin glargine', u'always_empty': u'', u'form': u'', u'brand': u'BASALOG INS', u'strength_3': u'', u'company': u'Biocon', u'unit': u''}

-- line #17011
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Insulin glargine', u'always_empty': u'', u'form': u'', u'brand': u'GLARITUS CARTRIDGE', u'strength_3': u'', u'company': u'Wockhardt', u'unit': u''}

-- line #17012
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Insulin glargine', u'always_empty': u'', u'form': u'', u'brand': u'GLARITUS DISPO PEN', u'strength_3': u'', u'company': u'Wockhardt', u'unit': u''}

-- line #17013
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Insulin glargine', u'always_empty': u'', u'form': u'', u'brand': u'LANTUS AUTOPEN', u'strength_3': u'', u'company': u'Sanofi Aventis', u'unit': u''}

-- line #17014
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100IU.', u'strength_2': u'ML', u'substance': u'Insulin glargine', u'always_empty': u'', u'form': u'KIT', u'brand': u'LANTUS IU CART STARTER', u'strength_3': u'', u'company': u'AVENTIS PH.', u'unit': u''}

-- line #17015
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3ML OF INSULIN GLULISINE EACH 1ML CONTAINS INSULIN GLULISINE & SOLOSTAR CONTAIN 300ML OF INSULINE GLULISINE', u'strength_2': u'', u'substance': u'INSULIN GLULISINE', u'always_empty': u'', u'form': u'SOLOSTAR INS', u'brand': u'APIDRA', u'strength_3': u'', u'company': u'Aventis', u'unit': u''}

-- line #17016
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100IU.', u'strength_2': u'ML', u'substance': u'Insulin Lispro', u'always_empty': u'', u'form': u'', u'brand': u'HUMALOG IUCARTIDGE', u'strength_3': u'', u'company': u'Eli Lilly', u'unit': u''}

-- line #17017
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40IU.', u'strength_2': u'ML', u'substance': u'Insulin Lispro', u'always_empty': u'', u'form': u'VIAL', u'brand': u'HUMALOG', u'strength_3': u'', u'company': u'Eli Lilly', u'unit': u''}

-- line #17018
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'INSULIN MIMETIC SUPPLEMENT', u'always_empty': u'', u'form': u'CAP', u'brand': u'INSULINOX', u'strength_3': u'', u'company': u'NEISS', u'unit': u''}

-- line #17019
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3 MIU', u'strength_2': u'', u'substance': u'Interferon', u'always_empty': u'', u'form': u'INJ', u'brand': u'ALFERON', u'strength_3': u'', u'company': u'Zydus', u'unit': u''}

-- line #17020
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3MIU(R-HUMAN INTERFERON ALPHA 2B)', u'strength_2': u'', u'substance': u'Interferon', u'always_empty': u'', u'form': u'', u'brand': u'EGLITON MIU', u'strength_3': u'', u'company': u'Ranbaxy', u'unit': u''}

-- line #17021
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5MIU(R-HUMAN INTERFERON ALPHA 2B)', u'strength_2': u'', u'substance': u'Interferon', u'always_empty': u'', u'form': u'', u'brand': u'EGLITON MIU', u'strength_3': u'', u'company': u'Ranbaxy', u'unit': u''}

-- line #17022
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3MILL.IU.', u'strength_2': u'V (ALPHA 2-A)', u'substance': u'Interferon', u'always_empty': u'', u'form': u'INJ', u'brand': u'INRON-AL', u'strength_3': u'', u'company': u'Biological E.', u'unit': u''}

-- line #17023
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3M.I.U.', u'strength_2': u'', u'substance': u'Interferon', u'always_empty': u'', u'form': u'V', u'brand': u'INTALFA', u'strength_3': u'', u'company': u'Intas', u'unit': u''}

-- line #17024
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5M.I.U.', u'strength_2': u'', u'substance': u'Interferon', u'always_empty': u'', u'form': u'V', u'brand': u'INTALFA', u'strength_3': u'', u'company': u'Intas', u'unit': u''}

-- line #17025
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3;MI.IU.', u'strength_2': u'V.(ALPHA 2-A)', u'substance': u'Interferon', u'always_empty': u'', u'form': u'', u'brand': u'LG INTERMAX ALPHA', u'strength_3': u'', u'company': u'Lglsi', u'unit': u''}

-- line #17026
-- ignoring line: field [strength_1] not numeric: >>>(NIT.CONT.1.2<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'(NIT.CONT.1.2', u'strength_2': u'', u'substance': u'Interferon', u'always_empty': u'', u'form': u'INJ', u'brand': u'NULIP', u'strength_3': u'', u'company': u'Gufic Bio.', u'unit': u'mg+NUCLEIC ACID 4'}

-- line #17027
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50MCG(PEG-INTERFERON ALPHA 2B)', u'strength_2': u'', u'substance': u'Interferon', u'always_empty': u'', u'form': u'', u'brand': u'PEGLITON MCG', u'strength_3': u'', u'company': u'Ranbaxy', u'unit': u''}

-- line #17028
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'80MCG(PEG-INTERFERON ALPHA 2B)', u'strength_2': u'', u'substance': u'Interferon', u'always_empty': u'', u'form': u'', u'brand': u'PEGLITON MCG', u'strength_3': u'', u'company': u'Ranbaxy', u'unit': u''}

-- line #17029
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3', u'strength_2': u'5 MILL. IU.(ALFA 2B)', u'substance': u'Interferon', u'always_empty': u'', u'form': u'INJ', u'brand': u'REALAFA-2B', u'strength_3': u'', u'company': u'Kee Ph.', u'unit': u''}

-- line #17030
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3', u'strength_2': u'5;MIU. ALFA', u'substance': u'Interferon', u'always_empty': u'', u'form': u'V', u'brand': u'REALFA', u'strength_3': u'', u'company': u'Kee Ph.', u'unit': u''}

-- line #17031
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'44MCG (BETA-1A)', u'strength_2': u'', u'substance': u'Interferon', u'always_empty': u'', u'form': u'INJ', u'brand': u'REBIF', u'strength_3': u'', u'company': u'Serum Inst.', u'unit': u''}

-- line #17032
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'44MCG (BETA-1A 44MCG)', u'strength_2': u'', u'substance': u'Interferon', u'always_empty': u'', u'form': u'', u'brand': u'REBIF PFS', u'strength_3': u'', u'company': u'Serum Inst.', u'unit': u''}

-- line #17033
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3MILL.IU.', u'strength_2': u'V.(ALPHA 2-B)', u'substance': u'Interferon', u'always_empty': u'', u'form': u'', u'brand': u'RELIFERON MIU', u'strength_3': u'', u'company': u'RELIANCE BIO.', u'unit': u''}

-- line #17034
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5MILL.IU.', u'strength_2': u'V.(ALPHA 2-B)', u'substance': u'Interferon', u'always_empty': u'', u'form': u'', u'brand': u'RELIFERON MIU', u'strength_3': u'', u'company': u'RELIANCE BIO.', u'unit': u''}

-- line #17035
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.5G', u'strength_2': u'', u'substance': u'INTRAVENOUS GAMMAGLOBULIN', u'always_empty': u'', u'form': u'INJ', u'brand': u'IV GLOBULIN', u'strength_3': u'', u'company': u'Zydus Cadila', u'unit': u''}

-- line #17036
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'INTRAVENOUS GAMMAGLOBULIN', u'always_empty': u'', u'form': u'INJ', u'brand': u'IV GLOBULIN', u'strength_3': u'', u'company': u'Zydus Cadila', u'unit': u''}

-- line #17037
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2G', u'strength_2': u'', u'substance': u'INTRAVENOUS GAMMAGLOBULIN', u'always_empty': u'', u'form': u'INJ', u'brand': u'IV GLOBULIN', u'strength_3': u'', u'company': u'Zydus Cadila', u'unit': u''}

-- line #17038
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FRUCTOCORE 10 (Claris L.)',
	'Invert Sugar',
	'INF',
	gm.nullify_empty_string('10')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FRUCTOCORE 10 (Claris L.)'
);

-- line #17039
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FRUCTODEX 10 (R.B.)',
	'Invert Sugar',
	'INF',
	gm.nullify_empty_string('10')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FRUCTODEX 10 (R.B.)'
);

-- line #17040
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUCOFRUCT 10 (TABLETS I.)',
	'Invert Sugar',
	'INF',
	gm.nullify_empty_string('10')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUCOFRUCT 10 (TABLETS I.)'
);

-- line #17041
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INVERT SUGAR 10 (Albert D.)',
	'Invert Sugar',
	'INF',
	gm.nullify_empty_string('10')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INVERT SUGAR 10 (Albert D.)'
);

-- line #17042
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVODEX % 10 (Mount M.)',
	'Invert Sugar',
	'INF',
	gm.nullify_empty_string('10')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVODEX % 10 (Mount M.)'
);

-- line #17043
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10G', u'strength_2': u'', u'substance': u'Invert Sugar', u'always_empty': u'', u'form': u'INF', u'brand': u'PD-INVERT', u'strength_3': u'', u'company': u'Parenteral', u'unit': u''}

-- line #17044
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COLLOSOL IODINE 8 (Solvay Ph.)',
	'Iodine',
	'LIQ',
	gm.nullify_empty_string('8')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COLLOSOL IODINE 8 (Solvay Ph.)'
);

-- line #17045
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'IODINE GUM PAINT', u'always_empty': u'', u'form': u'GUM PAINT', u'brand': u'IGP', u'strength_3': u'', u'company': u'AUGMENT REM.', u'unit': u''}

-- line #17046
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENTEROZYME 250 (Stadmed)',
	'Iodochlorodydroxyquin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENTEROZYME 250 (Stadmed)'
);

-- line #17047
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENTROZYME 250 (Stadmed)',
	'Iodochlorohydroxyquinoline',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENTROZYME 250 (Stadmed)'
);

-- line #17048
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RADIOPAQUE 240 (Dabur Ph.)',
	'Iohexol',
	'INJ',
	gm.nullify_empty_string('240')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RADIOPAQUE 240 (Dabur Ph.)'
);

-- line #17049
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RADIOPAQUE 300 (Dabur Ph.)',
	'Iohexol',
	'INJ',
	gm.nullify_empty_string('300')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RADIOPAQUE 300 (Dabur Ph.)'
);

-- line #17050
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RADIOPAQUE 350 (Dabur Ph.)',
	'Iohexol',
	'INJ',
	gm.nullify_empty_string('350')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RADIOPAQUE 350 (Dabur Ph.)'
);

-- line #17051
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RADIOPAQUE 300 (Dabur Ph.)',
	'Iohexol',
	'V',
	gm.nullify_empty_string('300')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RADIOPAQUE 300 (Dabur Ph.)'
);

-- line #17052
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RADIOPAQUE 350 (Dabur Ph.)',
	'Iohexol',
	'V',
	gm.nullify_empty_string('350')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RADIOPAQUE 350 (Dabur Ph.)'
);

-- line #17053
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IOPAC 500 (Dey''S)',
	'Iopanoid Acid',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IOPAC 500 (Dey''S)'
);

-- line #17054
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250MCG', u'strength_2': u'', u'substance': u'Ipratropium Bromide', u'always_empty': u'', u'form': u'LIQ', u'brand': u'IPNEB', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #17055
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250MCG', u'strength_2': u'ML', u'substance': u'Ipratropium Bromide', u'always_empty': u'', u'form': u'SOL', u'brand': u'IPRAMIST', u'strength_3': u'', u'company': u'German R.', u'unit': u''}

-- line #17056
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'42MCG', u'strength_2': u'', u'substance': u'Ipratropium Bromide', u'always_empty': u'', u'form': u'', u'brand': u'IPRANASE AQ', u'strength_3': u'', u'company': u'Protec', u'unit': u''}

-- line #17057
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'42MCG', u'strength_2': u'SPRAY', u'substance': u'Ipratropium Bromide', u'always_empty': u'', u'form': u'SPRAY', u'brand': u'IPRANASE AQ', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #17058
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200MCG', u'strength_2': u'D.', u'substance': u'Ipratropium Bromide', u'always_empty': u'', u'form': u'', u'brand': u'IPRATOP INH', u'strength_3': u'', u'company': u'Astrazeneca', u'unit': u''}

-- line #17059
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40MCG', u'strength_2': u'D.', u'substance': u'Ipratropium Bromide', u'always_empty': u'', u'form': u'F. INH', u'brand': u'IPRAVENT', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #17060
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20MCG', u'strength_2': u'PUFF', u'substance': u'Ipratropium Bromide', u'always_empty': u'', u'form': u'', u'brand': u'IPRAVENT INH', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #17061
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'2ML', u'substance': u'Ipratropium Bromide', u'always_empty': u'', u'form': u'RES', u'brand': u'IPRAVENT', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #17062
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250MCG', u'strength_2': u'ML', u'substance': u'Ipratropium Bromide', u'always_empty': u'', u'form': u'SOL', u'brand': u'IPRAVENT RESPIRATOR', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #17063
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Ipratropium Bromide', u'always_empty': u'', u'form': u'ROTACAPS', u'brand': u'IPRAVENT', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #17064
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APROVEL 150 (Sanofi Aventis)',
	'Irbesartan',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APROVEL 150 (Sanofi Aventis)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APROVEL 300 (Sanofi Aventis)',
	'Irbesartan',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APROVEL 300 (Sanofi Aventis)'
);

-- line #17065
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IRBEST 150 (Biochem)',
	'Irbesartan',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IRBEST 150 (Biochem)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IRBEST 300 (Biochem)',
	'Irbesartan',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IRBEST 300 (Biochem)'
);

-- line #17066
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IROVEL 150 (Sun)',
	'Irbesartan',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IROVEL 150 (Sun)'
);

-- line #17067
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IROVEL 300 (Sun)',
	'Irbesartan',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IROVEL 300 (Sun)'
);

-- line #17068
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COLOTECAN 20 (SUN)',
	'Irinotecan Hcl.',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COLOTECAN 20 (SUN)'
);

-- line #17069
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IRINOT 20 (Khandelwal)',
	'Irinotecan Hcl.',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IRINOT 20 (Khandelwal)'
);

-- line #17070
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IRINOT INJ 20 (Khandelwal)',
	'Irinotecan Hcl.',
	'V',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IRINOT INJ 20 (Khandelwal)'
);

-- line #17071
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IRNOCAM 40 (Dr.Reddy''S)',
	'Irinotecan Hcl.',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IRNOCAM 40 (Dr.Reddy''S)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IRNOCAM 100 (Dr.Reddy''S)',
	'Irinotecan Hcl.',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IRNOCAM 100 (Dr.Reddy''S)'
);

-- line #17072
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IRNOZEN 100 (Ranbaxy S.S.)',
	'Irinotecan Hcl.',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IRNOZEN 100 (Ranbaxy S.S.)'
);

-- line #17073
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IRNOZEN 40 (Ranbaxy S.S.)',
	'Irinotecan Hcl.',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IRNOZEN 40 (Ranbaxy S.S.)'
);

-- line #17074
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELERON 50 (Geno Ph.)',
	'Iron (III) Hydroxide Polymaltose Complex',
	'DPS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELERON 50 (Geno Ph.)'
);

-- line #17075
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELERON 50 (Geno Ph.)',
	'Iron (III) Hydroxide Polymaltose Complex',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELERON 50 (Geno Ph.)'
);

-- line #17076
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'3-UP 50 (Ups Hc.)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '3-UP 50 (Ups Hc.)'
);

-- line #17077
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADCOB 20 (Kinedex Hc.)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg(FERRIC HYDROXIDE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADCOB 20 (Kinedex Hc.)'
);

-- line #17078
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALFER 50 (Alde Medi.)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'DPS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALFER 50 (Alde Medi.)'
);

-- line #17079
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENIFER 50 (Baroque)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENIFER 50 (Baroque)'
);

-- line #17080
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron', u'always_empty': u'', u'form': u'SYR', u'brand': u'BIOFER', u'strength_3': u'', u'company': u'SANCHEZ LAB.', u'unit': u''}

-- line #17081
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARBIRAN 50 (ALLENGE)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'DPS',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARBIRAN 50 (ALLENGE)'
);

-- line #17082
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron', u'always_empty': u'', u'form': u'SYR', u'brand': u'CARBIRAN', u'strength_3': u'', u'company': u'ALLENGE', u'unit': u''}

-- line #17083
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHERISH 50 (Wanbury)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'DPS',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHERISH 50 (Wanbury)'
);

-- line #17084
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIFON 50 (Maan)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg(ELEMENTAL)/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIFON 50 (Maan)'
);

-- line #17085
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'(FERRIC HYDROXIDE WITH SUCROSE)', u'strength_2': u'', u'substance': u'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron', u'always_empty': u'', u'form': u'INJ', u'brand': u'COROFER', u'strength_3': u'', u'company': u'Corona', u'unit': u''}

-- line #17086
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COROFER 50 (Corona)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COROFER 50 (Corona)'
);

-- line #17087
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CPINK-S 20 (Wanbury)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg (FERRIC HYDROXIDE IN COMP. WITH SUCROSE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CPINK-S 20 (Wanbury)'
);

-- line #17088
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CPINK-S 20 (Wanbury)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg(FERRIC HYDROXIDE WITH SUCROSE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CPINK-S 20 (Wanbury)'
);

-- line #17089
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CPINK 20 (Wanbury)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'XT INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg(FERRIC HYDROXIDE IN COMLEX WITH SUCROSE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CPINK 20 (Wanbury)'
);

-- line #17090
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENCIFER 20 (Emcure)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg(FERRIC HYDROXIDE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENCIFER 20 (Emcure)'
);

-- line #17091
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FECOM 50 (Mapra)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg;5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FECOM 50 (Mapra)'
);

-- line #17092
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEGEM 50 (Torrent)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEGEM 50 (Torrent)'
);

-- line #17093
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEJET-I 20 (Venus Rem.)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'V',
	gm.nullify_empty_string('20')::numeric,
	'mg(FERRIC HYDROXIDE WITH SUCROSE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEJET-I 20 (Venus Rem.)'
);

-- line #17094
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEMALT 50 (Synokem)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEMALT 50 (Synokem)'
);

-- line #17095
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEMED 50 (Comed)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEMED 50 (Comed)'
);

-- line #17096
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEMED 100 (Comed)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEMED 100 (Comed)'
);

-- line #17097
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERAL PAED 50 (Southsourne)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'DPS',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERAL PAED 50 (Southsourne)'
);

-- line #17098
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERICH 50 (Maneesh)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'DROP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERICH 50 (Maneesh)'
);

-- line #17099
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERICIP 50 (Cipla)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'DPS',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERICIP 50 (Cipla)'
);

-- line #17100
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERICIP 50 (Cipla)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERICIP 50 (Cipla)'
);

-- line #17101
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERITIN 50 (Ind-Swift)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'DROP',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERITIN 50 (Ind-Swift)'
);

-- line #17102
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERITIN 50 (Ind-Swift)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERITIN 50 (Ind-Swift)'
);

-- line #17103
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERITONE 50 (Blue Cross)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'DPS',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERITONE 50 (Blue Cross)'
);

-- line #17104
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERIUM 50 (Emcure)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'DPS',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERIUM 50 (Emcure)'
);

-- line #17105
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERIUM 50 (Emcure)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERIUM 50 (Emcure)'
);

-- line #17106
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERIZEST 20 (Dwd)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg(FERRIC HYDROXIDE WITH SUCROSE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERIZEST 20 (Dwd)'
);

-- line #17107
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEROCID 50 (Admac Ph.)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'DROP',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEROCID 50 (Admac Ph.)'
);

-- line #17108
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEROCID 50 (Admac Ph.)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEROCID 50 (Admac Ph.)'
);

-- line #17109
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERONIA IV 20 (Zuventus)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'AMP',
	gm.nullify_empty_string('20')::numeric,
	'mg(FERRIC HYDROXIDE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERONIA IV 20 (Zuventus)'
);

-- line #17110
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERONIA-IV 20 (Zuventus)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg(FERRIC HYDROXIDE WITH SUCROSE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERONIA-IV 20 (Zuventus)'
);

-- line #17111
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERON 50 (Marc Lab)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERON 50 (Marc Lab)'
);

-- line #17112
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEROSE 50 (Cfl Ph.)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'DPS',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEROSE 50 (Cfl Ph.)'
);

-- line #17113
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron', u'always_empty': u'', u'form': u'', u'brand': u'FEROSE IV', u'strength_3': u'', u'company': u'Cosme F.', u'unit': u'mg(FERRIC HYDROXIDE WITH SUCROSE)'}

-- line #17114
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEROSE IV 20 (Cosme F.)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg(FERRIC HYDROXIDE WITH SUCROSE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEROSE IV 20 (Cosme F.)'
);

-- line #17115
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEROSE 50 (Cfl Ph.)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEROSE 50 (Cfl Ph.)'
);

-- line #17116
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERRI-D 50 (Emcure)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERRI-D 50 (Emcure)'
);

-- line #17117
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERRI 50 (Emcure)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'DPS',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERRI 50 (Emcure)'
);

-- line #17118
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERRI 20 (Emcure)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg(FERRIC HYDROXIDE WITH SUCROSE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERRI 20 (Emcure)'
);

-- line #17119
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERRI 50 (Emcure)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML (WITH DEXTRAN)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERRI 50 (Emcure)'
);

-- line #17120
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERRITIN 50 (Ind-Swift)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'DPS',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERRITIN 50 (Ind-Swift)'
);

-- line #17121
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERRITIN 50 (Ind-Swift)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERRITIN 50 (Ind-Swift)'
);

-- line #17122
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERROHEPATINE 50 (Indo French)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERROHEPATINE 50 (Indo French)'
);

-- line #17123
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron', u'always_empty': u'', u'form': u'SYR', u'brand': u'FERRY', u'strength_3': u'', u'company': u'ANQUIS(SANCHEZ)', u'unit': u''}

-- line #17124
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50MH', u'strength_2': u'ML', u'substance': u'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron', u'always_empty': u'', u'form': u'DROP', u'brand': u'FERSOL', u'strength_3': u'', u'company': u'Briskon', u'unit': u''}

-- line #17125
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERSOL 50 (Briskon)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERSOL 50 (Briskon)'
);

-- line #17126
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERST 50 (Pharmed)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'DPS',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERST 50 (Pharmed)'
);

-- line #17127
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERST 50 (Pharmed)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERST 50 (Pharmed)'
);

-- line #17128
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FETON 50 (Lincoln)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FETON 50 (Lincoln)'
);

-- line #17129
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FETOSE 50 (Stanmark)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'DPS',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FETOSE 50 (Stanmark)'
);

-- line #17130
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLINAL PLUS 50 (Alembic)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLINAL PLUS 50 (Alembic)'
);

-- line #17131
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEFER 20 (Grandix)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'F. INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg(FERRIC HYDROXIDE WITH SUCROSE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEFER 20 (Grandix)'
);

-- line #17132
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEFER 20 (Grandix)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg(FERRIC HYDROXIDE WITH SUCROSE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEFER 20 (Grandix)'
);

-- line #17133
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLOBIRON 50 (Aglowmed)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'DPS',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLOBIRON 50 (Aglowmed)'
);

-- line #17134
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLOBIRON 100 (Aglowmed)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg;5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLOBIRON 100 (Aglowmed)'
);

-- line #17135
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLOHAR-III 50 (Taurus Lab)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLOHAR-III 50 (Taurus Lab)'
);

-- line #17136
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLOXY III 50 (Cadex Lab)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLOXY III 50 (Cadex Lab)'
);

-- line #17137
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HAEMARANGE IPC 50 (Emcure)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg;5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HAEMARANGE IPC 50 (Emcure)'
);

-- line #17138
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HAEMINEX 50 (Eden Hc.)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HAEMINEX 50 (Eden Hc.)'
);

-- line #17139
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HAEM UP 50 (Cadila Ph.)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'CHEW TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HAEM UP 50 (Cadila Ph.)'
);

-- line #17140
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HAEM UP 50 (Cadila Ph.)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'DPS',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HAEM UP 50 (Cadila Ph.)'
);

-- line #17141
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HAEM UP 50 (Cadila Ph.)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'PM SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HAEM UP 50 (Cadila Ph.)'
);

-- line #17142
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HBFAST 50 (Biological E.)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'DPS',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HBFAST 50 (Biological E.)'
);

-- line #17143
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HBFAST 50 (Biological E.)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HBFAST 50 (Biological E.)'
);

-- line #17144
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HB MORE 100 (Mcneil Ph.)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HB MORE 100 (Mcneil Ph.)'
);

-- line #17145
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HBRON 50 (Medley)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HBRON 50 (Medley)'
);

-- line #17146
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEAMOTIN 50 (AIMCO PH.)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEAMOTIN 50 (AIMCO PH.)'
);

-- line #17147
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEMCIL 50 (Paras Lab)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg;5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEMCIL 50 (Paras Lab)'
);

-- line #17148
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMFERON-S 20 (Shreya)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg(FERRIC HYDROXIDE IN COMP. WITH SUCROSE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMFERON-S 20 (Shreya)'
);

-- line #17149
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'(FERRIC HYDROXIDE WITH SUCROSE)20', u'strength_2': u'', u'substance': u'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron', u'always_empty': u'', u'form': u'', u'brand': u'INNOFER', u'strength_3': u'', u'company': u'INNOVA LIFESCI.', u'unit': u'mg'}

-- line #17150
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron', u'always_empty': u'', u'form': u'', u'brand': u'IRN-100', u'strength_3': u'', u'company': u'Serum Int.', u'unit': u'mg(FERRIC HYDROXIDE)'}

-- line #17151
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron', u'always_empty': u'', u'form': u'', u'brand': u'IRN-50', u'strength_3': u'', u'company': u'Serum Int.', u'unit': u'mg(FERRIC HYDROXIDE)'}

-- line #17152
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IROFUR 50 (Cosmas Ph.)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IROFUR 50 (Cosmas Ph.)'
);

-- line #17153
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IROZORB-S 20 (Macleods)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg(FERRIC HYDROXIDE WITH SUCROSE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IROZORB-S 20 (Macleods)'
);

-- line #17154
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAM 50 (Dallas Ph.)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'DPS',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAM 50 (Dallas Ph.)'
);

-- line #17155
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAM 50 (Dallas Ph.)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAM 50 (Dallas Ph.)'
);

-- line #17156
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron', u'always_empty': u'', u'form': u'SYR', u'brand': u'LGFER', u'strength_3': u'', u'company': u'Eg Ph.', u'unit': u''}

-- line #17157
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALTOFER 50 (Chemo D.)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'DPS',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALTOFER 50 (Chemo D.)'
);

-- line #17158
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALTO-MIX 50 (Chemo D.)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALTO-MIX 50 (Chemo D.)'
);

-- line #17159
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUMFER 50 (Glenmark)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'DPS',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUMFER 50 (Glenmark)'
);

-- line #17160
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUMFER-S 20 (G & G)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg(FERRIC HYDROXIDE WITH SUCROSE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUMFER-S 20 (G & G)'
);

-- line #17161
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUMFER 50 (Glenmark)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUMFER 50 (Glenmark)'
);

-- line #17162
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVAGLOBEN 50 (Ultramark)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVAGLOBEN 50 (Ultramark)'
);

-- line #17163
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMRON 20 (GUJ. TE.)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'AMP',
	gm.nullify_empty_string('20')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMRON 20 (GUJ. TE.)'
);

-- line #17164
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OROFER DAILY 50 (Emcure)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OROFER DAILY 50 (Emcure)'
);

-- line #17165
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OROFER 50 (Emcure)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'DPS',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OROFER 50 (Emcure)'
);

-- line #17166
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OROFER-S 20 (Emcure)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg(FERRIC HYDROXIDE WITH SUCROSE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OROFER-S 20 (Emcure)'
);

-- line #17167
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERSOL 50 (Briskon)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'DPS',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERSOL 50 (Briskon)'
);

-- line #17168
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERSOL 50 (Briskon)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERSOL 50 (Briskon)'
);

-- line #17169
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHOSFOMIN-IRON 50 (Nicholas)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHOSFOMIN-IRON 50 (Nicholas)'
);

-- line #17170
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POLIREN 50 (Ronak Lab.)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POLIREN 50 (Ronak Lab.)'
);

-- line #17171
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POLYFER 50 (Svizera)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POLYFER 50 (Svizera)'
);

-- line #17172
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POLYREN 50 (Ronak Lab.)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POLYREN 50 (Ronak Lab.)'
);

-- line #17173
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RBH 50 (Winsome Lab)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RBH 50 (Winsome Lab)'
);

-- line #17174
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RICHEM 50 (Biocin Hc.)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RICHEM 50 (Biocin Hc.)'
);

-- line #17175
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RICHGLOBIN 50 (Lark Lab)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'DPS',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RICHGLOBIN 50 (Lark Lab)'
);

-- line #17176
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RICHGLOBIN 50 (Lark Lab)',
	'Iron (Iii) Hydroxide Polymaltose Complex Eq.To Elemental Iron',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RICHGLOBIN 50 (Lark Lab)'
);

-- line #17177
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IRRITERO 100 (HETERO HC.)',
	'IRONOTECAN HCL.',
	'VIAL',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IRRITERO 100 (HETERO HC.)'
);

-- line #17178
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IRRITERO 40 (HETERO HC.)',
	'IRONOTECAN HCL.',
	'VIAL',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IRRITERO 40 (HETERO HC.)'
);

-- line #17179
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERPLEX 800 (Elder)',
	'Iron Protein Succinylate',
	'SYR',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERPLEX 800 (Elder)'
);

-- line #17180
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JECKTOFER 50 (Cfl Ph.)',
	'Iron Sorbitol Cit.Acid',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/1.5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JECKTOFER 50 (Cfl Ph.)'
);

-- line #17181
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JECTOCOS 50 (Cfl Ph.)',
	'Iron Sorbitol Cit.Acid',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JECTOCOS 50 (Cfl Ph.)'
);

-- line #17182
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACEFER 100 (ACE PH.)',
	'IRON SUCROSE',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg(ELEMENTAL IRON)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACEFER 100 (ACE PH.)'
);

-- line #17183
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANOFER-S 100 (Sun)',
	'IRON SUCROSE',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANOFER-S 100 (Sun)'
);

-- line #17184
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANOFER-S 50 (Sun)',
	'IRON SUCROSE',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/2.5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANOFER-S 50 (Sun)'
);

-- line #17185
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVIFOL 20 (AVIS LIFE)',
	'IRON SUCROSE',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVIFOL 20 (AVIS LIFE)'
);

-- line #17186
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZOFER 20 (Rpg Life)',
	'IRON SUCROSE',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZOFER 20 (Rpg Life)'
);

-- line #17187
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARBO-S 100 (AXYZEN LIFE)',
	'IRON SUCROSE',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARBO-S 100 (AXYZEN LIFE)'
);

-- line #17188
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'IRON SUCROSE', u'always_empty': u'', u'form': u'INJ', u'brand': u'ENCIFER', u'strength_3': u'', u'company': u'Emcure', u'unit': u''}

-- line #17189
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'IRON SUCROSE', u'always_empty': u'', u'form': u'INJ', u'brand': u'FARRIS', u'strength_3': u'', u'company': u'AAMORB(SIOUX)', u'unit': u''}

-- line #17190
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'IRON SUCROSE', u'always_empty': u'', u'form': u'INJ', u'brand': u'FECROSE', u'strength_3': u'', u'company': u'BIORELM', u'unit': u''}

-- line #17191
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERICOSE 100 (Shantha Bio.)',
	'IRON SUCROSE',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERICOSE 100 (Shantha Bio.)'
);

-- line #17192
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERIKIND-S 50 (LIFESTAR)',
	'IRON SUCROSE',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg(ELEMENTAL IRON)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERIKIND-S 50 (LIFESTAR)'
);

-- line #17193
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'IRON SUCROSE', u'always_empty': u'', u'form': u'INJ', u'brand': u'FERISE', u'strength_3': u'', u'company': u'Intas', u'unit': u''}

-- line #17194
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2.5ML', u'strength_2': u'', u'substance': u'IRON SUCROSE', u'always_empty': u'', u'form': u'AMP', u'brand': u'FEROCORP', u'strength_3': u'', u'company': u'CH.Bhagat', u'unit': u''}

-- line #17195
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5ML', u'strength_2': u'', u'substance': u'IRON SUCROSE', u'always_empty': u'', u'form': u'AMP', u'brand': u'FEROCORP', u'strength_3': u'', u'company': u'CH.Bhagat', u'unit': u''}

-- line #17196
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEROJET 200 (Wockhardt)',
	'IRON SUCROSE',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEROJET 200 (Wockhardt)'
);

-- line #17197
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEROJET 50 (Wockhardt)',
	'IRON SUCROSE',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEROJET 50 (Wockhardt)'
);

-- line #17198
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEROSE 100 (ROSE LABS)',
	'IRON SUCROSE',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEROSE 100 (ROSE LABS)'
);

-- line #17199
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEROSIG 20 (SIGNOVA)',
	'IRON SUCROSE',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEROSIG 20 (SIGNOVA)'
);

-- line #17200
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEROSUC 100 (Ipca)',
	'IRON SUCROSE',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg(ELELMENTAL IRON)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEROSUC 100 (Ipca)'
);

-- line #17201
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEROZEN 50 (AXYZEN LIFE)',
	'IRON SUCROSE',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg(IRON DEXTRAN)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEROZEN 50 (AXYZEN LIFE)'
);

-- line #17202
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLOBAC SAFE 100 (ZYDUS NUT.)',
	'IRON SUCROSE',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/AMP'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLOBAC SAFE 100 (ZYDUS NUT.)'
);

-- line #17203
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLOBAC SAFE 50 (ZYDUS NUT.)',
	'IRON SUCROSE',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/AMP'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLOBAC SAFE 50 (ZYDUS NUT.)'
);

-- line #17204
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'IRON SUCROSE', u'always_empty': u'', u'form': u'SYR', u'brand': u'HEMIFOLIN-Z', u'strength_3': u'', u'company': u'Elfin Ph.', u'unit': u''}

-- line #17205
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HERFEM-S 100 (Torrent)',
	'IRON SUCROSE',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg(ELEMENTAL IRON)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HERFEM-S 100 (Torrent)'
);

-- line #17206
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HERFEM-S 50 (Torrent)',
	'IRON SUCROSE',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg(ELEMENTAL IRON)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HERFEM-S 50 (Torrent)'
);

-- line #17207
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'I CROS 100 (UNIMARK REM.)',
	'IRON SUCROSE',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'I CROS 100 (UNIMARK REM.)'
);

-- line #17208
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMAX-S 100 (Otsira)',
	'IRON SUCROSE',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMAX-S 100 (Otsira)'
);

-- line #17209
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMFERON 50 (Shreya)',
	'IRON SUCROSE',
	'AMP',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML(IRON DEXTRAN)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMFERON 50 (Shreya)'
);

-- line #17210
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMFERON 50 (Shreya)',
	'IRON SUCROSE',
	'MD VIAL',
	gm.nullify_empty_string('50')::numeric,
	'mg(FE DEXTRAN)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMFERON 50 (Shreya)'
);

-- line #17211
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTRAFER 50 (Intra Lab)',
	'IRON SUCROSE',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTRAFER 50 (Intra Lab)'
);

-- line #17212
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IROZORB-S 50 (Macleods)',
	'IRON SUCROSE',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg(DILUTED IN SOD. CHL. INJ 0.9'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IROZORB-S 50 (Macleods)'
);

-- line #17213
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'IRON SUCROSE', u'always_empty': u'', u'form': u'VIAL', u'brand': u'ISOFERON', u'strength_3': u'', u'company': u'Biocon', u'unit': u''}

-- line #17214
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIVOGEN 100 (Merck)',
	'IRON SUCROSE',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIVOGEN 100 (Merck)'
);

-- line #17215
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICROFER 100 (Micro Labs)',
	'IRON SUCROSE',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICROFER 100 (Micro Labs)'
);

-- line #17216
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAMFER 50 (NAMAS)',
	'IRON SUCROSE',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAMFER 50 (NAMAS)'
);

-- line #17217
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REDBURY 100 (HANBURYS)',
	'IRON SUCROSE',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REDBURY 100 (HANBURYS)'
);

-- line #17218
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISPACIN 250 (Macleods)',
	'ISEPAMICIN',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISPACIN 250 (Macleods)'
);

-- line #17219
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'ISO AMYL 2 CYANOCRYLATE', u'always_empty': u'', u'form': u'', u'brand': u'NOVOCRYL', u'strength_3': u'', u'company': u'Alkem', u'unit': u''}

-- line #17220
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'ISO AMYL 2 CYANOCRYLATE', u'always_empty': u'', u'form': u'AMP', u'brand': u'NOVOCRYL', u'strength_3': u'', u'company': u'Alkem', u'unit': u''}

-- line #17221
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Isoflavones(Phytoestrogens)', u'always_empty': u'', u'form': u'CR CAP', u'brand': u'ISOFLAV', u'strength_3': u'', u'company': u'R.B.', u'unit': u''}

-- line #17222
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MENOFLAV 40 (ZYDUS NUT.)',
	'Isoflavones(Phytoestrogens)',
	'CAP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MENOFLAV 40 (ZYDUS NUT.)'
);

-- line #17223
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Isoflurane', u'always_empty': u'', u'form': u'', u'brand': u'AERRANE', u'strength_3': u'', u'company': u'Nicholas', u'unit': u''}

-- line #17224
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Isoflurane', u'always_empty': u'', u'form': u'', u'brand': u'FORANE INHALANT', u'strength_3': u'', u'company': u'ABBOTT', u'unit': u''}

-- line #17225
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Isoflurane', u'always_empty': u'', u'form': u'', u'brand': u'ISOFLURANE', u'strength_3': u'', u'company': u'RAMAN & WEIL', u'unit': u''}

-- line #17226
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISORANE 15 (Nicholas)',
	'Isoflurane',
	'LIQ',
	gm.nullify_empty_string('15')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISORANE 15 (Nicholas)'
);

-- line #17227
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISORANE 5 (Piramal Hc.)',
	'Isoflurane',
	'LIQ',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISORANE 5 (Piramal Hc.)'
);

-- line #17228
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Isoflurane', u'always_empty': u'', u'form': u'LIQ', u'brand': u'ISOTROY', u'strength_3': u'', u'company': u'Troikaa', u'unit': u''}

-- line #17229
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'30ML', u'strength_2': u'', u'substance': u'Isoflurane', u'always_empty': u'', u'form': u'', u'brand': u'ISOTROY', u'strength_3': u'', u'company': u'Troikaa', u'unit': u''}

-- line #17230
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERBAZIDE 400 (Mac)',
	'Isoniazid',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg(GI.METHANESULFONATE OF INH)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERBAZIDE 400 (Mac)'
);

-- line #17231
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISOKIN 100 (PFIZER)',
	'Isoniazid',
	'LIQ',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISOKIN 100 (PFIZER)'
);

-- line #17232
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISOKIN 100 (PFIZER)',
	'Isoniazid',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISOKIN 100 (PFIZER)'
);

-- line #17233
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISONEX 300 (Pfizer)',
	'Isoniazid',
	'F. TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISONEX 300 (Pfizer)'
);

-- line #17234
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISONEX 100 (Pfizer)',
	'Isoniazid',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISONEX 100 (Pfizer)'
);

-- line #17235
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'400MCG', u'strength_2': u'', u'substance': u'Isoprenaline', u'always_empty': u'', u'form': u'', u'brand': u'AUTOHALER', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #17236
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISOLIN 2 (Samarth)',
	'Isoprenaline',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISOLIN 2 (Samarth)'
);

-- line #17237
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISOPRIN 2 (Unichem)',
	'Isoprenaline',
	'AMP',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISOPRIN 2 (Unichem)'
);

-- line #17238
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISOSOL 2 (SG PH.)',
	'Isoprenaline',
	'AMP',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISOSOL 2 (SG PH.)'
);

-- line #17239
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEO-EPININE 20 (Gsk)',
	'Isoprenaline',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEO-EPININE 20 (Gsk)'
);

-- line #17240
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'5-MONO 30 (Biochem)',
	'Isosorbide-5 Mononitrate',
	'SR TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '5-MONO 30 (Biochem)'
);

-- line #17241
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'5-MONO 60 (Biochem)',
	'Isosorbide-5 Mononitrate',
	'SR TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '5-MONO 60 (Biochem)'
);

-- line #17242
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'5-MONO 10 (Biochem)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '5-MONO 10 (Biochem)'
);

-- line #17243
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'5-MONO 20 (Biochem)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '5-MONO 20 (Biochem)'
);

-- line #17244
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'5-MONO 40 (Biochem)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '5-MONO 40 (Biochem)'
);

-- line #17245
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANGICOR 40 (Novartis)',
	'Isosorbide-5 Mononitrate',
	'SR TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANGICOR 40 (Novartis)'
);

-- line #17246
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANGICOR 60 (Novartis)',
	'Isosorbide-5 Mononitrate',
	'SR TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANGICOR 60 (Novartis)'
);

-- line #17247
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANGICOR 20 (Novartis)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANGICOR 20 (Novartis)'
);

-- line #17248
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANGICOR 60 (Novartis)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANGICOR 60 (Novartis)'
);

-- line #17249
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANGIMON 10 (Kamron)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANGIMON 10 (Kamron)'
);

-- line #17250
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANGIMON 20 (Kamron)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANGIMON 20 (Kamron)'
);

-- line #17251
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANGINEX 20 (Wyeth)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANGINEX 20 (Wyeth)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANGINEX 40 (Wyeth)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANGINEX 40 (Wyeth)'
);

-- line #17252
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANGITAB 60 (Nicholas)',
	'Isosorbide-5 Mononitrate',
	'SR TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANGITAB 60 (Nicholas)'
);

-- line #17253
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANGITAB 10 (Nicholas)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANGITAB 10 (Nicholas)'
);

-- line #17254
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANGITAB 20 (Nicholas)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANGITAB 20 (Nicholas)'
);

-- line #17255
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANGITAB 40 (Nicholas)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANGITAB 40 (Nicholas)'
);

-- line #17256
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANGITRIT 20 (Unisearch)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANGITRIT 20 (Unisearch)'
);

-- line #17257
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANGIVAS 30 (Yash Ph.)',
	'Isosorbide-5 Mononitrate',
	'CR CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANGIVAS 30 (Yash Ph.)'
);

-- line #17258
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANGIVAS 50 (Yash Ph.)',
	'Isosorbide-5 Mononitrate',
	'CR CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANGIVAS 50 (Yash Ph.)'
);

-- line #17259
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDIMON 20 (SHINE PH.)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDIMON 20 (SHINE PH.)'
);

-- line #17260
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CRDIMON 10 (SHINE PH.)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CRDIMON 10 (SHINE PH.)'
);

-- line #17261
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IHD 30 (Stadmed)',
	'Isosorbide-5 Mononitrate',
	'SR TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IHD 30 (Stadmed)'
);

-- line #17262
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IHD 60 (Stadmed)',
	'Isosorbide-5 Mononitrate',
	'SR TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IHD 60 (Stadmed)'
);

-- line #17263
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IHD 10 (Stadmed)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IHD 10 (Stadmed)'
);

-- line #17264
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IHD 20 (Stadmed)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IHD 20 (Stadmed)'
);

-- line #17265
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IHD 40 (Stadmed)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IHD 40 (Stadmed)'
);

-- line #17266
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMDUR 30 (Astrazeneca)',
	'Isosorbide-5 Mononitrate',
	'SR TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMDUR 30 (Astrazeneca)'
);

-- line #17267
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMDUR 60 (Astrazeneca)',
	'Isosorbide-5 Mononitrate',
	'SR TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMDUR 60 (Astrazeneca)'
);

-- line #17268
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMDUR 30 (Astrazeneca)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMDUR 30 (Astrazeneca)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMDUR 60 (Astrazeneca)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMDUR 60 (Astrazeneca)'
);

-- line #17269
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMNIT 30 (Dr.Reddy''S)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMNIT 30 (Dr.Reddy''S)'
);

-- line #17270
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMNIT 60 (Dr.Reddy''S)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMNIT 60 (Dr.Reddy''S)'
);

-- line #17271
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISMO RETARD 40 (Piramal Hc.)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISMO RETARD 40 (Piramal Hc.)'
);

-- line #17272
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISMO 10 (Piramal Hc.)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISMO 10 (Piramal Hc.)'
);

-- line #17273
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISMO 20 (Piramal Hc.)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISMO 20 (Piramal Hc.)'
);

-- line #17274
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISOACT 20 (Active Hc.)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISOACT 20 (Active Hc.)'
);

-- line #17275
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISOBAX 30 (Ranbaxy)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg(ISOSORBIDE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISOBAX 30 (Ranbaxy)'
);

-- line #17276
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISOBAX 60 (Ranbaxy)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg(ISOSORBIDE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISOBAX 60 (Ranbaxy)'
);

-- line #17277
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISOCOR 40 (Merck)',
	'Isosorbide-5 Mononitrate',
	'SR TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISOCOR 40 (Merck)'
);

-- line #17278
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISOCOR 20 (Merck)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISOCOR 20 (Merck)'
);

-- line #17279
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISOMEG 20 (N.A.)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISOMEG 20 (N.A.)'
);

-- line #17280
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISOMIN 20 (Cipla)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISOMIN 20 (Cipla)'
);

-- line #17281
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISONIT 20 (TASMED)',
	'Isosorbide-5 Mononitrate',
	'SR TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISONIT 20 (TASMED)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISONIT 30 (TASMED)',
	'Isosorbide-5 Mononitrate',
	'SR TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISONIT 30 (TASMED)'
);

-- line #17282
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Isosorbide-5 Mononitrate', u'always_empty': u'', u'form': u'SR TAB', u'brand': u'ISONORM', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #17283
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISONORM 10 (Lupin)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISONORM 10 (Lupin)'
);

-- line #17284
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISONORM 20 (Lupin)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISONORM 20 (Lupin)'
);

-- line #17285
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISONORM 30 (Lupin)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISONORM 30 (Lupin)'
);

-- line #17286
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISOTEC 10 (Sertec)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISOTEC 10 (Sertec)'
);

-- line #17287
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISOTEC 20 (Sertec)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISOTEC 20 (Sertec)'
);

-- line #17288
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONET 10 (Mapra)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONET 10 (Mapra)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONET 20 (Mapra)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONET 20 (Mapra)'
);

-- line #17289
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONICOR 20 (Wallace)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONICOR 20 (Wallace)'
);

-- line #17290
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONISTAC 10 (Stallion)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONISTAC 10 (Stallion)'
);

-- line #17291
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONISTAC 20 (Stallion)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONISTAC 20 (Stallion)'
);

-- line #17292
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONIT 50 (Intas)',
	'Isosorbide-5 Mononitrate',
	'OD TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONIT 50 (Intas)'
);

-- line #17293
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONIT 30 (Intas)',
	'Isosorbide-5 Mononitrate',
	'SR TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONIT 30 (Intas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONIT 60 (Intas)',
	'Isosorbide-5 Mononitrate',
	'SR TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONIT 60 (Intas)'
);

-- line #17294
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONIT 50 (Intas)',
	'Isosorbide-5 Mononitrate',
	'SR TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONIT 50 (Intas)'
);

-- line #17295
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONIT 10 (Intas)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONIT 10 (Intas)'
);

-- line #17296
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONIT 20 (Intas)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONIT 20 (Intas)'
);

-- line #17297
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONN 50 (Sun)',
	'Isosorbide-5 Mononitrate',
	'CD TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONN 50 (Sun)'
);

-- line #17298
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONN 10 (Sun)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONN 10 (Sun)'
);

-- line #17299
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONN 20 (Sun)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONN 20 (Sun)'
);

-- line #17300
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOBID 20 (Lincoln)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOBID 20 (Lincoln)'
);

-- line #17301
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOCONTIN 25 (Win-Medicare)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOCONTIN 25 (Win-Medicare)'
);

-- line #17302
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOCONTIN 50 (Win-Medicare)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOCONTIN 50 (Win-Medicare)'
);

-- line #17303
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOPARK 10 (Pfizer)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOPARK 10 (Pfizer)'
);

-- line #17304
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOPARK 20 (Pfizer)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOPARK 20 (Pfizer)'
);

-- line #17305
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOPARK 40 (Pfizer)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOPARK 40 (Pfizer)'
);

-- line #17306
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOS-20 20 (Royal)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOS-20 20 (Royal)'
);

-- line #17307
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOSORBITRATE 50 (Nicholas)',
	'Isosorbide-5 Mononitrate',
	'CR TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOSORBITRATE 50 (Nicholas)'
);

-- line #17308
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOSORBITRATE 30 (Nicholas)',
	'Isosorbide-5 Mononitrate',
	'OD TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg( DILUTED ISOSORBIDE MONONITRATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOSORBITRATE 30 (Nicholas)'
);

-- line #17309
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOSORBITRATE 10 (Piramal Hc.)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOSORBITRATE 10 (Piramal Hc.)'
);

-- line #17310
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOSORBITRATE 20 (Piramal Hc.)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOSORBITRATE 20 (Piramal Hc.)'
);

-- line #17311
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONO 10 (Biochem)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONO 10 (Biochem)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONO 20 (Biochem)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONO 20 (Biochem)'
);

-- line #17312
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOTRACE 10 (EAST WEST)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOTRACE 10 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOTRACE 20 (EAST WEST)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOTRACE 20 (EAST WEST)'
);

-- line #17313
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOTRATE 25 (Sun)',
	'Isosorbide-5 Mononitrate',
	'OD TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOTRATE 25 (Sun)'
);

-- line #17314
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOTRATE 50 (Sun)',
	'Isosorbide-5 Mononitrate',
	'OD TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOTRATE 50 (Sun)'
);

-- line #17315
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOTRATE 10 (Sun)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOTRATE 10 (Sun)'
);

-- line #17316
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOTRATE 20 (Sun)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOTRATE 20 (Sun)'
);

-- line #17317
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOTRATE 40 (Sun)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOTRATE 40 (Sun)'
);

-- line #17318
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOTRATE 50 (Sun)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOTRATE 50 (Sun)'
);

-- line #17319
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NICAN 40 (R.B.)',
	'Isosorbide-5 Mononitrate',
	'CR TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NICAN 40 (R.B.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NICAN 60 (R.B.)',
	'Isosorbide-5 Mononitrate',
	'CR TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NICAN 60 (R.B.)'
);

-- line #17320
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITROFIRST 10 (SINSAN PH.)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITROFIRST 10 (SINSAN PH.)'
);

-- line #17321
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITROFIRST 20 (SINSAN PH.)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITROFIRST 20 (SINSAN PH.)'
);

-- line #17322
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITROFIRST 30 (SINSAN PH.)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITROFIRST 30 (SINSAN PH.)'
);

-- line #17323
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITROFIRST 60 (SINSAN PH.)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITROFIRST 60 (SINSAN PH.)'
);

-- line #17324
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITROFIX 30 (Cardicare)',
	'Isosorbide-5 Mononitrate',
	'SR TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITROFIX 30 (Cardicare)'
);

-- line #17325
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITROFIX 10 (Cardicare)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITROFIX 10 (Cardicare)'
);

-- line #17326
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITROFIX 20 (Cardicare)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITROFIX 20 (Cardicare)'
);

-- line #17327
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITROFIX 30 (Cardicare)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITROFIX 30 (Cardicare)'
);

-- line #17328
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITROFIX 60 (Cardicare)',
	'Isosorbide-5 Mononitrate',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITROFIX 60 (Cardicare)'
);

-- line #17329
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITROVAS 30 (Argus)',
	'Isosorbide-5 Mononitrate',
	'SR TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITROVAS 30 (Argus)'
);

-- line #17330
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITROVAS 60 (Argus)',
	'Isosorbide-5 Mononitrate',
	'SR TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITROVAS 60 (Argus)'
);

-- line #17331
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANZIDIN 5 (Stadmed)',
	'Isosorbide Dinitrate',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANZIDIN 5 (Stadmed)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANZIDIN 10 (Stadmed)',
	'Isosorbide Dinitrate',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANZIDIN 10 (Stadmed)'
);

-- line #17332
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDICAP 10 (Natco Ph.)',
	'Isosorbide Dinitrate',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDICAP 10 (Natco Ph.)'
);

-- line #17333
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDICAP-TR 20 (Natco Ph.)',
	'Isosorbide Dinitrate',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDICAP-TR 20 (Natco Ph.)'
);

-- line #17334
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDICAP-TR 40 (Natco Ph.)',
	'Isosorbide Dinitrate',
	'CAP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDICAP-TR 40 (Natco Ph.)'
);

-- line #17335
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200 MET.', u'strength_2': u'', u'substance': u'Isosorbide Dinitrate', u'always_empty': u'', u'form': u'', u'brand': u'DINOSPRAY', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #17336
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DITRATE 20 (Panacea)',
	'Isosorbide Dinitrate',
	'SR TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DITRATE 20 (Panacea)'
);

-- line #17337
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DITRATE 40 (Panacea)',
	'Isosorbide Dinitrate',
	'SR TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DITRATE 40 (Panacea)'
);

-- line #17338
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DITRATE 10 (Panacea)',
	'Isosorbide Dinitrate',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DITRATE 10 (Panacea)'
);

-- line #17339
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DITRATE 5 (Panacea)',
	'Isosorbide Dinitrate',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DITRATE 5 (Panacea)'
);

-- line #17340
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISORDIL 10 (Wyeth)',
	'Isosorbide Dinitrate',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISORDIL 10 (Wyeth)'
);

-- line #17341
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISORDIL 5 (Wyeth)',
	'Isosorbide Dinitrate',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISORDIL 5 (Wyeth)'
);

-- line #17342
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACNESTAR 20 (LIFESTAR)',
	'ISOTRETINOIN',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACNESTAR 20 (LIFESTAR)'
);

-- line #17343
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACNEX 20 (Unichem)',
	'ISOTRETINOIN',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACNEX 20 (Unichem)'
);

-- line #17344
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACNO 10 (Ajanta Ph.)',
	'ISOTRETINOIN',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACNO 10 (Ajanta Ph.)'
);

-- line #17345
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTAME 10 (SOL DERMA)',
	'ISOTRETINOIN',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTAME 10 (SOL DERMA)'
);

-- line #17346
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTAME 20 (SOL DERMA)',
	'ISOTRETINOIN',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTAME 20 (SOL DERMA)'
);

-- line #17347
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5', u'strength_2': u'', u'substance': u'ISOTRETINOIN', u'always_empty': u'', u'form': u'', u'brand': u'ACTAME', u'strength_3': u'', u'company': u'SOL DERMA', u'unit': u'mg'}

-- line #17348
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AC-TIT 20 (Aldok Ph.)',
	'ISOTRETINOIN',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AC-TIT 20 (Aldok Ph.)'
);

-- line #17349
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACUTRET 10 (Ipca)',
	'ISOTRETINOIN',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'20'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACUTRET 10 (Ipca)'
);

-- line #17350
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACUTRET 5 (Ipca)',
	'ISOTRETINOIN',
	'CAP',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACUTRET 5 (Ipca)'
);

-- line #17351
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHITRET 20 (ETHINAXT PHARMA)',
	'ISOTRETINOIN',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHITRET 20 (ETHINAXT PHARMA)'
);

-- line #17352
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHIZINE 10 (ETHINEXT PHARMA)',
	'ISOTRETINOIN',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHIZINE 10 (ETHINEXT PHARMA)'
);

-- line #17353
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETINO 0.05 (KIVI LABS)',
	'ISOTRETINOIN',
	'CAP',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETINO 0.05 (KIVI LABS)'
);

-- line #17354
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IRET 20 (Cosme Hc.)',
	'ISOTRETINOIN',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IRET 20 (Cosme Hc.)'
);

-- line #17355
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISAC 10 (Systopic)',
	'ISOTRETINOIN',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISAC 10 (Systopic)'
);

-- line #17356
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISAC 20 (Systopic)',
	'ISOTRETINOIN',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISAC 20 (Systopic)'
);

-- line #17357
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'ISOTRETINOIN', u'always_empty': u'', u'form': u'', u'brand': u'ISO-ARET SOFGELS', u'strength_3': u'', u'company': u'Shalaks', u'unit': u'mg'}

-- line #17358
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISOBEST 10 (Gracewell)',
	'ISOTRETINOIN',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISOBEST 10 (Gracewell)'
);

-- line #17359
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISOBEST 20 (Gracewell)',
	'ISOTRETINOIN',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISOBEST 20 (Gracewell)'
);

-- line #17360
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISO CLEAR 20 (DATUM LAB.)',
	'ISOTRETINOIN',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISO CLEAR 20 (DATUM LAB.)'
);

-- line #17361
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISOIN 10 (Wallace)',
	'ISOTRETINOIN',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISOIN 10 (Wallace)'
);

-- line #17362
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISOIN 20 (Wallace)',
	'ISOTRETINOIN',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISOIN 20 (Wallace)'
);

-- line #17363
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISOPIL 10 (Glow derma)',
	'ISOTRETINOIN',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISOPIL 10 (Glow derma)'
);

-- line #17364
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISOPIL 20 (Glow derma)',
	'ISOTRETINOIN',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISOPIL 20 (Glow derma)'
);

-- line #17365
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISOPIL 5 (GLOWDERMA)',
	'ISOTRETINOIN',
	'CAP',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISOPIL 5 (GLOWDERMA)'
);

-- line #17366
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISORET 10 (Tripada)',
	'ISOTRETINOIN',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISORET 10 (Tripada)'
);

-- line #17367
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISORET 20 (Tripada)',
	'ISOTRETINOIN',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISORET 20 (Tripada)'
);

-- line #17368
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISOTANE 10 (Micro V.)',
	'ISOTRETINOIN',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISOTANE 10 (Micro V.)'
);

-- line #17369
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISOTANE 20 (Micro V.)',
	'ISOTRETINOIN',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISOTANE 20 (Micro V.)'
);

-- line #17370
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISOTIT 10 (Satyam)',
	'ISOTRETINOIN',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISOTIT 10 (Satyam)'
);

-- line #17371
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISOTIT 20 (Satyam)',
	'ISOTRETINOIN',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISOTIT 20 (Satyam)'
);

-- line #17372
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'ISOTRETINOIN', u'always_empty': u'', u'form': u'', u'brand': u'ISOTRET', u'strength_3': u'', u'company': u'Liva Hc.', u'unit': u''}

-- line #17373
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISOTRIZ 10 (Ritz Ph.)',
	'ISOTRETINOIN',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISOTRIZ 10 (Ritz Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISOTRIZ 20 (Ritz Ph.)',
	'ISOTRETINOIN',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISOTRIZ 20 (Ritz Ph.)'
);

-- line #17374
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISOTROIN 10 (Cipla)',
	'ISOTRETINOIN',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISOTROIN 10 (Cipla)'
);

-- line #17375
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISOTROIN 20 (Cipla)',
	'ISOTRETINOIN',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISOTROIN 20 (Cipla)'
);

-- line #17376
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEUTIN 20 (OREVA DARMO.)',
	'ISOTRETINOIN',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEUTIN 20 (OREVA DARMO.)'
);

-- line #17377
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCTORET 10 (Ochoa)',
	'ISOTRETINOIN',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCTORET 10 (Ochoa)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCTORET 20 (Ochoa)',
	'ISOTRETINOIN',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCTORET 20 (Ochoa)'
);

-- line #17378
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORARET 10 (Palsons)',
	'ISOTRETINOIN',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORARET 10 (Palsons)'
);

-- line #17379
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORARET 20 (Palsons)',
	'ISOTRETINOIN',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORARET 20 (Palsons)'
);

-- line #17380
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESOTEN 10 (KLM LAB.)',
	'ISOTRETINOIN',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESOTEN 10 (KLM LAB.)'
);

-- line #17381
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADILIN 40 (LINCOIN)',
	'Isoxsuprine Hcl.',
	'SR TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADILIN 40 (LINCOIN)'
);

-- line #17382
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALVASO 40 (ALPHA TH.)',
	'Isoxsuprine Hcl.',
	'SR TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALVASO 40 (ALPHA TH.)'
);

-- line #17383
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALVASO 10 (ALPHA TH.)',
	'Isoxsuprine Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALVASO 10 (ALPHA TH.)'
);

-- line #17384
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DESLAN 40 (Destin Lab)',
	'Isoxsuprine Hcl.',
	'SR TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DESLAN 40 (Destin Lab)'
);

-- line #17385
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DESLAN 10 (Destin Lab)',
	'Isoxsuprine Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DESLAN 10 (Destin Lab)'
);

-- line #17386
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DULOVAS 40 (Intra(INVISION))',
	'Isoxsuprine Hcl.',
	'SR TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DULOVAS 40 (Intra(INVISION))'
);

-- line #17387
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DULOVAS 10 (Intra(INVISION))',
	'Isoxsuprine Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DULOVAS 10 (Intra(INVISION))'
);

-- line #17388
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DULOVAS 20 (Intra(INVISION))',
	'Isoxsuprine Hcl.',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DULOVAS 20 (Intra(INVISION))'
);

-- line #17389
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUVADILAN 5 (Solvay Ph.)',
	'Isoxsuprine Hcl.',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUVADILAN 5 (Solvay Ph.)'
);

-- line #17390
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUVADILAN 40 (Solvay Ph.)',
	'Isoxsuprine Hcl.',
	'SR CAP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUVADILAN 40 (Solvay Ph.)'
);

-- line #17391
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUVADILAN 10 (Solvay Ph.)',
	'Isoxsuprine Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUVADILAN 10 (Solvay Ph.)'
);

-- line #17392
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYDILAN 40 (BIOKIND HC.)',
	'Isoxsuprine Hcl.',
	'SR TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYDILAN 40 (BIOKIND HC.)'
);

-- line #17393
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ECSOPRIN 40 (Ecstacy)',
	'Isoxsuprine Hcl.',
	'SR TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ECSOPRIN 40 (Ecstacy)'
);

-- line #17394
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FISOX 40 (Forgo Ph.)',
	'Isoxsuprine Hcl.',
	'SR TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FISOX 40 (Forgo Ph.)'
);

-- line #17395
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GESTAKIND 40 (LIFESTAR)',
	'Isoxsuprine Hcl.',
	'SR CAP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GESTAKIND 40 (LIFESTAR)'
);

-- line #17396
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GESTAKIND 10 (LIFESTAR)',
	'Isoxsuprine Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GESTAKIND 10 (LIFESTAR)'
);

-- line #17397
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GYLAN 40 (Cadex Lab)',
	'Isoxsuprine Hcl.',
	'SR TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GYLAN 40 (Cadex Lab)'
);

-- line #17398
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HERDILAN 40 (Torrent)',
	'Isoxsuprine Hcl.',
	'SR TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HERDILAN 40 (Torrent)'
);

-- line #17399
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INOX 40 (Goodrich)',
	'Isoxsuprine Hcl.',
	'SR TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INOX 40 (Goodrich)'
);

-- line #17400
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IORIL 10 (Zee Lab)',
	'Isoxsuprine Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IORIL 10 (Zee Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IORIL 40 (Zee Lab)',
	'Isoxsuprine Hcl.',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IORIL 40 (Zee Lab)'
);

-- line #17401
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISARIN 40 (Zenon Hc.)',
	'Isoxsuprine Hcl.',
	'SR TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISARIN 40 (Zenon Hc.)'
);

-- line #17402
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISCOM 5 (Comed)',
	'Isoxsuprine Hcl.',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISCOM 5 (Comed)'
);

-- line #17403
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISCOM 40 (Comed Chem.)',
	'Isoxsuprine Hcl.',
	'SR SR CAP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISCOM 40 (Comed Chem.)'
);

-- line #17404
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISO-10 10 (Zee Lab)',
	'Isoxsuprine Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISO-10 10 (Zee Lab)'
);

-- line #17405
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISOMIN 10 (PHARMIN)',
	'Isoxsuprine Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISOMIN 10 (PHARMIN)'
);

-- line #17406
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISOPREG 10 (AKUMENTIS HC.)',
	'Isoxsuprine Hcl.',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISOPREG 10 (AKUMENTIS HC.)'
);

-- line #17407
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISOPREG 10 (Global Med.)',
	'Isoxsuprine Hcl.',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISOPREG 10 (Global Med.)'
);

-- line #17408
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISOPREG 40 (AKUMENTIS HC.)',
	'Isoxsuprine Hcl.',
	'SR TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISOPREG 40 (AKUMENTIS HC.)'
);

-- line #17409
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISOPRIX 10 (Dial Ph.)',
	'Isoxsuprine Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISOPRIX 10 (Dial Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISOPRIX 20 (Dial Ph.)',
	'Isoxsuprine Hcl.',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISOPRIX 20 (Dial Ph.)'
);

-- line #17410
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISOWEL 40 (WELSTAR LS.)',
	'Isoxsuprine Hcl.',
	'SR TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISOWEL 40 (WELSTAR LS.)'
);

-- line #17411
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISOWEL 10 (WELSTAR LS.)',
	'Isoxsuprine Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISOWEL 10 (WELSTAR LS.)'
);

-- line #17412
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISOXIN 40 (BRILLIAN PH.)',
	'Isoxsuprine Hcl.',
	'SR TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISOXIN 40 (BRILLIAN PH.)'
);

-- line #17413
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISOX 40 (Stanmark)',
	'Isoxsuprine Hcl.',
	'SR TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISOX 40 (Stanmark)'
);

-- line #17414
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYPROX 40 (Radix Bio.)',
	'Isoxsuprine Hcl.',
	'SR TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYPROX 40 (Radix Bio.)'
);

-- line #17415
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLDILAN 40 (Evacare)',
	'Isoxsuprine Hcl.',
	'SR TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLDILAN 40 (Evacare)'
);

-- line #17416
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORDILAN 10 (Ordain Hc.)',
	'Isoxsuprine Hcl.',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORDILAN 10 (Ordain Hc.)'
);

-- line #17417
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORDILAN 40 (Ordain Hc.)',
	'Isoxsuprine Hcl.',
	'RETARD',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORDILAN 40 (Ordain Hc.)'
);

-- line #17418
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERIVALAN 10 (TABLETS I.)',
	'Isoxsuprine Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERIVALAN 10 (TABLETS I.)'
);

-- line #17419
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGLAN 5 (Speciality Med.)',
	'Isoxsuprine Hcl.',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGLAN 5 (Speciality Med.)'
);

-- line #17420
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGLAN 10 (Speciality Med.)',
	'Isoxsuprine Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGLAN 10 (Speciality Med.)'
);

-- line #17421
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGLAN 20 (Speciality Med.)',
	'Isoxsuprine Hcl.',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGLAN 20 (Speciality Med.)'
);

-- line #17422
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGLAN 40 (Speciality Med.)',
	'Isoxsuprine Hcl.',
	'TABSR',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGLAN 40 (Speciality Med.)'
);

-- line #17423
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGNADILAN 40 (Stanmark)',
	'Isoxsuprine Hcl.',
	'SR TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGNADILAN 40 (Stanmark)'
);

-- line #17424
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Isoxsuprine Hcl.', u'always_empty': u'', u'form': u'CAP', u'brand': u'PREGNIN RETARD', u'strength_3': u'', u'company': u'Overseas Hc.', u'unit': u''}

-- line #17425
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGNIN 10 (Overseas Hc.)',
	'Isoxsuprine Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGNIN 10 (Overseas Hc.)'
);

-- line #17426
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIDILAN 40 (Guj.Terce)',
	'Isoxsuprine Hcl.',
	'SR TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIDILAN 40 (Guj.Terce)'
);

-- line #17427
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIDILAN 10 (Guj.Terce)',
	'Isoxsuprine Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIDILAN 10 (Guj.Terce)'
);

-- line #17428
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIDILAN 20 (Guj.Terce)',
	'Isoxsuprine Hcl.',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIDILAN 20 (Guj.Terce)'
);

-- line #17429
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Ispaghula Husk', u'always_empty': u'', u'form': u'POW', u'brand': u'ALLSOFT', u'strength_3': u'', u'company': u'Aldok Ph.', u'unit': u''}

-- line #17430
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3.5GM', u'strength_2': u'', u'substance': u'Ispaghula Husk', u'always_empty': u'', u'form': u'POW', u'brand': u'BOWLAX', u'strength_3': u'', u'company': u'Stanmark', u'unit': u''}

-- line #17431
-- ignoring line: field [strength_1] not numeric: >>>47+HARITAKI 4<<<
-- {u'list_of_values_of_unknown_fields': [u'AMALTAS 3; ', u' %', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'47+HARITAKI 4', u'strength_2': u'', u'substance': u'Ispaghula Husk', u'always_empty': u'', u'form': u'POW', u'brand': u'CONSTIVAC', u'strength_3': u'', u'company': u'Lupin', u'unit': u'%'}

-- line #17432
-- ignoring line: field [strength_1] not numeric: >>>4.8G+NA 3.3<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'4.8G+NA 3.3', u'strength_2': u'', u'substance': u'Ispaghula Husk', u'always_empty': u'', u'form': u'GRAN', u'brand': u'CREMADIET', u'strength_3': u'', u'company': u'ABBOTT', u'unit': u'mg'}

-- line #17433
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3.5GPER 14.25G', u'strength_2': u'', u'substance': u'Ispaghula Husk', u'always_empty': u'', u'form': u'POW', u'brand': u'CREMAFFIN-FS', u'strength_3': u'', u'company': u'ABBOTT', u'unit': u''}

-- line #17434
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Ispaghula Husk', u'always_empty': u'', u'form': u'POW', u'brand': u'DICARE', u'strength_3': u'', u'company': u'Cubit Hc.', u'unit': u''}

-- line #17435
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I (WITH SENNA POW.)', u'strength_2': u'', u'substance': u'Ispaghula Husk', u'always_empty': u'', u'form': u'POW', u'brand': u'ECTILAX', u'strength_3': u'', u'company': u'Ecstacy', u'unit': u''}

-- line #17436
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Ispaghula Husk', u'always_empty': u'', u'form': u'POW', u'brand': u'EVA-Q', u'strength_3': u'', u'company': u'Medley', u'unit': u''}

-- line #17437
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'066G', u'strength_2': u'G', u'substance': u'Ispaghula Husk', u'always_empty': u'', u'form': u'POW', u'brand': u'EZEFLO', u'strength_3': u'', u'company': u'AXYZEN LIFE', u'unit': u''}

-- line #17438
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u' %', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'64.5WITH SARJIKA KSHAR 8.5', u'strength_2': u'', u'substance': u'Ispaghula Husk', u'always_empty': u'', u'form': u'', u'brand': u'EZYGO BOTTLE', u'strength_3': u'', u'company': u'KADAM HC.', u'unit': u'%'}

-- line #17439
-- ignoring line: field [strength_1] not numeric: >>>64.5WITH SARJIKA KSHAR 8.5<<<
-- {u'list_of_values_of_unknown_fields': [u' %', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'64.5WITH SARJIKA KSHAR 8.5', u'strength_2': u'', u'substance': u'Ispaghula Husk', u'always_empty': u'', u'form': u'SAC', u'brand': u'EZYGO', u'strength_3': u'', u'company': u'KADAM HC.', u'unit': u'%'}

-- line #17440
-- ignoring line: field [strength_1] not numeric: >>>3.5GM (+SARJIKA KESHAR 0.45G<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3.5GM (+SARJIKA KESHAR 0.45G', u'strength_2': u'', u'substance': u'Ispaghula Husk', u'always_empty': u'', u'form': u'POW', u'brand': u'FABOLITE', u'strength_3': u'', u'company': u'Nicholas', u'unit': u'NIMBU SATVA 0.48G)'}

-- line #17441
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3.5G', u'strength_2': u'4G', u'substance': u'Ispaghula Husk', u'always_empty': u'', u'form': u'POW', u'brand': u'FIBRADIET', u'strength_3': u'', u'company': u'Gsk', u'unit': u''}

-- line #17442
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIBRIL 65 (Lupin)',
	'Ispaghula Husk',
	'POW',
	gm.nullify_empty_string('65')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIBRIL 65 (Lupin)'
);

-- line #17443
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIBRIL 85.57 (Lupin)',
	'Ispaghula Husk',
	'SF POW',
	gm.nullify_empty_string('85.57')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIBRIL 85.57 (Lupin)'
);

-- line #17444
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'WITH METHYL CELLULOSE', u'strength_2': u'', u'substance': u'Ispaghula Husk', u'always_empty': u'', u'form': u'POW', u'brand': u'FIBROPIL', u'strength_3': u'', u'company': u'PIL', u'unit': u''}

-- line #17445
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3.5G', u'strength_2': u'5.4G', u'substance': u'Ispaghula Husk', u'always_empty': u'', u'form': u'GRAN', u'brand': u'FYBOGEL', u'strength_3': u'', u'company': u'Reckitt B.', u'unit': u''}

-- line #17446
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'85', u'strength_2': u'', u'substance': u'Ispaghula Husk', u'always_empty': u'', u'form': u'', u'brand': u'IGOL-D', u'strength_3': u'', u'company': u'R.B.', u'unit': u'%(SF)'}

-- line #17447
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Ispaghula Husk', u'always_empty': u'', u'form': u'', u'brand': u'IGOL PEARL', u'strength_3': u'', u'company': u'R.B.', u'unit': u''}

-- line #17448
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.66G', u'strength_2': u'', u'substance': u'Ispaghula Husk', u'always_empty': u'', u'form': u'POW', u'brand': u'IGOL', u'strength_3': u'', u'company': u'R.B.', u'unit': u''}

-- line #17449
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3.5G', u'strength_2': u'5.6G', u'substance': u'Ispaghula Husk', u'always_empty': u'', u'form': u'POW', u'brand': u'INULAX', u'strength_3': u'', u'company': u'IRM PH.', u'unit': u''}

-- line #17450
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Ispaghula Husk', u'always_empty': u'', u'form': u'POW', u'brand': u'ISADIET', u'strength_3': u'', u'company': u'Marc Lab', u'unit': u''}

-- line #17451
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Ispaghula Husk', u'always_empty': u'', u'form': u'', u'brand': u'ISBIS ISABGOL WAFERS', u'strength_3': u'', u'company': u'Zydus Cadila', u'unit': u''}

-- line #17452
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'27G', u'strength_2': u'30G', u'substance': u'Ispaghula Husk', u'always_empty': u'', u'form': u'GRAN', u'brand': u'ISOGEL', u'strength_3': u'', u'company': u'Gsk', u'unit': u''}

-- line #17453
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3.5G', u'strength_2': u'5.6G', u'substance': u'Ispaghula Husk', u'always_empty': u'', u'form': u'POW', u'brand': u'ITWORKS', u'strength_3': u'', u'company': u'Intas', u'unit': u''}

-- line #17454
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5.6GM', u'strength_2': u'', u'substance': u'Ispaghula Husk', u'always_empty': u'', u'form': u'SAC', u'brand': u'ITWORKS', u'strength_3': u'', u'company': u'Intas', u'unit': u''}

-- line #17455
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAXATAUR 650 (Taurus Lab)',
	'Ispaghula Husk',
	'GRAN',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAXATAUR 650 (Taurus Lab)'
);

-- line #17456
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3.125G', u'strength_2': u'', u'substance': u'Ispaghula Husk', u'always_empty': u'', u'form': u'POW', u'brand': u'LAXOVEL', u'strength_3': u'', u'company': u'Kinedex Hc.', u'unit': u''}

-- line #17457
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Ispaghula Husk', u'always_empty': u'', u'form': u'POW', u'brand': u'NATURLAX', u'strength_3': u'', u'company': u'NIVCA', u'unit': u''}

-- line #17458
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3.5G', u'strength_2': u'5.6G', u'substance': u'Ispaghula Husk', u'always_empty': u'', u'form': u'POW', u'brand': u'NATUROLAX', u'strength_3': u'', u'company': u'Infar', u'unit': u''}

-- line #17459
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3.5G;3.6G', u'strength_2': u'', u'substance': u'Ispaghula Husk', u'always_empty': u'', u'form': u'SF POW', u'brand': u'NATUROLAX', u'strength_3': u'', u'company': u'Infar', u'unit': u''}

-- line #17460
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3.75G', u'strength_2': u'', u'substance': u'Ispaghula Husk', u'always_empty': u'', u'form': u'GRAN', u'brand': u'PREGNALAX', u'strength_3': u'', u'company': u'Meyer Org.', u'unit': u''}

-- line #17461
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PSYLAX 520 (Inga)',
	'Ispaghula Husk',
	'CAP',
	gm.nullify_empty_string('520')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PSYLAX 520 (Inga)'
);

-- line #17462
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMPTY 50 (Mark Rem.)',
	'ITOPRIDE',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMPTY 50 (Mark Rem.)'
);

-- line #17463
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GANATON 150 (Abbott)',
	'ITOPRIDE',
	'OD CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GANATON 150 (Abbott)'
);

-- line #17464
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GANATON 50 (Abbott)',
	'ITOPRIDE',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GANATON 50 (Abbott)'
);

-- line #17465
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEPRIDE 50 (Intra Lab)',
	'ITOPRIDE',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEPRIDE 50 (Intra Lab)'
);

-- line #17466
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GIMATE 50 (Systopic)',
	'ITOPRIDE',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GIMATE 50 (Systopic)'
);

-- line #17467
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GITRAK 50 (Ferring Ph.)',
	'ITOPRIDE',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GITRAK 50 (Ferring Ph.)'
);

-- line #17468
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GI-TUNE 150 (INTAS)',
	'ITOPRIDE',
	'SR TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GI-TUNE 150 (INTAS)'
);

-- line #17469
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'ITOPRIDE', u'always_empty': u'', u'form': u'TAB', u'brand': u'GI-TUNE', u'strength_3': u'', u'company': u'INTAS', u'unit': u''}

-- line #17470
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ITCAN 150 (Genx Ph.)',
	'ITOPRIDE',
	'SR CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ITCAN 150 (Genx Ph.)'
);

-- line #17471
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ITCAN 50 (Genx Ph.)',
	'ITOPRIDE',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ITCAN 50 (Genx Ph.)'
);

-- line #17472
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ITOFLUX 50 (Aristo)',
	'ITOPRIDE',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ITOFLUX 50 (Aristo)'
);

-- line #17473
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ITOGUARD 50 (Shreya)',
	'ITOPRIDE',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ITOGUARD 50 (Shreya)'
);

-- line #17474
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ITOKINE-T 50 (Zydus Cadila)',
	'ITOPRIDE',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ITOKINE-T 50 (Zydus Cadila)'
);

-- line #17475
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ITOMIS 50 (MISSION RES.)',
	'ITOPRIDE',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ITOMIS 50 (MISSION RES.)'
);

-- line #17476
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ITONORM 50 (Gufic Bio.)',
	'ITOPRIDE',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ITONORM 50 (Gufic Bio.)'
);

-- line #17477
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ITOPRID 150 (CIPLA)',
	'ITOPRIDE',
	'SR CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ITOPRID 150 (CIPLA)'
);

-- line #17478
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ITOPRID 50 (Cipla)',
	'ITOPRIDE',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ITOPRID 50 (Cipla)'
);

-- line #17479
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ITOTOR 150 (Torrent)',
	'ITOPRIDE',
	'OD SR TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ITOTOR 150 (Torrent)'
);

-- line #17480
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ITOZ 50 (Wallace)',
	'ITOPRIDE',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ITOZ 50 (Wallace)'
);

-- line #17481
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ITZA 50 (Irm Ph.)',
	'ITOPRIDE',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ITZA 50 (Irm Ph.)'
);

-- line #17482
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'ITOPRIDE', u'always_empty': u'', u'form': u'TAB', u'brand': u'MOTIZA', u'strength_3': u'', u'company': u'AUSTER', u'unit': u''}

-- line #17483
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOSIB 150 (Franco I.)',
	'ITOPRIDE',
	'XR CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg S.R.'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOSIB 150 (Franco I.)'
);

-- line #17484
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'ITOPRIDE', u'always_empty': u'', u'form': u'CAP', u'brand': u'OPRIDE', u'strength_3': u'', u'company': u'MEDISYS', u'unit': u''}

-- line #17485
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RETRIDE 50 (Unichem)',
	'ITOPRIDE',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RETRIDE 50 (Unichem)'
);

-- line #17486
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RETUNE 50 (Zuventus)',
	'ITOPRIDE',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RETUNE 50 (Zuventus)'
);

-- line #17487
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOSPORE 100 (BIOSCIENCES)',
	'Itraconazole',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOSPORE 100 (BIOSCIENCES)'
);

-- line #17488
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANDISTAT 100 (Merck)',
	'Itraconazole',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANDISTAT 100 (Merck)'
);

-- line #17489
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANDITRAL 100 (Glenmark)',
	'Itraconazole',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANDITRAL 100 (Glenmark)'
);

-- line #17490
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAPITRA 100 (ALDERMAT PH.)',
	'Itraconazole',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAPITRA 100 (ALDERMAT PH.)'
);

-- line #17491
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUCOVER 100 (Saga Lab)',
	'Itraconazole',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUCOVER 100 (Saga Lab)'
);

-- line #17492
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FULCOVER 100 (Saga Lab)',
	'Itraconazole',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FULCOVER 100 (Saga Lab)'
);

-- line #17493
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNGITRACE 100 (Lifecare)',
	'Itraconazole',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNGITRACE 100 (Lifecare)'
);

-- line #17494
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ICOZ 100 (Raddison Hc.)',
	'Itraconazole',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ICOZ 100 (Raddison Hc.)'
);

-- line #17495
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ITASPOR 100 (Intas)',
	'Itraconazole',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ITASPOR 100 (Intas)'
);

-- line #17496
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Itraconazole', u'always_empty': u'', u'form': u'INJ', u'brand': u'ITASPOR', u'strength_3': u'', u'company': u'Intas', u'unit': u''}

-- line #17497
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ITRA 100 (EAST WEST)',
	'Itraconazole',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ITRA 100 (EAST WEST)'
);

-- line #17498
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ITROLE 100 (Chemo Bio.)',
	'Itraconazole',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ITROLE 100 (Chemo Bio.)'
);

-- line #17499
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRADIA 5 (Biocon)',
	'IVABRADINE',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRADIA 5 (Biocon)'
);

-- line #17500
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRADIA 7.5 (Biocon)',
	'IVABRADINE',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRADIA 7.5 (Biocon)'
);

-- line #17501
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5', u'strength_2': u'', u'substance': u'IVABRADINE', u'always_empty': u'', u'form': u'', u'brand': u'CORALAN', u'strength_3': u'', u'company': u'Serdia', u'unit': u'mg'}

-- line #17502
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'7,5', u'strength_2': u'', u'substance': u'IVABRADINE', u'always_empty': u'', u'form': u'', u'brand': u'CORALAN', u'strength_3': u'', u'company': u'Serdia', u'unit': u'mg'}

-- line #17503
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INAPURE 5 (Sun)',
	'IVABRADINE',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INAPURE 5 (Sun)'
);

-- line #17504
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INAPURE 7.5 (Sun)',
	'IVABRADINE',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INAPURE 7.5 (Sun)'
);

-- line #17505
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IVABID 5 (Piramal Hc.)',
	'IVABRADINE',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IVABID 5 (Piramal Hc.)'
);

-- line #17506
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IVABRAD 5 (Lupin)',
	'IVABRADINE',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IVABRAD 5 (Lupin)'
);

-- line #17507
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IVABRAD 7.5 (Lupin)',
	'IVABRADINE',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IVABRAD 7.5 (Lupin)'
);

-- line #17508
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IVANGIN 5 (Zydus Med.)',
	'IVABRADINE',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IVANGIN 5 (Zydus Med.)'
);

-- line #17509
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IVANGIN 7.5 (Zydus Med.)',
	'IVABRADINE',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IVANGIN 7.5 (Zydus Med.)'
);

-- line #17510
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IVANODE 5 (Torrent)',
	'IVABRADINE',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IVANODE 5 (Torrent)'
);

-- line #17511
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IVANODE 7.5 (Torrent)',
	'IVABRADINE',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IVANODE 7.5 (Torrent)'
);

-- line #17512
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IVAZINE 5 (Unisearch)',
	'IVABRADINE',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IVAZINE 5 (Unisearch)'
);

-- line #17513
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IVAZINE 7.5 (Unisearch)',
	'IVABRADINE',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IVAZINE 7.5 (Unisearch)'
);

-- line #17514
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RECARD 5 (Ranbaxy)',
	'IVABRADINE',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RECARD 5 (Ranbaxy)'
);

-- line #17515
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RECARD 7.5 (Ranbaxy)',
	'IVABRADINE',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RECARD 7.5 (Ranbaxy)'
);

-- line #17516
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASCAPIL 6 (Nicholas)',
	'IVERMECTIN',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASCAPIL 6 (Nicholas)'
);

-- line #17517
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVERTOL 3 (Olcare)',
	'Ivermectin',
	'TAB',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVERTOL 3 (Olcare)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVERTOL 6 (Olcare)',
	'Ivermectin',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVERTOL 6 (Olcare)'
);

-- line #17518
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EVERTIN 6 (OREVA DARMO.)',
	'Ivermectin',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EVERTIN 6 (OREVA DARMO.)'
);

-- line #17519
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMCET 6 (AXYZEN LIFE)',
	'Ivermectin',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMCET 6 (AXYZEN LIFE)'
);

-- line #17520
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMEC 12 (Cerspin)',
	'Ivermectin',
	'TAB',
	gm.nullify_empty_string('12')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMEC 12 (Cerspin)'
);

-- line #17521
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMECTIN 12 (Pulse Ph.)',
	'IVERMECTIN',
	'TAB',
	gm.nullify_empty_string('12')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMECTIN 12 (Pulse Ph.)'
);

-- line #17522
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMECTIN 3 (Pulse Ph.)',
	'IVERMECTIN',
	'TAB',
	gm.nullify_empty_string('3')::numeric,
	'6'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMECTIN 3 (Pulse Ph.)'
);

-- line #17523
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMT-6/12 6 (Aldok Ph.)',
	'Ivermectin',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMT-6/12 6 (Aldok Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMT-6/12 12 (Aldok Ph.)',
	'Ivermectin',
	'TAB',
	gm.nullify_empty_string('12')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMT-6/12 12 (Aldok Ph.)'
);

-- line #17524
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISCO 3 (Bennet Ph.)',
	'Ivermectin',
	'TAB',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISCO 3 (Bennet Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISCO 6 (Bennet Ph.)',
	'Ivermectin',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISCO 6 (Bennet Ph.)'
);

-- line #17525
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IVERCID 12 (EAST WEST)',
	'IVERMECTIN',
	'TAB',
	gm.nullify_empty_string('12')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IVERCID 12 (EAST WEST)'
);

-- line #17526
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IVERCID 3 (EAST WEST)',
	'IVERMECTIN',
	'TAB',
	gm.nullify_empty_string('3')::numeric,
	'6'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IVERCID 3 (EAST WEST)'
);

-- line #17527
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IVERMECTOL 12 (Ochoa)',
	'Ivermectin',
	'TAB',
	gm.nullify_empty_string('12')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IVERMECTOL 12 (Ochoa)'
);

-- line #17528
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IVERMECTOL 3 (Ochoa)',
	'Ivermectin',
	'TAB',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IVERMECTOL 3 (Ochoa)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IVERMECTOL 6 (Ochoa)',
	'Ivermectin',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IVERMECTOL 6 (Ochoa)'
);

-- line #17529
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IVERPIC 12 (Atopic Lab.)',
	'Ivermectin',
	'TAB',
	gm.nullify_empty_string('12')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IVERPIC 12 (Atopic Lab.)'
);

-- line #17530
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IVERPIC 6 (Atopic Lab.)',
	'Ivermectin',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IVERPIC 6 (Atopic Lab.)'
);

-- line #17531
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IVERT 12 (Tripada BIO.)',
	'Ivermectin',
	'TAB',
	gm.nullify_empty_string('12')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IVERT 12 (Tripada BIO.)'
);

-- line #17532
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IVERT 6 (Tripada BIO.)',
	'Ivermectin',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IVERT 6 (Tripada BIO.)'
);

-- line #17533
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IVMEC 6 (ADVENTUS)',
	'Ivermectin',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IVMEC 6 (ADVENTUS)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IVMEC 12 (ADVENTUS)',
	'Ivermectin',
	'TAB',
	gm.nullify_empty_string('12')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IVMEC 12 (ADVENTUS)'
);

-- line #17534
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IVORI 3 (Intra(INVISION))',
	'Ivermectin',
	'TAB',
	gm.nullify_empty_string('3')::numeric,
	'6'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IVORI 3 (Intra(INVISION))'
);

-- line #17535
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JETTA 6 (KIVI LABS)',
	'Ivermectin',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JETTA 6 (KIVI LABS)'
);

-- line #17536
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MECTIN 3 (Meridian)',
	'Ivermectin',
	'TAB',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MECTIN 3 (Meridian)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MECTIN 6 (Meridian)',
	'Ivermectin',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MECTIN 6 (Meridian)'
);

-- line #17537
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDTIN 3 (Meridian)',
	'Ivermectin',
	'TAB',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDTIN 3 (Meridian)'
);

-- line #17538
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDTIN 6 (Meridian)',
	'Ivermectin',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDTIN 6 (Meridian)'
);

-- line #17539
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORASCAB 12 (Palsons D.)',
	'Ivermectin',
	'TAB',
	gm.nullify_empty_string('12')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORASCAB 12 (Palsons D.)'
);

-- line #17540
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORASCAB 6 (PALSONS D.)',
	'Ivermectin',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORASCAB 6 (PALSONS D.)'
);

-- line #17541
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'JAPANESE ENCEPHALITIS VACCINE', u'always_empty': u'', u'form': u'VACC', u'brand': u'JENCEVAC', u'strength_3': u'', u'company': u'Shantha Bio.', u'unit': u''}

-- line #17542
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'NEW FROM CIMS BY JECKIL', u'strength_2': u'', u'substance': u'JECKIL', u'always_empty': u'', u'form': u'', u'brand': u'NEW FROM CIMS BY JECKIL', u'strength_3': u'', u'company': u'NEW FROM CIMS BY JECKIL', u'unit': u''}

-- line #17543
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EFFICIN 1000 (Lupin)',
	'Kanamycin',
	'V',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EFFICIN 1000 (Lupin)'
);

-- line #17544
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EFFICIN 500 (Lupin)',
	'Kanamycin',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EFFICIN 500 (Lupin)'
);

-- line #17545
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EFFICIN 750 (Lupin)',
	'Kanamycin',
	'V',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EFFICIN 750 (Lupin)'
);

-- line #17546
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Kanamycin', u'always_empty': u'', u'form': u'V', u'brand': u'KANAMAC', u'strength_3': u'', u'company': u'Macleods', u'unit': u''}

-- line #17547
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KANAMAC 500 (Macleods)',
	'Kanamycin',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KANAMAC 500 (Macleods)'
);

-- line #17548
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KANAMAC 750 (Macleods)',
	'Kanamycin',
	'V',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KANAMAC 750 (Macleods)'
);

-- line #17549
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Kanamycin', u'always_empty': u'', u'form': u'V', u'brand': u'KANAMYCIN', u'strength_3': u'', u'company': u'Samarth', u'unit': u''}

-- line #17550
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Kanamycin', u'always_empty': u'', u'form': u'V', u'brand': u'KANCIN', u'strength_3': u'', u'company': u'Alembic', u'unit': u''}

-- line #17551
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KANCIN 500 (Alembic)',
	'Kanamycin',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KANCIN 500 (Alembic)'
);

-- line #17552
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOKANYN 1000 (Neon)',
	'Kanamycin',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOKANYN 1000 (Neon)'
);

-- line #17553
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOKANYN 500 (Neon)',
	'Kanamycin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOKANYN 500 (Neon)'
);

-- line #17554
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOKANYN 750 (Neon)',
	'Kanamycin',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOKANYN 750 (Neon)'
);

-- line #17555
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANEKET 50 (Neon)',
	'Ketamine',
	'AMP',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANEKET 50 (Neon)'
);

-- line #17556
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANEKET 100 (Neon)',
	'Ketamine',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANEKET 100 (Neon)'
);

-- line #17557
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANEKET 10 (Neon)',
	'Ketamine',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANEKET 10 (Neon)'
);

-- line #17558
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANEKET 50 (Neon)',
	'Ketamine',
	'V',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANEKET 50 (Neon)'
);

-- line #17559
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALMOKET 50 (Csc Ph.)',
	'Ketamine',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALMOKET 50 (Csc Ph.)'
);

-- line #17560
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Ketamine', u'always_empty': u'', u'form': u'INJ', u'brand': u'HYNOKET', u'strength_3': u'', u'company': u'CH.Bhagat', u'unit': u''}

-- line #17561
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYPNOKET 500 (CH.Bhagat)',
	'Ketamine',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg/10ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYPNOKET 500 (CH.Bhagat)'
);

-- line #17562
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KATAMEN 50 (ROSE LABS)',
	'Ketamine',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KATAMEN 50 (ROSE LABS)'
);

-- line #17563
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETA 100 (Samarth)',
	'Ketamine',
	'AMP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETA 100 (Samarth)'
);

-- line #17564
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETAJET 50 (Sterfil)',
	'Ketamine',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETAJET 50 (Sterfil)'
);

-- line #17565
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETAJET 10 (Sterfil)',
	'Ketamine',
	'V',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETAJET 10 (Sterfil)'
);

-- line #17566
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETAJET 50 (Sterfil)',
	'Ketamine',
	'V',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETAJET 50 (Sterfil)'
);

-- line #17567
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETAJEX 50 (Claris L.)',
	'Ketamine',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETAJEX 50 (Claris L.)'
);

-- line #17568
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETAJEX 10 (Claris L.)',
	'Ketamine',
	'V',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETAJEX 10 (Claris L.)'
);

-- line #17569
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETALAR 50 (PFIZER)',
	'Ketamine',
	'AMP',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETALAR 50 (PFIZER)'
);

-- line #17570
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETALAR 10 (PFIZER)',
	'Ketamine',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETALAR 10 (PFIZER)'
);

-- line #17571
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETAMAX 50 (Troikaa)',
	'Ketamine',
	'AMP',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETAMAX 50 (Troikaa)'
);

-- line #17572
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETAMAX 10 (Troikaa)',
	'Ketamine',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETAMAX 10 (Troikaa)'
);

-- line #17573
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETAMAX 50 (Troikaa)',
	'Ketamine',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETAMAX 50 (Troikaa)'
);

-- line #17574
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETAMEN 50 (ROSE LABS)',
	'Ketamine',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETAMEN 50 (ROSE LABS)'
);

-- line #17575
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETAM 10 (Globus)',
	'Ketamine',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETAM 10 (Globus)'
);

-- line #17576
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETAM 50 (Globus)',
	'Ketamine',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETAM 50 (Globus)'
);

-- line #17577
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETANASE 10 (Jackson)',
	'Ketamine',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETANASE 10 (Jackson)'
);

-- line #17578
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETANASE 50 (Jackson)',
	'Ketamine',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETANASE 50 (Jackson)'
);

-- line #17579
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETAVAN 50 (Bharat S.)',
	'Ketamine',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETAVAN 50 (Bharat S.)'
);

-- line #17580
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETA 500 (Samarth)',
	'Ketamine',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETA 500 (Samarth)'
);

-- line #17581
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETMIN 10 (Themis)',
	'Ketamine',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETMIN 10 (Themis)'
);

-- line #17582
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETMIN 50 (Themis)',
	'Ketamine',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETMIN 50 (Themis)'
);

-- line #17583
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETOLIDE 50 (Indus)',
	'Ketamine',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETOLIDE 50 (Indus)'
);

-- line #17584
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETSIA 100 (CELON(REVILON))',
	'Ketamine',
	'AMP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETSIA 100 (CELON(REVILON))'
);

-- line #17585
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETSIA 500 (CELON(REVILON))',
	'Ketamine',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETSIA 500 (CELON(REVILON))'
);

-- line #17586
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETY 50 (Destin Lab)',
	'Ketamine',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETY 50 (Destin Lab)'
);

-- line #17587
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KMINE-50 50 (Jawa Ph.)',
	'Ketamine',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KMINE-50 50 (Jawa Ph.)'
);

-- line #17588
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REKITA 50 (Ind-Swift)',
	'Ketamine',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REKITA 50 (Ind-Swift)'
);

-- line #17589
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADACLIN 2 (ETHINAXT PHARMA)',
	'Ketoconazole',
	'SOAP',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADACLIN 2 (ETHINAXT PHARMA)'
);

-- line #17590
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARCOLANE SCALP 2 (Galderma)',
	'Ketoconazole',
	'SOL',
	gm.nullify_empty_string('2')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARCOLANE SCALP 2 (Galderma)'
);

-- line #17591
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATIKET 200 (ATOPIC)',
	'Ketoconazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATIKET 200 (ATOPIC)'
);

-- line #17592
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Ketoconazole', u'always_empty': u'', u'form': u'SOAP', u'brand': u'AXYTOP', u'strength_3': u'', u'company': u'AXYZEN LIFE', u'unit': u''}

-- line #17593
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHEMNIZOLE 200 (Merit Org.)',
	'Ketoconazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHEMNIZOLE 200 (Merit Org.)'
);

-- line #17594
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DANDOFF 2 (Lupin)',
	'Ketoconazole',
	'SOL',
	gm.nullify_empty_string('2')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DANDOFF 2 (Lupin)'
);

-- line #17595
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Ketoconazole', u'always_empty': u'', u'form': u'LOT', u'brand': u'DANDREX', u'strength_3': u'', u'company': u'Curex', u'unit': u''}

-- line #17596
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DANKET 2 (Dermocare)',
	'Ketoconazole',
	'LOT',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DANKET 2 (Dermocare)'
);

-- line #17597
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DANRUF 2 (Torrent)',
	'Ketoconazole',
	'SHAMPOO',
	gm.nullify_empty_string('2')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DANRUF 2 (Torrent)'
);

-- line #17598
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DENON 2 (OREVA DARMO.)',
	'Ketoconazole',
	'SHAMPOO',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DENON 2 (OREVA DARMO.)'
);

-- line #17599
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DENON 2 (OREVA DARMO.)',
	'Ketoconazole',
	'SOAP',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DENON 2 (OREVA DARMO.)'
);

-- line #17600
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DERM-KETA 20 (GALANTICA)',
	'Ketoconazole',
	'CRM',
	gm.nullify_empty_string('20')::numeric,
	'mg/G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DERM-KETA 20 (GALANTICA)'
);

-- line #17601
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUMYCOT 200 (Glow derma)',
	'Ketoconazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUMYCOT 200 (Glow derma)'
);

-- line #17602
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FINAZOLE 200 (Khandelwal)',
	'Ketoconazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FINAZOLE 200 (Khandelwal)'
);

-- line #17603
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNAZOLE 200 (Khandelwal)',
	'Ketoconazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNAZOLE 200 (Khandelwal)'
);

-- line #17604
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNGICIDE 200 (Torrent)',
	'Ketoconazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNGICIDE 200 (Torrent)'
);

-- line #17605
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNGINOC 2 (Torrent)',
	'Ketoconazole',
	'OINT',
	gm.nullify_empty_string('2')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNGINOC 2 (Torrent)'
);

-- line #17606
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNGINOC 2 (Torrent)',
	'Ketoconazole',
	'SHAMPOO',
	gm.nullify_empty_string('2')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNGINOC 2 (Torrent)'
);

-- line #17607
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNGIZOLE 2 (PSYCOREM)',
	'Ketoconazole',
	'SHAMPOO',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNGIZOLE 2 (PSYCOREM)'
);

-- line #17608
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNGIZOLE 200 (PSYCOREM)',
	'Ketoconazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNGIZOLE 200 (PSYCOREM)'
);

-- line #17609
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FURID 200 (Medo Chem)',
	'Ketoconazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FURID 200 (Medo Chem)'
);

-- line #17610
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2', u'strength_2': u'', u'substance': u'Ketoconazole', u'always_empty': u'', u'form': u'', u'brand': u'HAIRKLIN BAR', u'strength_3': u'', u'company': u'Elder', u'unit': u'%W/W'}

-- line #17611
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYPHORAL 200 (Ipca)',
	'Ketoconazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYPHORAL 200 (Ipca)'
);

-- line #17612
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Ketoconazole', u'always_empty': u'', u'form': u'LOT', u'brand': u'KAZOL', u'strength_3': u'', u'company': u'West Coast', u'unit': u''}

-- line #17613
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KENAZOL 2 (Indiana O.)',
	'Ketoconazole',
	'EYE DPS',
	gm.nullify_empty_string('2')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KENAZOL 2 (Indiana O.)'
);

-- line #17614
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KENAZOL 200 (P C INDIA)',
	'Ketoconazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KENAZOL 200 (P C INDIA)'
);

-- line #17615
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KENZ 2 (KLM LAB.)',
	'Ketoconazole',
	'LOT',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KENZ 2 (KLM LAB.)'
);

-- line #17616
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KENZ 200 (KLM LAB.)',
	'Ketoconazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KENZ 200 (KLM LAB.)'
);

-- line #17617
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETAFUNG 2 (EAST WEST)',
	'Ketoconazole',
	'CRM',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETAFUNG 2 (EAST WEST)'
);

-- line #17618
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETAFUNG 2 (EAST WEST)',
	'Ketoconazole',
	'SHAMPOO',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETAFUNG 2 (EAST WEST)'
);

-- line #17619
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETAFUNG 200 (EAST WEST)',
	'Ketoconazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETAFUNG 200 (EAST WEST)'
);

-- line #17620
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETANZ 2 (SOIN PH.)',
	'Ketoconazole',
	'LOT',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETANZ 2 (SOIN PH.)'
);

-- line #17621
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETOCO 2 (Ind-Swift)',
	'Ketoconazole',
	'SHAMPOO',
	gm.nullify_empty_string('2')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETOCO 2 (Ind-Swift)'
);

-- line #17622
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETO 2 (MED MANOR)',
	'Ketoconazole',
	'CRM',
	gm.nullify_empty_string('2')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETO 2 (MED MANOR)'
);

-- line #17623
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETODAN 2 (Unique)',
	'Ketoconazole',
	'SHAMPOO',
	gm.nullify_empty_string('2')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETODAN 2 (Unique)'
);

-- line #17624
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETOFRESH 2 (SMART LAB.)',
	'Ketoconazole',
	'SHAMPOO',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETOFRESH 2 (SMART LAB.)'
);

-- line #17625
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETO 5 (MED MANOR)',
	'Ketoconazole',
	'LOT',
	gm.nullify_empty_string('5')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETO 5 (MED MANOR)'
);

-- line #17626
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETO MED 2 (MED MANOR)',
	'Ketoconazole',
	'SOAP',
	gm.nullify_empty_string('2')::numeric,
	'%W/W(WITH ALOE VERA 10'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETO MED 2 (MED MANOR)'
);

-- line #17627
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETONEXT 2 (ETHINAXT PHARMA)',
	'Ketoconazole',
	'LOT',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETONEXT 2 (ETHINAXT PHARMA)'
);

-- line #17628
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETONEXT 2 (ETHINAXT PHARMA)',
	'Ketoconazole',
	'SOAP',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETONEXT 2 (ETHINAXT PHARMA)'
);

-- line #17629
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETOPIL 2 (Pil)',
	'Ketoconazole',
	'SHAMPOO',
	gm.nullify_empty_string('2')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETOPIL 2 (Pil)'
);

-- line #17630
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETO 2 (MED MANOR)',
	'Ketoconazole',
	'POW',
	gm.nullify_empty_string('2')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETO 2 (MED MANOR)'
);

-- line #17631
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETO 2 (MED MANOR)',
	'Ketoconazole',
	'SOAP',
	gm.nullify_empty_string('2')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETO 2 (MED MANOR)'
);

-- line #17632
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETO 200 (Cipla)',
	'Ketoconazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETO 200 (Cipla)'
);

-- line #17633
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETOVATE 2 (Bal Ph.)',
	'Ketoconazole',
	'CRM',
	gm.nullify_empty_string('2')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETOVATE 2 (Bal Ph.)'
);

-- line #17634
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETOVATE 2 (Bal Ph.)',
	'Ketoconazole',
	'SHAMPOO',
	gm.nullify_empty_string('2')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETOVATE 2 (Bal Ph.)'
);

-- line #17635
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETOVATE 200 (Bal Ph.)',
	'Ketoconazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETOVATE 200 (Bal Ph.)'
);

-- line #17636
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETOZOLE 200 (Rexcel)',
	'Ketoconazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETOZOLE 200 (Rexcel)'
);

-- line #17637
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Ketoconazole', u'always_empty': u'', u'form': u'SOAP', u'brand': u'KETOZ', u'strength_3': u'', u'company': u'Mahavir Ent.', u'unit': u''}

-- line #17638
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETZOL 2 (Calibar Ph.)',
	'Ketoconazole',
	'SHAMPOO',
	gm.nullify_empty_string('2')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETZOL 2 (Calibar Ph.)'
);

-- line #17639
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETZOL 200 (Calibar Ph.)',
	'Ketoconazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETZOL 200 (Calibar Ph.)'
);

-- line #17640
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Ketoconazole', u'always_empty': u'', u'form': u'SOAP', u'brand': u'KETZO', u'strength_3': u'', u'company': u'Mahavir Ent.', u'unit': u''}

-- line #17641
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEVON 2 (GLOWDERMA)',
	'Ketoconazole',
	'LOT',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEVON 2 (GLOWDERMA)'
);

-- line #17642
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Ketoconazole', u'always_empty': u'', u'form': u'SOAP', u'brand': u'KEYNET', u'strength_3': u'', u'company': u'Zee Lab', u'unit': u''}

-- line #17643
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEZOLE 2 (Pfiscar Ind.)',
	'Ketoconazole',
	'CRM',
	gm.nullify_empty_string('2')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEZOLE 2 (Pfiscar Ind.)'
);

-- line #17644
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEZOLE 2 (Tripada BIO.)',
	'Ketoconazole',
	'SHAMPOO',
	gm.nullify_empty_string('2')::numeric,
	'% SOL.'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEZOLE 2 (Tripada BIO.)'
);

-- line #17645
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Ketoconazole', u'always_empty': u'', u'form': u'LOT/SOAP', u'brand': u'KKZOLE', u'strength_3': u'', u'company': u'ADVENTUS', u'unit': u''}

-- line #17646
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Ketoconazole', u'always_empty': u'', u'form': u'TAB', u'brand': u'KKZOLE', u'strength_3': u'', u'company': u'ADVENTUS', u'unit': u''}

-- line #17647
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KONAL 200 (Jaywin)',
	'Ketoconazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KONAL 200 (Jaywin)'
);

-- line #17648
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KONAZ 200 (Chemo Bio.)',
	'Ketoconazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KONAZ 200 (Chemo Bio.)'
);

-- line #17649
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KT CURE 2 (AVITECH)',
	'Ketoconazole',
	'CRM',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KT CURE 2 (AVITECH)'
);

-- line #17650
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Ketoconazole', u'always_empty': u'', u'form': u'TAB', u'brand': u'KT CURE', u'strength_3': u'', u'company': u'AVITECH', u'unit': u''}

-- line #17651
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'K-ZOLE 200 (LUCENT PH.)',
	'Ketoconazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'K-ZOLE 200 (LUCENT PH.)'
);

-- line #17652
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIROTEK 200 (ADMIT)',
	'Ketoconazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIROTEK 200 (ADMIT)'
);

-- line #17653
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIZRAL 2 (Ethnor)',
	'Ketoconazole',
	'CRM',
	gm.nullify_empty_string('2')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIZRAL 2 (Ethnor)'
);

-- line #17654
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIZRAL 2 (Ethnor)',
	'Ketoconazole',
	'SHAMPOO',
	gm.nullify_empty_string('2')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIZRAL 2 (Ethnor)'
);

-- line #17655
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIZRAL 2 (Ethnor)',
	'Ketoconazole',
	'SOL',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIZRAL 2 (Ethnor)'
);

-- line #17656
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIZRAL 2 (Ethnor)',
	'Ketoconazole',
	'SOLN',
	gm.nullify_empty_string('2')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIZRAL 2 (Ethnor)'
);

-- line #17657
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIZRAL 200 (Ethnor)',
	'Ketoconazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIZRAL 200 (Ethnor)'
);

-- line #17658
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NODAN 2 (Lark Labs)',
	'Ketoconazole',
	'SHAMPOO',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NODAN 2 (Lark Labs)'
);

-- line #17659
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUKET 2 (Lancer)',
	'Ketoconazole',
	'SOL',
	gm.nullify_empty_string('2')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUKET 2 (Lancer)'
);

-- line #17660
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCONA 2 (Shalaks)',
	'Ketoconazole',
	'SOL(100)',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCONA 2 (Shalaks)'
);

-- line #17661
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCONA 2 (Shalaks)',
	'Ketoconazole',
	'SOL',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCONA 2 (Shalaks)'
);

-- line #17662
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Ketoconazole', u'always_empty': u'', u'form': u'DPS', u'brand': u'PHYTORAL', u'strength_3': u'', u'company': u'Micro Labs', u'unit': u''}

-- line #17663
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHYTORAL 2 (Micro Labs)',
	'Ketoconazole',
	'OINT',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHYTORAL 2 (Micro Labs)'
);

-- line #17664
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHYTORAL 2 (Micro Labs)',
	'Ketoconazole',
	'SHAMPOO',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHYTORAL 2 (Micro Labs)'
);

-- line #17665
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHYTORAL 200 (Brown & B.)',
	'Ketoconazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHYTORAL 200 (Brown & B.)'
);

-- line #17666
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETOFEN 50 (P C INDIA)',
	'Ketoprofen',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETOFEN 50 (P C INDIA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETOFEN 100 (P C INDIA)',
	'Ketoprofen',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETOFEN 100 (P C INDIA)'
);

-- line #17667
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'TRANSDERMAL PATCH 7*10CM', u'strength_2': u'', u'substance': u'Ketoprofen', u'always_empty': u'', u'form': u'', u'brand': u'KETOPATCH PATCH', u'strength_3': u'', u'company': u'Emcure', u'unit': u''}

-- line #17668
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSTOFEN 50 (Torrent)',
	'Ketoprofen',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSTOFEN 50 (Torrent)'
);

-- line #17669
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REDUFEN (R) 100 (Unique)',
	'Ketoprofen',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REDUFEN (R) 100 (Unique)'
);

-- line #17670
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REDUFEN 50 (Unique)',
	'Ketoprofen',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REDUFEN 50 (Unique)'
);

-- line #17671
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RHOFENID 100 (Nicholas)',
	'Ketoprofen',
	'EC TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RHOFENID 100 (Nicholas)'
);

-- line #17672
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RHOFENID 2.5 (Nicholas)',
	'Ketoprofen',
	'GEL',
	gm.nullify_empty_string('2.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RHOFENID 2.5 (Nicholas)'
);

-- line #17673
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RHOFENID 5 (Nicholas)',
	'Ketoprofen',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RHOFENID 5 (Nicholas)'
);

-- line #17674
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RHOFENID 200 (Nicholas)',
	'Ketoprofen',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RHOFENID 200 (Nicholas)'
);

-- line #17675
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACULAR 0.5 (Allergan)',
	'Ketorolac',
	'EYE DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACULAR 0.5 (Allergan)'
);

-- line #17676
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,45', u'strength_2': u'', u'substance': u'Ketorolac', u'always_empty': u'', u'form': u'', u'brand': u'ACUVAIL X', u'strength_3': u'', u'company': u'Allergan', u'unit': u'%'}

-- line #17677
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CADOLAC 0.5 (Irm Ph.)',
	'Ketorolac',
	'DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CADOLAC 0.5 (Irm Ph.)'
);

-- line #17678
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CADOLAC 30 (Irm Ph.)',
	'Ketorolac',
	'INJ',
	gm.nullify_empty_string('30')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CADOLAC 30 (Irm Ph.)'
);

-- line #17679
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CADOLAC 10 (Irm Ph.)',
	'Ketorolac',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CADOLAC 10 (Irm Ph.)'
);

-- line #17680
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CENTAGESIC 0.5 (Centaur)',
	'Ketorolac',
	'EYE DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CENTAGESIC 0.5 (Centaur)'
);

-- line #17681
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLOKET 4 (F D C)',
	'Ketorolac',
	'LS DPS',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLOKET 4 (F D C)'
);

-- line #17682
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EYE KET 0.5 (VISION PH.)',
	'Ketorolac',
	'DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EYE KET 0.5 (VISION PH.)'
);

-- line #17683
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORTRAL 30 (Perk Ph.)',
	'Ketorolac',
	'KT INJ',
	gm.nullify_empty_string('30')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORTRAL 30 (Perk Ph.)'
);

-- line #17684
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORTRAL 10 (Perk Ph.)',
	'Ketorolac',
	'KT TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORTRAL 10 (Perk Ph.)'
);

-- line #17685
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Ketorolac', u'always_empty': u'', u'form': u'DPS', u'brand': u'GEKET', u'strength_3': u'', u'company': u'Eg Ph.', u'unit': u''}

-- line #17686
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ITCHLUR 0.5 (Biocin Hc.)',
	'Ketorolac',
	'EYE DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ITCHLUR 0.5 (Biocin Hc.)'
);

-- line #17687
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KED 5 (Yash Vision)',
	'Ketorolac',
	'EYE DPS',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KED 5 (Yash Vision)'
);

-- line #17688
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KELAC 15 (INTAS)',
	'Ketorolac',
	'INJ',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KELAC 15 (INTAS)'
);

-- line #17689
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KELAC 30 (Intas)',
	'Ketorolac',
	'INJ',
	gm.nullify_empty_string('30')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KELAC 30 (Intas)'
);

-- line #17690
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KELAC 10 (Intas)',
	'Ketorolac',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KELAC 10 (Intas)'
);

-- line #17691
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KENALFIN 30 (Gufic Bio.)',
	'Ketorolac',
	'INJ',
	gm.nullify_empty_string('30')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KENALFIN 30 (Gufic Bio.)'
);

-- line #17692
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KENALFIN 10 (Gufic Bio.)',
	'Ketorolac',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KENALFIN 10 (Gufic Bio.)'
);

-- line #17693
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEROL 0.5 (Oscar Rem.)',
	'Ketorolac',
	'EYE DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEROL 0.5 (Oscar Rem.)'
);

-- line #17694
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETANOV 0.5 (Ranbaxy)',
	'Ketorolac',
	'DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETANOV 0.5 (Ranbaxy)'
);

-- line #17695
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETANOV 30 (Ranbaxy)',
	'Ketorolac',
	'INJ (PFC)',
	gm.nullify_empty_string('30')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETANOV 30 (Ranbaxy)'
);

-- line #17696
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETANOV 30 (Ranbaxy)',
	'Ketorolac',
	'INJ',
	gm.nullify_empty_string('30')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETANOV 30 (Ranbaxy)'
);

-- line #17697
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETANOV 10 (Ranbaxy)',
	'Ketorolac',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETANOV 10 (Ranbaxy)'
);

-- line #17698
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Ketorolac', u'always_empty': u'', u'form': u'EYE DPS', u'brand': u'KETAX', u'strength_3': u'', u'company': u'AXYZEN LIFE', u'unit': u''}

-- line #17699
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Ketorolac', u'always_empty': u'', u'form': u'INJ', u'brand': u'KETAX', u'strength_3': u'', u'company': u'AXYZEN LIFE', u'unit': u''}

-- line #17700
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETAX 10 (AXYZEN LIFE)',
	'Ketorolac',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETAX 10 (AXYZEN LIFE)'
);

-- line #17701
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETLAC 30 (Neon)',
	'Ketorolac',
	'INJ',
	gm.nullify_empty_string('30')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETLAC 30 (Neon)'
);

-- line #17702
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETLUR 0.5 (SUN)',
	'Ketorolac',
	'DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETLUR 0.5 (SUN)'
);

-- line #17703
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETLUR 0.4 (SUN)',
	'Ketorolac',
	'LS OPHTHAL SOL',
	gm.nullify_empty_string('0.4')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETLUR 0.4 (SUN)'
);

-- line #17704
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETODROPS 0.5 (Cipla)',
	'Ketorolac',
	'DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETODROPS 0.5 (Cipla)'
);

-- line #17705
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETOFAN 30 (EMAR)',
	'Ketorolac',
	'AMP',
	gm.nullify_empty_string('30')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETOFAN 30 (EMAR)'
);

-- line #17706
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETOFAN 10 (EMAR)',
	'Ketorolac',
	'DT TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETOFAN 10 (EMAR)'
);

-- line #17707
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETOLAS 0.5 (Dallas Ph.)',
	'Ketorolac',
	'EYE DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETOLAS 0.5 (Dallas Ph.)'
);

-- line #17708
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETOLAS 30 (Dallas Ph.)',
	'Ketorolac',
	'INJ',
	gm.nullify_empty_string('30')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETOLAS 30 (Dallas Ph.)'
);

-- line #17709
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETOLAS 10 (Dallas Ph.)',
	'Ketorolac',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETOLAS 10 (Dallas Ph.)'
);

-- line #17710
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETONIC 10 (Nicholas)',
	'Ketorolac',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETONIC 10 (Nicholas)'
);

-- line #17711
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETOROCIN 4 (Appasamy)',
	'Ketorolac',
	'LS EYE DPS',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETOROCIN 4 (Appasamy)'
);

-- line #17712
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETOROL 10 (Dr.Reddy''S)',
	'Ketorolac',
	'DT',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETOROL 10 (Dr.Reddy''S)'
);

-- line #17713
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETOROL 20 (DR. REDDY''S)',
	'Ketorolac',
	'GEL G',
	gm.nullify_empty_string('20')::numeric,
	'mg(ETHANOL 5'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETOROL 20 (DR. REDDY''S)'
);

-- line #17714
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETOROL 30 (Dr.Reddy''S)',
	'Ketorolac',
	'INJ',
	gm.nullify_empty_string('30')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETOROL 30 (Dr.Reddy''S)'
);

-- line #17715
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETOROL 10 (Dr.Reddy''S)',
	'Ketorolac',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETOROL 10 (Dr.Reddy''S)'
);

-- line #17716
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETOSTAR 0.5 (LIFESTAR)',
	'Ketorolac',
	'EYE DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETOSTAR 0.5 (LIFESTAR)'
);

-- line #17717
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETROC 10 (Intra Lab)',
	'Ketorolac',
	'DT',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETROC 10 (Intra Lab)'
);

-- line #17718
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETROCIN 10 (CHEMO HC.)',
	'Ketorolac',
	'DT',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETROCIN 10 (CHEMO HC.)'
);

-- line #17719
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Ketorolac', u'always_empty': u'', u'form': u'EYE DPS', u'brand': u'KETROL', u'strength_3': u'', u'company': u'Pfiscar Ind.', u'unit': u''}

-- line #17720
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETROMET 0.5 (Ophthal R.)',
	'Ketorolac',
	'DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETROMET 0.5 (Ophthal R.)'
);

-- line #17721
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETSENZ 0.4 (SENSES)',
	'Ketorolac',
	'EYE DPS',
	gm.nullify_empty_string('0.4')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETSENZ 0.4 (SENSES)'
);

-- line #17722
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Ketorolac', u'always_empty': u'', u'form': u'EYE DPS', u'brand': u'KETZY', u'strength_3': u'', u'company': u'Zee Lab', u'unit': u''}

-- line #17723
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETZY 10 (Zee Lab)',
	'Ketorolac',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETZY 10 (Zee Lab)'
);

-- line #17724
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEY 0.5 (Ind-Swift)',
	'Ketorolac',
	'EYE DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEY 0.5 (Ind-Swift)'
);

-- line #17725
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Ketorolac', u'always_empty': u'', u'form': u'EYE DPS', u'brand': u'KT', u'strength_3': u'', u'company': u'Optho Rem.', u'unit': u''}

-- line #17726
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KT 4 (Entod Ph.)',
	'Ketorolac',
	'LS EYE DPS',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KT 4 (Entod Ph.)'
);

-- line #17727
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOKAT 0.4 (Jawa Ph.)',
	'Ketorolac',
	'EYE DPS',
	gm.nullify_empty_string('0.4')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOKAT 0.4 (Jawa Ph.)'
);

-- line #17728
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDLUR 0.5 (MEDITRINA PH.)',
	'Ketorolac',
	'EYE DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDLUR 0.5 (MEDITRINA PH.)'
);

-- line #17729
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NATO 30 (Natco Ph.)',
	'Ketorolac',
	'INJ',
	gm.nullify_empty_string('30')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NATO 30 (Natco Ph.)'
);

-- line #17730
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NATO 10 (Natco Ph.)',
	'Ketorolac',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NATO 10 (Natco Ph.)'
);

-- line #17731
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NODINE 10 (Protec)',
	'Ketorolac',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NODINE 10 (Protec)'
);

-- line #17732
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Ketorolac', u'always_empty': u'', u'form': u'DROPS', u'brand': u'OCUAID EYE', u'strength_3': u'', u'company': u'DIVINE LAB.', u'unit': u''}

-- line #17733
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCULAC 0.5 (Svizera)',
	'Ketorolac',
	'DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCULAC 0.5 (Svizera)'
);

-- line #17734
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPTILAC 0.5 (Indiana O.)',
	'Ketorolac',
	'DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPTILAC 0.5 (Indiana O.)'
);

-- line #17735
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RHYTOR EYE 0.4 (RHYTHM PH.)',
	'Ketorolac',
	'DROPS',
	gm.nullify_empty_string('0.4')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RHYTOR EYE 0.4 (RHYTHM PH.)'
);

-- line #17736
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AIRYFEN 1 (Panacea)',
	'Ketotifen',
	'SYR',
	gm.nullify_empty_string('1')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AIRYFEN 1 (Panacea)'
);

-- line #17737
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AIRYFEN 1 (Panacea)',
	'Ketotifen',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AIRYFEN 1 (Panacea)'
);

-- line #17738
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBALON 0.5 (Allergan)',
	'Ketotifen',
	'EYE DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBALON 0.5 (Allergan)'
);

-- line #17739
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASTHAFEN 1 (Torrent)',
	'Ketotifen',
	'SYR',
	gm.nullify_empty_string('1')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASTHAFEN 1 (Torrent)'
);

-- line #17740
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASTHAFEN 1 (Torrent)',
	'Ketotifen',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASTHAFEN 1 (Torrent)'
);

-- line #17741
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZOFEN 1 (Lark Labs)',
	'KETOTIFEN',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZOFEN 1 (Lark Labs)'
);

-- line #17742
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETASMA 1 (Sun)',
	'Ketotifen',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETASMA 1 (Sun)'
);

-- line #17743
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETORID 0.025 (Milmet)',
	'Ketotifen',
	'DPS',
	gm.nullify_empty_string('0.025')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETORID 0.025 (Milmet)'
);

-- line #17744
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETOTIF 1 (Kopran)',
	'Ketotifen',
	'SYR',
	gm.nullify_empty_string('1')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETOTIF 1 (Kopran)'
);

-- line #17745
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETOTIF 1 (Kopran)',
	'Ketotifen',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETOTIF 1 (Kopran)'
);

-- line #17746
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETOVENT 1 (Intas)',
	'Ketotifen',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETOVENT 1 (Intas)'
);

-- line #17747
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1', u'strength_2': u'', u'substance': u'Ketotifen', u'always_empty': u'', u'form': u'', u'brand': u'MASTIFEN-TAB', u'strength_3': u'', u'company': u'EAST WEST', u'unit': u'mg'}

-- line #17748
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIVENT 1 (Micro Nova)',
	'Ketotifen',
	'DT TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIVENT 1 (Micro Nova)'
);

-- line #17749
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIVENT 0.05 (Micro Labs)',
	'Ketotifen',
	'EYE DPS',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIVENT 0.05 (Micro Labs)'
);

-- line #17750
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000', u'strength_2': u'', u'substance': u'KHATIKA CHURNA', u'always_empty': u'', u'form': u'', u'brand': u'DIGENE FASTMELT', u'strength_3': u'', u'company': u'Abbott', u'unit': u'mg'}

-- line #17751
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ME CAL 400 (Phyto Mark.)',
	'KUKKUTANDTWAK BHASMA (EGG SHELL)',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ME CAL 400 (Phyto Mark.)'
);

-- line #17752
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'KWIKPEN 25% INS. LISPRO 75% INS. LIS. PROTAMIN', u'always_empty': u'', u'form': u'', u'brand': u'HUMALOG MIX', u'strength_3': u'', u'company': u'Eli Lilly', u'unit': u''}

-- line #17753
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100 IU INS. LISPRO', u'strength_2': u'', u'substance': u'KWIKPEN', u'always_empty': u'', u'form': u'', u'brand': u'HUMALOG KWIKPEN', u'strength_3': u'', u'company': u'Eli Lilly', u'unit': u''}

-- line #17754
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEODEP 7.5 (MOLEKULE)',
	'L-5-METHYLTETRAHYDROFOLATE CALCIUM',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEODEP 7.5 (MOLEKULE)'
);

-- line #17755
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AB-LOL 50 (STEADFAST MEDI.)',
	'Labetalol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AB-LOL 50 (STEADFAST MEDI.)'
);

-- line #17756
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Labetalol', u'always_empty': u'', u'form': u'INJ', u'brand': u'ALPHA DIP', u'strength_3': u'', u'company': u'Dahlia Ph.', u'unit': u''}

-- line #17757
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Labetalol', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALPHA DIP', u'strength_3': u'', u'company': u'Dahlia Ph.', u'unit': u''}

-- line #17758
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EVABET 100 (CELON)',
	'Labetalol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EVABET 100 (CELON)'
);

-- line #17759
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRAVIDOL 5 (Mercury)',
	'Labetalol',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRAVIDOL 5 (Mercury)'
);

-- line #17760
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRAVIDOL 100 (Mercury)',
	'Labetalol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRAVIDOL 100 (Mercury)'
);

-- line #17761
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GYNAPRES-L 100 (LIFESTAR)',
	'Labetalol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GYNAPRES-L 100 (LIFESTAR)'
);

-- line #17762
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LABEBET 5 (Sun)',
	'Labetalol',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML-2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LABEBET 5 (Sun)'
);

-- line #17763
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LABEBET 100 (Sun)',
	'Labetalol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LABEBET 100 (Sun)'
);

-- line #17764
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LABESOL 20 (SG PH.)',
	'Labetalol',
	'AMP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LABESOL 20 (SG PH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LABESOL 100 (SG PH.)',
	'Labetalol',
	'AMP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LABESOL 100 (SG PH.)'
);

-- line #17765
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LABETOL 5 (DELVIN)',
	'Labetalol',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LABETOL 5 (DELVIN)'
);

-- line #17766
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LABIL 20 (CELON(REVILON))',
	'Labetalol',
	'AMP',
	gm.nullify_empty_string('20')::numeric,
	'mg/4ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LABIL 20 (CELON(REVILON))'
);

-- line #17767
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LABIL 100 (CELON(REVILON))',
	'Labetalol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LABIL 100 (CELON(REVILON))'
);

-- line #17768
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LABIL 100 (CELON(REVILON))',
	'Labetalol',
	'VIAL',
	gm.nullify_empty_string('100')::numeric,
	'mg/20ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LABIL 100 (CELON(REVILON))'
);

-- line #17769
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5', u'strength_2': u'', u'substance': u'Labetalol', u'always_empty': u'', u'form': u'', u'brand': u'LABLOL', u'strength_3': u'', u'company': u'Neon', u'unit': u'mg'}

-- line #17770
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAB 100 (AKUMENTIS HC.)',
	'Labetalol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAB 100 (AKUMENTIS HC.)'
);

-- line #17771
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOBET 5 (Samarth)',
	'Labetalol',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOBET 5 (Samarth)'
);

-- line #17772
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOBET 100 (Samarth)',
	'Labetalol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOBET 100 (Samarth)'
);

-- line #17773
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORMADATE 100 (Gsk)',
	'Labetalol',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORMADATE 100 (Gsk)'
);

-- line #17774
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORMADATE 200 (Gsk)',
	'Labetalol',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORMADATE 200 (Gsk)'
);

-- line #17775
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORMADATE 50 (Gsk)',
	'Labetalol',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORMADATE 50 (Gsk)'
);

-- line #17776
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'GAMMA CHAIN SPECIFIC ANTISERA TO HUMAN LG G(SOURCE:GOAT); TITRE T 30', u'strength_2': u'', u'substance': u'LABORATORY REAGENTS', u'always_empty': u'', u'form': u'', u'brand': u'ANTISERUM TO HUMAN IGG', u'strength_3': u'', u'company': u'Sanofi Aventis', u'unit': u'% I.E. 40.2IU./ML(3.5'}

-- line #17777
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'GLUCOSE TEST STRIP', u'strength_2': u'', u'substance': u'LABORATORY REAGENTS', u'always_empty': u'', u'form': u'', u'brand': u'BREEZE BLOOD', u'strength_3': u'', u'company': u'Biocon', u'unit': u''}

-- line #17778
-- ignoring line: field [strength_1] not numeric: >>>MONOCLONAL IMMUNO CONCENTRATION RAPID ELISA PREGANANCY TEST<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'MONOCLONAL IMMUNO CONCENTRATION RAPID ELISA PREGANANCY TEST', u'strength_2': u'', u'substance': u'LABORATORY REAGENTS', u'always_empty': u'', u'form': u'STRIP', u'brand': u'EARLIE ICON II', u'strength_3': u'', u'company': u'Ranbaxy', u'unit': u'TIME 3 MIN. SENSITIVITY 20MIU./ML'}

-- line #17779
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'URINE TEST STIROP FOR ESTIMATION OF GLUCOSE IN URINE', u'strength_2': u'', u'substance': u'LABORATORY REAGENTS', u'always_empty': u'', u'form': u'', u'brand': u'GLUCOTEST', u'strength_3': u'', u'company': u'Sanofi Aventis', u'unit': u''}

-- line #17780
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'DIAGNOTIC TEST STRIPS FOR ESTIMATION OF GLUCOSE & KETONES IN URINE', u'strength_2': u'', u'substance': u'LABORATORY REAGENTS', u'always_empty': u'', u'form': u'', u'brand': u'GLUKETUR TEST', u'strength_3': u'', u'company': u'Sanofi Aventis', u'unit': u''}

-- line #17781
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'DIAGNOSTIC STRIPS HAVING 2 REACTION ZONES WITH DIFFERENT SENSITIVITY TO GLUCOSE', u'strength_2': u'', u'substance': u'LABORATORY REAGENTS', u'always_empty': u'', u'form': u'', u'brand': u'HAEMO GLUKOTEST -800 R', u'strength_3': u'', u'company': u'Sanofi Aventis', u'unit': u''}

-- line #17782
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'DIAGNOSTIC STRIPS HAVING 2 REACTION ZONES WITH DIFFERENT SENSITIVENESS', u'strength_2': u'', u'substance': u'LABORATORY REAGENTS', u'always_empty': u'', u'form': u'', u'brand': u'HAEMO GLUKOTEST -800', u'strength_3': u'', u'company': u'Sanofi Aventis', u'unit': u''}

-- line #17783
-- ignoring line: field [strength_1] not numeric: >>>ALPHA CHAIN SPECIFIC ANTISERA TO HUMAN IGA (SOURCE : GOAT) ;TITRE T 30<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'ALPHA CHAIN SPECIFIC ANTISERA TO HUMAN IGA (SOURCE : GOAT) ;TITRE T 30', u'strength_2': u'', u'substance': u'LABORATORY REAGENTS', u'always_empty': u'', u'form': u'LIQ', u'brand': u'IGA(ALPHA CHAIN)', u'strength_3': u'', u'company': u'Sanofi Aventis', u'unit': u'% I.E. 89IU./ML (1.5G/1);HUMAN LG A (SOURCE:GOAT) ; TITRE 30'}

-- line #17784
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u' mg IGG/ML', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'ANTISERUM TO HUMAN LG LIQ. ANIMAL SERA OBTAINED BY IMMUNIZING GOATS WITH A MIXTURE OF IGG', u'strength_2': u'', u'substance': u'LABORATORY REAGENTS', u'always_empty': u'', u'form': u'', u'brand': u'IMMUNOGLOBULLINS', u'strength_3': u'', u'company': u'Sanofi Aventis', u'unit': u'IGA & IGM FROM HUMAN SERUM (SOURCE : GOAT) ; TITRE T 30'}

-- line #17785
-- ignoring line: field [strength_1] not numeric: >>>MULTIPUNCTURE APPLICATIOR LOADED WITH 3<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'MULTIPUNCTURE APPLICATIOR LOADED WITH 3', u'strength_2': u'', u'substance': u'LABORATORY REAGENTS', u'always_empty': u'', u'form': u'KIT', u'brand': u'MONOTEST', u'strength_3': u'', u'company': u'Aventis Pas.', u'unit': u'0'}

-- line #17786
-- ignoring line: field [strength_1] not numeric: >>>IG M 6<<<
-- {u'list_of_values_of_unknown_fields': [u' mg/ML', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'IG M 6', u'strength_2': u'ML', u'substance': u'LABORATORY REAGENTS', u'always_empty': u'', u'form': u'AMP', u'brand': u'PENTAGLOBIN', u'strength_3': u'', u'company': u'Paviour Ph.', u'unit': u'IG A 6/1ML'}

-- line #17787
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'ANTI H C G ANTI-SERA ON MEMBRANCE FOR DETACTION OF H C G IN URINE', u'strength_2': u'', u'substance': u'LABORATORY REAGENTS', u'always_empty': u'', u'form': u'', u'brand': u'PREGCOLOR CARD', u'strength_3': u'', u'company': u'Infar', u'unit': u''}

-- line #17788
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LACIVAS 2 (Sun)',
	'Lacidipine',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LACIVAS 2 (Sun)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LACIVAS 4 (Sun)',
	'Lacidipine',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LACIVAS 4 (Sun)'
);

-- line #17789
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100', u'strength_2': u'', u'substance': u'LACOSAMIDE', u'always_empty': u'', u'form': u'', u'brand': u'LACASA', u'strength_3': u'', u'company': u'Zydus N.S.', u'unit': u'mg'}

-- line #17790
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'150', u'strength_2': u'', u'substance': u'LACOSAMIDE', u'always_empty': u'', u'form': u'', u'brand': u'LACASA', u'strength_3': u'', u'company': u'Zydus N.S.', u'unit': u'mg'}

-- line #17791
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200', u'strength_2': u'', u'substance': u'LACOSAMIDE', u'always_empty': u'', u'form': u'', u'brand': u'LACASA', u'strength_3': u'', u'company': u'Zydus N.S.', u'unit': u'mg'}

-- line #17792
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50', u'strength_2': u'', u'substance': u'LACOSAMIDE', u'always_empty': u'', u'form': u'', u'brand': u'LACASA', u'strength_3': u'', u'company': u'Zydus N.S.', u'unit': u'mg'}

-- line #17793
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LACONEXT-100 100 (Lupin)',
	'LACOSAMIDE',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LACONEXT-100 100 (Lupin)'
);

-- line #17794
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LACONEXT-50 50 (Lupin)',
	'LACOSAMIDE',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LACONEXT-50 50 (Lupin)'
);

-- line #17795
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LACOSAM 100 (Torrent)',
	'LACOSAMIDE',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LACOSAM 100 (Torrent)'
);

-- line #17796
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LACOSAM 150 (Torrent)',
	'LACOSAMIDE',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LACOSAM 150 (Torrent)'
);

-- line #17797
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LACOSAM 200 (Torrent)',
	'LACOSAMIDE',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LACOSAM 200 (Torrent)'
);

-- line #17798
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LACOSAM 50 (Torrent)',
	'LACOSAMIDE',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LACOSAM 50 (Torrent)'
);

-- line #17799
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LACOSET 100 (SUN)',
	'LACOSAMIDE',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LACOSET 100 (SUN)'
);

-- line #17800
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LACOSET 50 (SUN)',
	'LACOSAMIDE',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LACOSET 50 (SUN)'
);

-- line #17801
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3000LU (DERIVED FROM ASPERGILLUS ORYZAE)', u'strength_2': u'', u'substance': u'LACTASE', u'always_empty': u'', u'form': u'TAB', u'brand': u'LACTES', u'strength_3': u'', u'company': u'A.F.D.', u'unit': u''}

-- line #17802
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100', u'strength_2': u'', u'substance': u'LACTIC ACID', u'always_empty': u'', u'form': u'', u'brand': u'CORECTIA', u'strength_3': u'', u'company': u'Pharmed', u'unit': u'mg'}

-- line #17803
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYDRALAC 12 (Stedman)',
	'LACTIC ACID',
	'CRM',
	gm.nullify_empty_string('12')::numeric,
	'%W/W(AS AMM.LACTATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYDRALAC 12 (Stedman)'
);

-- line #17804
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYDRALAC 12 (Stedman)',
	'LACTIC ACID',
	'LOT',
	gm.nullify_empty_string('12')::numeric,
	'%W/W(AS AMM.LACTATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYDRALAC 12 (Stedman)'
);

-- line #17805
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1', u'strength_2': u'', u'substance': u'LACTIC ACID', u'always_empty': u'', u'form': u'', u'brand': u'LACTIFEM', u'strength_3': u'', u'company': u'PROTEC THER.', u'unit': u'%'}

-- line #17806
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LACTIFEM-V VAG 5 (PROTEC THER.)',
	'LACTIC ACID',
	'GEL',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LACTIFEM-V VAG 5 (PROTEC THER.)'
);

-- line #17807
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10G', u'strength_2': u'', u'substance': u'LACTITOL MONOHYDRATE', u'always_empty': u'', u'form': u'', u'brand': u'CONSTEZ', u'strength_3': u'', u'company': u'LA RENON', u'unit': u''}

-- line #17808
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10G', u'strength_2': u'', u'substance': u'LACTITOL MONOHYDRATE', u'always_empty': u'', u'form': u'SYR', u'brand': u'CREMAHEP LACTITOL MONOHYDRATE', u'strength_3': u'', u'company': u'ABBOTT', u'unit': u''}

-- line #17809
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10', u'strength_2': u'20;G', u'substance': u'LACTITOL MONOHYDRATE', u'always_empty': u'', u'form': u'POUCH', u'brand': u'ENCELAX', u'strength_3': u'', u'company': u'Zydus A.', u'unit': u''}

-- line #17810
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10G', u'strength_2': u'', u'substance': u'LACTITOL MONOHYDRATE', u'always_empty': u'', u'form': u'POUCH', u'brand': u'LACTIHEP', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #17811
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LACTIHEP 66.67 (SUN)',
	'LACTITOL MONOHYDRATE',
	'SYR',
	gm.nullify_empty_string('66.67')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LACTIHEP 66.67 (SUN)'
);

-- line #17812
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10G', u'strength_2': u'', u'substance': u'LACTITOL MONOHYDRATE', u'always_empty': u'', u'form': u'SYRUP', u'brand': u'LACTIHEP', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #17813
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10G', u'strength_2': u'', u'substance': u'LACTITOL MONOHYDRATE', u'always_empty': u'', u'form': u'SAC', u'brand': u'LAXITOL', u'strength_3': u'', u'company': u'Macleods', u'unit': u''}

-- line #17814
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20G', u'strength_2': u'', u'substance': u'LACTITOL MONOHYDRATE', u'always_empty': u'', u'form': u'SAC', u'brand': u'LAXITOL', u'strength_3': u'', u'company': u'Macleods', u'unit': u''}

-- line #17815
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1BILL.', u'strength_2': u'', u'substance': u'Lactobacillus Acidophillus', u'always_empty': u'', u'form': u'SAC', u'brand': u'LACTIFLORA', u'strength_3': u'', u'company': u"Dr.Reddy''S", u'unit': u''}

-- line #17816
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'60MILL SP.', u'strength_2': u'', u'substance': u'Lactobacillus', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALDOLAC', u'strength_3': u'', u'company': u'Aldok Ph.', u'unit': u''}

-- line #17817
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Lactobacillus', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALDOLAC', u'strength_3': u'', u'company': u'Aldok Ph.', u'unit': u''}

-- line #17818
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'60MILL.SPOR.', u'strength_2': u'', u'substance': u'Lactobacillus', u'always_empty': u'', u'form': u'TAB', u'brand': u'BACLAC', u'strength_3': u'', u'company': u'Rapross', u'unit': u''}

-- line #17819
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Lactobacillus', u'always_empty': u'', u'form': u'CAP', u'brand': u'BIO', u'strength_3': u'', u'company': u'TABLETS I.', u'unit': u''}

-- line #17820
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10BILL.CELLS(LP299V NOT LESS )', u'strength_2': u'', u'substance': u'Lactobacillus', u'always_empty': u'', u'form': u'CAP', u'brand': u'DAROLAC IBS', u'strength_3': u'', u'company': u'Aristo', u'unit': u''}

-- line #17821
-- ignoring line: field [strength_1] not numeric: >>>LACTOBACILLUS REUTERI RC-14<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'LACTOBACILLUS REUTERI RC-14', u'strength_2': u'', u'substance': u'Lactobacillus', u'always_empty': u'', u'form': u'CAP', u'brand': u'ECONOVA', u'strength_3': u'', u'company': u'Glenmark', u'unit': u'LACTOBACILLUS RHAMNOSUS GR-1'}

-- line #17822
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'120MILLSP.', u'strength_2': u'', u'substance': u'Lactobacillus', u'always_empty': u'', u'form': u'TAB', u'brand': u'ECSPORE', u'strength_3': u'', u'company': u'Ecstacy', u'unit': u''}

-- line #17823
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Lactobacillus', u'always_empty': u'', u'form': u'TAB', u'brand': u'ENTROLAC', u'strength_3': u'', u'company': u'BSP PH.', u'unit': u''}

-- line #17824
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'60*10SP.', u'strength_2': u'', u'substance': u'Lactobacillus', u'always_empty': u'', u'form': u'DT TAB', u'brand': u'FLORA', u'strength_3': u'', u'company': u'Mankind', u'unit': u''}

-- line #17825
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'60*10 SP.', u'strength_2': u'', u'substance': u'Lactobacillus', u'always_empty': u'', u'form': u'KID TAB', u'brand': u'FLORA', u'strength_3': u'', u'company': u'Mankind', u'unit': u''}

-- line #17826
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'150MILL.', u'strength_2': u'', u'substance': u'Lactobacillus', u'always_empty': u'', u'form': u'TAB', u'brand': u'FLORA-L', u'strength_3': u'', u'company': u'Mcw Hc.', u'unit': u''}

-- line #17827
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.25BILL.SP.(ACIDOPHILLUS)', u'strength_2': u'', u'substance': u'Lactobacillus', u'always_empty': u'', u'form': u'SAC', u'brand': u'FLORA RICH', u'strength_3': u'', u'company': u'HALO MEDI.', u'unit': u''}

-- line #17828
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'60MILL.SP.', u'strength_2': u'', u'substance': u'Lactobacillus', u'always_empty': u'', u'form': u'TAB', u'brand': u'GISPORE', u'strength_3': u'', u'company': u'Shreeyam', u'unit': u''}

-- line #17829
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'60MILL SPOR.', u'strength_2': u'', u'substance': u'Lactobacillus', u'always_empty': u'', u'form': u'TAB', u'brand': u'J-V LAC', u'strength_3': u'', u'company': u'J.V.D. Ph.', u'unit': u''}

-- line #17830
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'60M.SPOR.', u'strength_2': u'', u'substance': u'Lactobacillus', u'always_empty': u'', u'form': u'TAB', u'brand': u'LAB-60', u'strength_3': u'', u'company': u'Olcare', u'unit': u''}

-- line #17831
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40MILL.', u'strength_2': u'', u'substance': u'Lactobacillus', u'always_empty': u'', u'form': u'TAB', u'brand': u'LABDIX', u'strength_3': u'', u'company': u'Medispan', u'unit': u''}

-- line #17832
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10 MILLION (COMBINATION)', u'strength_2': u'', u'substance': u'Lactobacillus', u'always_empty': u'', u'form': u'DT TAB', u'brand': u'LAC-M', u'strength_3': u'', u'company': u'MADHAV BIO.', u'unit': u''}

-- line #17833
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'60MILL.', u'strength_2': u'', u'substance': u'Lactobacillus', u'always_empty': u'', u'form': u'TAB', u'brand': u'LAC', u'strength_3': u'', u'company': u'Goodrich', u'unit': u''}

-- line #17834
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100 M.SP.', u'strength_2': u'', u'substance': u'Lactobacillus', u'always_empty': u'', u'form': u'TAB', u'brand': u'LACTAB', u'strength_3': u'', u'company': u'Sbeed Ph.', u'unit': u''}

-- line #17835
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10M.', u'strength_2': u'CAP OR 1G POW.(LYPHOLISED LACTOBACILLUS ACIDOPHILLUS)', u'substance': u'Lactobacillus', u'always_empty': u'', u'form': u'CAP/SAC', u'brand': u'LACTOBACIL', u'strength_3': u'', u'company': u'Infar', u'unit': u''}

-- line #17836
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100000000SP.', u'strength_2': u'', u'substance': u'Lactobacillus', u'always_empty': u'', u'form': u'DT', u'brand': u'LACTOGENES', u'strength_3': u'', u'company': u'Medispan', u'unit': u''}

-- line #17837
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'150MILL.', u'strength_2': u'', u'substance': u'Lactobacillus', u'always_empty': u'', u'form': u'SAC', u'brand': u'LACTOGENES', u'strength_3': u'', u'company': u'Medispan', u'unit': u''}

-- line #17838
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'60M.SPOR.', u'strength_2': u'', u'substance': u'Lactobacillus', u'always_empty': u'', u'form': u'TAB', u'brand': u'LACTO', u'strength_3': u'', u'company': u'Acron Ph.', u'unit': u''}

-- line #17839
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'150MIL.', u'strength_2': u'', u'substance': u'Lactobacillus', u'always_empty': u'', u'form': u'SAC', u'brand': u'LACTRA', u'strength_3': u'', u'company': u'Intra Lab', u'unit': u''}

-- line #17840
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'60MILL.', u'strength_2': u'', u'substance': u'Lactobacillus', u'always_empty': u'', u'form': u'TAB', u'brand': u'LACTRA', u'strength_3': u'', u'company': u'Intra Lab', u'unit': u''}

-- line #17841
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'150 MILLION (COMBINATION)', u'strength_2': u'', u'substance': u'Lactobacillus', u'always_empty': u'', u'form': u'DT TAB', u'brand': u'LACVEN', u'strength_3': u'', u'company': u'VENSAT', u'unit': u''}

-- line #17842
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'60MILL.', u'strength_2': u'', u'substance': u'Lactobacillus', u'always_empty': u'', u'form': u'TAB', u'brand': u'LAKSPOR', u'strength_3': u'', u'company': u'Beckcem', u'unit': u''}

-- line #17843
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10MILL.(LYPHOLISED LACTOBACILLUS ACIDOPHILLUS)', u'strength_2': u'', u'substance': u'Lactobacillus', u'always_empty': u'', u'form': u'CAP', u'brand': u'LAVIEST', u'strength_3': u'', u'company': u'Franco I.', u'unit': u''}

-- line #17844
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'60MILL.SPORES', u'strength_2': u'', u'substance': u'Lactobacillus', u'always_empty': u'', u'form': u'TAB', u'brand': u'L-BAC', u'strength_3': u'', u'company': u'ROSE LABS', u'unit': u''}

-- line #17845
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200000000SP.', u'strength_2': u'', u'substance': u'Lactobacillus', u'always_empty': u'', u'form': u'CAP', u'brand': u'MEDALAC', u'strength_3': u'', u'company': u'Medopharm', u'unit': u''}

-- line #17846
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'60000000SP.', u'strength_2': u'', u'substance': u'Lactobacillus', u'always_empty': u'', u'form': u'DT', u'brand': u'MEDALAC', u'strength_3': u'', u'company': u'Medopharm', u'unit': u''}

-- line #17847
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'WITH FOLIC ACID AND VIT.B12', u'strength_2': u'', u'substance': u'Lactobacillus', u'always_empty': u'', u'form': u'TAB', u'brand': u'MI FOL-L', u'strength_3': u'', u'company': u'AMEE PH.', u'unit': u''}

-- line #17848
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'150MILL.SP.', u'strength_2': u'', u'substance': u'Lactobacillus', u'always_empty': u'', u'form': u'VAGTAB', u'brand': u'MYCONIP', u'strength_3': u'', u'company': u'Uni-Sank.', u'unit': u''}

-- line #17849
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'150MILL.', u'strength_2': u'', u'substance': u'Lactobacillus', u'always_empty': u'', u'form': u'SAC', u'brand': u'OZOLAB', u'strength_3': u'', u'company': u'Ozone Ph.', u'unit': u''}

-- line #17850
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVIOSA -V 500 (Ranbaxy)',
	'LACTOBACILLUS PLANTARUM(LP299V) POWDER',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVIOSA -V 500 (Ranbaxy)'
);

-- line #17851
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200 MILLION (LACTOBACILLUS ACDIDOPHILUS)', u'strength_2': u'', u'substance': u'Lactobacillus', u'always_empty': u'', u'form': u'CAP', u'brand': u'P-R-B', u'strength_3': u'', u'company': u'Aglowmed', u'unit': u''}

-- line #17852
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'LACTOBACILLUS REUTERI DSM 17938-100 MILLION C.F.U.', u'always_empty': u'', u'form': u'CAP', u'brand': u'APYLORI', u'strength_3': u'', u'company': u'TABLETS I.', u'unit': u''}

-- line #17853
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1BILL SP.', u'strength_2': u'', u'substance': u'LACTOBACILLUS RHAMNOSUS', u'always_empty': u'', u'form': u'CAP', u'brand': u'FEMBIO', u'strength_3': u'', u'company': u'Zydus Cadila', u'unit': u''}

-- line #17854
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LACTOBIOTIC 60 (Lupin)',
	'LACTOFERRIN',
	'CAP',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LACTOBIOTIC 60 (Lupin)'
);

-- line #17855
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10G', u'strength_2': u'15ML', u'substance': u'Lactulose', u'always_empty': u'', u'form': u'SOL', u'brand': u'ACTILEX', u'strength_3': u'', u'company': u'Auroma Life', u'unit': u''}

-- line #17856
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AGILAX 3.35 (AGIO PH.)',
	'Lactulose',
	'SOL',
	gm.nullify_empty_string('3.35')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AGILAX 3.35 (AGIO PH.)'
);

-- line #17857
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Lactulose', u'always_empty': u'', u'form': u'SYR', u'brand': u'BIOLAC', u'strength_3': u'', u'company': u'United Bio.', u'unit': u''}

-- line #17858
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3.35G', u'strength_2': u'', u'substance': u'Lactulose', u'always_empty': u'', u'form': u'', u'brand': u'BOWELL', u'strength_3': u'', u'company': u'ERIS LIFE', u'unit': u''}

-- line #17859
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3.325G', u'strength_2': u'5ML', u'substance': u'Lactulose', u'always_empty': u'', u'form': u'SYR', u'brand': u'BOWLEASE', u'strength_3': u'', u'company': u'Lark Labs', u'unit': u''}

-- line #17860
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10G', u'strength_2': u'15ML', u'substance': u'Lactulose', u'always_empty': u'', u'form': u'SUS', u'brand': u'BULKY', u'strength_3': u'', u'company': u'Astrazeneca', u'unit': u''}

-- line #17861
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10G', u'strength_2': u'15ML', u'substance': u'Lactulose', u'always_empty': u'', u'form': u'SOL', u'brand': u'CONCURE', u'strength_3': u'', u'company': u'Patson', u'unit': u''}

-- line #17862
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10G', u'strength_2': u'', u'substance': u'Lactulose', u'always_empty': u'', u'form': u'SYR', u'brand': u'DE-LOGER', u'strength_3': u'', u'company': u'HALO MEDI.', u'unit': u''}

-- line #17863
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3.35G', u'strength_2': u'5ML', u'substance': u'Lactulose', u'always_empty': u'', u'form': u'LIQ', u'brand': u'DUPHALAC', u'strength_3': u'', u'company': u'Solvay Ph.', u'unit': u''}

-- line #17864
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUPHALAC 667 (Solvay Ph.)',
	'Lactulose',
	'SYR',
	gm.nullify_empty_string('667')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUPHALAC 667 (Solvay Ph.)'
);

-- line #17865
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10G CONC.', u'strength_2': u'', u'substance': u'Lactulose', u'always_empty': u'', u'form': u'', u'brand': u'ESIVAC S0L', u'strength_3': u'', u'company': u'Intas', u'unit': u''}

-- line #17866
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Lactulose', u'always_empty': u'', u'form': u'SYR', u'brand': u'EVALAK', u'strength_3': u'', u'company': u'Biomax Bio.', u'unit': u''}

-- line #17867
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10GM', u'strength_2': u'', u'substance': u'Lactulose', u'always_empty': u'', u'form': u'SYR', u'brand': u'EVALEX', u'strength_3': u'', u'company': u'Olcare', u'unit': u''}

-- line #17868
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10G', u'strength_2': u'', u'substance': u'Lactulose', u'always_empty': u'', u'form': u'LIQ', u'brand': u'EVICT', u'strength_3': u'', u'company': u'Albert D.', u'unit': u''}

-- line #17869
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10G', u'strength_2': u'15ML', u'substance': u'Lactulose', u'always_empty': u'', u'form': u'LIQ', u'brand': u'EVICT', u'strength_3': u'', u'company': u'Albert D.', u'unit': u''}

-- line #17870
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Lactulose', u'always_empty': u'', u'form': u'SOL', u'brand': u'FRESKY', u'strength_3': u'', u'company': u'AAMORB', u'unit': u''}

-- line #17871
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10G', u'strength_2': u'15ML', u'substance': u'Lactulose', u'always_empty': u'', u'form': u'SYR', u'brand': u'GUSH', u'strength_3': u'', u'company': u'Panacea', u'unit': u''}

-- line #17872
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10G (PALATABLE BASE Q.S.)', u'strength_2': u'', u'substance': u'Lactulose', u'always_empty': u'', u'form': u'SOL', u'brand': u'KOMFYLAC', u'strength_3': u'', u'company': u'ALEMBIC', u'unit': u''}

-- line #17873
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Lactulose', u'always_empty': u'', u'form': u'SYR', u'brand': u'LACLOUSE', u'strength_3': u'', u'company': u'Osper', u'unit': u''}

-- line #17874
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100ML', u'strength_2': u'', u'substance': u'Lactulose', u'always_empty': u'', u'form': u'', u'brand': u'LACREST', u'strength_3': u'', u'company': u'CH.Bhagat', u'unit': u''}

-- line #17875
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200ML', u'strength_2': u'', u'substance': u'Lactulose', u'always_empty': u'', u'form': u'', u'brand': u'LACREST', u'strength_3': u'', u'company': u'CH.Bhagat', u'unit': u''}

-- line #17876
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Lactulose', u'always_empty': u'', u'form': u'SYR', u'brand': u'LACREST', u'strength_3': u'', u'company': u'CH.Bhagat', u'unit': u''}

-- line #17877
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10G', u'strength_2': u'15ML', u'substance': u'Lactulose', u'always_empty': u'', u'form': u'SOLN', u'brand': u'LACSAN', u'strength_3': u'', u'company': u'Unique', u'unit': u''}

-- line #17878
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LACTULAX 50 (Samarth)',
	'Lactulose',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/100ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LACTULAX 50 (Samarth)'
);

-- line #17879
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10G', u'strength_2': u'15ML', u'substance': u'Lactulose', u'always_empty': u'', u'form': u'SYR', u'brand': u'LACTULIN', u'strength_3': u'', u'company': u'Meyer Org.', u'unit': u''}

-- line #17880
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Lactulose', u'always_empty': u'', u'form': u'SYR', u'brand': u'LACX', u'strength_3': u'', u'company': u'OCHOA LAB', u'unit': u''}

-- line #17881
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Lactulose', u'always_empty': u'', u'form': u'SYR', u'brand': u'LACX', u'strength_3': u'', u'company': u'Ochoa', u'unit': u''}

-- line #17882
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAXAID 10 (Shreya)',
	'Lactulose',
	'SAC',
	gm.nullify_empty_string('10')::numeric,
	'mg/15ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAXAID 10 (Shreya)'
);

-- line #17883
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAXAN 667 (Ochoa)',
	'Lactulose',
	'LIQ',
	gm.nullify_empty_string('667')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAXAN 667 (Ochoa)'
);

-- line #17884
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'CONC.', u'strength_2': u'', u'substance': u'Lactulose', u'always_empty': u'', u'form': u'SOL', u'brand': u'LAXAN', u'strength_3': u'', u'company': u'AUSTER', u'unit': u''}

-- line #17885
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3.35G', u'strength_2': u'', u'substance': u'Lactulose', u'always_empty': u'', u'form': u'', u'brand': u'LAXDAY', u'strength_3': u'', u'company': u'Overseas Hc.', u'unit': u''}

-- line #17886
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10G', u'strength_2': u'15ML', u'substance': u'Lactulose', u'always_empty': u'', u'form': u'SUSP', u'brand': u'LAXICARE SOFT', u'strength_3': u'', u'company': u'AZINE HC.', u'unit': u''}

-- line #17887
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3.35G', u'strength_2': u'5ML', u'substance': u'Lactulose', u'always_empty': u'', u'form': u'LIQ', u'brand': u'LAXIL', u'strength_3': u'', u'company': u'Mapra', u'unit': u''}

-- line #17888
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10G', u'strength_2': u'15ML', u'substance': u'Lactulose', u'always_empty': u'', u'form': u'SUS', u'brand': u'LAXIWAL', u'strength_3': u'', u'company': u'Wallace', u'unit': u''}

-- line #17889
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10G', u'strength_2': u'15ML', u'substance': u'Lactulose', u'always_empty': u'', u'form': u'LIQ', u'brand': u'LAXOLIN', u'strength_3': u'', u'company': u'Bombay T.', u'unit': u''}

-- line #17890
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10G', u'strength_2': u'15ML', u'substance': u'Lactulose', u'always_empty': u'', u'form': u'SYR', u'brand': u'LAXOSE', u'strength_3': u'', u'company': u'Indi Ph.', u'unit': u''}

-- line #17891
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10G', u'strength_2': u'15ML', u'substance': u'Lactulose', u'always_empty': u'', u'form': u'LIQ', u'brand': u'LIVINTACT-EV', u'strength_3': u'', u'company': u'Panjon', u'unit': u''}

-- line #17892
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10G', u'strength_2': u'15ML', u'substance': u'Lactulose', u'always_empty': u'', u'form': u'SYR', u'brand': u'LIVOLUK', u'strength_3': u'', u'company': u'Panacea', u'unit': u''}

-- line #17893
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3.325G', u'strength_2': u'5ML', u'substance': u'Lactulose', u'always_empty': u'', u'form': u'SYR', u'brand': u'LIVOLUK', u'strength_3': u'', u'company': u'Panacea', u'unit': u''}

-- line #17894
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3.35G', u'strength_2': u'5ML', u'substance': u'Lactulose', u'always_empty': u'', u'form': u'SOL', u'brand': u'LOGOUT', u'strength_3': u'', u'company': u'SEPTENNIEL', u'unit': u''}

-- line #17895
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'Lactulose', u'always_empty': u'', u'form': u'', u'brand': u'LOOZ ENEMA', u'strength_3': u'', u'company': u'Intas', u'unit': u'% W/W'}

-- line #17896
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOOZIT 10 (Intra Lab)',
	'Lactulose',
	'SUS',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOOZIT 10 (Intra Lab)'
);

-- line #17897
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10G CONC.', u'strength_2': u'', u'substance': u'Lactulose', u'always_empty': u'', u'form': u'SOL', u'brand': u'LOOZ', u'strength_3': u'', u'company': u'Intas', u'unit': u''}

-- line #17898
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10G', u'strength_2': u'5ML', u'substance': u'Lactulose', u'always_empty': u'', u'form': u'SOLN', u'brand': u'LOOZ', u'strength_3': u'', u'company': u'Intas', u'unit': u''}

-- line #17899
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10GM', u'strength_2': u'15ML', u'substance': u'Lactulose', u'always_empty': u'', u'form': u'SOLN', u'brand': u'LOOZ', u'strength_3': u'', u'company': u'Intas', u'unit': u''}

-- line #17900
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Lactulose', u'always_empty': u'', u'form': u'', u'brand': u'LOOZ SPRINKLES', u'strength_3': u'', u'company': u'Intas', u'unit': u''}

-- line #17901
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10G', u'strength_2': u'15ML', u'substance': u'Lactulose', u'always_empty': u'', u'form': u'LIQ', u'brand': u'LOOZYLAX', u'strength_3': u'', u'company': u'Skymax', u'unit': u''}

-- line #17902
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10G', u'strength_2': u'15ML', u'substance': u'Lactulose', u'always_empty': u'', u'form': u'SUS', u'brand': u'MTLAC', u'strength_3': u'', u'company': u'Cfl Ph.', u'unit': u''}

-- line #17903
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10G', u'strength_2': u'15ML', u'substance': u'Lactulose', u'always_empty': u'', u'form': u'SYR', u'brand': u'NEOSTIPAN', u'strength_3': u'', u'company': u'Bantom', u'unit': u''}

-- line #17904
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Lactulose', u'always_empty': u'', u'form': u'SOL', u'brand': u'NEWLA', u'strength_3': u'', u'company': u"Dr.Arvind Shah''S", u'unit': u''}

-- line #17905
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3.34G', u'strength_2': u'5ML', u'substance': u'Lactulose', u'always_empty': u'', u'form': u'SYR', u'brand': u'NOSTIPAN', u'strength_3': u'', u'company': u'Micro Nova', u'unit': u''}

-- line #17906
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10G', u'strength_2': u'15ML', u'substance': u'Lactulose', u'always_empty': u'', u'form': u'SYR', u'brand': u'OSLAX', u'strength_3': u'', u'company': u'Obsurge', u'unit': u''}

-- line #17907
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10G', u'strength_2': u'15ML', u'substance': u'Lactulose', u'always_empty': u'', u'form': u'SYR', u'brand': u'OSMOWIN', u'strength_3': u'', u'company': u'Win-Medicare', u'unit': u''}

-- line #17908
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3.35G', u'strength_2': u'5ML', u'substance': u'Lactulose', u'always_empty': u'', u'form': u'SOL', u'brand': u'RAPIDUCE', u'strength_3': u'', u'company': u'F D C', u'unit': u''}

-- line #17909
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REE LAX 10 (Saga Lab)',
	'Lactulose',
	'SOL',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REE LAX 10 (Saga Lab)'
);

-- line #17910
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RILIZ 10 (Ferring Ph.)',
	'Lactulose',
	'LIQ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RILIZ 10 (Ferring Ph.)'
);

-- line #17911
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUTADEN RABLET 10 (Emcure)',
	'LAFUTIDINE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUTADEN RABLET 10 (Emcure)'
);

-- line #17912
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LACILOC 10 (Cadila Ph.)',
	'LAFUTIDINE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LACILOC 10 (Cadila Ph.)'
);

-- line #17913
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAFAXID-10 10 (Zuventus)',
	'LAFUTIDINE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAFAXID-10 10 (Zuventus)'
);

-- line #17914
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAFJOY 10 (J. B. Chem.)',
	'LAFUTIDINE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAFJOY 10 (J. B. Chem.)'
);

-- line #17915
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAFTER 10 (Rapross)',
	'LAFUTIDINE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAFTER 10 (Rapross)'
);

-- line #17916
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAFTID 10 (Piramal Hc.)',
	'LAFUTIDINE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAFTID 10 (Piramal Hc.)'
);

-- line #17917
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAFTID 5 (Piramal Hc.)',
	'LAFUTIDINE',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAFTID 5 (Piramal Hc.)'
);

-- line #17918
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAFUDAC 10 (Unichem)',
	'LAFUTIDINE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAFUDAC 10 (Unichem)'
);

-- line #17919
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAFUDAC 5 (Unichem)',
	'LAFUTIDINE',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAFUDAC 5 (Unichem)'
);

-- line #17920
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAFUMAC-10 10 (Macleods)',
	'LAFUTIDINE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAFUMAC-10 10 (Macleods)'
);

-- line #17921
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAFUTAX 10 (ALMIRON)',
	'LAFUTIDINE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAFUTAX 10 (ALMIRON)'
);

-- line #17922
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAFUTAX 5 (ALMIRON)',
	'LAFUTIDINE',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAFUTAX 5 (ALMIRON)'
);

-- line #17923
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGACHOLIN 400 (Aristo)',
	'L-ALPHA GLYCERYL PHOSPHATE CHOLINE(ALPHA GPC)',
	'SOFT GEL CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGACHOLIN 400 (Aristo)'
);

-- line #17924
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEPAVUD 100 (Khandelwal)',
	'Lamivudine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEPAVUD 100 (Khandelwal)'
);

-- line #17925
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEPITEC 100 (Gsk)',
	'Lamivudine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEPITEC 100 (Gsk)'
);

-- line #17926
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEPTAVIR 100 (HETERO HC.)',
	'Lamivudine',
	'SOL',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEPTAVIR 100 (HETERO HC.)'
);

-- line #17927
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEPTAVIR 100 (Genix Ph.)',
	'Lamivudine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEPTAVIR 100 (Genix Ph.)'
);

-- line #17928
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEPTAVIR 150 (Genix Ph.)',
	'Lamivudine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEPTAVIR 150 (Genix Ph.)'
);

-- line #17929
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIVIR 100 (Sain Med.)',
	'Lamivudine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIVIR 100 (Sain Med.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIVIR 150 (Sain Med.)',
	'Lamivudine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIVIR 150 (Sain Med.)'
);

-- line #17930
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LADIWIN 150 (Zydus Vacc.)',
	'Lamivudine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LADIWIN 150 (Zydus Vacc.)'
);

-- line #17931
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMDA 150 (Le Sante)',
	'Lamivudine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMDA 150 (Le Sante)'
);

-- line #17932
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMIDAC 100 (Zydus A.)',
	'Lamivudine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMIDAC 100 (Zydus A.)'
);

-- line #17933
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMIHOPE 100 (Macleods)',
	'Lamivudine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMIHOPE 100 (Macleods)'
);

-- line #17934
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMIHOPE 300 (Macleods)',
	'Lamivudine',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMIHOPE 300 (Macleods)'
);

-- line #17935
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMI 100 (Mcneil & A.)',
	'Lamivudine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMI 100 (Mcneil & A.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMI 150 (Mcneil & A.)',
	'Lamivudine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMI 150 (Mcneil & A.)'
);

-- line #17936
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMIVIR-HBV 100 (Cipla)',
	'Lamivudine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMIVIR-HBV 100 (Cipla)'
);

-- line #17937
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMIVIR ORAL 50 (Cipla)',
	'Lamivudine',
	'SOL',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMIVIR ORAL 50 (Cipla)'
);

-- line #17938
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMIVIR 100 (Cipla)',
	'Lamivudine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMIVIR 100 (Cipla)'
);

-- line #17939
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMIVIR 150 (Cipla)',
	'Lamivudine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMIVIR 150 (Cipla)'
);

-- line #17940
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMIVIR 300 (Cipla)',
	'Lamivudine',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMIVIR 300 (Cipla)'
);

-- line #17941
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMIVOX 100 (Aurobindo)',
	'Lamivudine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMIVOX 100 (Aurobindo)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMIVOX 150 (Aurobindo)',
	'Lamivudine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMIVOX 150 (Aurobindo)'
);

-- line #17942
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMUCARE 150 (CHEMO HC.)',
	'Lamivudine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMUCARE 150 (CHEMO HC.)'
);

-- line #17943
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMUVID 100 (Nicholas)',
	'Lamivudine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMUVID 100 (Nicholas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMUVID 150 (Nicholas)',
	'Lamivudine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMUVID 150 (Nicholas)'
);

-- line #17944
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAVIR 50 (EMCURE(ARV))',
	'Lamivudine',
	'SOLN',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAVIR 50 (EMCURE(ARV))'
);

-- line #17945
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAVIR 150 (EMCURE(ARV))',
	'Lamivudine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAVIR 150 (EMCURE(ARV))'
);

-- line #17946
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RETROLAM-150 150 (Cytomed(Alkem))',
	'Lamivudine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RETROLAM-150 150 (Cytomed(Alkem))'
);

-- line #17947
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPITIC 100 (PSYCOREM)',
	'Lamotrigine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPITIC 100 (PSYCOREM)'
);

-- line #17948
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPITIC 25 (PSYCOREM)',
	'Lamotrigine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPITIC 25 (PSYCOREM)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPITIC 50 (PSYCOREM)',
	'Lamotrigine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPITIC 50 (PSYCOREM)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPITIC 100 (PSYCOREM)',
	'Lamotrigine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPITIC 100 (PSYCOREM)'
);

-- line #17949
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPITIC 25 (PSYCOREM)',
	'Lamotrigine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPITIC 25 (PSYCOREM)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPITIC 50 (PSYCOREM)',
	'Lamotrigine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPITIC 50 (PSYCOREM)'
);

-- line #17950
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAVLAM 100 (USV (CENTRA))',
	'Lamotrigine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAVLAM 100 (USV (CENTRA))'
);

-- line #17951
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAVLAM 25 (USV (CENTRA))',
	'Lamotrigine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAVLAM 25 (USV (CENTRA))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAVLAM 50 (USV (CENTRA))',
	'Lamotrigine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAVLAM 50 (USV (CENTRA))'
);

-- line #17952
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAGINE 50 (Theo Ph.)',
	'Lamotrigine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAGINE 50 (Theo Ph.)'
);

-- line #17953
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMACTIN 100 (Rpg Life)',
	'Lamotrigine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMACTIN 100 (Rpg Life)'
);

-- line #17954
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMACTIN 200 (Rpg Life)',
	'Lamotrigine',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMACTIN 200 (Rpg Life)'
);

-- line #17955
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMACTIN 25 (Rpg Life)',
	'Lamotrigine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMACTIN 25 (Rpg Life)'
);

-- line #17956
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMACTIN 50 (Rpg Life)',
	'Lamotrigine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMACTIN 50 (Rpg Life)'
);

-- line #17957
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMEPIL 100 (Ipca)',
	'Lamotrigine',
	'MR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMEPIL 100 (Ipca)'
);

-- line #17958
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMEPIL 50 (Ipca)',
	'Lamotrigine',
	'MR TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMEPIL 50 (Ipca)'
);

-- line #17959
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMEPIL 100 (Ipca)',
	'Lamotrigine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMEPIL 100 (Ipca)'
);

-- line #17960
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMEPIL 25 (Ipca)',
	'Lamotrigine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMEPIL 25 (Ipca)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMEPIL 50 (Ipca)',
	'Lamotrigine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMEPIL 50 (Ipca)'
);

-- line #17961
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMETEC 100 (Protec)',
	'Lamotrigine',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMETEC 100 (Protec)'
);

-- line #17962
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMETEC 50 (Protec)',
	'Lamotrigine',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMETEC 50 (Protec)'
);

-- line #17963
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMETEC 5 (Protec)',
	'Lamotrigine',
	'DT',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMETEC 5 (Protec)'
);

-- line #17964
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMETEC 100 (Protec)',
	'Lamotrigine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMETEC 100 (Protec)'
);

-- line #17965
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMETEC 25 (Protec)',
	'Lamotrigine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMETEC 25 (Protec)'
);

-- line #17966
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMETEC 50 (Protec)',
	'Lamotrigine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMETEC 50 (Protec)'
);

-- line #17967
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMEZ 100 (Intas)',
	'Lamotrigine',
	'OD TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMEZ 100 (Intas)'
);

-- line #17968
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMEZ 150 (Intas)',
	'Lamotrigine',
	'OD TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMEZ 150 (Intas)'
);

-- line #17969
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMEZ 200 (Intas)',
	'Lamotrigine',
	'OD TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMEZ 200 (Intas)'
);

-- line #17970
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMEZ 25 (Intas)',
	'Lamotrigine',
	'OD TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMEZ 25 (Intas)'
);

-- line #17971
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMEZ 50 (Intas)',
	'Lamotrigine',
	'OD TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMEZ 50 (Intas)'
);

-- line #17972
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMIDUS 100 (Zydus N.S.)',
	'Lamotrigine',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMIDUS 100 (Zydus N.S.)'
);

-- line #17973
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMIDUS 25 (Zydus N.S.)',
	'Lamotrigine',
	'DT',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMIDUS 25 (Zydus N.S.)'
);

-- line #17974
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMIDUS 50 (Zydus N.S.)',
	'Lamotrigine',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMIDUS 50 (Zydus N.S.)'
);

-- line #17975
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMITOR 100 (Torrent)',
	'Lamotrigine',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMITOR 100 (Torrent)'
);

-- line #17976
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMITOR 25 (Torrent)',
	'Lamotrigine',
	'DT',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMITOR 25 (Torrent)'
);

-- line #17977
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMITOR 50 (Torrent)',
	'Lamotrigine',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMITOR 50 (Torrent)'
);

-- line #17978
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMITOR 5 (Torrent)',
	'Lamotrigine',
	'DT',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMITOR 5 (Torrent)'
);

-- line #17979
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMITOR 100 (Torrent)',
	'Lamotrigine',
	'OD TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMITOR 100 (Torrent)'
);

-- line #17980
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMITOR 200 (Torrent)',
	'Lamotrigine',
	'OD TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMITOR 200 (Torrent)'
);

-- line #17981
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMITOR 50 (Torrent)',
	'Lamotrigine',
	'OD TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMITOR 50 (Torrent)'
);

-- line #17982
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMITOR ODT 12.5 (Torrent)',
	'Lamotrigine',
	'TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMITOR ODT 12.5 (Torrent)'
);

-- line #17983
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMIZINE 25 (OREVA DARMO.)',
	'Lamotrigine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMIZINE 25 (OREVA DARMO.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMIZINE 50 (OREVA DARMO.)',
	'Lamotrigine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMIZINE 50 (OREVA DARMO.)'
);

-- line #17984
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMOGIN 100 (F D C)',
	'Lamotrigine',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMOGIN 100 (F D C)'
);

-- line #17985
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMOGIN 25 (F D C)',
	'Lamotrigine',
	'DT',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMOGIN 25 (F D C)'
);

-- line #17986
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMOGIN 50 (F D C)',
	'Lamotrigine',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMOGIN 50 (F D C)'
);

-- line #17987
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMOGINE 50 (D.D. PH.)',
	'Lamotrigine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMOGINE 50 (D.D. PH.)'
);

-- line #17988
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMOKEM 100 (Alkem)',
	'Lamotrigine',
	'OD TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMOKEM 100 (Alkem)'
);

-- line #17989
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMOKEM 50 (Alkem)',
	'Lamotrigine',
	'OD TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMOKEM 50 (Alkem)'
);

-- line #17990
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMORIG 100 (Unichem)',
	'Lamotrigine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMORIG 100 (Unichem)'
);

-- line #17991
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMORIG 25 (Unichem)',
	'Lamotrigine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMORIG 25 (Unichem)'
);

-- line #17992
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMORIG 50 (Unichem)',
	'Lamotrigine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMORIG 50 (Unichem)'
);

-- line #17993
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMOSYN 100 (SUN)',
	'Lamotrigine',
	'OD TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMOSYN 100 (SUN)'
);

-- line #17994
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMOSYN 200 (SUN)',
	'Lamotrigine',
	'OD TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMOSYN 200 (SUN)'
);

-- line #17995
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMOSYN 50 (SUN)',
	'Lamotrigine',
	'OD TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMOSYN 50 (SUN)'
);

-- line #17996
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMOSYN 50 (Sun)',
	'Lamotrigine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMOSYN 50 (Sun)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMOSYN 100 (Sun)',
	'Lamotrigine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMOSYN 100 (Sun)'
);

-- line #17997
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMOSYN 5 (Sun)',
	'Lamotrigine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMOSYN 5 (Sun)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMOSYN 25 (Sun)',
	'Lamotrigine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMOSYN 25 (Sun)'
);

-- line #17998
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMOTRIVE 25 (STRIVE PH.)',
	'Lamotrigine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMOTRIVE 25 (STRIVE PH.)'
);

-- line #17999
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEMZ 100 (Tripada Hc.)',
	'Lamotrigine',
	'OD TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg M.R.'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEMZ 100 (Tripada Hc.)'
);

-- line #18000
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYZIN 100 (Pifer Ph.)',
	'Lamotrigine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYZIN 100 (Pifer Ph.)'
);

-- line #18001
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYZIN 25 (Pifer Ph.)',
	'Lamotrigine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYZIN 25 (Pifer Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYZIN 50 (Pifer Ph.)',
	'Lamotrigine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYZIN 50 (Pifer Ph.)'
);

-- line #18002
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOLAM 100 (Ranbaxy)',
	'Lamotrigine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOLAM 100 (Ranbaxy)'
);

-- line #18003
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOLAM 200 (Ranbaxy)',
	'Lamotrigine',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOLAM 200 (Ranbaxy)'
);

-- line #18004
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOLAM 50 (Ranbaxy)',
	'Lamotrigine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOLAM 50 (Ranbaxy)'
);

-- line #18005
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOMBRE 100 (Alkem)',
	'Lamotrigine',
	'OD TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOMBRE 100 (Alkem)'
);

-- line #18006
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOMBRE 50 (Alkem)',
	'Lamotrigine',
	'OD TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOMBRE 50 (Alkem)'
);

-- line #18007
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Lanolin', u'always_empty': u'', u'form': u'CRM', u'brand': u'CHAPCURE', u'strength_3': u'', u'company': u'Stedman', u'unit': u''}

-- line #18008
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Lanolin', u'always_empty': u'', u'form': u'CRM', u'brand': u'NIPCARE', u'strength_3': u'', u'company': u'Neon', u'unit': u''}

-- line #18009
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.(MODIFIED)', u'strength_2': u'', u'substance': u'Lanolin', u'always_empty': u'', u'form': u'OINT', u'brand': u'NIPHEAL', u'strength_3': u'', u'company': u'Sandoz', u'unit': u''}

-- line #18010
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACILANZ 15 (Themis Med.)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACILANZ 15 (Themis Med.)'
);

-- line #18011
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACILANZ 30 (Themis Med.)',
	'Lansoprazole',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACILANZ 30 (Themis Med.)'
);

-- line #18012
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANZ-30 30 (Monokem)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANZ-30 30 (Monokem)'
);

-- line #18013
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AQLANS 30 (Aquila)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AQLANS 30 (Aquila)'
);

-- line #18014
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARLAN 30 (Armour Rem.)',
	'Lansoprazole',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARLAN 30 (Armour Rem.)'
);

-- line #18015
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AUROLANE 30 (Auroma Life)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AUROLANE 30 (Auroma Life)'
);

-- line #18016
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BAL LANZ 30 (Bal Ph.)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BAL LANZ 30 (Bal Ph.)'
);

-- line #18017
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BELANSO 30 (Brooks Ph.)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BELANSO 30 (Brooks Ph.)'
);

-- line #18018
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAPRAZOLE 30 (Calibar Ph.)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAPRAZOLE 30 (Calibar Ph.)'
);

-- line #18019
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHEXID 30 (Aristo)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHEXID 30 (Aristo)'
);

-- line #18020
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COSLAN 30 (Cosmas Ph.)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COSLAN 30 (Cosmas Ph.)'
);

-- line #18021
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CULANS 30 (Elfin Ph.)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CULANS 30 (Elfin Ph.)'
);

-- line #18022
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYZOL 30 (Dynamic)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYZOL 30 (Dynamic)'
);

-- line #18023
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELOZA 30 (Ronak Lab.)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELOZA 30 (Ronak Lab.)'
);

-- line #18024
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELSAID 30 (Phytochem)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELSAID 30 (Phytochem)'
);

-- line #18025
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'15', u'strength_2': u'', u'substance': u'Lansoprazole', u'always_empty': u'', u'form': u'', u'brand': u'JUNIOR LANZOL', u'strength_3': u'', u'company': u'Cipla', u'unit': u'mg'}

-- line #18026
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JUNIOR LANZOL 30 (Cipla)',
	'Lansoprazole',
	'DT',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JUNIOR LANZOL 30 (Cipla)'
);

-- line #18027
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEXOL 30 (Cadex Lab)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEXOL 30 (Cadex Lab)'
);

-- line #18028
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KOPEN 30 (Kentreck)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KOPEN 30 (Kentreck)'
);

-- line #18029
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'L-15 15 (Brawn Lab)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'L-15 15 (Brawn Lab)'
);

-- line #18030
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'L-30 30 (Brawn Lab)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'L-30 30 (Brawn Lab)'
);

-- line #18031
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LACY 30 (Aronex Life)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LACY 30 (Aronex Life)'
);

-- line #18032
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMEM 30 (Anikem Lab.)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMEM 30 (Anikem Lab.)'
);

-- line #18033
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMPO-30 30 (Chemo D.)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMPO-30 30 (Chemo D.)'
);

-- line #18034
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANATE 30 (Briskon)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANATE 30 (Briskon)'
);

-- line #18035
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAN 15 (Intas)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('15')::numeric,
	'mg/30'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAN 15 (Intas)'
);

-- line #18036
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANCE 30 (Candor Bio.)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANCE 30 (Candor Bio.)'
);

-- line #18037
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANCER 15 (EAST WEST)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANCER 15 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANCER 30 (EAST WEST)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANCER 30 (EAST WEST)'
);

-- line #18038
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANCHEK 30 (Euphoric)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANCHEK 30 (Euphoric)'
);

-- line #18039
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANCIBAY 15 (Bayer)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANCIBAY 15 (Bayer)'
);

-- line #18040
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANCIBAY 30 (Bayer)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANCIBAY 30 (Bayer)'
);

-- line #18041
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANCID 15 (Brown & B.)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('15')::numeric,
	'mg/30'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANCID 15 (Brown & B.)'
);

-- line #18042
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANCIZ 30 (Indu D.)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANCIZ 30 (Indu D.)'
);

-- line #18043
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANCUS 30 (Cadila Ph.)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANCUS 30 (Cadila Ph.)'
);

-- line #18044
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANDS-30 30 (HANDS PH.)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANDS-30 30 (HANDS PH.)'
);

-- line #18045
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANGENIX 30 (Genix Ph.)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANGENIX 30 (Genix Ph.)'
);

-- line #18046
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANIP 30 (Winsome Lab)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANIP 30 (Winsome Lab)'
);

-- line #18047
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANNEZ 15 (Nestor)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANNEZ 15 (Nestor)'
);

-- line #18048
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANOCID 30 (Lark Labs)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANOCID 30 (Lark Labs)'
);

-- line #18049
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANOZ 30 (Osper)',
	'Lansoprazole',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANOZ 30 (Osper)'
);

-- line #18050
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANPIP 20 (Mefro Ph.)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANPIP 20 (Mefro Ph.)'
);

-- line #18051
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANPRO 15 (Unichem)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANPRO 15 (Unichem)'
);

-- line #18052
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANPRO 30 (Unichem)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANPRO 30 (Unichem)'
);

-- line #18053
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANSAIN 15 (Sain Med.)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANSAIN 15 (Sain Med.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANSAIN 30 (Sain Med.)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANSAIN 30 (Sain Med.)'
);

-- line #18054
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANSAPOLE 30 (Admac Ph.)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANSAPOLE 30 (Admac Ph.)'
);

-- line #18055
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANSEC 30 (Cipla)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANSEC 30 (Cipla)'
);

-- line #18056
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANSER 30 (Life Line)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANSER 30 (Life Line)'
);

-- line #18057
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANS 15 (Zydus Cadila)',
	'Lansoprazole',
	'MD CAP',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANS 15 (Zydus Cadila)'
);

-- line #18058
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANSNAT 15 (Natura)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANSNAT 15 (Natura)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANSNAT 30 (Natura)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANSNAT 30 (Natura)'
);

-- line #18059
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANSO-30 30 (Acron Ph.)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANSO-30 30 (Acron Ph.)'
);

-- line #18060
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANS 15 (Zydus Cadila)',
	'Lansoprazole',
	'OD CAP',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANS 15 (Zydus Cadila)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANS 30 (Zydus Cadila)',
	'Lansoprazole',
	'OD CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANS 30 (Zydus Cadila)'
);

-- line #18061
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANS 15 (Zydus Cadila)',
	'Lansoprazole',
	'OD CAP',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANS 15 (Zydus Cadila)'
);

-- line #18062
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANS 30 (Zydus Cadila)',
	'Lansoprazole',
	'OD CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANS 30 (Zydus Cadila)'
);

-- line #18063
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANSOFAST 15 (Zydus A.)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('15')::numeric,
	'mg/30'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANSOFAST 15 (Zydus A.)'
);

-- line #18064
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANSOL 30 (Arvind Lab.)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANSOL 30 (Arvind Lab.)'
);

-- line #18065
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANSOL 30 (Moraceae)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANSOL 30 (Moraceae)'
);

-- line #18066
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANSOMAC 30 (Mcneil & ARGUS)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANSOMAC 30 (Mcneil & ARGUS)'
);

-- line #18067
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANSOPAX 30 (Bipl(Radico Lab))',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANSOPAX 30 (Bipl(Radico Lab))'
);

-- line #18068
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANSOZ 15 (Finecure)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANSOZ 15 (Finecure)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANSOZ 30 (Finecure)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANSOZ 30 (Finecure)'
);

-- line #18069
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANSO 30 (ZOREX REM.)',
	'Lansoprazole',
	'ZR CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANSO 30 (ZOREX REM.)'
);

-- line #18070
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANSPEP 30 (Khandelwal)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANSPEP 30 (Khandelwal)'
);

-- line #18071
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANSPIC 30 (Alpic Ph.)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANSPIC 30 (Alpic Ph.)'
);

-- line #18072
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANSPRO 15 (Indchemie)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANSPRO 15 (Indchemie)'
);

-- line #18073
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANSPRO 30 (Indchemie)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANSPRO 30 (Indchemie)'
);

-- line #18074
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANSURE 15 (Allure Rem.)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('15')::numeric,
	'mg/30'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANSURE 15 (Allure Rem.)'
);

-- line #18075
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANSZEE 30 (G.T. Ph.)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANSZEE 30 (G.T. Ph.)'
);

-- line #18076
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANVI 30 (Acme Ph)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANVI 30 (Acme Ph)'
);

-- line #18077
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANZAP 15 (Dr.Reddy''S)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('15')::numeric,
	'mg/30'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANZAP 15 (Dr.Reddy''S)'
);

-- line #18078
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANZED 30 (Zota Ph.)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANZED 30 (Zota Ph.)'
);

-- line #18079
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANZEE 30 (Zee Lab)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANZEE 30 (Zee Lab)'
);

-- line #18080
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANZIP 30 (Cubit Hc.)',
	'Lansoprazole',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANZIP 30 (Cubit Hc.)'
);

-- line #18081
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANZO 30 (SANCHEZ LAB.)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANZO 30 (SANCHEZ LAB.)'
);

-- line #18082
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANZO 30 (Zydus Cadila)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANZO 30 (Zydus Cadila)'
);

-- line #18083
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANZOL 15 (Cipla)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('15')::numeric,
	'mg/30'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANZOL 15 (Cipla)'
);

-- line #18084
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANZOL JR 15 (Cipla)',
	'Lansoprazole',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANZOL JR 15 (Cipla)'
);

-- line #18085
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'15', u'strength_2': u'30', u'substance': u'Lansoprazole', u'always_empty': u'', u'form': u'', u'brand': u'LANZOL', u'strength_3': u'', u'company': u'Zydus Cadila', u'unit': u'mg'}

-- line #18086
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANZOPEN 15 (Morepen)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('15')::numeric,
	'mg/30'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANZOPEN 15 (Morepen)'
);

-- line #18087
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAP 30 (Antigen Hc.)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAP 30 (Antigen Hc.)'
);

-- line #18088
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LARIK 30 (Lanark)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LARIK 30 (Lanark)'
);

-- line #18089
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LASOLE 30 (Cure Quick)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LASOLE 30 (Cure Quick)'
);

-- line #18090
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAZ 30 (Active Hc.)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAZ 30 (Active Hc.)'
);

-- line #18091
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LECENT 30 (LUSTRE)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LECENT 30 (LUSTRE)'
);

-- line #18092
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEE 30 (Bestochem)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEE 30 (Bestochem)'
);

-- line #18093
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEED 30 (GENESIS)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEED 30 (GENESIS)'
);

-- line #18094
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEPEZ 30 (Symbiotic)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEPEZ 30 (Symbiotic)'
);

-- line #18095
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LERIZOL 30 (Biocin Hc.)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LERIZOL 30 (Biocin Hc.)'
);

-- line #18096
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LESOZAP 30 (Alde Medi.)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LESOZAP 30 (Alde Medi.)'
);

-- line #18097
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVANT 15 (Ranbaxy)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVANT 15 (Ranbaxy)'
);

-- line #18098
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVANT 30 (Ranbaxy)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVANT 30 (Ranbaxy)'
);

-- line #18099
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVANT 15 (Rextar)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVANT 15 (Rextar)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVANT 30 (Rextar)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVANT 30 (Rextar)'
);

-- line #18100
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVANT 30 (Ranbaxy)',
	'Lansoprazole',
	'EC GRAN CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVANT 30 (Ranbaxy)'
);

-- line #18101
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEZO 30 (Le Sante)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEZO 30 (Le Sante)'
);

-- line #18102
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEZOCID 30 (Ophthal R.)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEZOCID 30 (Ophthal R.)'
);

-- line #18103
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEZOL 30 (Vasphar)',
	'Lansoprazole',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEZOL 30 (Vasphar)'
);

-- line #18104
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIZA 30 (Ind-Swift)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIZA 30 (Ind-Swift)'
);

-- line #18105
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOCID 30 (Armour Rem.)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOCID 30 (Armour Rem.)'
);

-- line #18106
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOCID 30 (Pil)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOCID 30 (Pil)'
);

-- line #18107
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOC 30 (Siesta)',
	'Lansoprazole',
	'OD CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOC 30 (Siesta)'
);

-- line #18108
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LONA 30 (Orison Ph.)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LONA 30 (Orison Ph.)'
);

-- line #18109
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LONIDO 30 (SHINE PH.)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LONIDO 30 (SHINE PH.)'
);

-- line #18110
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOZ-30 30 (Malody Hc.)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOZ-30 30 (Malody Hc.)'
);

-- line #18111
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LP-30 30 (Waves Bio.)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LP-30 30 (Waves Bio.)'
);

-- line #18112
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LP 30 (Medo Chem)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LP 30 (Medo Chem)'
);

-- line #18113
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LPZ 30 (Laborate)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LPZ 30 (Laborate)'
);

-- line #18114
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUPIZOLE 30 (Lupin)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUPIZOLE 30 (Lupin)'
);

-- line #18115
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANSO 30 (Mercury Hc.)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANSO 30 (Mercury Hc.)'
);

-- line #18116
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOLAN 15 (Marc Lab)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOLAN 15 (Marc Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOLAN 30 (Marc Lab)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOLAN 30 (Marc Lab)'
);

-- line #18117
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEWZOL 30 (Dial Ph.)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEWZOL 30 (Dial Ph.)'
);

-- line #18118
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOACID 30 (Shinto Org.)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOACID 30 (Shinto Org.)'
);

-- line #18119
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OKALAN 30 (Cipla)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OKALAN 30 (Cipla)'
);

-- line #18120
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLANZ 30 (Olcare)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLANZ 30 (Olcare)'
);

-- line #18121
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLEZ-30 30 (D.R.John''S)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLEZ-30 30 (D.R.John''S)'
);

-- line #18122
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANCER 30 (Royal Lab)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANCER 30 (Royal Lab)'
);

-- line #18123
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEPSOLAN 30 (NOVARTIS)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEPSOLAN 30 (NOVARTIS)'
);

-- line #18124
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIFLAN 30 (Pifer Ph.)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIFLAN 30 (Pifer Ph.)'
);

-- line #18125
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROLAN 30 (Arbro Ph.)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROLAN 30 (Arbro Ph.)'
);

-- line #18126
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROPILAN 15 (Glenmark)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('15')::numeric,
	'mg/30'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROPILAN 15 (Glenmark)'
);

-- line #18127
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROTOGUT 15 (Novartis)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('15')::numeric,
	'mg/30'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROTOGUT 15 (Novartis)'
);

-- line #18128
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYLOREX 15 (VERITAZ)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYLOREX 15 (VERITAZ)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYLOREX 30 (VERITAZ)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYLOREX 30 (VERITAZ)'
);

-- line #18129
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q LANSE 30 (Que Ph.)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q LANSE 30 (Que Ph.)'
);

-- line #18130
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REFLAN 30 (Saga Lab)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REFLAN 30 (Saga Lab)'
);

-- line #18131
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RHOLAN 30 (Rhombus)',
	'Lansoprazole',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RHOLAN 30 (Rhombus)'
);

-- line #18132
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOSCHEK 250 (WOCKHARDT)',
	'LANTHANUM CARBONATE',
	'CHEW TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOSCHEK 250 (WOCKHARDT)'
);

-- line #18133
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOSCHEK 500 (WOCKHARDT)',
	'LANTHANUM CARBONATE',
	'CHEW TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOSCHEK 500 (WOCKHARDT)'
);

-- line #18134
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOSEND 250 (Dr.Reddy''S)',
	'LANTHANUM CARBONATE',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOSEND 250 (Dr.Reddy''S)'
);

-- line #18135
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOSEND 500 (Dr.Reddy''S)',
	'LANTHANUM CARBONATE',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOSEND 500 (Dr.Reddy''S)'
);

-- line #18136
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANTHONATE 250 (Micro Labs)',
	'LANTHANUM CARBONATE',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANTHONATE 250 (Micro Labs)'
);

-- line #18137
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANTHONATE 500 (Micro Labs)',
	'LANTHANUM CARBONATE',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANTHONATE 500 (Micro Labs)'
);

-- line #18138
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5G', u'strength_2': u'', u'substance': u'L-ARGININE', u'always_empty': u'', u'form': u'', u'brand': u'ARGIN', u'strength_3': u'', u'company': u'Fourrts', u'unit': u''}

-- line #18139
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARGINITRIC 500 (MEDREICH SAI.)',
	'L-ARGININE',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARGINITRIC 500 (MEDREICH SAI.)'
);

-- line #18140
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3G', u'strength_2': u'', u'substance': u'L-ARGININE', u'always_empty': u'', u'form': u'GRAN', u'brand': u'ARGINITRIC', u'strength_3': u'', u'company': u'MEDREICH SAI.', u'unit': u''}

-- line #18141
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3GM (+75', u'strength_2': u'', u'substance': u'L-ARGININE', u'always_empty': u'', u'form': u'', u'brand': u'ARGIPRIME', u'strength_3': u'', u'company': u'Sun', u'unit': u'mg PROANTHOCYANIDINS)'}

-- line #18142
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3G(ARGININE BP)', u'strength_2': u'', u'substance': u'L-ARGININE', u'always_empty': u'', u'form': u'TAB', u'brand': u'ARGISIDIL', u'strength_3': u'', u'company': u'Fourrts', u'unit': u''}

-- line #18143
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAVENOR 1000 (Indo French)',
	'L-ARGININE',
	'CAP',
	gm.nullify_empty_string('1000')::numeric,
	'mg(+PROANTHOCYANIDINS 20'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAVENOR 1000 (Indo French)'
);

-- line #18144
-- ignoring line: field [strength_1] not numeric: >>>500+(42.5<<<
-- {u'list_of_values_of_unknown_fields': [u'5; ', u' mg PINE BARK EXT.)', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500+(42.5', u'strength_2': u'', u'substance': u'L-ARGININE', u'always_empty': u'', u'form': u'SG CAP', u'brand': u'ENLARGE', u'strength_3': u'', u'company': u'Universal', u'unit': u'mg GINSENG EXT.'}

-- line #18145
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3G', u'strength_2': u'', u'substance': u'L-ARGININE', u'always_empty': u'', u'form': u'GRAN\\.', u'brand': u'GYARGIN', u'strength_3': u'', u'company': u'German R.', u'unit': u''}

-- line #18146
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3G', u'strength_2': u'', u'substance': u'L-ARGININE', u'always_empty': u'', u'form': u'', u'brand': u'L-ARGYL', u'strength_3': u'', u'company': u'APICAL HC.', u'unit': u''}

-- line #18147
-- ignoring line: field [strength_1] not numeric: >>>L-ARGININE<<<
-- {u'list_of_values_of_unknown_fields': [u'LYCOPENE', u'ZINC OXIDE', u'LUTEIN', u'ZEAXANITHIN COPPER', u'MANGANESE COPPER', u'MANGANESE METHYCOBALAMINE', u'SELENIOUS ACID', u'', u''], u'strength_1': u'L-ARGININE', u'strength_2': u'', u'substance': u'L-ARGININE', u'always_empty': u'', u'form': u'CAP', u'brand': u'LUTAMIN', u'strength_3': u'', u'company': u'DEWCARE', u'unit': u'VITAMIN E'}

-- line #18148
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITRIGA 5 (Indo French)',
	'L-ARGININE',
	'GEL',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITRIGA 5 (Indo French)'
);

-- line #18149
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10000IU.', u'strength_2': u'', u'substance': u'L-Asparaginase', u'always_empty': u'', u'form': u'INJ', u'brand': u'ALL-GINESE IU', u'strength_3': u'', u'company': u'Bharat S.', u'unit': u''}

-- line #18150
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU.', u'strength_2': u'', u'substance': u'L-Asparaginase', u'always_empty': u'', u'form': u'INJ', u'brand': u'ALL-GINESE IU', u'strength_3': u'', u'company': u'Bharat S.', u'unit': u''}

-- line #18151
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU.', u'strength_2': u'', u'substance': u'L-Asparaginase', u'always_empty': u'', u'form': u'INJ', u'brand': u'ASGINASE', u'strength_3': u'', u'company': u'SUPER SPE.', u'unit': u''}

-- line #18152
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10000IU.', u'strength_2': u'', u'substance': u'L-Asparaginase', u'always_empty': u'', u'form': u'V', u'brand': u'ASGINASE IU', u'strength_3': u'', u'company': u'Ranbaxy S.S.', u'unit': u''}

-- line #18153
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10000IU.', u'strength_2': u'', u'substance': u'L-Asparaginase', u'always_empty': u'', u'form': u'VIAL', u'brand': u'ASPANASE', u'strength_3': u'', u'company': u'Intas', u'unit': u''}

-- line #18154
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU.', u'strength_2': u'', u'substance': u'L-Asparaginase', u'always_empty': u'', u'form': u'VIAL', u'brand': u'ASPANASE', u'strength_3': u'', u'company': u'Intas', u'unit': u''}

-- line #18155
-- ignoring line: field [strength_1] not numeric: >>>5000IU<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU', u'strength_2': u'', u'substance': u'L-Asparaginase', u'always_empty': u'', u'form': u'INJ', u'brand': u'CELGINASE', u'strength_3': u'', u'company': u'CELON(VIVILON)', u'unit': u'10000IU'}

-- line #18156
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10000IU.(STERILE LYPHOLISED VIAL)', u'strength_2': u'', u'substance': u'L-Asparaginase', u'always_empty': u'', u'form': u'', u'brand': u'LAGICAD IU', u'strength_3': u'', u'company': u'Cadila Ph.', u'unit': u''}

-- line #18157
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU.(STERILE LYPHOLISED VIAL)', u'strength_2': u'', u'substance': u'L-Asparaginase', u'always_empty': u'', u'form': u'', u'brand': u'LAGICAD IU', u'strength_3': u'', u'company': u'Cadila Ph.', u'unit': u''}

-- line #18158
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10000IU.', u'strength_2': u'', u'substance': u'L-Asparaginase', u'always_empty': u'', u'form': u'INJ', u'brand': u'L-ASPARAGINASE IU', u'strength_3': u'', u'company': u"Dr.Reddy''S", u'unit': u''}

-- line #18159
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU.', u'strength_2': u'', u'substance': u'L-Asparaginase', u'always_empty': u'', u'form': u'INJ', u'brand': u'L-ASPARAGINASE IU', u'strength_3': u'', u'company': u"Dr.Reddy''S", u'unit': u''}

-- line #18160
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10000IU.', u'strength_2': u'', u'substance': u'L-Asparaginase', u'always_empty': u'', u'form': u'INJ', u'brand': u'L-ASPARAGINASE IU', u'strength_3': u'', u'company': u'Khandelwal', u'unit': u''}

-- line #18161
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU.', u'strength_2': u'', u'substance': u'L-Asparaginase', u'always_empty': u'', u'form': u'INJ', u'brand': u'L-ASPARAGINASE IU', u'strength_3': u'', u'company': u'Khandelwal', u'unit': u''}

-- line #18162
-- ignoring line: field [strength_1] not numeric: >>>5000IU<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU', u'strength_2': u'', u'substance': u'L-Asparaginase', u'always_empty': u'', u'form': u'VIAL', u'brand': u'L-ASPASE', u'strength_3': u'', u'company': u'MIRACALUS', u'unit': u'10000IU'}

-- line #18163
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10000IU.', u'strength_2': u'', u'substance': u'L-Asparaginase', u'always_empty': u'', u'form': u'INJ', u'brand': u'LEUCOGINASE', u'strength_3': u'', u'company': u'Vhb', u'unit': u''}

-- line #18164
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEUCOGINASE 10 (Vhb)',
	'L-Asparaginase',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'000KU'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEUCOGINASE 10 (Vhb)'
);

-- line #18165
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU.', u'strength_2': u'', u'substance': u'L-Asparaginase', u'always_empty': u'', u'form': u'INJ', u'brand': u'LEUCOGINASE', u'strength_3': u'', u'company': u'Vhb', u'unit': u''}

-- line #18166
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEUNASE 5 (Biochem)',
	'L-Asparaginase',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'000/10'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEUNASE 5 (Biochem)'
);

-- line #18167
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10000IU', u'strength_2': u'', u'substance': u'L-Asparaginase', u'always_empty': u'', u'form': u'INJ', u'brand': u'ONCOGINASE', u'strength_3': u'', u'company': u'CH.Bhagat', u'unit': u''}

-- line #18168
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'6000IU', u'strength_2': u'', u'substance': u'L-Asparaginase', u'always_empty': u'', u'form': u'INJ', u'brand': u'ONCOGINASE', u'strength_3': u'', u'company': u'CH.Bhagat', u'unit': u''}

-- line #18169
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50MCG', u'strength_2': u'ML', u'substance': u'Latanoprost', u'always_empty': u'', u'form': u'EYE DPS', u'brand': u'9PM', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #18170
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50MCG', u'strength_2': u'ML', u'substance': u'Latanoprost', u'always_empty': u'', u'form': u'EYE DPS', u'brand': u'IOPROST', u'strength_3': u'', u'company': u'FDC(PROXIMA)', u'unit': u''}

-- line #18171
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50MCG', u'strength_2': u'ML', u'substance': u'Latanoprost', u'always_empty': u'', u'form': u'DPS', u'brand': u'IOPTAME', u'strength_3': u'', u'company': u'Le Sante', u'unit': u''}

-- line #18172
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LACOMA 0.005 (Ajanta Ph.)',
	'Latanoprost',
	'EYE DPS',
	gm.nullify_empty_string('0.005')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LACOMA 0.005 (Ajanta Ph.)'
);

-- line #18173
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LATOCHEK 0.005 (Indoco Rem.)',
	'Latanoprost',
	'EYE DPS',
	gm.nullify_empty_string('0.005')::numeric,
	'%(0.02'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LATOCHEK 0.005 (Indoco Rem.)'
);

-- line #18174
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50MCG', u'strength_2': u'ML', u'substance': u'Latanoprost', u'always_empty': u'', u'form': u'DPS', u'brand': u'LATOPROST', u'strength_3': u'', u'company': u'Milmet', u'unit': u''}

-- line #18175
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,005', u'strength_2': u'', u'substance': u'Latanoprost', u'always_empty': u'', u'form': u'', u'brand': u'LATOPROST RT', u'strength_3': u'', u'company': u'Sun', u'unit': u'%'}

-- line #18176
-- ignoring line: field [strength_1] not numeric: >>>50MCG (BENZALKONIUM CH. 0.2<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50MCG (BENZALKONIUM CH. 0.2', u'strength_2': u'', u'substance': u'Latanoprost', u'always_empty': u'', u'form': u'EYE DPS', u'brand': u'LOPROST', u'strength_3': u'', u'company': u'F D C', u'unit': u'mg)'}

-- line #18177
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACYLCAR 500 (Intas)',
	'L-Carnitine',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg(ACETYL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACYLCAR 500 (Intas)'
);

-- line #18178
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'L-Carnitine', u'always_empty': u'', u'form': u'CAP', u'brand': u'CARNICLE', u'strength_3': u'', u'company': u'NEISS', u'unit': u''}

-- line #18179
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'L-Carnitine', u'always_empty': u'', u'form': u'INJ', u'brand': u'CARNILEV', u'strength_3': u'', u'company': u'AXERA', u'unit': u''}

-- line #18180
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500', u'strength_2': u'', u'substance': u'L-Carnitine', u'always_empty': u'', u'form': u'', u'brand': u'CARNISURE', u'strength_3': u'', u'company': u'Elder', u'unit': u'mg'}

-- line #18181
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'L-Carnitine', u'always_empty': u'', u'form': u'INJ', u'brand': u'CARNISURE', u'strength_3': u'', u'company': u'Elder', u'unit': u''}

-- line #18182
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARNISURE 500 (Elder)',
	'L-Carnitine',
	'SYR',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARNISURE 500 (Elder)'
);

-- line #18183
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'5ML', u'substance': u'L-Carnitine', u'always_empty': u'', u'form': u'AMP', u'brand': u'CARNITOR', u'strength_3': u'', u'company': u'Elder', u'unit': u''}

-- line #18184
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARNITOR 500 (Elder)',
	'L-Carnitine',
	'SYR',
	gm.nullify_empty_string('500')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARNITOR 500 (Elder)'
);

-- line #18185
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARNITOR 500 (Elder)',
	'L-Carnitine',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARNITOR 500 (Elder)'
);

-- line #18186
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARNITOR 500 (Modi Mundi)',
	'L-Carnitine',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARNITOR 500 (Modi Mundi)'
);

-- line #18187
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARNIVIT 500 (Ochoa)',
	'L-Carnitine',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARNIVIT 500 (Ochoa)'
);

-- line #18188
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAROVIT 500 (Tripada Hc.)',
	'L-Carnitine',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAROVIT 500 (Tripada Hc.)'
);

-- line #18189
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LACARNIT 200 (LA RENON)',
	'L-Carnitine',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LACARNIT 200 (LA RENON)'
);

-- line #18190
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LACARNIT 330 (LA RENON)',
	'L-Carnitine',
	'TAB',
	gm.nullify_empty_string('330')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LACARNIT 330 (LA RENON)'
);

-- line #18191
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'5ML', u'substance': u'L-Carnitine', u'always_empty': u'', u'form': u'INJ', u'brand': u'LENCAR', u'strength_3': u'', u'company': u'Elder', u'unit': u''}

-- line #18192
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LENCAR 500 (Elder)',
	'L-Carnitine',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LENCAR 500 (Elder)'
);

-- line #18193
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'L-TINE 330 (Mano Ph.)',
	'L-Carnitine',
	'TAB',
	gm.nullify_empty_string('330')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'L-TINE 330 (Mano Ph.)'
);

-- line #18194
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUCARNIT 330 (Nucron Ph.)',
	'L-Carnitine',
	'DT',
	gm.nullify_empty_string('330')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUCARNIT 330 (Nucron Ph.)'
);

-- line #18195
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REE 330 (Emcure)',
	'L-Carnitine',
	'TAB',
	gm.nullify_empty_string('330')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REE 330 (Emcure)'
);

-- line #18196
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REE 500 (EMCURE)',
	'L-Carnitine',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REE 500 (EMCURE)'
);

-- line #18197
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'L CAR 100 (Ordain Hc.)',
	'L-CARNOSINE',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'L CAR 100 (Ordain Hc.)'
);

-- line #18198
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARAVA 10 (Sanofi Aventis)',
	'Lefulnomide',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARAVA 10 (Sanofi Aventis)'
);

-- line #18199
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARAVA 20 (Sanofi Aventis)',
	'Lefulnomide',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARAVA 20 (Sanofi Aventis)'
);

-- line #18200
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLEFT 10 (Croslands)',
	'Lefulnomide',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLEFT 10 (Croslands)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLEFT 20 (Croslands)',
	'Lefulnomide',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLEFT 20 (Croslands)'
);

-- line #18201
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEFRA 10 (Torrent)',
	'Lefulnomide',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEFRA 10 (Torrent)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEFRA 20 (Torrent)',
	'Lefulnomide',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEFRA 20 (Torrent)'
);

-- line #18202
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEFUMIDE 10 (Cipla)',
	'Lefulnomide',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEFUMIDE 10 (Cipla)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEFUMIDE 20 (Cipla)',
	'Lefulnomide',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEFUMIDE 20 (Cipla)'
);

-- line #18203
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LISIFEN 10 (CADILA)',
	'LEFULNOMIDE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LISIFEN 10 (CADILA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LISIFEN 20 (CADILA)',
	'LEFULNOMIDE',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LISIFEN 20 (CADILA)'
);

-- line #18204
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LENALID 10 (Natco Ph.)',
	'LENALIDOMIDE',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LENALID 10 (Natco Ph.)'
);

-- line #18205
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LENALID 15 (Natco Ph.)',
	'LENALIDOMIDE',
	'CAP',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LENALID 15 (Natco Ph.)'
);

-- line #18206
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LENALID 5 (Natco Ph.)',
	'LENALIDOMIDE',
	'CAP',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LENALID 5 (Natco Ph.)'
);

-- line #18207
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10', u'strength_2': u'', u'substance': u'LENALIDOMIDE', u'always_empty': u'', u'form': u'', u'brand': u'LENANGIO', u'strength_3': u'', u'company': u"Dr.Reddy''S", u'unit': u'mg'}

-- line #18208
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5', u'strength_2': u'', u'substance': u'LENALIDOMIDE', u'always_empty': u'', u'form': u'', u'brand': u'LENANGIO', u'strength_3': u'', u'company': u"Dr.Reddy''S", u'unit': u'mg'}

-- line #18209
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LENANGIO 25 (DR. REDDY''S)',
	'LENALIDOMIDE',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LENANGIO 25 (DR. REDDY''S)'
);

-- line #18210
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LENOME 15 (Intas)',
	'LENALIDOMIDE',
	'CAP',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LENOME 15 (Intas)'
);

-- line #18211
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LENOME 25 (Intas)',
	'LENALIDOMIDE',
	'CAP',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LENOME 25 (Intas)'
);

-- line #18212
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LENOME 10 (INTAS BIO.)',
	'LENALIDOMIDE',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LENOME 10 (INTAS BIO.)'
);

-- line #18213
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LENOME 5 (INTAS BIO.)',
	'LENALIDOMIDE',
	'CAP',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LENOME 5 (INTAS BIO.)'
);

-- line #18214
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5', u'strength_2': u'', u'substance': u'LENALIDOMIDE', u'always_empty': u'', u'form': u'', u'brand': u'LENOMUST-5', u'strength_3': u'', u'company': u'Panacea', u'unit': u'mg'}

-- line #18215
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10', u'strength_2': u'', u'substance': u'LENALIDOMIDE', u'always_empty': u'', u'form': u'', u'brand': u'LENOMUST', u'strength_3': u'', u'company': u'Panacea', u'unit': u'mg'}

-- line #18216
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'25', u'strength_2': u'', u'substance': u'LENALIDOMIDE', u'always_empty': u'', u'form': u'', u'brand': u'LENOMUST', u'strength_3': u'', u'company': u'Panacea', u'unit': u'mg'}

-- line #18217
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LENZEST 10 (Sun)',
	'LENALIDOMIDE',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LENZEST 10 (Sun)'
);

-- line #18218
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LENZEST 25 (Sun)',
	'LENALIDOMIDE',
	'CAP',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LENZEST 25 (Sun)'
);

-- line #18219
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LENZEST 5 (Sun)',
	'LENALIDOMIDE',
	'CAP',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LENZEST 5 (Sun)'
);

-- line #18220
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINALID 15 (Natco Ph.)',
	'LENALIDOMIDE',
	'CAP',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINALID 15 (Natco Ph.)'
);

-- line #18221
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYELOMIDE 10 (SUPER SPE.)',
	'LENALIDOMIDE',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYELOMIDE 10 (SUPER SPE.)'
);

-- line #18222
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYELOMIDE 15 (SUPER SPE.)',
	'LENALIDOMIDE',
	'CAP',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYELOMIDE 15 (SUPER SPE.)'
);

-- line #18223
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYELOMIDE 25 (SUPER SPE.)',
	'LENALIDOMIDE',
	'CAP',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYELOMIDE 25 (SUPER SPE.)'
);

-- line #18224
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYELOMIDE 5 (SUPER SPE.)',
	'LENALIDOMIDE',
	'CAP',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYELOMIDE 5 (SUPER SPE.)'
);

-- line #18225
-- ignoring line: field [strength_1] not numeric: >>>MYCOBACTERIUM HEAT KILLED 0.5 * 10-9<<<
-- {u'list_of_values_of_unknown_fields': [u'NACL 0.9 ', u' %W/V', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'MYCOBACTERIUM HEAT KILLED 0.5 * 10-9', u'strength_2': u'', u'substance': u'LEPROSY IMMUNOMODULATOR', u'always_empty': u'', u'form': u'V', u'brand': u'IMMUVAC', u'strength_3': u'', u'company': u'CADILA ONCOCARE', u'unit': u'THIOMERSAL 0.1'}

-- line #18226
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANDIP 10 (Cardicare)',
	'Lercanidipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANDIP 10 (Cardicare)'
);

-- line #18227
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEREZ 10 (Healtheon)',
	'Lercanidipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEREZ 10 (Healtheon)'
);

-- line #18228
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LERKA 10 (Piramal Hc.)',
	'Lercanidipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LERKA 10 (Piramal Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LERKA 20 (Piramal Hc.)',
	'Lercanidipine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LERKA 20 (Piramal Hc.)'
);

-- line #18229
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LERVASC 10 (Lupin)',
	'Lercanidipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LERVASC 10 (Lupin)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LERVASC 20 (Lupin)',
	'Lercanidipine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LERVASC 20 (Lupin)'
);

-- line #18230
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOTENSYL 10 (Sun)',
	'Lercanidipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOTENSYL 10 (Sun)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOTENSYL 20 (Sun)',
	'Lercanidipine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOTENSYL 20 (Sun)'
);

-- line #18231
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANOLET 2.5 (Svizera)',
	'LETROZOLE',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANOLET 2.5 (Svizera)'
);

-- line #18232
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANOLET 5 (SVIZERA HC.)',
	'LETROZOLE',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANOLET 5 (SVIZERA HC.)'
);

-- line #18233
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APILET 2.5 (HEALTHCARE PL.)',
	'LETROZOLE',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APILET 2.5 (HEALTHCARE PL.)'
);

-- line #18234
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELOFEM 2.5 (CELON(VIVILON))',
	'LETROZOLE',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELOFEM 2.5 (CELON(VIVILON))'
);

-- line #18235
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELTROZ 2.5 (CELON)',
	'LETROZOLE',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELTROZ 2.5 (CELON)'
);

-- line #18236
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOMSET-L 2.5 (DAHLIA)',
	'LETROZOLE',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOMSET-L 2.5 (DAHLIA)'
);

-- line #18237
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEMARA 2.5 (Novartis)',
	'LETROZOLE',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEMARA 2.5 (Novartis)'
);

-- line #18238
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEOFER 2.5 (ALNA BIO.)',
	'LETROZOLE',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEOFER 2.5 (ALNA BIO.)'
);

-- line #18239
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLIRIPE 2.5 (Alembic)',
	'LETROZOLE',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLIRIPE 2.5 (Alembic)'
);

-- line #18240
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HERHOPE 2.5 (Torrent)',
	'LETROZOLE',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HERHOPE 2.5 (Torrent)'
);

-- line #18241
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDUKT 2.5 (Wanbury)',
	'LETROZOLE',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDUKT 2.5 (Wanbury)'
);

-- line #18242
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LECTOCOR 2.5 (CH.Bhagat)',
	'LETROZOLE',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LECTOCOR 2.5 (CH.Bhagat)'
);

-- line #18243
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEROS 0.25 (ROSE LABS)',
	'LETROZOLE',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEROS 0.25 (ROSE LABS)'
);

-- line #18244
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LETEGG 2.5 (German R.)',
	'LETROZOLE',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LETEGG 2.5 (German R.)'
);

-- line #18245
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LETERO 2.5 (HETERO HC.)',
	'LETROZOLE',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LETERO 2.5 (HETERO HC.)'
);

-- line #18246
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LETORIPE 2.5 (MIRACALUS)',
	'LETROZOLE',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LETORIPE 2.5 (MIRACALUS)'
);

-- line #18247
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LETOVAL 2.5 (Sun)',
	'LETROZOLE',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LETOVAL 2.5 (Sun)'
);

-- line #18248
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LETOV 2.5 (German R.)',
	'LETROZOLE',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LETOV 2.5 (German R.)'
);

-- line #18249
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LETPRO 2.5 (Otsira)',
	'LETROZOLE',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LETPRO 2.5 (Otsira)'
);

-- line #18250
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LET-REJUN 2.5 (Uni-Sank.)',
	'LETROZOLE',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LET-REJUN 2.5 (Uni-Sank.)'
);

-- line #18251
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LETROMAC 2.5 (Macleods)',
	'LETROZOLE',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LETROMAC 2.5 (Macleods)'
);

-- line #18252
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LETROPLUS 2.5 (Alkem)',
	'LETROZOLE',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LETROPLUS 2.5 (Alkem)'
);

-- line #18253
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LETROZ 2.5 (Sun)',
	'LETROZOLE',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LETROZ 2.5 (Sun)'
);

-- line #18254
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LETRYL 2.5 (Ar-Ex Labs.)',
	'LETROZOLE',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LETRYL 2.5 (Ar-Ex Labs.)'
);

-- line #18255
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LETSI 2.5 (Serum Int.)',
	'LETROZOLE',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LETSI 2.5 (Serum Int.)'
);

-- line #18256
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LETS 2.5 (Samarth)',
	'LETROZOLE',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LETS 2.5 (Samarth)'
);

-- line #18257
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LETZOL 2.5 (Vhb)',
	'LETROZOLE',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LETZOL 2.5 (Vhb)'
);

-- line #18258
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LETZ 2.5 (Chemech)',
	'LETROZOLE',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LETZ 2.5 (Chemech)'
);

-- line #18259
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2,5', u'strength_2': u'', u'substance': u'LETROZOLE', u'always_empty': u'', u'form': u'', u'brand': u'LYTROL', u'strength_3': u'', u'company': u'Ranbaxy', u'unit': u'mg'}

-- line #18260
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOMAZOL 2.5 (Khandelwal)',
	'LETROZOLE',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOMAZOL 2.5 (Khandelwal)'
);

-- line #18261
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEWOVA 2.5 (AKUMENTIS HC.)',
	'LETROZOLE',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEWOVA 2.5 (AKUMENTIS HC.)'
);

-- line #18262
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONCOLET 2.5 (Biochem)',
	'LETROZOLE',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONCOLET 2.5 (Biochem)'
);

-- line #18263
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORETA 2.5 (Dr.Reddy''S)',
	'LETROZOLE',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORETA 2.5 (Dr.Reddy''S)'
);

-- line #18264
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OVULET 2.5 (Bharat S.)',
	'LETROZOLE',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OVULET 2.5 (Bharat S.)'
);

-- line #18265
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OVULET 5 (Bharat S.)',
	'LETROZOLE',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OVULET 5 (Bharat S.)'
);

-- line #18266
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOVORIN 15 (Biochem)',
	'Leucovorin Calcium (Calcium Folinate)',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOVORIN 15 (Biochem)'
);

-- line #18267
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOVORIN 15 (Biochem)',
	'Leucovorin Calcium (Calcium Folinate)',
	'VIAL',
	gm.nullify_empty_string('15')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOVORIN 15 (Biochem)'
);

-- line #18268
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOVORIN 50 (Biochem)',
	'Leucovorin Calcium (Calcium Folinate)',
	'VIAL',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOVORIN 50 (Biochem)'
);

-- line #18269
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAFONATE 15 (MIRACALUS)',
	'Leucovorin Calcium (Calcium Folinate)',
	'AMP',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAFONATE 15 (MIRACALUS)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAFONATE 50 (MIRACALUS)',
	'Leucovorin Calcium (Calcium Folinate)',
	'AMP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAFONATE 50 (MIRACALUS)'
);

-- line #18270
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'15', u'strength_2': u'', u'substance': u'Leucovorin Calcium (Calcium Folinate)', u'always_empty': u'', u'form': u'', u'brand': u'CALCIUM FOLINATE', u'strength_3': u'', u'company': u"Dr.Reddy''S", u'unit': u'mg(FOLINIC ACID)'}

-- line #18271
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50', u'strength_2': u'', u'substance': u'Leucovorin Calcium (Calcium Folinate)', u'always_empty': u'', u'form': u'', u'brand': u'CALCIUM FOLINATE', u'strength_3': u'', u'company': u"Dr.Reddy''S", u'unit': u'mg(FOLINIC ACID)'}

-- line #18272
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALCIUM FOLINATE 15 (Biochem)',
	'Leucovorin Calcium (Calcium Folinate)',
	'INJ',
	gm.nullify_empty_string('15')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALCIUM FOLINATE 15 (Biochem)'
);

-- line #18273
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALCIUM FOLINATE 3 (Biochem)',
	'Leucovorin Calcium (Calcium Folinate)',
	'INJ',
	gm.nullify_empty_string('3')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALCIUM FOLINATE 3 (Biochem)'
);

-- line #18274
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALCIUM FOLINATE 15 (Biological E.)',
	'Leucovorin Calcium (Calcium Folinate)',
	'INJ',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALCIUM FOLINATE 15 (Biological E.)'
);

-- line #18275
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALCIUM FOLINATE 3 (Biological E.)',
	'Leucovorin Calcium (Calcium Folinate)',
	'INJ',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALCIUM FOLINATE 3 (Biological E.)'
);

-- line #18276
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALCIUM FOLINATE 50 (Biological E.)',
	'Leucovorin Calcium (Calcium Folinate)',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALCIUM FOLINATE 50 (Biological E.)'
);

-- line #18277
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALCIUM LEUCOVORIN 15 (Samarth)',
	'Leucovorin Calcium (Calcium Folinate)',
	'INJ',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALCIUM LEUCOVORIN 15 (Samarth)'
);

-- line #18278
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALCIUM LEUCOVORIN 3 (Samarth)',
	'Leucovorin Calcium (Calcium Folinate)',
	'INJ',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALCIUM LEUCOVORIN 3 (Samarth)'
);

-- line #18279
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALCIUM LEUCOVORIN 50 (Samarth)',
	'Leucovorin Calcium (Calcium Folinate)',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALCIUM LEUCOVORIN 50 (Samarth)'
);

-- line #18280
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALCIUM LEUCOVORIN 15 (Wyeth)',
	'Leucovorin Calcium (Calcium Folinate)',
	'INJ',
	gm.nullify_empty_string('15')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALCIUM LEUCOVORIN 15 (Wyeth)'
);

-- line #18281
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALCIUM LEUCOVORIN 3 (Wyeth)',
	'Leucovorin Calcium (Calcium Folinate)',
	'INJ',
	gm.nullify_empty_string('3')::numeric,
	'mg/1ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALCIUM LEUCOVORIN 3 (Wyeth)'
);

-- line #18282
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALCIUM LEUCOVORIN 50 (Wyeth)',
	'Leucovorin Calcium (Calcium Folinate)',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALCIUM LEUCOVORIN 50 (Wyeth)'
);

-- line #18283
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COVORIN 15 (CH.Bhagat)',
	'Leucovorin Calcium (Calcium Folinate)',
	'INJ',
	gm.nullify_empty_string('15')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COVORIN 15 (CH.Bhagat)'
);

-- line #18284
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COVORIN 3 (CH.Bhagat)',
	'Leucovorin Calcium (Calcium Folinate)',
	'INJ',
	gm.nullify_empty_string('3')::numeric,
	'mg/1ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COVORIN 3 (CH.Bhagat)'
);

-- line #18285
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COVORIN 15 (CH.Bhagat)',
	'Leucovorin Calcium (Calcium Folinate)',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COVORIN 15 (CH.Bhagat)'
);

-- line #18286
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COVORIN 50 (CH.Bhagat)',
	'Leucovorin Calcium (Calcium Folinate)',
	'VIAL',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COVORIN 50 (CH.Bhagat)'
);

-- line #18287
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DALISOL 15 (Lemery)',
	'Leucovorin Calcium (Calcium Folinate)',
	'INJ',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DALISOL 15 (Lemery)'
);

-- line #18288
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DALISOL 50 (Lemery)',
	'Leucovorin Calcium (Calcium Folinate)',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DALISOL 50 (Lemery)'
);

-- line #18289
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DALISOL 15 (Lemery)',
	'Leucovorin Calcium (Calcium Folinate)',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DALISOL 15 (Lemery)'
);

-- line #18290
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FASTOVORIN 3 (Cytomed(Alkem))',
	'Leucovorin Calcium (Calcium Folinate)',
	'INJ',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FASTOVORIN 3 (Cytomed(Alkem))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FASTOVORIN 15 (Cytomed(Alkem))',
	'Leucovorin Calcium (Calcium Folinate)',
	'INJ',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FASTOVORIN 15 (Cytomed(Alkem))'
);

-- line #18291
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FASTOVORIN 50 (Cytomed(Alkem))',
	'Leucovorin Calcium (Calcium Folinate)',
	'VIAL',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FASTOVORIN 50 (Cytomed(Alkem))'
);

-- line #18292
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Leucovorin Calcium (Calcium Folinate)', u'always_empty': u'', u'form': u'TAB', u'brand': u'KUNYRIN', u'strength_3': u'', u'company': u'Vhb', u'unit': u''}

-- line #18293
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEUCOPAR 15 (Parenteral)',
	'Leucovorin Calcium (Calcium Folinate)',
	'INJ',
	gm.nullify_empty_string('15')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEUCOPAR 15 (Parenteral)'
);

-- line #18294
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEUCOPAR 50 (Parenteral)',
	'Leucovorin Calcium (Calcium Folinate)',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEUCOPAR 50 (Parenteral)'
);

-- line #18295
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEUCORIN 15 (Samarth)',
	'Leucovorin Calcium (Calcium Folinate)',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEUCORIN 15 (Samarth)'
);

-- line #18296
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEUCOVORIN CALCIUM 15 (Biochem)',
	'Leucovorin Calcium (Calcium Folinate)',
	'INJ',
	gm.nullify_empty_string('15')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEUCOVORIN CALCIUM 15 (Biochem)'
);

-- line #18297
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEUCOVORIN CALCIUM 3 (Biochem)',
	'Leucovorin Calcium (Calcium Folinate)',
	'INJ',
	gm.nullify_empty_string('3')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEUCOVORIN CALCIUM 3 (Biochem)'
);

-- line #18298
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEUCOVORIN CALCIUM 50 (Biochem)',
	'Leucovorin Calcium (Calcium Folinate)',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEUCOVORIN CALCIUM 50 (Biochem)'
);

-- line #18299
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEUCOVORIN CALCIUM 3 (Cyanamid)',
	'Leucovorin Calcium (Calcium Folinate)',
	'INJ',
	gm.nullify_empty_string('3')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEUCOVORIN CALCIUM 3 (Cyanamid)'
);

-- line #18300
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEUCOVORIN CALCIUM 50 (Pharmacia)',
	'Leucovorin Calcium (Calcium Folinate)',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEUCOVORIN CALCIUM 50 (Pharmacia)'
);

-- line #18301
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEUCOVORIN 15 (Dabur Ph.)',
	'Leucovorin Calcium (Calcium Folinate)',
	'INJ',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEUCOVORIN 15 (Dabur Ph.)'
);

-- line #18302
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEUCOVORIN 3 (Dabur Ph.)',
	'Leucovorin Calcium (Calcium Folinate)',
	'INJ',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEUCOVORIN 3 (Dabur Ph.)'
);

-- line #18303
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEUCOVORIN 50 (Dabur Ph.)',
	'Leucovorin Calcium (Calcium Folinate)',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEUCOVORIN 50 (Dabur Ph.)'
);

-- line #18304
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUCAL 15 (CELON(VIVILON))',
	'Leucovorin Calcium (Calcium Folinate)',
	'AMP',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUCAL 15 (CELON(VIVILON))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUCAL 50 (CELON(VIVILON))',
	'Leucovorin Calcium (Calcium Folinate)',
	'AMP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUCAL 50 (CELON(VIVILON))'
);

-- line #18305
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUREN 15 (Intas)',
	'Leucovorin Calcium (Calcium Folinate)',
	'INJ',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUREN 15 (Intas)'
);

-- line #18306
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUREN 50 (Intas)',
	'Leucovorin Calcium (Calcium Folinate)',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUREN 50 (Intas)'
);

-- line #18307
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NYRIN 15 (Vhb)',
	'Leucovorin Calcium (Calcium Folinate)',
	'INJ',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NYRIN 15 (Vhb)'
);

-- line #18308
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NYRIN 3 (Vhb)',
	'Leucovorin Calcium (Calcium Folinate)',
	'INJ',
	gm.nullify_empty_string('3')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NYRIN 3 (Vhb)'
);

-- line #18309
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NYRIN 50 (Vhb)',
	'Leucovorin Calcium (Calcium Folinate)',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NYRIN 50 (Vhb)'
);

-- line #18310
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NYRIN 15 (Vhb)',
	'Leucovorin Calcium (Calcium Folinate)',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NYRIN 15 (Vhb)'
);

-- line #18311
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RECOVORIN 50 (Cadila Hc.)',
	'Leucovorin Calcium (Calcium Folinate)',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RECOVORIN 50 (Cadila Hc.)'
);

-- line #18312
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RECOVORIN 7.5 (Cadila Hc.)',
	'Leucovorin Calcium (Calcium Folinate)',
	'INJ',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RECOVORIN 7.5 (Cadila Hc.)'
);

-- line #18313
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RECOVORIN 15 (Cadila Hc.)',
	'Leucovorin Calcium (Calcium Folinate)',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RECOVORIN 15 (Cadila Hc.)'
);

-- line #18314
-- ignoring line: field [strength_1] not numeric: >>>1(BENZYL ALCOHOL IP 4.5<<<
-- {u'list_of_values_of_unknown_fields': [u' mg)', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1(BENZYL ALCOHOL IP 4.5', u'strength_2': u'', u'substance': u'Leuprolide Acetate', u'always_empty': u'', u'form': u'INJ', u'brand': u'AGOPRIDE', u'strength_3': u'', u'company': u'Alkem', u'unit': u'mg'}

-- line #18315
-- ignoring line: field [strength_1] not numeric: >>>4(BENZYL ALCOHOL IP 4.5<<<
-- {u'list_of_values_of_unknown_fields': [u' mg)', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'4(BENZYL ALCOHOL IP 4.5', u'strength_2': u'', u'substance': u'Leuprolide Acetate', u'always_empty': u'', u'form': u'INJ', u'brand': u'AGOPRIDE', u'strength_3': u'', u'company': u'Alkem', u'unit': u'mg'}

-- line #18316
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3,75', u'strength_2': u'', u'substance': u'Leuprolide Acetate', u'always_empty': u'', u'form': u'', u'brand': u'BLOZZOM', u'strength_3': u'', u'company': u'USV P', u'unit': u'mg'}

-- line #18317
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUROLIDE 4 (Samarth)',
	'Leuprolide Acetate',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg/4ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUROLIDE 4 (Samarth)'
);

-- line #18318
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUROLIDE 1 (Samarth)',
	'Leuprolide Acetate',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'mg/0.5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUROLIDE 1 (Samarth)'
);

-- line #18319
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEUPRODEX 3.75 (Bharat S.)',
	'Leuprolide Acetate',
	'INJ',
	gm.nullify_empty_string('3.75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEUPRODEX 3.75 (Bharat S.)'
);

-- line #18320
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Leuprolide Acetate', u'always_empty': u'', u'form': u'INJ', u'brand': u'LEUPROFACT', u'strength_3': u'', u'company': u'Zydus Cadila', u'unit': u''}

-- line #18321
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEUSVEN DEPO 11.25 (Sven Gen.)',
	'Leuprolide Acetate',
	'INJ',
	gm.nullify_empty_string('11.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEUSVEN DEPO 11.25 (Sven Gen.)'
);

-- line #18322
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEUSVEN DEPO 3.75 (Sven Gen.)',
	'Leuprolide Acetate',
	'INJ',
	gm.nullify_empty_string('3.75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEUSVEN DEPO 3.75 (Sven Gen.)'
);

-- line #18323
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEUSVEN 1 (Sven Gen.)',
	'Leuprolide Acetate',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'mg/0.5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEUSVEN 1 (Sven Gen.)'
);

-- line #18324
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEUSVEN 4 (Sven Gen.)',
	'Leuprolide Acetate',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg/4ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEUSVEN 4 (Sven Gen.)'
);

-- line #18325
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'11,25', u'strength_2': u'', u'substance': u'Leuprolide Acetate', u'always_empty': u'', u'form': u'INJ', u'brand': u'LEUSVEN', u'strength_3': u'', u'company': u'SVEN GENETECH', u'unit': u''}

-- line #18326
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'11,25', u'strength_2': u'', u'substance': u'Leuprolide Acetate', u'always_empty': u'', u'form': u'', u'brand': u'LUCRIN DEPOT', u'strength_3': u'', u'company': u'Abbott', u'unit': u'mg'}

-- line #18327
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3,75', u'strength_2': u'', u'substance': u'Leuprolide Acetate', u'always_empty': u'', u'form': u'', u'brand': u'LUCRIN DEPOT', u'strength_3': u'', u'company': u'Abbott', u'unit': u'mg'}

-- line #18328
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUPRIDE DEPOT 22.5 (Sun)',
	'Leuprolide Acetate',
	'INJ',
	gm.nullify_empty_string('22.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUPRIDE DEPOT 22.5 (Sun)'
);

-- line #18329
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUPRIDE DEPOT 7.5 (Sun)',
	'Leuprolide Acetate',
	'INJ',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUPRIDE DEPOT 7.5 (Sun)'
);

-- line #18330
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3,75', u'strength_2': u'', u'substance': u'Leuprolide Acetate', u'always_empty': u'', u'form': u'', u'brand': u'LUPRIDE DEPOT', u'strength_3': u'', u'company': u'Sun', u'unit': u'mg'}

-- line #18331
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUPRIDE 1 (Sun)',
	'Leuprolide Acetate',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUPRIDE 1 (Sun)'
);

-- line #18332
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Leuprolide Acetate', u'always_empty': u'', u'form': u'INJ', u'brand': u'LUPRIDE', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #18333
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUPROLIDE 3.75 (Lupin)',
	'Leuprolide Acetate',
	'INJ',
	gm.nullify_empty_string('3.75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUPROLIDE 3.75 (Lupin)'
);

-- line #18334
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NADOGON 3.75 (Life Med.)',
	'Leuprolide Acetate',
	'INJ',
	gm.nullify_empty_string('3.75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NADOGON 3.75 (Life Med.)'
);

-- line #18335
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROGTASE 1 (Wockhardt)',
	'Leuprolide Acetate',
	'AMP',
	gm.nullify_empty_string('1')::numeric,
	'mg/0.5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROGTASE 1 (Wockhardt)'
);

-- line #18336
-- ignoring line: field [strength_1] not numeric: >>>PH.EUR 2(BENZYL ALCOHOL 9<<<
-- {u'list_of_values_of_unknown_fields': [u' mg)', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'PH.EUR 2(BENZYL ALCOHOL 9', u'strength_2': u'', u'substance': u'LEUPRORELIN ACETATE', u'always_empty': u'', u'form': u'INJ', u'brand': u'LUPROIN', u'strength_3': u'', u'company': u'Themis Med.', u'unit': u'mg'}

-- line #18337
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUPRORIN DEPOT 3.75 (Intas)',
	'LEUPRORELIN ACETATE',
	'INJ',
	gm.nullify_empty_string('3.75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUPRORIN DEPOT 3.75 (Intas)'
);

-- line #18338
-- ignoring line: field [strength_1] not numeric: >>>PH.EUR 1<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'PH.EUR 1', u'strength_2': u'', u'substance': u'LEUPRORELIN ACETATE', u'always_empty': u'', u'form': u'INJ', u'brand': u'LUPRORIN', u'strength_3': u'', u'company': u'Themis Med.', u'unit': u'mg(BENZYL ALCOHOL 9'}

-- line #18339
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500', u'strength_2': u'', u'substance': u'LEVACECARNINE HCL', u'always_empty': u'', u'form': u'', u'brand': u'ELKAR', u'strength_3': u'', u'company': u'Ranbaxy', u'unit': u'mg'}

-- line #18340
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPAR 50 (Ornate Lab)',
	'Levamisole',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPAR 50 (Ornate Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPAR 150 (Ornate Lab)',
	'Levamisole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPAR 150 (Ornate Lab)'
);

-- line #18341
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEWORMIS 150 (GSK)',
	'Levamisole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEWORMIS 150 (GSK)'
);

-- line #18342
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEWORMIS 50 (GSK)',
	'Levamisole',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEWORMIS 50 (GSK)'
);

-- line #18343
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICARIS 150 (Ethnor)',
	'Levamisole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICARIS 150 (Ethnor)'
);

-- line #18344
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICARIS 50 (Ethnor)',
	'Levamisole',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICARIS 50 (Ethnor)'
);

-- line #18345
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMUMOD 50 (Tripada)',
	'Levamisole',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMUMOD 50 (Tripada)'
);

-- line #18346
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETRAX 150 (Nicholas)',
	'Levamisole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETRAX 150 (Nicholas)'
);

-- line #18347
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KETRAX 50 (Nicholas)',
	'Levamisole',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KETRAX 50 (Nicholas)'
);

-- line #18348
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVASOL 50 (Meridian)',
	'Levamisole',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVASOL 50 (Meridian)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVASOL 150 (Meridian)',
	'Levamisole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVASOL 150 (Meridian)'
);

-- line #18349
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVA 150 (Mdc Ph.)',
	'Levamisole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVA 150 (Mdc Ph.)'
);

-- line #18350
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOMOL 50 (Cipla)',
	'Levamisole',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOMOL 50 (Cipla)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOMOL 150 (Cipla)',
	'Levamisole',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOMOL 150 (Cipla)'
);

-- line #18351
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPICTAL 250 (Ipca)',
	'LEVETIRACETAM',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPICTAL 250 (Ipca)'
);

-- line #18352
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPICTAL 500 (Ipca)',
	'LEVETIRACETAM',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPICTAL 500 (Ipca)'
);

-- line #18353
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPICTAL 750 (Ipca)',
	'LEVETIRACETAM',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPICTAL 750 (Ipca)'
);

-- line #18354
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPILIVE 1000 (Lupin)',
	'LEVETIRACETAM',
	'ER',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPILIVE 1000 (Lupin)'
);

-- line #18355
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPILIVE 250 (Lupin)',
	'LEVETIRACETAM',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPILIVE 250 (Lupin)'
);

-- line #18356
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPILIVE 500 (Lupin)',
	'LEVETIRACETAM',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPILIVE 500 (Lupin)'
);

-- line #18357
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPILIVE 750 (Lupin)',
	'LEVETIRACETAM',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPILIVE 750 (Lupin)'
);

-- line #18358
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPLIVE 100 (Lupin)',
	'LEVETIRACETAM',
	'SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPLIVE 100 (Lupin)'
);

-- line #18359
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEPRA ORAL 100 (Ucb India)',
	'LEVETIRACETAM',
	'SOLS',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEPRA ORAL 100 (Ucb India)'
);

-- line #18360
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEPRA 1000 (Ucb India)',
	'LEVETIRACETAM',
	'TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEPRA 1000 (Ucb India)'
);

-- line #18361
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEPRA 250 (Ucb India)',
	'LEVETIRACETAM',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEPRA 250 (Ucb India)'
);

-- line #18362
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEPRA 500 (Ucb India)',
	'LEVETIRACETAM',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEPRA 500 (Ucb India)'
);

-- line #18363
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LENERVE 250 (EAST WEST)',
	'LEVETIRACETAM',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LENERVE 250 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LENERVE 500 (EAST WEST)',
	'LEVETIRACETAM',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LENERVE 500 (EAST WEST)'
);

-- line #18364
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVACETAM 250 (Micro Labs)',
	'LEVETIRACETAM',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVACETAM 250 (Micro Labs)'
);

-- line #18365
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVACETAM 500 (Micro Labs)',
	'LEVETIRACETAM',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVACETAM 500 (Micro Labs)'
);

-- line #18366
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVACETAM 750 (Micro Labs)',
	'LEVETIRACETAM',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVACETAM 750 (Micro Labs)'
);

-- line #18367
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVECETAM 250 (PSYCOREM)',
	'LEVETIRACETAM',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVECETAM 250 (PSYCOREM)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVECETAM 500 (PSYCOREM)',
	'LEVETIRACETAM',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVECETAM 500 (PSYCOREM)'
);

-- line #18368
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVERA 100 (Intas)',
	'LEVETIRACETAM',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVERA 100 (Intas)'
);

-- line #18369
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVERA 100 (INTAS)',
	'LEVETIRACETAM',
	'SOL',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVERA 100 (INTAS)'
);

-- line #18370
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVERA 1000 (ALTIMA (INTAS))',
	'LEVETIRACETAM',
	'TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVERA 1000 (ALTIMA (INTAS))'
);

-- line #18371
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVERA 1000 (Intas)',
	'LEVETIRACETAM',
	'XR TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVERA 1000 (Intas)'
);

-- line #18372
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVERA 500 (Intas)',
	'LEVETIRACETAM',
	'XR TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVERA 500 (Intas)'
);

-- line #18373
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVERA 750 (Intas)',
	'LEVETIRACETAM',
	'XR TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVERA 750 (Intas)'
);

-- line #18374
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVESAM 100 (Piramal Hc.)',
	'LEVETIRACETAM',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVESAM 100 (Piramal Hc.)'
);

-- line #18375
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVESAM 100 (Piramal Hc.)',
	'LEVETIRACETAM',
	'SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVESAM 100 (Piramal Hc.)'
);

-- line #18376
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVEXX ORAL 100 (Zydus N.S.)',
	'LEVETIRACETAM',
	'SOL',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVEXX ORAL 100 (Zydus N.S.)'
);

-- line #18377
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVEXX 250 (ZYDUS N.S.)',
	'LEVETIRACETAM',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVEXX 250 (ZYDUS N.S.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVEXX 500 (ZYDUS N.S.)',
	'LEVETIRACETAM',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVEXX 500 (ZYDUS N.S.)'
);

-- line #18378
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'750', u'strength_2': u'', u'substance': u'LEVETIRACETAM', u'always_empty': u'', u'form': u'TAB', u'brand': u'LEVEXX', u'strength_3': u'', u'company': u'ZYDUS N.S.', u'unit': u''}

-- line #18379
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVILEX 100 (ABBOTT)',
	'LEVETIRACETAM',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVILEX 100 (ABBOTT)'
);

-- line #18380
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVILEX 100 (ABBOTT)',
	'LEVETIRACETAM',
	'SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVILEX 100 (ABBOTT)'
);

-- line #18381
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVILEX 1000 (ABBOTT)',
	'LEVETIRACETAM',
	'TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVILEX 1000 (ABBOTT)'
);

-- line #18382
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVILEX 250 (ABBOTT)',
	'LEVETIRACETAM',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVILEX 250 (ABBOTT)'
);

-- line #18383
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVILEX 500 (ABBOTT)',
	'LEVETIRACETAM',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVILEX 500 (ABBOTT)'
);

-- line #18384
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVILEX 750 (ABBOTT)',
	'LEVETIRACETAM',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVILEX 750 (ABBOTT)'
);

-- line #18385
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVILEX 1000 (ABBOTT)',
	'LEVETIRACETAM',
	'XR TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVILEX 1000 (ABBOTT)'
);

-- line #18386
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVILEX 500 (ABBOTT)',
	'LEVETIRACETAM',
	'XR TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVILEX 500 (ABBOTT)'
);

-- line #18387
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVILEX 750 (ABBOTT)',
	'LEVETIRACETAM',
	'XR TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVILEX 750 (ABBOTT)'
);

-- line #18388
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVIL 1000 (Sun)',
	'LEVETIRACETAM',
	'TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVIL 1000 (Sun)'
);

-- line #18389
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVIPIL 100 (SUN)',
	'LEVETIRACETAM',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVIPIL 100 (SUN)'
);

-- line #18390
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVIPIL 100 (Sun)',
	'LEVETIRACETAM',
	'SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVIPIL 100 (Sun)'
);

-- line #18391
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEV 500 (Alkem)',
	'LEVETIRACETAM',
	'SR TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEV 500 (Alkem)'
);

-- line #18392
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVTAM 250 (Neu-Foreva)',
	'LEVETIRACETAM',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVTAM 250 (Neu-Foreva)'
);

-- line #18393
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVTAM 500 (Neu-Foreva)',
	'LEVETIRACETAM',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVTAM 500 (Neu-Foreva)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVTAM 750 (Neu-Foreva)',
	'LEVETIRACETAM',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVTAM 750 (Neu-Foreva)'
);

-- line #18394
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'LEVITERACETAM', u'always_empty': u'', u'form': u'XR TAB', u'brand': u'LEVIPIL', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #18395
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVIPIL 500 (Sun)',
	'LEVITERACETAM',
	'XR TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVIPIL 500 (Sun)'
);

-- line #18396
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVROXA 100 (Solus)',
	'LEVITERACETAM',
	'SOL',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVROXA 100 (Solus)'
);

-- line #18397
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVROXA 1000 (Solus)',
	'LEVITERACETAM',
	'TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVROXA 1000 (Solus)'
);

-- line #18398
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVROXA 250 (Solus)',
	'LEVITERACETAM',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVROXA 250 (Solus)'
);

-- line #18399
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVROXA 500 (Solus)',
	'LEVITERACETAM',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVROXA 500 (Solus)'
);

-- line #18400
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVROXA 750 (Solus)',
	'LEVITERACETAM',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVROXA 750 (Solus)'
);

-- line #18401
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500', u'strength_2': u'', u'substance': u'LEVOCARMINE', u'always_empty': u'', u'form': u'', u'brand': u'CARNIMED TM-500', u'strength_3': u'', u'company': u'Alkem', u'unit': u'mg'}

-- line #18402
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'1-AL 2.5 (F D C)',
	'Levocetirizine',
	'SYR',
	gm.nullify_empty_string('2.5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '1-AL 2.5 (F D C)'
);

-- line #18403
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'5-RIZ 5 (ARIAK BIO.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '5-RIZ 5 (ARIAK BIO.)'
);

-- line #18404
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACLOCET 5 (VILBERRY HC.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACLOCET 5 (VILBERRY HC.)'
);

-- line #18405
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Levocetirizine', u'always_empty': u'', u'form': u'SYR', u'brand': u'AIRITIS', u'strength_3': u'', u'company': u'Piramal Hc.', u'unit': u''}

-- line #18406
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AIRITIS 5 (Piramal Hc.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AIRITIS 5 (Piramal Hc.)'
);

-- line #18407
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AIRTIS 2.5 (Nicholas)',
	'Levocetirizine',
	'SYR',
	gm.nullify_empty_string('2.5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AIRTIS 2.5 (Nicholas)'
);

-- line #18408
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AIRTIS 5 (Nicholas)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AIRTIS 5 (Nicholas)'
);

-- line #18409
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Levocetirizine', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALCET', u'strength_3': u'', u'company': u'PRISM LIFESCI.', u'unit': u''}

-- line #18410
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALCI-5 5 (Bombay T.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALCI-5 5 (Bombay T.)'
);

-- line #18411
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5', u'strength_2': u'', u'substance': u'Levocetirizine', u'always_empty': u'', u'form': u'', u'brand': u'ALDAY ACTIV', u'strength_3': u'', u'company': u'SH PH.', u'unit': u'mg'}

-- line #18412
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALDINE 5 (NPIL)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALDINE 5 (NPIL)'
);

-- line #18413
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5', u'strength_2': u'', u'substance': u'Levocetirizine', u'always_empty': u'', u'form': u'', u'brand': u'ALERFIX', u'strength_3': u'', u'company': u'ERIS LIFE', u'unit': u'mg'}

-- line #18414
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALERTRIZ 5 (Cadila Ph.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALERTRIZ 5 (Cadila Ph.)'
);

-- line #18415
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALEVA 10 (Aronex Life)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALEVA 10 (Aronex Life)'
);

-- line #18416
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALEVA 5 (Aronex Life)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALEVA 5 (Aronex Life)'
);

-- line #18417
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALIDIL 5 (Pil)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALIDIL 5 (Pil)'
);

-- line #18418
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALLCET-DC 5 (LAKSUN)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALLCET-DC 5 (LAKSUN)'
);

-- line #18419
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALLENZA 5 (Stanmark)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALLENZA 5 (Stanmark)'
);

-- line #18420
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5', u'strength_2': u'', u'substance': u'Levocetirizine', u'always_empty': u'', u'form': u'', u'brand': u'ALLERTAG', u'strength_3': u'', u'company': u'SMENTAG PH.', u'unit': u'mg'}

-- line #18421
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALLES 5 (Destin Lab)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALLES 5 (Destin Lab)'
);

-- line #18422
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALLRITE 5 (German R.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALLRITE 5 (German R.)'
);

-- line #18423
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALRITE 5 (German R.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALRITE 5 (German R.)'
);

-- line #18424
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALTER-L 5 (Alkem)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg(DIHCL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALTER-L 5 (Alkem)'
);

-- line #18425
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALTIN-LE 5 (Sysmed)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALTIN-LE 5 (Sysmed)'
);

-- line #18426
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALTRIN 5 (TUNE PH.)',
	'Levocetirizine',
	'SYRUP',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALTRIN 5 (TUNE PH.)'
);

-- line #18427
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALTRIN 5 (TUNE PH.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALTRIN 5 (TUNE PH.)'
);

-- line #18428
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALVOZINE 5 (LEMON PH.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALVOZINE 5 (LEMON PH.)'
);

-- line #18429
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'DIHCL.', u'strength_2': u'', u'substance': u'Levocetirizine', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALZENE', u'strength_3': u'', u'company': u'Biochem', u'unit': u''}

-- line #18430
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZERO 5 (Indchemie)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZERO 5 (Indchemie)'
);

-- line #18431
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARCET 10 (Armour Rem.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARCET 10 (Armour Rem.)'
);

-- line #18432
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARGELLA 5 (Rowan Bio.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARGELLA 5 (Rowan Bio.)'
);

-- line #18433
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATCET-LV 5 (Atoz Ph.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATCET-LV 5 (Atoz Ph.)'
);

-- line #18434
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLUECET 5 (BLUE WINGS)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLUECET 5 (BLUE WINGS)'
);

-- line #18435
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BOROX 5 (BIOMAX LAB)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BOROX 5 (BIOMAX LAB)'
);

-- line #18436
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEFID-L 5 (Radicura)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEFID-L 5 (Radicura)'
);

-- line #18437
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETFIVE 5 (MEDISYS)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETFIVE 5 (MEDISYS)'
);

-- line #18438
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETLONG-L 5 (RND LAB)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETLONG-L 5 (RND LAB)'
);

-- line #18439
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETOM-L 5 (Om Bio.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETOM-L 5 (Om Bio.)'
);

-- line #18440
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETRIL-L 5 (Aquila)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETRIL-L 5 (Aquila)'
);

-- line #18441
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETRIL-L 5 (TRIDENT PH.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETRIL-L 5 (TRIDENT PH.)'
);

-- line #18442
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETRINA-LV 5 (Sayona)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETRINA-LV 5 (Sayona)'
);

-- line #18443
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETRITE 5 (Medopharm)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETRITE 5 (Medopharm)'
);

-- line #18444
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETSAFE 5 (UNI ORANGE(MAX))',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETSAFE 5 (UNI ORANGE(MAX))'
);

-- line #18445
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Levocetirizine', u'always_empty': u'', u'form': u'TAB', u'brand': u'C FRESH-L', u'strength_3': u'', u'company': u'SMART LAB.', u'unit': u''}

-- line #18446
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CISTIN-L 5 (D.R.John''S)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CISTIN-L 5 (D.R.John''S)'
);

-- line #18447
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIZ-LE 5 (ST.MORRISON)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIZ-LE 5 (ST.MORRISON)'
);

-- line #18448
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COVEL 5 (Glow derma)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COVEL 5 (Glow derma)'
);

-- line #18449
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEALL 5 (GENESIS)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEALL 5 (GENESIS)'
);

-- line #18450
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5', u'strength_2': u'', u'substance': u'Levocetirizine', u'always_empty': u'', u'form': u'', u'brand': u'DECET', u'strength_3': u'', u'company': u'ABLAZE HC', u'unit': u'mg'}

-- line #18451
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICET-L 5 (Divine Life)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICET-L 5 (Divine Life)'
);

-- line #18452
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILEVOCET 5 (Sanify)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILEVOCET 5 (Sanify)'
);

-- line #18453
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EKON 5 (Blue Cross)',
	'Levocetirizine',
	'XL TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EKON 5 (Blue Cross)'
);

-- line #18454
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Levocetirizine', u'always_empty': u'', u'form': u'SYR', u'brand': u'ELCETAL', u'strength_3': u'', u'company': u'STADCHEM', u'unit': u''}

-- line #18455
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELCETAL 5 (STADCHEM)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELCETAL 5 (STADCHEM)'
);

-- line #18456
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELCET 5 (Elfin Ph.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELCET 5 (Elfin Ph.)'
);

-- line #18457
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELCIHYST 5 (Indu D.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELCIHYST 5 (Indu D.)'
);

-- line #18458
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELCITY 5 (Biocin Hc.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELCITY 5 (Biocin Hc.)'
);

-- line #18459
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELCY 5 (Active Hc.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELCY 5 (Active Hc.)'
);

-- line #18460
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELRIZ 2.5 (Zuventus)',
	'Levocetirizine',
	'SYR',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELRIZ 2.5 (Zuventus)'
);

-- line #18461
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELRIZ 5 (Zuventus)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELRIZ 5 (Zuventus)'
);

-- line #18462
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELVO 5 (XCEL LABS)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELVO 5 (XCEL LABS)'
);

-- line #18463
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHIZINE 5 (ETHINEXT PHARMA)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHIZINE 5 (ETHINEXT PHARMA)'
);

-- line #18464
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FITIN 5 (Medley)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FITIN 5 (Medley)'
);

-- line #18465
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLAMOSET 5 (FLAMINGO PH.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLAMOSET 5 (FLAMINGO PH.)'
);

-- line #18466
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLCET 5 (Forgo Ph.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLCET 5 (Forgo Ph.)'
);

-- line #18467
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FREE-5 5 (Cerspin)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FREE-5 5 (Cerspin)'
);

-- line #18468
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FYCET 5 (Phytochem)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FYCET 5 (Phytochem)'
);

-- line #18469
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENLEVO 5 (Khandelwal)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENLEVO 5 (Khandelwal)'
);

-- line #18470
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLENCET 5 (Glenmark)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLENCET 5 (Glenmark)'
);

-- line #18471
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'H1 LEVO 5 (SYNER MED.)',
	'LEVOCETIRIZINE',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'H1 LEVO 5 (SYNER MED.)'
);

-- line #18472
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HATRIC 5 (Aristo)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HATRIC 5 (Aristo)'
);

-- line #18473
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HICET-L 5 (Micro Labs)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HICET-L 5 (Micro Labs)'
);

-- line #18474
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HISTACHEK 5 (Indoco Rem.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HISTACHEK 5 (Indoco Rem.)'
);

-- line #18475
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HISTEAL 5 (PHARMA P.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HISTEAL 5 (PHARMA P.)'
);

-- line #18476
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HITZIN-L 5 (HEXAL PH.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HITZIN-L 5 (HEXAL PH.)'
);

-- line #18477
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INCET 5 (VENSAT)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INCET 5 (VENSAT)'
);

-- line #18478
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Levocetirizine', u'always_empty': u'', u'form': u'MD TAB', u'brand': u'INCID', u'strength_3': u'', u'company': u'BAYER PH.', u'unit': u''}

-- line #18479
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JTRIN 5 (J.P. HC.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JTRIN 5 (J.P. HC.)'
);

-- line #18480
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JTRIN 5 (J.P.LIFE)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JTRIN 5 (J.P.LIFE)'
);

-- line #18481
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KIND 5 (SOLITAIRE(RADIX))',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KIND 5 (SOLITAIRE(RADIX))'
);

-- line #18482
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KLOCET 5 (KIVI LABS)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KLOCET 5 (KIVI LABS)'
);

-- line #18483
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'L-ALERID 2.5 (Cipla)',
	'Levocetirizine',
	'SYRUP',
	gm.nullify_empty_string('2.5')::numeric,
	'mg(DIHCL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'L-ALERID 2.5 (Cipla)'
);

-- line #18484
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'L-ALERID 5 (Cipla)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg(DIHCL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'L-ALERID 5 (Cipla)'
);

-- line #18485
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Levocetirizine', u'always_empty': u'', u'form': u'SYR', u'brand': u'LAVETA', u'strength_3': u'', u'company': u'Alembic', u'unit': u''}

-- line #18486
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAVETA 5 (Alembic)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAVETA 5 (Alembic)'
);

-- line #18487
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAZINE 5 (Genix Ph.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAZINE 5 (Genix Ph.)'
);

-- line #18488
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'L-CBIT 5 (Cubit Hc.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'L-CBIT 5 (Cubit Hc.)'
);

-- line #18489
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LC-DEX 5 (Cadex Lab)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LC-DEX 5 (Cadex Lab)'
);

-- line #18490
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LCD 5 (LA SERENA)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LCD 5 (LA SERENA)'
);

-- line #18491
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'L-CERIZINE 2.5 (Emcure)',
	'Levocetirizine',
	'SYRUP',
	gm.nullify_empty_string('2.5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'L-CERIZINE 2.5 (Emcure)'
);

-- line #18492
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'L-CERIZINE 5 (Emcure)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'L-CERIZINE 5 (Emcure)'
);

-- line #18493
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'L-CETANIL 5 (Jackson)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'L-CETANIL 5 (Jackson)'
);

-- line #18494
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'L-CETRIDOC 5 (GLENMARK)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'L-CETRIDOC 5 (GLENMARK)'
);

-- line #18495
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'L-CETRIZET 5 (Sun)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'L-CETRIZET 5 (Sun)'
);

-- line #18496
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'L-CETRON 2.5 (Cosme F.)',
	'Levocetirizine',
	'SYR',
	gm.nullify_empty_string('2.5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'L-CETRON 2.5 (Cosme F.)'
);

-- line #18497
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'L-CETRON 5 (Cfl Ph.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'L-CETRON 5 (Cfl Ph.)'
);

-- line #18498
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'L-CET 5 (Atrimed Ph.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'L-CET 5 (Atrimed Ph.)'
);

-- line #18499
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LC HISTA 5 (BIOCURE HC.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LC HISTA 5 (BIOCURE HC.)'
);

-- line #18500
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LCREST 5 (YASHTRA HEALTH)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LCREST 5 (YASHTRA HEALTH)'
);

-- line #18501
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LCT CURE 5 (CURE N CURE)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LCT CURE 5 (CURE N CURE)'
);

-- line #18502
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5', u'strength_2': u'', u'substance': u'Levocetirizine', u'always_empty': u'', u'form': u'', u'brand': u'LCT PURE', u'strength_3': u'', u'company': u'STERLING', u'unit': u'mg'}

-- line #18503
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LCZ-10 10 (RAPROSS)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg(DIHCL.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LCZ-10 10 (RAPROSS)'
);

-- line #18504
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Levocetirizine', u'always_empty': u'', u'form': u'', u'brand': u'LCZ-MID', u'strength_3': u'', u'company': u'Rapross', u'unit': u''}

-- line #18505
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LCZ 2.5 (Rapross)',
	'Levocetirizine',
	'SYR',
	gm.nullify_empty_string('2.5')::numeric,
	'mg/5ML(DIHCL.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LCZ 2.5 (Rapross)'
);

-- line #18506
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LCZ 5 (Rapross)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LCZ 5 (Rapross)'
);

-- line #18507
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'L DIO-1 10 (Unison)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'L DIO-1 10 (Unison)'
);

-- line #18508
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LECET 5 (SANCHEZ LAB.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LECET 5 (SANCHEZ LAB.)'
);

-- line #18509
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LECETZY 5 (Zee Lab)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LECETZY 5 (Zee Lab)'
);

-- line #18510
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LECOPE 5 (Mankind)',
	'Levocetirizine',
	'DT',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LECOPE 5 (Mankind)'
);

-- line #18511
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LECOPE 2.5 (Mankind)',
	'Levocetirizine',
	'SYR',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LECOPE 2.5 (Mankind)'
);

-- line #18512
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LECOPE 5 (Mankind)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LECOPE 5 (Mankind)'
);

-- line #18513
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LECY 5 (Bennet Ph.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LECY 5 (Bennet Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LECY 10 (Bennet Ph.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LECY 10 (Bennet Ph.)'
);

-- line #18514
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEDAY 5 (Burgeon Ph.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEDAY 5 (Burgeon Ph.)'
);

-- line #18515
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Levocetirizine', u'always_empty': u'', u'form': u'SYR', u'brand': u'LEET', u'strength_3': u'', u'company': u'WEST COAST', u'unit': u''}

-- line #18516
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Levocetirizine', u'always_empty': u'', u'form': u'TAB', u'brand': u'LEET', u'strength_3': u'', u'company': u'WEST COAST', u'unit': u''}

-- line #18517
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEEVIZ 5 (ADMAC (LEE BENZ))',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEEVIZ 5 (ADMAC (LEE BENZ))'
);

-- line #18518
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEHU 5 (ROSE LABS)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEHU 5 (ROSE LABS)'
);

-- line #18519
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LENCY 5 (Medoz Ph.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LENCY 5 (Medoz Ph.)'
);

-- line #18520
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LE-ONE 5 (Acron Ph.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LE-ONE 5 (Acron Ph.)'
);

-- line #18521
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEO 5 (ARCUS LABS)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEO 5 (ARCUS LABS)'
);

-- line #18522
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LERZIN 5 (Galpha)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LERZIN 5 (Galpha)'
);

-- line #18523
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LESET 5 (IPCA LAB.)',
	'Levocetirizine',
	'MD TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LESET 5 (IPCA LAB.)'
);

-- line #18524
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LESET 5 (Ipca)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LESET 5 (Ipca)'
);

-- line #18525
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LESTAL 5 (Rpg Life)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LESTAL 5 (Rpg Life)'
);

-- line #18526
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LET-5 5 (Siomond)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LET-5 5 (Siomond)'
);

-- line #18527
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LETINEM 5 (NEMI PH.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LETINEM 5 (NEMI PH.)'
);

-- line #18528
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVEREST 5 (MEDICO HEALTH)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVEREST 5 (MEDICO HEALTH)'
);

-- line #18529
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVINE-5 5 (Dominion)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVINE-5 5 (Dominion)'
);

-- line #18530
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOCE 5 (ALPHA TH.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOCE 5 (ALPHA TH.)'
);

-- line #18531
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOCETRIWAL 5 (Wallace)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOCETRIWAL 5 (Wallace)'
);

-- line #18532
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOCETS 5 (SHRESHTHA)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOCETS 5 (SHRESHTHA)'
);

-- line #18533
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOCET 2.5 (HETERO HC.)',
	'Levocetirizine',
	'SYR',
	gm.nullify_empty_string('2.5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOCET 2.5 (HETERO HC.)'
);

-- line #18534
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOCET 5 (HETERO HC.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOCET 5 (HETERO HC.)'
);

-- line #18535
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOCID 5 (AASTHA PH.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOCID 5 (AASTHA PH.)'
);

-- line #18536
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOC 5 (Regen Int.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOC 5 (Regen Int.)'
);

-- line #18537
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOHEXT 5 (AVENTIS PH.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOHEXT 5 (AVENTIS PH.)'
);

-- line #18538
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOHIST 5 (Yash Ph.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg(DIHCL.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOHIST 5 (Yash Ph.)'
);

-- line #18539
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOL 5 (TALENT LAB.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOL 5 (TALENT LAB.)'
);

-- line #18540
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOMED 5 (INNOMED HC.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOMED 5 (INNOMED HC.)'
);

-- line #18541
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVONITRIN 5 (Svizera)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVONITRIN 5 (Svizera)'
);

-- line #18542
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVONOZ 5 (INNOWAYZ PH.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVONOZ 5 (INNOWAYZ PH.)'
);

-- line #18543
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVORICH 5 (AXIS LIFE)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVORICH 5 (AXIS LIFE)'
);

-- line #18544
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVORID 5 (Cipla)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVORID 5 (Cipla)'
);

-- line #18545
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVORIL 5 (ACTO)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVORIL 5 (ACTO)'
);

-- line #18546
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVORIZE 5 (JARUN PH.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVORIZE 5 (JARUN PH.)'
);

-- line #18547
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVORIZ 20 (Ritz Ph.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVORIZ 20 (Ritz Ph.)'
);

-- line #18548
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Levocetirizine', u'always_empty': u'', u'form': u'MD TAB', u'brand': u'LEVOSIZ', u'strength_3': u'', u'company': u'Systopic', u'unit': u''}

-- line #18549
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOSIZ 5 (Systopic)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOSIZ 5 (Systopic)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOSIZ 10 (Systopic)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOSIZ 10 (Systopic)'
);

-- line #18550
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOSTAR 5 (Intra Lab)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOSTAR 5 (Intra Lab)'
);

-- line #18551
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOSTAT 5 (ALPHA & OMEGA)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOSTAT 5 (ALPHA & OMEGA)'
);

-- line #18552
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOTIN 5 (MOLEKULE)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg(DIHYDR.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOTIN 5 (MOLEKULE)'
);

-- line #18553
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOTRA 5 (MOLEKULE)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOTRA 5 (MOLEKULE)'
);

-- line #18554
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOTRINE 5 (Graf Lab.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOTRINE 5 (Graf Lab.)'
);

-- line #18555
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOZIC 5 (Nexus)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOZIC 5 (Nexus)'
);

-- line #18556
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOZIN 5 (Moraceae)',
	'Levocetirizine',
	'SUSP',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOZIN 5 (Moraceae)'
);

-- line #18557
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOZIN 5 (Moraceae)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOZIN 5 (Moraceae)'
);

-- line #18558
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Levocetirizine', u'always_empty': u'', u'form': u'TAB', u'brand': u'LEVOZ', u'strength_3': u'', u'company': u'ETHIX HC.', u'unit': u''}

-- line #18559
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVUXIA 5 (Chemo Bio.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVUXIA 5 (Chemo Bio.)'
);

-- line #18560
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEXCET 5 (AXEN PH.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEXCET 5 (AXEN PH.)'
);

-- line #18561
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEXOZEN 5 (AXYZEN LIFE)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEXOZEN 5 (AXYZEN LIFE)'
);

-- line #18562
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEXZIN 5 (LEXUS)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEXZIN 5 (LEXUS)'
);

-- line #18563
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEZEE 5 (SAILLON PH.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEZEE 5 (SAILLON PH.)'
);

-- line #18564
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Levocetirizine', u'always_empty': u'', u'form': u'TAB', u'brand': u'LEZET', u'strength_3': u'', u'company': u'ZOTICUS', u'unit': u''}

-- line #18565
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEZIT 10 (EHC)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEZIT 10 (EHC)'
);

-- line #18566
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEZO 5 (Cadila Ph.)',
	'Levocetirizine',
	'MD TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEZO 5 (Cadila Ph.)'
);

-- line #18567
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEZO 5 (Cadila Hc.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEZO 5 (Cadila Hc.)'
);

-- line #18568
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10 TAB', u'strength_2': u'', u'substance': u'Levocetirizine', u'always_empty': u'', u'form': u'TAB', u'brand': u'LEZYNCET-D', u'strength_3': u'', u'company': u'Unichem', u'unit': u''}

-- line #18569
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LE ZYNCET 2.5 (Unichem)',
	'Levocetirizine',
	'SYR',
	gm.nullify_empty_string('2.5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LE ZYNCET 2.5 (Unichem)'
);

-- line #18570
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LE ZYNCET 5 (Unichem)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LE ZYNCET 5 (Unichem)'
);

-- line #18571
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LFAST 5 (Le Sante)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LFAST 5 (Le Sante)'
);

-- line #18572
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LG-5 5 (UNITED LIFE)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LG-5 5 (UNITED LIFE)'
);

-- line #18573
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'L-HISTRIZ 5 (Theo Ph.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'L-HISTRIZ 5 (Theo Ph.)'
);

-- line #18574
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LITEC 5 (Tripada BIO.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LITEC 5 (Tripada BIO.)'
);

-- line #18575
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LITRIZ 5 (BIOKIND HC.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LITRIZ 5 (BIOKIND HC.)'
);

-- line #18576
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIVOT 5 (TRUMAC)',
	'Levocetirizine',
	'MD TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIVOT 5 (TRUMAC)'
);

-- line #18577
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIVOZINE 5 (SALVO HC.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIVOZINE 5 (SALVO HC.)'
);

-- line #18578
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOCET-5 5 (FIRST CHOICE)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOCET-5 5 (FIRST CHOICE)'
);

-- line #18579
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOD 5 (SOL DERMA)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOD 5 (SOL DERMA)'
);

-- line #18580
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOVECET 5 (CHEMO HC.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOVECET 5 (CHEMO HC.)'
);

-- line #18581
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'L-TRIZ 5 (Intra(INVISION))',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'L-TRIZ 5 (Intra(INVISION))'
);

-- line #18582
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUCET 5 (LUCIFER & H.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUCET 5 (LUCIFER & H.)'
);

-- line #18583
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'L-VCET 5 (Atrimed Ph.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'L-VCET 5 (Atrimed Ph.)'
);

-- line #18584
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Levocetirizine', u'always_empty': u'', u'form': u'TAB', u'brand': u'LVC', u'strength_3': u'', u'company': u'Zealot Biotech', u'unit': u''}

-- line #18585
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYCET 5 (MADHAV BIO.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYCET 5 (MADHAV BIO.)'
);

-- line #18586
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYNCET 5 (Dowell)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYNCET 5 (Dowell)'
);

-- line #18587
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Levocetirizine', u'always_empty': u'', u'form': u'TAB', u'brand': u'L-Z', u'strength_3': u'', u'company': u'NIVCA', u'unit': u''}

-- line #18588
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACLIZ 5 (Admac (CADMA))',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACLIZ 5 (Admac (CADMA))'
);

-- line #18589
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METLEZIN 5 (MODHIKE)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METLEZIN 5 (MODHIKE)'
);

-- line #18590
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NISLEVO 5 (Neiss)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NISLEVO 5 (Neiss)'
);

-- line #18591
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUCET 5 (Helax Hc.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUCET 5 (Helax Hc.)'
);

-- line #18592
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODICET 5 (Espira Life)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODICET 5 (Espira Life)'
);

-- line #18593
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFFCET-L 5 (R.B.REM.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFFCET-L 5 (R.B.REM.)'
);

-- line #18594
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OKACET-L 5 (Cipla)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OKACET-L 5 (Cipla)'
);

-- line #18595
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORIEL 5 (Intas)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg(DIHCL.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORIEL 5 (Intas)'
);

-- line #18596
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PALEO-5 5 (John Bio.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PALEO-5 5 (John Bio.)'
);

-- line #18597
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIMECET 5 (Ind-Swift)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIMECET 5 (Ind-Swift)'
);

-- line #18598
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRULET 5 (ALLAY PH.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRULET 5 (ALLAY PH.)'
);

-- line #18599
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PTCET 5 (Taurus Lab)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PTCET 5 (Taurus Lab)'
);

-- line #18600
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELECET 5 (Glister Hc.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELECET 5 (Glister Hc.)'
);

-- line #18601
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RINOCET 5 (Speciality Med.)',
	'Levocetirizine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RINOCET 5 (Speciality Med.)'
);

-- line #18602
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUPITUSS 35.4 (Lupin)',
	'LEVOCLOPERASTINE FENDIZOATE EQ TO LEVOPERASTINE HYDROCHLORIDE',
	'COUGH SYRUP',
	gm.nullify_empty_string('35.4')::numeric,
	'20'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUPITUSS 35.4 (Lupin)'
);

-- line #18603
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIDOPAL 500 (GSK)',
	'Levodopa',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIDOPAL 500 (GSK)'
);

-- line #18604
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOPA 500 (Wallace)',
	'Levodopa',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOPA 500 (Wallace)'
);

-- line #18605
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAPITUS 30 (MACLEODS)',
	'LEVODROPROPIZINE',
	'SUS',
	gm.nullify_empty_string('30')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAPITUS 30 (MACLEODS)'
);

-- line #18606
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACQUIRE 250 (SHRESHTHA)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACQUIRE 250 (SHRESHTHA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACQUIRE 500 (SHRESHTHA)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACQUIRE 500 (SHRESHTHA)'
);

-- line #18607
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACQUIRE 750 (SHRESHTHA)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACQUIRE 750 (SHRESHTHA)'
);

-- line #18608
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADDFLOX 500 (ADDPLUS)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADDFLOX 500 (ADDPLUS)'
);

-- line #18609
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AFLEVO 500 (POSITIF(AFIVE))',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AFLEVO 500 (POSITIF(AFIVE))'
);

-- line #18610
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AGILEVO 250 (AGIO PH.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AGILEVO 250 (AGIO PH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AGILEVO 500 (AGIO PH.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AGILEVO 500 (AGIO PH.)'
);

-- line #18611
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AGILEVO 750 (AGIO PH.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AGILEVO 750 (AGIO PH.)'
);

-- line #18612
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBACTIN 250 (Meridian)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBACTIN 250 (Meridian)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBACTIN 500 (Meridian)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBACTIN 500 (Meridian)'
);

-- line #18613
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBACTIN 250 (Meridian)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBACTIN 250 (Meridian)'
);

-- line #18614
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBACTIN 500 (Meridian)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBACTIN 500 (Meridian)'
);

-- line #18615
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALEFLOX 500 (AINA BIO.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALEFLOX 500 (AINA BIO.)'
);

-- line #18616
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALEVON 500 (ALPHA TH.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALEVON 500 (ALPHA TH.)'
);

-- line #18617
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALEVON 250 (ANAND HC.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALEVON 250 (ANAND HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALEVON 500 (ANAND HC.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALEVON 500 (ANAND HC.)'
);

-- line #18618
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALEVO 250 (Alkem)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALEVO 250 (Alkem)'
);

-- line #18619
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALEVO 500 (Alkem)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALEVO 500 (Alkem)'
);

-- line #18620
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALEVO 750 (Alkem)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALEVO 750 (Alkem)'
);

-- line #18621
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALFACIN 500 (Biocare Rem.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALFACIN 500 (Biocare Rem.)'
);

-- line #18622
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALVEOXY 250 (SKYLARK PH.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALVEOXY 250 (SKYLARK PH.)'
);

-- line #18623
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALVOX 250 (Bombay T.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALVOX 250 (Bombay T.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALVOX 500 (Bombay T.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALVOX 500 (Bombay T.)'
);

-- line #18624
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARVOF 500 (Ronak Lab.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARVOF 500 (Ronak Lab.)'
);

-- line #18625
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500', u'strength_2': u'', u'substance': u'Levofloxacin', u'always_empty': u'', u'form': u'', u'brand': u'ASTROSOL', u'strength_3': u'', u'company': u'Solitaire', u'unit': u'mg'}

-- line #18626
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZELEV-250 250 (ABLAZE HC)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZELEV-250 250 (ABLAZE HC)'
);

-- line #18627
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZELEV-500 500 (ABLAZE HC)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZELEV-500 500 (ABLAZE HC)'
);

-- line #18628
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACSTAN-L 500 (AVIS LIFE)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACSTAN-L 500 (AVIS LIFE)'
);

-- line #18629
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BESTOLEE-500 500 (Bestochem)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BESTOLEE-500 500 (Bestochem)'
);

-- line #18630
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLEVO 250 (AUGMENT REM.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLEVO 250 (AUGMENT REM.)'
);

-- line #18631
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLEVO 500 (AUGMENT REM.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLEVO 500 (AUGMENT REM.)'
);

-- line #18632
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLF-50 500 (BIOGENESIS)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLF-50 500 (BIOGENESIS)'
);

-- line #18633
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250', u'strength_2': u'', u'substance': u'Levofloxacin', u'always_empty': u'', u'form': u'', u'brand': u'BLUEQUIN-250', u'strength_3': u'', u'company': u'BLUE WINGS', u'unit': u'mg'}

-- line #18634
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500', u'strength_2': u'', u'substance': u'Levofloxacin', u'always_empty': u'', u'form': u'', u'brand': u'BLUEQUIN-500', u'strength_3': u'', u'company': u'BLUE WINGS', u'unit': u'mg'}

-- line #18635
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEVOBACT 250 (Malcom Ph.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEVOBACT 250 (Malcom Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEVOBACT 500 (Malcom Ph.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEVOBACT 500 (Malcom Ph.)'
);

-- line #18636
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHARLEV 250 (Charmos Bio.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHARLEV 250 (Charmos Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHARLEV 500 (Charmos Bio.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHARLEV 500 (Charmos Bio.)'
);

-- line #18637
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHARLEV 750 (Charmos Bio.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHARLEV 750 (Charmos Bio.)'
);

-- line #18638
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-LIVO 250 (Corona)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-LIVO 250 (Corona)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-LIVO 500 (Corona)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-LIVO 500 (Corona)'
);

-- line #18639
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COSFLOX 250 (Cosme F.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COSFLOX 250 (Cosme F.)'
);

-- line #18640
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COSFLOX 500 (Cosme F.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COSFLOX 500 (Cosme F.)'
);

-- line #18641
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUFLOX 500 (Cubit Hc.)',
	'Levofloxacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg/100ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUFLOX 500 (Cubit Hc.)'
);

-- line #18642
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUFLOX 500 (Cubit Hc.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUFLOX 500 (Cubit Hc.)'
);

-- line #18643
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUTIFLOX 500 (Indu D.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUTIFLOX 500 (Indu D.)'
);

-- line #18644
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAY-5 500 (Bestochem)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAY-5 500 (Bestochem)'
);

-- line #18645
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEFOX 500 (DAKSH)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEFOX 500 (DAKSH)'
);

-- line #18646
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIOLOF IV 500 (DIVINE LIFE)',
	'Levofloxacin',
	'INF',
	gm.nullify_empty_string('500')::numeric,
	'mg(+SOD. CHL. 900'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIOLOF IV 500 (DIVINE LIFE)'
);

-- line #18647
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIOLOF 750 (Divine Life)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIOLOF 750 (Divine Life)'
);

-- line #18648
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYLEVO 250 (Dynamic)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYLEVO 250 (Dynamic)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYLEVO 500 (Dynamic)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYLEVO 500 (Dynamic)'
);

-- line #18649
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'E-LIVO 500 (MARLINE BIO.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'E-LIVO 500 (MARLINE BIO.)'
);

-- line #18650
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELVOF 500 (Zedip Form.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELVOF 500 (Zedip Form.)'
);

-- line #18651
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELVOX 250 (Elder)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELVOX 250 (Elder)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELVOX 500 (Elder)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELVOX 500 (Elder)'
);

-- line #18652
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMCARE 500 (Shrinivas)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMCARE 500 (Shrinivas)'
);

-- line #18653
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENAFLOX 500 (Vivid Lab)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENAFLOX 500 (Vivid Lab)'
);

-- line #18654
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENATOME 250 (EPITOME)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENATOME 250 (EPITOME)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENATOME 500 (EPITOME)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENATOME 500 (EPITOME)'
);

-- line #18655
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENATOME 750 (EPITOME)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENATOME 750 (EPITOME)'
);

-- line #18656
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EVABIT 250 (ZUBIT)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EVABIT 250 (ZUBIT)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EVABIT 500 (ZUBIT)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EVABIT 500 (ZUBIT)'
);

-- line #18657
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EVAMAX 250 (Medicamen)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EVAMAX 250 (Medicamen)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EVAMAX 500 (Medicamen)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EVAMAX 500 (Medicamen)'
);

-- line #18658
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EVOCARE 250 (KPL LIFE)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EVOCARE 250 (KPL LIFE)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EVOCARE 500 (KPL LIFE)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EVOCARE 500 (KPL LIFE)'
);

-- line #18659
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EVOPIC 250 (Alpic Bio.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EVOPIC 250 (Alpic Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EVOPIC 500 (Alpic Bio.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EVOPIC 500 (Alpic Bio.)'
);

-- line #18660
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EVOPIC 750 (Alpic Bio.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EVOPIC 750 (Alpic Bio.)'
);

-- line #18661
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FINEFLOX 250 (FINE BIO-SC.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FINEFLOX 250 (FINE BIO-SC.)'
);

-- line #18662
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FINEFLOX 500 (FINE BIO-SC.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FINEFLOX 500 (FINE BIO-SC.)'
);

-- line #18663
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLAVO 500 (Forgo Ph.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLAVO 500 (Forgo Ph.)'
);

-- line #18664
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOLEV 500 (Intas)',
	'LEVOFloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOLEV 500 (Intas)'
);

-- line #18665
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOLEV 750 (Intas)',
	'LEVOFloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOLEV 750 (Intas)'
);

-- line #18666
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOQUIN 0.5 (Intra(INVISION))',
	'Levofloxacin',
	'DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOQUIN 0.5 (Intra(INVISION))'
);

-- line #18667
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOQUIN 500 (Intra(INVISION))',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOQUIN 500 (Intra(INVISION))'
);

-- line #18668
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOQUIN 250 (INVISION)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOQUIN 250 (INVISION)'
);

-- line #18669
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOVEX 500 (XCEL LABS)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOVEX 500 (XCEL LABS)'
);

-- line #18670
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXMED-250 250 (NUMED LAB.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXMED-250 250 (NUMED LAB.)'
);

-- line #18671
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXMED-500 500 (NUMED LAB.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXMED-500 500 (NUMED LAB.)'
);

-- line #18672
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FYFLOX 500 (Sanify)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FYFLOX 500 (Sanify)'
);

-- line #18673
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500', u'strength_2': u'', u'substance': u'Levofloxacin', u'always_empty': u'', u'form': u'', u'brand': u'FYNAL IV', u'strength_3': u'', u'company': u'Mankind', u'unit': u'mg'}

-- line #18674
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FYNAL 250 (Mankind)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FYNAL 250 (Mankind)'
);

-- line #18675
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FYNAL 500 (Mankind)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FYNAL 500 (Mankind)'
);

-- line #18676
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FYNAL 750 (Mankind)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FYNAL 750 (Mankind)'
);

-- line #18677
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G CLOX 500 (GRANDIX)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G CLOX 500 (GRANDIX)'
);

-- line #18678
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G CLOX 750 (Grandix)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G CLOX 750 (Grandix)'
);

-- line #18679
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500', u'strength_2': u'', u'substance': u'Levofloxacin', u'always_empty': u'', u'form': u'', u'brand': u'GEVOFLOX IV-BAG', u'strength_3': u'', u'company': u'NEISS', u'unit': u'mg'}

-- line #18680
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEVOFLOX 500 (NEISS)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEVOFLOX 500 (NEISS)'
);

-- line #18681
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLEVO 5 (Glenmark)',
	'Levofloxacin',
	'E/E DPS',
	gm.nullify_empty_string('5')::numeric,
	'mg(HYEMIHYDRT.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLEVO 5 (Glenmark)'
);

-- line #18682
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLEVO 500 (Glenmark)',
	'Levofloxacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg/100ML/150ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLEVO 500 (Glenmark)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLEVO 750 (Glenmark)',
	'Levofloxacin',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg/100ML/150ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLEVO 750 (Glenmark)'
);

-- line #18683
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLEVO 250 (Glenmark)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLEVO 250 (Glenmark)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLEVO 500 (Glenmark)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLEVO 500 (Glenmark)'
);

-- line #18684
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLEVO 750 (Glenmark)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLEVO 750 (Glenmark)'
);

-- line #18685
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HAWK 500 (STERLING)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HAWK 500 (STERLING)'
);

-- line #18686
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HINLEVO 500 (PERK PH.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HINLEVO 500 (PERK PH.)'
);

-- line #18687
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDIFAST 500 (Indilina Ph.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDIFAST 500 (Indilina Ph.)'
);

-- line #18688
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDLEVO 250 (Indchemie)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDLEVO 250 (Indchemie)'
);

-- line #18689
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDLEVO 500 (Indchemie)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDLEVO 500 (Indchemie)'
);

-- line #18690
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDLEVO 750 (Indchemie)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDLEVO 750 (Indchemie)'
);

-- line #18691
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISOFLOX 500 (UMBILICAL PH.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISOFLOX 500 (UMBILICAL PH.)'
);

-- line #18692
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JOYCIN 500 (Wisdom Ph.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JOYCIN 500 (Wisdom Ph.)'
);

-- line #18693
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250', u'strength_2': u'', u'substance': u'Levofloxacin', u'always_empty': u'', u'form': u'', u'brand': u'KINGLEVOX', u'strength_3': u'', u'company': u'SH PH.', u'unit': u'mg'}

-- line #18694
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500', u'strength_2': u'', u'substance': u'Levofloxacin', u'always_empty': u'', u'form': u'', u'brand': u'KINGLEVOX', u'strength_3': u'', u'company': u'SH PH.', u'unit': u'mg'}

-- line #18695
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'750', u'strength_2': u'', u'substance': u'Levofloxacin', u'always_empty': u'', u'form': u'', u'brand': u'KINGLEVOX', u'strength_3': u'', u'company': u'SH PH.', u'unit': u'mg'}

-- line #18696
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KLAVIN 125 (Kwik Hc.)',
	'Levofloxacin',
	'D.SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KLAVIN 125 (Kwik Hc.)'
);

-- line #18697
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KLAVIN 250 (Kwik Hc.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KLAVIN 250 (Kwik Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KLAVIN 500 (Kwik Hc.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KLAVIN 500 (Kwik Hc.)'
);

-- line #18698
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Levofloxacin', u'always_empty': u'', u'form': u'TAB', u'brand': u'KLEVO', u'strength_3': u'', u'company': u'KORES F.', u'unit': u''}

-- line #18699
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'L-250 250 (Svizera)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'L-250 250 (Svizera)'
);

-- line #18700
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'L-500 500 (Svizera)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'L-500 500 (Svizera)'
);

-- line #18701
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAVAZA 250 (ORION BIOTECH.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAVAZA 250 (ORION BIOTECH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAVAZA 500 (ORION BIOTECH.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAVAZA 500 (ORION BIOTECH.)'
);

-- line #18702
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAVOFLUS 500 (RADIUS HC.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAVOFLUS 500 (RADIUS HC.)'
);

-- line #18703
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAVOR 250 (Rhombus)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAVOR 250 (Rhombus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAVOR 500 (Rhombus)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAVOR 500 (Rhombus)'
);

-- line #18704
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAVOR 750 (Rhombus)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAVOR 750 (Rhombus)'
);

-- line #18705
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAXIFLOX 250 (Eminence)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAXIFLOX 250 (Eminence)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAXIFLOX 500 (Eminence)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAXIFLOX 500 (Eminence)'
);

-- line #18706
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500', u'strength_2': u'', u'substance': u'Levofloxacin', u'always_empty': u'', u'form': u'', u'brand': u'LAZANOL IV', u'strength_3': u'', u'company': u'Sandoz', u'unit': u'mg(+DEXTROSE)'}

-- line #18707
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAZANOL 250 (Sandoz)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAZANOL 250 (Sandoz)'
);

-- line #18708
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAZANOL 500 (Sandoz)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAZANOL 500 (Sandoz)'
);

-- line #18709
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAZANOL 750 (Sandoz)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAZANOL 750 (Sandoz)'
);

-- line #18710
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'L-BEST 500 (BCC HC.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'L-BEST 500 (BCC HC.)'
);

-- line #18711
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Levofloxacin', u'always_empty': u'', u'form': u'E/E DPS', u'brand': u'L-CIN', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #18712
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LCIN IV 500 (Lupin)',
	'Levofloxacin',
	'INF',
	gm.nullify_empty_string('500')::numeric,
	'mg(+ANHYD.DEXTROSE 5'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LCIN IV 500 (Lupin)'
);

-- line #18713
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'L-CIN 125 (Lupin)',
	'Levofloxacin',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'L-CIN 125 (Lupin)'
);

-- line #18714
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'L-CIN 250 (Lupin)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'L-CIN 250 (Lupin)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'L-CIN 500 (Lupin)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'L-CIN 500 (Lupin)'
);

-- line #18715
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'L-CIN 750 (Lupin)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'L-CIN 750 (Lupin)'
);

-- line #18716
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LCR 500 (Corona)',
	'Levofloxacin',
	'INF',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LCR 500 (Corona)'
);

-- line #18717
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LCR 250 (Corona)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LCR 250 (Corona)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LCR 500 (Corona)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LCR 500 (Corona)'
);

-- line #18718
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LCR 750 (Corona)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LCR 750 (Corona)'
);

-- line #18719
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEBACT-IV 500 (Piramal Hc.)',
	'Levofloxacin',
	'INF',
	gm.nullify_empty_string('500')::numeric,
	'mg/100ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEBACT-IV 500 (Piramal Hc.)'
);

-- line #18720
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEBACT 250 (NPIL HC.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEBACT 250 (NPIL HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEBACT 500 (NPIL HC.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEBACT 500 (NPIL HC.)'
);

-- line #18721
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEBACT 750 (NPIL HC.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEBACT 750 (NPIL HC.)'
);

-- line #18722
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LECIN 500 (Svizera)',
	'Levofloxacin',
	'INF',
	gm.nullify_empty_string('500')::numeric,
	'mg(+SOD. CHL. 900'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LECIN 500 (Svizera)'
);

-- line #18723
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LECIN 250 (Svizera)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LECIN 250 (Svizera)'
);

-- line #18724
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEDOR 500 (Candor Bio.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEDOR 500 (Candor Bio.)'
);

-- line #18725
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEDRIC 500 (CONDOR(EDRIC))',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEDRIC 500 (CONDOR(EDRIC))'
);

-- line #18726
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEEACT 500 (Health Care)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEEACT 500 (Health Care)'
);

-- line #18727
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEEFLOX 0.5 (Centaur)',
	'Levofloxacin',
	'EYE DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEEFLOX 0.5 (Centaur)'
);

-- line #18728
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEEFLOX 1.5 (Centaur)',
	'Levofloxacin',
	'EYE DPS',
	gm.nullify_empty_string('1.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEEFLOX 1.5 (Centaur)'
);

-- line #18729
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEEFLOX 250 (CENTAUR)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEEFLOX 250 (CENTAUR)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEEFLOX 500 (CENTAUR)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEEFLOX 500 (CENTAUR)'
);

-- line #18730
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEEFLOX 750 (CENTAUR)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEEFLOX 750 (CENTAUR)'
);

-- line #18731
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEEFLOX 250 (Cosmas Ph.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEEFLOX 250 (Cosmas Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEEFLOX 500 (Cosmas Ph.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEEFLOX 500 (Cosmas Ph.)'
);

-- line #18732
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Levofloxacin', u'always_empty': u'', u'form': u'', u'brand': u'LEE IV', u'strength_3': u'', u'company': u'Shreya', u'unit': u''}

-- line #18733
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEE 500 (Shreya)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEE 500 (Shreya)'
);

-- line #18734
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEE 750 (Shreya)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEE 750 (Shreya)'
);

-- line #18735
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250', u'strength_2': u'', u'substance': u'Levofloxacin', u'always_empty': u'', u'form': u'', u'brand': u'LEFFOR', u'strength_3': u'', u'company': u'FORAM BIO.', u'unit': u'mg'}

-- line #18736
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500', u'strength_2': u'', u'substance': u'Levofloxacin', u'always_empty': u'', u'form': u'', u'brand': u'LEFFOR', u'strength_3': u'', u'company': u'FORAM BIO.', u'unit': u'mg'}

-- line #18737
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEFLOX 500 (S.P.A.N.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEFLOX 500 (S.P.A.N.)'
);

-- line #18738
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEFLOZ 250 (SANCHEZ LAB.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEFLOZ 250 (SANCHEZ LAB.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEFLOZ 500 (SANCHEZ LAB.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEFLOZ 500 (SANCHEZ LAB.)'
);

-- line #18739
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEFOX 500 (DASTOOR PH.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEFOX 500 (DASTOOR PH.)'
);

-- line #18740
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEK 250 (Blue Cross)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEK 250 (Blue Cross)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEK 500 (Blue Cross)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEK 500 (Blue Cross)'
);

-- line #18741
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LELOXIN 500 (Depsons)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LELOXIN 500 (Depsons)'
);

-- line #18742
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEMED 250 (Aglowmed)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEMED 250 (Aglowmed)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEMED 500 (Aglowmed)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEMED 500 (Aglowmed)'
);

-- line #18743
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEOCIP 500 (VILBERRY HC.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEOCIP 500 (VILBERRY HC.)'
);

-- line #18744
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500', u'strength_2': u'', u'substance': u'Levofloxacin', u'always_empty': u'', u'form': u'', u'brand': u'LEON IV', u'strength_3': u'', u'company': u"Dr.Reddy''S", u'unit': u'mg/100ML (+5'}

-- line #18745
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEON 250 (Dr.Reddy''S)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEON 250 (Dr.Reddy''S)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEON 500 (Dr.Reddy''S)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEON 500 (Dr.Reddy''S)'
);

-- line #18746
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEON 750 (Dr.Reddy''S)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEON 750 (Dr.Reddy''S)'
);

-- line #18747
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEOZEN 500 (AXYZEN LIFE)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEOZEN 500 (AXYZEN LIFE)'
);

-- line #18748
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEPRO 750 (MEPRO PH.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEPRO 750 (MEPRO PH.)'
);

-- line #18749
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LERIN 250 (Water Lilly)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LERIN 250 (Water Lilly)'
);

-- line #18750
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LERIN 500 (Water Lilly)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LERIN 500 (Water Lilly)'
);

-- line #18751
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEROF 500 (ROSE LABS)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEROF 500 (ROSE LABS)'
);

-- line #18752
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LESAFLOX 500 (CANSAS LIFE)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LESAFLOX 500 (CANSAS LIFE)'
);

-- line #18753
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LESCAN 500 (CARE ON PH.)',
	'LEVOFloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LESCAN 500 (CARE ON PH.)'
);

-- line #18754
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVAB 500 (Aabtac Life)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVAB 500 (Aabtac Life)'
);

-- line #18755
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Levofloxacin', u'always_empty': u'', u'form': u'TAB', u'brand': u'LEVACE', u'strength_3': u'', u'company': u'Malody Hc.', u'unit': u''}

-- line #18756
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVAJ 500 (BAJAJ MEDI.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVAJ 500 (BAJAJ MEDI.)'
);

-- line #18757
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVANSH 500 (CIVANSH LIFESCI.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVANSH 500 (CIVANSH LIFESCI.)'
);

-- line #18758
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVATO-750 750 (STEIGEN PH.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVATO-750 750 (STEIGEN PH.)'
);

-- line #18759
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVATO 250 (STEIGEN PH.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVATO 250 (STEIGEN PH.)'
);

-- line #18760
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVATO 500 (STEIGEN PH.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVATO 500 (STEIGEN PH.)'
);

-- line #18761
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500', u'strength_2': u'', u'substance': u'Levofloxacin', u'always_empty': u'', u'form': u'', u'brand': u'LEVEN -', u'strength_3': u'', u'company': u'ENRICH PH.', u'unit': u'mg'}

-- line #18762
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVGEN 500 (BIOGEN PH.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVGEN 500 (BIOGEN PH.)'
);

-- line #18763
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEV-H 500 (HELIUM HC.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEV-H 500 (HELIUM HC.)'
);

-- line #18764
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVID 500 (CORE GESTRA)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVID 500 (CORE GESTRA)'
);

-- line #18765
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVIFLOX 750 (ERIS LIFE)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVIFLOX 750 (ERIS LIFE)'
);

-- line #18766
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVIKA 500 (STADCHEM)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVIKA 500 (STADCHEM)'
);

-- line #18767
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVLOC 500 (LE SANTE)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVLOC 500 (LE SANTE)'
);

-- line #18768
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVLOC 750 (LE SANTE)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVLOC 750 (LE SANTE)'
);

-- line #18769
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOACT 250 (Active Hc.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOACT 250 (Active Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOACT 500 (Active Hc.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOACT 500 (Active Hc.)'
);

-- line #18770
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOACT 750 (Active Hc.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOACT 750 (Active Hc.)'
);

-- line #18771
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOBACT 0.5 (Micro V.)',
	'Levofloxacin',
	'EYE DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOBACT 0.5 (Micro V.)'
);

-- line #18772
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOBACT 250 (ALKEM)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOBACT 250 (ALKEM)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOBACT 500 (ALKEM)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOBACT 500 (ALKEM)'
);

-- line #18773
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOBACT 750 (ALKEM)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOBACT 750 (ALKEM)'
);

-- line #18774
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOBENZ 500 (ADMAC (LEE BENZ))',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOBENZ 500 (ADMAC (LEE BENZ))'
);

-- line #18775
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOBOS 500 (ARUNABH)',
	'Levofloxacin',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg/1G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOBOS 500 (ARUNABH)'
);

-- line #18776
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOBOS 500 (ARUNABH)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOBOS 500 (ARUNABH)'
);

-- line #18777
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOBUS 500 (Globus)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOBUS 500 (Globus)'
);

-- line #18778
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOCAD 500 (Admac (CADMA))',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOCAD 500 (Admac (CADMA))'
);

-- line #18779
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOCAR 250 (CHEMO HC.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOCAR 250 (CHEMO HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOCAR 500 (CHEMO HC.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOCAR 500 (CHEMO HC.)'
);

-- line #18780
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOCAS 500 (CASCA)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOCAS 500 (CASCA)'
);

-- line #18781
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOCA 250 (Indica)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOCA 250 (Indica)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOCA 500 (Indica)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOCA 500 (Indica)'
);

-- line #18782
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Levofloxacin', u'always_empty': u'', u'form': u'TAB', u'brand': u'LEVOCA', u'strength_3': u'', u'company': u'NIVCA', u'unit': u''}

-- line #18783
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOCEF 500 (AXEN PH.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOCEF 500 (AXEN PH.)'
);

-- line #18784
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOCEF 250 (Shinto Org.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOCEF 250 (Shinto Org.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOCEF 500 (Shinto Org.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOCEF 500 (Shinto Org.)'
);

-- line #18785
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOCENT-500 500 (LA SERENA)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOCENT-500 500 (LA SERENA)'
);

-- line #18786
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOCENT 500 (ASCENT REM.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOCENT 500 (ASCENT REM.)'
);

-- line #18787
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOCIDE 500 (Cadila Ph.)',
	'Levofloxacin',
	'INF',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOCIDE 500 (Cadila Ph.)'
);

-- line #18788
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOCIDE 250 (Cadila Ph.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOCIDE 250 (Cadila Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOCIDE 500 (Cadila Ph.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOCIDE 500 (Cadila Ph.)'
);

-- line #18789
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOCIDE 750 (Cadila Ph.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOCIDE 750 (Cadila Ph.)'
);

-- line #18790
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500', u'strength_2': u'', u'substance': u'Levofloxacin', u'always_empty': u'', u'form': u'', u'brand': u'LEVOCIN', u'strength_3': u'', u'company': u'SWOT HC.', u'unit': u'mg'}

-- line #18791
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOCIN 250 (Biocin Hc.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOCIN 250 (Biocin Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOCIN 500 (Biocin Hc.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOCIN 500 (Biocin Hc.)'
);

-- line #18792
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOCIN 750 (Biocin Hc.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOCIN 750 (Biocin Hc.)'
);

-- line #18793
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOCLIN 500 (Auroma Life)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOCLIN 500 (Auroma Life)'
);

-- line #18794
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'750', u'strength_2': u'', u'substance': u'Levofloxacin', u'always_empty': u'', u'form': u'', u'brand': u'LEVOCON', u'strength_3': u'', u'company': u'Parenteral', u'unit': u'mg'}

-- line #18795
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOCRON 250 (Acron Ph.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOCRON 250 (Acron Ph.)'
);

-- line #18796
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOCRON 500 (Acron Ph.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOCRON 500 (Acron Ph.)'
);

-- line #18797
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVODAK 500 (ZODAK)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVODAK 500 (ZODAK)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVODAK 750 (ZODAK)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVODAK 750 (ZODAK)'
);

-- line #18798
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVODAY 500 (Zydus Cadila)',
	'Levofloxacin',
	'INF',
	gm.nullify_empty_string('500')::numeric,
	'mg/100ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVODAY 500 (Zydus Cadila)'
);

-- line #18799
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVODAY 250 (Zydus Cadila)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVODAY 250 (Zydus Cadila)'
);

-- line #18800
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVODAY 500 (Zydus Cadila)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVODAY 500 (Zydus Cadila)'
);

-- line #18801
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVODAY 750 (Zydus Cadila)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVODAY 750 (Zydus Cadila)'
);

-- line #18802
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVODEX 250 (DEXTUS LC.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVODEX 250 (DEXTUS LC.)'
);

-- line #18803
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVODEX 500 (DEXTUS LC.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVODEX 500 (DEXTUS LC.)'
);

-- line #18804
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVODIL 250 (Dial Ph.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVODIL 250 (Dial Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVODIL 500 (Dial Ph.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVODIL 500 (Dial Ph.)'
);

-- line #18805
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVODIS 500 (DISCOVERY PH.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVODIS 500 (DISCOVERY PH.)'
);

-- line #18806
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOD 500 (YASHTRA HEALTH)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOD 500 (YASHTRA HEALTH)'
);

-- line #18807
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOFAM 500 (SIFAM PH.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOFAM 500 (SIFAM PH.)'
);

-- line #18808
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOFF 500 (Biochem)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOFF 500 (Biochem)'
);

-- line #18809
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOFF 750 (BIOCHEM)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOFF 750 (BIOCHEM)'
);

-- line #18810
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500', u'strength_2': u'', u'substance': u'Levofloxacin', u'always_empty': u'', u'form': u'', u'brand': u'LEVOFIX', u'strength_3': u'', u'company': u'NAMAS', u'unit': u'mg'}

-- line #18811
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOFLOX 5 (Protec)',
	'Levofloxacin',
	'INF',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOFLOX 5 (Protec)'
);

-- line #18812
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOFLOX 250 (Protec)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOFLOX 250 (Protec)'
);

-- line #18813
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOFLOX 500 (Protec)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOFLOX 500 (Protec)'
);

-- line #18814
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOFLOX 750 (Protec)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOFLOX 750 (Protec)'
);

-- line #18815
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOFLOZ 500 (DYNAMIC LC.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOFLOZ 500 (DYNAMIC LC.)'
);

-- line #18816
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOF-ONE 500 (ONE LIFECARE)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOF-ONE 500 (ONE LIFECARE)'
);

-- line #18817
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOFOX 250 (DR. ALSON)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOFOX 250 (DR. ALSON)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOFOX 500 (DR. ALSON)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOFOX 500 (DR. ALSON)'
);

-- line #18818
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVO-FQ 500 (Venus Rem.)',
	'Levofloxacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg/100ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVO-FQ 500 (Venus Rem.)'
);

-- line #18819
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOFRESH 250 (SMART LAB.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOFRESH 250 (SMART LAB.)'
);

-- line #18820
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOFRESH 500 (SMART LAB.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOFRESH 500 (SMART LAB.)'
);

-- line #18821
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOF 500 (HBC LIFESCIENCE)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOF 500 (HBC LIFESCIENCE)'
);

-- line #18822
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOF 250 (Orison Ph.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOF 250 (Orison Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOF 500 (Orison Ph.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOF 500 (Orison Ph.)'
);

-- line #18823
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVO-GIS 500 (AGISTA PH.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVO-GIS 500 (AGISTA PH.)'
);

-- line #18824
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOGRACE 500 (VIDACARE PH.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOGRACE 500 (VIDACARE PH.)'
);

-- line #18825
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOGRAM 500 (UNITED LIFE)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOGRAM 500 (UNITED LIFE)'
);

-- line #18826
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOGRAM 500 (Votary Lab)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOGRAM 500 (Votary Lab)'
);

-- line #18827
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOGRA 250 (Graf Lab.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOGRA 250 (Graf Lab.)'
);

-- line #18828
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOGRA 500 (Graf Lab.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOGRA 500 (Graf Lab.)'
);

-- line #18829
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOKAB 500 (Lancer)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOKAB 500 (Lancer)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOKAB 750 (Lancer)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOKAB 750 (Lancer)'
);

-- line #18830
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOKAM 500 (KAMSONS PH.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOKAM 500 (KAMSONS PH.)'
);

-- line #18831
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOLARGE 250 (Votary Lab)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOLARGE 250 (Votary Lab)'
);

-- line #18832
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOLARGE 500 (Votary Lab)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOLARGE 500 (Votary Lab)'
);

-- line #18833
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOLA 250 (Intra Lab)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOLA 250 (Intra Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOLA 500 (Intra Lab)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOLA 500 (Intra Lab)'
);

-- line #18834
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOLA 750 (Intra Lab)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOLA 750 (Intra Lab)'
);

-- line #18835
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOLET 500 (Ikon Rem)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOLET 500 (Ikon Rem)'
);

-- line #18836
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOLIFE 500 (Life Line)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOLIFE 500 (Life Line)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOLIFE 750 (Life Line)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOLIFE 750 (Life Line)'
);

-- line #18837
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOLONG 500 (Mdc Ph.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOLONG 500 (Mdc Ph.)'
);

-- line #18838
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOLT 500 (BENGINN HC.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOLT 500 (BENGINN HC.)'
);

-- line #18839
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOMAC ORAL 125 (Macleods)',
	'Levofloxacin',
	'SOL',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOMAC ORAL 125 (Macleods)'
);

-- line #18840
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOMAG 500 (Magnus Bio.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOMAG 500 (Magnus Bio.)'
);

-- line #18841
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOMAN 250 (Maneesh)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOMAN 250 (Maneesh)'
);

-- line #18842
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOMAN 500 (Maneesh)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOMAN 500 (Maneesh)'
);

-- line #18843
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVO MDR 750 (Panacea)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVO MDR 750 (Panacea)'
);

-- line #18844
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOMITH 250 (Biosmith)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOMITH 250 (Biosmith)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOMITH 500 (Biosmith)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOMITH 500 (Biosmith)'
);

-- line #18845
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOMNI 250 (Cipla)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOMNI 250 (Cipla)'
);

-- line #18846
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOMNI 500 (Cipla)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOMNI 500 (Cipla)'
);

-- line #18847
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOMNI 750 (Cipla)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOMNI 750 (Cipla)'
);

-- line #18848
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVONA 500 (Cataliq Lab.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVONA 500 (Cataliq Lab.)'
);

-- line #18849
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVONEW 250 (Dr.Arvind Shah''S)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVONEW 250 (Dr.Arvind Shah''S)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVONEW 500 (Dr.Arvind Shah''S)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVONEW 500 (Dr.Arvind Shah''S)'
);

-- line #18850
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVONEX 250 (Nexus)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVONEX 250 (Nexus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVONEX 500 (Nexus)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVONEX 500 (Nexus)'
);

-- line #18851
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVONEZ 500 (Wintech)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVONEZ 500 (Wintech)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVONEZ 750 (Wintech)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVONEZ 750 (Wintech)'
);

-- line #18852
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVONIX 500 (PHENIX PH.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVONIX 500 (PHENIX PH.)'
);

-- line #18853
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVONIZ-250 250 (Sunij)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg(HEMIGYDRATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVONIZ-250 250 (Sunij)'
);

-- line #18854
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVONIZ-500 500 (Sunij)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg(HEMIGYDRATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVONIZ-500 500 (Sunij)'
);

-- line #18855
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVONOS-500 500 (BIO-SWITZ)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVONOS-500 500 (BIO-SWITZ)'
);

-- line #18856
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVONO 500 (LUCIFER & H.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVONO 500 (LUCIFER & H.)'
);

-- line #18857
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVON 250 (Azime Hc.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVON 250 (Azime Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVON 500 (Azime Hc.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVON 500 (Azime Hc.)'
);

-- line #18858
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOPAN 250 (PANTHER PH.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOPAN 250 (PANTHER PH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOPAN 500 (PANTHER PH.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOPAN 500 (PANTHER PH.)'
);

-- line #18859
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOPEN 500 (Morepen)',
	'Levofloxacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOPEN 500 (Morepen)'
);

-- line #18860
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOPEN 250 (Morepen)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOPEN 250 (Morepen)'
);

-- line #18861
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOPEN 500 (Morepen)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOPEN 500 (Morepen)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOPEN 750 (Morepen)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOPEN 750 (Morepen)'
);

-- line #18862
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOPIC-IV 500 (Alpic Rem.)',
	'Levofloxacin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOPIC-IV 500 (Alpic Rem.)'
);

-- line #18863
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOPIC 250 (Alpic Rem.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOPIC 250 (Alpic Rem.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOPIC 500 (Alpic Rem.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOPIC 500 (Alpic Rem.)'
);

-- line #18864
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOPIC 750 (Alpic Rem.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOPIC 750 (Alpic Rem.)'
);

-- line #18865
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Levofloxacin', u'always_empty': u'', u'form': u'', u'brand': u'LEVOPURE IV', u'strength_3': u'', u'company': u'STERLING PH.', u'unit': u''}

-- line #18866
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500', u'strength_2': u'', u'substance': u'Levofloxacin', u'always_empty': u'', u'form': u'', u'brand': u'LEVOPURE', u'strength_3': u'', u'company': u'STERLING', u'unit': u'mg'}

-- line #18867
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'750', u'strength_2': u'', u'substance': u'Levofloxacin', u'always_empty': u'', u'form': u'', u'brand': u'LEVOPURE', u'strength_3': u'', u'company': u'STERLING', u'unit': u'mg'}

-- line #18868
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOQUE 500 (Baroque)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOQUE 500 (Baroque)'
);

-- line #18869
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOQUIN 250 (Cipla)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOQUIN 250 (Cipla)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOQUIN 500 (Cipla)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOQUIN 500 (Cipla)'
);

-- line #18870
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVORA 0.5 (Intra Lab)',
	'Levofloxacin',
	'E/E DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVORA 0.5 (Intra Lab)'
);

-- line #18871
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVORBID 500 (HAMPS BIO)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVORBID 500 (HAMPS BIO)'
);

-- line #18872
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOREK 500 (SUBHREK PH.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOREK 500 (SUBHREK PH.)'
);

-- line #18873
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVORICH 500 (Goodrich)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVORICH 500 (Goodrich)'
);

-- line #18874
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500', u'strength_2': u'', u'substance': u'Levofloxacin', u'always_empty': u'', u'form': u'', u'brand': u'LEVORIN', u'strength_3': u'', u'company': u'ORIAN PH.', u'unit': u'mg'}

-- line #18875
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVORT 500 (COXSWAIN HC.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVORT 500 (COXSWAIN HC.)'
);

-- line #18876
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOSAFE 500 (SAFE PH.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOSAFE 500 (SAFE PH.)'
);

-- line #18877
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOSIP 500 (Sipra Rem.)',
	'Levofloxacin',
	'INF',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOSIP 500 (Sipra Rem.)'
);

-- line #18878
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOSIP 500 (Sipra Rem.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOSIP 500 (Sipra Rem.)'
);

-- line #18879
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOSONE 250 (Southsourne)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOSONE 250 (Southsourne)'
);

-- line #18880
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOSONE 500 (Southsourne)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOSONE 500 (Southsourne)'
);

-- line #18881
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOSON 250 (Patson)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOSON 250 (Patson)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOSON 500 (Patson)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOSON 500 (Patson)'
);

-- line #18882
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOSON 750 (Patson)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOSON 750 (Patson)'
);

-- line #18883
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOSPAN 250 (PHARMATECH)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOSPAN 250 (PHARMATECH)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOSPAN 500 (PHARMATECH)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOSPAN 500 (PHARMATECH)'
);

-- line #18884
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOSPIN 500 (Cerspin)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOSPIN 500 (Cerspin)'
);

-- line #18885
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOSTAL 250 (Stallion)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOSTAL 250 (Stallion)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOSTAL 500 (Stallion)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOSTAL 500 (Stallion)'
);

-- line #18886
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOSTAR 250 (CIPLA)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOSTAR 250 (CIPLA)'
);

-- line #18887
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOSTAR 500 (CIPLA)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOSTAR 500 (CIPLA)'
);

-- line #18888
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOSTA 250 (STAUNCH)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOSTA 250 (STAUNCH)'
);

-- line #18889
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOSTA 500 (STAUNCH)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOSTA 500 (STAUNCH)'
);

-- line #18890
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOSTA 750 (STAUNCH)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOSTA 750 (STAUNCH)'
);

-- line #18891
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOSURE 250 (LIFESTAR)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOSURE 250 (LIFESTAR)'
);

-- line #18892
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOSURE 500 (LIFESTAR)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOSURE 500 (LIFESTAR)'
);

-- line #18893
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOTAG 250 (SMENTAG PH.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOTAG 250 (SMENTAG PH.)'
);

-- line #18894
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOTAG 500 (SMENTAG PH.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOTAG 500 (SMENTAG PH.)'
);

-- line #18895
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOTA 250 (LUSTRE)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOTA 250 (LUSTRE)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOTA 500 (LUSTRE)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOTA 500 (LUSTRE)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOTA 750 (LUSTRE)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOTA 750 (LUSTRE)'
);

-- line #18896
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOTEC 250 (United Bio.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOTEC 250 (United Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOTEC 500 (United Bio.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOTEC 500 (United Bio.)'
);

-- line #18897
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOTEC 500 (UNITED BIO.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOTEC 500 (UNITED BIO.)'
);

-- line #18898
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOTOX 250 (Semsun Ph.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOTOX 250 (Semsun Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOTOX 500 (Semsun Ph.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOTOX 500 (Semsun Ph.)'
);

-- line #18899
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOTOZ 500 (Atoz Ph.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOTOZ 500 (Atoz Ph.)'
);

-- line #18900
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOTRIX 500 (AXIS LIFE)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOTRIX 500 (AXIS LIFE)'
);

-- line #18901
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOVID 500 (BHUVID RES.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOVID 500 (BHUVID RES.)'
);

-- line #18902
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOWAL 500 (Radicura)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOWAL 500 (Radicura)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOWAL 750 (Radicura)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOWAL 750 (Radicura)'
);

-- line #18903
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Levofloxacin', u'always_empty': u'', u'form': u'INF', u'brand': u'LEVOX', u'strength_3': u'', u'company': u'Claris L.', u'unit': u''}

-- line #18904
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOXN 250 (Parasol)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOXN 250 (Parasol)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOXN 500 (Parasol)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOXN 500 (Parasol)'
);

-- line #18905
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOX 500 (AASTHA PH.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOX 500 (AASTHA PH.)'
);

-- line #18906
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOXY 250 (Vega Lab)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOXY 250 (Vega Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOXY 500 (Vega Lab)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOXY 500 (Vega Lab)'
);

-- line #18907
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOZEAL 500 (ZEALOT BIOTECH)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOZEAL 500 (ZEALOT BIOTECH)'
);

-- line #18908
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVO 500 (ZOREX REM.)',
	'Levofloxacin',
	'ZR TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVO 500 (ZOREX REM.)'
);

-- line #18909
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVUM 250 (J.B. CHEM)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVUM 250 (J.B. CHEM)'
);

-- line #18910
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVUM 500 (J.B. CHEM)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVUM 500 (J.B. CHEM)'
);

-- line #18911
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEV-X 250 (Neuron Ph.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEV-X 250 (Neuron Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEV-X 500 (Neuron Ph.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEV-X 500 (Neuron Ph.)'
);

-- line #18912
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEXIFLOX 250 (ERIS LIFE)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEXIFLOX 250 (ERIS LIFE)'
);

-- line #18913
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEXIFLOX 500 (ERIS LIFE)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEXIFLOX 500 (ERIS LIFE)'
);

-- line #18914
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEZEN 250 (Sain Med.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEZEN 250 (Sain Med.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEZEN 500 (Sain Med.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEZEN 500 (Sain Med.)'
);

-- line #18915
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEZEN 500 (Vantage)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg(HEMIHYDRT.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEZEN 500 (Vantage)'
);

-- line #18916
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'L-FLOCIN 500 (NAVNIDHI LIFE)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'L-FLOCIN 500 (NAVNIDHI LIFE)'
);

-- line #18917
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250', u'strength_2': u'', u'substance': u'Levofloxacin', u'always_empty': u'', u'form': u'', u'brand': u'LFLOX-250', u'strength_3': u'', u'company': u'SPECTRUM HC.', u'unit': u'mg'}

-- line #18918
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500', u'strength_2': u'', u'substance': u'Levofloxacin', u'always_empty': u'', u'form': u'', u'brand': u'LFLOX-500', u'strength_3': u'', u'company': u'SPECTRUM HC.', u'unit': u'mg'}

-- line #18919
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'L-FLOXAN 250 (Pulse Ph.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'L-FLOXAN 250 (Pulse Ph.)'
);

-- line #18920
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'L-FLOXAN 500 (Pulse Ph.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'L-FLOXAN 500 (Pulse Ph.)'
);

-- line #18921
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'L-FLOXO 250 (Uniroyal)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'L-FLOXO 250 (Uniroyal)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'L-FLOXO 500 (Uniroyal)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'L-FLOXO 500 (Uniroyal)'
);

-- line #18922
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'L-FLOX 500 (Antigen Hc.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'L-FLOX 500 (Antigen Hc.)'
);

-- line #18923
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LF 250 (Finecure)',
	'LEVOFLOXACIN',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LF 250 (Finecure)'
);

-- line #18924
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LF 500 (Finecure)',
	'LEVOFLOXACIN',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LF 500 (Finecure)'
);

-- line #18925
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LFX 500 (Skymax)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LFX 500 (Skymax)'
);

-- line #18926
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500', u'strength_2': u'', u'substance': u'Levofloxacin', u'always_empty': u'', u'form': u'', u'brand': u'LIFELON', u'strength_3': u'', u'company': u'WARSILA BIO.', u'unit': u'mg'}

-- line #18927
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIFLO-IV 500 (Zenon Hc.)',
	'Levofloxacin',
	'INFUSION',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIFLO-IV 500 (Zenon Hc.)'
);

-- line #18928
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIFLO 500 (Zenon Hc.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIFLO 500 (Zenon Hc.)'
);

-- line #18929
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIFT-250 250 (AARON HC.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIFT-250 250 (AARON HC.)'
);

-- line #18930
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIFT-500 500 (AARON HC.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIFT-500 500 (AARON HC.)'
);

-- line #18931
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIKE 250 (GALLICA PH.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIKE 250 (GALLICA PH.)'
);

-- line #18932
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIKE 500 (GALLICA PH.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIKE 500 (GALLICA PH.)'
);

-- line #18933
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIN-500 500 (Admac Ph.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIN-500 500 (Admac Ph.)'
);

-- line #18934
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINA 500 (Sayona)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINA 500 (Sayona)'
);

-- line #18935
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPOXIL 500 (Khandelwal)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPOXIL 500 (Khandelwal)'
);

-- line #18936
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500', u'strength_2': u'', u'substance': u'Levofloxacin', u'always_empty': u'', u'form': u'', u'brand': u'LIVBEST', u'strength_3': u'', u'company': u'Nicholas', u'unit': u'mg'}

-- line #18937
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIVBEST 250 (Abbott)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIVBEST 250 (Abbott)'
);

-- line #18938
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIVETEX 500 (Aquila)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIVETEX 500 (Aquila)'
);

-- line #18939
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIVMAX 250 (WELLMAX)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIVMAX 250 (WELLMAX)'
);

-- line #18940
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIVMAX 500 (WELLMAX)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIVMAX 500 (WELLMAX)'
);

-- line #18941
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIVOCIN 500 (NITIN)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIVOCIN 500 (NITIN)'
);

-- line #18942
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIVOK 250 (HALO MEDI.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIVOK 250 (HALO MEDI.)'
);

-- line #18943
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIVOK 500 (HALO MEDI.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIVOK 500 (HALO MEDI.)'
);

-- line #18944
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIVOLISK 500 (OBELISK PH.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIVOLISK 500 (OBELISK PH.)'
);

-- line #18945
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIVOMAX 250 (Biomax Bio.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIVOMAX 250 (Biomax Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIVOMAX 500 (Biomax Bio.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIVOMAX 500 (Biomax Bio.)'
);

-- line #18946
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIVOMAX 750 (Biomax Bio.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIVOMAX 750 (Biomax Bio.)'
);

-- line #18947
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIVOQUIN 500 (BLUE WINGS)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIVOQUIN 500 (BLUE WINGS)'
);

-- line #18948
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIVOQUIN 500 (Exotic Lab.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIVOQUIN 500 (Exotic Lab.)'
);

-- line #18949
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIVORAN 250 (RADHE BIO.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIVORAN 250 (RADHE BIO.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIVORAN 500 (RADHE BIO.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIVORAN 500 (RADHE BIO.)'
);

-- line #18950
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIVORIC 250 (SYNTRO HC.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIVORIC 250 (SYNTRO HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIVORIC 500 (SYNTRO HC.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIVORIC 500 (SYNTRO HC.)'
);

-- line #18951
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIVORIN 250 (DOLPHIN PH.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIVORIN 250 (DOLPHIN PH.)'
);

-- line #18952
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIVORIN 500 (DOLPHIN PH.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIVORIN 500 (DOLPHIN PH.)'
);

-- line #18953
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIVOROL 500 (Royal)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIVOROL 500 (Royal)'
);

-- line #18954
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIVOSPAN 250 (PHARMATECH)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIVOSPAN 250 (PHARMATECH)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIVOSPAN 500 (PHARMATECH)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIVOSPAN 500 (PHARMATECH)'
);

-- line #18955
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIVOSTREAM 250 (MEDISTREAM)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIVOSTREAM 250 (MEDISTREAM)'
);

-- line #18956
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIVOSTREAM 500 (MEDISTREAM)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIVOSTREAM 500 (MEDISTREAM)'
);

-- line #18957
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIVOTA 500 (Zota Ph.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIVOTA 500 (Zota Ph.)'
);

-- line #18958
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIVOTIL 500 (Phytochem)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIVOTIL 500 (Phytochem)'
);

-- line #18959
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIVOTIN 500 (RIYA REM.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIVOTIN 500 (RIYA REM.)'
);

-- line #18960
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIVOVAR 500 (Zota Hc.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIVOVAR 500 (Zota Hc.)'
);

-- line #18961
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIVOVEN 250 (VENSAT)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIVOVEN 250 (VENSAT)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIVOVEN 500 (VENSAT)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIVOVEN 500 (VENSAT)'
);

-- line #18962
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIVOVEN 750 (VENSAT)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIVOVEN 750 (VENSAT)'
);

-- line #18963
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIVOX 500 (Zee Lab)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIVOX 500 (Zee Lab)'
);

-- line #18964
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIVPREN 250 (Esken)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIVPREN 250 (Esken)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIVPREN 500 (Esken)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIVPREN 500 (Esken)'
);

-- line #18965
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIXONE 500 (Tripada BIO.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIXONE 500 (Tripada BIO.)'
);

-- line #18966
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500', u'strength_2': u'', u'substance': u'Levofloxacin', u'always_empty': u'', u'form': u'', u'brand': u'L-KING', u'strength_3': u'', u'company': u'APTUS PH.', u'unit': u'mg'}

-- line #18967
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOFCIN 500 (MEDHEAL PH.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOFCIN 500 (MEDHEAL PH.)'
);

-- line #18968
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOFLOX 500 (Sierra)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOFLOX 500 (Sierra)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOFLOX 750 (Sierra)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOFLOX 750 (Sierra)'
);

-- line #18969
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LONARD 250 (Swiss Ph.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LONARD 250 (Swiss Ph.)'
);

-- line #18970
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LONARD 500 (Swiss Ph.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LONARD 500 (Swiss Ph.)'
);

-- line #18971
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOTOR 250 (Emcure)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOTOR 250 (Emcure)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOTOR 500 (Emcure)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOTOR 500 (Emcure)'
);

-- line #18972
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOTOR 750 (Emcure)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOTOR 750 (Emcure)'
);

-- line #18973
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOVOX-250 250 (AERO-CHEM)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOVOX-250 250 (AERO-CHEM)'
);

-- line #18974
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOVOX-500 500 (AERO-CHEM)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOVOX-500 500 (AERO-CHEM)'
);

-- line #18975
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250', u'strength_2': u'', u'substance': u'Levofloxacin', u'always_empty': u'', u'form': u'', u'brand': u'LOXLIFE -', u'strength_3': u'', u'company': u'GEMLIFE PH.', u'unit': u'mg'}

-- line #18976
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500', u'strength_2': u'', u'substance': u'Levofloxacin', u'always_empty': u'', u'form': u'', u'brand': u'LOXLIFE -', u'strength_3': u'', u'company': u'GEMLIFE PH.', u'unit': u'mg'}

-- line #18977
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOXOF 500 (Rexcel)',
	'Levofloxacin',
	'INF',
	gm.nullify_empty_string('500')::numeric,
	'mg/100ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOXOF 500 (Rexcel)'
);

-- line #18978
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOX OF ORAL 125 (Ranbaxy)',
	'Levofloxacin',
	'SOL',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOX OF ORAL 125 (Ranbaxy)'
);

-- line #18979
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOXOF 250 (Rexcel)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOXOF 250 (Rexcel)'
);

-- line #18980
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOXOF 500 (Rexcel)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOXOF 500 (Rexcel)'
);

-- line #18981
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOXOF 750 (Rexcel)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOXOF 750 (Rexcel)'
);

-- line #18982
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'L-OXO 250 (Ind-Swift)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'500'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'L-OXO 250 (Ind-Swift)'
);

-- line #18983
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LQUIN 250 (CIPLA)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LQUIN 250 (CIPLA)'
);

-- line #18984
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LQUIN 500 (CIPLA)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LQUIN 500 (CIPLA)'
);

-- line #18985
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LQUIN 750 (CIPLA)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LQUIN 750 (CIPLA)'
);

-- line #18986
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'L-SIG 500 (SIGNOVA)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'L-SIG 500 (SIGNOVA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'L-SIG 750 (SIGNOVA)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'L-SIG 750 (SIGNOVA)'
);

-- line #18987
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LTHROCIN 250 (AUM PH.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LTHROCIN 250 (AUM PH.)'
);

-- line #18988
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LTHROCIN 500 (AUM PH.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LTHROCIN 500 (AUM PH.)'
);

-- line #18989
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUFI 500 (Intas)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUFI 500 (Intas)'
);

-- line #18990
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUFI 500 (Ipca)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUFI 500 (Ipca)'
);

-- line #18991
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LV FLOX 5 (Entod Ph.)',
	'Levofloxacin',
	'EYE DPS',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LV FLOX 5 (Entod Ph.)'
);

-- line #18992
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LVOX 500 (DAVIDSON BROCKS)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LVOX 500 (DAVIDSON BROCKS)'
);

-- line #18993
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LXL-500 500 (Kamron)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LXL-500 500 (Kamron)'
);

-- line #18994
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILIVO 250 (GLENMARK(MILIEUS))',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILIVO 250 (GLENMARK(MILIEUS))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILIVO 500 (GLENMARK(MILIEUS))',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILIVO 500 (GLENMARK(MILIEUS))'
);

-- line #18995
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILIVO 750 (GLENMARK(MILIEUS))',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILIVO 750 (GLENMARK(MILIEUS))'
);

-- line #18996
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOD''S LEVO 500 (MODHIKE)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOD''S LEVO 500 (MODHIKE)'
);

-- line #18997
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOFLOX 250 (Centaur)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOFLOX 250 (Centaur)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOFLOX 500 (Centaur)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOFLOX 500 (Centaur)'
);

-- line #18998
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOFLOX 750 (Centaur)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOFLOX 750 (Centaur)'
);

-- line #18999
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MULTIVOX 250 (PSYCOREM)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MULTIVOX 250 (PSYCOREM)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MULTIVOX 500 (PSYCOREM)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MULTIVOX 500 (PSYCOREM)'
);

-- line #19000
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVAFLOX 50 (Novagen Ph.)',
	'Levofloxacin',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/100ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVAFLOX 50 (Novagen Ph.)'
);

-- line #19001
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVAFLOX 500 (Novagen Ph.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVAFLOX 500 (Novagen Ph.)'
);

-- line #19002
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORTID 250 (Ornate Ph.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORTID 250 (Ornate Ph.)'
);

-- line #19003
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORTID 500 (Ornate Ph.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORTID 500 (Ornate Ph.)'
);

-- line #19004
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSIBACT 250 (OSPER)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSIBACT 250 (OSPER)'
);

-- line #19005
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OTOLIV 500 (Radix Bio.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OTOLIV 500 (Radix Bio.)'
);

-- line #19006
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OTOTOP 5 (Ajanta Ph.)',
	'Levofloxacin',
	'DPS',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OTOTOP 5 (Ajanta Ph.)'
);

-- line #19007
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OVEL 500 (LEOLIFE)',
	'Levofloxacin',
	'INF',
	gm.nullify_empty_string('500')::numeric,
	'mg (900'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OVEL 500 (LEOLIFE)'
);

-- line #19008
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXILA 500 (Tnt Life)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXILA 500 (Tnt Life)'
);

-- line #19009
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QNOLIV 500 (ASTRA PH.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QNOLIV 500 (ASTRA PH.)'
);

-- line #19010
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINOCIN 500 (Synapse)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINOCIN 500 (Synapse)'
);

-- line #19011
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINOFLOX 250 (RIVAN PH.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINOFLOX 250 (RIVAN PH.)'
);

-- line #19012
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINOFLOX 500 (RIVAN PH.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINOFLOX 500 (RIVAN PH.)'
);

-- line #19013
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QULEF 250 (HETERO HC.)',
	'Levofloxacin',
	'OZ TAB',
	gm.nullify_empty_string('250')::numeric,
	'500'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QULEF 250 (HETERO HC.)'
);

-- line #19014
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QULEF 250 (HETERO HC.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QULEF 250 (HETERO HC.)'
);

-- line #19015
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QULEF 500 (HETERO HC.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QULEF 500 (HETERO HC.)'
);

-- line #19016
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QULEF 750 (HETERO HC.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QULEF 750 (HETERO HC.)'
);

-- line #19017
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500', u'strength_2': u'', u'substance': u'Levofloxacin', u'always_empty': u'', u'form': u'', u'brand': u'QURE IV', u'strength_3': u'', u'company': u'Aristo', u'unit': u'mg(5'}

-- line #19018
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QURE 250 (Aristo)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QURE 250 (Aristo)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QURE 500 (Aristo)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QURE 500 (Aristo)'
);

-- line #19019
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REALY 250 (Ritz Ph.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REALY 250 (Ritz Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REALY 500 (Ritz Ph.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REALY 500 (Ritz Ph.)'
);

-- line #19020
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REVONA 500 (Runa Ph.)',
	'Levofloxacin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REVONA 500 (Runa Ph.)'
);

-- line #19021
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'72-HOUR 0.75 (Vhb)',
	'Levonorgestrel',
	'TAB',
	gm.nullify_empty_string('0.75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '72-HOUR 0.75 (Vhb)'
);

-- line #19022
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ECEE 0.75 (German R.)',
	'Levonorgestrel',
	'TAB',
	gm.nullify_empty_string('0.75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ECEE 0.75 (German R.)'
);

-- line #19023
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G-PILL 0.75 (TAJ PH.)',
	'Levonorgestrel',
	'TAB',
	gm.nullify_empty_string('0.75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G-PILL 0.75 (TAJ PH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G-PILL 1.5 (TAJ PH.)',
	'Levonorgestrel',
	'TAB',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G-PILL 1.5 (TAJ PH.)'
);

-- line #19024
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Levonorgestrel intrauterine SYSTEM', u'always_empty': u'', u'form': u'', u'brand': u'MIRENA (IUS)', u'strength_3': u'', u'company': u'German R.', u'unit': u''}

-- line #19025
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IPILL 1.5 (Cipla)',
	'Levonorgestrel',
	'TAB',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IPILL 1.5 (Cipla)'
);

-- line #19026
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'I-PILL 1.5 (Piramal Hc.)',
	'Levonorgestrel',
	'TAB',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'I-PILL 1.5 (Piramal Hc.)'
);

-- line #19027
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LENOR 0.75 (Unicure)',
	'Levonorgestrel',
	'TAB',
	gm.nullify_empty_string('0.75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LENOR 0.75 (Unicure)'
);

-- line #19028
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1,5', u'strength_2': u'', u'substance': u'Levonorgestrel', u'always_empty': u'', u'form': u'', u'brand': u'MY PAL', u'strength_3': u'', u'company': u'Pfizer', u'unit': u'mg'}

-- line #19029
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'750MCG', u'strength_2': u'', u'substance': u'Levonorgestrel', u'always_empty': u'', u'form': u'TAB', u'brand': u'NORLEVO', u'strength_3': u'', u'company': u'Concept', u'unit': u''}

-- line #19030
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OH!GOD 1.5 (NEISS)',
	'Levonorgestrel',
	'TAB',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OH!GOD 1.5 (NEISS)'
);

-- line #19031
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PILL 0.75 (Cipla)',
	'Levonorgestrel',
	'TAB',
	gm.nullify_empty_string('0.75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PILL 0.75 (Cipla)'
);

-- line #19032
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100MCG', u'strength_2': u'', u'substance': u'Levosalbutamol', u'always_empty': u'', u'form': u'CAP', u'brand': u'AEROGEST', u'strength_3': u'', u'company': u'Macleods', u'unit': u''}

-- line #19033
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50MCG', u'strength_2': u'', u'substance': u'Levosalbutamol', u'always_empty': u'', u'form': u'', u'brand': u'AEROGEST INH', u'strength_3': u'', u'company': u'Macleods', u'unit': u'(SUSPENDED IN INERT SOLVENT AND AEROSOL PROPELLANT QS ETHANOL IP 8.33'}

-- line #19034
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AEROZEST 0.31 (Macleods)',
	'Levosalbutamol',
	'RES',
	gm.nullify_empty_string('0.31')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AEROZEST 0.31 (Macleods)'
);

-- line #19035
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AEROZEST 0.63 (Macleods)',
	'Levosalbutamol',
	'RES',
	gm.nullify_empty_string('0.63')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AEROZEST 0.63 (Macleods)'
);

-- line #19036
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AEROZEST 1.25 (Macleods)',
	'Levosalbutamol',
	'RES',
	gm.nullify_empty_string('1.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AEROZEST 1.25 (Macleods)'
);

-- line #19037
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50MCG(PROELLANI HFA 134A', u'strength_2': u'', u'substance': u'Levosalbutamol', u'always_empty': u'', u'form': u'', u'brand': u'LEVOIN AUTOHALER', u'strength_3': u'', u'company': u'Cipla', u'unit': u'ABSOLUTE ALCOHOL CONTENT 21.49'}

-- line #19038
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50MCG', u'strength_2': u'PUFF', u'substance': u'Levosalbutamol', u'always_empty': u'', u'form': u'INHALER', u'brand': u'LEVOLIN', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #19039
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOLIN 0.63 (Cipla)',
	'Levosalbutamol',
	'RES',
	gm.nullify_empty_string('0.63')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOLIN 0.63 (Cipla)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOLIN 1.25 (Cipla)',
	'Levosalbutamol',
	'RES',
	gm.nullify_empty_string('1.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOLIN 1.25 (Cipla)'
);

-- line #19040
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100MCG', u'strength_2': u'', u'substance': u'Levosalbutamol', u'always_empty': u'', u'form': u'', u'brand': u'LEVOLIN ROTACAP', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #19041
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOLIN 1 (Cipla)',
	'Levosalbutamol',
	'SYR',
	gm.nullify_empty_string('1')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOLIN 1 (Cipla)'
);

-- line #19042
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOLIN 1 (Cipla)',
	'Levosalbutamol',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOLIN 1 (Cipla)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOLIN 2 (Cipla)',
	'Levosalbutamol',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOLIN 2 (Cipla)'
);

-- line #19043
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMLEVO 100 (Emcure)',
	'LEVOSULPRIDE',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMLEVO 100 (Emcure)'
);

-- line #19044
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMLEVO 25 (Emcure)',
	'LEVOSULPRIDE',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMLEVO 25 (Emcure)'
);

-- line #19045
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMLEVO 50 (Emcure)',
	'LEVOSULPRIDE',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMLEVO 50 (Emcure)'
);

-- line #19046
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EVURIDE 25 (Ranbaxy)',
	'LEVOSULPRIDE',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EVURIDE 25 (Ranbaxy)'
);

-- line #19047
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LESURIDE 75 (Sun)',
	'LEVOSULPRIDE',
	'OD TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LESURIDE 75 (Sun)'
);

-- line #19048
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LESURIDE 25 (SUN)',
	'LEVOSULPRIDE',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LESURIDE 25 (SUN)'
);

-- line #19049
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVAZEO 100 (Torrent)',
	'LEVOSULPRIDE',
	'OD TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVAZEO 100 (Torrent)'
);

-- line #19050
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVAZEO 150 (Torrent)',
	'LEVOSULPRIDE',
	'OD TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVAZEO 150 (Torrent)'
);

-- line #19051
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVAZEO 200 (Torrent)',
	'LEVOSULPRIDE',
	'OD TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVAZEO 200 (Torrent)'
);

-- line #19052
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVAZEO 25 (Torrent)',
	'LEVOSULPRIDE',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVAZEO 25 (Torrent)'
);

-- line #19053
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100', u'strength_2': u'', u'substance': u'LEVOSULPRIDE', u'always_empty': u'', u'form': u'', u'brand': u'LEVAZEO', u'strength_3': u'', u'company': u'Torrent', u'unit': u'mg'}

-- line #19054
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50', u'strength_2': u'', u'substance': u'LEVOSULPRIDE', u'always_empty': u'', u'form': u'', u'brand': u'LEVAZEO', u'strength_3': u'', u'company': u'Torrent', u'unit': u'mg'}

-- line #19055
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVIPRIDE 100 (Intas)',
	'LEVOSULPRIDE',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVIPRIDE 100 (Intas)'
);

-- line #19056
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVIPRIDE 50 (Intas)',
	'LEVOSULPRIDE',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVIPRIDE 50 (Intas)'
);

-- line #19057
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOGASTROL 25 (Alembic)',
	'LEVOSULPRIDE',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOGASTROL 25 (Alembic)'
);

-- line #19058
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOGASTROL 75 (ALCARE)',
	'LEVOSULPRIDE',
	'OD TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOGASTROL 75 (ALCARE)'
);

-- line #19059
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOGOLD 100 (Lupin)',
	'LEVOSULPRIDE',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOGOLD 100 (Lupin)'
);

-- line #19060
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOGOLD 25 (Lupin)',
	'LEVOSULPRIDE',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOGOLD 25 (Lupin)'
);

-- line #19061
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOGOLD 50 (Lupin)',
	'LEVOSULPRIDE',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOGOLD 50 (Lupin)'
);

-- line #19062
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOGUT-25 25 (MISSION RES.)',
	'LEVOSULPRIDE',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOGUT-25 25 (MISSION RES.)'
);

-- line #19063
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOGUT-50 50 (MISSION RES.)',
	'LEVOSULPRIDE',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOGUT-50 50 (MISSION RES.)'
);

-- line #19064
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOPRIDE (2) 12.5 (Intas)',
	'LEVOSULPRIDE',
	'INJ',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOPRIDE (2) 12.5 (Intas)'
);

-- line #19065
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOPRIDE 75 (Intas)',
	'LEVOSULPRIDE',
	'SR TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOPRIDE 75 (Intas)'
);

-- line #19066
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOPRIDE 25 (Intas)',
	'LEVOSULPRIDE',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOPRIDE 25 (Intas)'
);

-- line #19067
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOPRIDE 50 (Intas)',
	'LEVOSULPRIDE',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOPRIDE 50 (Intas)'
);

-- line #19068
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEXIPRIDE 25 (Sun)',
	'LEVOSULPRIDE',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEXIPRIDE 25 (Sun)'
);

-- line #19069
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEXIPRIDE 100 (Sun)',
	'LEVOSULPRIDE',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEXIPRIDE 100 (Sun)'
);

-- line #19070
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEXIPRIDE 25 (Sun)',
	'LEVOSULPRIDE',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEXIPRIDE 25 (Sun)'
);

-- line #19071
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEXIPRIDE 50 (Sun)',
	'LEVOSULPRIDE',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEXIPRIDE 50 (Sun)'
);

-- line #19072
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROLEVO 25 (J.B. CHEM)',
	'LEVOSULPRIDE',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROLEVO 25 (J.B. CHEM)'
);

-- line #19073
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUTANEUROL 500 (Franco I.)',
	'L(+)Glutamic Acid',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUTANEUROL 500 (Franco I.)'
);

-- line #19074
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'15GM', u'strength_2': u'', u'substance': u'L-GLUTAMINE', u'always_empty': u'', u'form': u'SAC', u'brand': u'GLUTAHENZ', u'strength_3': u'', u'company': u'LA RENON', u'unit': u''}

-- line #19075
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10GM', u'strength_2': u'', u'substance': u'L-GLUTAMINE', u'always_empty': u'', u'form': u'', u'brand': u'GLUTAPEP', u'strength_3': u'', u'company': u'VENUS REM.', u'unit': u''}

-- line #19076
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10G', u'strength_2': u'', u'substance': u'L-GLUTAMINE', u'always_empty': u'', u'form': u'SAC', u'brand': u'G-MUNE', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #19077
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'L-GLUTAMINE', u'always_empty': u'', u'form': u'POUCH', u'brand': u'LAMICAD', u'strength_3': u'', u'company': u'Cadila Ph.', u'unit': u''}

-- line #19078
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100MCG', u'strength_2': u'', u'substance': u'L-HUPERZINE A', u'always_empty': u'', u'form': u'CAP', u'brand': u'MEMPIL', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #19079
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200MCG', u'strength_2': u'', u'substance': u'L-HUPERZINE A', u'always_empty': u'', u'form': u'CAP', u'brand': u'MEMPIL', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #19080
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5', u'strength_2': u'', u'substance': u'Lidocaine', u'always_empty': u'', u'form': u'', u'brand': u'LIDOPATCH', u'strength_3': u'', u'company': u'Zydus Cad.', u'unit': u'%'}

-- line #19081
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLINIUM 60 (Ethnor)',
	'Lidoflazine',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLINIUM 60 (Ethnor)'
);

-- line #19082
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANDRECAINE % 1 (Intas)',
	'Lignocaine',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANDRECAINE % 1 (Intas)'
);

-- line #19083
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANDRECAINE % 2 (Intas)',
	'Lignocaine',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANDRECAINE % 2 (Intas)'
);

-- line #19084
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GESICAIN % 1 (Nicholas)',
	'Lignocaine',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GESICAIN % 1 (Nicholas)'
);

-- line #19085
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GESICAIN % 2 (Nicholas)',
	'Lignocaine',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GESICAIN % 2 (Nicholas)'
);

-- line #19086
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GESICAIN 5 (Nicholas)',
	'Lignocaine',
	'OINT',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GESICAIN 5 (Nicholas)'
);

-- line #19087
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GESICAIN TOPICAL 4 (Nicholas)',
	'Lignocaine',
	'SOL',
	gm.nullify_empty_string('4')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GESICAIN TOPICAL 4 (Nicholas)'
);

-- line #19088
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GESICAIN % 2 (Nicholas)',
	'Lignocaine',
	'VISCOUS',
	gm.nullify_empty_string('2')::numeric,
	'% (20'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GESICAIN % 2 (Nicholas)'
);

-- line #19089
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GESICARD 20 (Nicholas)',
	'Lignocaine',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg/ML(ANHYDR.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GESICARD 20 (Nicholas)'
);

-- line #19090
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APRICAINE 21.3 (Indus)',
	'Lignocaine Hcl.',
	'INJ',
	gm.nullify_empty_string('21.3')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APRICAINE 21.3 (Indus)'
);

-- line #19091
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIDFAST % 2 (Samarth)',
	'Lignocaine',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIDFAST % 2 (Samarth)'
);

-- line #19092
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIGNOCAINE 2 (Cadila Ph.)',
	'Lignocaine',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIGNOCAINE 2 (Cadila Ph.)'
);

-- line #19093
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIGNOCAINE % 1 (Haffkine)',
	'Lignocaine',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIGNOCAINE % 1 (Haffkine)'
);

-- line #19094
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIGNOCAINE 2 (Nicholas)',
	'Lignocaine',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIGNOCAINE 2 (Nicholas)'
);

-- line #19095
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIGNOCIP 2 (Cipla)',
	'Lignocaine',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIGNOCIP 2 (Cipla)'
);

-- line #19096
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIGNOLOC % 2 (CH.Bhagat)',
	'Lignocaine',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'%/50ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIGNOLOC % 2 (CH.Bhagat)'
);

-- line #19097
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIGNOLOC 5 (CH.Bhagat)',
	'Lignocaine',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'%/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIGNOLOC 5 (CH.Bhagat)'
);

-- line #19098
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIGNOX 4 (Warren)',
	'Lignocaine',
	'GEL',
	gm.nullify_empty_string('4')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIGNOX 4 (Warren)'
);

-- line #19099
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIGNOX % 1 (Warren)',
	'Lignocaine',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIGNOX % 1 (Warren)'
);

-- line #19100
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIGNOX % 2 (Warren)',
	'Lignocaine',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIGNOX % 2 (Warren)'
);

-- line #19101
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIGNOX 5 (Warren)',
	'Lignocaine',
	'OINT',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIGNOX 5 (Warren)'
);

-- line #19102
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIGNOX 15 (Warren)',
	'Lignocaine',
	'SPRAY',
	gm.nullify_empty_string('15')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIGNOX 15 (Warren)'
);

-- line #19103
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIGNOX 4 (Warren)',
	'Lignocaine',
	'TOPICAL',
	gm.nullify_empty_string('4')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIGNOX 4 (Warren)'
);

-- line #19104
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOCAINE 2 (Csc Ph.)',
	'Lignocaine',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOCAINE 2 (Csc Ph.)'
);

-- line #19105
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOX % 2 (Neon)',
	'Lignocaine',
	'AMP',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOX % 2 (Neon)'
);

-- line #19106
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOX % 21.3 (Neon)',
	'Lignocaine',
	'INJ',
	gm.nullify_empty_string('21.3')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOX % 21.3 (Neon)'
);

-- line #19107
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2', u'strength_2': u'', u'substance': u'Lignocaine', u'always_empty': u'', u'form': u'', u'brand': u'LOX JELLY', u'strength_3': u'', u'company': u'Neon', u'unit': u'%'}

-- line #19108
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESOCAINE 21.3 (Ind-Swift)',
	'Lignocaine',
	'INJ',
	gm.nullify_empty_string('21.3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESOCAINE 21.3 (Ind-Swift)'
);

-- line #19109
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Lincomycin Hcl.', u'always_empty': u'', u'form': u'INJ', u'brand': u'AMLINC', u'strength_3': u'', u'company': u'AMRIT', u'unit': u''}

-- line #19110
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHEMLIN 500 (Merit Org.)',
	'Lincomycin Hcl.',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHEMLIN 500 (Merit Org.)'
);

-- line #19111
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COSTEP-I 300 (Intracin)',
	'Lincomycin Hcl.',
	'AMP',
	gm.nullify_empty_string('300')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COSTEP-I 300 (Intracin)'
);

-- line #19112
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENDOSEP 300 (Eden Hc.)',
	'Lincomycin Hcl.',
	'INJ',
	gm.nullify_empty_string('300')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENDOSEP 300 (Eden Hc.)'
);

-- line #19113
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HILINC 300 (Prohealth)',
	'Lincomycin Hcl.',
	'INJ',
	gm.nullify_empty_string('300')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HILINC 300 (Prohealth)'
);

-- line #19114
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYNEX 300 (Jackson)',
	'Lincomycin Hcl.',
	'INJ',
	gm.nullify_empty_string('300')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYNEX 300 (Jackson)'
);

-- line #19115
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Lincomycin Hcl.', u'always_empty': u'', u'form': u'INJ', u'brand': u'INK', u'strength_3': u'', u'company': u'Medoz Ph.', u'unit': u''}

-- line #19116
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JOLINK 300 (Jollen Med.)',
	'Lincomycin Hcl.',
	'INJ',
	gm.nullify_empty_string('300')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JOLINK 300 (Jollen Med.)'
);

-- line #19117
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAPIS 500 (Aronex Life)',
	'Lincomycin Hcl.',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAPIS 500 (Aronex Life)'
);

-- line #19118
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINCIN 300 (Dynamic)',
	'Lincomycin Hcl.',
	'AMP',
	gm.nullify_empty_string('300')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINCIN 300 (Dynamic)'
);

-- line #19119
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINCIN 250 (Dynamic)',
	'Lincomycin Hcl.',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINCIN 250 (Dynamic)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINCIN 500 (Dynamic)',
	'Lincomycin Hcl.',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINCIN 500 (Dynamic)'
);

-- line #19120
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINCOCIN 500 (MAX)',
	'Lincomycin Hcl.',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINCOCIN 500 (MAX)'
);

-- line #19121
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINCOCIN 300 (MAX)',
	'Lincomycin Hcl.',
	'INJ',
	gm.nullify_empty_string('300')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINCOCIN 300 (MAX)'
);

-- line #19122
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Lincomycin Hcl.', u'always_empty': u'', u'form': u'INJ', u'brand': u'LINCOFIN', u'strength_3': u'', u'company': u'Finesse Ph.', u'unit': u''}

-- line #19123
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINCOSA 300 (Sayona)',
	'Lincomycin Hcl.',
	'INJ',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINCOSA 300 (Sayona)'
);

-- line #19124
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINCOZIN 250 (TAJ PH.)',
	'Lincomycin Hcl.',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINCOZIN 250 (TAJ PH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINCOZIN 500 (TAJ PH.)',
	'Lincomycin Hcl.',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINCOZIN 500 (TAJ PH.)'
);

-- line #19125
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINCOZIN 300 (TAJ PH.)',
	'Lincomycin Hcl.',
	'INJ',
	gm.nullify_empty_string('300')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINCOZIN 300 (TAJ PH.)'
);

-- line #19126
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINCOZIN 125 (TAJ PH.)',
	'Lincomycin Hcl.',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINCOZIN 125 (TAJ PH.)'
);

-- line #19127
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINKA 300 (Global Med.)',
	'Lincomycin Hcl.',
	'INJ',
	gm.nullify_empty_string('300')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINKA 300 (Global Med.)'
);

-- line #19128
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINKAM 500 (Kamron)',
	'Lincomycin Hcl.',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINKAM 500 (Kamron)'
);

-- line #19129
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINKAM 300 (Kamron)',
	'Lincomycin Hcl.',
	'INJ',
	gm.nullify_empty_string('300')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINKAM 300 (Kamron)'
);

-- line #19130
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINK 500 (Ind-Swift)',
	'Lincomycin Hcl.',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINK 500 (Ind-Swift)'
);

-- line #19131
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINK 2 (Ind-Swift)',
	'Lincomycin Hcl.',
	'GEL',
	gm.nullify_empty_string('2')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINK 2 (Ind-Swift)'
);

-- line #19132
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINK 300 (Ind-Swift)',
	'Lincomycin Hcl.',
	'INJ',
	gm.nullify_empty_string('300')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINK 300 (Ind-Swift)'
);

-- line #19133
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Lincomycin Hcl.', u'always_empty': u'', u'form': u'CAP', u'brand': u'LINOCIN', u'strength_3': u'', u'company': u'Redson', u'unit': u''}

-- line #19134
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINOCIN 300 (Redson)',
	'Lincomycin Hcl.',
	'INJ',
	gm.nullify_empty_string('300')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINOCIN 300 (Redson)'
);

-- line #19135
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINOSON 300 (Adison Lab)',
	'Lincomycin Hcl.',
	'INJ',
	gm.nullify_empty_string('300')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINOSON 300 (Adison Lab)'
);

-- line #19136
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINT 300 (Oscar Rem.)',
	'Lincomycin Hcl.',
	'INJ',
	gm.nullify_empty_string('300')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINT 300 (Oscar Rem.)'
);

-- line #19137
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINTOP 500 (Zenon Hc.)',
	'Lincomycin Hcl.',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINTOP 500 (Zenon Hc.)'
);

-- line #19138
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINTOP 300 (Zenon Hc.)',
	'Lincomycin Hcl.',
	'INJ',
	gm.nullify_empty_string('300')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINTOP 300 (Zenon Hc.)'
);

-- line #19139
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10. Okt', u'strength_2': u'', u'substance': u'Lincomycin Hcl.', u'always_empty': u'', u'form': u'CAP', u'brand': u'LIOD', u'strength_3': u'', u'company': u'Bennet Ph.', u'unit': u''}

-- line #19140
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIOD 300 (Bennet Ph.)',
	'Lincomycin Hcl.',
	'INJ',
	gm.nullify_empty_string('300')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIOD 300 (Bennet Ph.)'
);

-- line #19141
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIOD 125 (Bennet Ph.)',
	'Lincomycin Hcl.',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIOD 125 (Bennet Ph.)'
);

-- line #19142
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYNX 250 (Wallace)',
	'Lincomycin Hcl.',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYNX 250 (Wallace)'
);

-- line #19143
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYNX 500 (Wallace)',
	'Lincomycin Hcl.',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYNX 500 (Wallace)'
);

-- line #19144
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYNX 2 (Wallace)',
	'Lincomycin Hcl.',
	'GEL',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYNX 2 (Wallace)'
);

-- line #19145
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYNX INJ 300 (Wallace)',
	'Lincomycin Hcl.',
	'V',
	gm.nullify_empty_string('300')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYNX INJ 300 (Wallace)'
);

-- line #19146
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYNX 300 (Wallace)',
	'Lincomycin Hcl.',
	'INJ',
	gm.nullify_empty_string('300')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYNX 300 (Wallace)'
);

-- line #19147
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYNX 125 (Wallace)',
	'Lincomycin Hcl.',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYNX 125 (Wallace)'
);

-- line #19148
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCOVIN 250 (Southsourne)',
	'Lincomycin Hcl.',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg (BASE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCOVIN 250 (Southsourne)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCOVIN 500 (Southsourne)',
	'Lincomycin Hcl.',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg (BASE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCOVIN 500 (Southsourne)'
);

-- line #19149
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEW LINK 300 (Sanjeevani Bio.)',
	'Lincomycin Hcl.',
	'INJ',
	gm.nullify_empty_string('300')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEW LINK 300 (Sanjeevani Bio.)'
);

-- line #19150
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONYLIN 300 (Healthgaurd)',
	'Lincomycin Hcl.',
	'INJ',
	gm.nullify_empty_string('300')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONYLIN 300 (Healthgaurd)'
);

-- line #19151
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROLINC 300 (Prohealth)',
	'Lincomycin Hcl.',
	'INJ',
	gm.nullify_empty_string('300')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROLINC 300 (Prohealth)'
);

-- line #19152
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REOMYCIN 300 (Radix Bio.)',
	'Lincomycin Hcl.',
	'INJ',
	gm.nullify_empty_string('300')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REOMYCIN 300 (Radix Bio.)'
);

-- line #19153
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIT-N-MITE 1 (Makers)',
	'Lindane',
	'LOT',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIT-N-MITE 1 (Makers)'
);

-- line #19154
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZOLID 600 (Alembic)',
	'Linezolid',
	'INF',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZOLID 600 (Alembic)'
);

-- line #19155
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZOLID 600 (Alembic)',
	'Linezolid',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZOLID 600 (Alembic)'
);

-- line #19156
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANZOLID 200 (Claris L.)',
	'Linezolid',
	'INF',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANZOLID 200 (Claris L.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANZOLID 600 (Claris L.)',
	'Linezolid',
	'INF',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANZOLID 600 (Claris L.)'
);

-- line #19157
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'600', u'strength_2': u'', u'substance': u'Linezolid', u'always_empty': u'', u'form': u'', u'brand': u'ENTAVAR', u'strength_3': u'', u'company': u'Biocon', u'unit': u'mg/300ML'}

-- line #19158
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENTAVAR 600 (Biocon)',
	'Linezolid',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENTAVAR 600 (Biocon)'
);

-- line #19159
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INFULID 600 (NEISS)',
	'Linezolid',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INFULID 600 (NEISS)'
);

-- line #19160
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTRALIZ 600 (Intra Lab)',
	'Linezolid',
	'TAB/INF',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTRALIZ 600 (Intra Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTRALIZ 600 (Intra Lab)',
	'Linezolid',
	'TAB/INF',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTRALIZ 600 (Intra Lab)'
);

-- line #19161
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINID 600 (Zydus Cadila)',
	'Linezolid',
	'INFUSION',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINID 600 (Zydus Cadila)'
);

-- line #19162
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINID 600 (Zydus Cadila)',
	'Linezolid',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINID 600 (Zydus Cadila)'
);

-- line #19163
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2', u'strength_2': u'', u'substance': u'Linezolid', u'always_empty': u'', u'form': u'', u'brand': u'LINOPLUS IV', u'strength_3': u'', u'company': u'Piramal Hc.', u'unit': u'mg'}

-- line #19164
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINOPLUS 600 (Piramal Hc.)',
	'Linezolid',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINOPLUS 600 (Piramal Hc.)'
);

-- line #19165
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINOSEPT 600 (Eros Ph.)',
	'Linezolid',
	'INF',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINOSEPT 600 (Eros Ph.)'
);

-- line #19166
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINOSEPT 600 (Eros Ph.)',
	'Linezolid',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINOSEPT 600 (Eros Ph.)'
);

-- line #19167
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINOSPAN 100 (Cipla)',
	'Linezolid',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINOSPAN 100 (Cipla)'
);

-- line #19168
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINOSPAN 200 (Cipla)',
	'Linezolid',
	'INF',
	gm.nullify_empty_string('200')::numeric,
	'mg/100ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINOSPAN 200 (Cipla)'
);

-- line #19169
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINOSPAN 600 (Cipla)',
	'Linezolid',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINOSPAN 600 (Cipla)'
);

-- line #19170
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINOX 600 (Unichem)',
	'Linezolid',
	'INF',
	gm.nullify_empty_string('600')::numeric,
	'mg/300ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINOX 600 (Unichem)'
);

-- line #19171
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINOX-I 200 (Unichem)',
	'Linezolid',
	'V',
	gm.nullify_empty_string('200')::numeric,
	'mg/100ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINOX-I 200 (Unichem)'
);

-- line #19172
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINOX 600 (Unichem)',
	'Linezolid',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINOX 600 (Unichem)'
);

-- line #19173
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200', u'strength_2': u'', u'substance': u'Linezolid', u'always_empty': u'', u'form': u'', u'brand': u'LINOZID IV', u'strength_3': u'', u'company': u'Troikaa', u'unit': u'mg/100ML'}

-- line #19174
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINOZID 600 (Troikaa)',
	'Linezolid',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINOZID 600 (Troikaa)'
);

-- line #19175
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINTRAN IV 2 (Shreya)',
	'Linezolid',
	'POUCH',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINTRAN IV 2 (Shreya)'
);

-- line #19176
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINTRAN 600 (Shreya)',
	'Linezolid',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINTRAN 600 (Shreya)'
);

-- line #19177
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINZEX 600 (EXCELLA)',
	'Linezolid',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINZEX 600 (EXCELLA)'
);

-- line #19178
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINZID 600 (United Bio.)',
	'Linezolid',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINZID 600 (United Bio.)'
);

-- line #19179
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIZBID 600 (Nicholas)',
	'Linezolid',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIZBID 600 (Nicholas)'
);

-- line #19180
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIZEMOX 600 (MOLEKULE)',
	'Linezolid',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIZEMOX 600 (MOLEKULE)'
);

-- line #19181
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIZOFORCE 600 (Mankind)',
	'Linezolid',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIZOFORCE 600 (Mankind)'
);

-- line #19182
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIZOLID 200 (Gracewell)',
	'Linezolid',
	'INF',
	gm.nullify_empty_string('200')::numeric,
	'mg/100ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIZOLID 200 (Gracewell)'
);

-- line #19183
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIZOLID 600 (Gracewell)',
	'Linezolid',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIZOLID 600 (Gracewell)'
);

-- line #19184
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIZOMAC 600 (Macleods)',
	'Linezolid',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIZOMAC 600 (Macleods)'
);

-- line #19185
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIZOMED 100 (Aglowmed)',
	'Linezolid',
	'D.SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIZOMED 100 (Aglowmed)'
);

-- line #19186
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIZOMED 600 (Aglowmed)',
	'Linezolid',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIZOMED 600 (Aglowmed)'
);

-- line #19187
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIZORAN 600 (Ranbaxy)',
	'Linezolid',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIZORAN 600 (Ranbaxy)'
);

-- line #19188
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LNZ 600 (Lupin)',
	'Linezolid',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LNZ 600 (Lupin)'
);

-- line #19189
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAXOLID 600 (Macleods)',
	'Linezolid',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAXOLID 600 (Macleods)'
);

-- line #19190
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLUSLINE 600 (Wanbury)',
	'Linezolid',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLUSLINE 600 (Wanbury)'
);

-- line #19191
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'LIGHT', u'strength_2': u'', u'substance': u'Liq.Paraffin', u'always_empty': u'', u'form': u'LIQ', u'brand': u'ENSI', u'strength_3': u'', u'company': u'Dermocare', u'unit': u''}

-- line #19192
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Liq.Paraffin', u'always_empty': u'', u'form': u'SYR', u'brand': u'LIQ PARAFFIN', u'strength_3': u'', u'company': u'Kim Chem.', u'unit': u''}

-- line #19193
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOYZEN 63.4 (Icpa)',
	'Liq.Paraffin',
	'LIQD',
	gm.nullify_empty_string('63.4')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOYZEN 63.4 (Icpa)'
);

-- line #19194
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'63,4', u'strength_2': u'', u'substance': u'Liq.Paraffin', u'always_empty': u'', u'form': u'', u'brand': u'OILATUM EMOLIENT', u'strength_3': u'', u'company': u'STIEFEL', u'unit': u'%'}

-- line #19195
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACEBITOR 5 (GSK)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACEBITOR 5 (GSK)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACEBITOR 10 (GSK)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACEBITOR 10 (GSK)'
);

-- line #19196
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACINOPRIL 10 (SANOFI AV.)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACINOPRIL 10 (SANOFI AV.)'
);

-- line #19197
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACINOPRIL 2.5 (SANOFI AV.)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACINOPRIL 2.5 (SANOFI AV.)'
);

-- line #19198
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACINOPRIL 5 (SANOFI AV.)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACINOPRIL 5 (SANOFI AV.)'
);

-- line #19199
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALIS 5 (Lincoln)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALIS 5 (Lincoln)'
);

-- line #19200
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOLIS-5 5 (Chemo Bio.)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOLIS-5 5 (Chemo Bio.)'
);

-- line #19201
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOPRIL 10 (Biochem)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOPRIL 10 (Biochem)'
);

-- line #19202
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOPRIL 2.5 (Biochem)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOPRIL 2.5 (Biochem)'
);

-- line #19203
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOPRIL 5 (Biochem)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOPRIL 5 (Biochem)'
);

-- line #19204
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPRIL 10 (Cipla)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPRIL 10 (Cipla)'
);

-- line #19205
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPRIL 2.5 (Cipla)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPRIL 2.5 (Cipla)'
);

-- line #19206
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPRIL 5 (Cipla)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPRIL 5 (Cipla)'
);

-- line #19207
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILACE 5 (Orchid Hc.)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILACE 5 (Orchid Hc.)'
);

-- line #19208
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILIS 5 (Ind-Swift)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILIS 5 (Ind-Swift)'
);

-- line #19209
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ES 10 (Stadmed)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ES 10 (Stadmed)'
);

-- line #19210
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ES 2.5 (Stadmed)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ES 2.5 (Stadmed)'
);

-- line #19211
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ES 5 (Stadmed)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ES 5 (Stadmed)'
);

-- line #19212
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIPRIL 10 (Carsyon)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIPRIL 10 (Carsyon)'
);

-- line #19213
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIPRIL 2.5 (Carsyon)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIPRIL 2.5 (Carsyon)'
);

-- line #19214
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIPRIL 5 (Carsyon)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIPRIL 5 (Carsyon)'
);

-- line #19215
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYPACE 10 (Merind)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYPACE 10 (Merind)'
);

-- line #19216
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYPACE 2.5 (Merind)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYPACE 2.5 (Merind)'
);

-- line #19217
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYPACE 5 (Merind)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYPACE 5 (Merind)'
);

-- line #19218
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ILIS 10 (Zydus Cadila)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ILIS 10 (Zydus Cadila)'
);

-- line #19219
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ILIS 2.5 (Zydus Cadila)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ILIS 2.5 (Zydus Cadila)'
);

-- line #19220
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ILIS 5 (Zydus Cadila)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ILIS 5 (Zydus Cadila)'
);

-- line #19221
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INRAS 10 (Merind)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INRAS 10 (Merind)'
);

-- line #19222
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INRAS 2.5 (Merind)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INRAS 2.5 (Merind)'
);

-- line #19223
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INRAS 5 (Merind)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INRAS 5 (Merind)'
);

-- line #19224
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LESOPRIL 5 (Themis)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LESOPRIL 5 (Themis)'
);

-- line #19225
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINOPRIL 2.5 (EAST WEST)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINOPRIL 2.5 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINOPRIL 5 (EAST WEST)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINOPRIL 5 (EAST WEST)'
);

-- line #19226
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINORIL 10 (Stadmed)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINORIL 10 (Stadmed)'
);

-- line #19227
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINORIL 2.5 (Stadmed)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINORIL 2.5 (Stadmed)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINORIL 5 (Stadmed)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINORIL 5 (Stadmed)'
);

-- line #19228
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINVAS 10 (Zydus Cadila)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINVAS 10 (Zydus Cadila)'
);

-- line #19229
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINVAS 2.5 (Zydus Cadila)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINVAS 2.5 (Zydus Cadila)'
);

-- line #19230
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINVAS 5 (Zydus Cadila)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINVAS 5 (Zydus Cadila)'
);

-- line #19231
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPRIL 10 (Lupin)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPRIL 10 (Lupin)'
);

-- line #19232
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPRIL 2.5 (Lupin)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPRIL 2.5 (Lupin)'
);

-- line #19233
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPRIL 5 (Lupin)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPRIL 5 (Lupin)'
);

-- line #19234
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LISACE 10 (A.F.D.)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LISACE 10 (A.F.D.)'
);

-- line #19235
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LISACE 2.5 (A.F.D.)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LISACE 2.5 (A.F.D.)'
);

-- line #19236
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LISACE 5 (A.F.D.)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LISACE 5 (A.F.D.)'
);

-- line #19237
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LISCARD 10 (Intra Lab)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LISCARD 10 (Intra Lab)'
);

-- line #19238
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LISCARD 2.5 (Intra Lab)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LISCARD 2.5 (Intra Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LISCARD 5 (Intra Lab)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LISCARD 5 (Intra Lab)'
);

-- line #19239
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LISICARD 10 (Gufic Bio.)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LISICARD 10 (Gufic Bio.)'
);

-- line #19240
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LISICARD 2.5 (Gufic Bio.)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LISICARD 2.5 (Gufic Bio.)'
);

-- line #19241
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LISICARD 5 (Gufic Bio.)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LISICARD 5 (Gufic Bio.)'
);

-- line #19242
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LISINACE 10 (Bergen)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LISINACE 10 (Bergen)'
);

-- line #19243
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LISINACE 2.5 (Bergen)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LISINACE 2.5 (Bergen)'
);

-- line #19244
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LISINACE 5 (Bergen)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LISINACE 5 (Bergen)'
);

-- line #19245
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LISIP 5 (Indica)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LISIP 5 (Indica)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LISIP 10 (Indica)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LISIP 10 (Indica)'
);

-- line #19246
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LISIR 2.5 (Kopran)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LISIR 2.5 (Kopran)'
);

-- line #19247
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LISIR 5 (Kopran)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LISIR 5 (Kopran)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LISIR 10 (Kopran)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LISIR 10 (Kopran)'
);

-- line #19248
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LISITEC 5 (Cipla)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LISITEC 5 (Cipla)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LISITEC 10 (Cipla)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LISITEC 10 (Cipla)'
);

-- line #19249
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LISLO 10 (Nicholas)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LISLO 10 (Nicholas)'
);

-- line #19250
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LISLO 2.5 (Nicholas)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LISLO 2.5 (Nicholas)'
);

-- line #19251
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LISLO 5 (Nicholas)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LISLO 5 (Nicholas)'
);

-- line #19252
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LISNOP 2.5 (Ajanta Ph.)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LISNOP 2.5 (Ajanta Ph.)'
);

-- line #19253
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LISNOP 5 (Ajanta Ph.)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LISNOP 5 (Ajanta Ph.)'
);

-- line #19254
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LISORIL 10 (Ipca)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LISORIL 10 (Ipca)'
);

-- line #19255
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LISORIL 20 (Ipca)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LISORIL 20 (Ipca)'
);

-- line #19256
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LISORIL 2.5 (Ipca)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LISORIL 2.5 (Ipca)'
);

-- line #19257
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LISORIL 5 (Ipca)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LISORIL 5 (Ipca)'
);

-- line #19258
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LISOTEC 2.5 (Sun)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LISOTEC 2.5 (Sun)'
);

-- line #19259
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LISOTEC 5 (Sun)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LISOTEC 5 (Sun)'
);

-- line #19260
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LISPRES 10 (Unique)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LISPRES 10 (Unique)'
);

-- line #19261
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LISPRES 2.5 (Unique)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LISPRES 2.5 (Unique)'
);

-- line #19262
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LISPRES 5 (Unique)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LISPRES 5 (Unique)'
);

-- line #19263
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LISPRIL 5 (Arvind Lab.)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LISPRIL 5 (Arvind Lab.)'
);

-- line #19264
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LISTRIL 10 (Torrent)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LISTRIL 10 (Torrent)'
);

-- line #19265
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LISTRIL 2.5 (Torrent)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LISTRIL 2.5 (Torrent)'
);

-- line #19266
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LISTRIL 5 (Torrent)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LISTRIL 5 (Torrent)'
);

-- line #19267
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LPL 10 (Concept)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LPL 10 (Concept)'
);

-- line #19268
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LPL 2.5 (Concept)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LPL 2.5 (Concept)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LPL 5 (Concept)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LPL 5 (Concept)'
);

-- line #19269
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LPL 2.5 (Concept)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LPL 2.5 (Concept)'
);

-- line #19270
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LPL 5 (Concept)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LPL 5 (Concept)'
);

-- line #19271
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LPRIL 10 (Mano)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LPRIL 10 (Mano)'
);

-- line #19272
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LPRIL 2.5 (Mano)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LPRIL 2.5 (Mano)'
);

-- line #19273
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LPRIL 5 (Mano)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LPRIL 5 (Mano)'
);

-- line #19274
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIVANT 10 (German R.)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIVANT 10 (German R.)'
);

-- line #19275
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIVANT 20 (German R.)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIVANT 20 (German R.)'
);

-- line #19276
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIVANT 2.5 (German R.)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIVANT 2.5 (German R.)'
);

-- line #19277
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIVANT 5 (German R.)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIVANT 5 (German R.)'
);

-- line #19278
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORMOPRIL 10 (Genetica)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORMOPRIL 10 (Genetica)'
);

-- line #19279
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORMOPRIL 2.5 (Genetica)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORMOPRIL 2.5 (Genetica)'
);

-- line #19280
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORMOPRIL 5 (Genetica)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORMOPRIL 5 (Genetica)'
);

-- line #19281
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODACE 10 (Zydus Cadila)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODACE 10 (Zydus Cadila)'
);

-- line #19282
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODACE 2.5 (Zydus Cadila)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODACE 2.5 (Zydus Cadila)'
);

-- line #19283
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODACE 5 (Zydus Cadila)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODACE 5 (Zydus Cadila)'
);

-- line #19284
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREVACE 10 (Rpg Life)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREVACE 10 (Rpg Life)'
);

-- line #19285
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREVACE 2.5 (Rpg Life)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREVACE 2.5 (Rpg Life)'
);

-- line #19286
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREVACE 5 (Rpg Life)',
	'Lisinopril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREVACE 5 (Rpg Life)'
);

-- line #19287
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALKALITH 450 (Pentacare)',
	'Lithium',
	'CR TAB',
	gm.nullify_empty_string('450')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALKALITH 450 (Pentacare)'
);

-- line #19288
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'A-LITH 400 (Pfizer)',
	'Lithium Carbonate',
	'SR TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'A-LITH 400 (Pfizer)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'A-LITH 450 (Pfizer)',
	'Lithium Carbonate',
	'SR TAB',
	gm.nullify_empty_string('450')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'A-LITH 450 (Pfizer)'
);

-- line #19289
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'A-LITH 300 (Pfizer)',
	'Lithium Carbonate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'A-LITH 300 (Pfizer)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'A-LITH 400 (Pfizer)',
	'Lithium Carbonate',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'A-LITH 400 (Pfizer)'
);

-- line #19290
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARBOLITH 400 (PSYCOREM)',
	'Lithium Carbonate',
	'SR TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARBOLITH 400 (PSYCOREM)'
);

-- line #19291
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARBOLITH 450 (PSYCOREM)',
	'Lithium Carbonate',
	'SR TAB',
	gm.nullify_empty_string('450')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARBOLITH 450 (PSYCOREM)'
);

-- line #19292
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARBOLITH 300 (PSYCOREM)',
	'Lithium Carbonate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARBOLITH 300 (PSYCOREM)'
);

-- line #19293
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARBOLITH 400 (PSYCOREM)',
	'Lithium Carbonate',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARBOLITH 400 (PSYCOREM)'
);

-- line #19294
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARLIT 300 (SYKOCURE)',
	'Lithium Carbonate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARLIT 300 (SYKOCURE)'
);

-- line #19295
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYLITH 300 (Cyril Ph.)',
	'Lithium Carbonate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYLITH 300 (Cyril Ph.)'
);

-- line #19296
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELCAB 300 (BARODA)',
	'Lithium Carbonate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELCAB 300 (BARODA)'
);

-- line #19297
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDLITH 300 (Ind-Swift)',
	'Lithium Carbonate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDLITH 300 (Ind-Swift)'
);

-- line #19298
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTALITH 400 (Intas)',
	'Lithium Carbonate',
	'CR TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTALITH 400 (Intas)'
);

-- line #19299
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTALITH 150 (Intas)',
	'Lithium Carbonate',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTALITH 150 (Intas)'
);

-- line #19300
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTALITH 300 (Intas)',
	'Lithium Carbonate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTALITH 300 (Intas)'
);

-- line #19301
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LALITHIUM 300 (LA DRUG)',
	'Lithium Carbonate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LALITHIUM 300 (LA DRUG)'
);

-- line #19302
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LALITHIUM 400 (LA DRUG)',
	'Lithium Carbonate',
	'XR TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LALITHIUM 400 (LA DRUG)'
);

-- line #19303
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LERITHIUM 400 (RECOUPE)',
	'Lithium Carbonate',
	'SR TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LERITHIUM 400 (RECOUPE)'
);

-- line #19304
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LERITHIUM 300 (RECOUPE)',
	'Lithium Carbonate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LERITHIUM 300 (RECOUPE)'
);

-- line #19305
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LICAB 300 (Torrent)',
	'Lithium Carbonate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LICAB 300 (Torrent)'
);

-- line #19306
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LICAB 400 (Torrent)',
	'Lithium Carbonate',
	'XL TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LICAB 400 (Torrent)'
);

-- line #19307
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LITHICAB 450 (TASMED)',
	'Lithium Carbonate',
	'SR',
	gm.nullify_empty_string('450')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LITHICAB 450 (TASMED)'
);

-- line #19308
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LITHICAB 300 (TASMED)',
	'Lithium Carbonate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LITHICAB 300 (TASMED)'
);

-- line #19309
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LITHIUM 400 (SYNAPSE)',
	'Lithium Carbonate',
	'SR TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LITHIUM 400 (SYNAPSE)'
);

-- line #19310
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LITHIUM 250 (SYNAPSE)',
	'Lithium Carbonate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LITHIUM 250 (SYNAPSE)'
);

-- line #19311
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LITHIUM 300 (SYNAPSE)',
	'Lithium Carbonate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LITHIUM 300 (SYNAPSE)'
);

-- line #19312
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LITHOCAP 150 (Intas)',
	'Lithium Carbonate',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LITHOCAP 150 (Intas)'
);

-- line #19313
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LITHOCAP 300 (Intas)',
	'Lithium Carbonate',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LITHOCAP 300 (Intas)'
);

-- line #19314
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LITHOCENT 450 (Crescent Th.)',
	'Lithium Carbonate',
	'CR',
	gm.nullify_empty_string('450')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LITHOCENT 450 (Crescent Th.)'
);

-- line #19315
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LITHOCENT 300 (Crescent Th.)',
	'Lithium Carbonate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LITHOCENT 300 (Crescent Th.)'
);

-- line #19316
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LITHONEX 400 (Theo Ph.)',
	'Lithium Carbonate',
	'SR/XL TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LITHONEX 400 (Theo Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LITHONEX 450 (Theo Ph.)',
	'Lithium Carbonate',
	'SR/XL TAB',
	gm.nullify_empty_string('450')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LITHONEX 450 (Theo Ph.)'
);

-- line #19317
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LITHONEX 150 (Theo Ph.)',
	'Lithium Carbonate',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LITHONEX 150 (Theo Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LITHONEX 300 (Theo Ph.)',
	'Lithium Carbonate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LITHONEX 300 (Theo Ph.)'
);

-- line #19318
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LITHON 300 (Rkg)',
	'Lithium Carbonate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LITHON 300 (Rkg)'
);

-- line #19319
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LITHORIL 400 (Reliance)',
	'Lithium Carbonate',
	'SR TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LITHORIL 400 (Reliance)'
);

-- line #19320
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LITHORIL 300 (Reliance)',
	'Lithium Carbonate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LITHORIL 300 (Reliance)'
);

-- line #19321
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LITHUS 300 (Taurus Lab)',
	'Lithium Carbonate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LITHUS 300 (Taurus Lab)'
);

-- line #19322
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANICARB 300 (Pil)',
	'Lithium Carbonate',
	'SR TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANICARB 300 (Pil)'
);

-- line #19323
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANICARB 400 (Pil)',
	'Lithium Carbonate',
	'SR TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANICARB 400 (Pil)'
);

-- line #19324
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANICARB 450 (Pil)',
	'Lithium Carbonate',
	'SR TAB',
	gm.nullify_empty_string('450')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANICARB 450 (Pil)'
);

-- line #19325
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANICARB 300 (Pil)',
	'Lithium Carbonate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANICARB 300 (Pil)'
);

-- line #19326
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOLITH 300 (Mano)',
	'Lithium Carbonate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOLITH 300 (Mano)'
);

-- line #19327
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROLITHIUM 400 (Olcare)',
	'Lithium Carbonate',
	'SR TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROLITHIUM 400 (Olcare)'
);

-- line #19328
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROLITHIUM 300 (Olcare)',
	'Lithium Carbonate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROLITHIUM 300 (Olcare)'
);

-- line #19329
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LITHOSUN 400 (Sun)',
	'Lithium',
	'SR TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LITHOSUN 400 (Sun)'
);

-- line #19330
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LITHOSUN 250 (Sun)',
	'Lithium',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LITHOSUN 250 (Sun)'
);

-- line #19331
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LITHOSUN 300 (Sun)',
	'Lithium',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LITHOSUN 300 (Sun)'
);

-- line #19332
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'LIVER TONIC', u'always_empty': u'', u'form': u'', u'brand': u'LIV DE MI', u'strength_3': u'', u'company': u'AMEE PH.', u'unit': u''}

-- line #19333
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'LIVER TONIC', u'always_empty': u'', u'form': u'SYR', u'brand': u'LIVFIL', u'strength_3': u'', u'company': u'R.B.REM.', u'unit': u''}

-- line #19334
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'L-15 150 (TABLETS I.)',
	'L-Lysine Hcl.',
	'CRM',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'L-15 150 (TABLETS I.)'
);

-- line #19335
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'15', u'strength_2': u'', u'substance': u'L-Lysine Hcl.', u'always_empty': u'', u'form': u'', u'brand': u'LYSEAL', u'strength_3': u'', u'company': u'TABLETS I.', u'unit': u'%W/W'}

-- line #19336
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'L-LYSINE WITH ANTIOXIDANT MULTIVITAMINS & MULTI MINERAL LIQUID', u'always_empty': u'', u'form': u'LIQ', u'brand': u'FATFIT', u'strength_3': u'', u'company': u'NAMAS', u'unit': u''}

-- line #19337
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10000IU', u'strength_2': u'10ML(NADROPARIN)', u'substance': u'L M W H', u'always_empty': u'', u'form': u'INJ', u'brand': u'CARDIOPARIN', u'strength_3': u'', u'company': u'CH.Bhagat', u'unit': u''}

-- line #19338
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2500IU', u'strength_2': u'ML(NADROPARIN)', u'substance': u'L M W H', u'always_empty': u'', u'form': u'INJ', u'brand': u'CARDIOPARIN', u'strength_3': u'', u'company': u'CH.Bhagat', u'unit': u''}

-- line #19339
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'4000IU', u'strength_2': u'0.4ML(NADROPARIN)', u'substance': u'L M W H', u'always_empty': u'', u'form': u'INJ', u'brand': u'CARDIOPARIN', u'strength_3': u'', u'company': u'CH.Bhagat', u'unit': u''}

-- line #19340
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'6000IU', u'strength_2': u'0.6ML(NADROPARIN)', u'substance': u'L M W H', u'always_empty': u'', u'form': u'INJ', u'brand': u'CARDIOPARIN', u'strength_3': u'', u'company': u'CH.Bhagat', u'unit': u''}

-- line #19341
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU(DALTEPARIN SOD.)', u'strength_2': u'', u'substance': u'L M W H', u'always_empty': u'', u'form': u'INJ', u'brand': u'DALTEPIN IU', u'strength_3': u'', u'company': u'Intas', u'unit': u''}

-- line #19342
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10000I.U.(DALTEPARIN SOD.)', u'strength_2': u'', u'substance': u'L M W H', u'always_empty': u'', u'form': u'VIAL', u'brand': u'DALTEPIN IU', u'strength_3': u'', u'company': u'Intas', u'unit': u''}

-- line #19343
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2500 I.U.(DALTEPARIN SOD. PH EUR)', u'strength_2': u'', u'substance': u'L M W H', u'always_empty': u'', u'form': u'VIAL', u'brand': u'DALTEPIN IU', u'strength_3': u'', u'company': u'Intas', u'unit': u''}

-- line #19344
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'7500 I.U.(DALTEPARIN SOD. PH EUR)', u'strength_2': u'', u'substance': u'L M W H', u'always_empty': u'', u'form': u'VIAL', u'brand': u'DALTEPIN IU', u'strength_3': u'', u'company': u'Intas', u'unit': u''}

-- line #19345
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10000 I.U.(DALTEPARIN SOD. PH EUR)', u'strength_2': u'', u'substance': u'L M W H', u'always_empty': u'', u'form': u'VIAL (PFS)', u'brand': u'DALTEPIN IU', u'strength_3': u'', u'company': u'Intas', u'unit': u''}

-- line #19346
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10', u'strength_2': u'', u'substance': u'L M W H', u'always_empty': u'', u'form': u'', u'brand': u'FRAGMIN-GS ,000', u'strength_3': u'', u'company': u'Pharmacia', u'unit': u'000IU(DALTEPAIN SOD.)'}

-- line #19347
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'7500IU(DALTEPARIN SOD.)', u'strength_2': u'', u'substance': u'L M W H', u'always_empty': u'', u'form': u'', u'brand': u'FRAGMIN-GS', u'strength_3': u'', u'company': u'Pharmacia', u'unit': u''}

-- line #19348
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU(DALTEPARIN SOD.)', u'strength_2': u'', u'substance': u'L M W H', u'always_empty': u'', u'form': u'INJ', u'brand': u'FRAGMIN', u'strength_3': u'', u'company': u'Pharmacia', u'unit': u''}

-- line #19349
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2500 I.U.(DALTEPARIN SOD.)', u'strength_2': u'', u'substance': u'L M W H', u'always_empty': u'', u'form': u'INJ', u'brand': u'FRAGMIN IU', u'strength_3': u'', u'company': u'Pharmacia', u'unit': u''}

-- line #19350
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU(DALTEPARIN SOD.)', u'strength_2': u'', u'substance': u'L M W H', u'always_empty': u'', u'form': u'', u'brand': u'FRAGMIN IU PS', u'strength_3': u'', u'company': u'Pharmacia', u'unit': u''}

-- line #19351
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10000I.U.(DALTEPARIN SOD.)', u'strength_2': u'', u'substance': u'L M W H', u'always_empty': u'', u'form': u'V', u'brand': u'FRAGMIN IU', u'strength_3': u'', u'company': u'Pharmacia', u'unit': u''}

-- line #19352
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1L.U.(DALTEPARIN SOD.)', u'strength_2': u'', u'substance': u'L M W H', u'always_empty': u'', u'form': u'V', u'brand': u'FRAGMIN LU', u'strength_3': u'', u'company': u'Pharmacia', u'unit': u''}

-- line #19353
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'8600I.U. (NADROPARIN)', u'strength_2': u'', u'substance': u'L M W H', u'always_empty': u'', u'form': u'INJ', u'brand': u'FRAXIPARINE', u'strength_3': u'', u'company': u'GSK', u'unit': u''}

-- line #19354
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3075 I.U.(NADROPARIN)', u'strength_2': u'', u'substance': u'L M W H', u'always_empty': u'', u'form': u'', u'brand': u'FRAXIPARINE IUINJ', u'strength_3': u'', u'company': u'Sanofi Aventis', u'unit': u''}

-- line #19355
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'4100 I.U.(NADROPARIN)', u'strength_2': u'', u'substance': u'L M W H', u'always_empty': u'', u'form': u'INJ', u'brand': u'FRAXIPARINE IU', u'strength_3': u'', u'company': u'Sanofi Aventis', u'unit': u''}

-- line #19356
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'6150 I.U.(NADROPARIN)', u'strength_2': u'', u'substance': u'L M W H', u'always_empty': u'', u'form': u'INJ', u'brand': u'FRAXIPARINE IU', u'strength_3': u'', u'company': u'Sanofi Aventis', u'unit': u''}

-- line #19357
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'8600I.U. (NADROPARIN)', u'strength_2': u'', u'substance': u'L M W H', u'always_empty': u'', u'form': u'INJ', u'brand': u'FRAXIPARINE IU', u'strength_3': u'', u'company': u'Sanofi Aventis', u'unit': u''}

-- line #19358
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2500 I.U.(ARDEPARIN)', u'strength_2': u'', u'substance': u'L M W H', u'always_empty': u'', u'form': u'INJ', u'brand': u'INDEPARIN IU', u'strength_3': u'', u'company': u'Gland Ph.', u'unit': u''}

-- line #19359
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000 I.U.(ARDEPARIN)', u'strength_2': u'', u'substance': u'L M W H', u'always_empty': u'', u'form': u'INJ', u'brand': u'INDEPARIN IU', u'strength_3': u'', u'company': u'Gland Ph.', u'unit': u''}

-- line #19360
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'L M W H', u'always_empty': u'', u'form': u'', u'brand': u'LMWX PFS', u'strength_3': u'', u'company': u'Nicholas', u'unit': u'mg'}

-- line #19361
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40', u'strength_2': u'', u'substance': u'L M W H', u'always_empty': u'', u'form': u'', u'brand': u'LMWX PFS', u'strength_3': u'', u'company': u'Nicholas', u'unit': u'mg'}

-- line #19362
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'60', u'strength_2': u'', u'substance': u'L M W H', u'always_empty': u'', u'form': u'', u'brand': u'LMWX PFS', u'strength_3': u'', u'company': u'Nicholas', u'unit': u'mg'}

-- line #19363
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'80', u'strength_2': u'', u'substance': u'L M W H', u'always_empty': u'', u'form': u'', u'brand': u'LMWX PFS', u'strength_3': u'', u'company': u'Nicholas', u'unit': u'mg'}

-- line #19364
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOMORIN 40 (Vhb)',
	'L M W H',
	'INJ PFS',
	gm.nullify_empty_string('40')::numeric,
	'mg/0.4ML(GENSPARIN SOD.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOMORIN 40 (Vhb)'
);

-- line #19365
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOMORIN 60 (Vhb)',
	'L M W H',
	'INJPFS',
	gm.nullify_empty_string('60')::numeric,
	'mg/0.6ML(GENSPARIN SOD.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOMORIN 60 (Vhb)'
);

-- line #19366
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G(GENSPARIN SOD.)', u'strength_2': u'', u'substance': u'L M W H', u'always_empty': u'', u'form': u'INJ', u'brand': u'LOMORIN', u'strength_3': u'', u'company': u'Vhb', u'unit': u''}

-- line #19367
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOMORIN 20 (Vhb)',
	'L M W H',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg/0.2ML(GENSPARIN SOD.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOMORIN 20 (Vhb)'
);

-- line #19368
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOMORIN 40 (Vhb)',
	'L M W H',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg/0.4ML(GENSPARIN SOD.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOMORIN 40 (Vhb)'
);

-- line #19369
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOMORIN 60 (Vhb)',
	'L M W H',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg/0.6ML(GENSPARIN SOD.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOMORIN 60 (Vhb)'
);

-- line #19370
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOMORIN 80 (Vhb)',
	'L M W H',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg/0.8ML(GENSPARIN SOD.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOMORIN 80 (Vhb)'
);

-- line #19371
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2850IU.', u'strength_2': u'0.3ML(NADROPARIN)', u'substance': u'L M W H', u'always_empty': u'', u'form': u'', u'brand': u'NADROHEP IU', u'strength_3': u'', u'company': u'Gland Ph.', u'unit': u''}

-- line #19372
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3850IU.', u'strength_2': u'0.3ML(NADROPARIN)', u'substance': u'L M W H', u'always_empty': u'', u'form': u'', u'brand': u'NADROHEP IU', u'strength_3': u'', u'company': u'Gland Ph.', u'unit': u''}

-- line #19373
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXADAY 400 (Croslands)',
	'Lomefloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXADAY 400 (Croslands)'
);

-- line #19374
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXAQUIN 400 (Themis)',
	'Lomefloxacin',
	'LA TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXAQUIN 400 (Themis)'
);

-- line #19375
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOXIL 400 (ABBOTT)',
	'Lomefloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOXIL 400 (ABBOTT)'
);

-- line #19376
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GYNALOM 400 (Wockhardt)',
	'Lomefloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GYNALOM 400 (Wockhardt)'
);

-- line #19377
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOFLOX 400 (Noir)',
	'Lomefloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOFLOX 400 (Noir)'
);

-- line #19378
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOMADAY 400 (Dr.Reddy''S)',
	'Lomefloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOMADAY 400 (Dr.Reddy''S)'
);

-- line #19379
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOMECARE 400 (Olcare)',
	'Lomefloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOMECARE 400 (Olcare)'
);

-- line #19380
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOMEDON 400 (Zydus Cadila)',
	'Lomefloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOMEDON 400 (Zydus Cadila)'
);

-- line #19381
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOMEF-400 400 (Torrent)',
	'Lomefloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOMEF-400 400 (Torrent)'
);

-- line #19382
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOMEGEN 400 (Genix Ph.)',
	'Lomefloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOMEGEN 400 (Genix Ph.)'
);

-- line #19383
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOMEWON 400 (Max)',
	'Lomefloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOMEWON 400 (Max)'
);

-- line #19384
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOMEWON 400 (MAX)',
	'Lomefloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOMEWON 400 (MAX)'
);

-- line #19385
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOMEXEL 400 (Medley)',
	'Lomefloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOMEXEL 400 (Medley)'
);

-- line #19386
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOM 0.3 (Oscar Rem.)',
	'Lomefloxacin',
	'EYE DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOM 0.3 (Oscar Rem.)'
);

-- line #19387
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOMFLOX 400 (Ipca)',
	'Lomefloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOMFLOX 400 (Ipca)'
);

-- line #19388
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOMIBACT 3 (Milmet)',
	'Lomefloxacin',
	'DPS',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOMIBACT 3 (Milmet)'
);

-- line #19389
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOMIBACT 400 (Sun)',
	'Lomefloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOMIBACT 400 (Sun)'
);

-- line #19390
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOMITAS 400 (Intas)',
	'Lomefloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOMITAS 400 (Intas)'
);

-- line #19391
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOXACIN 400 (NOVARTIS)',
	'Lomefloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOXACIN 400 (NOVARTIS)'
);

-- line #19392
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOXIPEN 400 (Morepen)',
	'Lomefloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOXIPEN 400 (Morepen)'
);

-- line #19393
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAHAQUIN 400 (Rpg Life)',
	'Lomefloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAHAQUIN 400 (Rpg Life)'
);

-- line #19394
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OKACIN 3 (Novartis)',
	'Lomefloxacin',
	'DPS',
	gm.nullify_empty_string('3')::numeric,
	'mg(+GLYCEROL'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OKACIN 3 (Novartis)'
);

-- line #19395
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUMAX 400 (Alkem)',
	'Lomefloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUMAX 400 (Alkem)'
);

-- line #19396
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELOM 400 (Sanofi Aventis)',
	'Lomefloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELOM 400 (Sanofi Aventis)'
);

-- line #19397
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOMTIN 40 (Dr.Reddy''S)',
	'Lomustine',
	'CAP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOMTIN 40 (Dr.Reddy''S)'
);

-- line #19398
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOMUSTINE 40 (GSK)',
	'Lomustine',
	'CAP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOMUSTINE 40 (GSK)'
);

-- line #19399
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUSTINE 40 (Samarth)',
	'Lomustine',
	'CAP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUSTINE 40 (Samarth)'
);

-- line #19400
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELDOPER 2 (Brown & B.)',
	'Loperamide',
	'CAP',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELDOPER 2 (Brown & B.)'
);

-- line #19401
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANDIAL 1 (VERITAZ)',
	'Loperamide Hcl.',
	'LIQ',
	gm.nullify_empty_string('1')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANDIAL 1 (VERITAZ)'
);

-- line #19402
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANDIAL 2 (VERITAZ)',
	'Loperamide Hcl.',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANDIAL 2 (VERITAZ)'
);

-- line #19403
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIAL 2 (Kaiser Ph.)',
	'Loperamide Hcl.',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIAL 2 (Kaiser Ph.)'
);

-- line #19404
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIARLOP 2 (Jagsonpal)',
	'Loperamide Hcl.',
	'CAP',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIARLOP 2 (Jagsonpal)'
);

-- line #19405
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILOP 2 (Trio Rem.)',
	'Loperamide Hcl.',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILOP 2 (Trio Rem.)'
);

-- line #19406
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KLOP-2 2 (Kosha Lab.)',
	'Loperamide Hcl.',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KLOP-2 2 (Kosha Lab.)'
);

-- line #19407
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOMIN 2 (Intra Lab)',
	'Loperamide Hcl.',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOMIN 2 (Intra Lab)'
);

-- line #19408
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOMIN 5 (Intra Lab)',
	'Loperamide Hcl.',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOMIN 5 (Intra Lab)'
);

-- line #19409
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOPAJOY 2 (Torrent)',
	'Loperamide Hcl.',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOPAJOY 2 (Torrent)'
);

-- line #19410
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOPONA 2 (Sayona)',
	'Loperamide Hcl.',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOPONA 2 (Sayona)'
);

-- line #19411
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOPRON 2 (Ronak Lab.)',
	'Loperamide Hcl.',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOPRON 2 (Ronak Lab.)'
);

-- line #19412
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NELOP 2 (Nestor)',
	'Loperamide Hcl.',
	'CAP',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NELOP 2 (Nestor)'
);

-- line #19413
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PELOPEM 2 (Mercury)',
	'Loperamide Hcl.',
	'CAP',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PELOPEM 2 (Mercury)'
);

-- line #19414
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIDOL 1 (Gufic Bio.)',
	'Loperamide Hcl.',
	'SOLN',
	gm.nullify_empty_string('1')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIDOL 1 (Gufic Bio.)'
);

-- line #19415
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIDOL 2 (Gufic Bio.)',
	'Loperamide Hcl.',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIDOL 2 (Gufic Bio.)'
);

-- line #19416
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMODIUM 2 (Ethnor)',
	'Loperamide',
	'CAP',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMODIUM 2 (Ethnor)'
);

-- line #19417
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOPAMIDE 2 (Torrent)',
	'Loperamide',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOPAMIDE 2 (Torrent)'
);

-- line #19418
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOPERAM 2 (AGIO PH.)',
	'Loperamide',
	'CAP',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOPERAM 2 (AGIO PH.)'
);

-- line #19419
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOPERAMIDE 2 (Ethnor)',
	'Loperamide',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOPERAMIDE 2 (Ethnor)'
);

-- line #19420
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALASPAN 1 (Fulford)',
	'Loratadine',
	'SUS',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALASPAN 1 (Fulford)'
);

-- line #19421
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALASPAN 10 (Fulford)',
	'Loratadine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALASPAN 10 (Fulford)'
);

-- line #19422
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALGO 10 (Rapross)',
	'Loratadine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALGO 10 (Rapross)'
);

-- line #19423
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALGYFREE 5 (Galpha)',
	'Loratadine',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALGYFREE 5 (Galpha)'
);

-- line #19424
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALGYFREE 10 (Galpha)',
	'Loratadine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALGYFREE 10 (Galpha)'
);

-- line #19425
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALLERBAN 10 (Saga Lab)',
	'Loratadine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALLERBAN 10 (Saga Lab)'
);

-- line #19426
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLARIDIN 5 (Morepen)',
	'Loratadine',
	'DT',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLARIDIN 5 (Morepen)'
);

-- line #19427
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLARIDIN 10 (Morepen)',
	'Loratadine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLARIDIN 10 (Morepen)'
);

-- line #19428
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOZA 10 (Tnt Life)',
	'Loratadine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOZA 10 (Tnt Life)'
);

-- line #19429
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COZY 10 (Ind-Swift)',
	'Loratadine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COZY 10 (Ind-Swift)'
);

-- line #19430
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTRALOR 10 (Intra Lab)',
	'Loratadine',
	'TAB/SYR',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTRALOR 10 (Intra Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTRALOR 5 (Intra Lab)',
	'Loratadine',
	'TAB/SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTRALOR 5 (Intra Lab)'
);

-- line #19431
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIT 10 (Satyam)',
	'Loratadine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIT 10 (Satyam)'
);

-- line #19432
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOG 10 (Idol Bio.)',
	'Loratadine',
	'DT',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOG 10 (Idol Bio.)'
);

-- line #19433
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORA-10 10 (Apex Form.)',
	'Loratadine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORA-10 10 (Apex Form.)'
);

-- line #19434
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORACT 10 (Organic Lab)',
	'Loratadine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORACT 10 (Organic Lab)'
);

-- line #19435
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORANGE 10 (Panjon)',
	'Loratadine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORANGE 10 (Panjon)'
);

-- line #19436
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORATE 10 (Pifer Ph.)',
	'Loratadine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORATE 10 (Pifer Ph.)'
);

-- line #19437
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORATIA-10 10 (Chemo Bio.)',
	'Loratadine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORATIA-10 10 (Chemo Bio.)'
);

-- line #19438
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORATIN 10 (Cipla)',
	'Loratadine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORATIN 10 (Cipla)'
);

-- line #19439
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORDAY 10 (Mdc Ph.)',
	'Loratadine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORDAY 10 (Mdc Ph.)'
);

-- line #19440
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10', u'strength_2': u'', u'substance': u'Loratadine', u'always_empty': u'', u'form': u'', u'brand': u'LORFAST MELTAB', u'strength_3': u'', u'company': u'Le Sante', u'unit': u'mg'}

-- line #19441
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORFAST 10 (Cadila Hc.)',
	'Loratadine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORFAST 10 (Cadila Hc.)'
);

-- line #19442
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORHIST 10 (Hitech Form.)',
	'Loratadine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORHIST 10 (Hitech Form.)'
);

-- line #19443
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORID 10 (Finecure)',
	'Loratadine',
	'DT',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORID 10 (Finecure)'
);

-- line #19444
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORIDIN 1 (Zydus Cadila)',
	'Loratadine',
	'SUS',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORIDIN 1 (Zydus Cadila)'
);

-- line #19445
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORIDIN 10 (Zydus Cadila)',
	'Loratadine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORIDIN 10 (Zydus Cadila)'
);

-- line #19446
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORINOL 10 (Micro Labs)',
	'Loratadine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORINOL 10 (Micro Labs)'
);

-- line #19447
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORIN 1 (Stadmed)',
	'Loratadine',
	'SYR',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORIN 1 (Stadmed)'
);

-- line #19448
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORIN 10 (Stadmed)',
	'Loratadine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORIN 10 (Stadmed)'
);

-- line #19449
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORLEY 10 (ZODLEY)',
	'Loratadine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORLEY 10 (ZODLEY)'
);

-- line #19450
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORMEG 5 (Alembic)',
	'Loratadine',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORMEG 5 (Alembic)'
);

-- line #19451
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORMEG 10 (Alembic)',
	'Loratadine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORMEG 10 (Alembic)'
);

-- line #19452
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORPD 10 (Pharma Drugs)',
	'Loratadine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORPD 10 (Pharma Drugs)'
);

-- line #19453
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOTID 10 (Ethilex Hc.)',
	'Loratadine',
	'DT',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOTID 10 (Ethilex Hc.)'
);

-- line #19454
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LR-10 10 (Mcneil & ARGUS)',
	'Loratadine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LR-10 10 (Mcneil & ARGUS)'
);

-- line #19455
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LTD 10 (Candor Bio.)',
	'Loratadine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LTD 10 (Candor Bio.)'
);

-- line #19456
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALDINE 10 (Malcom Ph.)',
	'Loratadine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALDINE 10 (Malcom Ph.)'
);

-- line #19457
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYLOR 10 (Radix Bio.)',
	'Loratadine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYLOR 10 (Radix Bio.)'
);

-- line #19458
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEORATE 10 (Biocin Gen.)',
	'Loratadine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEORATE 10 (Biocin Gen.)'
);

-- line #19459
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLANG 5 (Olcare)',
	'Loratadine',
	'DT',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLANG 5 (Olcare)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLANG 10 (Olcare)',
	'Loratadine',
	'DT',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLANG 10 (Olcare)'
);

-- line #19460
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORID 10 (Dynamic)',
	'Loratadine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORID 10 (Dynamic)'
);

-- line #19461
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRODIN 10 (Mefro Ph.)',
	'Loratadine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRODIN 10 (Mefro Ph.)'
);

-- line #19462
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALMAZINE 1 (PSYCOREM)',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALMAZINE 1 (PSYCOREM)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALMAZINE 2 (PSYCOREM)',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALMAZINE 2 (PSYCOREM)'
);

-- line #19463
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMPEZ 1 (Cadex Lab)',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMPEZ 1 (Cadex Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMPEZ 2 (Cadex Lab)',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMPEZ 2 (Cadex Lab)'
);

-- line #19464
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANXILOR 1 (TASMED)',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANXILOR 1 (TASMED)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANXILOR 2 (TASMED)',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANXILOR 2 (TASMED)'
);

-- line #19465
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANXIPOSE 0.5 (Pil)',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANXIPOSE 0.5 (Pil)'
);

-- line #19466
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANXIPOSE 1 (Pil)',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANXIPOSE 1 (Pil)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANXIPOSE 2 (Pil)',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANXIPOSE 2 (Pil)'
);

-- line #19467
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARKAPAM 2 (Rkg)',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARKAPAM 2 (Rkg)'
);

-- line #19468
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATIPAM 1 (Ind-Swift)',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATIPAM 1 (Ind-Swift)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATIPAM 2 (Ind-Swift)',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATIPAM 2 (Ind-Swift)'
);

-- line #19469
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATIPAM 1 (K.C. Lab)',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATIPAM 1 (K.C. Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATIPAM 2 (K.C. Lab)',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATIPAM 2 (K.C. Lab)'
);

-- line #19470
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATIVAM 1 (Wyeth)',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATIVAM 1 (Wyeth)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATIVAM 2 (Wyeth)',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATIVAM 2 (Wyeth)'
);

-- line #19471
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATIVAN 1 (Wyeth)',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATIVAN 1 (Wyeth)'
);

-- line #19472
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATIVAN 2 (Wyeth)',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATIVAN 2 (Wyeth)'
);

-- line #19473
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOLAR 2 (Chemo Bio.)',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOLAR 2 (Chemo Bio.)'
);

-- line #19474
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALMESE 2 (Themis Med.)',
	'Lorazepam',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALMESE 2 (Themis Med.)'
);

-- line #19475
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALMESE 1 (Themis)',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALMESE 1 (Themis)'
);

-- line #19476
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALMESE 2 (Themis)',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALMESE 2 (Themis)'
);

-- line #19477
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2', u'strength_2': u'', u'substance': u'Lorazepam', u'always_empty': u'', u'form': u'', u'brand': u'FORCIPAM', u'strength_3': u'', u'company': u'MEDIFORECE', u'unit': u'mg'}

-- line #19478
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LARPOSE 1 (Cipla)',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LARPOSE 1 (Cipla)'
);

-- line #19479
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LARPOSE 2 (Cipla)',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LARPOSE 2 (Cipla)'
);

-- line #19480
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEROL-2 2 (AMEE PH.)',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEROL-2 2 (AMEE PH.)'
);

-- line #19481
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEROL-3 3 (AMEE PH.)',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEROL-3 3 (AMEE PH.)'
);

-- line #19482
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOPAM 2 (NAVNIDHI LIFE)',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOPAM 2 (NAVNIDHI LIFE)'
);

-- line #19483
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOPAM 1 (Vgr Bio.)',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOPAM 1 (Vgr Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOPAM 2 (Vgr Bio.)',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOPAM 2 (Vgr Bio.)'
);

-- line #19484
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOPEZ 2 (Intas)',
	'Lorazepam',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOPEZ 2 (Intas)'
);

-- line #19485
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOPEZ 1 (Intas)',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOPEZ 1 (Intas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOPEZ 2 (Intas)',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOPEZ 2 (Intas)'
);

-- line #19486
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORACALM 1 (Torrent)',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORACALM 1 (Torrent)'
);

-- line #19487
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORA 2 (Orchid Hc.)',
	'Lorazepam',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORA 2 (Orchid Hc.)'
);

-- line #19488
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORAZINE 1 (Micro Labs)',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORAZINE 1 (Micro Labs)'
);

-- line #19489
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORAZINE 2 (Micro Labs)',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORAZINE 2 (Micro Labs)'
);

-- line #19490
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Lorazepam', u'always_empty': u'', u'form': u'INJ', u'brand': u'LORAZ', u'strength_3': u'', u'company': u'Theo Ph.', u'unit': u''}

-- line #19491
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORAZ 1 (RECOUPE)',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORAZ 1 (RECOUPE)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORAZ 2 (RECOUPE)',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORAZ 2 (RECOUPE)'
);

-- line #19492
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORAZ 1 (Theo Ph.)',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORAZ 1 (Theo Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORAZ 2 (Theo Ph.)',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORAZ 2 (Theo Ph.)'
);

-- line #19493
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOREL 1 (Reliance)',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOREL 1 (Reliance)'
);

-- line #19494
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOREL 2 (Reliance)',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOREL 2 (Reliance)'
);

-- line #19495
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORIPAM 2 (TRITON(CALYX))',
	'Lorazepam',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORIPAM 2 (TRITON(CALYX))'
);

-- line #19496
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORIPAM-SL 1 (Triton Hc.)',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORIPAM-SL 1 (Triton Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORIPAM-SL 2 (Triton Hc.)',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORIPAM-SL 2 (Triton Hc.)'
);

-- line #19497
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORIPAM 1 (TRITON(CALYX))',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORIPAM 1 (TRITON(CALYX))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORIPAM 2 (TRITON(CALYX))',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORIPAM 2 (TRITON(CALYX))'
);

-- line #19498
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORIVAN 1 (Servetus)',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORIVAN 1 (Servetus)'
);

-- line #19499
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORIVAN 2 (Servetus)',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORIVAN 2 (Servetus)'
);

-- line #19500
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORMAN-2 2 (ROSE LABS)',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORMAN-2 2 (ROSE LABS)'
);

-- line #19501
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORPIK 1 (Aarpik Ph.)',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORPIK 1 (Aarpik Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORPIK 2 (Aarpik Ph.)',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORPIK 2 (Aarpik Ph.)'
);

-- line #19502
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOZ 2 (NAVNIDHI LIFE)',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOZ 2 (NAVNIDHI LIFE)'
);

-- line #19503
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LPAM 1 (Mano)',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LPAM 1 (Mano)'
);

-- line #19504
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LPAM 2 (Mano)',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg/3'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LPAM 2 (Mano)'
);

-- line #19505
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'L-ZEPAM 1 (BARODA)',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'L-ZEPAM 1 (BARODA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'L-ZEPAM 2 (BARODA)',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'L-ZEPAM 2 (BARODA)'
);

-- line #19506
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MORAL 1 (APOLO)',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MORAL 1 (APOLO)'
);

-- line #19507
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLRAZ 1 (Olcare)',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLRAZ 1 (Olcare)'
);

-- line #19508
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLRAZ 2 (Olcare)',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLRAZ 2 (Olcare)'
);

-- line #19509
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORAZEP 1 (Crescent Th.)',
	'LORAZEPAM',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'2'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORAZEP 1 (Crescent Th.)'
);

-- line #19510
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROLINE 1 (SHINE PH.)',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROLINE 1 (SHINE PH.)'
);

-- line #19511
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROLINE 2 (SHINE PH.)',
	'Lorazepam',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROLINE 2 (SHINE PH.)'
);

-- line #19512
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANALIV 5 (Systopic)',
	'L-Ornithine L-Aspartate',
	'AMP',
	gm.nullify_empty_string('5')::numeric,
	'mg/10ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANALIV 5 (Systopic)'
);

-- line #19513
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANALIV 5 (Systopic)',
	'L-Ornithine L-Aspartate',
	'AMP',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANALIV 5 (Systopic)'
);

-- line #19514
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANALIV 5 (Systopic)',
	'L-Ornithine L-Aspartate',
	'INF',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANALIV 5 (Systopic)'
);

-- line #19515
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANALIV 500 (Systopic)',
	'L-Ornithine L-Aspartate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANALIV 500 (Systopic)'
);

-- line #19516
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5G', u'strength_2': u'', u'substance': u'L-Ornithine L-Aspartate', u'always_empty': u'', u'form': u'V', u'brand': u'BIOHEP', u'strength_3': u'', u'company': u'Kee Ph.', u'unit': u''}

-- line #19517
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DETOX 150 (Mars)',
	'L-Ornithine L-Aspartate',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DETOX 150 (Mars)'
);

-- line #19518
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEPACORE 5 (Intas)',
	'L-Ornithine L-Aspartate',
	'INF',
	gm.nullify_empty_string('5')::numeric,
	'mg/10ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEPACORE 5 (Intas)'
);

-- line #19519
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEPACOR 150 (Intas)',
	'L-Ornithine L-Aspartate',
	'INF',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEPACOR 150 (Intas)'
);

-- line #19520
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3G', u'strength_2': u'', u'substance': u'L-Ornithine L-Aspartate', u'always_empty': u'', u'form': u'POW', u'brand': u'HEPACOR', u'strength_3': u'', u'company': u'Intas', u'unit': u''}

-- line #19521
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEPACOR 150 (Intas)',
	'L-Ornithine L-Aspartate',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEPACOR 150 (Intas)'
);

-- line #19522
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3G', u'strength_2': u'', u'substance': u'L-Ornithine L-Aspartate', u'always_empty': u'', u'form': u'SAC', u'brand': u'HEPACURE', u'strength_3': u'', u'company': u'MISSION RES.', u'unit': u''}

-- line #19523
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEPACURE 500 (MISSION RES.)',
	'L-Ornithine L-Aspartate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEPACURE 500 (MISSION RES.)'
);

-- line #19524
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5G', u'strength_2': u'', u'substance': u'L-Ornithine L-Aspartate', u'always_empty': u'', u'form': u'INJ', u'brand': u'HEPAGARD', u'strength_3': u'', u'company': u'United Bio.', u'unit': u''}

-- line #19525
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3G', u'strength_2': u'5G', u'substance': u'L-Ornithine L-Aspartate', u'always_empty': u'', u'form': u'GRAN', u'brand': u'HEPA-MERZ', u'strength_3': u'', u'company': u'Win-Medicare', u'unit': u''}

-- line #19526
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5G', u'strength_2': u'10ML', u'substance': u'L-Ornithine L-Aspartate', u'always_empty': u'', u'form': u'INF', u'brand': u'HEPA-MERZ', u'strength_3': u'', u'company': u'Win-Medicare', u'unit': u''}

-- line #19527
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5G', u'strength_2': u'', u'substance': u'L-Ornithine L-Aspartate', u'always_empty': u'', u'form': u'INJ', u'brand': u'HEPASTAR', u'strength_3': u'', u'company': u'Intra(INVISION)', u'unit': u''}

-- line #19528
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEPASTAR 150 (Intra(INVISION))',
	'L-Ornithine L-Aspartate',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEPASTAR 150 (Intra(INVISION))'
);

-- line #19529
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEPAWIN 5 (Waves Bio.)',
	'L-Ornithine L-Aspartate',
	'INF CONC',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEPAWIN 5 (Waves Bio.)'
);

-- line #19530
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5G', u'strength_2': u'10ML', u'substance': u'L-Ornithine L-Aspartate', u'always_empty': u'', u'form': u'AMP', u'brand': u'HEPAZE', u'strength_3': u'', u'company': u'Zee Lab', u'unit': u''}

-- line #19531
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTRALIV 5 (Intra Lab)',
	'L-Ornithine L-Aspartate',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTRALIV 5 (Intra Lab)'
);

-- line #19532
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTRALIV 150 (Intra Lab)',
	'L-Ornithine L-Aspartate',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTRALIV 150 (Intra Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTRALIV 500 (Intra Lab)',
	'L-Ornithine L-Aspartate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTRALIV 500 (Intra Lab)'
);

-- line #19533
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'L-Ornithine L-Aspartate', u'always_empty': u'', u'form': u'F. INJ', u'brand': u'LIV CURE', u'strength_3': u'', u'company': u'Pfiscar Ind.', u'unit': u''}

-- line #19534
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIVIVE 150 (Emcure)',
	'L-Ornithine L-Aspartate',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIVIVE 150 (Emcure)'
);

-- line #19535
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIVIVE 500 (Emcure)',
	'L-Ornithine L-Aspartate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIVIVE 500 (Emcure)'
);

-- line #19536
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5G', u'strength_2': u'10ML', u'substance': u'L-Ornithine L-Aspartate', u'always_empty': u'', u'form': u'INF', u'brand': u'LIVOGARD', u'strength_3': u'', u'company': u'Lark Labs', u'unit': u''}

-- line #19537
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LONGLIV 150 (Wallace)',
	'L-Ornithine L-Aspartate',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LONGLIV 150 (Wallace)'
);

-- line #19538
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'L-ORAS 150 (ROSE LABS)',
	'L-Ornithine L-Aspartate',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'L-ORAS 150 (ROSE LABS)'
);

-- line #19539
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5G', u'strength_2': u'', u'substance': u'L-Ornithine L-Aspartate', u'always_empty': u'', u'form': u'INF', u'brand': u'LORNIT', u'strength_3': u'', u'company': u'Zuventus', u'unit': u''}

-- line #19540
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3G', u'strength_2': u'', u'substance': u'L-Ornithine L-Aspartate', u'always_empty': u'', u'form': u'SAC', u'brand': u'LORNIT', u'strength_3': u'', u'company': u'Zuventus', u'unit': u''}

-- line #19541
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORNIT 150 (Zuventus)',
	'L-Ornithine L-Aspartate',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORNIT 150 (Zuventus)'
);

-- line #19542
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORNIT 500 (Zuventus)',
	'L-Ornithine L-Aspartate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORNIT 500 (Zuventus)'
);

-- line #19543
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5G', u'strength_2': u'', u'substance': u'L-Ornithine L-Aspartate', u'always_empty': u'', u'form': u'INFU', u'brand': u'LORNOLAS', u'strength_3': u'', u'company': u'Windlas', u'unit': u''}

-- line #19544
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORNOLAS 250 (Windlas)',
	'L-Ornithine L-Aspartate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORNOLAS 250 (Windlas)'
);

-- line #19545
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5G', u'strength_2': u'10ML', u'substance': u'L-Ornithine L-Aspartate', u'always_empty': u'', u'form': u'INF', u'brand': u'ORNILIV', u'strength_3': u'', u'company': u'Life Med.', u'unit': u''}

-- line #19546
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'L-Ornithine L-Aspartate', u'always_empty': u'', u'form': u'INJ', u'brand': u'REJUVE', u'strength_3': u'', u'company': u'Pfiscar Ind.', u'unit': u''}

-- line #19547
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALGESIN 4 (ALEMBIC)',
	'LORNOXICAM',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALGESIN 4 (ALEMBIC)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALGESIN 8 (ALEMBIC)',
	'LORNOXICAM',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALGESIN 8 (ALEMBIC)'
);

-- line #19548
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXILOCAM 4 (AXIS LIFE)',
	'LORNOXICAM',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXILOCAM 4 (AXIS LIFE)'
);

-- line #19549
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAMRI 4 (ZYDUS SYNO.)',
	'LORNOXICAM',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAMRI 4 (ZYDUS SYNO.)'
);

-- line #19550
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAMRI 8 (ZYDUS SYNO.)',
	'LORNOXICAM',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAMRI 8 (ZYDUS SYNO.)'
);

-- line #19551
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'LORNOXICAM', u'always_empty': u'', u'form': u'INJ', u'brand': u'FLEXILOR', u'strength_3': u'', u'company': u'Glenmark', u'unit': u''}

-- line #19552
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLEXILOR 4 (Glenmark)',
	'LORNOXICAM',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLEXILOR 4 (Glenmark)'
);

-- line #19553
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLEXILOR 8 (Glenmark)',
	'LORNOXICAM',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLEXILOR 8 (Glenmark)'
);

-- line #19554
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FULACTIVE 8 (Ranbaxy)',
	'LORNOXICAM',
	'INJ',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FULACTIVE 8 (Ranbaxy)'
);

-- line #19555
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FULACTIVE 4 (Ranbaxy)',
	'LORNOXICAM',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FULACTIVE 4 (Ranbaxy)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FULACTIVE 8 (Ranbaxy)',
	'LORNOXICAM',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FULACTIVE 8 (Ranbaxy)'
);

-- line #19556
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLX-4 4 (Gufic Bio.)',
	'LORNOXICAM',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLX-4 4 (Gufic Bio.)'
);

-- line #19557
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLX-8 8 (Gufic Bio.)',
	'LORNOXICAM',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLX-8 8 (Gufic Bio.)'
);

-- line #19558
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLX 8 (Gufic Bio.)',
	'LORNOXICAM',
	'INJ',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLX 8 (Gufic Bio.)'
);

-- line #19559
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HINOCAM 4 (Intas)',
	'LORNOXICAM',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HINOCAM 4 (Intas)'
);

-- line #19560
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HINOCAM 8 (Intas)',
	'LORNOXICAM',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HINOCAM 8 (Intas)'
);

-- line #19561
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANAGESIC 8 (Wockhardt)',
	'LORNOXICAM',
	'INJ',
	gm.nullify_empty_string('8')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANAGESIC 8 (Wockhardt)'
);

-- line #19562
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANAGESIC 4 (Wockhardt)',
	'LORNOXICAM',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANAGESIC 4 (Wockhardt)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANAGESIC 8 (Wockhardt)',
	'LORNOXICAM',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANAGESIC 8 (Wockhardt)'
);

-- line #19563
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIRMA 4 (Galpha)',
	'LORNOXICAM',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIRMA 4 (Galpha)'
);

-- line #19564
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIRMA 8 (Galpha)',
	'LORNOXICAM',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIRMA 8 (Galpha)'
);

-- line #19565
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOFECAM 8 (Sun)',
	'LORNOXICAM',
	'INJ',
	gm.nullify_empty_string('8')::numeric,
	'mg/10ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOFECAM 8 (Sun)'
);

-- line #19566
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOFECAM 4 (SUN)',
	'LORNOXICAM',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOFECAM 4 (SUN)'
);

-- line #19567
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOFECAM 8 (SUN)',
	'LORNOXICAM',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOFECAM 8 (SUN)'
);

-- line #19568
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORCAM 4 (Pharmed)',
	'LORNOXICAM',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORCAM 4 (Pharmed)'
);

-- line #19569
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORCAM 8 (Pharmed)',
	'LORNOXICAM',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORCAM 8 (Pharmed)'
);

-- line #19570
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORFIT 8 (Alembic)',
	'LORNOXICAM',
	'INJ',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORFIT 8 (Alembic)'
);

-- line #19571
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORFIT 4 (Alembic)',
	'LORNOXICAM',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORFIT 4 (Alembic)'
);

-- line #19572
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORFIT 8 (Alembic)',
	'LORNOXICAM',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORFIT 8 (Alembic)'
);

-- line #19573
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'4', u'strength_2': u'', u'substance': u'LORNOXICAM', u'always_empty': u'', u'form': u'', u'brand': u'LORFLEX', u'strength_3': u'', u'company': u'Macleods', u'unit': u'mg'}

-- line #19574
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'8', u'strength_2': u'', u'substance': u'LORNOXICAM', u'always_empty': u'', u'form': u'', u'brand': u'LORFLEX', u'strength_3': u'', u'company': u'Macleods', u'unit': u'mg'}

-- line #19575
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORNACRAT-P 500 (CRATUS)',
	'LORNOXICAM',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORNACRAT-P 500 (CRATUS)'
);

-- line #19576
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORNACRAT 8 (CRATUS)',
	'LORNOXICAM',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORNACRAT 8 (CRATUS)'
);

-- line #19577
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORNA 16 (COSME F.)',
	'LORNOXICAM',
	'SR TAB',
	gm.nullify_empty_string('16')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORNA 16 (COSME F.)'
);

-- line #19578
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORNA 4 (Cosme F.)',
	'LORNOXICAM',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORNA 4 (Cosme F.)'
);

-- line #19579
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORNA 8 (Cosme F.)',
	'LORNOXICAM',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORNA 8 (Cosme F.)'
);

-- line #19580
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORNICAM 4 (Aristo)',
	'LORNOXICAM',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORNICAM 4 (Aristo)'
);

-- line #19581
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORNICAM 8 (Aristo)',
	'LORNOXICAM',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORNICAM 8 (Aristo)'
);

-- line #19582
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORNICA 4 (Micro)',
	'LORNOXICAM',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORNICA 4 (Micro)'
);

-- line #19583
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORNICA 8 (Micro)',
	'LORNOXICAM',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORNICA 8 (Micro)'
);

-- line #19584
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORNIFLEX 8 (Otsira)',
	'LORNOXICAM',
	'INJ',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORNIFLEX 8 (Otsira)'
);

-- line #19585
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORNIFLEX 4 (Lupin)',
	'LORNOXICAM',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORNIFLEX 4 (Lupin)'
);

-- line #19586
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORNIFLEX 8 (Lupin)',
	'LORNOXICAM',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORNIFLEX 8 (Lupin)'
);

-- line #19587
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORNISTAR 4 (Intra Lab)',
	'LORNOXICAM',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORNISTAR 4 (Intra Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORNISTAR 8 (Intra Lab)',
	'LORNOXICAM',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORNISTAR 8 (Intra Lab)'
);

-- line #19588
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORNOFAN 8 (EMAR)',
	'LORNOXICAM',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORNOFAN 8 (EMAR)'
);

-- line #19589
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORNOXI-M 8 (HETERO HC.)',
	'LORNOXICAM',
	'INJ',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORNOXI-M 8 (HETERO HC.)'
);

-- line #19590
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORNOXI 4 (HETERO HC.)',
	'LORNOXICAM',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORNOXI 4 (HETERO HC.)'
);

-- line #19591
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORNOXI 8 (HETERO HC.)',
	'LORNOXICAM',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORNOXI 8 (HETERO HC.)'
);

-- line #19592
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORNOXY 8 (ZODAK)',
	'LORNOXICAM',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORNOXY 8 (ZODAK)'
);

-- line #19593
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOR ORS 4 (Wanbury)',
	'LORNOXICAM',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOR ORS 4 (Wanbury)'
);

-- line #19594
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOROX 16 (DYOTA NU.)',
	'LORNOXICAM',
	'OD TAB',
	gm.nullify_empty_string('16')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOROX 16 (DYOTA NU.)'
);

-- line #19595
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOROX 4 (Dyota N.)',
	'LORNOXICAM',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOROX 4 (Dyota N.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOROX 8 (Dyota N.)',
	'LORNOXICAM',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOROX 8 (Dyota N.)'
);

-- line #19596
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORQRS 4 (Wanbury)',
	'LORNOXICAM',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORQRS 4 (Wanbury)'
);

-- line #19597
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORQRS 8 (Wanbury)',
	'LORNOXICAM',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORQRS 8 (Wanbury)'
);

-- line #19598
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORSAID 16 (Piramal Hc.)',
	'LORNOXICAM',
	'OD TAB',
	gm.nullify_empty_string('16')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORSAID 16 (Piramal Hc.)'
);

-- line #19599
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORSAID 4 (Nicholas)',
	'LORNOXICAM',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORSAID 4 (Nicholas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORSAID 8 (Nicholas)',
	'LORNOXICAM',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORSAID 8 (Nicholas)'
);

-- line #19600
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORSAID 8 (Piramal Hc.)',
	'LORNOXICAM',
	'VIAL',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORSAID 8 (Piramal Hc.)'
);

-- line #19601
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOXCAM 8 (AKESISS)',
	'LORNOXICAM',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOXCAM 8 (AKESISS)'
);

-- line #19602
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LRN 8 (Glenmark)',
	'LORNOXICAM',
	'INJ',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LRN 8 (Glenmark)'
);

-- line #19603
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LRN 4 (MAJESTA)',
	'LORNOXICAM',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LRN 4 (MAJESTA)'
);

-- line #19604
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LRN 8 (MAJESTA)',
	'LORNOXICAM',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LRN 8 (MAJESTA)'
);

-- line #19605
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LX FAST 4 (WANDER)',
	'LORNOXICAM',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LX FAST 4 (WANDER)'
);

-- line #19606
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAXILOR 4 (STEIGEN PH.)',
	'LORNOXICAM',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAXILOR 4 (STEIGEN PH.)'
);

-- line #19607
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAXILOR 8 (STEIGEN PH.)',
	'LORNOXICAM',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAXILOR 8 (STEIGEN PH.)'
);

-- line #19608
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MITILOR 4 (F D C)',
	'LORNOXICAM',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MITILOR 4 (F D C)'
);

-- line #19609
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MITILOR 8 (F D C)',
	'LORNOXICAM',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MITILOR 8 (F D C)'
);

-- line #19610
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEUCAM 8 (Lupin)',
	'LORNOXICAM',
	'INJ',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEUCAM 8 (Lupin)'
);

-- line #19611
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEUCAM 8 (Lupin)',
	'LORNOXICAM',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEUCAM 8 (Lupin)'
);

-- line #19612
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOXILOR 8 (Lyka)',
	'LORNOXICAM',
	'INJ',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOXILOR 8 (Lyka)'
);

-- line #19613
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NYOX 8 (Wallace)',
	'LORNOXICAM',
	'INJ',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NYOX 8 (Wallace)'
);

-- line #19614
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NYOX 4 (Wallace)',
	'LORNOXICAM',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NYOX 4 (Wallace)'
);

-- line #19615
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NYOX 8 (Wallace)',
	'LORNOXICAM',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NYOX 8 (Wallace)'
);

-- line #19616
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSTIFLEX 16 (Cadila Hc.)',
	'LORNOXICAM',
	'OD',
	gm.nullify_empty_string('16')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSTIFLEX 16 (Cadila Hc.)'
);

-- line #19617
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTILOP 25 (Active Hc.)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTILOP 25 (Active Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTILOP 50 (Active Hc.)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTILOP 50 (Active Hc.)'
);

-- line #19618
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALSARTAN 25 (Aristo)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALSARTAN 25 (Aristo)'
);

-- line #19619
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALSARTAN 50 (Aristo)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALSARTAN 50 (Aristo)'
);

-- line #19620
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'25', u'strength_2': u'50', u'substance': u'Losartan Pot.', u'always_empty': u'', u'form': u'', u'brand': u'ANGILOS', u'strength_3': u'', u'company': u'TALENT PH.', u'unit': u'mg'}

-- line #19621
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANGIZAAR 25 (Carsyon)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANGIZAAR 25 (Carsyon)'
);

-- line #19622
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANGIZAAR 50 (Carsyon)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANGIZAAR 50 (Carsyon)'
);

-- line #19623
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARBLOS 25 (AQUALIFE)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARBLOS 25 (AQUALIFE)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARBLOS 50 (AQUALIFE)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARBLOS 50 (AQUALIFE)'
);

-- line #19624
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASART 25 (Stadmed)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASART 25 (Stadmed)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASART 50 (Stadmed)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASART 50 (Stadmed)'
);

-- line #19625
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASORTAN 25 (AS PHARMA)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASORTAN 25 (AS PHARMA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASORTAN 50 (AS PHARMA)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASORTAN 50 (AS PHARMA)'
);

-- line #19626
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOSARTAN 25 (Biochem)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOSARTAN 25 (Biochem)'
);

-- line #19627
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOSARTAN 50 (Biochem)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOSARTAN 50 (Biochem)'
);

-- line #19628
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOZAAR 25 (Biological E.)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOZAAR 25 (Biological E.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOZAAR 50 (Biological E.)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOZAAR 50 (Biological E.)'
);

-- line #19629
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLOSAR 50 (Siomond)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLOSAR 50 (Siomond)'
);

-- line #19630
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BPCURE-25 25 (HBC LIFESCIENCE)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BPCURE-25 25 (HBC LIFESCIENCE)'
);

-- line #19631
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BPCURE-50 50 (HBC LIFESCIENCE)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BPCURE-50 50 (HBC LIFESCIENCE)'
);

-- line #19632
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDIKARE 25 (Jagsonpal)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDIKARE 25 (Jagsonpal)'
);

-- line #19633
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDIKARE 50 (Jagsonpal)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDIKARE 50 (Jagsonpal)'
);

-- line #19634
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COSART 25 (Cipla)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COSART 25 (Cipla)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COSART 50 (Cipla)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COSART 50 (Cipla)'
);

-- line #19635
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COVANCE 25 (Ranbaxy)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COVANCE 25 (Ranbaxy)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COVANCE 50 (Ranbaxy)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COVANCE 50 (Ranbaxy)'
);

-- line #19636
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COVANCE 25 (Ranbaxy Cv)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COVANCE 25 (Ranbaxy Cv)'
);

-- line #19637
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COVANCE 50 (Ranbaxy Cv)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COVANCE 50 (Ranbaxy Cv)'
);

-- line #19638
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CZAR 25 (VERITAZ)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CZAR 25 (VERITAZ)'
);

-- line #19639
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CZAR 50 (VERITAZ)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CZAR 50 (VERITAZ)'
);

-- line #19640
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CZARTAN 25 (Macleods)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CZARTAN 25 (Macleods)'
);

-- line #19641
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CZARTAN 50 (Macleods)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CZARTAN 50 (Macleods)'
);

-- line #19642
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELOPY 25 (Biocin Hc.)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELOPY 25 (Biocin Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELOPY 50 (Biocin Hc.)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELOPY 50 (Biocin Hc.)'
);

-- line #19643
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELSAR 25 (Elfin Ph.)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELSAR 25 (Elfin Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELSAR 50 (Elfin Ph.)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELSAR 50 (Elfin Ph.)'
);

-- line #19644
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELSPOT 50 (Indu D.)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELSPOT 50 (Indu D.)'
);

-- line #19645
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'25', u'strength_2': u'50;ML', u'substance': u'Losartan Pot.', u'always_empty': u'', u'form': u'TAB', u'brand': u'GIFTAN', u'strength_3': u'', u'company': u'Systopic', u'unit': u''}

-- line #19646
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GOSART 25 (CMGBT)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GOSART 25 (CMGBT)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GOSART 50 (CMGBT)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GOSART 50 (CMGBT)'
);

-- line #19647
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYPART 50 (NEISS)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYPART 50 (NEISS)'
);

-- line #19648
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANXES 25 (AAMORB(XEENA))',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANXES 25 (AAMORB(XEENA))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANXES 50 (AAMORB(XEENA))',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANXES 50 (AAMORB(XEENA))'
);

-- line #19649
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LARA 25 (Alkem)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LARA 25 (Alkem)'
);

-- line #19650
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LARA 50 (Alkem)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LARA 50 (Alkem)'
);

-- line #19651
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LARTAN 25 (AVINASH)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LARTAN 25 (AVINASH)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LARTAN 50 (AVINASH)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LARTAN 50 (AVINASH)'
);

-- line #19652
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIBITZ 25 (BEATZ LIFESCI.)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIBITZ 25 (BEATZ LIFESCI.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIBITZ 50 (BEATZ LIFESCI.)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIBITZ 50 (BEATZ LIFESCI.)'
);

-- line #19653
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50', u'strength_2': u'', u'substance': u'Losartan Pot.', u'always_empty': u'', u'form': u'', u'brand': u'LOPULSE-50', u'strength_3': u'', u'company': u'HAMPS BIO', u'unit': u'mg'}

-- line #19654
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORIL 50 (ESSWEIL)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORIL 50 (ESSWEIL)'
);

-- line #19655
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORSAVE 25 (ERIS LIFE)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORSAVE 25 (ERIS LIFE)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORSAVE 50 (ERIS LIFE)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORSAVE 50 (ERIS LIFE)'
);

-- line #19656
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSAGARD 25 (Lupin)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSAGARD 25 (Lupin)'
);

-- line #19657
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSAGARD 50 (Lupin)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSAGARD 50 (Lupin)'
);

-- line #19658
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSAIN 50 (SAIN)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSAIN 50 (SAIN)'
);

-- line #19659
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSAKIND 25 (MANKIND)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSAKIND 25 (MANKIND)'
);

-- line #19660
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSAKIND 50 (Mankind)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSAKIND 50 (Mankind)'
);

-- line #19661
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSAK 25 (Riasma Life)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSAK 25 (Riasma Life)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSAK 50 (Riasma Life)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSAK 50 (Riasma Life)'
);

-- line #19662
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSALIFE 25 (Torrent)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSALIFE 25 (Torrent)'
);

-- line #19663
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSALIFE 50 (Torrent)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSALIFE 50 (Torrent)'
);

-- line #19664
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSAMAX 25 (Indoco Rem.)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSAMAX 25 (Indoco Rem.)'
);

-- line #19665
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSAMAX 50 (Indoco Rem.)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSAMAX 50 (Indoco Rem.)'
);

-- line #19666
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSAN 25 (Kopran)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSAN 25 (Kopran)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSAN 50 (Kopran)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSAN 50 (Kopran)'
);

-- line #19667
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSAPOT 25 (QCHECK)',
	'Losartan Pot.',
	'FC TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSAPOT 25 (QCHECK)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSAPOT 50 (QCHECK)',
	'Losartan Pot.',
	'FC TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSAPOT 50 (QCHECK)'
);

-- line #19668
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSAREN 25 (ARCUS LABS)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSAREN 25 (ARCUS LABS)'
);

-- line #19669
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSAREN 50 (ARCUS LABS)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSAREN 50 (ARCUS LABS)'
);

-- line #19670
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSAR 100 (Unichem)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSAR 100 (Unichem)'
);

-- line #19671
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSAR 25 (Unichem)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSAR 25 (Unichem)'
);

-- line #19672
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSAR 50 (Unichem)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSAR 50 (Unichem)'
);

-- line #19673
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSARTAS 100 (Intas)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSARTAS 100 (Intas)'
);

-- line #19674
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSARTAS 25 (Intas)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSARTAS 25 (Intas)'
);

-- line #19675
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSARTAS 50 (Intas)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSARTAS 50 (Intas)'
);

-- line #19676
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSARZED-K 25 (Zota)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSARZED-K 25 (Zota)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSARZED-K 50 (Zota)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSARZED-K 50 (Zota)'
);

-- line #19677
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSASUN 25 (Sunij)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSASUN 25 (Sunij)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSASUN 50 (Sunij)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSASUN 50 (Sunij)'
);

-- line #19678
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSATEC 25 (Rpg Life)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSATEC 25 (Rpg Life)'
);

-- line #19679
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSATEC 50 (Rpg Life)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSATEC 50 (Rpg Life)'
);

-- line #19680
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSATRUST 25 (Centaur)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSATRUST 25 (Centaur)'
);

-- line #19681
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSATRUST 50 (Centaur)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSATRUST 50 (Centaur)'
);

-- line #19682
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSAVAS 25 (MANO)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSAVAS 25 (MANO)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSAVAS 50 (MANO)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSAVAS 50 (MANO)'
);

-- line #19683
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSAVIK 25 (ANVIK BIO.)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSAVIK 25 (ANVIK BIO.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSAVIK 50 (ANVIK BIO.)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSAVIK 50 (ANVIK BIO.)'
);

-- line #19684
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSCARD 25 (Intra Lab)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSCARD 25 (Intra Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSCARD 50 (Intra Lab)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSCARD 50 (Intra Lab)'
);

-- line #19685
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSCOM 25 (Comed)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSCOM 25 (Comed)'
);

-- line #19686
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSCOM 50 (Comed)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSCOM 50 (Comed)'
);

-- line #19687
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSFIRST 25 (SINSAN PH.)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSFIRST 25 (SINSAN PH.)'
);

-- line #19688
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSFIRST 50 (SINSAN PH.)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSFIRST 50 (SINSAN PH.)'
);

-- line #19689
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSIUM 25 (Cadila Ph.)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSIUM 25 (Cadila Ph.)'
);

-- line #19690
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSIUM 50 (Cadila Ph.)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSIUM 50 (Cadila Ph.)'
);

-- line #19691
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSPOT 25 (Ind-Swift)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSPOT 25 (Ind-Swift)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSPOT 50 (Ind-Swift)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSPOT 50 (Ind-Swift)'
);

-- line #19692
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSSAR 25 (Finecure)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSSAR 25 (Finecure)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSSAR 50 (Finecure)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSSAR 50 (Finecure)'
);

-- line #19693
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSSI 25 (Cadex Lab)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSSI 25 (Cadex Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSSI 50 (Cadex Lab)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSSI 50 (Cadex Lab)'
);

-- line #19694
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSTAT 25 (Blue Cross)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSTAT 25 (Blue Cross)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSTAT 50 (Blue Cross)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSTAT 50 (Blue Cross)'
);

-- line #19695
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LO 25 (EAST WEST)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LO 25 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LO 50 (EAST WEST)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LO 50 (EAST WEST)'
);

-- line #19696
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOTACE 25 (Kapl)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOTACE 25 (Kapl)'
);

-- line #19697
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOTACE 50 (Kapl)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOTACE 50 (Kapl)'
);

-- line #19698
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOTAK 25 (Caplet Ind.)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOTAK 25 (Caplet Ind.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOTAK 50 (Caplet Ind.)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOTAK 50 (Caplet Ind.)'
);

-- line #19699
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOTAN 25 (Taurus Lab)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOTAN 25 (Taurus Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOTAN 50 (Taurus Lab)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOTAN 50 (Taurus Lab)'
);

-- line #19700
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOTAS 50 (TASMED)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOTAS 50 (TASMED)'
);

-- line #19701
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOTEN 25 (Indica)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOTEN 25 (Indica)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOTEN 50 (Indica)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOTEN 50 (Indica)'
);

-- line #19702
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOTINVAS 25 (Badrivas)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOTINVAS 25 (Badrivas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOTINVAS 50 (Badrivas)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOTINVAS 50 (Badrivas)'
);

-- line #19703
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOT 25 (Piramal Hc.)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOT 25 (Piramal Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOT 50 (Piramal Hc.)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOT 50 (Piramal Hc.)'
);

-- line #19704
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOT 25 (Piramal Hc.)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOT 25 (Piramal Hc.)'
);

-- line #19705
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOT 50 (Piramal Hc.)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOT 50 (Piramal Hc.)'
);

-- line #19706
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOZITAN 25 (Wockhardt)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOZITAN 25 (Wockhardt)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOZITAN 50 (Wockhardt)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOZITAN 50 (Wockhardt)'
);

-- line #19707
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDILOS 25 (MEDISYS)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDILOS 25 (MEDISYS)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDILOS 50 (MEDISYS)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDILOS 50 (MEDISYS)'
);

-- line #19708
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYOTAN 25 (Unique)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYOTAN 25 (Unique)'
);

-- line #19709
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYOTAN 50 (Unique)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYOTAN 50 (Unique)'
);

-- line #19710
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUSAR 25 (Emcure)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUSAR 25 (Emcure)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUSAR 50 (Emcure)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUSAR 50 (Emcure)'
);

-- line #19711
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSART 25 (Intra(INVISION))',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSART 25 (Intra(INVISION))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSART 50 (Intra(INVISION))',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSART 50 (Intra(INVISION))'
);

-- line #19712
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRESARTAN 25 (Ipca)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRESARTAN 25 (Ipca)'
);

-- line #19713
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRESARTAN 50 (Ipca)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRESARTAN 50 (Ipca)'
);

-- line #19714
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REGULATE 25 (Olcare)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REGULATE 25 (Olcare)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REGULATE 50 (Olcare)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REGULATE 50 (Olcare)'
);

-- line #19715
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REPACE 25 (Sun)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REPACE 25 (Sun)'
);

-- line #19716
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REPACE 50 (Sun)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REPACE 50 (Sun)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REPACE 100 (Sun)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REPACE 100 (Sun)'
);

-- line #19717
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESILO 25 (Dr.Reddy''S)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESILO 25 (Dr.Reddy''S)'
);

-- line #19718
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESILO 50 (Dr.Reddy''S)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESILO 50 (Dr.Reddy''S)'
);

-- line #19719
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIGARD 25 (VHB)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIGARD 25 (VHB)'
);

-- line #19720
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIGARD 50 (VHB)',
	'Losartan Pot.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIGARD 50 (VHB)'
);

-- line #19721
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOTEFLAM 5 (Protec)',
	'Loteprednol Etabonate',
	'DPS',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOTEFLAM 5 (Protec)'
);

-- line #19722
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOTEL 2 (ILLUMA)',
	'Loteprednol Etabonate',
	'LS DPS',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOTEL 2 (ILLUMA)'
);

-- line #19723
-- ignoring line: field [strength_1] not numeric: >>>100MCG(0.1<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100MCG(0.1', u'strength_2': u'', u'substance': u'Loteprednol Etabonate', u'always_empty': u'', u'form': u'NASAL SPRAY', u'brand': u'LOTENASE', u'strength_3': u'', u'company': u'Ajanta Ph.', u'unit': u'%)'}

-- line #19724
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOTEPRED 5 (Milmet)',
	'Loteprednol Etabonate',
	'DPS',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOTEPRED 5 (Milmet)'
);

-- line #19725
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOTEPRED 0.2 (SUN)',
	'Loteprednol Etabonate',
	'LS EYE DPS',
	gm.nullify_empty_string('0.2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOTEPRED 0.2 (SUN)'
);

-- line #19726
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Loteprednol Etabonate', u'always_empty': u'', u'form': u'', u'brand': u'LPRED', u'strength_3': u'', u'company': u'Allergan', u'unit': u''}

-- line #19727
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZTATIN 10 (Sun)',
	'Lovastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZTATIN 10 (Sun)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZTATIN 20 (Sun)',
	'Lovastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZTATIN 20 (Sun)'
);

-- line #19728
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELSTATIN 10 (Glenmark)',
	'Lovastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELSTATIN 10 (Glenmark)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELSTATIN 20 (Glenmark)',
	'Lovastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELSTATIN 20 (Glenmark)'
);

-- line #19729
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELSTIN 10 (EAST WEST)',
	'Lovastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELSTIN 10 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELSTIN 20 (EAST WEST)',
	'Lovastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELSTIN 20 (EAST WEST)'
);

-- line #19730
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAVOLIP 10 (Nicholas)',
	'Lovastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAVOLIP 10 (Nicholas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAVOLIP 20 (Nicholas)',
	'Lovastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAVOLIP 20 (Nicholas)'
);

-- line #19731
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LESTRIC 10 (Solus)',
	'Lovastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LESTRIC 10 (Solus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LESTRIC 20 (Solus)',
	'Lovastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LESTRIC 20 (Solus)'
);

-- line #19732
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPDIP 20 (Kee Ph.)',
	'Lovastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPDIP 20 (Kee Ph.)'
);

-- line #19733
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPISTAT 10 (Rpg Life)',
	'Lovastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPISTAT 10 (Rpg Life)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPISTAT 20 (Rpg Life)',
	'Lovastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPISTAT 20 (Rpg Life)'
);

-- line #19734
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOCHOL 10 (Carsyon)',
	'Lovastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOCHOL 10 (Carsyon)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOCHOL 20 (Carsyon)',
	'Lovastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOCHOL 20 (Carsyon)'
);

-- line #19735
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOLIPOZ 20 (Olcare)',
	'Lovastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOLIPOZ 20 (Olcare)'
);

-- line #19736
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSTATIN 10 (Dr.Reddy''S)',
	'Lovastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSTATIN 10 (Dr.Reddy''S)'
);

-- line #19737
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSTATIN 20 (Dr.Reddy''S)',
	'Lovastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSTATIN 20 (Dr.Reddy''S)'
);

-- line #19738
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOTIN 10 (Intas)',
	'Lovastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOTIN 10 (Intas)'
);

-- line #19739
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOTIN 20 (Intas)',
	'Lovastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOTIN 20 (Intas)'
);

-- line #19740
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOVACARD 20 (Cipla)',
	'Lovastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOVACARD 20 (Cipla)'
);

-- line #19741
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOVADAC 10 (Zydus A.)',
	'Lovastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOVADAC 10 (Zydus A.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOVADAC 20 (Zydus A.)',
	'Lovastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOVADAC 20 (Zydus A.)'
);

-- line #19742
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOVALIP 10 (Cadila Ph.)',
	'Lovastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOVALIP 10 (Cadila Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOVALIP 20 (Cadila Ph.)',
	'Lovastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOVALIP 20 (Cadila Ph.)'
);

-- line #19743
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOVAMEG 10 (Alembic)',
	'Lovastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOVAMEG 10 (Alembic)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOVAMEG 20 (Alembic)',
	'Lovastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOVAMEG 20 (Alembic)'
);

-- line #19744
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOVASTAT 20 (Torrent)',
	'Lovastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOVASTAT 20 (Torrent)'
);

-- line #19745
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOVASTROL 20 (Medley)',
	'Lovastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOVASTROL 20 (Medley)'
);

-- line #19746
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOVA 10 (Mano)',
	'Lovastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOVA 10 (Mano)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOVA 20 (Mano)',
	'Lovastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOVA 20 (Mano)'
);

-- line #19747
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOVATIN 10 (Intas)',
	'Lovastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOVATIN 10 (Intas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOVATIN 20 (Intas)',
	'Lovastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOVATIN 20 (Intas)'
);

-- line #19748
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOVEX 10 (Lupin)',
	'Lovastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOVEX 10 (Lupin)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOVEX 20 (Lupin)',
	'Lovastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOVEX 20 (Lupin)'
);

-- line #19749
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRO HDL 10 (Wockhardt)',
	'Lovastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRO HDL 10 (Wockhardt)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRO HDL 20 (Wockhardt)',
	'Lovastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRO HDL 20 (Wockhardt)'
);

-- line #19750
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RECOL 10 (Themis)',
	'Lovastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RECOL 10 (Themis)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RECOL 20 (Themis)',
	'Lovastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RECOL 20 (Themis)'
);

-- line #19751
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOXABOL 10 (K.C. Lab)',
	'Loxapine',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOXABOL 10 (K.C. Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOXABOL 25 (K.C. Lab)',
	'Loxapine',
	'CAP',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOXABOL 25 (K.C. Lab)'
);

-- line #19752
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOXAPAC 10 (Wyeth)',
	'Loxapine',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg(SUCCINATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOXAPAC 10 (Wyeth)'
);

-- line #19753
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOXAPAC 25 (Wyeth)',
	'Loxapine',
	'CAP',
	gm.nullify_empty_string('25')::numeric,
	'mg(SUCCINATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOXAPAC 25 (Wyeth)'
);

-- line #19754
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOXAPAC 50 (Wyeth)',
	'Loxapine',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg(SUCCINATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOXAPAC 50 (Wyeth)'
);

-- line #19755
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOXAPAC-C 25 (Wyeth)',
	'Loxapine',
	'LIQ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML(HCL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOXAPAC-C 25 (Wyeth)'
);

-- line #19756
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOXEP 10 (Tripada Hc.)',
	'Loxapine',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOXEP 10 (Tripada Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOXEP 25 (Tripada Hc.)',
	'Loxapine',
	'CAP',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOXEP 25 (Tripada Hc.)'
);

-- line #19757
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'60', u'strength_2': u'', u'substance': u'LOXOPROFEN SOD.', u'always_empty': u'', u'form': u'', u'brand': u'LOXOMAC', u'strength_3': u'', u'company': u'Macleods', u'unit': u'mg'}

-- line #19758
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'24MCG', u'strength_2': u'', u'substance': u'LUBIPROSTONE', u'always_empty': u'', u'form': u'CAP', u'brand': u'LUBOWEL', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #19759
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'8MCG', u'strength_2': u'', u'substance': u'LUBIPROSTONE', u'always_empty': u'', u'form': u'CAP', u'brand': u'LUBOWEL', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #19760
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LULIFIN 1 (Ranbaxy)',
	'LULICONAZOLE',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LULIFIN 1 (Ranbaxy)'
);

-- line #19761
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'WITH MULTIVITAMIN', u'strength_2': u'', u'substance': u'LYCOPENE', u'always_empty': u'', u'form': u'SYR', u'brand': u'LEXIBION PLUS', u'strength_3': u'', u'company': u'Cadex Lab', u'unit': u''}

-- line #19762
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'LYCOPENE', u'always_empty': u'', u'form': u'CAP', u'brand': u'LYCOAGE', u'strength_3': u'', u'company': u'ALLENGE', u'unit': u''}

-- line #19763
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'WITH ANTIOXIDANT MULTIVITAMIN', u'strength_2': u'', u'substance': u'LYCOPENE', u'always_empty': u'', u'form': u'CAP', u'brand': u'LYCO AMV', u'strength_3': u'', u'company': u'CIVANSH LIFESCI.', u'unit': u''}

-- line #19764
-- ignoring line: field [strength_1] not numeric: >>>WITH VITAMINS<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'WITH VITAMINS', u'strength_2': u'', u'substance': u'LYCOPENE', u'always_empty': u'', u'form': u'SYR', u'brand': u'LYCOBEL', u'strength_3': u'', u'company': u'BLUBELL', u'unit': u'MULTIMINERALS'}

-- line #19765
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'MULTIVITAMIN', u'strength_2': u'', u'substance': u'LYCOPENE', u'always_empty': u'', u'form': u'SYR', u'brand': u'LYCO-FIRST', u'strength_3': u'', u'company': u'Intra(INVISION)', u'unit': u''}

-- line #19766
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYCOMAN 250 (ROSE LABS)',
	'LYCOPENE',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'SP.VITMAINS'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYCOMAN 250 (ROSE LABS)'
);

-- line #19767
-- ignoring line: field [strength_1] not numeric: >>>1000MCG (WITH VIT.A<<<
-- {u'list_of_values_of_unknown_fields': [u'ZINC GL.', u'MANGANESE', u'COPPER', u'VIT.B2', u'VIT.B6)', u'', u'', u'', u''], u'strength_1': u'1000MCG (WITH VIT.A', u'strength_2': u'', u'substance': u'LYCOPENE', u'always_empty': u'', u'form': u'SYR', u'brand': u'LYCORED', u'strength_3': u'', u'company': u'Jagsonpal', u'unit': u'E'}

-- line #19768
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2000MCG', u'strength_2': u'', u'substance': u'LYCOPENE', u'always_empty': u'', u'form': u'CAP', u'brand': u'LYCORICH PLUS', u'strength_3': u'', u'company': u'Zee Lab', u'unit': u''}

-- line #19769
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'LYCOPENE', u'always_empty': u'', u'form': u'LIQ', u'brand': u'LYMAN', u'strength_3': u'', u'company': u'ROSE LABS', u'unit': u''}

-- line #19770
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'WITH VITAMINS', u'strength_2': u'', u'substance': u'LYCOPENE', u'always_empty': u'', u'form': u'TAB', u'brand': u'LYMAN', u'strength_3': u'', u'company': u'ROSE LABS', u'unit': u''}

-- line #19771
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000MCG - WITH ANTIOXIDANTS', u'strength_2': u'', u'substance': u'LYCOPENE', u'always_empty': u'', u'form': u'XL CAP', u'brand': u'MCM', u'strength_3': u'', u'company': u'OREVA DARMO.', u'unit': u''}

-- line #19772
-- ignoring line: field [strength_1] not numeric: >>>WITH LUTEIN<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'WITH LUTEIN', u'strength_2': u'', u'substance': u'LYCOPENE', u'always_empty': u'', u'form': u'SG CAP', u'brand': u'NISULTIN', u'strength_3': u'', u'company': u'NEISS', u'unit': u'GREEN TEA EXTR. GRAPSEED'}

-- line #19773
-- ignoring line: field [strength_1] not numeric: >>>WITH CAL.<<<
-- {u'list_of_values_of_unknown_fields': [u'ZINC', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'WITH CAL.', u'strength_2': u'', u'substance': u'LYCOPENE', u'always_empty': u'', u'form': u'POWD', u'brand': u'OMAATO', u'strength_3': u'', u'company': u'Centaur', u'unit': u'VITAMINS'}

-- line #19774
-- ignoring line: field [strength_1] not numeric: >>>WITH VIT.A<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'WITH VIT.A', u'strength_2': u'', u'substance': u'LYCOPENE', u'always_empty': u'', u'form': u'CAP', u'brand': u'OVIT-L', u'strength_3': u'', u'company': u'Tripada BIO.', u'unit': u'ANTIOXIDANT'}

-- line #19775
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'ANTIOXIDANT', u'strength_2': u'', u'substance': u'LYCOPENE', u'always_empty': u'', u'form': u'CAP', u'brand': u'OXYBID', u'strength_3': u'', u'company': u'AASHRAY', u'unit': u''}

-- line #19776
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2000MCG( WITH ANTIOXIDANTS)', u'strength_2': u'', u'substance': u'LYCOPENE', u'always_empty': u'', u'form': u'CAP', u'brand': u'PINELEX PLUS', u'strength_3': u'', u'company': u'AXYZEN LIFE', u'unit': u''}

-- line #19777
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'WITH ANTIOXIDANT', u'strength_2': u'', u'substance': u'LYCOPENE', u'always_empty': u'', u'form': u'SYR', u'brand': u'PINELEX', u'strength_3': u'', u'company': u'AXYZEN LIFE', u'unit': u''}

-- line #19778
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OIRGAMETRIL 5 (Infar)',
	'Lynestrenol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OIRGAMETRIL 5 (Infar)'
);

-- line #19779
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMMUOREL % 5 (RELIANCE BIO.)',
	'Lyophilised Human Immunoglobulin',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'%(HUMAN IMMUNOGLOBULIN (PH4) FOR INTRAVENOUS)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMMUOREL % 5 (RELIANCE BIO.)'
);

-- line #19780
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5G(HUMAN IMMUNOGLOBULIN (PH4) FOR INTRAVENOUS)', u'strength_2': u'', u'substance': u'Lyophilised Human Immunoglobulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'MEGLOB GM', u'strength_3': u'', u'company': u'Synergy D.', u'unit': u''}

-- line #19781
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAMIFOS 30 (Dabur Ph.)',
	'Lypholised Pamidronate',
	'INJ',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAMIFOS 30 (Dabur Ph.)'
);

-- line #19782
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAMIFOS 60 (Dabur Ph.)',
	'Lypholised Pamidronate',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAMIFOS 60 (Dabur Ph.)'
);

-- line #19783
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAMIFOS 90 (Dabur Ph.)',
	'Lypholised Pamidronate',
	'INJ',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAMIFOS 90 (Dabur Ph.)'
);

-- line #19784
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5 BILL.', u'strength_2': u'', u'substance': u'Lypholized Lactobacillus Acidophillus', u'always_empty': u'', u'form': u'F. CAP', u'brand': u'LACTROL', u'strength_3': u'', u'company': u'R.B.', u'unit': u''}

-- line #19785
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10 BILL.', u'strength_2': u'SAC.', u'substance': u'Lypholized Lactobacillus Acidophillus', u'always_empty': u'', u'form': u'F. SAC', u'brand': u'LACTROL', u'strength_3': u'', u'company': u'R.B.', u'unit': u''}

-- line #19786
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYCIMAX 150 (Lupin)',
	'LYSINE HCL.',
	'TUBE',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYCIMAX 150 (Lupin)'
);

-- line #19787
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANOREST 40 (NATCO PH.)',
	'MAGESTEROL ACETATE',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANOREST 40 (NATCO PH.)'
);

-- line #19788
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILK OF MAGNESIA 85 (Dey''S)',
	'Mag.Hydrox.',
	'LIQ',
	gm.nullify_empty_string('85')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILK OF MAGNESIA 85 (Dey''S)'
);

-- line #19789
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILK OF MAGNESIA 310 (Dey''S)',
	'Mag.Hydrox.',
	'TAB',
	gm.nullify_empty_string('310')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILK OF MAGNESIA 310 (Dey''S)'
);

-- line #19790
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMNICID 185 (Cipla)',
	'Mag.Hydrox.',
	'GEL (MINT)',
	gm.nullify_empty_string('185')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMNICID 185 (Cipla)'
);

-- line #19791
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACORATE 200 (Sun)',
	'MAGNESIUM VALPROATE PROLONGED',
	'CR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACORATE 200 (Sun)'
);

-- line #19792
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACORATE 400 (Sun)',
	'Magnesium VALPROAT',
	'CR',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACORATE 400 (Sun)'
);

-- line #19793
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACORATE 500 (SUN)',
	'Magnesium VALPROAT',
	'CR TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg(PROLONGED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACORATE 500 (SUN)'
);

-- line #19794
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACORATE 200 (Sun)',
	'Magnesium VALPROAT',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACORATE 200 (Sun)'
);

-- line #19795
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACORATE 400 (Sun)',
	'Magnesium VALPROAT',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACORATE 400 (Sun)'
);

-- line #19796
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAGNEON 50 (Neon)',
	'Mag.Sulph',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAGNEON 50 (Neon)'
);

-- line #19797
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50', u'strength_2': u'', u'substance': u'Mag.Sulph', u'always_empty': u'', u'form': u'', u'brand': u'MAGNEON', u'strength_3': u'', u'company': u'Neon', u'unit': u'%W/V'}

-- line #19798
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Mag.Sulph', u'always_empty': u'', u'form': u'INJ', u'brand': u'MAGNISTA', u'strength_3': u'', u'company': u'Emcure', u'unit': u''}

-- line #19799
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'MALAR LACTATE', u'always_empty': u'', u'form': u'INF', u'brand': u'MOLAR', u'strength_3': u'', u'company': u'Mount M.', u'unit': u''}

-- line #19800
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'MALAR LACTATE', u'always_empty': u'', u'form': u'INF', u'brand': u'MOLAR LACTATE', u'strength_3': u'', u'company': u'Albert D.', u'unit': u''}

-- line #19801
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'MALAR LACTATE', u'always_empty': u'', u'form': u'', u'brand': u'MOLAR LACTATE', u'strength_3': u'', u'company': u'Mount M.', u'unit': u''}

-- line #19802
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'150MCG', u'strength_2': u'', u'substance': u'Malogramostim', u'always_empty': u'', u'form': u'INJ', u'brand': u'LEUCOMAX', u'strength_3': u'', u'company': u'Novartis', u'unit': u''}

-- line #19803
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'300MCG', u'strength_2': u'', u'substance': u'Malogramostim', u'always_empty': u'', u'form': u'INJ', u'brand': u'LEUCOMAX', u'strength_3': u'', u'company': u'Novartis', u'unit': u''}

-- line #19804
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'450MCG', u'strength_2': u'', u'substance': u'Malogramostim', u'always_empty': u'', u'form': u'INJ', u'brand': u'LEUCOMAX', u'strength_3': u'', u'company': u'Novartis', u'unit': u''}

-- line #19805
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'10% MANNITOL 10 (K.K.)',
	'MANNITOL',
	'INF',
	gm.nullify_empty_string('10')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '10% MANNITOL 10 (K.K.)'
);

-- line #19806
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'10% MANNITOL 10 (TABLETS I.)',
	'MANNITOL',
	'INF',
	gm.nullify_empty_string('10')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '10% MANNITOL 10 (TABLETS I.)'
);

-- line #19807
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'20% MANNITOL 20 (Albert D.)',
	'MANNITOL',
	'INF',
	gm.nullify_empty_string('20')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '20% MANNITOL 20 (Albert D.)'
);

-- line #19808
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'20% MANNITOL 20 (Cadila Ph.)',
	'MANNITOL',
	'INF',
	gm.nullify_empty_string('20')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '20% MANNITOL 20 (Cadila Ph.)'
);

-- line #19809
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'20% MANNITOL 20 (Claris L.)',
	'MANNITOL',
	'INF',
	gm.nullify_empty_string('20')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '20% MANNITOL 20 (Claris L.)'
);

-- line #19810
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'20% MANNITOL 20 (Mount M.)',
	'MANNITOL',
	'INF',
	gm.nullify_empty_string('20')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '20% MANNITOL 20 (Mount M.)'
);

-- line #19811
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'20% MANNITOL 20 (Parenteral)',
	'MANNITOL',
	'INF',
	gm.nullify_empty_string('20')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '20% MANNITOL 20 (Parenteral)'
);

-- line #19812
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'20% MANNITOL 20 (Sipra Rem.)',
	'MANNITOL',
	'INF',
	gm.nullify_empty_string('20')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '20% MANNITOL 20 (Sipra Rem.)'
);

-- line #19813
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'20% MANNITOL 20 (TABLETS I.)',
	'MANNITOL',
	'INF',
	gm.nullify_empty_string('20')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '20% MANNITOL 20 (TABLETS I.)'
);

-- line #19814
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'20% MANNTIOL 20 (K.K.)',
	'MANNITOL',
	'INF',
	gm.nullify_empty_string('20')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '20% MANNTIOL 20 (K.K.)'
);

-- line #19815
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'5% MANNITOL 5 (K.K.)',
	'MANNITOL',
	'INF',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '5% MANNITOL 5 (K.K.)'
);

-- line #19816
-- ignoring line: field [strength_1] not numeric: >>>10G<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10G', u'strength_2': u'', u'substance': u'MANNITOL', u'always_empty': u'', u'form': u'INJ', u'brand': u'KRATOL', u'strength_3': u'', u'company': u'MOLEKULE', u'unit': u'10G/100ML'}

-- line #19817
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICROTOL 20 (Micro Labs)',
	'MANNITOL',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICROTOL 20 (Micro Labs)'
);

-- line #19818
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'MANNITOL', u'always_empty': u'', u'form': u'', u'brand': u'NEUROTOL-M', u'strength_3': u'', u'company': u'VENUS REM.', u'unit': u''}

-- line #19819
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JOCAL 1000 (D.R.John''S)',
	'M.C.H.C.',
	'TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JOCAL 1000 (D.R.John''S)'
);

-- line #19820
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000', u'strength_2': u'0.5ML', u'substance': u'MEASLES VIRUS VACCINE', u'always_empty': u'', u'form': u'VAC)', u'brand': u'M-VAC INJ(MEASLES', u'strength_3': u'', u'company': u'Serum Inst.', u'unit': u''}

-- line #19821
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRODOZOLE 100 (Shalaks)',
	'Mebendazole',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRODOZOLE 100 (Shalaks)'
);

-- line #19822
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EBEN 100 (Gufic Bio.)',
	'Mebendazole',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EBEN 100 (Gufic Bio.)'
);

-- line #19823
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EBEN 100 (Gufic Bio.)',
	'Mebendazole',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EBEN 100 (Gufic Bio.)'
);

-- line #19824
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELMIN 100 (Yash Ph.)',
	'Mebendazole',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELMIN 100 (Yash Ph.)'
);

-- line #19825
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELMIN 100 (Yash Ph.)',
	'Mebendazole',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELMIN 100 (Yash Ph.)'
);

-- line #19826
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELZOL 100 (Camlin)',
	'Mebendazole',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELZOL 100 (Camlin)'
);

-- line #19827
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HELEX 100 (Shaimil)',
	'Mebendazole',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HELEX 100 (Shaimil)'
);

-- line #19828
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HELMINTOL 100 (Medley)',
	'Mebendazole',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HELMINTOL 100 (Medley)'
);

-- line #19829
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HELMINTOL 100 (Medley)',
	'Mebendazole',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HELMINTOL 100 (Medley)'
);

-- line #19830
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYBEN 100 (Trio Rem.)',
	'Mebendazole',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYBEN 100 (Trio Rem.)'
);

-- line #19831
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IDIBEND 100 (Idpl)',
	'Mebendazole',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IDIBEND 100 (Idpl)'
);

-- line #19832
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IDIBEND 100 (Idpl)',
	'Mebendazole',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IDIBEND 100 (Idpl)'
);

-- line #19833
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KIT KAT 100 (Mapra)',
	'Mebendazole',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KIT KAT 100 (Mapra)'
);

-- line #19834
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KIT KAT 100 (Mapra)',
	'Mebendazole',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KIT KAT 100 (Mapra)'
);

-- line #19835
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVASOL-M 100 (Meridian)',
	'Mebendazole',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVASOL-M 100 (Meridian)'
);

-- line #19836
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUPIMEB 100 (Lupin)',
	'Mebendazole',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUPIMEB 100 (Lupin)'
);

-- line #19837
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEBAZOLE 100 (Torrent)',
	'Mebendazole',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEBAZOLE 100 (Torrent)'
);

-- line #19838
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEBEX 200 (Cipla)',
	'Mebendazole',
	'SAC',
	gm.nullify_empty_string('200')::numeric,
	'mg/5G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEBEX 200 (Cipla)'
);

-- line #19839
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEBEX 100 (Cipla)',
	'Mebendazole',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEBEX 100 (Cipla)'
);

-- line #19840
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEBEX 100 (Cipla)',
	'Mebendazole',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEBEX 100 (Cipla)'
);

-- line #19841
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDIWORM 100 (Medico)',
	'Mebendazole',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDIWORM 100 (Medico)'
);

-- line #19842
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MENDAZOLE 100 (GSK)',
	'Mebendazole',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MENDAZOLE 100 (GSK)'
);

-- line #19843
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOMEX 500 (Neon)',
	'Mebendazole',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOMEX 500 (Neon)'
);

-- line #19844
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTELMIN 100 (Ethnor)',
	'Mebendazole',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTELMIN 100 (Ethnor)'
);

-- line #19845
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTELMIN 100 (Ethnor)',
	'Mebendazole',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTELMIN 100 (Ethnor)'
);

-- line #19846
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARID 200 (Systopic)',
	'Mebendazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARID 200 (Systopic)'
);

-- line #19847
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COLOSPA 135 (Solvay Ph.)',
	'Mebeverine',
	'TAB',
	gm.nullify_empty_string('135')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COLOSPA 135 (Solvay Ph.)'
);

-- line #19848
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEBALFA 200 (Torrent)',
	'Mebeverine Hcl.',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEBALFA 200 (Torrent)'
);

-- line #19849
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEBIZ 200 (Sun)',
	'Mebeverine Hcl.',
	'SR CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEBIZ 200 (Sun)'
);

-- line #19850
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOREASE 200 (DR. REDDY''S)',
	'Mebeverine Hcl.',
	'SR',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOREASE 200 (DR. REDDY''S)'
);

-- line #19851
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Mebeverine', u'always_empty': u'', u'form': u'TAB', u'brand': u'LIBURE', u'strength_3': u'', u'company': u'AMORB(SIOUX)', u'unit': u''}

-- line #19852
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEBASPA 135 (U S V)',
	'Mebeverine',
	'TAB',
	gm.nullify_empty_string('135')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEBASPA 135 (U S V)'
);

-- line #19853
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEBRIN 135 (PSYCOREM)',
	'Mebeverine',
	'TAB',
	gm.nullify_empty_string('135')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEBRIN 135 (PSYCOREM)'
);

-- line #19854
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOREASE 135 (Dr.Reddy''S)',
	'Mebeverine',
	'TAB',
	gm.nullify_empty_string('135')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOREASE 135 (Dr.Reddy''S)'
);

-- line #19855
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILIGAN 25 (Ucb India)',
	'Meclizine Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILIGAN 25 (Ucb India)'
);

-- line #19856
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'DM INJ', u'brand': u'ABSOLUTE', u'strength_3': u'', u'company': u'Pharmed', u'unit': u''}

-- line #19857
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'TAB', u'brand': u'ACTIV-12', u'strength_3': u'', u'company': u'Unimarck', u'unit': u''}

-- line #19858
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'TAB', u'brand': u'ACTORICH', u'strength_3': u'', u'company': u'Crescent Th.', u'unit': u''}

-- line #19859
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'INJ', u'brand': u'ACVIT-12', u'strength_3': u'', u'company': u'UNIMARK REM.', u'unit': u''}

-- line #19860
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'ML', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'INJ', u'brand': u'ALPHAMIX', u'strength_3': u'', u'company': u'QCHECK', u'unit': u''}

-- line #19861
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'TAB', u'brand': u'AMBEE', u'strength_3': u'', u'company': u'Aust Ind.', u'unit': u''}

-- line #19862
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'INJ', u'brand': u'AMECO', u'strength_3': u'', u'company': u'ST.MORRISON', u'unit': u''}

-- line #19863
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'INJ', u'brand': u'ATNURON', u'strength_3': u'', u'company': u'Atoz Ph.', u'unit': u''}

-- line #19864
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000MCG WITH B-COMPLEX', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'INJ', u'brand': u'AVINEURON', u'strength_3': u'', u'company': u'Admac (CADMA)', u'unit': u''}

-- line #19865
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG WITH B-COMPLEX', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'TAB', u'brand': u'AVINEURON', u'strength_3': u'', u'company': u'Admac (CADMA)', u'unit': u''}

-- line #19866
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'750MCG( WITH B-COMPLEX)', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'INJ', u'brand': u'AXYMORE', u'strength_3': u'', u'company': u'AXYZEN LIFE', u'unit': u''}

-- line #19867
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'TAB', u'brand': u'BALCOBAL', u'strength_3': u'', u'company': u'Samarth', u'unit': u''}

-- line #19868
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'INJ', u'brand': u'BALCOMIN', u'strength_3': u'', u'company': u'MOVA PH.', u'unit': u''}

-- line #19869
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'TAB', u'brand': u'BALCOMIN', u'strength_3': u'', u'company': u'MOVA PH.', u'unit': u''}

-- line #19870
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'INJ', u'brand': u'BEVEL', u'strength_3': u'', u'company': u'Solitaire', u'unit': u''}

-- line #19871
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000MCG', u'strength_2': u'2ML', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'INJ', u'brand': u'BIGVIN', u'strength_3': u'', u'company': u'Bestochem', u'unit': u''}

-- line #19872
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'INJ', u'brand': u'BIGVIN', u'strength_3': u'', u'company': u'Bestochem', u'unit': u''}

-- line #19873
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'1ML', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'INJ', u'brand': u'BIGVIN', u'strength_3': u'', u'company': u'Bestochem', u'unit': u''}

-- line #19874
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'TAB', u'brand': u'BIGVIN', u'strength_3': u'', u'company': u'Bestochem', u'unit': u''}

-- line #19875
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'TAB', u'brand': u'BIGVIN', u'strength_3': u'', u'company': u'Bestochem', u'unit': u''}

-- line #19876
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'TAB', u'brand': u'BIGVIN', u'strength_3': u'', u'company': u'Bestochem', u'unit': u''}

-- line #19877
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'ML', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'INJ', u'brand': u'BIOCOBAL', u'strength_3': u'', u'company': u'Orchid Hc.', u'unit': u''}

-- line #19878
-- ignoring line: field [strength_1] not numeric: >>>500MCG (+VITAMINS<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG (+VITAMINS', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'SYR', u'brand': u'BIOCOBAL', u'strength_3': u'', u'company': u'Orchid Hc.', u'unit': u'LYSINE & D-PANTHENOL)'}

-- line #19879
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'TAB', u'brand': u'BIOCOBAL', u'strength_3': u'', u'company': u'Orchid Hc.', u'unit': u''}

-- line #19880
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'TAB', u'brand': u'BIOCOBAL', u'strength_3': u'', u'company': u'Orchid Hc.', u'unit': u''}

-- line #19881
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'INJ', u'brand': u'CABOSOFT', u'strength_3': u'', u'company': u'Torrent', u'unit': u''}

-- line #19882
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'TAB', u'brand': u'CALLY', u'strength_3': u'', u'company': u'Shinto Org.', u'unit': u''}

-- line #19883
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'TAB', u'brand': u'CALLY', u'strength_3': u'', u'company': u'Shinto Org.', u'unit': u''}

-- line #19884
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'TAB', u'brand': u'CANBOL', u'strength_3': u'', u'company': u'Candor Bio.', u'unit': u''}

-- line #19885
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CITON 1 (Neon)',
	'MECOBALAMIN',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CITON 1 (Neon)'
);

-- line #19886
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'OD TAB', u'brand': u'COBAL', u'strength_3': u'', u'company': u'Mars', u'unit': u''}

-- line #19887
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'INJ', u'brand': u'COBALOM', u'strength_3': u'', u'company': u'Om Bio.', u'unit': u''}

-- line #19888
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'TAB', u'brand': u'COBAL', u'strength_3': u'', u'company': u'Mars', u'unit': u''}

-- line #19889
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'SYR', u'brand': u'COBALVIT-D', u'strength_3': u'', u'company': u'Intra Lab', u'unit': u''}

-- line #19890
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'ML', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'INJ', u'brand': u'COBALVIT', u'strength_3': u'', u'company': u'Intra Lab', u'unit': u''}

-- line #19891
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'OD TAB', u'brand': u'COBALVIT', u'strength_3': u'', u'company': u'Intra Lab', u'unit': u''}

-- line #19892
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'OD TAB', u'brand': u'COBAL VIT', u'strength_3': u'', u'company': u'Intra Lab', u'unit': u''}

-- line #19893
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'INJ', u'brand': u'COBAMET', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #19894
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'OD TAB', u'brand': u'COBAMET', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #19895
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'TAB', u'brand': u'COBAMET', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #19896
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'INJ', u'brand': u'COBANERVE', u'strength_3': u'', u'company': u'Intra(INVISION)', u'unit': u''}

-- line #19897
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'OD TAB', u'brand': u'COBANERVE', u'strength_3': u'', u'company': u'Intra(INVISION)', u'unit': u''}

-- line #19898
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'TAB', u'brand': u'COBA', u'strength_3': u'', u'company': u'Corolla(Triton)', u'unit': u''}

-- line #19899
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'INJ', u'brand': u'COBLONA', u'strength_3': u'', u'company': u'Sayona', u'unit': u''}

-- line #19900
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'CAP', u'brand': u'DIABANERVE', u'strength_3': u'', u'company': u'TAJ PH.', u'unit': u''}

-- line #19901
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'INJ', u'brand': u'DIABANERVE', u'strength_3': u'', u'company': u'TAJ PH.', u'unit': u''}

-- line #19902
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'TAB', u'brand': u'DIABANERVE', u'strength_3': u'', u'company': u'TAJ PH.', u'unit': u''}

-- line #19903
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'INJ', u'brand': u'DIACOBAL', u'strength_3': u'', u'company': u'Orchid Hc.', u'unit': u''}

-- line #19904
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'TAB', u'brand': u'DIACOBAL SL', u'strength_3': u'', u'company': u'Orchid Hc.', u'unit': u''}

-- line #19905
-- ignoring line: field [strength_1] not numeric: >>>500MCG (+VITAMINS<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG (+VITAMINS', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'SYR', u'brand': u'DIACOBAL', u'strength_3': u'', u'company': u'Orchid Hc.', u'unit': u'LYSINE & D-PANTHENOL)'}

-- line #19906
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'TAB', u'brand': u'DIACOBAL', u'strength_3': u'', u'company': u'Orchid Hc.', u'unit': u''}

-- line #19907
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'TAB', u'brand': u'DIACOBAL', u'strength_3': u'', u'company': u'Orchid Hc.', u'unit': u''}

-- line #19908
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'INJ', u'brand': u'E-COB', u'strength_3': u'', u'company': u'ZOTA', u'unit': u''}

-- line #19909
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'OD TAB', u'brand': u'EFCOBA', u'strength_3': u'', u'company': u'Triton Hc.', u'unit': u''}

-- line #19910
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'TAB', u'brand': u'EFCOBA', u'strength_3': u'', u'company': u'Triton Hc.', u'unit': u''}

-- line #19911
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'INJ', u'brand': u'ELMECOB', u'strength_3': u'', u'company': u'Elder', u'unit': u''}

-- line #19912
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'OD TAB', u'brand': u'ELMECOB', u'strength_3': u'', u'company': u'Elder', u'unit': u''}

-- line #19913
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'TAB', u'brand': u'ELMECOB', u'strength_3': u'', u'company': u'Elder', u'unit': u''}

-- line #19914
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'TAB', u'brand': u'FYCOBAL', u'strength_3': u'', u'company': u'Phytochem', u'unit': u''}

-- line #19915
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'ML', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'INJ', u'brand': u'GERNE', u'strength_3': u'', u'company': u'Harson Lab', u'unit': u''}

-- line #19916
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'TAB', u'brand': u'GERNE', u'strength_3': u'', u'company': u'Harson Lab', u'unit': u''}

-- line #19917
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'TAB', u'brand': u'HALCOMB SL', u'strength_3': u'', u'company': u'Indchemie', u'unit': u''}

-- line #19918
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'OD TAB', u'brand': u'LBEX-12', u'strength_3': u'', u'company': u'Lincoln', u'unit': u''}

-- line #19919
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'OD TAB', u'brand': u'L-BEX-12', u'strength_3': u'', u'company': u'Lincoln', u'unit': u''}

-- line #19920
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000MCG WITH B-COMPLEX', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'INJ', u'brand': u'LINEURON', u'strength_3': u'', u'company': u'ADMAC (LEE BENZ)', u'unit': u''}

-- line #19921
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG WITH B-COMPLEX', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'TAB', u'brand': u'LINEURON', u'strength_3': u'', u'company': u'ADMAC (LEE BENZ)', u'unit': u''}

-- line #19922
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'INJ', u'brand': u'LOGIC', u'strength_3': u'', u'company': u'Sienna Form.', u'unit': u''}

-- line #19923
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'INJ', u'brand': u'LOGY', u'strength_3': u'', u'company': u'Sienna Form.', u'unit': u''}

-- line #19924
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'INJ', u'brand': u'MATILDA', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #19925
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'OD TAB', u'brand': u'MATILDA', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #19926
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'OD TAB', u'brand': u'MATILDA', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #19927
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'INJ', u'brand': u'MB-12', u'strength_3': u'', u'company': u'Mapra', u'unit': u''}

-- line #19928
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'INJ', u'brand': u'MCBIT', u'strength_3': u'', u'company': u'Cubit Hc.', u'unit': u''}

-- line #19929
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'INJ', u'brand': u'ME-12', u'strength_3': u'', u'company': u'Systopic', u'unit': u''}

-- line #19930
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'1ML', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'INJ', u'brand': u'MECOBA', u'strength_3': u'', u'company': u'Nicholas', u'unit': u''}

-- line #19931
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'ML', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'INJ', u'brand': u'MECOBAL', u'strength_3': u'', u'company': u'Rapross', u'unit': u''}

-- line #19932
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'OD TAB', u'brand': u'MECOBAL', u'strength_3': u'', u'company': u'Rapross', u'unit': u''}

-- line #19933
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'TAB', u'brand': u'MECOBAL', u'strength_3': u'', u'company': u'Rapross', u'unit': u''}

-- line #19934
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500', u'strength_2': u'1500;MCG', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'TAB', u'brand': u'MECOBA', u'strength_3': u'', u'company': u'Nicholas', u'unit': u''}

-- line #19935
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'INJ', u'brand': u'MECOBEST', u'strength_3': u'', u'company': u'LUPINOVA', u'unit': u''}

-- line #19936
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'INJ', u'brand': u'MECOLIFE', u'strength_3': u'', u'company': u'Life Med.', u'unit': u''}

-- line #19937
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'INJ', u'brand': u'MECOLIFE', u'strength_3': u'', u'company': u'Life Med.', u'unit': u''}

-- line #19938
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'OD TAB', u'brand': u'MECOLIFE', u'strength_3': u'', u'company': u'Life Med.', u'unit': u''}

-- line #19939
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'OD TAB', u'brand': u'MECOLIFE', u'strength_3': u'', u'company': u'Life Med.', u'unit': u''}

-- line #19940
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500', u'strength_2': u'1500;MCG', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'F. TAB', u'brand': u'MECOMIN', u'strength_3': u'', u'company': u'Mdc Ph.', u'unit': u''}

-- line #19941
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'INJ', u'brand': u'MECONERV', u'strength_3': u'', u'company': u'Micro Labs', u'unit': u''}

-- line #19942
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'TAB', u'brand': u'MECONERV', u'strength_3': u'', u'company': u'Micro Labs', u'unit': u''}

-- line #19943
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'TAB', u'brand': u'MECONERV', u'strength_3': u'', u'company': u'Micro Labs', u'unit': u''}

-- line #19944
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'AMP', u'brand': u'MECONEURON', u'strength_3': u'', u'company': u'Pulse Ph.', u'unit': u''}

-- line #19945
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'TAB', u'brand': u'MECONEURON', u'strength_3': u'', u'company': u'Pulse Ph.', u'unit': u''}

-- line #19946
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'OD TAB', u'brand': u'MECONOVIT', u'strength_3': u'', u'company': u'ACTO', u'unit': u''}

-- line #19947
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'INJ', u'brand': u'MECOVON', u'strength_3': u'', u'company': u'Zuventus', u'unit': u''}

-- line #19948
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MECOVON 500 (Zuventus)',
	'Mecobalamin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MECOVON 500 (Zuventus)'
);

-- line #19949
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'MD TAB', u'brand': u'MECOZEN', u'strength_3': u'', u'company': u'Sain Med.', u'unit': u''}

-- line #19950
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'OD TAB', u'brand': u'MECOZEN', u'strength_3': u'', u'company': u'Sain Med.', u'unit': u''}

-- line #19951
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'TAB', u'brand': u'MECZE', u'strength_3': u'', u'company': u'Zee Lab', u'unit': u''}

-- line #19952
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'ML', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'AMP', u'brand': u'MEDHAMIN', u'strength_3': u'', u'company': u'EMAR', u'unit': u''}

-- line #19953
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDINERV 1500 (PROCURE)',
	'MECOBALAMIN',
	'TAB',
	gm.nullify_empty_string('1500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDINERV 1500 (PROCURE)'
);

-- line #19954
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'INJ', u'brand': u'MEEL', u'strength_3': u'', u'company': u'Elf Biomed', u'unit': u''}

-- line #19955
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'POW', u'brand': u'MEEL PLUS', u'strength_3': u'', u'company': u'Elf Biomed', u'unit': u''}

-- line #19956
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'TAB', u'brand': u'MEEL', u'strength_3': u'', u'company': u'Elf Biomed', u'unit': u''}

-- line #19957
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'INJ', u'brand': u'MEGABO', u'strength_3': u'', u'company': u'Globus', u'unit': u''}

-- line #19958
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'INJ', u'brand': u'MEGO', u'strength_3': u'', u'company': u'Blue Cross', u'unit': u''}

-- line #19959
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'TAB', u'brand': u'MEGO SL', u'strength_3': u'', u'company': u'Blue Cross', u'unit': u''}

-- line #19960
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'OD TAB', u'brand': u'ME', u'strength_3': u'', u'company': u'Systopic', u'unit': u''}

-- line #19961
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METHERLIN 0.125 (TAJ PH.)',
	'MECOBALAMIN',
	'TAB',
	gm.nullify_empty_string('0.125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METHERLIN 0.125 (TAJ PH.)'
);

-- line #19962
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METHERLIN 0.2 (TAJ PH.)',
	'MECOBALAMIN',
	'VIAL',
	gm.nullify_empty_string('0.2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METHERLIN 0.2 (TAJ PH.)'
);

-- line #19963
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METHICO 1 (EAST WEST)',
	'MECOBALAMIN',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'1.5'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METHICO 1 (EAST WEST)'
);

-- line #19964
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'INJ', u'brand': u'METHICO', u'strength_3': u'', u'company': u'EAST WEST', u'unit': u''}

-- line #19965
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'OD TAB', u'brand': u'METHICO', u'strength_3': u'', u'company': u'EAST WEST', u'unit': u''}

-- line #19966
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'TAB', u'brand': u'METHICO', u'strength_3': u'', u'company': u'EAST WEST', u'unit': u''}

-- line #19967
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'TAB', u'brand': u'METHICO', u'strength_3': u'', u'company': u'EAST WEST', u'unit': u''}

-- line #19968
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'TAB', u'brand': u'METHICO', u'strength_3': u'', u'company': u'EAST WEST', u'unit': u''}

-- line #19969
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'TAB', u'brand': u'METHNEURON', u'strength_3': u'', u'company': u'Meridian', u'unit': u''}

-- line #19970
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'INJ', u'brand': u'METHYCOBAL', u'strength_3': u'', u'company': u'Merind', u'unit': u''}

-- line #19971
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'TAB', u'brand': u'METHYCOBAL', u'strength_3': u'', u'company': u'Merind', u'unit': u''}

-- line #19972
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'OD TAB', u'brand': u'METHYNEURON', u'strength_3': u'', u'company': u'Meridian', u'unit': u''}

-- line #19973
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'TAB', u'brand': u'METHYNEURON', u'strength_3': u'', u'company': u'Meridian', u'unit': u''}

-- line #19974
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'TAB', u'brand': u'MEWIN', u'strength_3': u'', u'company': u'Winsome Lab', u'unit': u''}

-- line #19975
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG (+VITAMINS)', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'SYR', u'brand': u'MICOVIT DL', u'strength_3': u'', u'company': u'Tripada Hc.', u'unit': u''}

-- line #19976
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'ML', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'INJ', u'brand': u'MIKO', u'strength_3': u'', u'company': u'GENESIS', u'unit': u''}

-- line #19977
-- ignoring line: field [strength_1] not numeric: >>>500MCG(+BENZYL ALCOHOL 85 2<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG(+BENZYL ALCOHOL 85 2', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'INJ', u'brand': u'MOVACOBAL', u'strength_3': u'', u'company': u'MOVA PH.', u'unit': u'%W/V)'}

-- line #19978
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'', u'brand': u'MOVACOBAL MCG', u'strength_3': u'', u'company': u'MOVA PH.', u'unit': u''}

-- line #19979
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'OD TAB', u'brand': u'MYCOBAL', u'strength_3': u'', u'company': u'Ind-Swift', u'unit': u''}

-- line #19980
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'TAB', u'brand': u'MYCOBAL', u'strength_3': u'', u'company': u'Ind-Swift', u'unit': u''}

-- line #19981
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500', u'strength_2': u'500;MCG', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'TAB/INJ', u'brand': u'MYCOBAL', u'strength_3': u'', u'company': u'Ind-Swift', u'unit': u''}

-- line #19982
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500', u'strength_2': u'500;MCG', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'TAB/INJ', u'brand': u'MYCOBAL', u'strength_3': u'', u'company': u'Marc Lab', u'unit': u''}

-- line #19983
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'INJ', u'brand': u'MYCOL', u'strength_3': u'', u'company': u'A.F.D.', u'unit': u''}

-- line #19984
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'TAB', u'brand': u'MYELOGEN', u'strength_3': u'', u'company': u'Panacea', u'unit': u''}

-- line #19985
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'TAB', u'brand': u'MYNURON', u'strength_3': u'', u'company': u'Aglowmed', u'unit': u''}

-- line #19986
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'TAB', u'brand': u'NECOB', u'strength_3': u'', u'company': u'Nitin Ph.', u'unit': u''}

-- line #19987
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'TAB', u'brand': u'NERVIC', u'strength_3': u'', u'company': u'Unimarck', u'unit': u''}

-- line #19988
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'INJ', u'brand': u'NERVUP', u'strength_3': u'', u'company': u'Nicholas', u'unit': u''}

-- line #19989
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'INJ', u'brand': u'NEUCOBAL', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #19990
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500', u'strength_2': u'1500;MCG', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'TAB', u'brand': u'NEUCOBAL', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #19991
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'INJ', u'brand': u'NEURATAB-M-F', u'strength_3': u'', u'company': u'Waves Bio.', u'unit': u''}

-- line #19992
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'INJ', u'brand': u'NEURATAB-M', u'strength_3': u'', u'company': u'Waves Bio.', u'unit': u''}

-- line #19993
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'TAB', u'brand': u'NEUROAGE', u'strength_3': u'', u'company': u'ALLENGE', u'unit': u''}

-- line #19994
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'MD TAB', u'brand': u'NEUROLAC', u'strength_3': u'', u'company': u'LACLIN', u'unit': u''}

-- line #19995
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'OD TAB', u'brand': u'NEUROLAX', u'strength_3': u'', u'company': u'Helax Hc.', u'unit': u''}

-- line #19996
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'F. AMP', u'brand': u'NEUROMED', u'strength_3': u'', u'company': u'DAKSH', u'unit': u''}

-- line #19997
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'INJ', u'brand': u'NEUROMIN', u'strength_3': u'', u'company': u'ORDAIN HC.', u'unit': u''}

-- line #19998
-- ignoring line: field [strength_1] not numeric: >>>500MCG(+BENZYL ALCOHL 2<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG(+BENZYL ALCOHL 2', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'INJ', u'brand': u'NEUROMIN', u'strength_3': u'', u'company': u'Ordain Hc.', u'unit': u'%)'}

-- line #19999
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'5ML', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'LIQ', u'brand': u'NEUROMIN', u'strength_3': u'', u'company': u'Ordain Hc.', u'unit': u''}

-- line #20000
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEUROMIN 500 (Ordain Hc.)',
	'Mecobalamin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEUROMIN 500 (Ordain Hc.)'
);

-- line #20001
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500', u'strength_2': u'1000;MCG', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'TAB', u'brand': u'NEUROPAT', u'strength_3': u'', u'company': u'MEDISYS', u'unit': u''}

-- line #20002
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'POWER TAB', u'brand': u'NEURO', u'strength_3': u'', u'company': u'Swift Med.', u'unit': u''}

-- line #20003
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2500MCG', u'strength_2': u'ML', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'INJ', u'brand': u'NEUROSWIFT', u'strength_3': u'', u'company': u'Ind-Swift', u'unit': u''}

-- line #20004
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'INJ', u'brand': u'NEUROTONE', u'strength_3': u'', u'company': u'P C INDIA', u'unit': u''}

-- line #20005
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'AMP', u'brand': u'NEUROVIG-M', u'strength_3': u'', u'company': u'MADHAV BIO.', u'unit': u''}

-- line #20006
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'INJ', u'brand': u'NEUROZ', u'strength_3': u'', u'company': u'ZYDUS NUT.', u'unit': u''}

-- line #20007
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEUROZ 1.5 (ZYDUS NUT.)',
	'MECOBALAMIN',
	'OD INJ',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEUROZ 1.5 (ZYDUS NUT.)'
);

-- line #20008
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'AMP', u'brand': u'NEUTRON', u'strength_3': u'', u'company': u'ICARUS', u'unit': u''}

-- line #20009
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NISCOBAL 1 (NEISS)',
	'MECOBALAMIN',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NISCOBAL 1 (NEISS)'
);

-- line #20010
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'TAB', u'brand': u'NU-B', u'strength_3': u'', u'company': u'Sanjivani', u'unit': u''}

-- line #20011
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'AMP', u'brand': u'NURITE', u'strength_3': u'', u'company': u'Centaur', u'unit': u''}

-- line #20012
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'TAB', u'brand': u'NUROCLAD-F', u'strength_3': u'', u'company': u'Symbiotic', u'unit': u''}

-- line #20013
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'TAB', u'brand': u'NUROCLAD', u'strength_3': u'', u'company': u'Symbiotic', u'unit': u''}

-- line #20014
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'TAB', u'brand': u'NURODAY', u'strength_3': u'', u'company': u'Wockhardt', u'unit': u''}

-- line #20015
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'1ML', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'INJ', u'brand': u'NUROKIND', u'strength_3': u'', u'company': u'Mankind', u'unit': u''}

-- line #20016
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'OD TAB', u'brand': u'NUROKIND', u'strength_3': u'', u'company': u'Mankind', u'unit': u''}

-- line #20017
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'OD TAB', u'brand': u'NUROKIND', u'strength_3': u'', u'company': u'Mankind', u'unit': u''}

-- line #20018
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'TAB', u'brand': u'NUROKIND', u'strength_3': u'', u'company': u'Mankind', u'unit': u''}

-- line #20019
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'TAB', u'brand': u'NUROKIND', u'strength_3': u'', u'company': u'Mankind', u'unit': u''}

-- line #20020
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'AMP', u'brand': u'NUROMAX', u'strength_3': u'', u'company': u'Active Hc.', u'unit': u''}

-- line #20021
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'INJ', u'brand': u'NUROZ', u'strength_3': u'', u'company': u'Zydus Cadila', u'unit': u''}

-- line #20022
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'OD TAB', u'brand': u'NUROZ', u'strength_3': u'', u'company': u'Zydus Cadila', u'unit': u''}

-- line #20023
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'INJ', u'brand': u'NUVOLT', u'strength_3': u'', u'company': u'Wisdom Ph.', u'unit': u''}

-- line #20024
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'TAB', u'brand': u'NUVOLT', u'strength_3': u'', u'company': u'Wisdom Ph.', u'unit': u''}

-- line #20025
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'F. TAB', u'brand': u'OB-12', u'strength_3': u'', u'company': u'Obsurge', u'unit': u''}

-- line #20026
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'TAB', u'brand': u'OB-12', u'strength_3': u'', u'company': u'Obsurge', u'unit': u''}

-- line #20027
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500', u'strength_2': u'1500;MCG', u'substance': u'MECOBALAMIN', u'always_empty': u'', u'form': u'TAB', u'brand': u'PSYNEURON', u'strength_3': u'', u'company': u'PSYCOREM', u'unit': u''}

-- line #20028
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Mecobalamin', u'always_empty': u'', u'form': u'TAB', u'brand': u'REGEN', u'strength_3': u'', u'company': u'Bal Ph.', u'unit': u''}

-- line #20029
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMPRO 10 (AIMCO PH.)',
	'Medroxyprogesterone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMPRO 10 (AIMCO PH.)'
);

-- line #20030
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DB 10 (Unicure)',
	'Medroxyprogesterone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DB 10 (Unicure)'
);

-- line #20031
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPO PROGESTIN 150 (DKT I.)',
	'Medroxyprogesterone',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/30ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPO PROGESTIN 150 (DKT I.)'
);

-- line #20032
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEVIRY 100 (Elder)',
	'Medroxyprogesterone',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEVIRY 100 (Elder)'
);

-- line #20033
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEVIRY 10 (Elder)',
	'Medroxyprogesterone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEVIRY 10 (Elder)'
);

-- line #20034
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEVIRY 2.5 (Elder)',
	'Medroxyprogesterone',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEVIRY 2.5 (Elder)'
);

-- line #20035
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMBRYOGEN 10 (EAST WEST)',
	'Medroxyprogesterone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMBRYOGEN 10 (EAST WEST)'
);

-- line #20036
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMPEEA 10 (Wyeth)',
	'Medroxyprogesterone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMPEEA 10 (Wyeth)'
);

-- line #20037
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMPEEA 2.5 (Wyeth)',
	'Medroxyprogesterone',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMPEEA 2.5 (Wyeth)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMPEEA 5 (Wyeth)',
	'Medroxyprogesterone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMPEEA 5 (Wyeth)'
);

-- line #20038
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FARLUTAL 100 (Pharmacia)',
	'Medroxyprogesterone',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg(ACETATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FARLUTAL 100 (Pharmacia)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FARLUTAL 500 (Pharmacia)',
	'Medroxyprogesterone',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg(ACETATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FARLUTAL 500 (Pharmacia)'
);

-- line #20039
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FARLUTAL 10 (Pharmacia)',
	'Medroxyprogesterone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FARLUTAL 10 (Pharmacia)'
);

-- line #20040
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FARLUTAL 2.5 (Pharmacia)',
	'Medroxyprogesterone',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FARLUTAL 2.5 (Pharmacia)'
);

-- line #20041
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FARLUTAL 5 (Pharmacia)',
	'Medroxyprogesterone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FARLUTAL 5 (Pharmacia)'
);

-- line #20042
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LITMUS-10 10 (Siesta)',
	'Medroxyprogesterone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LITMUS-10 10 (Siesta)'
);

-- line #20043
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAXOGEST 10 (Corona)',
	'Medroxyprogesterone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAXOGEST 10 (Corona)'
);

-- line #20044
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDONA 10 (WEST COAST)',
	'Medroxyprogesterone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDONA 10 (WEST COAST)'
);

-- line #20045
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDONA 2.5 (WEST COAST)',
	'Medroxyprogesterone',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDONA 2.5 (WEST COAST)'
);

-- line #20046
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDRIGEST 100 (VHB)',
	'Medroxyprogesterone',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDRIGEST 100 (VHB)'
);

-- line #20047
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDRIGEST 10 (VHB)',
	'Medroxyprogesterone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDRIGEST 10 (VHB)'
);

-- line #20048
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDRIGEST 2.5 (VHB)',
	'Medroxyprogesterone',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDRIGEST 2.5 (VHB)'
);

-- line #20049
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDRONORM 10 (Obsurge)',
	'Medroxyprogesterone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDRONORM 10 (Obsurge)'
);

-- line #20050
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDTET 10 (Cadila Ph.)',
	'Medroxyprogesterone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDTET 10 (Cadila Ph.)'
);

-- line #20051
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGESTONE 10 (Rekvina)',
	'Medroxyprogesterone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGESTONE 10 (Rekvina)'
);

-- line #20052
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGEST 10 (Uni-Sank.)',
	'Medroxyprogesterone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg (ACETATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGEST 10 (Uni-Sank.)'
);

-- line #20053
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGEST 2.5 (Uni-Sank.)',
	'Medroxyprogesterone',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg(ACETATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGEST 2.5 (Uni-Sank.)'
);

-- line #20054
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEPRATE 2.5 (Serum Inst.)',
	'Medroxyprogesterone',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEPRATE 2.5 (Serum Inst.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEPRATE 10 (Serum Inst.)',
	'Medroxyprogesterone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEPRATE 10 (Serum Inst.)'
);

-- line #20055
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MODUS 10 (Gsk)',
	'Medroxyprogesterone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MODUS 10 (Gsk)'
);

-- line #20056
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MODUS 2.5 (Gsk)',
	'Medroxyprogesterone',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MODUS 2.5 (Gsk)'
);

-- line #20057
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'150', u'strength_2': u'', u'substance': u'Medroxyprogesterone', u'always_empty': u'', u'form': u'', u'brand': u'MYONE DEPOT PFS', u'strength_3': u'', u'company': u'Sun', u'unit': u'mg/ML(ACETATE)'}

-- line #20058
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORGAMED 10 (Infar)',
	'Medroxyprogesterone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg(ACETATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORGAMED 10 (Infar)'
);

-- line #20059
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROVERA 10 (Pharmacia)',
	'Medroxyprogesterone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROVERA 10 (Pharmacia)'
);

-- line #20060
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROVERA 2.5 (Pharmacia)',
	'Medroxyprogesterone',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROVERA 2.5 (Pharmacia)'
);

-- line #20061
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROVERA 5 (Pharmacia)',
	'Medroxyprogesterone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROVERA 5 (Pharmacia)'
);

-- line #20062
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REGEEVA 5 (Novartis)',
	'Medroxyprogesterone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg(ACET.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REGEEVA 5 (Novartis)'
);

-- line #20063
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYSMEN 500 (Svizera)',
	'Mefenamic Acid',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYSMEN 500 (Svizera)'
);

-- line #20064
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDOL 500 (Mac)',
	'Mefenamic Acid',
	'F. TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDOL 500 (Mac)'
);

-- line #20065
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEFACID 100 (FLOREAT)',
	'mefenamic acid',
	'DT TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEFACID 100 (FLOREAT)'
);

-- line #20066
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEFACID 100 (FLOREAT)',
	'mefenamic acid',
	'SUSP',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEFACID 100 (FLOREAT)'
);

-- line #20067
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEFACID 250 (FLOREAT)',
	'mefenamic acid',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEFACID 250 (FLOREAT)'
);

-- line #20068
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEFACID 500 (FLOREAT)',
	'mefenamic acid',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEFACID 500 (FLOREAT)'
);

-- line #20069
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEFANORM 100 (Serum Int.)',
	'Mefenamic Acid',
	'SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEFANORM 100 (Serum Int.)'
);

-- line #20070
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEFAST 100 (LASOR PH.)',
	'Mefenamic Acid',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEFAST 100 (LASOR PH.)'
);

-- line #20071
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEFDOL 500 (Bal Ph.)',
	'Mefenamic Acid',
	'F. TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEFDOL 500 (Bal Ph.)'
);

-- line #20072
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEFDOL 250 (Bal Ph.)',
	'Mefenamic Acid',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEFDOL 250 (Bal Ph.)'
);

-- line #20073
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEFF-P 100 (Bestochem)',
	'Mefenamic Acid',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEFF-P 100 (Bestochem)'
);

-- line #20074
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEFJET 250 (Trio Rem.)',
	'Mefenamic Acid',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEFJET 250 (Trio Rem.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEFJET 500 (Trio Rem.)',
	'Mefenamic Acid',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEFJET 500 (Trio Rem.)'
);

-- line #20075
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEFKIND-P 100 (LIFESTAR)',
	'Mefenamic Acid',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEFKIND-P 100 (LIFESTAR)'
);

-- line #20076
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEFKIND-P 100 (LIFESTAR)',
	'Mefenamic Acid',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEFKIND-P 100 (LIFESTAR)'
);

-- line #20077
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEFLUP 250 (Lupin)',
	'Mefenamic Acid',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEFLUP 250 (Lupin)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEFLUP 500 (Lupin)',
	'Mefenamic Acid',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEFLUP 500 (Lupin)'
);

-- line #20078
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEFTAL-P 100 (Blue Cross)',
	'Mefenamic Acid',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEFTAL-P 100 (Blue Cross)'
);

-- line #20079
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEFTAL-P 100 (Blue Cross)',
	'Mefenamic Acid',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEFTAL-P 100 (Blue Cross)'
);

-- line #20080
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEFTAL 250 (Blue Cross)',
	'Mefenamic Acid',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEFTAL 250 (Blue Cross)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEFTAL 500 (Blue Cross)',
	'Mefenamic Acid',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEFTAL 500 (Blue Cross)'
);

-- line #20081
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEPEN 500 (Unicure)',
	'Mefenamic Acid',
	'DS TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEPEN 500 (Unicure)'
);

-- line #20082
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PONSTAN 250 (Pfizer)',
	'Mefenamic Acid',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PONSTAN 250 (Pfizer)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PONSTAN 500 (Pfizer)',
	'Mefenamic Acid',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PONSTAN 500 (Pfizer)'
);

-- line #20083
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PONSTAN 125 (Pfizer)',
	'Mefenamic Acid',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PONSTAN 125 (Pfizer)'
);

-- line #20084
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PONSTAN 50 (Pfizer)',
	'Mefenamic Acid',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PONSTAN 50 (Pfizer)'
);

-- line #20085
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PONTAX-100 100 (Mankind)',
	'Mefenamic Acid',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PONTAX-100 100 (Mankind)'
);

-- line #20086
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONFAL 250 (Lupin)',
	'Mefloquine Hcl.',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONFAL 250 (Lupin)'
);

-- line #20087
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FACITAL 250 (Zydus Cadila)',
	'Mefloquine Hcl.',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FACITAL 250 (Zydus Cadila)'
);

-- line #20088
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FALCITAL 250 (Cadila Ph.)',
	'Mefloquine Hcl.',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FALCITAL 250 (Cadila Ph.)'
);

-- line #20089
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LARIMEF 250 (Ipca)',
	'Mefloquine Hcl.',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LARIMEF 250 (Ipca)'
);

-- line #20090
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALACURE-MF 250 (Patson)',
	'Mefloquine Hcl.',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALACURE-MF 250 (Patson)'
);

-- line #20091
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALARIUM 250 (Jenburkt)',
	'Mefloquine Hcl.',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALARIUM 250 (Jenburkt)'
);

-- line #20092
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEFAX 250 (Alkem)',
	'Mefloquine Hcl.',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEFAX 250 (Alkem)'
);

-- line #20093
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEFCY 250 (Skymax)',
	'Mefloquine Hcl.',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEFCY 250 (Skymax)'
);

-- line #20094
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEFLIAM 250 (Cipla)',
	'Mefloquine Hcl.',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEFLIAM 250 (Cipla)'
);

-- line #20095
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEFLOC 250 (Aristo)',
	'Mefloquine Hcl.',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEFLOC 250 (Aristo)'
);

-- line #20096
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEFLOQUINE 250 (Emcure)',
	'Mefloquine Hcl.',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEFLOQUINE 250 (Emcure)'
);

-- line #20097
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEFLOTAS 250 (Intas)',
	'Mefloquine Hcl.',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEFLOTAS 250 (Intas)'
);

-- line #20098
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEFQUE 250 (Zydus A.)',
	'Mefloquine Hcl.',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEFQUE 250 (Zydus A.)'
);

-- line #20099
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MQF 250 (Sun)',
	'Mefloquine Hcl.',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MQF 250 (Sun)'
);

-- line #20100
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENDACE-40 40 (Samarth)',
	'Megestrol Acetate',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENDACE-40 40 (Samarth)'
);

-- line #20101
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMONIN 0.25 (TASMED)',
	'Melatonin',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMONIN 0.25 (TASMED)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMONIN 0.5 (TASMED)',
	'Melatonin',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMONIN 0.5 (TASMED)'
);

-- line #20102
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELOSET 3 (Aristo)',
	'Melatonin',
	'TAB',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELOSET 3 (Aristo)'
);

-- line #20103
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARTAZ 15 (Neu-Foreva)',
	'Meloxicam',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARTAZ 15 (Neu-Foreva)'
);

-- line #20104
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARTAZ 7.5 (Neu-Foreva)',
	'Meloxicam',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARTAZ 7.5 (Neu-Foreva)'
);

-- line #20105
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ECWIN 15 (Alembic)',
	'Meloxicam',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ECWIN 15 (Alembic)'
);

-- line #20106
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ECWIN 7.5 (Alembic)',
	'Meloxicam',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ECWIN 7.5 (Alembic)'
);

-- line #20107
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'M CAM 15 (Unichem)',
	'Meloxicam',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'M CAM 15 (Unichem)'
);

-- line #20108
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'M CAM 7.5 (Unichem)',
	'Meloxicam',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'M CAM 7.5 (Unichem)'
);

-- line #20109
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELA 15 (Sysmed)',
	'Meloxicam',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELA 15 (Sysmed)'
);

-- line #20110
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELA 7.5 (Sysmed)',
	'Meloxicam',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELA 7.5 (Sysmed)'
);

-- line #20111
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELFLAM 15 (Cipla)',
	'Meloxicam',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELFLAM 15 (Cipla)'
);

-- line #20112
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELFLAM 7.5 (Cipla)',
	'Meloxicam',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELFLAM 7.5 (Cipla)'
);

-- line #20113
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEL 15 (Zydus Cadila)',
	'Meloxicam',
	'OD TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEL 15 (Zydus Cadila)'
);

-- line #20114
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEL 7.5 (Zydus Cadila)',
	'Meloxicam',
	'OD TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEL 7.5 (Zydus Cadila)'
);

-- line #20115
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELOGESIC 15 (Lupin)',
	'Meloxicam',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELOGESIC 15 (Lupin)'
);

-- line #20116
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELOGESIC 7.5 (Lupin)',
	'Meloxicam',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELOGESIC 7.5 (Lupin)'
);

-- line #20117
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELONE 15 (Elder)',
	'Meloxicam',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELONE 15 (Elder)'
);

-- line #20118
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELONE 7.5 (Elder)',
	'Meloxicam',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELONE 7.5 (Elder)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELONE 15 (Elder)',
	'Meloxicam',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELONE 15 (Elder)'
);

-- line #20119
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELONE 7.5 (Elder)',
	'Meloxicam',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELONE 7.5 (Elder)'
);

-- line #20120
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELOSUGANRIL 15 (Nicholas)',
	'Meloxicam',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELOSUGANRIL 15 (Nicholas)'
);

-- line #20121
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELOSUGANRIL 7.5 (Nicholas)',
	'Meloxicam',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELOSUGANRIL 7.5 (Nicholas)'
);

-- line #20122
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELO 15 (Maneesh)',
	'Meloxicam',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELO 15 (Maneesh)'
);

-- line #20123
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELO 7.5 (Maneesh)',
	'Meloxicam',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELO 7.5 (Maneesh)'
);

-- line #20124
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELOXI 15 (Bal Ph.)',
	'Meloxicam',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELOXI 15 (Bal Ph.)'
);

-- line #20125
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELOXI 7.5 (Bal Ph.)',
	'Meloxicam',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELOXI 7.5 (Bal Ph.)'
);

-- line #20126
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELWIN 7.5 (Genix Ph.)',
	'Meloxicam',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELWIN 7.5 (Genix Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELWIN 15 (Genix Ph.)',
	'Meloxicam',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELWIN 15 (Genix Ph.)'
);

-- line #20127
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEXAM 15 (Zydus Cadila)',
	'Meloxicam',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEXAM 15 (Zydus Cadila)'
);

-- line #20128
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEXAM 7.5 (Zydus Cadila)',
	'Meloxicam',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEXAM 7.5 (Zydus Cadila)'
);

-- line #20129
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOVAC 15 (Alkem)',
	'Meloxicam',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOVAC 15 (Alkem)'
);

-- line #20130
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOVAC 7.5 (Alkem)',
	'Meloxicam',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOVAC 7.5 (Alkem)'
);

-- line #20131
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUVERA 15 (Sun)',
	'Meloxicam',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUVERA 15 (Sun)'
);

-- line #20132
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUVERA 7.5 (Sun)',
	'Meloxicam',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUVERA 7.5 (Sun)'
);

-- line #20133
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUVIK 7.5 (Le Sante)',
	'Meloxicam',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUVIK 7.5 (Le Sante)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUVIK 15 (Le Sante)',
	'Meloxicam',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUVIK 15 (Le Sante)'
);

-- line #20134
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUVIK TT 15 (Cadila Ph.)',
	'Meloxicam',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUVIK TT 15 (Cadila Ph.)'
);

-- line #20135
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUVIK TT 7.5 (Cadila Ph.)',
	'Meloxicam',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUVIK TT 7.5 (Cadila Ph.)'
);

-- line #20136
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAFREE 15 (Dr.Reddy''S)',
	'Meloxicam',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAFREE 15 (Dr.Reddy''S)'
);

-- line #20137
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAFREE 7.5 (Dr.Reddy''S)',
	'Meloxicam',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAFREE 7.5 (Dr.Reddy''S)'
);

-- line #20138
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALKACEL 2 (CELON(VIVILON))',
	'Melphalan',
	'FC TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALKACEL 2 (CELON(VIVILON))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALKACEL 5 (CELON(VIVILON))',
	'Melphalan',
	'FC TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALKACEL 5 (CELON(VIVILON))'
);

-- line #20139
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALKACEL 50 (CELON(VIVILON))',
	'Melphalan',
	'VIAL',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALKACEL 50 (CELON(VIVILON))'
);

-- line #20140
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALKERAN 50 (Gsk)',
	'Melphalan',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALKERAN 50 (Gsk)'
);

-- line #20141
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALKERAN 2 (Gsk)',
	'Melphalan',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALKERAN 2 (Gsk)'
);

-- line #20142
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALKERAN 5 (Gsk)',
	'Melphalan',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALKERAN 5 (Gsk)'
);

-- line #20143
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEFAN 2 (Intas)',
	'Melphalan',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEFAN 2 (Intas)'
);

-- line #20144
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEFAN 5 (Intas)',
	'Melphalan',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEFAN 5 (Intas)'
);

-- line #20145
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADMENTA 10 (Sun)',
	'MEMANTINE',
	'MD TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADMENTA 10 (Sun)'
);

-- line #20146
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADMENTA 5 (Sun)',
	'MEMANTINE',
	'MD TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADMENTA 5 (Sun)'
);

-- line #20147
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXURA 10 (Win Medicare)',
	'MEMANTINE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXURA 10 (Win Medicare)'
);

-- line #20148
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MENTADEM 10 (Torrent)',
	'MEMANTINE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MENTADEM 10 (Torrent)'
);

-- line #20149
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MENTADEM 5 (Torrent)',
	'MEMANTINE',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MENTADEM 5 (Torrent)'
);

-- line #20150
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'K-NAT 1 (Kontest)',
	'Menadione',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'mg(SOD.BISULPHITE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'K-NAT 1 (Kontest)'
);

-- line #20151
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KAPILIN 10 (Gsk)',
	'Menapthone',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg(VITAMIN K ANALOQUE MENAPHTHONE NA BI SULPHITE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KAPILIN 10 (Gsk)'
);

-- line #20152
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50MCG', u'strength_2': u'0.5ML', u'substance': u'MENINGOCOCCAL VACCINE', u'always_empty': u'', u'form': u'INJ', u'brand': u'MENINGOCOCCAL A&C', u'strength_3': u'', u'company': u'Serum Inst.', u'unit': u''}

-- line #20153
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50MCG', u'strength_2': u'0.5ML', u'substance': u'MENINGOCOCCAL VACCINE', u'always_empty': u'', u'form': u'INJ', u'brand': u'QUADRIMENINGO', u'strength_3': u'', u'company': u'Biomed', u'unit': u''}

-- line #20154
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u' mg', u'POTASSIUM DIHYDROGEN ORTHOPHOSPHATE BP 0.46 ', u' mg', u'DIPOTASSIUM HYDROGEN ORTHOPHOSPHATE BP 0.36 ', u' mg', u'', u'', u'', u''], u'strength_1': u'MENOTROPINS USP EQ TO THE ACITIVITY OF FOLLICLE STIMULATING HORMONE (FSH) 75IU', u'strength_2': u'', u'substance': u'Menotrophin (Fsh & Lh 1:1)', u'always_empty': u'', u'form': u'', u'brand': u'EEMA HMG', u'strength_3': u'', u'company': u'Corona', u'unit': u'LUTEINIZING HORMONE (LH) 75IU'}

-- line #20155
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'150IU.', u'strength_2': u'', u'substance': u'Menotrophin (Fsh & Lh 1:1)', u'always_empty': u'', u'form': u'INJ', u'brand': u'EVENTIN', u'strength_3': u'', u'company': u'Svizera', u'unit': u''}

-- line #20156
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75IU.', u'strength_2': u'', u'substance': u'Menotrophin (Fsh & Lh 1:1)', u'always_empty': u'', u'form': u'INJ', u'brand': u'EVENTIN', u'strength_3': u'', u'company': u'Svizera', u'unit': u''}

-- line #20157
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'###############################################################################################################################################################################################################################################################', u'strength_2': u'', u'substance': u'Menotrophin (Fsh & Lh 1:1)', u'always_empty': u'', u'form': u'INJ', u'brand': u'EVENTIN IU (HP) (HMG)', u'strength_3': u'', u'company': u'Svizera', u'unit': u''}

-- line #20158
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75IU.(FOLLICLE STIMULATING HORMONE(FSH)', u'strength_2': u'', u'substance': u'Menotrophin (Fsh & Lh 1:1)', u'always_empty': u'', u'form': u'INJ', u'brand': u'FOLITON-INGA', u'strength_3': u'', u'company': u'Inga', u'unit': u''}

-- line #20159
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75', u'strength_2': u'150;IU.(HUMAN MENOPAUSAL GONADOTR.)', u'substance': u'Menotrophin (Fsh & Lh 1:1)', u'always_empty': u'', u'form': u'VIAL', u'brand': u'FOLLINIS', u'strength_3': u'', u'company': u'NEISS', u'unit': u''}

-- line #20160
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75', u'strength_2': u'150;IU.(FOLLICLE STIMULATING HORMONE(FSH)', u'substance': u'Menotrophin (Fsh & Lh 1:1)', u'always_empty': u'', u'form': u'INJ', u'brand': u'FOLLITEC', u'strength_3': u'', u'company': u'United Bio.', u'unit': u''}

-- line #20161
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'150IU', u'strength_2': u'', u'substance': u'Menotrophin (Fsh & Lh 1:1)', u'always_empty': u'', u'form': u'INJ', u'brand': u'GHM', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #20162
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75IU', u'strength_2': u'', u'substance': u'Menotrophin (Fsh & Lh 1:1)', u'always_empty': u'', u'form': u'INJ', u'brand': u'GHM', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #20163
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'150I.U.', u'strength_2': u'', u'substance': u'Menotrophin (Fsh & Lh 1:1)', u'always_empty': u'', u'form': u'V', u'brand': u'GMH IU', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #20164
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75I.U.', u'strength_2': u'', u'substance': u'Menotrophin (Fsh & Lh 1:1)', u'always_empty': u'', u'form': u'V', u'brand': u'GMH IU', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #20165
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75', u'strength_2': u'150;IU.', u'substance': u'Menotrophin (Fsh & Lh 1:1)', u'always_empty': u'', u'form': u'VIAL', u'brand': u'GMH', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #20166
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'150IU.(HUMAN MENOPAUSAL GONADOTR.)', u'strength_2': u'', u'substance': u'Menotrophin (Fsh & Lh 1:1)', u'always_empty': u'', u'form': u'INJ', u'brand': u'GONOTROP-M IU', u'strength_3': u'', u'company': u'Modi Mundi', u'unit': u''}

-- line #20167
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75IU.', u'strength_2': u'', u'substance': u'Menotrophin (Fsh & Lh 1:1)', u'always_empty': u'', u'form': u'INJ', u'brand': u'GONOTROP-M IU', u'strength_3': u'', u'company': u'Modi Mundi', u'unit': u''}

-- line #20168
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'###############################################################################################################################################################################################################################################################', u'strength_2': u'', u'substance': u'Menotrophin (Fsh & Lh 1:1)', u'always_empty': u'', u'form': u'INJ', u'brand': u'GRAFOVA', u'strength_3': u'', u'company': u'Glenmark', u'unit': u''}

-- line #20169
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75', u'strength_2': u'150 IU.', u'substance': u'Menotrophin (Fsh & Lh 1:1)', u'always_empty': u'', u'form': u'INJ', u'brand': u'GYNOGEN', u'strength_3': u'', u'company': u'Uni-Sank.', u'unit': u''}

-- line #20170
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75', u'strength_2': u'150;IU.', u'substance': u'Menotrophin (Fsh & Lh 1:1)', u'always_empty': u'', u'form': u'INJ', u'brand': u'HMG-SP', u'strength_3': u'', u'company': u'Samarth', u'unit': u''}

-- line #20171
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75IU.', u'strength_2': u'', u'substance': u'Menotrophin (Fsh & Lh 1:1)', u'always_empty': u'', u'form': u'INJ', u'brand': u'HUMEGON', u'strength_3': u'', u'company': u'Infar', u'unit': u''}

-- line #20172
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'150IU', u'strength_2': u'', u'substance': u'Menotrophin (Fsh & Lh 1:1)', u'always_empty': u'', u'form': u'VIAL', u'brand': u'HUMOG', u'strength_3': u'', u'company': u'Bharat S.', u'unit': u''}

-- line #20173
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75IU', u'strength_2': u'', u'substance': u'Menotrophin (Fsh & Lh 1:1)', u'always_empty': u'', u'form': u'VIAL', u'brand': u'HUMOG', u'strength_3': u'', u'company': u'Bharat S.', u'unit': u''}

-- line #20174
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'150IU.', u'strength_2': u'', u'substance': u'Menotrophin (Fsh & Lh 1:1)', u'always_empty': u'', u'form': u'INJ', u'brand': u'INJ HMGCUT', u'strength_3': u'', u'company': u'ACE PH.', u'unit': u''}

-- line #20175
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75IU.', u'strength_2': u'', u'substance': u'Menotrophin (Fsh & Lh 1:1)', u'always_empty': u'', u'form': u'INJ', u'brand': u'INJ HMGCUT', u'strength_3': u'', u'company': u'ACE PH.', u'unit': u''}

-- line #20176
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'150IU.(FOLICAL STIMULATING HORMONE WITH MANNITOL)', u'strength_2': u'', u'substance': u'Menotrophin (Fsh & Lh 1:1)', u'always_empty': u'', u'form': u'INJ', u'brand': u'INTAS-HMG', u'strength_3': u'', u'company': u'INTAS', u'unit': u''}

-- line #20177
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75IU. (FOLICAL STIMULATING HORMONE)', u'strength_2': u'', u'substance': u'Menotrophin (Fsh & Lh 1:1)', u'always_empty': u'', u'form': u'INJ', u'brand': u'INTAS HMG', u'strength_3': u'', u'company': u'INTAS', u'unit': u''}

-- line #20178
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75', u'strength_2': u'150 IU.', u'substance': u'Menotrophin (Fsh & Lh 1:1)', u'always_empty': u'', u'form': u'INJ', u'brand': u'IVF-M', u'strength_3': u'', u'company': u'Biochem', u'unit': u''}

-- line #20179
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'150IU', u'strength_2': u'', u'substance': u'Menotrophin (Fsh & Lh 1:1)', u'always_empty': u'', u'form': u'VIAL', u'brand': u'LG IVF-M', u'strength_3': u'', u'company': u'Lglsi', u'unit': u''}

-- line #20180
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75IU', u'strength_2': u'', u'substance': u'Menotrophin (Fsh & Lh 1:1)', u'always_empty': u'', u'form': u'VIAL', u'brand': u'LG IVF-M', u'strength_3': u'', u'company': u'Lglsi', u'unit': u''}

-- line #20181
-- ignoring line: field [strength_1] not numeric: >>>150IU.(+ MANNITOL 12<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'150IU.(+ MANNITOL 12', u'strength_2': u'', u'substance': u'Menotrophin (Fsh & Lh 1:1)', u'always_empty': u'', u'form': u'AMP', u'brand': u'LUPI-HMG', u'strength_3': u'', u'company': u'Lupin', u'unit': u'mg)'}

-- line #20182
-- ignoring line: field [strength_1] not numeric: >>>75IU.(+ MANNITOL 12<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75IU.(+ MANNITOL 12', u'strength_2': u'', u'substance': u'Menotrophin (Fsh & Lh 1:1)', u'always_empty': u'', u'form': u'AMP', u'brand': u'LUPI-HMG', u'strength_3': u'', u'company': u'Lupin', u'unit': u'mg)'}

-- line #20183
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75IU(LH)', u'strength_2': u'', u'substance': u'Menotrophin (Fsh & Lh 1:1)', u'always_empty': u'', u'form': u'VIAL', u'brand': u'LUVERIS', u'strength_3': u'', u'company': u'Serum Inst.', u'unit': u''}

-- line #20184
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'150IU.(FSH)', u'strength_2': u'', u'substance': u'Menotrophin (Fsh & Lh 1:1)', u'always_empty': u'', u'form': u'INJ', u'brand': u'MAGNACENT IU', u'strength_3': u'', u'company': u'Alkem', u'unit': u''}

-- line #20185
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75IU.(FSH)', u'strength_2': u'', u'substance': u'Menotrophin (Fsh & Lh 1:1)', u'always_empty': u'', u'form': u'INJ', u'brand': u'MAGNACENT IU', u'strength_3': u'', u'company': u'Alkem', u'unit': u''}

-- line #20186
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'150IU', u'strength_2': u'', u'substance': u'Menotrophin (Fsh & Lh 1:1)', u'always_empty': u'', u'form': u'', u'brand': u'MATERNA-HMG IU', u'strength_3': u'', u'company': u'Emcure', u'unit': u'150IU(TOACTIVITY OF FOLLICLE STIMULATING HORMONE(FSH)'}

-- line #20187
-- ignoring line: field [strength_2] not numeric: >>>150 IU.(H<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': Decimal('75'), u'strength_2': u'150 IU.(H', u'substance': u'Menotrophin (Fsh & Lh 1:1)', u'always_empty': u'', u'form': u'VIAL', u'brand': u'MENODAC', u'strength_3': u'', u'company': u'Zydus Cadila', u'unit': u'mg)'}

-- line #20188
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75IU.', u'strength_2': u'', u'substance': u'Menotrophin (Fsh & Lh 1:1)', u'always_empty': u'', u'form': u'INJ', u'brand': u'MENOGON IU', u'strength_3': u'', u'company': u'Ferring Ph.', u'unit': u''}

-- line #20189
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75', u'strength_2': u'150IU.', u'substance': u'Menotrophin (Fsh & Lh 1:1)', u'always_empty': u'', u'form': u'VIAL', u'brand': u'MENOLIFE', u'strength_3': u'', u'company': u'Life Med.', u'unit': u''}

-- line #20190
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75I.U.', u'strength_2': u'', u'substance': u'Menotrophin (Fsh & Lh 1:1)', u'always_empty': u'', u'form': u'INJ', u'brand': u'MENOPUR', u'strength_3': u'', u'company': u'Ferring Ph.', u'unit': u''}

-- line #20191
-- ignoring line: field [strength_2] not numeric: >>>150;IU.(H<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': Decimal('75'), u'strength_2': u'150;IU.(H', u'substance': u'Menotrophin (Fsh & Lh 1:1)', u'always_empty': u'', u'form': u'INJ', u'brand': u'MENOTEC', u'strength_3': u'', u'company': u'United Bio.', u'unit': u'mg)'}

-- line #20192
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75IU', u'strength_2': u'', u'substance': u'Menotrophin (Fsh & Lh 1:1)', u'always_empty': u'', u'form': u'VIAL', u'brand': u'MENOVUL', u'strength_3': u'', u'company': u'Walter B.', u'unit': u''}

-- line #20193
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'150IU', u'strength_2': u'', u'substance': u'Menotrophin (Fsh & Lh 1:1)', u'always_empty': u'', u'form': u'V', u'brand': u'MENOVUL', u'strength_3': u'', u'company': u'Walter B.', u'unit': u''}

-- line #20194
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75IU.(HUMAN MENOPAUSAL GONADOTR.)', u'strength_2': u'', u'substance': u'Menotrophin (Fsh & Lh 1:1)', u'always_empty': u'', u'form': u'VIAL', u'brand': u'METERNA HMG', u'strength_3': u'', u'company': u'SHWEIZ', u'unit': u''}

-- line #20195
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'150IU.(RECOMBINENT FSH)', u'strength_2': u'', u'substance': u'Menotrophin (Fsh & Lh 1:1)', u'always_empty': u'', u'form': u'INJ', u'brand': u'NEWMOM-R IU', u'strength_3': u'', u'company': u'Lglsi', u'unit': u''}

-- line #20196
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'225IU.(RECOMBINENT FSH)', u'strength_2': u'', u'substance': u'Menotrophin (Fsh & Lh 1:1)', u'always_empty': u'', u'form': u'INJ', u'brand': u'NEWMOM-R IU', u'strength_3': u'', u'company': u'Lglsi', u'unit': u''}

-- line #20197
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'300IU.(RECOMBINENT FSH)', u'strength_2': u'', u'substance': u'Menotrophin (Fsh & Lh 1:1)', u'always_empty': u'', u'form': u'INJ', u'brand': u'NEWMOM-R IU', u'strength_3': u'', u'company': u'Lglsi', u'unit': u''}

-- line #20198
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75IU.(RECOMBINENT FSH)', u'strength_2': u'', u'substance': u'Menotrophin (Fsh & Lh 1:1)', u'always_empty': u'', u'form': u'INJ', u'brand': u'NEWMOM-R IU', u'strength_3': u'', u'company': u'Lglsi', u'unit': u''}

-- line #20199
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75', u'strength_2': u'150;IU.(HUM MENOPA.GONADOTROPHIN)', u'substance': u'Menotrophin (Fsh & Lh 1:1)', u'always_empty': u'', u'form': u'INJ', u'brand': u'NUGON', u'strength_3': u'', u'company': u'Solvay Ph.', u'unit': u''}

-- line #20200
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'150IU', u'strength_2': u'', u'substance': u'Menotrophin (Fsh & Lh 1:1)', u'always_empty': u'', u'form': u'HP INJ', u'brand': u'OVUGRAF', u'strength_3': u'', u'company': u'Vhb', u'unit': u''}

-- line #20201
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75IU', u'strength_2': u'', u'substance': u'Menotrophin (Fsh & Lh 1:1)', u'always_empty': u'', u'form': u'HP INJ', u'brand': u'OVUGRAF', u'strength_3': u'', u'company': u'Vhb', u'unit': u''}

-- line #20202
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'150IU', u'strength_2': u'', u'substance': u'Menotrophin (Fsh & Lh 1:1)', u'always_empty': u'', u'form': u'INJ', u'brand': u'OVULATE-M', u'strength_3': u'', u'company': u'German Life', u'unit': u''}

-- line #20203
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75IU', u'strength_2': u'', u'substance': u'Menotrophin (Fsh & Lh 1:1)', u'always_empty': u'', u'form': u'INJ', u'brand': u'OVULATE-M', u'strength_3': u'', u'company': u'German Life', u'unit': u''}

-- line #20204
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75IU LH & 75IU.FSH', u'strength_2': u'', u'substance': u'Menotrophin (Fsh & Lh 1:1)', u'always_empty': u'', u'form': u'INJ', u'brand': u'PERGONAL', u'strength_3': u'', u'company': u'Serum Inst.', u'unit': u''}

-- line #20205
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'150IU', u'strength_2': u'', u'substance': u'Menotrophin (Fsh & Lh 1:1)', u'always_empty': u'', u'form': u'INJ', u'brand': u'PREGNORM', u'strength_3': u'', u'company': u'Win-Medicare', u'unit': u''}

-- line #20206
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75IU', u'strength_2': u'', u'substance': u'Menotrophin (Fsh & Lh 1:1)', u'always_empty': u'', u'form': u'INJ', u'brand': u'PREGNORM', u'strength_3': u'', u'company': u'Win-Medicare', u'unit': u''}

-- line #20207
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'150IU', u'strength_2': u'', u'substance': u'Menotrophin (Fsh & Lh 1:1)', u'always_empty': u'', u'form': u'', u'brand': u'REPROGON IU', u'strength_3': u'', u'company': u'Ferring Ph.', u'unit': u''}

-- line #20208
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75IU', u'strength_2': u'', u'substance': u'Menotrophin (Fsh & Lh 1:1)', u'always_empty': u'', u'form': u'', u'brand': u'REPROGON IU', u'strength_3': u'', u'company': u'Ferring Ph.', u'unit': u''}

-- line #20209
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALADIN 100 (Unicure)',
	'Mepacrine Hcl.',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALADIN 100 (Unicure)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALADIN 300 (Unicure)',
	'Mepacrine Hcl.',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALADIN 300 (Unicure)'
);

-- line #20210
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEPHENTERMINE SULPHATE IP 30 (Troikaa)',
	'Mephentermine',
	'VIAL',
	gm.nullify_empty_string('30')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEPHENTERMINE SULPHATE IP 30 (Troikaa)'
);

-- line #20211
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEPHENTINE 15 (Wyeth)',
	'Mephentermine',
	'INJ',
	gm.nullify_empty_string('15')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEPHENTINE 15 (Wyeth)'
);

-- line #20212
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEPHENTINE 10 (Wyeth)',
	'Mephentermine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEPHENTINE 10 (Wyeth)'
);

-- line #20213
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEPHENTINE 30 (Wyeth)',
	'Mephentermine',
	'VIAL',
	gm.nullify_empty_string('30')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEPHENTINE 30 (Wyeth)'
);

-- line #20214
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'6-MP 50 (German R.)',
	'Mercaptopurine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '6-MP 50 (German R.)'
);

-- line #20215
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMPURINE 50 (Dabur Ph.)',
	'Mercaptopurine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMPURINE 50 (Dabur Ph.)'
);

-- line #20216
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MERCAPTO 50 (CH.Bhagat)',
	'Mercaptopurine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MERCAPTO 50 (CH.Bhagat)'
);

-- line #20217
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PURINETHOL 50 (Gsk)',
	'Mercaptopurine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PURINETHOL 50 (Gsk)'
);

-- line #20218
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PURI-NETHOL 50 (GSK)',
	'Mercaptopurine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PURI-NETHOL 50 (GSK)'
);

-- line #20219
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PURINETONE 50 (CH.Bhagat)',
	'Mercaptopurine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PURINETONE 50 (CH.Bhagat)'
);

-- line #20220
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACEPENUM 1000 (ACE PH.)',
	'MEROPENEM',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACEPENUM 1000 (ACE PH.)'
);

-- line #20221
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'MEROPENEM', u'always_empty': u'', u'form': u'VIAL', u'brand': u'AMEROPEM', u'strength_3': u'', u'company': u'ADLEY PHARMA.', u'unit': u''}

-- line #20222
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMROPENEM 125 (HEALTH BIO.)',
	'MEROPENEM',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMROPENEM 125 (HEALTH BIO.)'
);

-- line #20223
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'MEROPENEM', u'always_empty': u'', u'form': u'TAB', u'brand': u'AMROPENEM', u'strength_3': u'', u'company': u'HEALTH BIO.', u'unit': u''}

-- line #20224
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMROPENEM 500 (HEALTH BIO.)',
	'MEROPENEM',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMROPENEM 500 (HEALTH BIO.)'
);

-- line #20225
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZOPEN GM 1000 (Rpg Life)',
	'MEROPENEM',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZOPEN GM 1000 (Rpg Life)'
);

-- line #20226
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZOPEN GM 500 (Rpg Life)',
	'MEROPENEM',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZOPEN GM 500 (Rpg Life)'
);

-- line #20227
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'MEROPENEM', u'always_empty': u'', u'form': u'INJ', u'brand': u'CARBAPEN-M', u'strength_3': u'', u'company': u'Blue Cross', u'unit': u''}

-- line #20228
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARBAPEN-M 500 (Blue Cross)',
	'MEROPENEM',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg(+SODIUM CARBONATE 45.1'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARBAPEN-M 500 (Blue Cross)'
);

-- line #20229
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1GM', u'strength_2': u'', u'substance': u'MEROPENEM', u'always_empty': u'', u'form': u'INJ', u'brand': u'CIDAPENEM GM', u'strength_3': u'', u'company': u'Samarth Life', u'unit': u''}

-- line #20230
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIDAPENEM 500 (Samarth Life)',
	'MEROPENEM',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIDAPENEM 500 (Samarth Life)'
);

-- line #20231
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G(SODIUM 90.2', u'strength_2': u'', u'substance': u'MEROPENEM', u'always_empty': u'', u'form': u'', u'brand': u'ESBLANEM G', u'strength_3': u'', u'company': u'Gsk', u'unit': u'mg)'}

-- line #20232
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500', u'strength_2': u'', u'substance': u'MEROPENEM', u'always_empty': u'', u'form': u'', u'brand': u'ESBLANEM', u'strength_3': u'', u'company': u'Gsk', u'unit': u'mg(SODIUM CARBONATE 45.1'}

-- line #20233
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250', u'strength_2': u'', u'substance': u'MEROPENEM', u'always_empty': u'', u'form': u'', u'brand': u'EUPEN', u'strength_3': u'', u'company': u'Neon', u'unit': u'mg'}

-- line #20234
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'MEROPENEM', u'always_empty': u'', u'form': u'VIAL', u'brand': u'EUPEN', u'strength_3': u'', u'company': u'Neon', u'unit': u''}

-- line #20235
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUPEN 500 (Neon)',
	'MEROPENEM',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUPEN 500 (Neon)'
);

-- line #20236
-- ignoring line: field [strength_1] not numeric: >>>1G<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'500', u'substance': u'MEROPENEM', u'always_empty': u'', u'form': u'VIAL', u'brand': u'EXMER G/500', u'strength_3': u'', u'company': u'EXCELLA', u'unit': u'mg'}

-- line #20237
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1GM', u'strength_2': u'', u'substance': u'MEROPENEM', u'always_empty': u'', u'form': u'VIAL', u'brand': u'EXMER GM', u'strength_3': u'', u'company': u'EXCELLA', u'unit': u''}

-- line #20238
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXMER 500 (EXCELLA)',
	'MEROPENEM',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXMER 500 (EXCELLA)'
);

-- line #20239
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'MEROPENEM', u'always_empty': u'', u'form': u'VIAL', u'brand': u'FEROPENEM', u'strength_3': u'', u'company': u'FERON LS', u'unit': u''}

-- line #20240
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEROPENEM 500 (FERON LS)',
	'MEROPENEM',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEROPENEM 500 (FERON LS)'
);

-- line #20241
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ICUBAC 1000 (Sandoz)',
	'MEROPENEM',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg(+90.2'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ICUBAC 1000 (Sandoz)'
);

-- line #20242
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ICUBAC 500 (Sandoz)',
	'MEROPENEM',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg (+45.1'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ICUBAC 500 (Sandoz)'
);

-- line #20243
-- ignoring line: field [strength_1] not numeric: >>>1000(ANHYDR.)<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000(ANHYDR.)', u'strength_2': u'', u'substance': u'MEROPENEM', u'always_empty': u'', u'form': u'INJ', u'brand': u'INLIFE', u'strength_3': u'', u'company': u'Medispan', u'unit': u'NA 90.2'}

-- line #20244
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INNOMER 1000 (INNOVA LIFESCI.)',
	'MEROPENEM',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INNOMER 1000 (INNOVA LIFESCI.)'
);

-- line #20245
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INNOMER 500 (INNOVA LIFESCI.)',
	'MEROPENEM',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INNOMER 500 (INNOVA LIFESCI.)'
);

-- line #20246
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'MEROPENEM', u'always_empty': u'', u'form': u'INJ', u'brand': u'INPENAM', u'strength_3': u'', u'company': u'Intra Lab', u'unit': u''}

-- line #20247
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'MEROPENEM', u'always_empty': u'', u'form': u'INJ', u'brand': u'KANAM', u'strength_3': u'', u'company': u'FLAMINGO PH.', u'unit': u''}

-- line #20248
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KANAM 500 (FLAMINGO PH.)',
	'MEROPENEM',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KANAM 500 (FLAMINGO PH.)'
);

-- line #20249
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1GM', u'strength_2': u'', u'substance': u'MEROPENEM', u'always_empty': u'', u'form': u'INJ', u'brand': u'LAURUNAM', u'strength_3': u'', u'company': u'STAUNCH', u'unit': u''}

-- line #20250
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAP 500 (Health Care)',
	'MEROPENEM',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAP 500 (Health Care)'
);

-- line #20251
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'MEROPENEM', u'always_empty': u'', u'form': u'VIAL', u'brand': u'MARNIF', u'strength_3': u'', u'company': u'AAMORB(ST. MORISON)', u'unit': u''}

-- line #20252
-- ignoring line: field [strength_1] not numeric: >>>1000(ANHYDR.)<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000(ANHYDR.)', u'strength_2': u'', u'substance': u'MEROPENEM', u'always_empty': u'', u'form': u'INJ', u'brand': u'MAXINEM', u'strength_3': u'', u'company': u'VHB', u'unit': u'NA 86'}

-- line #20253
-- ignoring line: field [strength_1] not numeric: >>>500(ANHYDR.)<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500(ANHYDR.)', u'strength_2': u'', u'substance': u'MEROPENEM', u'always_empty': u'', u'form': u'INJ', u'brand': u'MAXINEM', u'strength_3': u'', u'company': u'VHB', u'unit': u'NA 43'}

-- line #20254
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1GM', u'strength_2': u'', u'substance': u'MEROPENEM', u'always_empty': u'', u'form': u'VIAL', u'brand': u'MAXOPEN', u'strength_3': u'', u'company': u'Samarth', u'unit': u''}

-- line #20255
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAXOPEN 500 (Samarth)',
	'MEROPENEM',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAXOPEN 500 (Samarth)'
);

-- line #20256
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1GM', u'strength_2': u'', u'substance': u'MEROPENEM', u'always_empty': u'', u'form': u'INJ', u'brand': u'MENEM', u'strength_3': u'', u'company': u'United Bio.', u'unit': u''}

-- line #20257
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MENEM 500 (United Bio.)',
	'MEROPENEM',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MENEM 500 (United Bio.)'
);

-- line #20258
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'MEROPENEM', u'always_empty': u'', u'form': u'', u'brand': u'MEPEM GM', u'strength_3': u'', u'company': u'ZYPHARS PH.', u'unit': u''}

-- line #20259
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500', u'strength_2': u'', u'substance': u'MEROPENEM', u'always_empty': u'', u'form': u'', u'brand': u'MEPEM', u'strength_3': u'', u'company': u'ZYPHARS PH.', u'unit': u'mg'}

-- line #20260
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'MEROPENEM', u'always_empty': u'', u'form': u'VIAL', u'brand': u'MERENZ', u'strength_3': u'', u'company': u'ADMAC(LEE BENZ)', u'unit': u''}

-- line #20261
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'MEROPENEM', u'always_empty': u'', u'form': u'VIAL', u'brand': u'MEROBACT', u'strength_3': u'', u'company': u'INVISION', u'unit': u''}

-- line #20262
-- ignoring line: field [strength_1] not numeric: >>>1G<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'500', u'substance': u'MEROPENEM', u'always_empty': u'', u'form': u'VIAL', u'brand': u'MEROBEST G/500', u'strength_3': u'', u'company': u'SHRESHTHA', u'unit': u'mg'}

-- line #20263
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'MEROPENEM', u'always_empty': u'', u'form': u'INJ', u'brand': u'MEROCIDE', u'strength_3': u'', u'company': u'Gland Ph.', u'unit': u''}

-- line #20264
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEROCIDE 500 (Gland Ph.)',
	'MEROPENEM',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEROCIDE 500 (Gland Ph.)'
);

-- line #20265
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEROCRIT BABY 125 (Cipla)',
	'MEROPENEM',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg (SOD. 11.28'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEROCRIT BABY 125 (Cipla)'
);

-- line #20266
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'MEROPENEM', u'always_empty': u'', u'form': u'INJ', u'brand': u'MEROCRIT', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #20267
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEROCRIT 250 (Cipla)',
	'MEROPENEM',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg (SOD. 22.55'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEROCRIT 250 (Cipla)'
);

-- line #20268
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEROCRIT 500 (Cipla)',
	'MEROPENEM',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEROCRIT 500 (Cipla)'
);

-- line #20269
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G(SODIUM CARBONATE EQ TO (SODIUM) 98.2', u'strength_2': u'', u'substance': u'MEROPENEM', u'always_empty': u'', u'form': u'', u'brand': u'MERO FAST', u'strength_3': u'', u'company': u'SYNER MED.', u'unit': u'mg)'}

-- line #20270
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEROGOL 1000 (Parenteral)',
	'MEROPENEM',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEROGOL 1000 (Parenteral)'
);

-- line #20271
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEROGOL 500 (Parenteral)',
	'MEROPENEM',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEROGOL 500 (Parenteral)'
);

-- line #20272
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1GM', u'strength_2': u'', u'substance': u'MEROPENEM', u'always_empty': u'', u'form': u'INJ', u'brand': u'MEROJET', u'strength_3': u'', u'company': u'LYKA LABS', u'unit': u''}

-- line #20273
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEROJET 500 (LYKA LABS)',
	'MEROPENEM',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEROJET 500 (LYKA LABS)'
);

-- line #20274
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEROKEM 125 (TAJ PH.)',
	'MEROPENEM',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEROKEM 125 (TAJ PH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEROKEM 500 (TAJ PH.)',
	'MEROPENEM',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEROKEM 500 (TAJ PH.)'
);

-- line #20275
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'MEROPENEM', u'always_empty': u'', u'form': u'INJ', u'brand': u'MEROKEM', u'strength_3': u'', u'company': u'TAJ PH.', u'unit': u''}

-- line #20276
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEROMAC 125 (Macleods)',
	'MEROPENEM',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg(+SOD.CARB. 11.275'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEROMAC 125 (Macleods)'
);

-- line #20277
-- ignoring line: field [strength_1] not numeric: >>>0.2G (18.04<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.2G (18.04', u'strength_2': u'', u'substance': u'MEROPENEM', u'always_empty': u'', u'form': u'VIAL', u'brand': u'MEROMAC PS', u'strength_3': u'', u'company': u'Macleods', u'unit': u'mg SODIUM CARB.)'}

-- line #20278
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEROMATE 500 (Baxter)',
	'MEROPENEM',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg/1G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEROMATE 500 (Baxter)'
);

-- line #20279
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEROMER 500 (Orchid Hc.)',
	'MEROPENEM',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg/1G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEROMER 500 (Orchid Hc.)'
);

-- line #20280
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'MEROPENEM', u'always_empty': u'', u'form': u'INJ', u'brand': u'MERONEM', u'strength_3': u'', u'company': u'Astrazeneca', u'unit': u''}

-- line #20281
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MERONEM 500 (Astrazeneca)',
	'MEROPENEM',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MERONEM 500 (Astrazeneca)'
);

-- line #20282
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'MEROPENEM', u'always_empty': u'', u'form': u'VIAL', u'brand': u'MERONIS', u'strength_3': u'', u'company': u'NEISS', u'unit': u''}

-- line #20283
-- ignoring line: field [strength_1] not numeric: >>>1G<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'500', u'substance': u'MEROPENEM', u'always_empty': u'', u'form': u'VIAL', u'brand': u'MEROPAM G/500', u'strength_3': u'', u'company': u'Osper', u'unit': u'mg'}

-- line #20284
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEROPAM 125 (Osper)',
	'MEROPENEM',
	'VIAL',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEROPAM 125 (Osper)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEROPAM 250 (Osper)',
	'MEROPENEM',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEROPAM 250 (Osper)'
);

-- line #20285
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'MEROPENEM', u'always_empty': u'', u'form': u'', u'brand': u'MEROPLAN GM', u'strength_3': u'', u'company': u'Piramal Hc.', u'unit': u''}

-- line #20286
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500', u'strength_2': u'', u'substance': u'MEROPENEM', u'always_empty': u'', u'form': u'', u'brand': u'MEROPLAN', u'strength_3': u'', u'company': u'Piramal Hc.', u'unit': u'mg'}

-- line #20287
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'MEROPENEM', u'always_empty': u'', u'form': u'INJ', u'brand': u'MEROSE', u'strength_3': u'', u'company': u'ROSE LABS', u'unit': u''}

-- line #20288
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEROS GM 1000 (ALEXUS(SURYA))',
	'MEROPENEM',
	'VIAL',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEROS GM 1000 (ALEXUS(SURYA))'
);

-- line #20289
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'MEROPENEM', u'always_empty': u'', u'form': u'INJ', u'brand': u'MEROSTA', u'strength_3': u'', u'company': u'Bharat S.', u'unit': u''}

-- line #20290
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEROS 500 (ALEXUS(SURYA))',
	'MEROPENEM',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg(ANHYDROUS)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEROS 500 (ALEXUS(SURYA))'
);

-- line #20291
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'MEROPENEM', u'always_empty': u'', u'form': u'', u'brand': u'MEROTAZ GM', u'strength_3': u'', u'company': u'Nippon Siy.', u'unit': u''}

-- line #20292
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEROTEC 500 (Zuventus)',
	'MEROPENEM',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEROTEC 500 (Zuventus)'
);

-- line #20293
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'MEROPENEM', u'always_empty': u'', u'form': u'', u'brand': u'MEROTEC IV', u'strength_3': u'', u'company': u'Zuventus', u'unit': u''}

-- line #20294
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'MEROPENEM', u'always_empty': u'', u'form': u'INJ', u'brand': u'MEROTOP', u'strength_3': u'', u'company': u'Sanat', u'unit': u''}

-- line #20295
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEROTOP 500 (Sanat)',
	'MEROPENEM',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEROTOP 500 (Sanat)'
);

-- line #20296
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.25G', u'strength_2': u'', u'substance': u'MEROPENEM', u'always_empty': u'', u'form': u'INJ', u'brand': u'MEROTROL', u'strength_3': u'', u'company': u'LUPIN', u'unit': u''}

-- line #20297
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'MEROPENEM', u'always_empty': u'', u'form': u'INJ', u'brand': u'MEROTROL', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #20298
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEROTROL 500 (Lupin)',
	'MEROPENEM',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEROTROL 500 (Lupin)'
);

-- line #20299
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000', u'strength_2': u'', u'substance': u'MEROPENEM', u'always_empty': u'', u'form': u'', u'brand': u'MEROWIN', u'strength_3': u'', u'company': u'Grandix', u'unit': u'mg(+SOD. AS BUFFER 90.2'}

-- line #20300
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEROZA 500 (German R.)',
	'MEROPENEM',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg/1G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEROZA 500 (German R.)'
);

-- line #20301
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000', u'strength_2': u'', u'substance': u'MEROPENEM', u'always_empty': u'', u'form': u'', u'brand': u'MICROPENAM', u'strength_3': u'', u'company': u'Micro Labs', u'unit': u'mg'}

-- line #20302
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'M-NEM 1000 (AVENTIS PH.)',
	'MEROPENEM',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg(SODIUM CARBONATE IP EQ TO SODIUM 90.2'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'M-NEM 1000 (AVENTIS PH.)'
);

-- line #20303
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'M-NEM 500 (AVENTIS PH.)',
	'MEROPENEM',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg(SODIUM CARBONATE IP EQ TO SODIUM 45.1'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'M-NEM 500 (AVENTIS PH.)'
);

-- line #20304
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1GM', u'strength_2': u'', u'substance': u'MEROPENEM', u'always_empty': u'', u'form': u'INJ', u'brand': u'MOREPENEM', u'strength_3': u'', u'company': u'Morepen', u'unit': u''}

-- line #20305
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'MEROPENEM', u'always_empty': u'', u'form': u'INJ', u'brand': u'MUCAD', u'strength_3': u'', u'company': u'Cadila Ph.', u'unit': u''}

-- line #20306
-- ignoring line: field [strength_1] not numeric: >>>1G<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'500', u'substance': u'MEROPENEM', u'always_empty': u'', u'form': u'INJ', u'brand': u'ONMERO', u'strength_3': u'', u'company': u'RISHAB(OROCHEM)', u'unit': u'mg'}

-- line #20307
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPEN 1000 (Zee Lab)',
	'MEROPENEM',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPEN 1000 (Zee Lab)'
);

-- line #20308
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PACETAKER 250 (LITTLE GREAVE)',
	'MEROPENEM',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PACETAKER 250 (LITTLE GREAVE)'
);

-- line #20309
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENEM 0.5 (Sanjivani)',
	'MEROPENEM',
	'INJ',
	gm.nullify_empty_string('0.5')::numeric,
	'1;G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENEM 0.5 (Sanjivani)'
);

-- line #20310
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500', u'strength_2': u'', u'substance': u'MEROPENEM', u'always_empty': u'', u'form': u'', u'brand': u'PENMER', u'strength_3': u'', u'company': u'Biocon', u'unit': u'mg'}

-- line #20311
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'MEROPENEM', u'always_empty': u'', u'form': u'INJ', u'brand': u'PENMER', u'strength_3': u'', u'company': u'Biocon', u'unit': u''}

-- line #20312
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'MEROPENEM', u'always_empty': u'', u'form': u'VIAL', u'brand': u'PIPACTUM', u'strength_3': u'', u'company': u'Zenon Hc.', u'unit': u''}

-- line #20313
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'5A 400 (Wallace)',
	'MESALAZINE(5-Amino Salicylic Acid)',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '5A 400 (Wallace)'
);

-- line #20314
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASACOL 400 (Win Medicare)',
	'MESALAZINE(5-Amino Salicylic Acid)',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASACOL 400 (Win Medicare)'
);

-- line #20315
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'4G', u'strength_2': u'', u'substance': u'MESALAZINE(5-Amino Salicylic Acid)', u'always_empty': u'', u'form': u'TAB', u'brand': u'ASACOL', u'strength_3': u'', u'company': u'Win-Medicare', u'unit': u''}

-- line #20316
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.2G(MESALAMINE)', u'strength_2': u'', u'substance': u'MESALAZINE(5-Amino Salicylic Acid)', u'always_empty': u'', u'form': u'TAB', u'brand': u'COOLGUT', u'strength_3': u'', u'company': u'Torrent', u'unit': u''}

-- line #20317
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COSACOL 400 (Cfl Ph.)',
	'MESALAZINE(5-Amino Salicylic Acid)',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COSACOL 400 (Cfl Ph.)'
);

-- line #20318
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELMES 500 (Elder)',
	'MESALAZINE(5-Amino Salicylic Acid)',
	'SAC',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELMES 500 (Elder)'
);

-- line #20319
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETIASA 500 (NOVARTIS)',
	'MESALAZINE(5-Amino Salicylic Acid)',
	'SAC',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETIASA 500 (NOVARTIS)'
);

-- line #20320
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.2G(MESALAMINE)', u'strength_2': u'', u'substance': u'MESALAZINE(5-Amino Salicylic Acid)', u'always_empty': u'', u'form': u'SR TAB', u'brand': u'INFLACOL', u'strength_3': u'', u'company': u'Intas', u'unit': u''}

-- line #20321
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INFLACOL 400 (Intas)',
	'MESALAZINE(5-Amino Salicylic Acid)',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg (MESALAMINE U S P)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INFLACOL 400 (Intas)'
);

-- line #20322
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INFLACOL 800 (INTAS)',
	'MESALAZINE(5-Amino Salicylic Acid)',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg(MESALAMINE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INFLACOL 800 (INTAS)'
);

-- line #20323
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAZAKOOL 400 (Alembic)',
	'MESALAZINE(5-Amino Salicylic Acid)',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAZAKOOL 400 (Alembic)'
);

-- line #20324
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.2G(MESALAMINE PROLONGED)', u'strength_2': u'', u'substance': u'MESALAZINE(5-Amino Salicylic Acid)', u'always_empty': u'', u'form': u'OD TAB', u'brand': u'MESACOL', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #20325
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENTASA 500 (Ferring Ph.)',
	'MESALAZINE(5-Amino Salicylic Acid)',
	'SR TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENTASA 500 (Ferring Ph.)'
);

-- line #20326
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.2G(MESALAMINE)', u'strength_2': u'', u'substance': u'MESALAZINE(5-Amino Salicylic Acid)', u'always_empty': u'', u'form': u'OD TAB', u'brand': u'PROCOL', u'strength_3': u'', u'company': u'DELVIN', u'unit': u''}

-- line #20327
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'4G', u'strength_2': u'', u'substance': u'MESALAZINE', u'always_empty': u'', u'form': u'', u'brand': u'MESACOL ENEMA', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #20328
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MESACOL 500 (Sun)',
	'MESALAZINE',
	'SUPPOS',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MESACOL 500 (Sun)'
);

-- line #20329
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MESACOL 400 (Sun)',
	'MESALAZINE',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MESACOL 400 (Sun)'
);

-- line #20330
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MESACOL 800 (Sun)',
	'MESALAZINE',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MESACOL 800 (Sun)'
);

-- line #20331
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MESNA 200 (Alkem)',
	'MESNA',
	'AMP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MESNA 200 (Alkem)'
);

-- line #20332
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MESNA 2 (Cytomed(Alkem))',
	'Mesna',
	'AMP.',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MESNA 2 (Cytomed(Alkem))'
);

-- line #20333
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MESNA CYTOCARE 200 (Vhb)',
	'MESNA',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MESNA CYTOCARE 200 (Vhb)'
);

-- line #20334
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MESNA 200 (Cipla)',
	'MESNA',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MESNA 200 (Cipla)'
);

-- line #20335
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MESNA 100 (Dabur Ph.)',
	'Mesna',
	'INJ.',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MESNA 100 (Dabur Ph.)'
);

-- line #20336
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MISTABRON 200 (Ucb India)',
	'Mesna',
	'AMP',
	gm.nullify_empty_string('200')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MISTABRON 200 (Ucb India)'
);

-- line #20337
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MESTILON 25 (Uni-Sank.)',
	'Mesterolone',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MESTILON 25 (Uni-Sank.)'
);

-- line #20338
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROVIRONUM 25 (German R.)',
	'Mesterolone',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROVIRONUM 25 (German R.)'
);

-- line #20339
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESTORE 25 (Brown & B.)',
	'Mesterolone',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESTORE 25 (Brown & B.)'
);

-- line #20340
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METABAX 500 (Ranbaxy)',
	'METASOXINE',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METABAX 500 (Ranbaxy)'
);

-- line #20341
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METADOXIL 60 (Micro Labs)',
	'METASOXINE',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METADOXIL 60 (Micro Labs)'
);

-- line #20342
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METADOXIL 500 (Micro Labs)',
	'METASOXINE',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METADOXIL 500 (Micro Labs)'
);

-- line #20343
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASOFORMIN 500 (AS PHARMA)',
	'Metformin',
	'SR TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASOFORMIN 500 (AS PHARMA)'
);

-- line #20344
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASOFORMIN 500 (AS PHARMA)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASOFORMIN 500 (AS PHARMA)'
);

-- line #20345
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATFORMIN 500 (Active Hc.)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATFORMIN 500 (Active Hc.)'
);

-- line #20346
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BAYMET 500 (Bayer)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BAYMET 500 (Bayer)'
);

-- line #20347
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Metformin', u'always_empty': u'', u'form': u'SR TAB', u'brand': u'BDID', u'strength_3': u'', u'company': u'SINSAN PH.', u'unit': u''}

-- line #20348
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Metformin', u'always_empty': u'', u'form': u'TAB', u'brand': u'BDID TH', u'strength_3': u'', u'company': u'SINSAN PH.', u'unit': u''}

-- line #20349
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIDIAB 500 (Pfizer)',
	'Metformin',
	'SR TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIDIAB 500 (Pfizer)'
);

-- line #20350
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIDIAB 850 (Pfizer)',
	'Metformin',
	'SR TAB',
	gm.nullify_empty_string('850')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIDIAB 850 (Pfizer)'
);

-- line #20351
-- ignoring line: field [strength_1] not numeric: >>>1G<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'500', u'substance': u'Metformin', u'always_empty': u'', u'form': u'TAB', u'brand': u'BIGESENS G/500', u'strength_3': u'', u'company': u'Zydus Cadila', u'unit': u'mg'}

-- line #20352
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Metformin', u'always_empty': u'', u'form': u'XR TAB', u'brand': u'BIGESENS', u'strength_3': u'', u'company': u'Zydus Cadila', u'unit': u''}

-- line #20353
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIGESENS 500 (Zydus Cadila)',
	'Metformin',
	'XR TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIGESENS 500 (Zydus Cadila)'
);

-- line #20354
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'750', u'strength_2': u'', u'substance': u'Metformin', u'always_empty': u'', u'form': u'', u'brand': u'BIGOMET', u'strength_3': u'', u'company': u'Otsira', u'unit': u'mg'}

-- line #20355
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIGOMET 1000 (Otsira)',
	'Metformin',
	'SR TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIGOMET 1000 (Otsira)'
);

-- line #20356
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIGOMET 500 (Otsira)',
	'Metformin',
	'SR TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIGOMET 500 (Otsira)'
);

-- line #20357
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIGOMET 250 (Otsira)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIGOMET 250 (Otsira)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIGOMET 500 (Otsira)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIGOMET 500 (Otsira)'
);

-- line #20358
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIGOMET 850 (Otsira)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('850')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIGOMET 850 (Otsira)'
);

-- line #20359
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARBOPHAGE 100 (Merck)',
	'Metformin',
	'SR',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARBOPHAGE 100 (Merck)'
);

-- line #20360
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARBOPHAGE 500 (Merck)',
	'Metformin',
	'SR',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARBOPHAGE 500 (Merck)'
);

-- line #20361
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETAPIN 500 (Sanofi Aventis)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETAPIN 500 (Sanofi Aventis)'
);

-- line #20362
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETAPIN 1000 (AVENTIS)',
	'Metformin',
	'XR TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETAPIN 1000 (AVENTIS)'
);

-- line #20363
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETAPIN 500 (AVENTIS)',
	'Metformin',
	'XR TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETAPIN 500 (AVENTIS)'
);

-- line #20364
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-MINE 500 (Corona)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-MINE 500 (Corona)'
);

-- line #20365
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONFORMIN 500 (CONCERTINA)',
	'Metformin',
	'SR TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg/1000'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONFORMIN 500 (CONCERTINA)'
);

-- line #20366
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAOMET 100 (J. B. Chem.)',
	'Metformin',
	'SR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg (SR)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAOMET 100 (J. B. Chem.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAOMET 500 (J. B. Chem.)',
	'Metformin',
	'SR TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg (SR)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAOMET 500 (J. B. Chem.)'
);

-- line #20367
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAOMET 100 (J.B.Chem.)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAOMET 100 (J.B.Chem.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAOMET 500 (J.B.Chem.)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAOMET 500 (J.B.Chem.)'
);

-- line #20368
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'D-BAY 500 (Argus)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'D-BAY 500 (Argus)'
);

-- line #20369
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'D-BAY 850 (Argus)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('850')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'D-BAY 850 (Argus)'
);

-- line #20370
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIAFER 500 (EAST WEST)',
	'Metformin',
	'ER TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIAFER 500 (EAST WEST)'
);

-- line #20371
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIAFER 850 (EAST WEST)',
	'Metformin',
	'F. TAB',
	gm.nullify_empty_string('850')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIAFER 850 (EAST WEST)'
);

-- line #20372
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIAFER 500 (EAST WEST)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIAFER 500 (EAST WEST)'
);

-- line #20373
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIAFORMIN 500 (Cfl Ph.)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIAFORMIN 500 (Cfl Ph.)'
);

-- line #20374
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIAFORMIN 850 (Cfl Ph.)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('850')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIAFORMIN 850 (Cfl Ph.)'
);

-- line #20375
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIAMET 1000 (Bal Ph.)',
	'Metformin',
	'SR TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIAMET 1000 (Bal Ph.)'
);

-- line #20376
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIAMET 500 (Bal Ph.)',
	'Metformin',
	'SR TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIAMET 500 (Bal Ph.)'
);

-- line #20377
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIAMET 500 (Bal Ph.)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIAMET 500 (Bal Ph.)'
);

-- line #20378
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIAMET 850 (Bal Ph.)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('850')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIAMET 850 (Bal Ph.)'
);

-- line #20379
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIAMIN 500 (Sain Med.)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIAMIN 500 (Sain Med.)'
);

-- line #20380
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIBETA 1000 (Torrent)',
	'Metformin',
	'SR TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIBETA 1000 (Torrent)'
);

-- line #20381
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Metformin', u'always_empty': u'', u'form': u'SR TAB', u'brand': u'DIBETA', u'strength_3': u'', u'company': u'Torrent', u'unit': u''}

-- line #20382
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIBETA 500 (Torrent)',
	'Metformin',
	'SR TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIBETA 500 (Torrent)'
);

-- line #20383
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIBETA TR 1000 (Torrent)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIBETA TR 1000 (Torrent)'
);

-- line #20384
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIBETA TR 500 (Torrent)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIBETA TR 500 (Torrent)'
);

-- line #20385
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIBIMET 500 (Novartis)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIBIMET 500 (Novartis)'
);

-- line #20386
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIFORM 500 (LA DRUG)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIFORM 500 (LA DRUG)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIFORM 850 (LA DRUG)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('850')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIFORM 850 (LA DRUG)'
);

-- line #20387
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'D-MET 1000 (GRANDIX)',
	'Metformin',
	'SR TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'D-MET 1000 (GRANDIX)'
);

-- line #20388
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'D-MET 500 (GRANDIX)',
	'Metformin',
	'SR TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'D-MET 500 (GRANDIX)'
);

-- line #20389
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'D-MET 250 (GRANDIX)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'D-MET 250 (GRANDIX)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'D-MET 500 (GRANDIX)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'D-MET 500 (GRANDIX)'
);

-- line #20390
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'D-MET 850 (GRANDIX)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('850')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'D-MET 850 (GRANDIX)'
);

-- line #20391
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOKMET 500 (J. B. Chem.)',
	'Metformin',
	'SR TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOKMET 500 (J. B. Chem.)'
);

-- line #20392
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUOMET 1000 (BIOCHEM)',
	'Metformin',
	'ER TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUOMET 1000 (BIOCHEM)'
);

-- line #20393
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUOMET 500 (Biochem)',
	'Metformin',
	'ER TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUOMET 500 (Biochem)'
);

-- line #20394
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMFOR 500 (Stadmed)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMFOR 500 (Stadmed)'
);

-- line #20395
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMNORM 500 (Ipca)',
	'Metformin',
	'ER TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMNORM 500 (Ipca)'
);

-- line #20396
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMNORM 1000 (Ipca)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMNORM 1000 (Ipca)'
);

-- line #20397
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMNORM 250 (Ipca)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMNORM 250 (Ipca)'
);

-- line #20398
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMNORM 500 (Ipca)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMNORM 500 (Ipca)'
);

-- line #20399
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMNORM 850 (Ipca)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('850')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMNORM 850 (Ipca)'
);

-- line #20400
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETFORMIN 500 (Dey''S)',
	'Metformin',
	'SR TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETFORMIN 500 (Dey''S)'
);

-- line #20401
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETFORMIN 500 (Dey''S)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETFORMIN 500 (Dey''S)'
);

-- line #20402
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUMET 500 (Symbiotic)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUMET 500 (Symbiotic)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUMET 850 (Symbiotic)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('850')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUMET 850 (Symbiotic)'
);

-- line #20403
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EVIZEN 1000 (NOVARTIS)',
	'Metformin',
	'BR TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EVIZEN 1000 (NOVARTIS)'
);

-- line #20404
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EVIZEN 500 (NOVARTIS)',
	'Metformin',
	'BR TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EVIZEN 500 (NOVARTIS)'
);

-- line #20405
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXERMET 500 (Cipla)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg/1G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXERMET 500 (Cipla)'
);

-- line #20406
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXERMET 850 (Cipla)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('850')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXERMET 850 (Cipla)'
);

-- line #20407
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Metformin', u'always_empty': u'', u'form': u'SR TAB', u'brand': u'FORMET', u'strength_3': u'', u'company': u'Chemech', u'unit': u''}

-- line #20408
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORMET 500 (Chemech)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORMET 500 (Chemech)'
);

-- line #20409
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Metformin', u'always_empty': u'', u'form': u'SR TAB', u'brand': u'FORMINAL', u'strength_3': u'', u'company': u'Alembic', u'unit': u''}

-- line #20410
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORMINAL 500 (Alembic)',
	'Metformin',
	'SR TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORMINAL 500 (Alembic)'
);

-- line #20411
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORMINAL 500 (Alembic)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORMINAL 500 (Alembic)'
);

-- line #20412
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORMINAL 850 (Alembic)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('850')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORMINAL 850 (Alembic)'
);

-- line #20413
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORMIN 1000 (Alkem)',
	'Metformin',
	'SR TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORMIN 1000 (Alkem)'
);

-- line #20414
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORMIN 500 (Alkem)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORMIN 500 (Alkem)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORMIN 850 (Alkem)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('850')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORMIN 850 (Alkem)'
);

-- line #20415
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FRAME 500 (TRITON(CALYX))',
	'Metformin',
	'SR TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FRAME 500 (TRITON(CALYX))'
);

-- line #20416
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUCONORM 500 (Lupin)',
	'Metformin',
	'SR TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg/1G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUCONORM 500 (Lupin)'
);

-- line #20417
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUFORMIN 500 (Nicholas)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUFORMIN 500 (Nicholas)'
);

-- line #20418
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUFORMIN 850 (Nicholas)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('850')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUFORMIN 850 (Nicholas)'
);

-- line #20419
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUFORMIN 1000 (Nicholas)',
	'Metformin',
	'XL TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg(S.R.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUFORMIN 1000 (Nicholas)'
);

-- line #20420
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUFORMIN 500 (Nicholas)',
	'Metformin',
	'XL TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg(S.R.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUFORMIN 500 (Nicholas)'
);

-- line #20421
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUMET EXT 500 (Cipla)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUMET EXT 500 (Cipla)'
);

-- line #20422
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUMET 500 (Protec)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUMET 500 (Protec)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUMET 850 (Protec)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('850')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUMET 850 (Protec)'
);

-- line #20423
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUMET 500 (Protec)',
	'Metformin',
	'XR TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUMET 500 (Protec)'
);

-- line #20424
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYCIFIT 1000 (Shreya)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg(SR)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYCIFIT 1000 (Shreya)'
);

-- line #20425
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYCIFORMIN 500 (Stanmark)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg(SR)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYCIFORMIN 500 (Stanmark)'
);

-- line #20426
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYCIPHAGE 100 (Franco I.)',
	'Metformin',
	'SOL',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYCIPHAGE 100 (Franco I.)'
);

-- line #20427
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1GM', u'strength_2': u'', u'substance': u'Metformin', u'always_empty': u'', u'form': u'SR TAB', u'brand': u'GLYCIPHAGE', u'strength_3': u'', u'company': u'Franco I.', u'unit': u''}

-- line #20428
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYCIPHAGE 500 (Franco I.)',
	'Metformin',
	'SR TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYCIPHAGE 500 (Franco I.)'
);

-- line #20429
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYCIPHAGE 250 (Franco I.)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYCIPHAGE 250 (Franco I.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYCIPHAGE 500 (Franco I.)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYCIPHAGE 500 (Franco I.)'
);

-- line #20430
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYCIPHAGE 850 (Franco I.)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('850')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYCIPHAGE 850 (Franco I.)'
);

-- line #20431
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYCIZ 500 (Indu D.)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYCIZ 500 (Indu D.)'
);

-- line #20432
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYCOMET 850 (PHARMA(USV))',
	'Metformin',
	'SR',
	gm.nullify_empty_string('850')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYCOMET 850 (PHARMA(USV))'
);

-- line #20433
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1GM', u'strength_2': u'', u'substance': u'Metformin', u'always_empty': u'', u'form': u'SR TAB', u'brand': u'GLYCOMET', u'strength_3': u'', u'company': u'U S V', u'unit': u''}

-- line #20434
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYCOMET 500 (USV LTD)',
	'Metformin',
	'SR TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYCOMET 500 (USV LTD)'
);

-- line #20435
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYCOMET 500 (U S V)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYCOMET 500 (U S V)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYCOMET 850 (U S V)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('850')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYCOMET 850 (U S V)'
);

-- line #20436
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Metformin', u'always_empty': u'', u'form': u'TAB', u'brand': u'GLYCOMET', u'strength_3': u'', u'company': u'USV LTD', u'unit': u''}

-- line #20437
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYCOMET 250 (USV LTD)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYCOMET 250 (USV LTD)'
);

-- line #20438
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYREP 1000 (Emcure)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYREP 1000 (Emcure)'
);

-- line #20439
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYREP 500 (Emcure)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYREP 500 (Emcure)'
);

-- line #20440
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G-MET 850 (EAST WEST)',
	'Metformin',
	'F.',
	gm.nullify_empty_string('850')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G-MET 850 (EAST WEST)'
);

-- line #20441
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G-MET 250 (EAST WEST)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg/500'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G-MET 250 (EAST WEST)'
);

-- line #20442
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G-MET 500 (EAST WEST)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G-MET 500 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G-MET 850 (EAST WEST)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('850')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G-MET 850 (EAST WEST)'
);

-- line #20443
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Metformin', u'always_empty': u'', u'form': u'SR TAB', u'brand': u'GREG', u'strength_3': u'', u'company': u'Mano', u'unit': u''}

-- line #20444
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GREG 500 (Mano)',
	'Metformin',
	'SR TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GREG 500 (Mano)'
);

-- line #20445
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G-REG 500 (Orchid Hc.)',
	'Metformin',
	'SR TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G-REG 500 (Orchid Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G-REG 1000 (Orchid Hc.)',
	'Metformin',
	'SR TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G-REG 1000 (Orchid Hc.)'
);

-- line #20446
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GREG 250 (Mano)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GREG 250 (Mano)'
);

-- line #20447
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GREG 500 (Mano)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GREG 500 (Mano)'
);

-- line #20448
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GREG 850 (Mano)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('850')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GREG 850 (Mano)'
);

-- line #20449
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G-REG 250 (Orchid Hc.)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G-REG 250 (Orchid Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G-REG 500 (Orchid Hc.)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G-REG 500 (Orchid Hc.)'
);

-- line #20450
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G-REG 850 (Orchid Hc.)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('850')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G-REG 850 (Orchid Hc.)'
);

-- line #20451
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HERMTF 500 (Torrent)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HERMTF 500 (Torrent)'
);

-- line #20452
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INNOMET 1000 (INNOVA LIFESCI.)',
	'Metformin',
	'SR TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INNOMET 1000 (INNOVA LIFESCI.)'
);

-- line #20453
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INNOMET 500 (INNOVA LIFESCI.)',
	'Metformin',
	'SR TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INNOMET 500 (INNOVA LIFESCI.)'
);

-- line #20454
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INSUMET 1000 (CADILA PH.)',
	'Metformin',
	'SR TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INSUMET 1000 (CADILA PH.)'
);

-- line #20455
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INSUMET 500 (Cadila Ph.)',
	'Metformin',
	'SR TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INSUMET 500 (Cadila Ph.)'
);

-- line #20456
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INSUMET 500 (Cadila Ph.)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INSUMET 500 (Cadila Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INSUMET 850 (Cadila Ph.)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('850')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INSUMET 850 (Cadila Ph.)'
);

-- line #20457
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'K-MET 500 (Blue Cross)',
	'Metformin',
	'SR TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'K-MET 500 (Blue Cross)'
);

-- line #20458
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MATCE 500 (AAMORB(XEENA))',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MATCE 500 (AAMORB(XEENA))'
);

-- line #20459
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDFORMIN 500 (Medopharm)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDFORMIN 500 (Medopharm)'
);

-- line #20460
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDFOR 850 (SHINE PH.)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('850')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDFOR 850 (SHINE PH.)'
);

-- line #20461
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEFOMIN 1000 (Macleods)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEFOMIN 1000 (Macleods)'
);

-- line #20462
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEFOMIN 500 (Macleods)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEFOMIN 500 (Macleods)'
);

-- line #20463
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELMET 1000 (Micro Labs)',
	'Metformin',
	'SR TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELMET 1000 (Micro Labs)'
);

-- line #20464
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELMET 500 (Micro Labs)',
	'Metformin',
	'SR TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELMET 500 (Micro Labs)'
);

-- line #20465
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELMET 500 (Blue Cross)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELMET 500 (Blue Cross)'
);

-- line #20466
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MESITE XR 1000 (AVENTIS PH.)',
	'Metformin',
	'XL TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MESITE XR 1000 (AVENTIS PH.)'
);

-- line #20467
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MESITE XR 500 (AVENTIS PH.)',
	'Metformin',
	'XL TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MESITE XR 500 (AVENTIS PH.)'
);

-- line #20468
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METADOZE IPR 500 (Biocon)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METADOZE IPR 500 (Biocon)'
);

-- line #20469
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METADOZE-IPR 850 (Biocon)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('850')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METADOZE-IPR 850 (Biocon)'
);

-- line #20470
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METAFOR 500 (Meridian)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METAFOR 500 (Meridian)'
);

-- line #20471
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METAFORT 1200 (ERIS LIFE)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('1200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METAFORT 1200 (ERIS LIFE)'
);

-- line #20472
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METAFORT 1000 (ERIS THER.)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METAFORT 1000 (ERIS THER.)'
);

-- line #20473
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METAFORT 500 (ERIS THER.)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METAFORT 500 (ERIS THER.)'
);

-- line #20474
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METANORM 500 (Elder)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METANORM 500 (Elder)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METANORM 1000 (Elder)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METANORM 1000 (Elder)'
);

-- line #20475
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METAPHAGE 1000 (Meyer Org.)',
	'Metformin',
	'SR TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METAPHAGE 1000 (Meyer Org.)'
);

-- line #20476
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METATIME 500 (Mankind)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METATIME 500 (Mankind)'
);

-- line #20477
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METATIME 1000 (Mankind)',
	'Metformin',
	'XR',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METATIME 1000 (Mankind)'
);

-- line #20478
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METATIME 500 (Mankind)',
	'Metformin',
	'XR TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METATIME 500 (Mankind)'
);

-- line #20479
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000', u'strength_2': u'', u'substance': u'Metformin', u'always_empty': u'', u'form': u'', u'brand': u'METBAY', u'strength_3': u'', u'company': u'Bayer', u'unit': u'mg SR'}

-- line #20480
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500', u'strength_2': u'', u'substance': u'Metformin', u'always_empty': u'', u'form': u'', u'brand': u'METBAY', u'strength_3': u'', u'company': u'Bayer', u'unit': u'mg SR'}

-- line #20481
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METCHEK 500 (Indoco Rem.)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METCHEK 500 (Indoco Rem.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METCHEK 850 (Indoco Rem.)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('850')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METCHEK 850 (Indoco Rem.)'
);

-- line #20482
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METCOM 500 (Comed)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METCOM 500 (Comed)'
);

-- line #20483
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METCOM 850 (Comed)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('850')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METCOM 850 (Comed)'
);

-- line #20484
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METFOR 500 (Cipla)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METFOR 500 (Cipla)'
);

-- line #20485
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METGLIB 500 (Taurus Lab)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METGLIB 500 (Taurus Lab)'
);

-- line #20486
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METICA 500 (SPPL)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METICA 500 (SPPL)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METICA 850 (SPPL)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('850')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METICA 850 (SPPL)'
);

-- line #20487
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METKAP 500 (KAPL)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METKAP 500 (KAPL)'
);

-- line #20488
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METLIFE 500 (Discovery M.)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METLIFE 500 (Discovery M.)'
);

-- line #20489
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METLIFE 1000 (Discovery M.)',
	'Metformin',
	'XR TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METLIFE 1000 (Discovery M.)'
);

-- line #20490
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METLONG 500 (Panacea)',
	'Metformin',
	'DS TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METLONG 500 (Panacea)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METLONG 1000 (Panacea)',
	'Metformin',
	'DS TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METLONG 1000 (Panacea)'
);

-- line #20491
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Metformin', u'always_empty': u'', u'form': u'TAB', u'brand': u'METLONG', u'strength_3': u'', u'company': u'Panacea', u'unit': u''}

-- line #20492
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METLONG 500 (Panacea)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METLONG 500 (Panacea)'
);

-- line #20493
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METMIN 500 (Jenburkt)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METMIN 500 (Jenburkt)'
);

-- line #20494
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METNEED 500 (Reliance)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METNEED 500 (Reliance)'
);

-- line #20495
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METNEED 850 (Reliance)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('850')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METNEED 850 (Reliance)'
);

-- line #20496
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METSAFE 1000 (SAFE MED(MSN))',
	'Metformin',
	'SR TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg S.R.'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METSAFE 1000 (SAFE MED(MSN))'
);

-- line #20497
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METSAFE 500 (SAFE MED(MSN))',
	'Metformin',
	'SR TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg S.R.'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METSAFE 500 (SAFE MED(MSN))'
);

-- line #20498
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METSAR 500 (Unichem)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg/1G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METSAR 500 (Unichem)'
);

-- line #20499
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MET 500 (WEST COAST)',
	'Metformin',
	'SR TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg S.R.'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MET 500 (WEST COAST)'
);

-- line #20500
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METZ 500 (BEATZ LIFESCI.)',
	'Metformin',
	'SR TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METZ 500 (BEATZ LIFESCI.)'
);

-- line #20501
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MF-500 500 (Pil)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MF-500 500 (Pil)'
);

-- line #20502
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MF 500 (Pil)',
	'Metformin',
	'ER TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg(E.R.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MF 500 (Pil)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MF 1000 (Pil)',
	'Metformin',
	'ER TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg(E.R.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MF 1000 (Pil)'
);

-- line #20503
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'M-FORLIN 500 (Lincoln)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'M-FORLIN 500 (Lincoln)'
);

-- line #20504
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'M-FORLIN 850 (Lincoln)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('850')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'M-FORLIN 850 (Lincoln)'
);

-- line #20505
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MF 500 (Pil)',
	'Metformin',
	'SR TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MF 500 (Pil)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MF 1000 (Pil)',
	'Metformin',
	'SR TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MF 1000 (Pil)'
);

-- line #20506
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MINIMET 1000 (Micro Labs)',
	'Metformin',
	'SR TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MINIMET 1000 (Micro Labs)'
);

-- line #20507
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MINIMET 500 (Micro Labs)',
	'Metformin',
	'SR TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MINIMET 500 (Micro Labs)'
);

-- line #20508
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MINMET 500 (Carsyon)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MINMET 500 (Carsyon)'
);

-- line #20509
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOFIN 500 (MOVA PH.)',
	'Metformin',
	'SR TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOFIN 500 (MOVA PH.)'
);

-- line #20510
-- ignoring line: field [strength_1] not numeric: >>>1G<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'500', u'substance': u'Metformin', u'always_empty': u'', u'form': u'TAB', u'brand': u'MR-MET G/500', u'strength_3': u'', u'company': u'AKESISS', u'unit': u'mg'}

-- line #20511
-- ignoring line: field [strength_1] not numeric: >>>1G<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'500', u'substance': u'Metformin', u'always_empty': u'', u'form': u'TAB', u'brand': u'MR-MET IPR G/500', u'strength_3': u'', u'company': u'AKESISS', u'unit': u'mg'}

-- line #20512
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'N-MET 500 (Dr.Reddy''S)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'N-MET 500 (Dr.Reddy''S)'
);

-- line #20513
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OBIMET 500 (Abbott)',
	'Metformin',
	'SR TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OBIMET 500 (Abbott)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OBIMET 1000 (Abbott)',
	'Metformin',
	'SR TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OBIMET 1000 (Abbott)'
);

-- line #20514
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OBIMET 500 (Themis)',
	'Metformin',
	'SR TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OBIMET 500 (Themis)'
);

-- line #20515
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OBIMET 500 (Abbott)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OBIMET 500 (Abbott)'
);

-- line #20516
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OKAMET 500 (Cipla)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OKAMET 500 (Cipla)'
);

-- line #20517
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OZOMET 1000 (Ozone Sp.)',
	'Metformin',
	'DS TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OZOMET 1000 (Ozone Sp.)'
);

-- line #20518
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OZOMET 500 (Ozone Sp.)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OZOMET 500 (Ozone Sp.)'
);

-- line #20519
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q-MET 250 (QCHECK)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q-MET 250 (QCHECK)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q-MET 500 (QCHECK)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q-MET 500 (QCHECK)'
);

-- line #20520
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q-MET 500 (QCHECK)',
	'Metformin',
	'XL TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg/1G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q-MET 500 (QCHECK)'
);

-- line #20521
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REDIDROP 1000 (Jagsonpal)',
	'Metformin',
	'SR TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REDIDROP 1000 (Jagsonpal)'
);

-- line #20522
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REDIDROP 500 (Jagsonpal)',
	'Metformin',
	'SR TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REDIDROP 500 (Jagsonpal)'
);

-- line #20523
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REDIDROP 500 (Jagsonpal)',
	'Metformin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REDIDROP 500 (Jagsonpal)'
);

-- line #20524
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIOMET 100 (Ranbaxy Cv)',
	'Metformin',
	'LIQ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIOMET 100 (Ranbaxy Cv)'
);

-- line #20525
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIOMET 1000 (Ranbaxy Cv)',
	'Metformin',
	'OD TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIOMET 1000 (Ranbaxy Cv)'
);

-- line #20526
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIOMET 500 (Ranbaxy Cv)',
	'Metformin',
	'OD TAB',
	gm.nullify_empty_string('500')::numeric,
	'850'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIOMET 500 (Ranbaxy Cv)'
);

-- line #20527
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILOSYN 4 (Gsk)',
	'Methdilazine',
	'SYR',
	gm.nullify_empty_string('4')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILOSYN 4 (Gsk)'
);

-- line #20528
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILOSYN 8 (Gsk)',
	'Methdilazine',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILOSYN 8 (Gsk)'
);

-- line #20529
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'METHENAMINE', u'always_empty': u'', u'form': u'TAB', u'brand': u'MANDALAMINE', u'strength_3': u'', u'company': u'Warner', u'unit': u''}

-- line #20530
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANDALAMINE 500 (Warner)',
	'METHENAMINE',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANDALAMINE 500 (Warner)'
);

-- line #20531
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALLTREX 25 (Vhb)',
	'Methotrexate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALLTREX 25 (Vhb)'
);

-- line #20532
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALLTREX 5 (Vhb)',
	'Methotrexate',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALLTREX 5 (Vhb)'
);

-- line #20533
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALLTREX 2.5 (Vhb)',
	'Methotrexate',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALLTREX 2.5 (Vhb)'
);

-- line #20534
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALLTREX 500 (Vhb)',
	'Methotrexate',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALLTREX 500 (Vhb)'
);

-- line #20535
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMTREX 50 (AMRONCO)',
	'Methotrexate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMTREX 50 (AMRONCO)'
);

-- line #20536
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOTREXATE 50 (Biochem)',
	'Methotrexate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOTREXATE 50 (Biochem)'
);

-- line #20537
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOTREXATE 5 (Biochem)',
	'Methotrexate',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOTREXATE 5 (Biochem)'
);

-- line #20538
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOTREXATE 2.5 (Biochem)',
	'Methotrexate',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOTREXATE 2.5 (Biochem)'
);

-- line #20539
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOTREXATE 7.5 (Biochem)',
	'Methotrexate',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOTREXATE 7.5 (Biochem)'
);

-- line #20540
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CADITREX 10 (Cadila Ph.)',
	'METHOTREXATE',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CADITREX 10 (Cadila Ph.)'
);

-- line #20541
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CADITREX 25 (Cadila Ph.)',
	'METHOTREXATE',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CADITREX 25 (Cadila Ph.)'
);

-- line #20542
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CADITREX 2.5 (Cadila Ph.)',
	'METHOTREXATE',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CADITREX 2.5 (Cadila Ph.)'
);

-- line #20543
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDITREX 25 (CADILA(ONCOCARE))',
	'Methotrexate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDITREX 25 (CADILA(ONCOCARE))'
);

-- line #20544
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDITREX 2.5 (CADILA(ONCOCARE))',
	'Methotrexate',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDITREX 2.5 (CADILA(ONCOCARE))'
);

-- line #20545
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DERMATREX 2.5 (EAST WEST)',
	'Methotrexate',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DERMATREX 2.5 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DERMATREX 5 (EAST WEST)',
	'Methotrexate',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DERMATREX 5 (EAST WEST)'
);

-- line #20546
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DERMATREX 7.5 (EAST WEST)',
	'Methotrexate',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DERMATREX 7.5 (EAST WEST)'
);

-- line #20547
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DERMOTREX 2.5 (EAST WEST)',
	'Methotrexate',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DERMOTREX 2.5 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DERMOTREX 5 (EAST WEST)',
	'Methotrexate',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DERMOTREX 5 (EAST WEST)'
);

-- line #20548
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DERMOTREX 7.5 (EAST WEST)',
	'Methotrexate',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DERMOTREX 7.5 (EAST WEST)'
);

-- line #20549
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLITRAX 7.5 (Ipca)',
	'Methotrexate',
	'INJ',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLITRAX 7.5 (Ipca)'
);

-- line #20550
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLITRAX 10 (Ipca)',
	'METHOTREXATE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLITRAX 10 (Ipca)'
);

-- line #20551
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLITRAX 15 (Ipca)',
	'Methotrexate',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLITRAX 15 (Ipca)'
);

-- line #20552
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLITRAX 2.5 (Ipca)',
	'METHOTREXATE',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLITRAX 2.5 (Ipca)'
);

-- line #20553
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLITRAX 5 (Ipca)',
	'METHOTREXATE',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLITRAX 5 (Ipca)'
);

-- line #20554
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLITRAX 7.5 (Ipca)',
	'METHOTREXATE',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLITRAX 7.5 (Ipca)'
);

-- line #20555
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOLITRAX 15 (Ipca)',
	'METHOTREXATE',
	'VIAL',
	gm.nullify_empty_string('15')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOLITRAX 15 (Ipca)'
);

-- line #20556
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HI-TREX 2.5 (EAST WEST)',
	'Methotrexate',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HI-TREX 2.5 (EAST WEST)'
);

-- line #20557
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMUTREX 15 (Cipla)',
	'Methotrexate',
	'INJ',
	gm.nullify_empty_string('15')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMUTREX 15 (Cipla)'
);

-- line #20558
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMUTREX 10 (Cipla)',
	'Methotrexate',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMUTREX 10 (Cipla)'
);

-- line #20559
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMUTREX 2.5 (Cipla)',
	'Methotrexate',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMUTREX 2.5 (Cipla)'
);

-- line #20560
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMUTREX 7.5 (Cipla)',
	'Methotrexate',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMUTREX 7.5 (Cipla)'
);

-- line #20561
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEREX 15 (Intas)',
	'Methotrexate',
	'INJ',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEREX 15 (Intas)'
);

-- line #20562
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Methotrexate', u'always_empty': u'', u'form': u'INJ', u'brand': u'MEREX', u'strength_3': u'', u'company': u'Intas', u'unit': u''}

-- line #20563
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEREX 500 (Intas)',
	'Methotrexate',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEREX 500 (Intas)'
);

-- line #20564
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEREX 50 (Intas)',
	'Methotrexate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEREX 50 (Intas)'
);

-- line #20565
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Methotrexate', u'always_empty': u'', u'form': u'GEL', u'brand': u'METH', u'strength_3': u'', u'company': u'WEST COAST', u'unit': u''}

-- line #20566
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METHOCEL 15 (CELON(VIVILON))',
	'Methotrexate',
	'INJ',
	gm.nullify_empty_string('15')::numeric,
	'50'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METHOCEL 15 (CELON(VIVILON))'
);

-- line #20567
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METHOCEL 500 (CELON(VIVILON))',
	'Methotrexate',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METHOCEL 500 (CELON(VIVILON))'
);

-- line #20568
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METHOCEL 2.5 (CELON(VIVILON))',
	'Methotrexate',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METHOCEL 2.5 (CELON(VIVILON))'
);

-- line #20569
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METHOCIP 50 (Cipla)',
	'Methotrexate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METHOCIP 50 (Cipla)'
);

-- line #20570
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METHOREX 100 (German R.)',
	'Methotrexate',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METHOREX 100 (German R.)'
);

-- line #20571
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METHOREX 25 (German R.)',
	'Methotrexate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METHOREX 25 (German R.)'
);

-- line #20572
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METHOREX 5 (German R.)',
	'Methotrexate',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METHOREX 5 (German R.)'
);

-- line #20573
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METHOREX 2.5 (German R.)',
	'Methotrexate',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METHOREX 2.5 (German R.)'
);

-- line #20574
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METHOTREXATE 50 (Pharmacia)',
	'Methotrexate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METHOTREXATE 50 (Pharmacia)'
);

-- line #20575
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METHOTREXATE 5 (Wyeth)',
	'Methotrexate',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METHOTREXATE 5 (Wyeth)'
);

-- line #20576
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METHOTREXATE 2.5 (Wyeth)',
	'Methotrexate',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METHOTREXATE 2.5 (Wyeth)'
);

-- line #20577
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METHOTREXATE-VHB 15 (Vhb)',
	'Methotrexate',
	'INJ',
	gm.nullify_empty_string('15')::numeric,
	'mg/3ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METHOTREXATE-VHB 15 (Vhb)'
);

-- line #20578
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METHOTREXATE-VHB 50 (Vhb)',
	'Methotrexate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METHOTREXATE-VHB 50 (Vhb)'
);

-- line #20579
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METHOTREXATE-VHB 2.5 (Vhb)',
	'Methotrexate',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METHOTREXATE-VHB 2.5 (Vhb)'
);

-- line #20580
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METOREX 15 (Biological E.)',
	'Methotrexate',
	'INJ',
	gm.nullify_empty_string('15')::numeric,
	'mg/3ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METOREX 15 (Biological E.)'
);

-- line #20581
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METOREX 50 (Biological E.)',
	'Methotrexate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METOREX 50 (Biological E.)'
);

-- line #20582
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METREX 15 (CH.Bhagat)',
	'Methotrexate',
	'INJ',
	gm.nullify_empty_string('15')::numeric,
	'mg/3ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METREX 15 (CH.Bhagat)'
);

-- line #20583
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METREX 50 (CH.Bhagat)',
	'Methotrexate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METREX 50 (CH.Bhagat)'
);

-- line #20584
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METREX 2.5 (CH.Bhagat)',
	'Methotrexate',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METREX 2.5 (CH.Bhagat)'
);

-- line #20585
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEXATE 15 (Cadila Hc.)',
	'Methotrexate',
	'INJ',
	gm.nullify_empty_string('15')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEXATE 15 (Cadila Hc.)'
);

-- line #20586
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEXATE 250 (Cadila Hc.)',
	'Methotrexate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/10ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEXATE 250 (Cadila Hc.)'
);

-- line #20587
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEXATE 50 (Cadila Hc.)',
	'Methotrexate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEXATE 50 (Cadila Hc.)'
);

-- line #20588
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEXATE 15 (ZYDUS SYNO.)',
	'Methotrexate',
	'INJ',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEXATE 15 (ZYDUS SYNO.)'
);

-- line #20589
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEXATE 7.5 (ZYDUS SYNO.)',
	'Methotrexate',
	'INJ',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEXATE 7.5 (ZYDUS SYNO.)'
);

-- line #20590
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEXATE 2.5 (Cadila Hc.)',
	'Methotrexate',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'7.5'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEXATE 2.5 (Cadila Hc.)'
);

-- line #20591
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEXATE 10 (ZYDUS SYNO.)',
	'Methotrexate',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEXATE 10 (ZYDUS SYNO.)'
);

-- line #20592
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEXATE 15 (ZYDUS SYNO.)',
	'Methotrexate',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEXATE 15 (ZYDUS SYNO.)'
);

-- line #20593
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEXATE 5 (ZYDUS SYNO.)',
	'Methotrexate',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEXATE 5 (ZYDUS SYNO.)'
);

-- line #20594
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEXT 15 (Wallace)',
	'Methotrexate',
	'INJ',
	gm.nullify_empty_string('15')::numeric,
	'mg(+SOD.CHL. 4.9'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEXT 15 (Wallace)'
);

-- line #20595
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEXT 25 (Wallace)',
	'Methotrexate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg(+SOD.CHL. 4.9'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEXT 25 (Wallace)'
);

-- line #20596
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEXT 10 (Wallace)',
	'Methotrexate',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEXT 10 (Wallace)'
);

-- line #20597
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEXT 15 (Wallace)',
	'Methotrexate',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEXT 15 (Wallace)'
);

-- line #20598
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEXT 2.5 (Wallace)',
	'Methotrexate',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEXT 2.5 (Wallace)'
);

-- line #20599
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEXT 5 (Wallace)',
	'Methotrexate',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEXT 5 (Wallace)'
);

-- line #20600
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'7,5', u'strength_2': u'', u'substance': u'Methotrexate', u'always_empty': u'', u'form': u'', u'brand': u'MEXT', u'strength_3': u'', u'company': u'Wallace', u'unit': u'mg'}

-- line #20601
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOTREXATE 50 (Gsk)',
	'Methotrexate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOTREXATE 50 (Gsk)'
);

-- line #20602
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOTREXATE 2.5 (Gsk)',
	'Methotrexate',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOTREXATE 2.5 (Gsk)'
);

-- line #20603
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONCOTREX 10 (Khandelwal)',
	'Methotrexate',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONCOTREX 10 (Khandelwal)'
);

-- line #20604
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONCOTREX 50 (Sun)',
	'Methotrexate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONCOTREX 50 (Sun)'
);

-- line #20605
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONCOTREX 10 (Sun)',
	'Methotrexate',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONCOTREX 10 (Sun)'
);

-- line #20606
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONCOTREX 2.5 (Sun)',
	'Methotrexate',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONCOTREX 2.5 (Sun)'
);

-- line #20607
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONCOTREX 5 (Sun)',
	'Methotrexate',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONCOTREX 5 (Sun)'
);

-- line #20608
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONCOTREX 7.5 (Sun)',
	'Methotrexate',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONCOTREX 7.5 (Sun)'
);

-- line #20609
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONOTREX 50 (Spectra)',
	'Methotrexate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONOTREX 50 (Spectra)'
);

-- line #20610
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONOTREX 2.5 (Spectra)',
	'Methotrexate',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONOTREX 2.5 (Spectra)'
);

-- line #20611
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLASTOMET 50 (Khandelwal)',
	'Methotrexate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLASTOMET 50 (Khandelwal)'
);

-- line #20612
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLASTOMET 2.5 (SUN)',
	'Methotrexate',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLASTOMET 2.5 (SUN)'
);

-- line #20613
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PSORIAX 2.5 (Tripada)',
	'Methotrexate',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PSORIAX 2.5 (Tripada)'
);

-- line #20614
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RA-MEX 10 (Ranbaxy)',
	'Methotrexate',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RA-MEX 10 (Ranbaxy)'
);

-- line #20615
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RA-MEX 15 (Ranbaxy)',
	'Methotrexate',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RA-MEX 15 (Ranbaxy)'
);

-- line #20616
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RA-MEX 2.5 (Ranbaxy)',
	'Methotrexate',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RA-MEX 2.5 (Ranbaxy)'
);

-- line #20617
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RA-MEX 5 (Ranbaxy)',
	'Methotrexate',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RA-MEX 5 (Ranbaxy)'
);

-- line #20618
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RA-MEX 7.5 (Ranbaxy)',
	'Methotrexate',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RA-MEX 7.5 (Ranbaxy)'
);

-- line #20619
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REMTREX 15 (Cytomed(Alkem))',
	'Methotrexate',
	'INJ',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REMTREX 15 (Cytomed(Alkem))'
);

-- line #20620
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REMTREX 50 (Cytomed(Alkem))',
	'Methotrexate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REMTREX 50 (Cytomed(Alkem))'
);

-- line #20621
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REMTREX 2.5 (Cytomed(Alkem))',
	'Methotrexate',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REMTREX 2.5 (Cytomed(Alkem))'
);

-- line #20622
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REMTREX 30 (Cytomed(Alkem))',
	'Methotrexate',
	'VIAL',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REMTREX 30 (Cytomed(Alkem))'
);

-- line #20623
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REXTOP 0.25 (Systopic)',
	'Methotrexate',
	'GEL',
	gm.nullify_empty_string('0.25')::numeric,
	'% (IN HYDROXY GEL BASE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REXTOP 0.25 (Systopic)'
);

-- line #20624
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACSORALEN 10 (Mac)',
	'Methoxsalen',
	'CAPS',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACSORALEN 10 (Mac)'
);

-- line #20625
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACSORALEN 1 (Mac)',
	'Methoxsalen',
	'SOL',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACSORALEN 1 (Mac)'
);

-- line #20626
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACSORALEN 10 (Mac)',
	'Methoxsalen',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACSORALEN 10 (Mac)'
);

-- line #20627
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50', u'strength_2': u'', u'substance': u'Methoxsalen', u'always_empty': u'', u'form': u'', u'brand': u'MELADERM PAINT', u'strength_3': u'', u'company': u'Inga', u'unit': u'mg/ML'}

-- line #20628
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELADERM 10 (Inga)',
	'Methoxsalen',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELADERM 10 (Inga)'
);

-- line #20629
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELANOCYL 0.75 (Franco I.)',
	'Methoxsalen',
	'SOL',
	gm.nullify_empty_string('0.75')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELANOCYL 0.75 (Franco I.)'
);

-- line #20630
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELANOCYL 10 (Franco I.)',
	'Methoxsalen',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELANOCYL 10 (Franco I.)'
);

-- line #20631
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELCYL 10 (EAST WEST)',
	'Methoxsalen',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELCYL 10 (EAST WEST)'
);

-- line #20632
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REPIGMIN 10 (Ranbaxy)',
	'Methoxsalen',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REPIGMIN 10 (Ranbaxy)'
);

-- line #20633
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REPIGMIN 20 (Ranbaxy)',
	'Methoxsalen',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REPIGMIN 20 (Ranbaxy)'
);

-- line #20634
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'', u'brand': u'ACOBMIN', u'strength_3': u'', u'company': u'SHINCE PH.', u'unit': u''}

-- line #20635
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'WITH B-COMPLEX', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'TAB', u'brand': u'ADEE-12', u'strength_3': u'', u'company': u'Admac Ph.', u'unit': u''}

-- line #20636
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'TAB', u'brand': u'AXINERVE', u'strength_3': u'', u'company': u'AVIS LIFE', u'unit': u''}

-- line #20637
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'CAP', u'brand': u'BETA-COBAL', u'strength_3': u'', u'company': u'Synokem', u'unit': u''}

-- line #20638
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'F. CAP', u'brand': u'BETA-COBAL', u'strength_3': u'', u'company': u'Synokem', u'unit': u''}

-- line #20639
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'', u'brand': u'BET-A SOFGEL', u'strength_3': u'', u'company': u'Synokem', u'unit': u''}

-- line #20640
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'TAB', u'brand': u'CARECOBAL', u'strength_3': u'', u'company': u'Vivid Bio.', u'unit': u''}

-- line #20641
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'TAB', u'brand': u'COBAGEN', u'strength_3': u'', u'company': u'Macleods', u'unit': u''}

-- line #20642
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'INJ', u'brand': u'COBATP', u'strength_3': u'', u'company': u'Taurus Lab', u'unit': u''}

-- line #20643
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'TAB', u'brand': u'COBATP', u'strength_3': u'', u'company': u'Taurus Lab', u'unit': u''}

-- line #20644
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'INJ', u'brand': u'COMSCAV', u'strength_3': u'', u'company': u'COMED CHEM.', u'unit': u''}

-- line #20645
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'ML', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'INJ', u'brand': u'CUBAL', u'strength_3': u'', u'company': u'Cure Quick', u'unit': u''}

-- line #20646
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'TAB', u'brand': u'CUBAL', u'strength_3': u'', u'company': u'Cure Quick', u'unit': u''}

-- line #20647
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2500MCG', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'INJ', u'brand': u'CUMEE', u'strength_3': u'', u'company': u'Curex', u'unit': u''}

-- line #20648
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000MCG', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'F. VIAL', u'brand': u'DUMEL', u'strength_3': u'', u'company': u"D.R.John''S", u'unit': u''}

-- line #20649
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'VIAL', u'brand': u'DUMEL', u'strength_3': u'', u'company': u"D.R.John''S", u'unit': u''}

-- line #20650
-- ignoring line: field [strength_1] not numeric: >>>1500MCG<<<
-- {u'list_of_values_of_unknown_fields': [u'60', u' mg', u'65', u' mg', u'3', u' mg', u'1,5', u' mg', u'100MCG'], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'TAB', u'brand': u'ELMECOB PLUS', u'strength_3': u'', u'company': u'Elder', u'unit': u'100'}

-- line #20651
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000MCG', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'INJ', u'brand': u'EMNEURO', u'strength_3': u'', u'company': u'Emcure', u'unit': u''}

-- line #20652
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'INJ', u'brand': u'EMNEURO', u'strength_3': u'', u'company': u'Emcure', u'unit': u''}

-- line #20653
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'CAP', u'brand': u'EU-B12', u'strength_3': u'', u'company': u'Jaywin', u'unit': u''}

-- line #20654
-- ignoring line: field [strength_1] not numeric: >>>500MCG(+BENZYL ALCOHOL 2<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG(+BENZYL ALCOHOL 2', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'INJ', u'brand': u'GAME', u'strength_3': u'', u'company': u'Dyota N.', u'unit': u'%)'}

-- line #20655
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'INJ', u'brand': u'KEENEURON', u'strength_3': u'', u'company': u'Kee Ph.', u'unit': u''}

-- line #20656
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'OD TAB', u'brand': u'LAMECO', u'strength_3': u'', u'company': u'LA DRUG', u'unit': u''}

-- line #20657
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'INJ', u'brand': u'MATHYCOB', u'strength_3': u'', u'company': u'R.B.REM.', u'unit': u''}

-- line #20658
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'INJ', u'brand': u'MCBM', u'strength_3': u'', u'company': u'Indoco Rem.', u'unit': u''}

-- line #20659
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'TAB', u'brand': u'M-COMIN', u'strength_3': u'', u'company': u'Aquila', u'unit': u''}

-- line #20660
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'TAB', u'brand': u'MCO', u'strength_3': u'', u'company': u'ROSE LABS', u'unit': u''}

-- line #20661
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'ML', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'INJ', u'brand': u'MECMIN', u'strength_3': u'', u'company': u'Kapl', u'unit': u''}

-- line #20662
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'TAB', u'brand': u'MECMIN', u'strength_3': u'', u'company': u'Kapl', u'unit': u''}

-- line #20663
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'INJ', u'brand': u'MECOBEX', u'strength_3': u'', u'company': u'Burgeon Ph.', u'unit': u''}

-- line #20664
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'#REF!', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'INJ', u'brand': u'MECO', u'strength_3': u'', u'company': u'ROSE LABS', u'unit': u''}

-- line #20665
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'TAB', u'brand': u'MECOLBIN', u'strength_3': u'', u'company': u'JARUN PH.', u'unit': u''}

-- line #20666
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'METHYlcobalamin', u'always_empty': u'', u'form': u'OD MCG', u'brand': u'MECOMORE', u'strength_3': u'', u'company': u'Morepen', u'unit': u''}

-- line #20667
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'ML', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'INJ', u'brand': u'MECONEURON', u'strength_3': u'', u'company': u'Pulse Ph.', u'unit': u''}

-- line #20668
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'OD TAB', u'brand': u'MECONEURON', u'strength_3': u'', u'company': u'Pulse Ph.', u'unit': u''}

-- line #20669
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'INJ', u'brand': u'MECOROL', u'strength_3': u'', u'company': u'Royal', u'unit': u''}

-- line #20670
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MECOSOL-SL 1.5 (Meyer Org.)',
	'Methylcobalamin',
	'TAB',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MECOSOL-SL 1.5 (Meyer Org.)'
);

-- line #20671
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'OD TAB', u'brand': u'MECOZOL', u'strength_3': u'', u'company': u'Jollen Med.', u'unit': u''}

-- line #20672
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'INJ', u'brand': u'MEGANATE', u'strength_3': u'', u'company': u'MEGAVISION', u'unit': u''}

-- line #20673
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'TAB', u'brand': u'METHIBION', u'strength_3': u'', u'company': u'Sven Gen.', u'unit': u''}

-- line #20674
-- ignoring line: field [strength_1] not numeric: >>>500MCG(+BENZYL ALCOHOL 2<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG(+BENZYL ALCOHOL 2', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'INJ', u'brand': u'METHYGARD', u'strength_3': u'', u'company': u'Indoco Rem.', u'unit': u'%)'}

-- line #20675
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'ML', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'INJ', u'brand': u'MET-NEUROBION', u'strength_3': u'', u'company': u'Merck', u'unit': u''}

-- line #20676
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'TAB', u'brand': u'MICOMAL', u'strength_3': u'', u'company': u'Malar Hc.', u'unit': u''}

-- line #20677
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIOL 1000 (D.R.John''S)',
	'Methylcobalamin',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIOL 1000 (D.R.John''S)'
);

-- line #20678
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'TAB', u'brand': u'MOBLO', u'strength_3': u'', u'company': u'Medizone', u'unit': u''}

-- line #20679
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'INJ', u'brand': u'MY-B12', u'strength_3': u'', u'company': u'MEDHEAL PH.', u'unit': u''}

-- line #20680
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'CAP', u'brand': u'NACCUM', u'strength_3': u'', u'company': u'Nac Int.', u'unit': u''}

-- line #20681
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'TAB', u'brand': u'NACCUM', u'strength_3': u'', u'company': u'Nac Int.', u'unit': u''}

-- line #20682
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'1ML', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'INJ', u'brand': u'NEURI', u'strength_3': u'', u'company': u'Perk Ph.', u'unit': u''}

-- line #20683
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEURI 1500 (Perk Ph.)',
	'Methylcobalamin',
	'TAB',
	gm.nullify_empty_string('1500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEURI 1500 (Perk Ph.)'
);

-- line #20684
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG(+LYCOPENE 1000MCG)', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'SYR', u'brand': u'NEUROAGE PLUS', u'strength_3': u'', u'company': u'ALLENGE', u'unit': u''}

-- line #20685
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'WITH VITAMINS', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'SYR', u'brand': u'NEUROAGE', u'strength_3': u'', u'company': u'ALLENGE', u'unit': u''}

-- line #20686
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'TAB', u'brand': u'NEURO B12', u'strength_3': u'', u'company': u'TENGEE', u'unit': u''}

-- line #20687
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'INJ', u'brand': u'NEUROFAST', u'strength_3': u'', u'company': u'STAUNCH', u'unit': u''}

-- line #20688
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'', u'brand': u'NEUROKAM', u'strength_3': u'', u'company': u'KAMSONS PH.', u'unit': u''}

-- line #20689
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'WITH PROTEIN POWDER', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'POWD', u'brand': u'NEUROMED', u'strength_3': u'', u'company': u'DAKSH', u'unit': u''}

-- line #20690
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'MD TAB', u'brand': u'NEURON', u'strength_3': u'', u'company': u'Neuron Ph.', u'unit': u''}

-- line #20691
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'TAB', u'brand': u'NEUTONE', u'strength_3': u'', u'company': u'SANCHEZ LAB.', u'unit': u''}

-- line #20692
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'TAB', u'brand': u'NEUTONE', u'strength_3': u'', u'company': u'SANCHEZ LAB.', u'unit': u''}

-- line #20693
-- ignoring line: field [strength_1] not numeric: >>>500MCG(BENZYL ALCOHOL 2.0<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG(BENZYL ALCOHOL 2.0', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'KIT INJ', u'brand': u'NUROBEST', u'strength_3': u'', u'company': u'Ttk Hc.', u'unit': u'%V/V)'}

-- line #20694
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'MD TAB', u'brand': u'NUROBEST', u'strength_3': u'', u'company': u'Ttk Hc.', u'unit': u''}

-- line #20695
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'OD TAB', u'brand': u'NUROCA', u'strength_3': u'', u'company': u'Indica', u'unit': u''}

-- line #20696
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'TAB', u'brand': u'NUROCA', u'strength_3': u'', u'company': u'Indica', u'unit': u''}

-- line #20697
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000MCG', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'INJ', u'brand': u'NURODIL', u'strength_3': u'', u'company': u'BIOKIND HC.', u'unit': u''}

-- line #20698
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUROMET 500 (Cosmas Ph.)',
	'Methylcobalamin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUROMET 500 (Cosmas Ph.)'
);

-- line #20699
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'OD TAB', u'brand': u'NUROMET', u'strength_3': u'', u'company': u'Cosmas Ph.', u'unit': u''}

-- line #20700
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'ML', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'INJ', u'brand': u'NUROTROY', u'strength_3': u'', u'company': u'Troikaa', u'unit': u''}

-- line #20701
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'TAB', u'brand': u'NUROTROY', u'strength_3': u'', u'company': u'Troikaa', u'unit': u''}

-- line #20702
-- ignoring line: field [strength_1] not numeric: >>>ANTIOXIDENTS<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'ANTIOXIDENTS', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'TAB', u'brand': u'NUTRAMAX', u'strength_3': u'', u'company': u'Skymax', u'unit': u'MULTIVITAMINS & MULTIMINERALS'}

-- line #20703
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'TAB', u'brand': u'ODICOBA', u'strength_3': u'', u'company': u'Corolla(Triton)', u'unit': u''}

-- line #20704
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'WITH ANTIOXIDANT MULTIVITAMIN', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'CAP', u'brand': u'OVIT-M', u'strength_3': u'', u'company': u'Tripada BIO.', u'unit': u''}

-- line #20705
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500MCG', u'strength_2': u'', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'TAB', u'brand': u'R1500', u'strength_3': u'', u'company': u'Entod Ph.', u'unit': u''}

-- line #20706
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000MCG', u'strength_2': u'1ML (+BENZYL ALCOHOL)', u'substance': u'Methylcobalamin', u'always_empty': u'', u'form': u'INJ', u'brand': u'RENERVE', u'strength_3': u'', u'company': u'GRANDIX', u'unit': u''}

-- line #20707
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALDOPAM 250 (Neon)',
	'Methyldopa',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALDOPAM 250 (Neon)'
);

-- line #20708
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPHADOPA 250 (Merind)',
	'Methyldopa',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPHADOPA 250 (Merind)'
);

-- line #20709
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOPAGYT 250 (Themis)',
	'Methyldopa',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOPAGYT 250 (Themis)'
);

-- line #20710
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMDOPA 250 (Idpl)',
	'Methyldopa',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMDOPA 250 (Idpl)'
);

-- line #20711
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GYNAPRES 250 (Mankind)',
	'Methyldopa',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GYNAPRES 250 (Mankind)'
);

-- line #20712
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMATRIN 0.125 (Sayona)',
	'Methylergometrine Maleate',
	'TAB',
	gm.nullify_empty_string('0.125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMATRIN 0.125 (Sayona)'
);

-- line #20713
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMERGIN 0.2 (Mapra)',
	'Methylergometrine Maleate',
	'INJ',
	gm.nullify_empty_string('0.2')::numeric,
	'mg/1ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMERGIN 0.2 (Mapra)'
);

-- line #20714
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERGAGIN 0.2 (Mercury)',
	'Methylergometrine Maleate',
	'INJ',
	gm.nullify_empty_string('0.2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERGAGIN 0.2 (Mercury)'
);

-- line #20715
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERGAGIN 0.125 (Mercury)',
	'Methylergometrine Maleate',
	'TAB',
	gm.nullify_empty_string('0.125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERGAGIN 0.125 (Mercury)'
);

-- line #20716
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERGATAUR 0.2 (Taurus Lab)',
	'Methylergometrine Maleate',
	'INJ',
	gm.nullify_empty_string('0.2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERGATAUR 0.2 (Taurus Lab)'
);

-- line #20717
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERGOGIN 0.2 (Cipla)',
	'Methylergometrine Maleate',
	'INJ',
	gm.nullify_empty_string('0.2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERGOGIN 0.2 (Cipla)'
);

-- line #20718
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERGOGIN 0.125 (Cipla)',
	'Methylergometrine Maleate',
	'TAB',
	gm.nullify_empty_string('0.125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERGOGIN 0.125 (Cipla)'
);

-- line #20719
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERGOLIN 0.2 (Lincoln)',
	'Methylergometrine Maleate',
	'INJ',
	gm.nullify_empty_string('0.2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERGOLIN 0.2 (Lincoln)'
);

-- line #20720
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERGOLIN 0.125 (Lincoln)',
	'Methylergometrine Maleate',
	'TAB',
	gm.nullify_empty_string('0.125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERGOLIN 0.125 (Lincoln)'
);

-- line #20721
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERGOMET 0.2 (M.M. Labs)',
	'Methylergometrine Maleate',
	'AMP',
	gm.nullify_empty_string('0.2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERGOMET 0.2 (M.M. Labs)'
);

-- line #20722
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERGOMETHYL 0.2 (TWILIGHT LIT.)',
	'Methylergometrine Maleate',
	'INJ',
	gm.nullify_empty_string('0.2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERGOMETHYL 0.2 (TWILIGHT LIT.)'
);

-- line #20723
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERGOMET 0.2 (Taurus Lab)',
	'Methylergometrine Maleate',
	'INJ',
	gm.nullify_empty_string('0.2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERGOMET 0.2 (Taurus Lab)'
);

-- line #20724
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERGOMET 0.125 (M.M. Labs)',
	'Methylergometrine Maleate',
	'TAB',
	gm.nullify_empty_string('0.125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERGOMET 0.125 (M.M. Labs)'
);

-- line #20725
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERGOMET 0.125 (Taurus Lab)',
	'Methylergometrine Maleate',
	'TAB',
	gm.nullify_empty_string('0.125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERGOMET 0.125 (Taurus Lab)'
);

-- line #20726
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERGOTAUR 0.2 (Taurus Lab)',
	'Methylergometrine Maleate',
	'INJ',
	gm.nullify_empty_string('0.2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERGOTAUR 0.2 (Taurus Lab)'
);

-- line #20727
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERGOTAUR 0.125 (Taurus Lab)',
	'Methylergometrine Maleate',
	'TAB',
	gm.nullify_empty_string('0.125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERGOTAUR 0.125 (Taurus Lab)'
);

-- line #20728
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERGOTIME 0.2 (Radix Bio.)',
	'Methylergometrine Maleate',
	'INJ',
	gm.nullify_empty_string('0.2')::numeric,
	'mg/1ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERGOTIME 0.2 (Radix Bio.)'
);

-- line #20729
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERINMET 0.5 (Neon)',
	'Methylergometrine Maleate',
	'INJ',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERINMET 0.5 (Neon)'
);

-- line #20730
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EVA-MERGIN 0.2 (RADHE BIO.)',
	'Methylergometrine Maleate',
	'INJ',
	gm.nullify_empty_string('0.2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EVA-MERGIN 0.2 (RADHE BIO.)'
);

-- line #20731
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EVA-MERGIN 0.125 (RADHE BIO.)',
	'Methylergometrine Maleate',
	'TAB',
	gm.nullify_empty_string('0.125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EVA-MERGIN 0.125 (RADHE BIO.)'
);

-- line #20732
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GOTRIN 0.125 (Rekvina)',
	'Methylergometrine Maleate',
	'TAB',
	gm.nullify_empty_string('0.125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GOTRIN 0.125 (Rekvina)'
);

-- line #20733
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HICON 0.125 (Systopic)',
	'Methylergometrine Maleate',
	'TAB',
	gm.nullify_empty_string('0.125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HICON 0.125 (Systopic)'
);

-- line #20734
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INGAGEN-M 0.2 (Inga)',
	'Methylergometrine Maleate',
	'INJ',
	gm.nullify_empty_string('0.2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INGAGEN-M 0.2 (Inga)'
);

-- line #20735
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INGAGEN-M 0.125 (Inga)',
	'Methylergometrine Maleate',
	'TAB',
	gm.nullify_empty_string('0.125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INGAGEN-M 0.125 (Inga)'
);

-- line #20736
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEMIN 0.2 (Cadex Lab)',
	'Methylergometrine Maleate',
	'INJ',
	gm.nullify_empty_string('0.2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEMIN 0.2 (Cadex Lab)'
);

-- line #20737
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEMIN 0.125 (Cadex Lab)',
	'Methylergometrine Maleate',
	'TAB',
	gm.nullify_empty_string('0.125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEMIN 0.125 (Cadex Lab)'
);

-- line #20738
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LERIN 0.2 (Troikaa)',
	'Methylergometrine Maleate',
	'INJ',
	gm.nullify_empty_string('0.2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LERIN 0.2 (Troikaa)'
);

-- line #20739
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LERIN 0.125 (Troikaa)',
	'Methylergometrine Maleate',
	'TAB',
	gm.nullify_empty_string('0.125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LERIN 0.125 (Troikaa)'
);

-- line #20740
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEM 0.2 (Neon)',
	'Methylergometrine Maleate',
	'INJ',
	gm.nullify_empty_string('0.2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEM 0.2 (Neon)'
);

-- line #20741
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEMJET 0.2 (Sterkem Ph.)',
	'Methylergometrine Maleate',
	'INJ',
	gm.nullify_empty_string('0.2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEMJET 0.2 (Sterkem Ph.)'
);

-- line #20742
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEMJET 0.125 (Sterkem Ph.)',
	'Methylergometrine Maleate',
	'TAB',
	gm.nullify_empty_string('0.125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEMJET 0.125 (Sterkem Ph.)'
);

-- line #20743
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEM 0.125 (Neon)',
	'Methylergometrine Maleate',
	'TAB',
	gm.nullify_empty_string('0.125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEM 0.125 (Neon)'
);

-- line #20744
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MERGIN 0.2 (Shrinivas)',
	'Methylergometrine Maleate',
	'INJ',
	gm.nullify_empty_string('0.2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MERGIN 0.2 (Shrinivas)'
);

-- line #20745
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MERGIN 0.125 (Shrinivas)',
	'Methylergometrine Maleate',
	'TAB',
	gm.nullify_empty_string('0.125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MERGIN 0.125 (Shrinivas)'
);

-- line #20746
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MERGOX 0.2 (Bpl Ph.)',
	'Methylergometrine Maleate',
	'AMP',
	gm.nullify_empty_string('0.2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MERGOX 0.2 (Bpl Ph.)'
);

-- line #20747
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MERGOX 0.125 (Bpl Ph.)',
	'Methylergometrine Maleate',
	'TAB',
	gm.nullify_empty_string('0.125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MERGOX 0.125 (Bpl Ph.)'
);

-- line #20748
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MERZEN 0.2 (Zee Lab)',
	'Methylergometrine Maleate',
	'INJ',
	gm.nullify_empty_string('0.2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MERZEN 0.2 (Zee Lab)'
);

-- line #20749
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MERZEN 0.125 (Zee Lab)',
	'Methylergometrine Maleate',
	'TAB',
	gm.nullify_empty_string('0.125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MERZEN 0.125 (Zee Lab)'
);

-- line #20750
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METEHRZEX 0.2 (AXYZEN LIFE)',
	'Methylergometrine Maleate',
	'INJ',
	gm.nullify_empty_string('0.2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METEHRZEX 0.2 (AXYZEN LIFE)'
);

-- line #20751
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METERMIN 0.2 (Cadila Ph.)',
	'Methylergometrine Maleate',
	'INJ',
	gm.nullify_empty_string('0.2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METERMIN 0.2 (Cadila Ph.)'
);

-- line #20752
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METERMIN 0.125 (Cadila Ph.)',
	'Methylergometrine Maleate',
	'TAB',
	gm.nullify_empty_string('0.125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METERMIN 0.125 (Cadila Ph.)'
);

-- line #20753
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METHADIN 0.2 (Pfiscar Ind.)',
	'Methylergometrine Maleate',
	'INJ',
	gm.nullify_empty_string('0.2')::numeric,
	'mg/1ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METHADIN 0.2 (Pfiscar Ind.)'
);

-- line #20754
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METHASTAR 0.125 (Cadila Ph.)',
	'Methylergometrine Maleate',
	'TAB',
	gm.nullify_empty_string('0.125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METHASTAR 0.125 (Cadila Ph.)'
);

-- line #20755
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METHERGIN 0.2 (Novartis)',
	'Methylergometrine Maleate',
	'INJ',
	gm.nullify_empty_string('0.2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METHERGIN 0.2 (Novartis)'
);

-- line #20756
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METHERGIN 0.125 (Novartis)',
	'Methylergometrine Maleate',
	'TAB',
	gm.nullify_empty_string('0.125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METHERGIN 0.125 (Novartis)'
);

-- line #20757
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METHERZEX 0.125 (AXYZEN LIFE)',
	'Methylergometrine Maleate',
	'TAB',
	gm.nullify_empty_string('0.125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METHERZEX 0.125 (AXYZEN LIFE)'
);

-- line #20758
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METHIN 0.2 (Ind-Swift)',
	'Methylergometrine Maleate',
	'INJ',
	gm.nullify_empty_string('0.2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METHIN 0.2 (Ind-Swift)'
);

-- line #20759
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METHOCIN 0.2 (Ttk Hc.)',
	'Methylergometrine Maleate',
	'INJ',
	gm.nullify_empty_string('0.2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METHOCIN 0.2 (Ttk Hc.)'
);

-- line #20760
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METHOSPAN 0.2 (Indus)',
	'Methylergometrine Maleate',
	'INJ',
	gm.nullify_empty_string('0.2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METHOSPAN 0.2 (Indus)'
);

-- line #20761
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METHYLERGOMETRINE MALEATE 0.2 (Novartis)',
	'Methylergometrine Maleate',
	'INJ',
	gm.nullify_empty_string('0.2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METHYLERGOMETRINE MALEATE 0.2 (Novartis)'
);

-- line #20762
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METHYLERGOMETRINE MALEATE 0.125 (Novartis)',
	'Methylergometrine Maleate',
	'TAB',
	gm.nullify_empty_string('0.125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METHYLERGOMETRINE MALEATE 0.125 (Novartis)'
);

-- line #20763
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INSPIRAL 10 (Ipca)',
	'METHYLPHENIDATE',
	'SR TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INSPIRAL 10 (Ipca)'
);

-- line #20764
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INSPIRAL 20 (Ipca)',
	'METHYLPHENIDATE',
	'SR TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INSPIRAL 20 (Ipca)'
);

-- line #20765
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INSPIRAL 10 (Ipca)',
	'METHYLPHENIDATE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INSPIRAL 10 (Ipca)'
);

-- line #20766
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INSPIRAL 20 (Ipca)',
	'METHYLPHENIDATE',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INSPIRAL 20 (Ipca)'
);

-- line #20767
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INSPIRAL 5 (Ipca)',
	'METHYLPHENIDATE',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INSPIRAL 5 (Ipca)'
);

-- line #20768
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METHOD 10 (Intas)',
	'METHYLPHENIDATE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METHOD 10 (Intas)'
);

-- line #20769
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METHOD 20 (Intas)',
	'METHYLPHENIDATE',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METHOD 20 (Intas)'
);

-- line #20770
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMNACORTIL 0.1 (Macleods)',
	'Methyl Prednisolone ACEPONATE',
	'CRM',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMNACORTIL 0.1 (Macleods)'
);

-- line #20771
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGA PRED 40 (VENUS REM.)',
	'Methyl Prednisolone Acetate',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGA PRED 40 (VENUS REM.)'
);

-- line #20772
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MPA 40 (CH.Bhagat)',
	'Methyl Prednisolone Acetate',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg/1ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MPA 40 (CH.Bhagat)'
);

-- line #20773
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MPA 80 (CH.Bhagat)',
	'Methyl Prednisolone Acetate',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MPA 80 (CH.Bhagat)'
);

-- line #20774
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTO-PRED 4 (Ferring Ph.)',
	'Methyl Prednisolone',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTO-PRED 4 (Ferring Ph.)'
);

-- line #20775
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARTIPRED 16 (EAST WEST)',
	'Methyl Prednisolone',
	'CAP',
	gm.nullify_empty_string('16')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARTIPRED 16 (EAST WEST)'
);

-- line #20776
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARTIPRED 2 (EAST WEST)',
	'Methyl Prednisolone',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARTIPRED 2 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARTIPRED 4 (EAST WEST)',
	'Methyl Prednisolone',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARTIPRED 4 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARTIPRED 8 (EAST WEST)',
	'Methyl Prednisolone',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARTIPRED 8 (EAST WEST)'
);

-- line #20777
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Methyl Prednisolone', u'always_empty': u'', u'form': u'INJ', u'brand': u'DEPOMAX', u'strength_3': u'', u'company': u'Biomax Lab', u'unit': u''}

-- line #20778
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Methyl Prednisolone', u'always_empty': u'', u'form': u'INJ', u'brand': u'DEPOMAX-S', u'strength_3': u'', u'company': u'BIOMAX BIO.', u'unit': u''}

-- line #20779
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPOMAX 16 (BIOMAX BIO.)',
	'Methyl Prednisolone',
	'TAB',
	gm.nullify_empty_string('16')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPOMAX 16 (BIOMAX BIO.)'
);

-- line #20780
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPOMAX 4 (BIOMAX BIO.)',
	'Methyl Prednisolone',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPOMAX 4 (BIOMAX BIO.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPOMAX 8 (BIOMAX BIO.)',
	'Methyl Prednisolone',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPOMAX 8 (BIOMAX BIO.)'
);

-- line #20781
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DISPRED 16 (J. B. Chem.)',
	'Methyl Prednisolone',
	'TAB',
	gm.nullify_empty_string('16')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DISPRED 16 (J. B. Chem.)'
);

-- line #20782
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DISPRED 4 (J. B. Chem.)',
	'Methyl Prednisolone',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DISPRED 4 (J. B. Chem.)'
);

-- line #20783
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DISPRED 8 (J. B. Chem.)',
	'Methyl Prednisolone',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DISPRED 8 (J. B. Chem.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DISPRED 24 (J. B. Chem.)',
	'Methyl Prednisolone',
	'TAB',
	gm.nullify_empty_string('24')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DISPRED 24 (J. B. Chem.)'
);

-- line #20784
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IVEPRED 24 (Sun)',
	'Methyl Prednisolone',
	'TAB',
	gm.nullify_empty_string('24')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IVEPRED 24 (Sun)'
);

-- line #20785
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUPUS 4 (BIOSCIENCES)',
	'Methyl Prednisolone',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUPUS 4 (BIOSCIENCES)'
);

-- line #20786
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACPRED-16 16 (Macleods)',
	'Methyl Prednisolone',
	'TAB',
	gm.nullify_empty_string('16')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACPRED-16 16 (Macleods)'
);

-- line #20787
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACPRED-4 4 (Macleods)',
	'Methyl Prednisolone',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACPRED-4 4 (Macleods)'
);

-- line #20788
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACPRED-8 8 (Macleods)',
	'Methyl Prednisolone',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACPRED-8 8 (Macleods)'
);

-- line #20789
-- ignoring line: field [strength_1] not numeric: >>>1G<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'25', u'substance': u'Methyl Prednisolone', u'always_empty': u'', u'form': u'TAB', u'brand': u'MBSOLE', u'strength_3': u'', u'company': u'HEALTH BIO.', u'unit': u'mg/40'}

-- line #20790
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDEL 80 (AXYZEN LIFE)',
	'Methyl Prednisolone',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDEL 80 (AXYZEN LIFE)'
);

-- line #20791
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDEL 4 (AXYZEN LIFE)',
	'Methyl Prednisolone',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDEL 4 (AXYZEN LIFE)'
);

-- line #20792
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDICORT 4 (TRUMAC)',
	'Methyl Prednisolone',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDICORT 4 (TRUMAC)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDICORT 8 (TRUMAC)',
	'Methyl Prednisolone',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDICORT 8 (TRUMAC)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDICORT 10 (TRUMAC)',
	'Methyl Prednisolone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDICORT 10 (TRUMAC)'
);

-- line #20793
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDROL 8 (Pfizer)',
	'Methyl Prednisolone',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDROL 8 (Pfizer)'
);

-- line #20794
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGA-PRED-24 24 (VENUS REM.)',
	'Methyl Prednisolone',
	'TAB',
	gm.nullify_empty_string('24')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGA-PRED-24 24 (VENUS REM.)'
);

-- line #20795
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGA PRED 16 (VENUS REM.)',
	'Methyl Prednisolone',
	'TAB',
	gm.nullify_empty_string('16')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGA PRED 16 (VENUS REM.)'
);

-- line #20796
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGA PRED 4 (VENUS REM.)',
	'Methyl Prednisolone',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGA PRED 4 (VENUS REM.)'
);

-- line #20797
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGA-PRED 8 (VENUS REM.)',
	'Methyl Prednisolone',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGA-PRED 8 (VENUS REM.)'
);

-- line #20798
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELPRED 1000 (Cipla)',
	'Methyl Prednisolone',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELPRED 1000 (Cipla)'
);

-- line #20799
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELPRED 125 (Cipla)',
	'Methyl Prednisolone',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELPRED 125 (Cipla)'
);

-- line #20800
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELPRED 40 (Cipla)',
	'Methyl Prednisolone',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELPRED 40 (Cipla)'
);

-- line #20801
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELPRED 500 (Cipla)',
	'Methyl Prednisolone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELPRED 500 (Cipla)'
);

-- line #20802
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELPRED 16 (Cipla)',
	'Methyl Prednisolone',
	'TAB',
	gm.nullify_empty_string('16')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELPRED 16 (Cipla)'
);

-- line #20803
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELPRED 4 (Cipla)',
	'Methyl Prednisolone',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELPRED 4 (Cipla)'
);

-- line #20804
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEPRESSO-D 40 (Intas)',
	'Methyl Prednisolone',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEPRESSO-D 40 (Intas)'
);

-- line #20805
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEPRESSO T-16 16 (Intas)',
	'Methyl Prednisolone',
	'TAB',
	gm.nullify_empty_string('16')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEPRESSO T-16 16 (Intas)'
);

-- line #20806
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEPRESSO T-4 4 (Intas)',
	'Methyl Prednisolone',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEPRESSO T-4 4 (Intas)'
);

-- line #20807
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEPRESSO T-8 8 (Intas)',
	'Methyl Prednisolone',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEPRESSO T-8 8 (Intas)'
);

-- line #20808
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Methyl Prednisolone', u'always_empty': u'', u'form': u'INJ', u'brand': u'MEPSONATE', u'strength_3': u'', u'company': u'Gland Ph.', u'unit': u''}

-- line #20809
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEPSONATE 500 (Gland Ph.)',
	'Methyl Prednisolone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEPSONATE 500 (Gland Ph.)'
);

-- line #20810
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METHPRED 500 (Troikaa)',
	'Methyl Prednisolone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg/1G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METHPRED 500 (Troikaa)'
);

-- line #20811
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MPSS 125 (CH.Bhagat)',
	'Methyl Prednisolone',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MPSS 125 (CH.Bhagat)'
);

-- line #20812
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Methyl Prednisolone', u'always_empty': u'', u'form': u'INJ', u'brand': u'MPSS', u'strength_3': u'', u'company': u'CH.Bhagat', u'unit': u''}

-- line #20813
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MPSS 250 (CH.Bhagat)',
	'Methyl Prednisolone',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MPSS 250 (CH.Bhagat)'
);

-- line #20814
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MPSS 40 (CH.Bhagat)',
	'Methyl Prednisolone',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MPSS 40 (CH.Bhagat)'
);

-- line #20815
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'16ML', u'strength_2': u'', u'substance': u'Methyl Prednisolone', u'always_empty': u'', u'form': u'TAB', u'brand': u'MPS', u'strength_3': u'', u'company': u'Tripada BIO.', u'unit': u''}

-- line #20816
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MPS 4 (Tripada BIO.)',
	'Methyl Prednisolone',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MPS 4 (Tripada BIO.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MPS 8 (Tripada BIO.)',
	'Methyl Prednisolone',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MPS 8 (Tripada BIO.)'
);

-- line #20817
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYPRED 16 (Samarth)',
	'Methyl Prednisolone',
	'TAB',
	gm.nullify_empty_string('16')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYPRED 16 (Samarth)'
);

-- line #20818
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYPRED 4 (Samarth)',
	'Methyl Prednisolone',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYPRED 4 (Samarth)'
);

-- line #20819
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEODROL-AS 40 (Neon)',
	'Methyl Prednisolone',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEODROL-AS 40 (Neon)'
);

-- line #20820
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NICORT 16 (Nicholas)',
	'Methyl Prednisolone',
	'TAB',
	gm.nullify_empty_string('16')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NICORT 16 (Nicholas)'
);

-- line #20821
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NICORT 4 (Nicholas)',
	'Methyl Prednisolone',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NICORT 4 (Nicholas)'
);

-- line #20822
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUCORT-M16 16 (Mankind)',
	'Methyl Prednisolone',
	'TAB',
	gm.nullify_empty_string('16')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUCORT-M16 16 (Mankind)'
);

-- line #20823
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUCORT-M4 4 (LIFESTAR)',
	'Methyl Prednisolone',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUCORT-M4 4 (LIFESTAR)'
);

-- line #20824
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUCORT-M8 8 (LIFESTAR)',
	'Methyl Prednisolone',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUCORT-M8 8 (LIFESTAR)'
);

-- line #20825
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENSONE 5 (PSYCOREM)',
	'Methyl Prednisolone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENSONE 5 (PSYCOREM)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENSONE 10 (PSYCOREM)',
	'Methyl Prednisolone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENSONE 10 (PSYCOREM)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENSONE 20 (PSYCOREM)',
	'Methyl Prednisolone',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENSONE 20 (PSYCOREM)'
);

-- line #20826
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREDACE 16 (Micro Labs)',
	'Methyl Prednisolone',
	'TAB',
	gm.nullify_empty_string('16')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREDACE 16 (Micro Labs)'
);

-- line #20827
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREDACE 4 (Micro Labs)',
	'Methyl Prednisolone',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREDACE 4 (Micro Labs)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREDACE 8 (Micro Labs)',
	'Methyl Prednisolone',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREDACE 8 (Micro Labs)'
);

-- line #20828
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREDMET 24 (Sun)',
	'Methyl Prednisolone',
	'TAB',
	gm.nullify_empty_string('24')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREDMET 24 (Sun)'
);

-- line #20829
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREDMET 4 (Sun)',
	'Methyl Prednisolone',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREDMET 4 (Sun)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREDMET 8 (Sun)',
	'Methyl Prednisolone',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREDMET 8 (Sun)'
);

-- line #20830
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREDON-M 4 (ORION BIOTECH.)',
	'Methyl Prednisolone',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREDON-M 4 (ORION BIOTECH.)'
);

-- line #20831
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRELID 8 (GLOWDERMA)',
	'Methyl Prednisolone',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRELID 8 (GLOWDERMA)'
);

-- line #20832
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROLID 16 (GLOWDERMA)',
	'Methyl Prednisolone',
	'TAB',
	gm.nullify_empty_string('16')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROLID 16 (GLOWDERMA)'
);

-- line #20833
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROLID 4 (GLOWDERMA)',
	'Methyl Prednisolone',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROLID 4 (GLOWDERMA)'
);

-- line #20834
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Methyl Prednisolone Sodium Succinate', u'always_empty': u'', u'form': u'VIAL', u'brand': u'ACTO-PRED', u'strength_3': u'', u'company': u'Ferring Ph.', u'unit': u''}

-- line #20835
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTO-PRED 500 (Ferring Ph.)',
	'Methyl Prednisolone Sodium Succinate',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTO-PRED 500 (Ferring Ph.)'
);

-- line #20836
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYTOSYN 500 (Panacea)',
	'Methyl Prednisolone Sodium Succinate',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYTOSYN 500 (Panacea)'
);

-- line #20837
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Methyl Prednisolone Sodium Succinate', u'always_empty': u'', u'form': u'V', u'brand': u'CYTOSYN', u'strength_3': u'', u'company': u'Panacea', u'unit': u''}

-- line #20838
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPOTEX 500 (German R.)',
	'Methyl Prednisolone Sodium Succinate',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPOTEX 500 (German R.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPOTEX 1000 (German R.)',
	'Methyl Prednisolone Sodium Succinate',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPOTEX 1000 (German R.)'
);

-- line #20839
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I', u'strength_2': u'', u'substance': u'Methyl Prednisolone Sodium Succinate', u'always_empty': u'', u'form': u'INJ', u'brand': u'DEPOTEX', u'strength_3': u'', u'company': u'German R.', u'unit': u''}

-- line #20840
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Methyl Prednisolone Sodium Succinate', u'always_empty': u'', u'form': u'INJ', u'brand': u'MEDNISOL', u'strength_3': u'', u'company': u'Bharat S.', u'unit': u''}

-- line #20841
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDNISOL 500 (Bharat S.)',
	'Methyl Prednisolone Sodium Succinate',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDNISOL 500 (Bharat S.)'
);

-- line #20842
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Methyl Prednisolone Sodium Succinate', u'always_empty': u'', u'form': u'INJ', u'brand': u'MEPROSOL', u'strength_3': u'', u'company': u'NEW MEDICON', u'unit': u''}

-- line #20843
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEPSONATE 40 (Gland Ph.)',
	'Methyl Prednisolone Sodium Succinate',
	'VIAL',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEPSONATE 40 (Gland Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEPSONATE 125 (Gland Ph.)',
	'Methyl Prednisolone Sodium Succinate',
	'VIAL',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEPSONATE 125 (Gland Ph.)'
);

-- line #20844
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METHYL-PRED 500 (SHRESHTHA)',
	'Methyl Prednisolone Sodium Succinate',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METHYL-PRED 500 (SHRESHTHA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METHYL-PRED 1000 (SHRESHTHA)',
	'Methyl Prednisolone Sodium Succinate',
	'VIAL',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METHYL-PRED 1000 (SHRESHTHA)'
);

-- line #20845
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MPSS 40 (CH.Bhagat)',
	'Methyl Prednisolone Sodium Succinate',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MPSS 40 (CH.Bhagat)'
);

-- line #20846
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYPRED 40 (Samarth)',
	'Methyl Prednisolone Sodium Succinate',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYPRED 40 (Samarth)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYPRED 125 (Samarth)',
	'Methyl Prednisolone Sodium Succinate',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYPRED 125 (Samarth)'
);

-- line #20847
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYPRED 500 (Samarth)',
	'Methyl Prednisolone Sodium Succinate',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYPRED 500 (Samarth)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYPRED 1000 (Samarth)',
	'Methyl Prednisolone Sodium Succinate',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYPRED 1000 (Samarth)'
);

-- line #20848
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEO-DROL 1000 (Vhb)',
	'Methyl Prednisolone Sodium Succinate',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEO-DROL 1000 (Vhb)'
);

-- line #20849
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEO-DROL 125 (Vhb)',
	'Methyl Prednisolone Sodium Succinate',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEO-DROL 125 (Vhb)'
);

-- line #20850
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEO-DROL 40 (Vhb)',
	'Methyl Prednisolone Sodium Succinate',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEO-DROL 40 (Vhb)'
);

-- line #20851
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEO-DROL 500 (Vhb)',
	'Methyl Prednisolone Sodium Succinate',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEO-DROL 500 (Vhb)'
);

-- line #20852
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEO-DROL 40 (Neon)',
	'Methyl Prednisolone Sodium Succinate',
	'VIAL',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEO-DROL 40 (Neon)'
);

-- line #20853
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEO-DROL 125 (Neon)',
	'Methyl Prednisolone Sodium Succinate',
	'V',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEO-DROL 125 (Neon)'
);

-- line #20854
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Methyl Prednisolone Sodium Succinate', u'always_empty': u'', u'form': u'V', u'brand': u'NEO-DROL', u'strength_3': u'', u'company': u'Neon', u'unit': u''}

-- line #20855
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEO-DROL 500 (Neon)',
	'Methyl Prednisolone Sodium Succinate',
	'V',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEO-DROL 500 (Neon)'
);

-- line #20856
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NISPRED 1 (NEISS)',
	'Methyl Prednisolone Sodium Succinate',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NISPRED 1 (NEISS)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NISPRED 125 (NEISS)',
	'Methyl Prednisolone Sodium Succinate',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NISPRED 125 (NEISS)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NISPRED 500 (NEISS)',
	'Methyl Prednisolone Sodium Succinate',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NISPRED 500 (NEISS)'
);

-- line #20857
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500', u'strength_2': u'', u'substance': u'Methyl Prednisolone Sodium Succinate', u'always_empty': u'', u'form': u'', u'brand': u'PREDNIMOR', u'strength_3': u'', u'company': u'Biocon', u'unit': u'mg'}

-- line #20858
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREDSILONE 1000 (ACE PH.)',
	'Methyl Prednisolone Sodium Succinate',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREDSILONE 1000 (ACE PH.)'
);

-- line #20859
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREMISOL 125 (MOLEKULE)',
	'Methyl Prednisolone Sodium Succinate',
	'INJ',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREMISOL 125 (MOLEKULE)'
);

-- line #20860
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Methyl Prednisolone Sodium Succinate', u'always_empty': u'', u'form': u'INJ', u'brand': u'PREMISOL', u'strength_3': u'', u'company': u'MOLEKULE', u'unit': u''}

-- line #20861
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREMISOL 40 (MOLEKULE)',
	'Methyl Prednisolone Sodium Succinate',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREMISOL 40 (MOLEKULE)'
);

-- line #20862
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREMISOL 500 (MOLEKULE)',
	'Methyl Prednisolone Sodium Succinate',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREMISOL 500 (MOLEKULE)'
);

-- line #20863
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRESOL 1000 (ROSE LABS)',
	'Methyl Prednisolone Sodium Succinate',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRESOL 1000 (ROSE LABS)'
);

-- line #20864
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOSULPH 500 (Obsurge)',
	'Methyl Sulphony Methane',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOSULPH 500 (Obsurge)'
);

-- line #20865
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMENIL 5 (Astrazeneca)',
	'Metoclopramide',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMENIL 5 (Astrazeneca)'
);

-- line #20866
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMENIL 10 (Astrazeneca)',
	'Metoclopramide',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMENIL 10 (Astrazeneca)'
);

-- line #20867
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADINORM 5 (Andre)',
	'Metoclopramide Hcl.',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADINORM 5 (Andre)'
);

-- line #20868
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACNORM 5 (BACTOLAC)',
	'Metoclopramide Hcl.',
	'DPS',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACNORM 5 (BACTOLAC)'
);

-- line #20869
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Metoclopramide Hcl.', u'always_empty': u'', u'form': u'INJ', u'brand': u'BEMETO', u'strength_3': u'', u'company': u'Brooks Ph.', u'unit': u''}

-- line #20870
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLONORM 10 (AIMCO PH.)',
	'Metoclopramide Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLONORM 10 (AIMCO PH.)'
);

-- line #20871
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DONMET 5 (Neon)',
	'Metoclopramide Hcl.',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DONMET 5 (Neon)'
);

-- line #20872
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYSVON 5 (Suvik Hit.)',
	'Metoclopramide Hcl.',
	'LIQ',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYSVON 5 (Suvik Hit.)'
);

-- line #20873
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYSVON 10 (Suvik Hit.)',
	'Metoclopramide Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYSVON 10 (Suvik Hit.)'
);

-- line #20874
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMENIL 5 (Astrazeneca)',
	'Metoclopramide Hcl.',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMENIL 5 (Astrazeneca)'
);

-- line #20875
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAXERON 5 (Wallace)',
	'Metoclopramide Hcl.',
	'VIAL',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAXERON 5 (Wallace)'
);

-- line #20876
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAXINORM 10 (Pharma synth)',
	'Metoclopramide Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAXINORM 10 (Pharma synth)'
);

-- line #20877
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METAJEX 5 (CADILA)',
	'Metoclopramide Hcl.',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METAJEX 5 (CADILA)'
);

-- line #20878
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METARMIN 5 (P C INDIA)',
	'Metoclopramide Hcl.',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METARMIN 5 (P C INDIA)'
);

-- line #20879
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METOCLOP 5 (Ind-Swift)',
	'Metoclopramide Hcl.',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METOCLOP 5 (Ind-Swift)'
);

-- line #20880
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METOCLOP 5 (Ind-Swift)',
	'Metoclopramide Hcl.',
	'VIAL',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METOCLOP 5 (Ind-Swift)'
);

-- line #20881
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METOCONTIN 15 (Modi Mundi)',
	'Metoclopramide Hcl.',
	'CR TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METOCONTIN 15 (Modi Mundi)'
);

-- line #20882
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METONORM 5 (Ophthal R.)',
	'Metoclopramide Hcl.',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METONORM 5 (Ophthal R.)'
);

-- line #20883
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METOTID 5 (Biological E.)',
	'Metoclopramide Hcl.',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METOTID 5 (Biological E.)'
);

-- line #20884
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METOTID 5 (Biological E.)',
	'Metoclopramide Hcl.',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METOTID 5 (Biological E.)'
);

-- line #20885
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METOTID 10 (Biological E.)',
	'Metoclopramide Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METOTID 10 (Biological E.)'
);

-- line #20886
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METROMIDE 10 (Pfiscar Ind.)',
	'Metoclopramide Hcl.',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METROMIDE 10 (Pfiscar Ind.)'
);

-- line #20887
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERICURE 5 (Indus)',
	'Metoclopramide Hcl.',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERICURE 5 (Indus)'
);

-- line #20888
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERIFORD 10 (Ronak Lab.)',
	'Metoclopramide Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERIFORD 10 (Ronak Lab.)'
);

-- line #20889
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERIGLAN 10 (Trio Rem.)',
	'Metoclopramide Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERIGLAN 10 (Trio Rem.)'
);

-- line #20890
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERIGLO 10 (Global Med.)',
	'Metoclopramide Hcl.',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERIGLO 10 (Global Med.)'
);

-- line #20891
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERINORM 15 (Ipca)',
	'Metoclopramide Hcl.',
	'CD CAP',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERINORM 15 (Ipca)'
);

-- line #20892
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERINORM 5 (Ipca)',
	'Metoclopramide Hcl.',
	'DT',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERINORM 5 (Ipca)'
);

-- line #20893
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERINORM 5 (Ipca)',
	'Metoclopramide Hcl.',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERINORM 5 (Ipca)'
);

-- line #20894
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERINORM 5 (Ipca)',
	'Metoclopramide Hcl.',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERINORM 5 (Ipca)'
);

-- line #20895
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERINORM 10 (Ipca)',
	'Metoclopramide Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERINORM 10 (Ipca)'
);

-- line #20896
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERINORM 5 (Ipca)',
	'Metoclopramide Hcl.',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERINORM 5 (Ipca)'
);

-- line #20897
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROMET 5 (Lupin)',
	'Metoclopramide Hcl.',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROMET 5 (Lupin)'
);

-- line #20898
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REGGI 5 (Shalaks)',
	'Metoclopramide Hcl.',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5 ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REGGI 5 (Shalaks)'
);

-- line #20899
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REGGI 10 (Shalaks)',
	'Metoclopramide Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REGGI 10 (Shalaks)'
);

-- line #20900
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REGLAN 5 (Cfl Ph.)',
	'Metoclopramide Hcl.',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REGLAN 5 (Cfl Ph.)'
);

-- line #20901
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REGLAN 5 (Cfl Ph.)',
	'Metoclopramide Hcl.',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5 ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REGLAN 5 (Cfl Ph.)'
);

-- line #20902
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REGLAN 10 (Cfl Ph.)',
	'Metoclopramide Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REGLAN 10 (Cfl Ph.)'
);

-- line #20903
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REGLAN 5 (Cfl Ph.)',
	'Metoclopramide Hcl.',
	'VIAL',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REGLAN 5 (Cfl Ph.)'
);

-- line #20904
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAXERON 5 (Wallace)',
	'Metoclopramide',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAXERON 5 (Wallace)'
);

-- line #20905
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAXERON 5 (Wallace)',
	'Metoclopramide',
	'LIQ',
	gm.nullify_empty_string('5')::numeric,
	'mg/5 ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAXERON 5 (Wallace)'
);

-- line #20906
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAXERON 10 (Wallace)',
	'Metoclopramide',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAXERON 10 (Wallace)'
);

-- line #20907
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIUREM 2.5 (Cipla)',
	'METOLAZONE',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIUREM 2.5 (Cipla)'
);

-- line #20908
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIUREM 5 (Cipla)',
	'METOLAZONE',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIUREM 5 (Cipla)'
);

-- line #20909
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELA 2.5 (Rpg Life)',
	'METOLAZONE',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELA 2.5 (Rpg Life)'
);

-- line #20910
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELA 5 (Rpg Life)',
	'METOLAZONE',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELA 5 (Rpg Life)'
);

-- line #20911
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METADURE 2.5 (Micro Labs)',
	'METOLAZONE',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METADURE 2.5 (Micro Labs)'
);

-- line #20912
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METADURE 5 (Micro Labs)',
	'METOLAZONE',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METADURE 5 (Micro Labs)'
);

-- line #20913
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METOLAZ 2.5 (Centaur)',
	'METOLAZONE',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METOLAZ 2.5 (Centaur)'
);

-- line #20914
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METOLAZ 5 (Centaur)',
	'METOLAZONE',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METOLAZ 5 (Centaur)'
);

-- line #20915
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10GM', u'strength_2': u'', u'substance': u'METOLAZONE', u'always_empty': u'', u'form': u'TAB', u'brand': u'METORAL', u'strength_3': u'', u'company': u"DR. REDDY''S", u'unit': u''}

-- line #20916
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METORAL 2.5 (Dr.Reddy''S)',
	'METOLAZONE',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METORAL 2.5 (Dr.Reddy''S)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METORAL 5 (Dr.Reddy''S)',
	'METOLAZONE',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METORAL 5 (Dr.Reddy''S)'
);

-- line #20917
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METOZIDE 2.5 (TORRENT)',
	'METOLAZONE',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METOZIDE 2.5 (TORRENT)'
);

-- line #20918
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METOZIDE 5 (TORRENT)',
	'METOLAZONE',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METOZIDE 5 (TORRENT)'
);

-- line #20919
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METOZ 10 (Centaur)',
	'METOLAZONE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METOZ 10 (Centaur)'
);

-- line #20920
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METOZ 2.5 (Centaur)',
	'METOLAZONE',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METOZ 2.5 (Centaur)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METOZ 5 (Centaur)',
	'METOLAZONE',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METOZ 5 (Centaur)'
);

-- line #20921
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACIL 100 (D.R.John''S)',
	'Metoprolol',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACIL 100 (D.R.John''S)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACIL 200 (D.R.John''S)',
	'Metoprolol',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACIL 200 (D.R.John''S)'
);

-- line #20922
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACIL 500 (D.R.John''S)',
	'Metoprolol',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACIL 500 (D.R.John''S)'
);

-- line #20923
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACIL 100 (D.R.John''S)',
	'Metoprolol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACIL 100 (D.R.John''S)'
);

-- line #20924
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACIL 25 (D.R.John''S)',
	'Metoprolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACIL 25 (D.R.John''S)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACIL 50 (D.R.John''S)',
	'Metoprolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACIL 50 (D.R.John''S)'
);

-- line #20925
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTIBLOK-IPR 100 (Biocon)',
	'Metoprolol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTIBLOK-IPR 100 (Biocon)'
);

-- line #20926
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTIBLOK-IPR 25 (Biocon)',
	'Metoprolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTIBLOK-IPR 25 (Biocon)'
);

-- line #20927
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTIBLOK-IPR 50 (Biocon)',
	'Metoprolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTIBLOK-IPR 50 (Biocon)'
);

-- line #20928
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANGIBLOC 12.5 (Alkem)',
	'Metoprolol',
	'ER TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg(TARTRATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANGIBLOC 12.5 (Alkem)'
);

-- line #20929
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANGIBLOC 25 (Alkem)',
	'Metoprolol',
	'ER TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg(TARTRATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANGIBLOC 25 (Alkem)'
);

-- line #20930
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANGIBLOC 50 (Alkem)',
	'Metoprolol',
	'ER TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg(TARTRATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANGIBLOC 50 (Alkem)'
);

-- line #20931
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASOMET 25 (Emcure)',
	'Metoprolol',
	'XL TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg S(-)(TART.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASOMET 25 (Emcure)'
);

-- line #20932
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Metoprolol', u'always_empty': u'', u'form': u'XL TAB', u'brand': u'ASOMET', u'strength_3': u'', u'company': u'Emcure', u'unit': u''}

-- line #20933
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASOPROL 25 (AS PHARMA)',
	'Metoprolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASOPROL 25 (AS PHARMA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASOPROL 50 (AS PHARMA)',
	'Metoprolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASOPROL 50 (AS PHARMA)'
);

-- line #20934
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETABEST 25 (Medley)',
	'Metoprolol',
	'XL TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETABEST 25 (Medley)'
);

-- line #20935
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETABEST 50 (Medley)',
	'Metoprolol',
	'XL TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETABEST 50 (Medley)'
);

-- line #20936
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETACON 25 (CONCERTINA)',
	'Metoprolol',
	'ER CAP',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETACON 25 (CONCERTINA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETACON 50 (CONCERTINA)',
	'Metoprolol',
	'ER CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETACON 50 (CONCERTINA)'
);

-- line #20937
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETALOC 25 (Astrazeneca)',
	'Metoprolol',
	'CAP',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETALOC 25 (Astrazeneca)'
);

-- line #20938
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETALOC 1 (Astrazeneca)',
	'Metoprolol',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETALOC 1 (Astrazeneca)'
);

-- line #20939
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETALOC 100 (Astrazeneca)',
	'Metoprolol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETALOC 100 (Astrazeneca)'
);

-- line #20940
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETALOC 25 (Astrazeneca)',
	'Metoprolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETALOC 25 (Astrazeneca)'
);

-- line #20941
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETALOC 50 (Astrazeneca)',
	'Metoprolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETALOC 50 (Astrazeneca)'
);

-- line #20942
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETALOL 2.5 (EAST WEST)',
	'Metoprolol',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'5'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETALOL 2.5 (EAST WEST)'
);

-- line #20943
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETAONE 12.5 (Dr.Reddy''S)',
	'Metoprolol',
	'XL TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETAONE 12.5 (Dr.Reddy''S)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETAONE 100 (Dr.Reddy''S)',
	'Metoprolol',
	'XL TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETAONE 100 (Dr.Reddy''S)'
);

-- line #20944
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETATONE 12.5 (Dr.Reddy''S)',
	'Metoprolol',
	'XL CAP',
	gm.nullify_empty_string('12.5')::numeric,
	'mg(ER)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETATONE 12.5 (Dr.Reddy''S)'
);

-- line #20945
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETATONE 25 (Dr.Reddy''S)',
	'Metoprolol',
	'XL TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg(ER)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETATONE 25 (Dr.Reddy''S)'
);

-- line #20946
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETATONE 50 (Dr.Reddy''S)',
	'Metoprolol',
	'XL TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg(ER)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETATONE 50 (Dr.Reddy''S)'
);

-- line #20947
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'25', u'strength_2': u'', u'substance': u'Metoprolol', u'always_empty': u'', u'form': u'', u'brand': u'BITAFIT', u'strength_3': u'', u'company': u'Unisearch', u'unit': u'mg'}

-- line #20948
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50', u'strength_2': u'', u'substance': u'Metoprolol', u'always_empty': u'', u'form': u'', u'brand': u'BITAFIT', u'strength_3': u'', u'company': u'Unisearch', u'unit': u'mg'}

-- line #20949
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLUMETA 25 (Blue Cross)',
	'Metoprolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg (TART.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLUMETA 25 (Blue Cross)'
);

-- line #20950
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLUMETA 50 (Blue Cross)',
	'Metoprolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg (TART.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLUMETA 50 (Blue Cross)'
);

-- line #20951
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLUMET 25 (Blue Cross)',
	'Metoprolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLUMET 25 (Blue Cross)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLUMET 50 (Blue Cross)',
	'Metoprolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLUMET 50 (Blue Cross)'
);

-- line #20952
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BP-LOC 25 (AEGIS)',
	'Metoprolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BP-LOC 25 (AEGIS)'
);

-- line #20953
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BPMET 12.5 (Emcure)',
	'Metoprolol',
	'XL TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg S(-)(TART.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BPMET 12.5 (Emcure)'
);

-- line #20954
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BPMET 25 (Emcure)',
	'Metoprolol',
	'XL TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg S(-)(TART.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BPMET 25 (Emcure)'
);

-- line #20955
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BPMET 50 (Emcure)',
	'Metoprolol',
	'XL TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg S(-)(TART.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BPMET 50 (Emcure)'
);

-- line #20956
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDIBETA 100 (Ranbaxy)',
	'Metoprolol',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg (95'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDIBETA 100 (Ranbaxy)'
);

-- line #20957
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDIBETA 12.5 (Ranbaxy)',
	'Metoprolol',
	'CAP',
	gm.nullify_empty_string('12.5')::numeric,
	'mg (11.875 METOPROLOL SUCC.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDIBETA 12.5 (Ranbaxy)'
);

-- line #20958
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDIBETA 25 (Ranbaxy)',
	'Metoprolol',
	'CAP',
	gm.nullify_empty_string('25')::numeric,
	'mg (23.75 METOPROLOL SUCC.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDIBETA 25 (Ranbaxy)'
);

-- line #20959
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDIBETA 50 (Ranbaxy)',
	'Metoprolol',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg (47.5 METOPROLOL SUCC.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDIBETA 50 (Ranbaxy)'
);

-- line #20960
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYMET 25 (Systopic)',
	'Metoprolol',
	'ER TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYMET 25 (Systopic)'
);

-- line #20961
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYMET 50 (Systopic)',
	'Metoprolol',
	'ER TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYMET 50 (Systopic)'
);

-- line #20962
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMBETA 100 (Intas)',
	'Metoprolol',
	'XR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg (95'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMBETA 100 (Intas)'
);

-- line #20963
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMBETA 25 (Intas)',
	'Metoprolol',
	'XR TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMBETA 25 (Intas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMBETA 50 (Intas)',
	'Metoprolol',
	'XR TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMBETA 50 (Intas)'
);

-- line #20964
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GUDPRES 25 (Mankind)',
	'Metoprolol',
	'XL TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg(TART.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GUDPRES 25 (Mankind)'
);

-- line #20965
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GUDPRES 50 (Mankind)',
	'Metoprolol',
	'XL TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GUDPRES 50 (Mankind)'
);

-- line #20966
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTRAMET 25 (Intra Lab)',
	'Metoprolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTRAMET 25 (Intra Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTRAMET 50 (Intra Lab)',
	'Metoprolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTRAMET 50 (Intra Lab)'
);

-- line #20967
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KIMET 12.5 (Zuventus)',
	'Metoprolol',
	'XL TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg((S METOPROLOL SUCC.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KIMET 12.5 (Zuventus)'
);

-- line #20968
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KIMET 25 (Zuventus)',
	'Metoprolol',
	'XL TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg((S METOPROLOL SUCC.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KIMET 25 (Zuventus)'
);

-- line #20969
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KIMET 50 (Zuventus)',
	'Metoprolol',
	'XL TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg((S METOPROLOL SUCC.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KIMET 50 (Zuventus)'
);

-- line #20970
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100', u'strength_2': u'', u'substance': u'Metoprolol', u'always_empty': u'', u'form': u'', u'brand': u'LOPRESOR MG', u'strength_3': u'', u'company': u'Novartis', u'unit': u'mg'}

-- line #20971
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOPRESOR 25 (NOVARTIS)',
	'Metoprolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOPRESOR 25 (NOVARTIS)'
);

-- line #20972
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOPRESOR 50 (Novartis)',
	'Metoprolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOPRESOR 50 (Novartis)'
);

-- line #20973
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOPRESOR 50 (Novartis)',
	'Metoprolol',
	'XL TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg E.R.'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOPRESOR 50 (Novartis)'
);

-- line #20974
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEPOL 50 (Taurus Lab)',
	'Metoprolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEPOL 50 (Taurus Lab)'
);

-- line #20975
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METALOC 100 (ERIS LIFE)',
	'Metoprolol',
	'XL TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METALOC 100 (ERIS LIFE)'
);

-- line #20976
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METALOC 25 (ERIS LIFE)',
	'Metoprolol',
	'XL TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METALOC 25 (ERIS LIFE)'
);

-- line #20977
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METALOC 50 (ERIS LIFE)',
	'Metoprolol',
	'XL TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METALOC 50 (ERIS LIFE)'
);

-- line #20978
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METAPRO 25 (Micro Labs)',
	'Metoprolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METAPRO 25 (Micro Labs)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METAPRO 50 (Micro Labs)',
	'Metoprolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METAPRO 50 (Micro Labs)'
);

-- line #20979
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METAPRO 25 (Micro Labs)',
	'Metoprolol',
	'XL TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg(SUCC.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METAPRO 25 (Micro Labs)'
);

-- line #20980
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METAPRO 50 (Micro Labs)',
	'Metoprolol',
	'XL TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg(SUCC.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METAPRO 50 (Micro Labs)'
);

-- line #20981
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METFIRST 25 (SINSAN PH.)',
	'Metoprolol',
	'XL TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METFIRST 25 (SINSAN PH.)'
);

-- line #20982
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METFIRST 50 (SINSAN PH.)',
	'Metoprolol',
	'XL TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METFIRST 50 (SINSAN PH.)'
);

-- line #20983
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METOCARD 100 (Torrent)',
	'Metoprolol',
	'XL TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METOCARD 100 (Torrent)'
);

-- line #20984
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METOCARD 12.5 (Torrent)',
	'Metoprolol',
	'XL TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METOCARD 12.5 (Torrent)'
);

-- line #20985
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METOCARD 25 (Torrent)',
	'Metoprolol',
	'XL TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METOCARD 25 (Torrent)'
);

-- line #20986
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METOCARD 50 (Torrent)',
	'Metoprolol',
	'XL TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METOCARD 50 (Torrent)'
);

-- line #20987
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METOCARD 75 (Torrent)',
	'Metoprolol',
	'XL TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METOCARD 75 (Torrent)'
);

-- line #20988
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METOCARE 25 (Intra(INVISION))',
	'Metoprolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METOCARE 25 (Intra(INVISION))'
);

-- line #20989
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METOCARE 50 (Intra(INVISION))',
	'Metoprolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METOCARE 50 (Intra(INVISION))'
);

-- line #20990
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METO 12.5 (Mano Ph.)',
	'Metoprolol',
	'ER TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METO 12.5 (Mano Ph.)'
);

-- line #20991
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METO 100 (Orchid Hc.)',
	'Metoprolol',
	'ER TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METO 100 (Orchid Hc.)'
);

-- line #20992
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METO 25 (Orchid Hc.)',
	'Metoprolol',
	'ER TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METO 25 (Orchid Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METO 50 (Orchid Hc.)',
	'Metoprolol',
	'ER TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METO 50 (Orchid Hc.)'
);

-- line #20993
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METOFIN 25 (QCHECK)',
	'Metoprolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METOFIN 25 (QCHECK)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METOFIN 50 (QCHECK)',
	'Metoprolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METOFIN 50 (QCHECK)'
);

-- line #20994
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METOGOLD 25 (VIDACARE PH.)',
	'Metoprolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METOGOLD 25 (VIDACARE PH.)'
);

-- line #20995
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METOGOLD 50 (VIDACARE PH.)',
	'Metoprolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METOGOLD 50 (VIDACARE PH.)'
);

-- line #20996
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METOLAR 1 (Cipla)',
	'Metoprolol',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METOLAR 1 (Cipla)'
);

-- line #20997
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METOLAR 100 (Cipla)',
	'Metoprolol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METOLAR 100 (Cipla)'
);

-- line #20998
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METOLAR 25 (Cipla)',
	'Metoprolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METOLAR 25 (Cipla)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METOLAR 50 (Cipla)',
	'Metoprolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METOLAR 50 (Cipla)'
);

-- line #20999
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METOLAR 12.5 (Cipla)',
	'Metoprolol',
	'XR CAP',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METOLAR 12.5 (Cipla)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METOLAR 25 (Cipla)',
	'Metoprolol',
	'XR CAP',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METOLAR 25 (Cipla)'
);

-- line #21000
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METOLAR 50 (Cipla)',
	'Metoprolol',
	'XR CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METOLAR 50 (Cipla)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METOLAR 100 (Cipla)',
	'Metoprolol',
	'XR CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METOLAR 100 (Cipla)'
);

-- line #21001
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METOMAC 25 (Macleods)',
	'Metoprolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METOMAC 25 (Macleods)'
);

-- line #21002
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METOMAC 50 (Macleods)',
	'Metoprolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METOMAC 50 (Macleods)'
);

-- line #21003
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METOPROL 25 (ECON HC.)',
	'Metoprolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METOPROL 25 (ECON HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METOPROL 50 (ECON HC.)',
	'Metoprolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METOPROL 50 (ECON HC.)'
);

-- line #21004
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METO 100 (Mano)',
	'Metoprolol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METO 100 (Mano)'
);

-- line #21005
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METO 25 (Mano)',
	'Metoprolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METO 25 (Mano)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METO 50 (Mano)',
	'Metoprolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METO 50 (Mano)'
);

-- line #21006
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METOX 100 (Wockhardt)',
	'Metoprolol',
	'ER TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METOX 100 (Wockhardt)'
);

-- line #21007
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METOX 25 (Wockhardt)',
	'Metoprolol',
	'ER TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METOX 25 (Wockhardt)'
);

-- line #21008
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METOX 50 (Wockhardt)',
	'Metoprolol',
	'ER TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METOX 50 (Wockhardt)'
);

-- line #21009
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METPURE IR 25 (Emcure)',
	'Metoprolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg(S-METOPROLOL TART.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METPURE IR 25 (Emcure)'
);

-- line #21010
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METPURE IR 50 (Emcure)',
	'Metoprolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg(S-METOPROLOL TART.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METPURE IR 50 (Emcure)'
);

-- line #21011
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10', u'strength_2': u'', u'substance': u'Metoprolol', u'always_empty': u'', u'form': u'', u'brand': u'METPURE ORAL', u'strength_3': u'', u'company': u'Emcure', u'unit': u'mg(S-METOPROLOL TART.)'}

-- line #21012
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METPURE 25 (Emcure)',
	'Metoprolol',
	'XL TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg(S-METOPROLOL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METPURE 25 (Emcure)'
);

-- line #21013
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METPURE 50 (Emcure)',
	'Metoprolol',
	'XL TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg(S-METOPROLOL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METPURE 50 (Emcure)'
);

-- line #21014
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METSPOT 25 (Cadila Ph.)',
	'Metoprolol',
	'XL TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METSPOT 25 (Cadila Ph.)'
);

-- line #21015
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METSPOT 50 (Cadila Ph.)',
	'Metoprolol',
	'XL TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METSPOT 50 (Cadila Ph.)'
);

-- line #21016
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MET 100 (Ajanta Ph.)',
	'Metoprolol',
	'XL TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MET 100 (Ajanta Ph.)'
);

-- line #21017
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MET 12.5 (Ajanta Ph.)',
	'Metoprolol',
	'XL TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MET 12.5 (Ajanta Ph.)'
);

-- line #21018
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MET 25 (Ajanta Ph.)',
	'Metoprolol',
	'XL TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MET 25 (Ajanta Ph.)'
);

-- line #21019
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MET 50 (Ajanta Ph.)',
	'Metoprolol',
	'XL TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MET 50 (Ajanta Ph.)'
);

-- line #21020
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METZOK 100 (CORVETTE (USV))',
	'Metoprolol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METZOK 100 (CORVETTE (USV))'
);

-- line #21021
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METZOK 12.5 (CORVETTE (USV))',
	'Metoprolol',
	'TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METZOK 12.5 (CORVETTE (USV))'
);

-- line #21022
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METZOK 25 (CORVETTE (USV))',
	'Metoprolol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METZOK 25 (CORVETTE (USV))'
);

-- line #21023
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METZOK 50 (CORVETTE (USV))',
	'Metoprolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METZOK 50 (CORVETTE (USV))'
);

-- line #21024
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METZ 50 (ARCUS LABS)',
	'Metoprolol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg(SUCCINATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METZ 50 (ARCUS LABS)'
);

-- line #21025
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEXES 25 (AAMORB)',
	'Metoprolol',
	'ER TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEXES 25 (AAMORB)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEXES 50 (AAMORB)',
	'Metoprolol',
	'ER TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEXES 50 (AAMORB)'
);

-- line #21026
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEXES 25 (AAMORB(XEENA))',
	'Metoprolol',
	'XL EXT TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEXES 25 (AAMORB(XEENA))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEXES 50 (AAMORB(XEENA))',
	'Metoprolol',
	'XL EXT TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEXES 50 (AAMORB(XEENA))'
);

-- line #21027
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'M-LOL 25 (MOVA PH.)',
	'Metoprolol',
	'ER TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'M-LOL 25 (MOVA PH.)'
);

-- line #21028
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'M-LOL 50 (MOVA PH.)',
	'Metoprolol',
	'ER TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'M-LOL 50 (MOVA PH.)'
);

-- line #21029
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOTOBLOCK 50 (TALENT LAB.)',
	'Metoprolol',
	'XR TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOTOBLOCK 50 (TALENT LAB.)'
);

-- line #21030
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYOPROL 100 (Otsira)',
	'Metoprolol',
	'XL TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYOPROL 100 (Otsira)'
);

-- line #21031
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYOPROL 25 (Otsira)',
	'Metoprolol',
	'XL TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYOPROL 25 (Otsira)'
);

-- line #21032
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYOPROL 50 (Otsira)',
	'Metoprolol',
	'XL TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYOPROL 50 (Otsira)'
);

-- line #21033
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROLOMET 12.5 (SUN)',
	'Metoprolol',
	'XL TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg(SUCCINATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROLOMET 12.5 (SUN)'
);

-- line #21034
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROTOL 100 (ERIS THER.)',
	'Metoprolol',
	'XL TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROTOL 100 (ERIS THER.)'
);

-- line #21035
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROTOL 25 (ERIS THER.)',
	'Metoprolol',
	'XL TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROTOL 25 (ERIS THER.)'
);

-- line #21036
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROTOL 50 (ERIS THER.)',
	'Metoprolol',
	'XL TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROTOL 50 (ERIS THER.)'
);

-- line #21037
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALDEZOLE 200 (Albert D.)',
	'Metronidazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALDEZOLE 200 (Albert D.)'
);

-- line #21038
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALDEZOLE 200 (Albert D.)',
	'Metronidazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALDEZOLE 200 (Albert D.)'
);

-- line #21039
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALDEZOLE 400 (Albert D.)',
	'Metronidazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALDEZOLE 400 (Albert D.)'
);

-- line #21040
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALDEZOL IV 500 (Albert D.)',
	'Metronidazole',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALDEZOL IV 500 (Albert D.)'
);

-- line #21041
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANAERID SIV 500 (Mount M.)',
	'Metronidazole',
	'INF',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANAERID SIV 500 (Mount M.)'
);

-- line #21042
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANTAMEBIN 200 (R.B.)',
	'Metronidazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANTAMEBIN 200 (R.B.)'
);

-- line #21043
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANTAMEBIN 200 (R.B.)',
	'Metronidazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANTAMEBIN 200 (R.B.)'
);

-- line #21044
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANTIGYL 400 (Pharma synth)',
	'Metronidazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANTIGYL 400 (Pharma synth)'
);

-- line #21045
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500', u'strength_2': u'', u'substance': u'Metronidazole', u'always_empty': u'', u'form': u'', u'brand': u'ARISTOGYL IV', u'strength_3': u'', u'company': u'Aristo', u'unit': u'mg/100ML'}

-- line #21046
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARISTOGYL 100 (Aristo)',
	'Metronidazole',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARISTOGYL 100 (Aristo)'
);

-- line #21047
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARISTOGYL 200 (Aristo)',
	'Metronidazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARISTOGYL 200 (Aristo)'
);

-- line #21048
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARISTOGYL 400 (Aristo)',
	'Metronidazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARISTOGYL 400 (Aristo)'
);

-- line #21049
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVIMET 100 (Moraceae)',
	'Metronidazole',
	'SUSP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVIMET 100 (Moraceae)'
);

-- line #21050
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'NI', u'strength_2': u'', u'substance': u'Metronidazole', u'always_empty': u'', u'form': u'GEL', u'brand': u'BALGYL', u'strength_3': u'', u'company': u'Bal Ph.', u'unit': u''}

-- line #21051
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COMPEBA 200 (Idpl)',
	'Metronidazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COMPEBA 200 (Idpl)'
);

-- line #21052
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMNAC 400 (EMCURE)',
	'Metronidazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMNAC 400 (EMCURE)'
);

-- line #21053
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLAGYL 500 (Nicholas)',
	'Metronidazole',
	'INF',
	gm.nullify_empty_string('500')::numeric,
	'mg/100ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLAGYL 500 (Nicholas)'
);

-- line #21054
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLAGYL 200 (Nicholas)',
	'Metronidazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg(BENZ.)/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLAGYL 200 (Nicholas)'
);

-- line #21055
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLAGYL 200 (Nicholas)',
	'Metronidazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLAGYL 200 (Nicholas)'
);

-- line #21056
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLAGYL 400 (Nicholas)',
	'Metronidazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLAGYL 400 (Nicholas)'
);

-- line #21057
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUCOGYL 0.2 (Mount M.)',
	'Metronidazole',
	'INJ',
	gm.nullify_empty_string('0.2')::numeric,
	'5'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUCOGYL 0.2 (Mount M.)'
);

-- line #21058
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IVMETRO 500 (Torrent)',
	'Metronidazole',
	'INF',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IVMETRO 500 (Torrent)'
);

-- line #21059
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KLONT 200 (Dolphin)',
	'Metronidazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KLONT 200 (Dolphin)'
);

-- line #21060
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KLONT 400 (Dolphin)',
	'Metronidazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KLONT 400 (Dolphin)'
);

-- line #21061
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LARGYL 0.5 (Lark Lab)',
	'Metronidazole',
	'GEL',
	gm.nullify_empty_string('0.5')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LARGYL 0.5 (Lark Lab)'
);

-- line #21062
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LARGYL 200 (Lark Lab)',
	'Metronidazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LARGYL 200 (Lark Lab)'
);

-- line #21063
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LARGYL 400 (Lark Lab)',
	'Metronidazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LARGYL 400 (Lark Lab)'
);

-- line #21064
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Metronidazole', u'always_empty': u'', u'form': u'GEL', u'brand': u'LUPIGYL', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #21065
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METGYL 200 (Jagsonpal)',
	'Metronidazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METGYL 200 (Jagsonpal)'
);

-- line #21066
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METGYL 400 (Jagsonpal)',
	'Metronidazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METGYL 400 (Jagsonpal)'
);

-- line #21067
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METRIS 500 (Claris L.)',
	'Metronidazole',
	'INF',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METRIS 500 (Claris L.)'
);

-- line #21068
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METROGYL 1 (J.B. CHEM)',
	'Metronidazole',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METROGYL 1 (J.B. CHEM)'
);

-- line #21069
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500', u'strength_2': u'', u'substance': u'Metronidazole', u'always_empty': u'', u'form': u'', u'brand': u'METROGYL IV', u'strength_3': u'', u'company': u'J.B. CHEM', u'unit': u'mg/5ML'}

-- line #21070
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METROGYL 200 (J.B. CHEM)',
	'Metronidazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METROGYL 200 (J.B. CHEM)'
);

-- line #21071
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METROGYL 200 (J.B. CHEM)',
	'Metronidazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METROGYL 200 (J.B. CHEM)'
);

-- line #21072
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METROGYL 400 (J.B. CHEM)',
	'Metronidazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METROGYL 400 (J.B. CHEM)'
);

-- line #21073
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METROGYL-V 10 (J.B. CHEM)',
	'Metronidazole',
	'GEL',
	gm.nullify_empty_string('10')::numeric,
	'mg/G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METROGYL-V 10 (J.B. CHEM)'
);

-- line #21074
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METRON -F 400 (Alkem)',
	'Metronidazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METRON -F 400 (Alkem)'
);

-- line #21075
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METRONIDAZOLE 500 (Albert D.)',
	'Metronidazole',
	'INF',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METRONIDAZOLE 500 (Albert D.)'
);

-- line #21076
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500', u'strength_2': u'', u'substance': u'Metronidazole', u'always_empty': u'', u'form': u'', u'brand': u'METRONIDAZOLE IV', u'strength_3': u'', u'company': u'Claris L.', u'unit': u'mg'}

-- line #21077
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METRON 5 (Alkem)',
	'Metronidazole',
	'INF',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML (AS BENZOATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METRON 5 (Alkem)'
);

-- line #21078
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500', u'strength_2': u'', u'substance': u'Metronidazole', u'always_empty': u'', u'form': u'', u'brand': u'METRON IV', u'strength_3': u'', u'company': u'Alkem', u'unit': u'mg'}

-- line #21079
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METRON 200 (Alkem)',
	'Metronidazole',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML(AS BENZOATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METRON 200 (Alkem)'
);

-- line #21080
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METRON 200 (Alkem)',
	'Metronidazole',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METRON 200 (Alkem)'
);

-- line #21081
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METROSUN - 400 (Sunij)',
	'Metronidazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METROSUN - 400 (Sunij)'
);

-- line #21082
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MET 400 (Ind-Swift)',
	'Metronidazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MET 400 (Ind-Swift)'
);

-- line #21083
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MET 400 (Torrent)',
	'Metronidazole',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MET 400 (Torrent)'
);

-- line #21084
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONIZOLE 600 (P C INDIA)',
	'Metronidazole',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONIZOLE 600 (P C INDIA)'
);

-- line #21085
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PDZOLE-D 200 (Parenteral)',
	'Metronidazole',
	'INF',
	gm.nullify_empty_string('200')::numeric,
	'mg/100ML(5'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PDZOLE-D 200 (Parenteral)'
);

-- line #21086
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEXITIL 150 (German R.)',
	'Mexiletine Hcl.',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEXITIL 150 (German R.)'
);

-- line #21087
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEXITIL 50 (German R.)',
	'Mexiletine Hcl.',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEXITIL 50 (German R.)'
);

-- line #21088
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEXITIL 250 (German R.)',
	'Mexiletine Hcl.',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEXITIL 250 (German R.)'
);

-- line #21089
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPNON 10 (Infar)',
	'Mianserin Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPNON 10 (Infar)'
);

-- line #21090
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPNON 30 (Infar)',
	'Mianserin Hcl.',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPNON 30 (Infar)'
);

-- line #21091
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCAMINE 50 (Gsk)',
	'MICAFUNGIN',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCAMINE 50 (Gsk)'
);

-- line #21092
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETADINE 200 (Win Medicare)',
	'MICONAZOLE',
	'VAGINAL',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETADINE 200 (Win Medicare)'
);

-- line #21093
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANDISTAT 2 (Merck)',
	'Miconazole',
	'CRM',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANDISTAT 2 (Merck)'
);

-- line #21094
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANDIZOLE 2 (Bal Ph.)',
	'Miconazole',
	'CRM',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANDIZOLE 2 (Bal Ph.)'
);

-- line #21095
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAKTARIN 2 (Ethnor)',
	'Miconazole',
	'CRM',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAKTARIN 2 (Ethnor)'
);

-- line #21096
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAKTARIN 2 (Ethnor)',
	'Miconazole',
	'GEL',
	gm.nullify_empty_string('2')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAKTARIN 2 (Ethnor)'
);

-- line #21097
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAKTARIN 2 (Ethnor)',
	'Miconazole',
	'POW',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAKTARIN 2 (Ethnor)'
);

-- line #21098
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAKTARIN 2 (Ethnor)',
	'Miconazole',
	'SOL',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAKTARIN 2 (Ethnor)'
);

-- line #21099
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECANAZOLE 2 (Alkem)',
	'Miconazole',
	'CRM',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECANAZOLE 2 (Alkem)'
);

-- line #21100
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DERMIZOLE 2 (Alkem)',
	'Miconazole',
	'CRM',
	gm.nullify_empty_string('2')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DERMIZOLE 2 (Alkem)'
);

-- line #21101
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMICONAZOLE 2 (Emcure)',
	'Miconazole',
	'GEL',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMICONAZOLE 2 (Emcure)'
);

-- line #21102
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNGITOP 2 (Micro Labs)',
	'Miconazole',
	'GEL',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNGITOP 2 (Micro Labs)'
);

-- line #21103
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GYNO DAKTARIN 2 (Ethnor)',
	'Miconazole',
	'GEL',
	gm.nullify_empty_string('2')::numeric,
	'% W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GYNO DAKTARIN 2 (Ethnor)'
);

-- line #21104
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200', u'strength_2': u'', u'substance': u'Miconazole', u'always_empty': u'', u'form': u'', u'brand': u'GYNO DAKTARIN OVULES', u'strength_3': u'', u'company': u'J.&J.', u'unit': u'mg'}

-- line #21105
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICODOL 2 (Dolphin)',
	'Miconazole',
	'OINT',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICODOL 2 (Dolphin)'
);

-- line #21106
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICOGEL 2 (Cipla)',
	'Miconazole',
	'CRM',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICOGEL 2 (Cipla)'
);

-- line #21107
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Miconazole', u'always_empty': u'', u'form': u'CRM', u'brand': u'MICONAZOLE', u'strength_3': u'', u'company': u'Dopson Ph.', u'unit': u''}

-- line #21108
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20G', u'strength_2': u'', u'substance': u'Miconazole', u'always_empty': u'', u'form': u'GEL', u'brand': u'MICONIT', u'strength_3': u'', u'company': u'EAST WEST', u'unit': u''}

-- line #21109
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1', u'strength_2': u'', u'substance': u'Miconazole', u'always_empty': u'', u'form': u'', u'brand': u'MICOPTIC OPTICOP', u'strength_3': u'', u'company': u'F D C', u'unit': u'%W/V'}

-- line #21110
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICOSON 2 (AGIO PH.)',
	'Miconazole',
	'CRM',
	gm.nullify_empty_string('2')::numeric,
	'%W/W/G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICOSON 2 (AGIO PH.)'
);

-- line #21111
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCOBAN 1 (Perch)',
	'Miconazole',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCOBAN 1 (Perch)'
);

-- line #21112
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCOBAN 1 (Perch)',
	'Miconazole',
	'POW',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCOBAN 1 (Perch)'
);

-- line #21113
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCOBAN 1 (Perch)',
	'Miconazole',
	'SOL',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCOBAN 1 (Perch)'
);

-- line #21114
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLMICO 2 (Olcare)',
	'Miconazole',
	'CRM',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLMICO 2 (Olcare)'
);

-- line #21115
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REXGARD 2 (Sandoz)',
	'Miconazole',
	'TUBE',
	gm.nullify_empty_string('2')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REXGARD 2 (Sandoz)'
);

-- line #21116
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2', u'strength_2': u'', u'substance': u'Miconazole', u'always_empty': u'', u'form': u'', u'brand': u'RINGCUTER-M', u'strength_3': u'', u'company': u'Jagsonpal', u'unit': u'%'}

-- line #21117
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AIMIZOLAM 1 (ALEMBIC)',
	'Midazolam',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AIMIZOLAM 1 (ALEMBIC)'
);

-- line #21118
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENZOSED 5 (Troikaa)',
	'Midazolam',
	'AMP',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENZOSED 5 (Troikaa)'
);

-- line #21119
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENZOSED 1 (Troikaa)',
	'Midazolam',
	'VIAL',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENZOSED 1 (Troikaa)'
);

-- line #21120
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FULSED 5 (Ranbaxy)',
	'Midazolam',
	'AMP',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FULSED 5 (Ranbaxy)'
);

-- line #21121
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FULSED 1 (Ranbaxy)',
	'Midazolam',
	'VIAL',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FULSED 1 (Ranbaxy)'
);

-- line #21122
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'15', u'strength_2': u'', u'substance': u'Midazolam', u'always_empty': u'', u'form': u'', u'brand': u'INSED NASAL ATOMISER', u'strength_3': u'', u'company': u'Samarth', u'unit': u'mg/3ML'}

-- line #21123
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEZOLAM 5 (Neon)',
	'Midazolam',
	'AMP',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEZOLAM 5 (Neon)'
);

-- line #21124
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Midazolam', u'always_empty': u'', u'form': u'', u'brand': u'MEZOLAM', u'strength_3': u'', u'company': u'Neon', u'unit': u''}

-- line #21125
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEZOLAM 7.5 (Neon)',
	'Midazolam',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEZOLAM 7.5 (Neon)'
);

-- line #21126
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEZOLAM 1 (Neon)',
	'Midazolam',
	'VIAL',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEZOLAM 1 (Neon)'
);

-- line #21127
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIBEN 5 (CELON(REVILON))',
	'Midazolam',
	'AMP',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIBEN 5 (CELON(REVILON))'
);

-- line #21128
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIBEN 1 (CELON(REVILON))',
	'Midazolam',
	'VIAL',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIBEN 1 (CELON(REVILON))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIBEN 10 (CELON(REVILON))',
	'Midazolam',
	'VIAL',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIBEN 10 (CELON(REVILON))'
);

-- line #21129
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIDAPIC 5 (Rusan Hc)',
	'MIDAZOLAM',
	'AMP',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIDAPIC 5 (Rusan Hc)'
);

-- line #21130
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIDAPIC 1 (Rusan Hc)',
	'MIDAZOLAM',
	'VIAL',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIDAPIC 1 (Rusan Hc)'
);

-- line #21131
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIDAZ 1 (Piramal Hc.)',
	'Midazolam',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIDAZ 1 (Piramal Hc.)'
);

-- line #21132
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIDAZ 5 (Piramal Hc.)',
	'Midazolam',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIDAZ 5 (Piramal Hc.)'
);

-- line #21133
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIDLUM 5 (Csc Ph.)',
	'Midazolam',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIDLUM 5 (Csc Ph.)'
);

-- line #21134
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIDOSED 1 (Sun)',
	'Midazolam',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIDOSED 1 (Sun)'
);

-- line #21135
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIDOSED 5 (Sun)',
	'Midazolam',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIDOSED 5 (Sun)'
);

-- line #21136
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIDZEE 1 (Gland Ph.)',
	'Midazolam',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'mg/10ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIDZEE 1 (Gland Ph.)'
);

-- line #21137
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIDZEE 1 (Gland Ph.)',
	'Midazolam',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIDZEE 1 (Gland Ph.)'
);

-- line #21138
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIDZEE 5 (Gland Ph.)',
	'Midazolam',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIDZEE 5 (Gland Ph.)'
);

-- line #21139
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIDZOL 10 (CH.Bhagat)',
	'Midazolam',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIDZOL 10 (CH.Bhagat)'
);

-- line #21140
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIDZOL 10 (CH.Bhagat)',
	'Midazolam',
	'VIAL',
	gm.nullify_empty_string('10')::numeric,
	'mg/10ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIDZOL 10 (CH.Bhagat)'
);

-- line #21141
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIDZOL 5 (CH.Bhagat)',
	'Midazolam',
	'VIAL',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIDZOL 5 (CH.Bhagat)'
);

-- line #21142
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PACIMID 5 (ZENOTECH LAB.)',
	'Midazolam',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PACIMID 5 (ZENOTECH LAB.)'
);

-- line #21143
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PACIMID (VI) 10 (ZENOTECH LAB.)',
	'Midazolam',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg/10ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PACIMID (VI) 10 (ZENOTECH LAB.)'
);

-- line #21144
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PACIMID (VI) 5 (ZENOTECH LAB.)',
	'Midazolam',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PACIMID (VI) 5 (ZENOTECH LAB.)'
);

-- line #21145
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ABORTAB 200 (Bharat S.)',
	'Mifepristone',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ABORTAB 200 (Bharat S.)'
);

-- line #21146
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANTI-PREG 200 (Intas)',
	'Mifepristone',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANTI-PREG 200 (Intas)'
);

-- line #21147
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONTRAPILL 200 (Cadila Ph.)',
	'Mifepristone',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONTRAPILL 200 (Cadila Ph.)'
);

-- line #21148
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EJECT 200 (Galpha)',
	'Mifepristone',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EJECT 200 (Galpha)'
);

-- line #21149
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELMIF 200 (Elder)',
	'Mifepristone',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELMIF 200 (Elder)'
);

-- line #21150
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'L-PILL-M 200 (Lincoln)',
	'Mifepristone',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'L-PILL-M 200 (Lincoln)'
);

-- line #21151
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEFEPIL 200 (Piramal Hc.)',
	'Mifepristone',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEFEPIL 200 (Piramal Hc.)'
);

-- line #21152
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEFEPRIN 200 (Sun)',
	'Mifepristone',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEFEPRIN 200 (Sun)'
);

-- line #21153
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEFIPIL 200 (Nicholas)',
	'Mifepristone',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEFIPIL 200 (Nicholas)'
);

-- line #21154
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEFIPRO 200 (HIND. LATEX)',
	'Mifepristone',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEFIPRO 200 (HIND. LATEX)'
);

-- line #21155
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEFIWIS 200 (Wisdom Ph.)',
	'Mifepristone',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEFIWIS 200 (Wisdom Ph.)'
);

-- line #21156
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEFNIL 200 (Lupin)',
	'Mifepristone',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEFNIL 200 (Lupin)'
);

-- line #21157
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MF-KARE 200 (DKT I.)',
	'Mifepristone',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MF-KARE 200 (DKT I.)'
);

-- line #21158
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Mifepristone', u'always_empty': u'', u'form': u'TAB', u'brand': u'MIFABORT', u'strength_3': u'', u'company': u'Troikaa', u'unit': u''}

-- line #21159
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIFEGEST 200 (Zydus)',
	'Mifepristone',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIFEGEST 200 (Zydus)'
);

-- line #21160
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIFEPRIN 200 (SUN)',
	'Mifepristone',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIFEPRIN 200 (SUN)'
);

-- line #21161
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIFEST 200 (AXYZEN LIFE)',
	'Mifepristone',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIFEST 200 (AXYZEN LIFE)'
);

-- line #21162
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MTPILL 200 (Cipla)',
	'Mifepristone',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MTPILL 200 (Cipla)'
);

-- line #21163
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIVC 200 (Alembic)',
	'Mifepristone',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIVC 200 (Alembic)'
);

-- line #21164
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RECYCLE PILL 200 (ROSE LABS)',
	'Mifepristone',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RECYCLE PILL 200 (ROSE LABS)'
);

-- line #21165
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELEZED 200 (Zee Lab)',
	'Mifepristone',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELEZED 200 (Zee Lab)'
);

-- line #21166
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLOCK 25 (Unisearch)',
	'MIGITOL',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLOCK 25 (Unisearch)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLOCK 50 (Unisearch)',
	'MIGITOL',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLOCK 50 (Unisearch)'
);

-- line #21167
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIAMIG 25 (Micro Labs)',
	'MIGLITOL',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIAMIG 25 (Micro Labs)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIAMIG 50 (Micro Labs)',
	'MIGLITOL',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIAMIG 50 (Micro Labs)'
);

-- line #21168
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELITOX 25 (Ranbaxy Cv)',
	'MIGLITOL',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELITOX 25 (Ranbaxy Cv)'
);

-- line #21169
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELITOX 50 (Ranbaxy C V)',
	'MIGLITOL',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELITOX 50 (Ranbaxy C V)'
);

-- line #21170
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUGLITOL 25 (Nicholas)',
	'MIGLITOL',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUGLITOL 25 (Nicholas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUGLITOL 50 (Nicholas)',
	'MIGLITOL',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUGLITOL 50 (Nicholas)'
);

-- line #21171
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIGLIT-25 25 (BIOCON LTD.)',
	'MIGLITOL',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIGLIT-25 25 (BIOCON LTD.)'
);

-- line #21172
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIGLIT-50 50 (BIOCON LTD.)',
	'MIGLITOL',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIGLIT-50 50 (BIOCON LTD.)'
);

-- line #21173
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIGNAR 25 (Healtheon)',
	'MIGLITOL',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIGNAR 25 (Healtheon)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIGNAR 50 (Healtheon)',
	'MIGLITOL',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIGNAR 50 (Healtheon)'
);

-- line #21174
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIGTOR 25 (Torrent)',
	'MIGLITOL',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIGTOR 25 (Torrent)'
);

-- line #21175
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIGTOR 50 (Torrent)',
	'MIGLITOL',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIGTOR 50 (Torrent)'
);

-- line #21176
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MINERVA 25 (Mano Ph.)',
	'MIGLITOL',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MINERVA 25 (Mano Ph.)'
);

-- line #21177
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MINERVA 50 (Mano Ph.)',
	'MIGLITOL',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MINERVA 50 (Mano Ph.)'
);

-- line #21178
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MISOBIT 25 (Lupin)',
	'MIGLITOL',
	'FC TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MISOBIT 25 (Lupin)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MISOBIT 50 (Lupin)',
	'MIGLITOL',
	'FC TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MISOBIT 50 (Lupin)'
);

-- line #21179
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MISOBIT 25 (LUPIN)',
	'MIGLITOL',
	'MD TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MISOBIT 25 (LUPIN)'
);

-- line #21180
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MISOBIT 50 (LUPIN)',
	'MIGLITOL',
	'MD TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MISOBIT 50 (LUPIN)'
);

-- line #21181
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACMIL 25 (Ranbaxy)',
	'MILANACIPRAN HCL.',
	'CAP',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACMIL 25 (Ranbaxy)'
);

-- line #21182
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACMIL 50 (Ranbaxy)',
	'MILANACIPRAN HCL.',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACMIL 50 (Ranbaxy)'
);

-- line #21183
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILBORN 25 (Sun)',
	'MILNACIPRAN HCL',
	'CAP',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILBORN 25 (Sun)'
);

-- line #21184
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILBORN 50 (Sun)',
	'MILNACIPRAN HCL',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILBORN 50 (Sun)'
);

-- line #21185
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILNACE 25 (Torrent)',
	'MILNACIPRAN HCL',
	'CAP',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILNACE 25 (Torrent)'
);

-- line #21186
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILNACE 50 (Torrent)',
	'MILNACIPRAN HCL',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILNACE 50 (Torrent)'
);

-- line #21187
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILPRAN 25 (VERIZON)',
	'MILNACIPRAN HCL',
	'CAP',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILPRAN 25 (VERIZON)'
);

-- line #21188
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILPRAN 50 (VERIZON)',
	'MILNACIPRAN HCL',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILPRAN 50 (VERIZON)'
);

-- line #21189
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILZA 25 (Intas)',
	'MILNACIPRAN HCL',
	'CAP',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILZA 25 (Intas)'
);

-- line #21190
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILZA 50 (Intas)',
	'MILNACIPRAN HCL',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILZA 50 (Intas)'
);

-- line #21191
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILICOR 10 (Samarth)',
	'MILRINONE',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg/10ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILICOR 10 (Samarth)'
);

-- line #21192
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILRIN 10 (Gland Ph.)',
	'Milrinone',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg/10ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILRIN 10 (Gland Ph.)'
);

-- line #21193
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILRON 10 (United Bio.)',
	'Milrinone',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg/10ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILRON 10 (United Bio.)'
);

-- line #21194
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYOLONG 1 (VHB)',
	'MILRINONE',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYOLONG 1 (VHB)'
);

-- line #21195
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIMACOR IV 1 (Sanofi Aventis)',
	'Milrinone',
	'AMP',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIMACOR IV 1 (Sanofi Aventis)'
);

-- line #21196
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEWSOFT 7.5 (Torrent)',
	'MINERAL OIL',
	'SOAP',
	gm.nullify_empty_string('7.5')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEWSOFT 7.5 (Torrent)'
);

-- line #21197
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'7,5', u'strength_2': u'', u'substance': u'MINERAL OIL', u'always_empty': u'', u'form': u'', u'brand': u'OILATUM BAR', u'strength_3': u'', u'company': u'STIEFEL', u'unit': u'%'}

-- line #21198
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CNN 100 (Ipca)',
	'Minocycline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CNN 100 (Ipca)'
);

-- line #21199
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CNN 50 (Ipca)',
	'Minocycline',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CNN 50 (Ipca)'
);

-- line #21200
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYNOMYCIN 100 (Wyeth)',
	'Minocycline',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYNOMYCIN 100 (Wyeth)'
);

-- line #21201
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYNOMYCIN 50 (Wyeth)',
	'Minocycline',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYNOMYCIN 50 (Wyeth)'
);

-- line #21202
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MINOLOX 50 (Micro V.)',
	'Minocycline',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MINOLOX 50 (Micro V.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MINOLOX 100 (Micro V.)',
	'Minocycline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MINOLOX 100 (Micro V.)'
);

-- line #21203
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMOLIN 100 (Ochoa)',
	'Minocycline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMOLIN 100 (Ochoa)'
);

-- line #21204
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMOLIN 50 (Ochoa)',
	'Minocycline',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMOLIN 50 (Ochoa)'
);

-- line #21205
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COVERIT % 10 (Micro Labs)',
	'Minoxidil',
	'SOL',
	gm.nullify_empty_string('10')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COVERIT % 10 (Micro Labs)'
);

-- line #21206
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COVERIT % 2 (Micro V.)',
	'Minoxidil',
	'SOLN',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COVERIT % 2 (Micro V.)'
);

-- line #21207
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COVERIT % 5 (Micro V.)',
	'Minoxidil',
	'SOLN',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COVERIT % 5 (Micro V.)'
);

-- line #21208
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVIDIL 50 (DIVINE LAB.)',
	'Minoxidil',
	'F. TOPICAL SOL',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVIDIL 50 (DIVINE LAB.)'
);

-- line #21209
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVIDIL TOPICAL 20 (DIVINE LAB.)',
	'Minoxidil',
	'SOL',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVIDIL TOPICAL 20 (DIVINE LAB.)'
);

-- line #21210
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GROMANE 20 (Zydus A.)',
	'Minoxidil',
	'SOL',
	gm.nullify_empty_string('20')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GROMANE 20 (Zydus A.)'
);

-- line #21211
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2', u'strength_2': u'', u'substance': u'Minoxidil', u'always_empty': u'', u'form': u'', u'brand': u'GROMO %', u'strength_3': u'', u'company': u'CHC', u'unit': u'60'}

-- line #21212
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5', u'strength_2': u'', u'substance': u'Minoxidil', u'always_empty': u'', u'form': u'', u'brand': u'GROMO %', u'strength_3': u'', u'company': u'CHC', u'unit': u'38'}

-- line #21213
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HAIREX 20 (KOPRAN)',
	'Minoxidil',
	'SOL',
	gm.nullify_empty_string('20')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HAIREX 20 (KOPRAN)'
);

-- line #21214
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEBALD 2 (Intas)',
	'Minoxidil',
	'SOL',
	gm.nullify_empty_string('2')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEBALD 2 (Intas)'
);

-- line #21215
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYGAINE 20 (Dabur Ph.)',
	'Minoxidil',
	'SOL',
	gm.nullify_empty_string('20')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYGAINE 20 (Dabur Ph.)'
);

-- line #21216
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INOXI 50 (PSYCOREM)',
	'Minoxidil',
	'F.',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INOXI 50 (PSYCOREM)'
);

-- line #21217
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INOXI 20 (PSYCOREM)',
	'Minoxidil',
	'SOL',
	gm.nullify_empty_string('20')::numeric,
	'100'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INOXI 20 (PSYCOREM)'
);

-- line #21218
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INOXI-T 5 (PSYCOREM)',
	'Minoxidil',
	'F. SOL',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INOXI-T 5 (PSYCOREM)'
);

-- line #21219
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INOXI-T 2 (PSYCOREM)',
	'Minoxidil',
	'SOL',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INOXI-T 2 (PSYCOREM)'
);

-- line #21220
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANDIL 2 (OREVA DARMO.)',
	'Minoxidil',
	'SOL',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANDIL 2 (OREVA DARMO.)'
);

-- line #21221
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANEXIL 2 (Fem care)',
	'Minoxidil',
	'GEL',
	gm.nullify_empty_string('2')::numeric,
	'%/W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANEXIL 2 (Fem care)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANEXIL 5 (Fem care)',
	'Minoxidil',
	'GEL',
	gm.nullify_empty_string('5')::numeric,
	'%/W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANEXIL 5 (Fem care)'
);

-- line #21222
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MINSCALP 2 (EAST WEST)',
	'Minoxidil',
	'GEL',
	gm.nullify_empty_string('2')::numeric,
	'5'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MINSCALP 2 (EAST WEST)'
);

-- line #21223
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MINTOP 5 (Dr.Reddy''S)',
	'Minoxidil',
	'F. FOAM',
	gm.nullify_empty_string('5')::numeric,
	'%( ABSOLUTE ALCOHOL 54.6'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MINTOP 5 (Dr.Reddy''S)'
);

-- line #21224
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MINTOP 2 (Dr.Reddy''S)',
	'Minoxidil',
	'FOAM',
	gm.nullify_empty_string('2')::numeric,
	'%( ABSOLUTE ALCOHOL 54.6'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MINTOP 2 (Dr.Reddy''S)'
);

-- line #21225
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Minoxidil', u'always_empty': u'', u'form': u'F. SOL', u'brand': u'MINTOP', u'strength_3': u'', u'company': u"Dr.Reddy''S", u'unit': u''}

-- line #21226
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MINTOP 100 (Dr.Reddy''S)',
	'Minoxidil',
	'SOL',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MINTOP 100 (Dr.Reddy''S)'
);

-- line #21227
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MINTOP 2 (Dr.Reddy''S)',
	'Minoxidil',
	'SOL',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MINTOP 2 (Dr.Reddy''S)'
);

-- line #21228
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MORR 5 (Intas)',
	'Minoxidil',
	'F. SOL',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MORR 5 (Intas)'
);

-- line #21229
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MORR 2 (Intas)',
	'Minoxidil',
	'SOL',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MORR 2 (Intas)'
);

-- line #21230
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MORR % 3 (Intas)',
	'Minoxidil',
	'SOL',
	gm.nullify_empty_string('3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MORR % 3 (Intas)'
);

-- line #21231
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Minoxidil', u'always_empty': u'', u'form': u'SPRAY', u'brand': u'MULTIGAIN', u'strength_3': u'', u'company': u'Torrent', u'unit': u''}

-- line #21232
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MX-2 TOPICAL 2 (H & H Ph.)',
	'Minoxidil',
	'SOL',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MX-2 TOPICAL 2 (H & H Ph.)'
);

-- line #21233
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MX-5 TOPICAL 5 (H & H Ph.)',
	'Minoxidil',
	'SOL',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MX-5 TOPICAL 5 (H & H Ph.)'
);

-- line #21234
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PILOGRO 2 (Fulford)',
	'Minoxidil',
	'SOL',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PILOGRO 2 (Fulford)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PILOGRO 5 (Fulford)',
	'Minoxidil',
	'SOL',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PILOGRO 5 (Fulford)'
);

-- line #21235
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Minoxidil', u'always_empty': u'', u'form': u'SOL', u'brand': u'REGROW', u'strength_3': u'', u'company': u'West Coast', u'unit': u''}

-- line #21236
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAZ 7.5 (EAST WEST)',
	'Mirtazapine',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAZ 7.5 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAZ 15 (EAST WEST)',
	'Mirtazapine',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAZ 15 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAZ 30 (EAST WEST)',
	'Mirtazapine',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAZ 30 (EAST WEST)'
);

-- line #21237
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Mirtazapine', u'always_empty': u'', u'form': u'TAB', u'brand': u'MEEZ-15', u'strength_3': u'', u'company': u'Biocin Hc.', u'unit': u''}

-- line #21238
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIRAMIND 15 (Torrent)',
	'Mirtazapine',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIRAMIND 15 (Torrent)'
);

-- line #21239
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIRAMIND 30 (Torrent)',
	'Mirtazapine',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIRAMIND 30 (Torrent)'
);

-- line #21240
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIRAMIND 7.5 (Torrent)',
	'Mirtazapine',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIRAMIND 7.5 (Torrent)'
);

-- line #21241
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIRAZEP 15 (Synapse)',
	'Mirtazapine',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIRAZEP 15 (Synapse)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIRAZEP 30 (Synapse)',
	'Mirtazapine',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIRAZEP 30 (Synapse)'
);

-- line #21242
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIRAZ 7.5 (Theo Ph.)',
	'Mirtazapine',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIRAZ 7.5 (Theo Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIRAZ 15 (Theo Ph.)',
	'Mirtazapine',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIRAZ 15 (Theo Ph.)'
);

-- line #21243
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIRNITE 15 (Intas)',
	'Mirtazapine',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIRNITE 15 (Intas)'
);

-- line #21244
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIRNITE 30 (Intas)',
	'Mirtazapine',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIRNITE 30 (Intas)'
);

-- line #21245
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIRNITE 45 (Intas)',
	'Mirtazapine',
	'TAB',
	gm.nullify_empty_string('45')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIRNITE 45 (Intas)'
);

-- line #21246
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIRPINE 30 (PSYCOREM)',
	'Mirtazapine',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIRPINE 30 (PSYCOREM)'
);

-- line #21247
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIRPINE 7.5 (PSYCOREM)',
	'Mirtazapine',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIRPINE 7.5 (PSYCOREM)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIRPINE 15 (PSYCOREM)',
	'Mirtazapine',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIRPINE 15 (PSYCOREM)'
);

-- line #21248
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIRTADEP 7.5 (Neu-Foreva)',
	'Mirtazapine',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIRTADEP 7.5 (Neu-Foreva)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIRTADEP 15 (Neu-Foreva)',
	'Mirtazapine',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIRTADEP 15 (Neu-Foreva)'
);

-- line #21249
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIRTAKEM 15 (Alkem)',
	'Mirtazapine',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIRTAKEM 15 (Alkem)'
);

-- line #21250
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIRTAKEM 30 (Alkem)',
	'Mirtazapine',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIRTAKEM 30 (Alkem)'
);

-- line #21251
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIRTAKEM 7.5 (Alkem)',
	'Mirtazapine',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIRTAKEM 7.5 (Alkem)'
);

-- line #21252
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIRTAZ 15 (Sun)',
	'Mirtazapine',
	'MD',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIRTAZ 15 (Sun)'
);

-- line #21253
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIRTAZ 30 (Sun)',
	'Mirtazapine',
	'MD',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIRTAZ 30 (Sun)'
);

-- line #21254
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIRTAZ 7.5 (Sun)',
	'Mirtazapine',
	'MD',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIRTAZ 7.5 (Sun)'
);

-- line #21255
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIRTAZ 15 (Sun)',
	'Mirtazapine',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIRTAZ 15 (Sun)'
);

-- line #21256
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIRTAZ 30 (Sun)',
	'Mirtazapine',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIRTAZ 30 (Sun)'
);

-- line #21257
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIRTAZ 7.5 (Sun)',
	'Mirtazapine',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIRTAZ 7.5 (Sun)'
);

-- line #21258
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIRT 15 (Panacea)',
	'Mirtazapine',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIRT 15 (Panacea)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIRT 30 (Panacea)',
	'Mirtazapine',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIRT 30 (Panacea)'
);

-- line #21259
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIRT 45 (Panacea)',
	'Mirtazapine',
	'TAB',
	gm.nullify_empty_string('45')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIRT 45 (Panacea)'
);

-- line #21260
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIRZEST 30 (LA DRUG)',
	'Mirtazapine',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIRZEST 30 (LA DRUG)'
);

-- line #21261
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIRZEST 7.5 (LA DRUG)',
	'Mirtazapine',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIRZEST 7.5 (LA DRUG)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIRZEST 15 (LA DRUG)',
	'Mirtazapine',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIRZEST 15 (LA DRUG)'
);

-- line #21262
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MITOCENT 7.5 (Crescent Th.)',
	'Mirtazapine',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MITOCENT 7.5 (Crescent Th.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MITOCENT 15 (Crescent Th.)',
	'Mirtazapine',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MITOCENT 15 (Crescent Th.)'
);

-- line #21263
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MITPIN 15 (D.D. PH.)',
	'Mirtazapine',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MITPIN 15 (D.D. PH.)'
);

-- line #21264
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIZ-15 15 (Tripada Hc.)',
	'Mirtazapine',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIZ-15 15 (Tripada Hc.)'
);

-- line #21265
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIZ-30 30 (Tripada Hc.)',
	'Mirtazapine',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIZ-30 30 (Tripada Hc.)'
);

-- line #21266
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIZ-75 7.5 (Tripada Hc.)',
	'Mirtazapine',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIZ-75 7.5 (Tripada Hc.)'
);

-- line #21267
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIZHRA 30 (CENTRA(USV))',
	'Mirtazapine',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIZHRA 30 (CENTRA(USV))'
);

-- line #21268
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIZHRA 7.5 (CENTRA(USV))',
	'Mirtazapine',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIZHRA 7.5 (CENTRA(USV))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIZHRA 15 (CENTRA(USV))',
	'Mirtazapine',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIZHRA 15 (CENTRA(USV))'
);

-- line #21269
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NASSA 15 (TRITON(CALYX))',
	'Mirtazapine',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NASSA 15 (TRITON(CALYX))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NASSA 30 (TRITON(CALYX))',
	'Mirtazapine',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NASSA 30 (TRITON(CALYX))'
);

-- line #21270
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUTAZ 15 (ALKEM)',
	'Mirtazapine',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUTAZ 15 (ALKEM)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUTAZ 30 (ALKEM)',
	'Mirtazapine',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUTAZ 30 (ALKEM)'
);

-- line #21271
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUTAZ 7.5 (ALKEM)',
	'Mirtazapine',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUTAZ 7.5 (ALKEM)'
);

-- line #21272
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMIR 15 (OREVA DARMO.)',
	'Mirtazapine',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMIR 15 (OREVA DARMO.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMIR 30 (OREVA DARMO.)',
	'Mirtazapine',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMIR 30 (OREVA DARMO.)'
);

-- line #21273
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESTOPAM 7.5 (AVIS LIFE)',
	'Mirtazapine',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESTOPAM 7.5 (AVIS LIFE)'
);

-- line #21274
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200MCG', u'strength_2': u'', u'substance': u'Misoprostol', u'always_empty': u'', u'form': u'DUO TAB', u'brand': u'CONTRAPILL', u'strength_3': u'', u'company': u'Cadila Ph.', u'unit': u''}

-- line #21275
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'25MCG', u'strength_2': u'', u'substance': u'Misoprostol', u'always_empty': u'', u'form': u'TAB', u'brand': u'CYROLOG', u'strength_3': u'', u'company': u'Zydus A.', u'unit': u''}

-- line #21276
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'25MCG', u'strength_2': u'', u'substance': u'Misoprostol', u'always_empty': u'', u'form': u'TAB', u'brand': u'CYTOLOG MCG', u'strength_3': u'', u'company': u'Zydus A.', u'unit': u''}

-- line #21277
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100MCG', u'strength_2': u'', u'substance': u'Misoprostol', u'always_empty': u'', u'form': u'TAB', u'brand': u'CYTOLOG', u'strength_3': u'', u'company': u'Zydus Cadila', u'unit': u''}

-- line #21278
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200MCG', u'strength_2': u'', u'substance': u'Misoprostol', u'always_empty': u'', u'form': u'TAB', u'brand': u'CYTOLOG', u'strength_3': u'', u'company': u'Zydus Cadila', u'unit': u''}

-- line #21279
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200MCG', u'strength_2': u'', u'substance': u'Misoprostol', u'always_empty': u'', u'form': u'TAB', u'brand': u'EMTEE', u'strength_3': u'', u'company': u'Ind-Swift', u'unit': u''}

-- line #21280
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200MCG', u'strength_2': u'', u'substance': u'Misoprostol', u'always_empty': u'', u'form': u'TAB', u'brand': u'L-PILL', u'strength_3': u'', u'company': u'Lincoln', u'unit': u''}

-- line #21281
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200MCG', u'strength_2': u'', u'substance': u'Misoprostol', u'always_empty': u'', u'form': u'TAB', u'brand': u'MESOPIL', u'strength_3': u'', u'company': u'Nicholas', u'unit': u''}

-- line #21282
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200MCG', u'strength_2': u'', u'substance': u'Misoprostol', u'always_empty': u'', u'form': u'TAB', u'brand': u'MIPROST', u'strength_3': u'', u'company': u'HIND. LATEX', u'unit': u''}

-- line #21283
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200MCG', u'strength_2': u'', u'substance': u'Misoprostol', u'always_empty': u'', u'form': u'TAB', u'brand': u'MISOGEST', u'strength_3': u'', u'company': u'Elder', u'unit': u''}

-- line #21284
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200MCG', u'strength_2': u'', u'substance': u'Misoprostol', u'always_empty': u'', u'form': u'TAB', u'brand': u'MISO-GYN', u'strength_3': u'', u'company': u'Bharat S.', u'unit': u''}

-- line #21285
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'25MCG', u'strength_2': u'', u'substance': u'Misoprostol', u'always_empty': u'', u'form': u'TAB', u'brand': u'MISO-GYN', u'strength_3': u'', u'company': u'Bharat S.', u'unit': u''}

-- line #21286
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50MCG', u'strength_2': u'', u'substance': u'Misoprostol', u'always_empty': u'', u'form': u'TAB', u'brand': u'MISO-GYN', u'strength_3': u'', u'company': u'Bharat S.', u'unit': u''}

-- line #21287
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200MCG', u'strength_2': u'', u'substance': u'Misoprostol', u'always_empty': u'', u'form': u'TAB', u'brand': u'MISOLAST MCG', u'strength_3': u'', u'company': u'F D C', u'unit': u''}

-- line #21288
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200MCG', u'strength_2': u'', u'substance': u'Misoprostol', u'always_empty': u'', u'form': u'TAB', u'brand': u'MISOLOG', u'strength_3': u'', u'company': u'Intas', u'unit': u''}

-- line #21289
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MISOLOG 25 (Intas)',
	'Misoprostol',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MISOLOG 25 (Intas)'
);

-- line #21290
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MISOLUP 200 (Lupin)',
	'Misoprostol',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MISOLUP 200 (Lupin)'
);

-- line #21291
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200MCG', u'strength_2': u'', u'substance': u'Misoprostol', u'always_empty': u'', u'form': u'TAB', u'brand': u'MISONIL', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #21292
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'25MCG', u'strength_2': u'', u'substance': u'Misoprostol', u'always_empty': u'', u'form': u'TAB', u'brand': u'MISONIL', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #21293
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200MCG', u'strength_2': u'', u'substance': u'Misoprostol', u'always_empty': u'', u'form': u'', u'brand': u'MISOPIL', u'strength_3': u'', u'company': u'Piramal Hc.', u'unit': u''}

-- line #21294
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100MCG', u'strength_2': u'', u'substance': u'Misoprostol', u'always_empty': u'', u'form': u'TAB', u'brand': u'MISOPROST', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #21295
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200MCG', u'strength_2': u'', u'substance': u'Misoprostol', u'always_empty': u'', u'form': u'TAB', u'brand': u'MISOPROST', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #21296
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'25MCG', u'strength_2': u'', u'substance': u'Misoprostol', u'always_empty': u'', u'form': u'TAB', u'brand': u'MISOPROST', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #21297
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200MCG', u'strength_2': u'', u'substance': u'Misoprostol', u'always_empty': u'', u'form': u'TAB', u'brand': u'MISO', u'strength_3': u'', u'company': u'Bestochem', u'unit': u''}

-- line #21298
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Misoprostol', u'always_empty': u'', u'form': u'TAB', u'brand': u'MISOTROY', u'strength_3': u'', u'company': u'Troikaa', u'unit': u''}

-- line #21299
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200MCG', u'strength_2': u'', u'substance': u'Misoprostol', u'always_empty': u'', u'form': u'TAB', u'brand': u'MIZOLAST', u'strength_3': u'', u'company': u'F D C', u'unit': u''}

-- line #21300
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'600MCG', u'strength_2': u'', u'substance': u'Misoprostol', u'always_empty': u'', u'form': u'TAB', u'brand': u'PPH', u'strength_3': u'', u'company': u'Meyer Org.', u'unit': u''}

-- line #21301
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200MCG', u'strength_2': u'', u'substance': u'Misoprostol', u'always_empty': u'', u'form': u'TAB', u'brand': u'PREGCLEAR', u'strength_3': u'', u'company': u'ALKEM', u'unit': u''}

-- line #21302
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200MCG', u'strength_2': u'', u'substance': u'Misoprostol', u'always_empty': u'', u'form': u'TAB', u'brand': u'PRESTAKIND', u'strength_3': u'', u'company': u'Mankind', u'unit': u''}

-- line #21303
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200MCG', u'strength_2': u'', u'substance': u'Misoprostol', u'always_empty': u'', u'form': u'TAB', u'brand': u'PROSTOL', u'strength_3': u'', u'company': u'ROSE LABS', u'unit': u''}

-- line #21304
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALMITO 10 (Cytomed(Alkem))',
	'Mitomycin',
	'VIAL',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALMITO 10 (Cytomed(Alkem))'
);

-- line #21305
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALMITO 2 (Cytomed(Alkem))',
	'Mitomycin',
	'VIAL',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALMITO 2 (Cytomed(Alkem))'
);

-- line #21306
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MITOCIN 10 (Cadila)',
	'Mitomycin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MITOCIN 10 (Cadila)'
);

-- line #21307
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MITOCIN 2 (Cadila)',
	'Mitomycin',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MITOCIN 2 (Cadila)'
);

-- line #21308
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MITODUS 10 (Oncomed)',
	'Mitomycin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MITODUS 10 (Oncomed)'
);

-- line #21309
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MITODUS 2 (Oncomed)',
	'Mitomycin',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MITODUS 2 (Oncomed)'
);

-- line #21310
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MITOMYCIN-C 10 (Biochem)',
	'Mitomycin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MITOMYCIN-C 10 (Biochem)'
);

-- line #21311
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MITOMYCIN-C 2 (Biochem)',
	'Mitomycin',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MITOMYCIN-C 2 (Biochem)'
);

-- line #21312
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MITOMYCIN-C 40 (BIOCHEM)',
	'Mitomycin',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MITOMYCIN-C 40 (BIOCHEM)'
);

-- line #21313
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MITONCO 10 (Vhb)',
	'Mitomycin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MITONCO 10 (Vhb)'
);

-- line #21314
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MITONCO 2 (Vhb)',
	'Mitomycin',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MITONCO 2 (Vhb)'
);

-- line #21315
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MITOPLUS 10 (Vhb)',
	'Mitomycin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MITOPLUS 10 (Vhb)'
);

-- line #21316
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MITOPLUS 2 (Vhb)',
	'Mitomycin',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MITOPLUS 2 (Vhb)'
);

-- line #21317
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONCOCIN 10 (CH.Bhagat)',
	'Mitomycin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONCOCIN 10 (CH.Bhagat)'
);

-- line #21318
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONCOCIN 2 (CH.Bhagat)',
	'Mitomycin',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONCOCIN 2 (CH.Bhagat)'
);

-- line #21319
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MITOZAN 20 (Vhb)',
	'Mitoxantrone',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg/10ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MITOZAN 20 (Vhb)'
);

-- line #21320
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONCOTRON 2 (Sun)',
	'Mitoxantrone',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONCOTRON 2 (Sun)'
);

-- line #21321
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIXCAROTIN 15.44 (Franco I.)',
	'Mixed Carotenoids',
	'CAP',
	gm.nullify_empty_string('15.44')::numeric,
	'mg(AS OILY SUS.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIXCAROTIN 15.44 (Franco I.)'
);

-- line #21322
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELINA 10 (Dr.Reddy''S)',
	'Mizolastine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELINA 10 (Dr.Reddy''S)'
);

-- line #21323
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOREX 150 (Synapse)',
	'Moclobemide',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOREX 150 (Synapse)'
);

-- line #21324
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOREX 150 (Synchro)',
	'Moclobemide',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOREX 150 (Synchro)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOREX 300 (Synchro)',
	'Moclobemide',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOREX 300 (Synchro)'
);

-- line #21325
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIMAREX 150 (Sun)',
	'Moclobemide',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIMAREX 150 (Sun)'
);

-- line #21326
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIMAREX 300 (Sun)',
	'Moclobemide',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIMAREX 300 (Sun)'
);

-- line #21327
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MODAFIL 100 (Intas)',
	'MODAFINIL',
	'MD TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MODAFIL 100 (Intas)'
);

-- line #21328
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MODAFIL 200 (Intas)',
	'MODAFINIL',
	'MD TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MODAFIL 200 (Intas)'
);

-- line #21329
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MODALERT 100 (Sun)',
	'MODAFINIL',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MODALERT 100 (Sun)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MODALERT 200 (Sun)',
	'MODAFINIL',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MODALERT 200 (Sun)'
);

-- line #21330
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROVAKE 100 (Ranbaxy)',
	'MODAFINIL',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROVAKE 100 (Ranbaxy)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROVAKE 200 (Ranbaxy)',
	'MODAFINIL',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROVAKE 200 (Ranbaxy)'
);

-- line #21331
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACROGEN 400 (Ranbaxy S.S.)',
	'MOLGRAMOSTIM',
	'VIAL',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACROGEN 400 (Ranbaxy S.S.)'
);

-- line #21332
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AQUAMET 0.1 (Sun)',
	'Mometasone',
	'NASAL SPRAY',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AQUAMET 0.1 (Sun)'
);

-- line #21333
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZOKID 0.1 (Elder)',
	'Mometasone',
	'CRM',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZOKID 0.1 (Elder)'
);

-- line #21334
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLEAROID 0.1 (Themis Med.)',
	'Mometasone',
	'GEL',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLEAROID 0.1 (Themis Med.)'
);

-- line #21335
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,1', u'strength_2': u'', u'substance': u'Mometasone', u'always_empty': u'', u'form': u'', u'brand': u'CORTICOM', u'strength_3': u'', u'company': u'Helios Ph.', u'unit': u'%W/W'}

-- line #21336
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CRATISONE 0.1 (CRATUS)',
	'Mometasone',
	'OINT',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CRATISONE 0.1 (CRATUS)'
);

-- line #21337
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUMEF 0.1 (Cubit Hc.)',
	'Mometasone',
	'CRM',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUMEF 0.1 (Cubit Hc.)'
);

-- line #21338
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUTIZONE 0.1 (Croslands)',
	'Mometasone',
	'CRM',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUTIZONE 0.1 (Croslands)'
);

-- line #21339
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUTIZONE 0.1 (Croslands)',
	'Mometasone',
	'LOT',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUTIZONE 0.1 (Croslands)'
);

-- line #21340
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUTIZONE 0.1 (Croslands)',
	'Mometasone',
	'OINT',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUTIZONE 0.1 (Croslands)'
);

-- line #21341
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DERMANEX 0.001 (Torrent)',
	'Mometasone',
	'CRM',
	gm.nullify_empty_string('0.001')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DERMANEX 0.001 (Torrent)'
);

-- line #21342
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DERMANEX 0.001 (Torrent)',
	'Mometasone',
	'LOT',
	gm.nullify_empty_string('0.001')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DERMANEX 0.001 (Torrent)'
);

-- line #21343
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DERMANEX 0.001 (Torrent)',
	'Mometasone',
	'OINT',
	gm.nullify_empty_string('0.001')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DERMANEX 0.001 (Torrent)'
);

-- line #21344
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DERMITOP 1 (Cadila Ph.)',
	'Mometasone',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DERMITOP 1 (Cadila Ph.)'
);

-- line #21345
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DERMITOP 0.1 (Cadila Ph.)',
	'Mometasone',
	'LOT',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DERMITOP 0.1 (Cadila Ph.)'
);

-- line #21346
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Mometasone', u'always_empty': u'', u'form': u'CRM', u'brand': u'DIVISONE', u'strength_3': u'', u'company': u'DIVINE LAB.', u'unit': u''}

-- line #21347
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ECOMOM 0.1 (ALDERMAT PH.)',
	'Mometasone',
	'CRM',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ECOMOM 0.1 (ALDERMAT PH.)'
);

-- line #21348
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ECONOM 0.1 (ALDERMAT PH.)',
	'Mometasone',
	'CRM',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ECONOM 0.1 (ALDERMAT PH.)'
);

-- line #21349
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELOCON 0.1 (Fulford)',
	'Mometasone',
	'OINT/CREAM G',
	gm.nullify_empty_string('0.1')::numeric,
	'%/0.1'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELOCON 0.1 (Fulford)'
);

-- line #21350
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELOCON 0.1 (Fulford)',
	'Mometasone',
	'OINT/LOT/CREAM',
	gm.nullify_empty_string('0.1')::numeric,
	'%/0.1'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELOCON 0.1 (Fulford)'
);

-- line #21351
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELOMATE 1 (Elder)',
	'Mometasone',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELOMATE 1 (Elder)'
);

-- line #21352
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHIMOM 0.1 (ETHINEXT PHARMA)',
	'Mometasone',
	'CRM',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHIMOM 0.1 (ETHINEXT PHARMA)'
);

-- line #21353
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEMCORT 0.1 (Fem Care)',
	'Mometasone',
	'CRM',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEMCORT 0.1 (Fem Care)'
);

-- line #21354
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FURATE 0.1 (BIOGENESIS)',
	'Mometasone',
	'CRM',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FURATE 0.1 (BIOGENESIS)'
);

-- line #21355
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HHSONE 0.1 (H & H)',
	'Mometasone',
	'LOT',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HHSONE 0.1 (H & H)'
);

-- line #21356
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MENZO 0.1 (AGIO PH.)',
	'Mometasone',
	'CRM',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MENZO 0.1 (AGIO PH.)'
);

-- line #21357
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METACON 0.1 (PSYCOREM)',
	'Mometasone',
	'CRM',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METACON 0.1 (PSYCOREM)'
);

-- line #21358
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,1', u'strength_2': u'', u'substance': u'Mometasone', u'always_empty': u'', u'form': u'', u'brand': u'METACORTIL', u'strength_3': u'', u'company': u'Macleods', u'unit': u'%'}

-- line #21359
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METACORT 0.1 (Shreya)',
	'Mometasone',
	'OINT/CREAM',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METACORT 0.1 (Shreya)'
);

-- line #21360
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,1', u'strength_2': u'', u'substance': u'Mometasone', u'always_empty': u'', u'form': u'', u'brand': u'METASAFE', u'strength_3': u'', u'company': u'F D C', u'unit': u'%'}

-- line #21361
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50CG', u'strength_2': u'DOSE', u'substance': u'Mometasone', u'always_empty': u'', u'form': u'', u'brand': u'METASPRAY', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #21362
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METNIL 0.1 (Sandoz)',
	'Mometasone',
	'TUBE',
	gm.nullify_empty_string('0.1')::numeric,
	'%W.W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METNIL 0.1 (Sandoz)'
);

-- line #21363
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEZO 0.1 (AGIO PH.)',
	'Mometasone',
	'CRM',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEZO 0.1 (AGIO PH.)'
);

-- line #21364
-- ignoring line: field [strength_1] not numeric: >>>0.1 (METHYLPARABEN IP 0.02<<<
-- {u'list_of_values_of_unknown_fields': [u' % W/W)', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.1 (METHYLPARABEN IP 0.02', u'strength_2': u'', u'substance': u'Mometasone', u'always_empty': u'', u'form': u'CRM GM', u'brand': u'MEZO', u'strength_3': u'', u'company': u'AGIO PH.', u'unit': u'% W/W'}

-- line #21365
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MF CURE 0.1 (AVITECH)',
	'Mometasone',
	'CRM',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MF CURE 0.1 (AVITECH)'
);

-- line #21366
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MFSONE 0.1 (KLM LAB.)',
	'Mometasone',
	'CRM',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MFSONE 0.1 (KLM LAB.)'
);

-- line #21367
-- ignoring line: field [strength_1] not numeric: >>>0.1W<<<
-- {u'list_of_values_of_unknown_fields': [u' %)', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.1W', u'strength_2': u'V (+METHYL PARABEN 0.2', u'substance': u'Mometasone', u'always_empty': u'', u'form': u'CRM', u'brand': u'MIDSONE', u'strength_3': u'', u'company': u'PALSONS D.', u'unit': u'%'}

-- line #21368
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIDSONE 0.1 (PALSONS D.)',
	'Mometasone',
	'LOT',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIDSONE 0.1 (PALSONS D.)'
);

-- line #21369
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MMF 0.1 (OREVA DARMO.)',
	'Mometasone',
	'CRM',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MMF 0.1 (OREVA DARMO.)'
);

-- line #21370
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MMF 0.1 (Zee Lab)',
	'Mometasone',
	'CRM',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MMF 0.1 (Zee Lab)'
);

-- line #21371
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MMS 0.1 (Liva Hc.)',
	'Mometasone',
	'CRM',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MMS 0.1 (Liva Hc.)'
);

-- line #21372
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOCO 0.1 (HALEDEW)',
	'Mometasone',
	'CRM',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOCO 0.1 (HALEDEW)'
);

-- line #21373
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MO 0.1 (NORTECH REM.)',
	'Mometasone',
	'CRM',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MO 0.1 (NORTECH REM.)'
);

-- line #21374
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOMACTIN 0.1 (Ttk Hc.)',
	'Mometasone',
	'CRM',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOMACTIN 0.1 (Ttk Hc.)'
);

-- line #21375
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOMATE 0.1 (Gracewell)',
	'Mometasone',
	'LOT',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOMATE 0.1 (Gracewell)'
);

-- line #21376
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOMATE 0.1 (Gracewell)',
	'Mometasone',
	'OINT',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOMATE 0.1 (Gracewell)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOMATE 0.1 (Gracewell)',
	'Mometasone',
	'OINT',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOMATE 0.1 (Gracewell)'
);

-- line #21377
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOMCURE 0.1 (BIOCURE HC.)',
	'Mometasone',
	'CRM',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOMCURE 0.1 (BIOCURE HC.)'
);

-- line #21378
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOMECON 0.1 (Gracewell)',
	'Mometasone',
	'CRM',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOMECON 0.1 (Gracewell)'
);

-- line #21379
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOMECORT 0.1 (Sunways)',
	'Mometasone',
	'CRM',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOMECORT 0.1 (Sunways)'
);

-- line #21380
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOMEFIT 0.1 (Entod Ph.)',
	'Mometasone',
	'NASAL SPRAY',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOMEFIT 0.1 (Entod Ph.)'
);

-- line #21381
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50MCG', u'strength_2': u'SPRAY', u'substance': u'Mometasone', u'always_empty': u'', u'form': u'', u'brand': u'MOMEFLO N-SPRAY', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #21382
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOMENTA 0.1 (Nulife)',
	'Mometasone',
	'LOT/CR',
	gm.nullify_empty_string('0.1')::numeric,
	'%/1'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOMENTA 0.1 (Nulife)'
);

-- line #21383
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOMENTA 0.05 (Nulife)',
	'Mometasone',
	'NASAL SPRAY',
	gm.nullify_empty_string('0.05')::numeric,
	'% W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOMENTA 0.05 (Nulife)'
);

-- line #21384
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOMENTO 1 (TALENT LAB.)',
	'Mometasone',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOMENTO 1 (TALENT LAB.)'
);

-- line #21385
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOMESONE 0.1 (Intas)',
	'Mometasone',
	'CRM',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOMESONE 0.1 (Intas)'
);

-- line #21386
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOMETA 0.1 (Gracewell)',
	'Mometasone',
	'CRM',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOMETA 0.1 (Gracewell)'
);

-- line #21387
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOMET 0.1 (Taurus Lab)',
	'Mometasone',
	'OINT',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOMET 0.1 (Taurus Lab)'
);

-- line #21388
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOMIVATE 0.1 (SOL DERMA)',
	'Mometasone',
	'CRM',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOMIVATE 0.1 (SOL DERMA)'
);

-- line #21389
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOMOZ 0.1 (UNIKARE)',
	'Mometasone',
	'CRM',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOMOZ 0.1 (UNIKARE)'
);

-- line #21390
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOMPRO 0.1 (MEPRO PH.)',
	'Mometasone',
	'CRM',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOMPRO 0.1 (MEPRO PH.)'
);

-- line #21391
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOMSTAR 0.1 (LIFESTAR)',
	'Mometasone',
	'CRM',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOMSTAR 0.1 (LIFESTAR)'
);

-- line #21392
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOMTAS 1 (Cfl Ph.)',
	'Mometasone',
	'CRM/OINT',
	gm.nullify_empty_string('1')::numeric,
	'mg/G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOMTAS 1 (Cfl Ph.)'
);

-- line #21393
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOSONE 1 (Olcare)',
	'Mometasone',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOSONE 1 (Olcare)'
);

-- line #21394
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOST 0.1 (DAKSH)',
	'Mometasone',
	'OINT',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOST 0.1 (DAKSH)'
);

-- line #21395
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'M-PAD 0.1 (Tripada BIO.)',
	'Mometasone',
	'CRM',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'M-PAD 0.1 (Tripada BIO.)'
);

-- line #21396
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MSONE 1 (OMNI LIFE)',
	'Mometasone',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MSONE 1 (OMNI LIFE)'
);

-- line #21397
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MTAZ 1 (Wallace)',
	'Mometasone',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MTAZ 1 (Wallace)'
);

-- line #21398
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYTOLIC 0.1 (PERCOS)',
	'Mometasone',
	'CRM',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYTOLIC 0.1 (PERCOS)'
);

-- line #21399
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENOQUIN 20 (Mac)',
	'Monobenzone',
	'OINT',
	gm.nullify_empty_string('20')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENOQUIN 20 (Mac)'
);

-- line #21400
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Monoclonal anti HCC test', u'always_empty': u'', u'form': u'KIT', u'brand': u'PREGCOLOR TEST', u'strength_3': u'', u'company': u'Infar', u'unit': u''}

-- line #21401
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AIRWAY 10 (Intra Lab)',
	'Montelukast Sodium',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AIRWAY 10 (Intra Lab)'
);

-- line #21402
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARILUNG 10 (Biochem)',
	'Montelukast Sodium',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARILUNG 10 (Biochem)'
);

-- line #21403
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASTHAM 10 (F D C)',
	'Montelukast Sodium',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASTHAM 10 (F D C)'
);

-- line #21404
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASTHAM 4 (F D C)',
	'Montelukast Sodium',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASTHAM 4 (F D C)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASTHAM 5 (F D C)',
	'Montelukast Sodium',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASTHAM 5 (F D C)'
);

-- line #21405
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BREATHEZY 10 (SAFE MED(MSN))',
	'Montelukast Sodium',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BREATHEZY 10 (SAFE MED(MSN))'
);

-- line #21406
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BREATHEZY 4 (SAFE MED(MSN))',
	'Montelukast Sodium',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BREATHEZY 4 (SAFE MED(MSN))'
);

-- line #21407
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMLUCAST 10 (Dr.Reddy''S)',
	'Montelukast Sodium',
	'CHEW TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMLUCAST 10 (Dr.Reddy''S)'
);

-- line #21408
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMLUCAST 4 (Dr.Reddy''S)',
	'Montelukast Sodium',
	'CHEW TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMLUCAST 4 (Dr.Reddy''S)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMLUCAST 5 (Dr.Reddy''S)',
	'Montelukast Sodium',
	'CHEW TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMLUCAST 5 (Dr.Reddy''S)'
);

-- line #21409
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMUCAST 10 (Dr.Reddy''S)',
	'Montelukast Sodium',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMUCAST 10 (Dr.Reddy''S)'
);

-- line #21410
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMUCAST 4 (Dr.Reddy''S)',
	'Montelukast Sodium',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMUCAST 4 (Dr.Reddy''S)'
);

-- line #21411
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMUCAST 5 (Dr.Reddy''S)',
	'Montelukast Sodium',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMUCAST 5 (Dr.Reddy''S)'
);

-- line #21412
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUTAIR 10 (Cadex Lab)',
	'Montelukast Sodium',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUTAIR 10 (Cadex Lab)'
);

-- line #21413
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUENTO 10 (WANBURY)',
	'Montelukast Sodium',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUENTO 10 (WANBURY)'
);

-- line #21414
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUENTO 4 (WANBURY)',
	'Montelukast Sodium',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUENTO 4 (WANBURY)'
);

-- line #21415
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUENTO 5 (WANBURY)',
	'Montelukast Sodium',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUENTO 5 (WANBURY)'
);

-- line #21416
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JOTAIR 10 (D.R.John''S)',
	'Montelukast Sodium',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JOTAIR 10 (D.R.John''S)'
);

-- line #21417
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KAST 10 (RND LAB)',
	'Montelukast Sodium',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KAST 10 (RND LAB)'
);

-- line #21418
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LASMA 4 (Apex Labs.)',
	'Montelukast Sodium',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LASMA 4 (Apex Labs.)'
);

-- line #21419
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LASMA 5 (Apex Labs.)',
	'Montelukast Sodium',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LASMA 5 (Apex Labs.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LASMA 10 (Apex Labs.)',
	'Montelukast Sodium',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LASMA 10 (Apex Labs.)'
);

-- line #21420
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LASTAIR 10 (Cipla)',
	'Montelukast Sodium',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LASTAIR 10 (Cipla)'
);

-- line #21421
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LASTAIR 5 (Cipla)',
	'Montelukast Sodium',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LASTAIR 5 (Cipla)'
);

-- line #21422
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUKAS 5 (ROSE LABS)',
	'Montelukast Sodium',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUKAS 5 (ROSE LABS)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUKAS 10 (ROSE LABS)',
	'Montelukast Sodium',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUKAS 10 (ROSE LABS)'
);

-- line #21423
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOKA 10 (Divine Life)',
	'Montelukast Sodium',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOKA 10 (Divine Life)'
);

-- line #21424
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOLLY 5 (ALLENGE)',
	'Montelukast Sodium',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOLLY 5 (ALLENGE)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOLLY 10 (ALLENGE)',
	'Montelukast Sodium',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOLLY 10 (ALLENGE)'
);

-- line #21425
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONATIR 5 (Cipla)',
	'Montelukast Sodium',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONATIR 5 (Cipla)'
);

-- line #21426
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONTAIR 10 (Cipla)',
	'Montelukast Sodium',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONTAIR 10 (Cipla)'
);

-- line #21427
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONTAIR 4 (Cipla)',
	'Montelukast Sodium',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONTAIR 4 (Cipla)'
);

-- line #21428
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONTAIR 5 (Cipla)',
	'Montelukast Sodium',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONTAIR 5 (Cipla)'
);

-- line #21429
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONTAL 10 (PSYCOREM)',
	'Montelukast Sodium',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONTAL 10 (PSYCOREM)'
);

-- line #21430
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONTASMA 4 (ICARUS)',
	'Montelukast Sodium',
	'DT TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONTASMA 4 (ICARUS)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONTASMA 5 (ICARUS)',
	'Montelukast Sodium',
	'DT TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONTASMA 5 (ICARUS)'
);

-- line #21431
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONTEK 10 (Sun)',
	'Montelukast Sodium',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONTEK 10 (Sun)'
);

-- line #21432
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONTEK 4 (Sun)',
	'Montelukast Sodium',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONTEK 4 (Sun)'
);

-- line #21433
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONTEK 5 (Sun)',
	'Montelukast Sodium',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONTEK 5 (Sun)'
);

-- line #21434
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONTELAST 10 (Le Sante)',
	'Montelukast Sodium',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONTELAST 10 (Le Sante)'
);

-- line #21435
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONTELAST 4 (Le Sante)',
	'Montelukast Sodium',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONTELAST 4 (Le Sante)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONTELAST 5 (Le Sante)',
	'Montelukast Sodium',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONTELAST 5 (Le Sante)'
);

-- line #21436
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONTELAST 10 (Morepen)',
	'Montelukast Sodium',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONTELAST 10 (Morepen)'
);

-- line #21437
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONTELAST 4 (MOREPEN)',
	'Montelukast Sodium',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONTELAST 4 (MOREPEN)'
);

-- line #21438
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONTEMAC 4 (Macleods)',
	'Montelukast Sodium',
	'DT',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONTEMAC 4 (Macleods)'
);

-- line #21439
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONTEMAC 10 (Macleods)',
	'Montelukast Sodium',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONTEMAC 10 (Macleods)'
);

-- line #21440
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONTEMAC 5 (Macleods)',
	'Montelukast Sodium',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONTEMAC 5 (Macleods)'
);

-- line #21441
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'4', u'strength_2': u'', u'substance': u'Montelukast Sodium', u'always_empty': u'', u'form': u'', u'brand': u'MONTEST-4 ODT', u'strength_3': u'', u'company': u'DELVIN', u'unit': u'mg'}

-- line #21442
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5', u'strength_2': u'', u'substance': u'Montelukast Sodium', u'always_empty': u'', u'form': u'', u'brand': u'MONTEST-5 ODT', u'strength_3': u'', u'company': u'DELVIN', u'unit': u'mg'}

-- line #21443
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10', u'strength_2': u'', u'substance': u'Montelukast Sodium', u'always_empty': u'', u'form': u'', u'brand': u'MONTEST - ODT', u'strength_3': u'', u'company': u'DELVIN', u'unit': u'mg'}

-- line #21444
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONTI 10 (Piramal Hc.)',
	'Montelukast Sodium',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONTI 10 (Piramal Hc.)'
);

-- line #21445
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONTI 4 (Piramal Hc.)',
	'Montelukast Sodium',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONTI 4 (Piramal Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONTI 5 (Piramal Hc.)',
	'Montelukast Sodium',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONTI 5 (Piramal Hc.)'
);

-- line #21446
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODIMONT 10 (GERMAN REM.)',
	'Montelukast Sodium',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODIMONT 10 (GERMAN REM.)'
);

-- line #21447
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODIMONT 4 (GERMAN REM.)',
	'Montelukast Sodium',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODIMONT 4 (GERMAN REM.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODIMONT 5 (GERMAN REM.)',
	'Montelukast Sodium',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODIMONT 5 (GERMAN REM.)'
);

-- line #21448
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PULMOKAST 10 (Serve Ph.)',
	'Montelukast Sodium',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PULMOKAST 10 (Serve Ph.)'
);

-- line #21449
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'MORINGA OLEIFERA BOERHAVIA DIFFUSA TECOMELLA UNDULATA ETC', u'always_empty': u'', u'form': u'', u'brand': u'IMZON', u'strength_3': u'', u'company': u'PINK HEALTH', u'unit': u''}

-- line #21450
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DURAMOR 10 (Biological E.)',
	'Morphine Sulphate',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg(C.R.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DURAMOR 10 (Biological E.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DURAMOR 30 (Biological E.)',
	'Morphine Sulphate',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg(C.R.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DURAMOR 30 (Biological E.)'
);

-- line #21451
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'M-ESLON 30 (NOVARTIS)',
	'Morphine Sulphate',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'M-ESLON 30 (NOVARTIS)'
);

-- line #21452
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MORCONTIN 10 (Modi Mundi)',
	'Morphine Sulphate',
	'CR TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MORCONTIN 10 (Modi Mundi)'
);

-- line #21453
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MORCONTIN 30 (Modi Mundi)',
	'Morphine Sulphate',
	'CR TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MORCONTIN 30 (Modi Mundi)'
);

-- line #21454
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MORPHINE SULPHATE 10 (Haffkine)',
	'Morphine Sulphate',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg/10ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MORPHINE SULPHATE 10 (Haffkine)'
);

-- line #21455
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUOCIS 5 (Baroque)',
	'Mosapride',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUOCIS 5 (Baroque)'
);

-- line #21456
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELPRIDE 5 (Elfin Ph.)',
	'Mosapride',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELPRIDE 5 (Elfin Ph.)'
);

-- line #21457
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KINETIX 5 (Lupin)',
	'Mosapride',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KINETIX 5 (Lupin)'
);

-- line #21458
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIC 2.5 (Alembic)',
	'Mosapride',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIC 2.5 (Alembic)'
);

-- line #21459
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIC 5 (Alembic)',
	'Mosapride',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIC 5 (Alembic)'
);

-- line #21460
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOPID 2.5 (TASMED)',
	'Mosapride',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOPID 2.5 (TASMED)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOPID 5 (TASMED)',
	'Mosapride',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOPID 5 (TASMED)'
);

-- line #21461
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOPRIDE 2.5 (Micro Nova)',
	'Mosapride',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOPRIDE 2.5 (Micro Nova)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOPRIDE 5 (Micro Nova)',
	'Mosapride',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOPRIDE 5 (Micro Nova)'
);

-- line #21462
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOSADEC 5 (Zydus Cadila)',
	'Mosapride',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOSADEC 5 (Zydus Cadila)'
);

-- line #21463
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOSAFE 2.5 (Glenmark)',
	'Mosapride',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOSAFE 2.5 (Glenmark)'
);

-- line #21464
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOSAFE 5 (Glenmark)',
	'Mosapride',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOSAFE 5 (Glenmark)'
);

-- line #21465
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOSAGEN 5 (Geno Ph.)',
	'Mosapride',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOSAGEN 5 (Geno Ph.)'
);

-- line #21466
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOSAKIND-5 5 (Mankind)',
	'Mosapride',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOSAKIND-5 5 (Mankind)'
);

-- line #21467
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOSAPID 5 (Cipla)',
	'Mosapride',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOSAPID 5 (Cipla)'
);

-- line #21468
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOSAP 2.5 (Medley)',
	'Mosapride',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOSAP 2.5 (Medley)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOSAP 5 (Medley)',
	'Mosapride',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOSAP 5 (Medley)'
);

-- line #21469
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOSART 2.5 (Irm Ph.)',
	'Mosapride',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOSART 2.5 (Irm Ph.)'
);

-- line #21470
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOSART 5 (Irm Ph.)',
	'Mosapride',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOSART 5 (Irm Ph.)'
);

-- line #21471
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOSASEF 2.5 (Solares (Sun))',
	'Mosapride',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg/5'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOSASEF 2.5 (Solares (Sun))'
);

-- line #21472
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOSIBA 2.5 (Bennet Ph.)',
	'Mosapride',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOSIBA 2.5 (Bennet Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOSIBA 5 (Bennet Ph.)',
	'Mosapride',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOSIBA 5 (Bennet Ph.)'
);

-- line #21473
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOSID 2.5 (Torrent)',
	'Mosapride',
	'MT',
	gm.nullify_empty_string('2.5')::numeric,
	'mg/5'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOSID 2.5 (Torrent)'
);

-- line #21474
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOSID 15 (Torrent)',
	'Mosapride',
	'OD TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOSID 15 (Torrent)'
);

-- line #21475
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOSYS 15 (Systopic)',
	'Mosapride',
	'SR TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOSYS 15 (Systopic)'
);

-- line #21476
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2,5', u'strength_2': u'5', u'substance': u'Mosapride', u'always_empty': u'', u'form': u'', u'brand': u'MOTEN INSTAB', u'strength_3': u'', u'company': u'Rexcel', u'unit': u'mg'}

-- line #21477
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOZASEF 2.5 (Solares (Sun))',
	'Mosapride',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOZASEF 2.5 (Solares (Sun))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOZASEF 5 (Solares (Sun))',
	'Mosapride',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOZASEF 5 (Solares (Sun))'
);

-- line #21478
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Mosapride', u'always_empty': u'', u'form': u'SR TAB', u'brand': u'MOZA', u'strength_3': u'', u'company': u'Intas', u'unit': u''}

-- line #21479
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOZA 10 (Intas)',
	'Mosapride',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOZA 10 (Intas)'
);

-- line #21480
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOZA 2.5 (Intas)',
	'Mosapride',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOZA 2.5 (Intas)'
);

-- line #21481
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOZA 5 (Intas)',
	'Mosapride',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOZA 5 (Intas)'
);

-- line #21482
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOZATONE 2.5 (Indoco Rem.)',
	'Mosapride',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOZATONE 2.5 (Indoco Rem.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOZATONE 5 (Indoco Rem.)',
	'Mosapride',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOZATONE 5 (Indoco Rem.)'
);

-- line #21483
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOZAX MELTING 2.5 (Sun)',
	'Mosapride',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOZAX MELTING 2.5 (Sun)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOZAX MELTING 5 (Sun)',
	'Mosapride',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOZAX MELTING 5 (Sun)'
);

-- line #21484
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'M-PRIDE 5 (Centaur)',
	'Mosapride',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'M-PRIDE 5 (Centaur)'
);

-- line #21485
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUSAPRO 2.5 (Emcure)',
	'Mosapride',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUSAPRO 2.5 (Emcure)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUSAPRO 5 (Emcure)',
	'Mosapride',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUSAPRO 5 (Emcure)'
);

-- line #21486
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUZIC 2.5 (Alkem)',
	'Mosapride',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUZIC 2.5 (Alkem)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUZIC 5 (Alkem)',
	'Mosapride',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUZIC 5 (Alkem)'
);

-- line #21487
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYOSYS-5 5 (Systopic)',
	'Mosapride',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYOSYS-5 5 (Systopic)'
);

-- line #21488
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYPRIDE 5 (TALENT LAB.)',
	'Mosapride',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYPRIDE 5 (TALENT LAB.)'
);

-- line #21489
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORMAGUT 2.5 (Wockhardt)',
	'Mosapride',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORMAGUT 2.5 (Wockhardt)'
);

-- line #21490
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORMAGUT 5 (Wockhardt)',
	'Mosapride',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORMAGUT 5 (Wockhardt)'
);

-- line #21491
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROMOT 5 (Olcare)',
	'Mosapride',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROMOT 5 (Olcare)'
);

-- line #21492
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REGMOTIL-M 5 (Bsp Ph.)',
	'Mosapride',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REGMOTIL-M 5 (Bsp Ph.)'
);

-- line #21493
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REMOT 2.5 (Wanbury)',
	'Mosapride',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REMOT 2.5 (Wanbury)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REMOT 5 (Wanbury)',
	'Mosapride',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REMOT 5 (Wanbury)'
);

-- line #21494
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'4QUIN 0.5 (Entod Ph.)',
	'Moxifloxacin',
	'EYE DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '4QUIN 0.5 (Entod Ph.)'
);

-- line #21495
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'4QUIN 0.5 (Entod Ph.)',
	'Moxifloxacin',
	'EYE OINT',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '4QUIN 0.5 (Entod Ph.)'
);

-- line #21496
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Moxifloxacin', u'always_empty': u'', u'form': u'EYE DPS', u'brand': u'ADMOX', u'strength_3': u'', u'company': u'ADVENTUS', u'unit': u''}

-- line #21497
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APDROPS 0.5 (Ajanta Ph.)',
	'Moxifloxacin',
	'EYE DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%;2/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APDROPS 0.5 (Ajanta Ph.)'
);

-- line #21498
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CENTAFLOX 5 (CENTAUR PH.)',
	'Moxifloxacin',
	'EYE DPS',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CENTAFLOX 5 (CENTAUR PH.)'
);

-- line #21499
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMEF 0.5 (Ind-Swift)',
	'Moxifloxacin',
	'EYE DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMEF 0.5 (Ind-Swift)'
);

-- line #21500
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EYE QUIN 5 (Le Sante)',
	'Moxifloxacin',
	'EYE DPS',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EYE QUIN 5 (Le Sante)'
);

-- line #21501
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXASAFE 400 (SAFE MED(MSN))',
	'Moxifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXASAFE 400 (SAFE MED(MSN))'
);

-- line #21502
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'400', u'strength_2': u'', u'substance': u'Moxifloxacin', u'always_empty': u'', u'form': u'', u'brand': u'FLOXSAFE IV', u'strength_3': u'', u'company': u'MSN LAB.', u'unit': u'mg'}

-- line #21503
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAHAFLOX EYE 0.5 (LIFESTAR)',
	'Moxifloxacin',
	'DROPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%;W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAHAFLOX EYE 0.5 (LIFESTAR)'
);

-- line #21504
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'400', u'strength_2': u'', u'substance': u'Moxifloxacin', u'always_empty': u'', u'form': u'', u'brand': u'M-CIN IV', u'strength_3': u'', u'company': u'Lupin', u'unit': u'mg(MANNITOL 5'}

-- line #21505
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'M-CIN 400 (Lupin)',
	'Moxifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'M-CIN 400 (Lupin)'
);

-- line #21506
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,5', u'strength_2': u'', u'substance': u'Moxifloxacin', u'always_empty': u'', u'form': u'', u'brand': u'MEFLOTAS', u'strength_3': u'', u'company': u'Intas', u'unit': u'%W/V'}

-- line #21507
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MFC 0.5 (Jawa Ph.)',
	'Moxifloxacin',
	'EYE DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MFC 0.5 (Jawa Ph.)'
);

-- line #21508
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILFLOX 5 (Sun)',
	'Moxifloxacin',
	'DPS',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILFLOX 5 (Sun)'
);

-- line #21509
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOFELDER 5 (Elder V.)',
	'Moxifloxacin',
	'EYE DPS',
	gm.nullify_empty_string('5')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOFELDER 5 (Elder V.)'
);

-- line #21510
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MO-FLOREN 5 (INDOCO(EXCEL))',
	'Moxifloxacin',
	'EYE DPS',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MO-FLOREN 5 (INDOCO(EXCEL))'
);

-- line #21511
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOFLOREN 5 (Warren)',
	'Moxifloxacin',
	'EYE DPS',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOFLOREN 5 (Warren)'
);

-- line #21512
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOSI 0.5 (F D C)',
	'Moxifloxacin',
	'EYE DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOSI 0.5 (F D C)'
);

-- line #21513
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOTIFAX 0.5 (Optho Rem.)',
	'Moxifloxacin',
	'EYE DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOTIFAX 0.5 (Optho Rem.)'
);

-- line #21514
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXIBLU 0.5 (Lupin)',
	'Moxifloxacin',
	'EYE DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXIBLU 0.5 (Lupin)'
);

-- line #21515
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Moxifloxacin', u'always_empty': u'', u'form': u'EYE DPS', u'brand': u'MOXICIP', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #21516
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Moxifloxacin', u'always_empty': u'', u'form': u'EYE OINT', u'brand': u'MOXICIP', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #21517
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXICIP 400 (Cipla)',
	'Moxifloxacin',
	'INF',
	gm.nullify_empty_string('400')::numeric,
	'mg(+SOD.CHL 0.8'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXICIP 400 (Cipla)'
);

-- line #21518
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXICIP 400 (Cipla)',
	'Moxifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXICIP 400 (Cipla)'
);

-- line #21519
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXIDEX 0.5 (Parenteral)',
	'Moxifloxacin',
	'EYE DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXIDEX 0.5 (Parenteral)'
);

-- line #21520
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Moxifloxacin', u'always_empty': u'', u'form': u'INF', u'brand': u'MOXIF IV', u'strength_3': u'', u'company': u'Torrent', u'unit': u''}

-- line #21521
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXIF 400 (Torrent)',
	'Moxifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXIF 400 (Torrent)'
);

-- line #21522
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXIFUR 0.5 (Appasamy)',
	'Moxifloxacin',
	'EYE DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXIFUR 0.5 (Appasamy)'
);

-- line #21523
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXIGEN 0.5 (RENOVA HC.)',
	'Moxifloxacin',
	'EYE DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXIGEN 0.5 (RENOVA HC.)'
);

-- line #21524
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXIGRAM 0.5 (Micro Labs)',
	'Moxifloxacin',
	'EYE DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXIGRAM 0.5 (Micro Labs)'
);

-- line #21525
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXIKED 0.5 (Yash Ph.)',
	'Moxifloxacin',
	'EYE DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXIKED 0.5 (Yash Ph.)'
);

-- line #21526
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'400', u'strength_2': u'', u'substance': u'Moxifloxacin', u'always_empty': u'', u'form': u'', u'brand': u'MOXIMAC IV', u'strength_3': u'', u'company': u'Macleods', u'unit': u'mg (MANNITOL 5'}

-- line #21527
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXIMAC 400 (Macleods)',
	'Moxifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXIMAC 400 (Macleods)'
);

-- line #21528
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXIMUM 5 (YASH PH.)',
	'Moxifloxacin',
	'DPS',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXIMUM 5 (YASH PH.)'
);

-- line #21529
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXIMYCIN 400 (VENUS REM.)',
	'Moxifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXIMYCIN 400 (VENUS REM.)'
);

-- line #21530
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXISTAR 0.5 (DREAM PH.)',
	'Moxifloxacin',
	'DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXISTAR 0.5 (DREAM PH.)'
);

-- line #21531
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXITAK 5 (Pharmtak)',
	'Moxifloxacin',
	'EYE DPS',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXITAK 5 (Pharmtak)'
);

-- line #21532
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXITAK 0.5 (Pharmtak)',
	'Moxifloxacin',
	'TUBE',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXITAK 0.5 (Pharmtak)'
);

-- line #21533
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXL 0.5 (DEWCARE)',
	'Moxifloxacin',
	'DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXL 0.5 (DEWCARE)'
);

-- line #21534
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXOFT 0.5 (Alembic)',
	'Moxifloxacin',
	'SOL',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXOFT 0.5 (Alembic)'
);

-- line #21535
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Moxifloxacin', u'always_empty': u'', u'form': u'EYE DROP', u'brand': u'MOXYSIGN', u'strength_3': u'', u'company': u'SUNSIGN PH.', u'unit': u''}

-- line #21536
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEWQUIN 0.5 (Cipla)',
	'Moxifloxacin',
	'EYE DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEWQUIN 0.5 (Cipla)'
);

-- line #21537
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEWQUIN 400 (Cipla)',
	'Moxifloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEWQUIN 400 (Cipla)'
);

-- line #21538
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Moxifloxacin', u'always_empty': u'', u'form': u'DPS', u'brand': u'OCCUMOX', u'strength_3': u'', u'company': u'Sunways', u'unit': u''}

-- line #21539
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RHYMOXI 0.5 (RHYTHM PH.)',
	'Moxifloxacin',
	'EYE DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RHYMOXI 0.5 (RHYTHM PH.)'
);

-- line #21540
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXOVAS 0.2 (Macleods)',
	'MOXONIDINE',
	'TAB',
	gm.nullify_empty_string('0.2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXOVAS 0.2 (Macleods)'
);

-- line #21541
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'805IU', u'strength_2': u'ML', u'substance': u'MU-CHAIN SPECIFIC ANTISERA HUMAN HUMAN IG', u'always_empty': u'', u'form': u'', u'brand': u'IGM(MU-CHAIN)', u'strength_3': u'', u'company': u'SANOFI AV.', u'unit': u''}

-- line #21542
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250IU', u'strength_2': u'G', u'substance': u'Mucopolysaccharide Poly Sulfate(Heparinoid)', u'always_empty': u'', u'form': u'CRM', u'brand': u'HIRUDOID', u'strength_3': u'', u'company': u'Cfl Ph.', u'unit': u''}

-- line #21543
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'MULTIVITAMINS', u'always_empty': u'', u'form': u'TAB', u'brand': u'MIVETS-G', u'strength_3': u'', u'company': u'Alembic', u'unit': u''}

-- line #21544
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'MULTIVITAMINS', u'always_empty': u'', u'form': u'TAB', u'brand': u'ONE-UP GOLD', u'strength_3': u'', u'company': u'Torrent', u'unit': u''}

-- line #21545
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACTIBADE 2 (Sandoz)',
	'Mupirocin',
	'OINT',
	gm.nullify_empty_string('2')::numeric,
	'%W/W (IN A NON GREASY BASE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACTIBADE 2 (Sandoz)'
);

-- line #21546
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACTROBAN 2 (Gsk)',
	'Mupirocin',
	'OINT',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACTROBAN 2 (Gsk)'
);

-- line #21547
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2', u'strength_2': u'', u'substance': u'Mupirocin', u'always_empty': u'', u'form': u'', u'brand': u'B-BACT', u'strength_3': u'', u'company': u'Wallace', u'unit': u'%W/W'}

-- line #21548
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPO-MEDROL 40 (Pharmacia)',
	'Mupirocin',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg/ML (STERILE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPO-MEDROL 40 (Pharmacia)'
);

-- line #21549
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IBACT 2 (Intra Lab)',
	'Mupirocin',
	'CRM',
	gm.nullify_empty_string('2')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IBACT 2 (Intra Lab)'
);

-- line #21550
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Mupirocin', u'always_empty': u'', u'form': u'', u'brand': u'MOPRY', u'strength_3': u'', u'company': u'UNIKARE', u'unit': u''}

-- line #21551
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'M POWER 2 (LIVA HC.)',
	'Mupirocin',
	'CRM',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'M POWER 2 (LIVA HC.)'
);

-- line #21552
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MPOWER 2 (Liva Hc.)',
	'Mupirocin',
	'OINT',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MPOWER 2 (Liva Hc.)'
);

-- line #21553
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'M-TOP 2 (G.Nine Form.)',
	'Mupirocin',
	'CRM',
	gm.nullify_empty_string('2')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'M-TOP 2 (G.Nine Form.)'
);

-- line #21554
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUFECT 2 (Sun)',
	'Mupirocin',
	'OINT',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUFECT 2 (Sun)'
);

-- line #21555
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2', u'strength_2': u'', u'substance': u'Mupirocin', u'always_empty': u'', u'form': u'', u'brand': u'MU-OINT', u'strength_3': u'', u'company': u'Ind-Swift', u'unit': u'%'}

-- line #21556
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUPIBACT 2 (PALSONS)',
	'Mupirocin',
	'CRM',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUPIBACT 2 (PALSONS)'
);

-- line #21557
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUPIBAN 2 (AGIO PH.)',
	'Mupirocin',
	'OINT',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUPIBAN 2 (AGIO PH.)'
);

-- line #21558
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUPINOVA 2 (Zuventus)',
	'Mupirocin',
	'CRM',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUPINOVA 2 (Zuventus)'
);

-- line #21559
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUPIRAX 2 (Micro Labs)',
	'Mupirocin',
	'OINT',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUPIRAX 2 (Micro Labs)'
);

-- line #21560
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUPRICON 2 (Indchemie)',
	'Mupirocin',
	'OINT',
	gm.nullify_empty_string('2')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUPRICON 2 (Indchemie)'
);

-- line #21561
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Mupirocin', u'always_empty': u'', u'form': u'CRM', u'brand': u'PIROCIN', u'strength_3': u'', u'company': u'PSYCOREM', u'unit': u''}

-- line #21562
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIROCIN 2 (PSYCOREM)',
	'Mupirocin',
	'CRM',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIROCIN 2 (PSYCOREM)'
);

-- line #21563
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIROTOP 2 (Themis Med.)',
	'Mupirocin',
	'OINT',
	gm.nullify_empty_string('2')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIROTOP 2 (Themis Med.)'
);

-- line #21564
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUSTINE 10 (Abbott)',
	'MUSTINE HCL.',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUSTINE 10 (Abbott)'
);

-- line #21565
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BAXMUNE 250 (Ranbaxy)',
	'Mycophenolate Mofetil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BAXMUNE 250 (Ranbaxy)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BAXMUNE 500 (Ranbaxy)',
	'Mycophenolate Mofetil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BAXMUNE 500 (Ranbaxy)'
);

-- line #21566
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOMYF 500 (BIONICHE)',
	'Mycophenolate Mofetil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOMYF 500 (BIONICHE)'
);

-- line #21567
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELLMUNE 500 (Cipla)',
	'Mycophenolate Mofetil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELLMUNE 500 (Cipla)'
);

-- line #21568
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMCEPT-S 360 (Emcure)',
	'Mycophenolate Mofetil',
	'TAB',
	gm.nullify_empty_string('360')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMCEPT-S 360 (Emcure)'
);

-- line #21569
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMCEPT 500 (Emcure)',
	'Mycophenolate Mofetil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMCEPT 500 (Emcure)'
);

-- line #21570
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMCEPT 750 (Emcure)',
	'Mycophenolate Mofetil',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMCEPT 750 (Emcure)'
);

-- line #21571
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMMUTIL 500 (LA RENON)',
	'Mycophenolate Mofetil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMMUTIL 500 (LA RENON)'
);

-- line #21572
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MMF 500 (Ipca)',
	'Mycophenolate Mofetil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MMF 500 (Ipca)'
);

-- line #21573
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOFETYL 250 (Rpg Life)',
	'Mycophenolate Mofetil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOFETYL 250 (Rpg Life)'
);

-- line #21574
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOFETYL 500 (Rpg Life)',
	'Mycophenolate Mofetil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOFETYL 500 (Rpg Life)'
);

-- line #21575
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOFILET 250 (Emcure)',
	'Mycophenolate Mofetil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOFILET 250 (Emcure)'
);

-- line #21576
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOFILET 500 (Emcure)',
	'Mycophenolate Mofetil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOFILET 500 (Emcure)'
);

-- line #21577
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOFILET 750 (Emcure)',
	'Mycophenolate Mofetil',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOFILET 750 (Emcure)'
);

-- line #21578
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCEPT 250 (Panacea)',
	'Mycophenolate Mofetil',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCEPT 250 (Panacea)'
);

-- line #21579
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCEPT 500 (Panacea)',
	'Mycophenolate Mofetil',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCEPT 500 (Panacea)'
);

-- line #21580
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCEPT 750 (Panacea)',
	'Mycophenolate Mofetil',
	'CAP',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCEPT 750 (Panacea)'
);

-- line #21581
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'540', u'strength_2': u'', u'substance': u'Mycophenolate Mofetil', u'always_empty': u'', u'form': u'', u'brand': u'MYCEPT-S', u'strength_3': u'', u'company': u'Panacea', u'unit': u'mg(MYCOPHENOLIC ACID)'}

-- line #21582
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCEPT 500 (Panacea)',
	'Mycophenolate Mofetil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg(MYCOPHENOLIC ACID)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCEPT 500 (Panacea)'
);

-- line #21583
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCOFIT 250 (Intas)',
	'Mycophenolate Mofetil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCOFIT 250 (Intas)'
);

-- line #21584
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCOFIT 500 (Intas)',
	'Mycophenolate Mofetil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCOFIT 500 (Intas)'
);

-- line #21585
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCOMUNE 500 (Zydus Bio.)',
	'Mycophenolate Mofetil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCOMUNE 500 (Zydus Bio.)'
);

-- line #21586
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCOPHEN 250 (Micro Labs)',
	'Mycophenolate Mofetil',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCOPHEN 250 (Micro Labs)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCOPHEN 500 (Micro Labs)',
	'Mycophenolate Mofetil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCOPHEN 500 (Micro Labs)'
);

-- line #21587
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYGRAFT 500 (Claris L.)',
	'Mycophenolate Mofetil',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYGRAFT 500 (Claris L.)'
);

-- line #21588
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'540', u'strength_2': u'', u'substance': u'Mycophenolate Mofetil', u'always_empty': u'', u'form': u'', u'brand': u'RENODAPT-5', u'strength_3': u'', u'company': u'Biocon', u'unit': u'mg(MYCOPHENOLIC ACID)'}

-- line #21589
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RENODAPT 250 (Biocon)',
	'Mycophenolate Mofetil',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RENODAPT 250 (Biocon)'
);

-- line #21590
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RENODAPT 500 (Biocon)',
	'Mycophenolate Mofetil',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RENODAPT 500 (Biocon)'
);

-- line #21591
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RENODAPT 750 (Biocon)',
	'Mycophenolate Mofetil',
	'CAP',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RENODAPT 750 (Biocon)'
);

-- line #21592
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RENOFIX-M 250 (Unichem)',
	'Mycophenolate Mofetil',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RENOFIX-M 250 (Unichem)'
);

-- line #21593
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RENOFIX-M 500 (Unichem)',
	'Mycophenolate Mofetil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RENOFIX-M 500 (Unichem)'
);

-- line #21594
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMMUTIL-S 360 (LA RENON)',
	'Mycophenolate SODIUM',
	'TAB',
	gm.nullify_empty_string('360')::numeric,
	'mg(MYCOPHENOLIC ACID)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMMUTIL-S 360 (LA RENON)'
);

-- line #21595
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCEPT-S 180 (Panacea)',
	'Mycophenolate SODIUM',
	'TAB',
	gm.nullify_empty_string('180')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCEPT-S 180 (Panacea)'
);

-- line #21596
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCEPT-S 360 (Panacea)',
	'Mycophenolate SODIUM',
	'TAB',
	gm.nullify_empty_string('360')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCEPT-S 360 (Panacea)'
);

-- line #21597
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCOFORCE 360 (Ipca)',
	'Mycophenolate SODIUM',
	'TAB',
	gm.nullify_empty_string('360')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCOFORCE 360 (Ipca)'
);

-- line #21598
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCOPHENOLATE SOD 360 (ZYDUS NEPHRO)',
	'Mycophenolate SODIUM',
	'TAB',
	gm.nullify_empty_string('360')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCOPHENOLATE SOD 360 (ZYDUS NEPHRO)'
);

-- line #21599
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCORAL 180 (Wockhardt)',
	'Mycophenolate SODIUM',
	'TAB',
	gm.nullify_empty_string('180')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCORAL 180 (Wockhardt)'
);

-- line #21600
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCORAL 360 (Wockhardt)',
	'Mycophenolate SODIUM',
	'TAB',
	gm.nullify_empty_string('360')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCORAL 360 (Wockhardt)'
);

-- line #21601
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'360', u'strength_2': u'', u'substance': u'Mycophenolate SODIUM', u'always_empty': u'', u'form': u'', u'brand': u'MY', u'strength_3': u'', u'company': u'STEADFAST MEDI.', u'unit': u'mg'}

-- line #21602
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PICEPT 180 (Lupin)',
	'Mycophenolate SODIUM',
	'TAB',
	gm.nullify_empty_string('180')::numeric,
	'mg(MYCOPHENOLIC ACID)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PICEPT 180 (Lupin)'
);

-- line #21603
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RENODAPT-S 180 (Biocon)',
	'Mycophenolate SODIUM',
	'TAB',
	gm.nullify_empty_string('180')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RENODAPT-S 180 (Biocon)'
);

-- line #21604
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RENODAPT-S 360 (Biocon)',
	'Mycophenolate SODIUM',
	'TAB',
	gm.nullify_empty_string('360')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RENODAPT-S 360 (Biocon)'
);

-- line #21605
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RENOFIX-S 360 (Unichem)',
	'Mycophenolate SODIUM',
	'TAB',
	gm.nullify_empty_string('360')::numeric,
	'mg(MYCOPHENOIC ACID)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RENOFIX-S 360 (Unichem)'
);

-- line #21606
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PMUTE 1000 (Wanbury)',
	'NABUMATONE',
	'TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PMUTE 1000 (Wanbury)'
);

-- line #21607
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NABUFLAM 500 (Micro Labs)',
	'NABUMETONE',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NABUFLAM 500 (Micro Labs)'
);

-- line #21608
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEBUFLAM 500 (MICRO HC.)',
	'NABUMETONE',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEBUFLAM 500 (MICRO HC.)'
);

-- line #21609
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NILITIS 1000 (Ipca)',
	'NABUMETONE',
	'TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NILITIS 1000 (Ipca)'
);

-- line #21610
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NILTIS 500 (Ipca)',
	'NABUMETONE',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NILTIS 500 (Ipca)'
);

-- line #21611
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NILTIS 750 (Ipca)',
	'NABUMETONE',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NILTIS 750 (Ipca)'
);

-- line #21612
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200', u'strength_2': u'', u'substance': u'N-Acetylcysteine', u'always_empty': u'', u'form': u'', u'brand': u'MUCOMELT ML', u'strength_3': u'', u'company': u'VENUS REM.', u'unit': u'mg/1ML'}

-- line #21613
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONYLAC 8 (Cipla)',
	'NACL LACQUER',
	'SOL',
	gm.nullify_empty_string('8')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONYLAC 8 (Cipla)'
);

-- line #21614
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NADIBACT 10 (Cipla)',
	'Nadifloxacin',
	'CRM',
	gm.nullify_empty_string('10')::numeric,
	'mg/G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NADIBACT 10 (Cipla)'
);

-- line #21615
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NADIDERM 1 (Nicholas)',
	'Nadifloxacin',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NADIDERM 1 (Nicholas)'
);

-- line #21616
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NADIKAM 10 (DERMACARE)',
	'Nadifloxacin',
	'CRM',
	gm.nullify_empty_string('10')::numeric,
	'mg/G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NADIKAM 10 (DERMACARE)'
);

-- line #21617
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NADIMAX 1 (OREVA DARMO.)',
	'Nadifloxacin',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NADIMAX 1 (OREVA DARMO.)'
);

-- line #21618
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NADIM 10 (Genx Ph.)',
	'Nadifloxacin',
	'OINT',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NADIM 10 (Genx Ph.)'
);

-- line #21619
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NADISKIN 1 (HETERO HC.)',
	'Nadifloxacin',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NADISKIN 1 (HETERO HC.)'
);

-- line #21620
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NADOXIN 10 (WOCKHARDT)',
	'Nadifloxacin',
	'GEL',
	gm.nullify_empty_string('10')::numeric,
	'mg/G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NADOXIN 10 (WOCKHARDT)'
);

-- line #21621
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Nadifloxacin', u'always_empty': u'', u'form': u'POW', u'brand': u'NADOXIN', u'strength_3': u'', u'company': u'WOCKHARDT', u'unit': u''}

-- line #21622
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2850I.U.', u'strength_2': u'', u'substance': u'NADROPARIN', u'always_empty': u'', u'form': u'', u'brand': u'NADROPARIN IU', u'strength_3': u'', u'company': u'Bharat S.', u'unit': u''}

-- line #21623
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3800I.U.', u'strength_2': u'', u'substance': u'NADROPARIN', u'always_empty': u'', u'form': u'', u'brand': u'NADROPARIN IU', u'strength_3': u'', u'company': u'Bharat S.', u'unit': u''}

-- line #21624
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5700I.U.', u'strength_2': u'', u'substance': u'NADROPARIN', u'always_empty': u'', u'form': u'', u'brand': u'NADROPARIN IU', u'strength_3': u'', u'company': u'Bharat S.', u'unit': u''}

-- line #21625
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAFODIL 25 (Intas)',
	'NAFTOPIDIL',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAFODIL 25 (Intas)'
);

-- line #21626
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAFODIL 50 (Intas)',
	'NAFTOPIDIL',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAFODIL 50 (Intas)'
);

-- line #21627
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAFODIL 75 (Intas)',
	'NAFTOPIDIL',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAFODIL 75 (Intas)'
);

-- line #21628
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAFTOMAX 50 (SUN)',
	'NAFTOPIDIL',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAFTOMAX 50 (SUN)'
);

-- line #21629
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAFTOMAX 75 (SUN)',
	'NAFTOPIDIL',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAFTOMAX 75 (SUN)'
);

-- line #21630
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NALFY 10 (Glenmark)',
	'NALBUPHINE HCL.',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg/1ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NALFY 10 (Glenmark)'
);

-- line #21631
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NALFY 20 (Glenmark)',
	'NALBUPHINE HCL.',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg/1ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NALFY 20 (Glenmark)'
);

-- line #21632
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIARLOP 300 (Jagsonpal)',
	'Nalidixic Acid',
	'SUS',
	gm.nullify_empty_string('300')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIARLOP 300 (Jagsonpal)'
);

-- line #21633
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIX 300 (P C INDIA)',
	'Nalidixic Acid',
	'SYR',
	gm.nullify_empty_string('300')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIX 300 (P C INDIA)'
);

-- line #21634
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Nalidixic Acid', u'always_empty': u'', u'form': u'TAB', u'brand': u'DIX', u'strength_3': u'', u'company': u'P C INDIA', u'unit': u''}

-- line #21635
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIX 250 (P C INDIA)',
	'Nalidixic Acid',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIX 250 (P C INDIA)'
);

-- line #21636
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIX 500 (P C INDIA)',
	'Nalidixic Acid',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIX 500 (P C INDIA)'
);

-- line #21637
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMTERODIX 300 (Albert D.)',
	'Nalidixic Acid',
	'SYR',
	gm.nullify_empty_string('300')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMTERODIX 300 (Albert D.)'
);

-- line #21638
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENTERODIX 500 (Albert D.)',
	'Nalidixic Acid',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENTERODIX 500 (Albert D.)'
);

-- line #21639
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRAMONEG 500 (Ranbaxy)',
	'Nalidixic Acid',
	'DT',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRAMONEG 500 (Ranbaxy)'
);

-- line #21640
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRAMONEG 300 (Ranbaxy)',
	'Nalidixic Acid',
	'SUS',
	gm.nullify_empty_string('300')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRAMONEG 300 (Ranbaxy)'
);

-- line #21641
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRAMONEG 500 (Ranbaxy)',
	'Nalidixic Acid',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRAMONEG 500 (Ranbaxy)'
);

-- line #21642
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'300', u'strength_2': u'', u'substance': u'Nalidixic Acid', u'always_empty': u'', u'form': u'', u'brand': u'NADIX ACUTAB', u'strength_3': u'', u'company': u'Troikaa', u'unit': u'mg'}

-- line #21643
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NALIDIXIC ACID 300 (Dopson Ph.)',
	'Nalidixic Acid',
	'SUS',
	gm.nullify_empty_string('300')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NALIDIXIC ACID 300 (Dopson Ph.)'
);

-- line #21644
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEGADIX 125 (Cfl Ph.)',
	'Nalidixic Acid',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEGADIX 125 (Cfl Ph.)'
);

-- line #21645
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEGADIX 500 (Cfl Ph.)',
	'Nalidixic Acid',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEGADIX 500 (Cfl Ph.)'
);

-- line #21646
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20MCG', u'strength_2': u'', u'substance': u'Naloxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'NALOX', u'strength_3': u'', u'company': u'Samarth', u'unit': u''}

-- line #21647
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'400MCG', u'strength_2': u'', u'substance': u'Naloxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'NALOX', u'strength_3': u'', u'company': u'Samarth', u'unit': u''}

-- line #21648
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20MCG', u'strength_2': u'ML', u'substance': u'Naloxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'NARCOTAN', u'strength_3': u'', u'company': u'Troikaa', u'unit': u''}

-- line #21649
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'400MCG', u'strength_2': u'ML', u'substance': u'Naloxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'NARCOTAN', u'strength_3': u'', u'company': u'Troikaa', u'unit': u''}

-- line #21650
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20MCG', u'strength_2': u'', u'substance': u'Naloxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'NEX', u'strength_3': u'', u'company': u'Neon', u'unit': u''}

-- line #21651
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'400MCG', u'strength_2': u'', u'substance': u'Naloxone', u'always_empty': u'', u'form': u'INJ', u'brand': u'NEX', u'strength_3': u'', u'company': u'Neon', u'unit': u''}

-- line #21652
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NALTIMA 50 (Intas)',
	'Naltrexone',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NALTIMA 50 (Intas)'
);

-- line #21653
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NODICT 50 (Synergy)',
	'Naltrexone',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NODICT 50 (Synergy)'
);

-- line #21654
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETALOBIN 25 (Bestochem)',
	'Nandrolone',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETALOBIN 25 (Bestochem)'
);

-- line #21655
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BONODEC 25 (Ultramark)',
	'Nandrolone',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BONODEC 25 (Ultramark)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BONODEC 50 (Ultramark)',
	'Nandrolone',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BONODEC 50 (Ultramark)'
);

-- line #21656
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CNP 25 (Curex)',
	'Nandrolone',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CNP 25 (Curex)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CNP 50 (Curex)',
	'Nandrolone',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CNP 50 (Curex)'
);

-- line #21657
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AFDEC 25 (Alpha Arom.)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AFDEC 25 (Alpha Arom.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AFDEC 50 (Alpha Arom.)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AFDEC 50 (Alpha Arom.)'
);

-- line #21658
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMEND 25 (MEGAVISION)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMEND 25 (MEGAVISION)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMEND 50 (MEGAVISION)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMEND 50 (MEGAVISION)'
);

-- line #21659
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANDEE 50 (Aust Ind.)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANDEE 50 (Aust Ind.)'
);

-- line #21660
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANDYSAN 25 (Sanify)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANDYSAN 25 (Sanify)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANDYSAN 50 (Sanify)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANDYSAN 50 (Sanify)'
);

-- line #21661
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXYDEC 25 (AXYZEN LIFE)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXYDEC 25 (AXYZEN LIFE)'
);

-- line #21662
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXYDEC 50 (AXYZEN LIFE)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXYDEC 50 (AXYZEN LIFE)'
);

-- line #21663
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETADECABOLIN 25 (Bestochem)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETADECABOLIN 25 (Bestochem)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETADECABOLIN 50 (Bestochem)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETADECABOLIN 50 (Bestochem)'
);

-- line #21664
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIODEC 25 (Biosmith)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIODEC 25 (Biosmith)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIODEC 50 (Biosmith)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIODEC 50 (Biosmith)'
);

-- line #21665
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BOLISTER-D 25 (Biocin Hc.)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BOLISTER-D 25 (Biocin Hc.)'
);

-- line #21666
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BOLISTER-D 50 (Biocin Hc.)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BOLISTER-D 50 (Biocin Hc.)'
);

-- line #21667
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRODIC 25 (Briskon)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRODIC 25 (Briskon)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRODIC 50 (Briskon)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRODIC 50 (Briskon)'
);

-- line #21668
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANDO-DECA 25 (Candor Bio.)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANDO-DECA 25 (Candor Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANDO-DECA 50 (Candor Bio.)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANDO-DECA 50 (Candor Bio.)'
);

-- line #21669
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAREBOLIN 25 (CHEMO HC.)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAREBOLIN 25 (CHEMO HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAREBOLIN 50 (CHEMO HC.)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAREBOLIN 50 (CHEMO HC.)'
);

-- line #21670
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CASBOL 25 (Armour Rem.)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CASBOL 25 (Armour Rem.)'
);

-- line #21671
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELON 25 (Vasphar)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELON 25 (Vasphar)'
);

-- line #21672
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUDEC 25 (Curex)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUDEC 25 (Curex)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUDEC 50 (Curex)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUDEC 50 (Curex)'
);

-- line #21673
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUREDEC 25 (Dynamic)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUREDEC 25 (Dynamic)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUREDEC 50 (Dynamic)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUREDEC 50 (Dynamic)'
);

-- line #21674
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DALBOLIN 25 (Dallas Ph.)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DALBOLIN 25 (Dallas Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DALBOLIN 50 (Dallas Ph.)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DALBOLIN 50 (Dallas Ph.)'
);

-- line #21675
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECA-ARODEC 25 (WILLOW)',
	'Nandrolone Decanoate',
	'AMP',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECA-ARODEC 25 (WILLOW)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECA-ARODEC 50 (WILLOW)',
	'Nandrolone Decanoate',
	'AMP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECA-ARODEC 50 (WILLOW)'
);

-- line #21676
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECAB 25 (ROSE LABS)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECAB 25 (ROSE LABS)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECAB 50 (ROSE LABS)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECAB 50 (ROSE LABS)'
);

-- line #21677
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECABOL 25 (Dynamic)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECABOL 25 (Dynamic)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECABOL 50 (Dynamic)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECABOL 50 (Dynamic)'
);

-- line #21678
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'25', u'strength_2': u'', u'substance': u'Nandrolone Decanoate', u'always_empty': u'', u'form': u'', u'brand': u'DECABOL', u'strength_3': u'', u'company': u'Jackson', u'unit': u'mg/ML'}

-- line #21679
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECA-DURABOLIN 100 (Infar)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECA-DURABOLIN 100 (Infar)'
);

-- line #21680
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECA-DURABOLIN 25 (Infar)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECA-DURABOLIN 25 (Infar)'
);

-- line #21681
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECA-DURABOLIN 50 (Infar)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECA-DURABOLIN 50 (Infar)'
);

-- line #21682
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECA-DURALIN 100 (TAJ PH.)',
	'Nandrolone Decanoate',
	'AMP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECA-DURALIN 100 (TAJ PH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECA-DURALIN 200 (TAJ PH.)',
	'Nandrolone Decanoate',
	'AMP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECA-DURALIN 200 (TAJ PH.)'
);

-- line #21683
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECA-DURALIN 25 (TAJ PH.)',
	'Nandrolone Decanoate',
	'AMP',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECA-DURALIN 25 (TAJ PH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECA-DURALIN 50 (TAJ PH.)',
	'Nandrolone Decanoate',
	'AMP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECA-DURALIN 50 (TAJ PH.)'
);

-- line #21684
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECA-EVABOLIN 25 (Concept)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECA-EVABOLIN 25 (Concept)'
);

-- line #21685
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECA-GERIBOL 25 (Pfiscar Ind.)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECA-GERIBOL 25 (Pfiscar Ind.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECA-GERIBOL 50 (Pfiscar Ind.)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECA-GERIBOL 50 (Pfiscar Ind.)'
);

-- line #21686
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECAGUARD 50 (Healthgaurd)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECAGUARD 50 (Healthgaurd)'
);

-- line #21687
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECAMERIBOL 25 (Meridian)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECAMERIBOL 25 (Meridian)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECAMERIBOL 50 (Meridian)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECAMERIBOL 50 (Meridian)'
);

-- line #21688
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECA-NANDROBOL 25 (CADILA)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECA-NANDROBOL 25 (CADILA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECA-NANDROBOL 50 (CADILA)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECA-NANDROBOL 50 (CADILA)'
);

-- line #21689
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECA-NANDROBOL 25 (Cadila Ph.)',
	'Nandrolone decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECA-NANDROBOL 25 (Cadila Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECA-NANDROBOL 50 (Cadila Ph.)',
	'Nandrolone decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECA-NANDROBOL 50 (Cadila Ph.)'
);

-- line #21690
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECANEURABOL 25 (Zydus A.)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECANEURABOL 25 (Zydus A.)'
);

-- line #21691
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECANEURABOL 50 (Zydus A.)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECANEURABOL 50 (Zydus A.)'
);

-- line #21692
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECANEUROPHEN 25 (Ind-Swift)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECANEUROPHEN 25 (Ind-Swift)'
);

-- line #21693
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECANEUROPHEN 50 (Ind-Swift)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECANEUROPHEN 50 (Ind-Swift)'
);

-- line #21694
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECAP 25 (Alpic Rem.)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECAP 25 (Alpic Rem.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECAP 50 (Alpic Rem.)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECAP 50 (Alpic Rem.)'
);

-- line #21695
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECARAS 25 (RASS HC.)',
	'Nandrolone Decanoate',
	'AMP',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECARAS 25 (RASS HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECARAS 50 (RASS HC.)',
	'Nandrolone Decanoate',
	'AMP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECARAS 50 (RASS HC.)'
);

-- line #21696
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECARIN 25 (Phytochem)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECARIN 25 (Phytochem)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECARIN 50 (Phytochem)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECARIN 50 (Phytochem)'
);

-- line #21697
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECARISE 25 (Global Med.)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECARISE 25 (Global Med.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECARISE 50 (Global Med.)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECARISE 50 (Global Med.)'
);

-- line #21698
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECASOLINE 25 (Redson)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECASOLINE 25 (Redson)'
);

-- line #21699
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECASOLINE 50 (Redson)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECASOLINE 50 (Redson)'
);

-- line #21700
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECASUN 25 (LAKSUN)',
	'Nandrolone Decanoate',
	'AMP',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECASUN 25 (LAKSUN)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECASUN 50 (LAKSUN)',
	'Nandrolone Decanoate',
	'AMP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECASUN 50 (LAKSUN)'
);

-- line #21701
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECATOP 25 (MADHAV BIO.)',
	'Nandrolone Decanoate',
	'AMP',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECATOP 25 (MADHAV BIO.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECATOP 50 (MADHAV BIO.)',
	'Nandrolone Decanoate',
	'AMP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECATOP 50 (MADHAV BIO.)'
);

-- line #21702
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECAVEN 25 (VENSAT)',
	'Nandrolone Decanoate',
	'AMP',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECAVEN 25 (VENSAT)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECAVEN 50 (VENSAT)',
	'Nandrolone Decanoate',
	'AMP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECAVEN 50 (VENSAT)'
);

-- line #21703
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECAVILLIN 25 (Admac Ph.)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECAVILLIN 25 (Admac Ph.)'
);

-- line #21704
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECAVILLIN 50 (Admac Ph.)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECAVILLIN 50 (Admac Ph.)'
);

-- line #21705
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECKET 25 (Elf Biomed)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECKET 25 (Elf Biomed)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECKET 50 (Elf Biomed)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECKET 50 (Elf Biomed)'
);

-- line #21706
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECOLANE 25 (Cubit Hc.)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECOLANE 25 (Cubit Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECOLANE 50 (Cubit Hc.)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECOLANE 50 (Cubit Hc.)'
);

-- line #21707
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEC-OMBOLIN 25 (Om Bio.)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEC-OMBOLIN 25 (Om Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEC-OMBOLIN 50 (Om Bio.)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEC-OMBOLIN 50 (Om Bio.)'
);

-- line #21708
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECON 25 (Adison Lab)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECON 25 (Adison Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECON 50 (Adison Lab)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECON 50 (Adison Lab)'
);

-- line #21709
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECWELL 25 (HANBURYS)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECWELL 25 (HANBURYS)'
);

-- line #21710
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEKABOL 25 (Brooks Ph.)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEKABOL 25 (Brooks Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEKABOL 50 (Brooks Ph.)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEKABOL 50 (Brooks Ph.)'
);

-- line #21711
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIPINATE 25 (Mcneil Ph.)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIPINATE 25 (Mcneil Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIPINATE 50 (Mcneil Ph.)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIPINATE 50 (Mcneil Ph.)'
);

-- line #21712
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DURAMAC 25 (Makbro Hc.)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DURAMAC 25 (Makbro Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DURAMAC 50 (Makbro Hc.)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DURAMAC 50 (Makbro Hc.)'
);

-- line #21713
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DURAS 25 (SHRESHTHA)',
	'Nandrolone Decanoate',
	'AMP',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DURAS 25 (SHRESHTHA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DURAS 50 (SHRESHTHA)',
	'Nandrolone Decanoate',
	'AMP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DURAS 50 (SHRESHTHA)'
);

-- line #21714
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EFFILIN 25 (Alde Medi.)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EFFILIN 25 (Alde Medi.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EFFILIN 50 (Alde Medi.)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EFFILIN 50 (Alde Medi.)'
);

-- line #21715
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELDEC 25 (Elfin Ph.)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELDEC 25 (Elfin Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELDEC 50 (Elfin Ph.)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELDEC 50 (Elfin Ph.)'
);

-- line #21716
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORDEC 25 (Forgo Ph.)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORDEC 25 (Forgo Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORDEC 50 (Forgo Ph.)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORDEC 50 (Forgo Ph.)'
);

-- line #21717
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIDEC 25 (Logos)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIDEC 25 (Logos)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIDEC 50 (Logos)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIDEC 50 (Logos)'
);

-- line #21718
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IDEC 25 (INVISION)',
	'Nandrolone Decanoate',
	'VIAL',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IDEC 25 (INVISION)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IDEC 50 (INVISION)',
	'Nandrolone Decanoate',
	'VIAL',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IDEC 50 (INVISION)'
);

-- line #21719
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INSTADEC 25 (Indus)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INSTADEC 25 (Indus)'
);

-- line #21720
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INSTADEC 50 (Indus)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INSTADEC 50 (Indus)'
);

-- line #21721
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTRADEC 25 (Intra Lab)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTRADEC 25 (Intra Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTRADEC 50 (Intra Lab)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTRADEC 50 (Intra Lab)'
);

-- line #21722
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEDEC 100 (Lanark)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEDEC 100 (Lanark)'
);

-- line #21723
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEDEC 25 (Lanark)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEDEC 25 (Lanark)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEDEC 50 (Lanark)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEDEC 50 (Lanark)'
);

-- line #21724
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAGABOL 25 (Helax Hc.)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAGABOL 25 (Helax Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAGABOL 50 (Helax Hc.)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAGABOL 50 (Helax Hc.)'
);

-- line #21725
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDIDAC 25 (Mefro Ph.)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDIDAC 25 (Mefro Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDIDAC 50 (Mefro Ph.)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDIDAC 50 (Mefro Ph.)'
);

-- line #21726
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGABOL-D 25 (Atoz Ph.)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGABOL-D 25 (Atoz Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGABOL-D 50 (Atoz Ph.)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGABOL-D 50 (Atoz Ph.)'
);

-- line #21727
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MENDRO 25 (Medizone)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MENDRO 25 (Medizone)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MENDRO 50 (Medizone)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MENDRO 50 (Medizone)'
);

-- line #21728
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METABOLIN-DEPOT 25 (Kerp Ph.)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METABOLIN-DEPOT 25 (Kerp Ph.)'
);

-- line #21729
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METADEC 25 (Jagsonpal)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METADEC 25 (Jagsonpal)'
);

-- line #21730
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METADEC 50 (Jagsonpal)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METADEC 50 (Jagsonpal)'
);

-- line #21731
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METUP 25 (Obsurge)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METUP 25 (Obsurge)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METUP 50 (Obsurge)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METUP 50 (Obsurge)'
);

-- line #21732
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONODIK PLUS 25 (Mefro Ph.)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONODIK PLUS 25 (Mefro Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONODIK PLUS 50 (Mefro Ph.)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONODIK PLUS 50 (Mefro Ph.)'
);

-- line #21733
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYOBOLIN 25 (Troikaa)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYOBOLIN 25 (Troikaa)'
);

-- line #21734
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NANDONE 25 (Royal)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/1ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NANDONE 25 (Royal)'
);

-- line #21735
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NANDONE 50 (Royal)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/1ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NANDONE 50 (Royal)'
);

-- line #21736
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NANDRODEC 25 (Radicura)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NANDRODEC 25 (Radicura)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NANDRODEC 50 (Radicura)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NANDRODEC 50 (Radicura)'
);

-- line #21737
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NANDY 25 (Siomond)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NANDY 25 (Siomond)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NANDY 50 (Siomond)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NANDY 50 (Siomond)'
);

-- line #21738
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NDC-25/50 25 (PARASOL)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NDC-25/50 25 (PARASOL)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NDC-25/50 50 (PARASOL)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NDC-25/50 50 (PARASOL)'
);

-- line #21739
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEODEC 25 (Nitin Ph.)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEODEC 25 (Nitin Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEODEC 50 (Nitin Ph.)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEODEC 50 (Nitin Ph.)'
);

-- line #21740
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Nandrolone Decanoate', u'always_empty': u'', u'form': u'INJ', u'brand': u'NISDROL', u'strength_3': u'', u'company': u'NEISS', u'unit': u''}

-- line #21741
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NMX 50 (BIOMAX BIO.)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NMX 50 (BIOMAX BIO.)'
);

-- line #21742
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVABOLIN-D 25 (Ophthal R.)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVABOLIN-D 25 (Ophthal R.)'
);

-- line #21743
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVABOLIN-D 50 (Ophthal R.)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVABOLIN-D 50 (Ophthal R.)'
);

-- line #21744
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUDEK 25 (Paras Lab)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUDEK 25 (Paras Lab)'
);

-- line #21745
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'N-ZOL 25 (D.R.John''S)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'N-ZOL 25 (D.R.John''S)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'N-ZOL 50 (D.R.John''S)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'N-ZOL 50 (D.R.John''S)'
);

-- line #21746
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCTODEC 25 (Symbiotic)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCTODEC 25 (Symbiotic)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCTODEC 50 (Symbiotic)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCTODEC 50 (Symbiotic)'
);

-- line #21747
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROBOL 25 (Dynamic)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROBOL 25 (Dynamic)'
);

-- line #21748
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROBOL 50 (Dynamic)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROBOL 50 (Dynamic)'
);

-- line #21749
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRODEC 25 (Prohealth)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRODEC 25 (Prohealth)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRODEC 50 (Prohealth)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRODEC 50 (Prohealth)'
);

-- line #21750
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROLONE 25 (Prohealth)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROLONE 25 (Prohealth)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROLONE 50 (Prohealth)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROLONE 50 (Prohealth)'
);

-- line #21751
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROTOMARK 25 (Unimarck)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROTOMARK 25 (Unimarck)'
);

-- line #21752
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROTOMARK 50 (Unimarck)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROTOMARK 50 (Unimarck)'
);

-- line #21753
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PUREDEC 25 (Solitaire)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PUREDEC 25 (Solitaire)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PUREDEC 50 (Solitaire)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PUREDEC 50 (Solitaire)'
);

-- line #21754
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RADIBOLIN 25 (Raddison Hc.)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RADIBOLIN 25 (Raddison Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RADIBOLIN 50 (Raddison Hc.)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RADIBOLIN 50 (Raddison Hc.)'
);

-- line #21755
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RECOBOL 25 (Cosmic Ph.)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RECOBOL 25 (Cosmic Ph.)'
);

-- line #21756
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RECOBOL 50 (Cosmic Ph.)',
	'Nandrolone Decanoate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RECOBOL 50 (Cosmic Ph.)'
);

-- line #21757
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECOZOOM 25 (SYNTRO HC.)',
	'Nandrolone',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECOZOOM 25 (SYNTRO HC.)'
);

-- line #21758
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NDN 25 (Finecure)',
	'Nandrolone',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NDN 25 (Finecure)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NDN 50 (Finecure)',
	'Nandrolone',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NDN 50 (Finecure)'
);

-- line #21759
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ABONIC 25 (Shinto Org.)',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ABONIC 25 (Shinto Org.)'
);

-- line #21760
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ABONIC 50 (Shinto Org.)',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ABONIC 50 (Shinto Org.)'
);

-- line #21761
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVILLIN 25 (Admac Ph.)',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVILLIN 25 (Admac Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVILLIN 50 (Admac Ph.)',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVILLIN 50 (Admac Ph.)'
);

-- line #21762
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVILLIN 25 (Admac Ph.)',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVILLIN 25 (Admac Ph.)'
);

-- line #21763
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVILLIN 50 (Admac Ph.)',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVILLIN 50 (Admac Ph.)'
);

-- line #21764
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETABOLIN 25 (Bestochem)',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETABOLIN 25 (Bestochem)'
);

-- line #21765
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BONOBOL 25 (Ultramark)',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BONOBOL 25 (Ultramark)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BONOBOL 50 (Ultramark)',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BONOBOL 50 (Ultramark)'
);

-- line #21766
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CADEC 25 (Admac Ph.)',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CADEC 25 (Admac Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CADEC 50 (Admac Ph.)',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CADEC 50 (Admac Ph.)'
);

-- line #21767
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANDOBOL 25 (Candor Bio.)',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANDOBOL 25 (Candor Bio.)'
);

-- line #21768
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANON 25 (USP LIFE)',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANON 25 (USP LIFE)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANON 50 (USP LIFE)',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANON 50 (USP LIFE)'
);

-- line #21769
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUREBOL 25 (Cure Quick)',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUREBOL 25 (Cure Quick)'
);

-- line #21770
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUREBOL 50 (Cure Quick)',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUREBOL 50 (Cure Quick)'
);

-- line #21771
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DENA-N 25 (Sayona)',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DENA-N 25 (Sayona)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DENA-N 50 (Sayona)',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DENA-N 50 (Sayona)'
);

-- line #21772
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIPINORLE 25 (Mcneil Ph.)',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIPINORLE 25 (Mcneil Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIPINORLE 50 (Mcneil Ph.)',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIPINORLE 50 (Mcneil Ph.)'
);

-- line #21773
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLONE 25 (Eg Ph.)',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLONE 25 (Eg Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLONE 50 (Eg Ph.)',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLONE 50 (Eg Ph.)'
);

-- line #21774
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOROLON 25 (Oscar Rem.)',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOROLON 25 (Oscar Rem.)'
);

-- line #21775
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOROLON 50 (Oscar Rem.)',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOROLON 50 (Oscar Rem.)'
);

-- line #21776
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DURABOLIN 25 (Infar)',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DURABOLIN 25 (Infar)'
);

-- line #21777
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EFFIBOL 25 (Alde Medi.)',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EFFIBOL 25 (Alde Medi.)'
);

-- line #21778
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EFFIBOL 50 (Alde Medi.)',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EFFIBOL 50 (Alde Medi.)'
);

-- line #21779
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMBOLIN 25 (B.M.Ph.)',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMBOLIN 25 (B.M.Ph.)'
);

-- line #21780
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EVABOLIN 25 (Concept)',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EVABOLIN 25 (Concept)'
);

-- line #21781
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GROBULIN 25 (Growell)',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GROBULIN 25 (Growell)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GROBULIN 50 (Growell)',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GROBULIN 50 (Growell)'
);

-- line #21782
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIBOL 25 (Logos)',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIBOL 25 (Logos)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIBOL 50 (Logos)',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIBOL 50 (Logos)'
);

-- line #21783
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDOBOLIN 10 (Indus)',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDOBOLIN 10 (Indus)'
);

-- line #21784
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDOBOLIN 25 (Indus)',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDOBOLIN 25 (Indus)'
);

-- line #21785
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LABDEC 25 (ADMAC (LEE BENZ))',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LABDEC 25 (ADMAC (LEE BENZ))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LABDEC 50 (ADMAC (LEE BENZ))',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LABDEC 50 (ADMAC (LEE BENZ))'
);

-- line #21786
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MC-PLAIN 25 (Curex)',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MC-PLAIN 25 (Curex)'
);

-- line #21787
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MERIBOL 25 (Meridian)',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MERIBOL 25 (Meridian)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MERIBOL 50 (Meridian)',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MERIBOL 50 (Meridian)'
);

-- line #21788
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METABOLIN 25 (Kerp Ph.)',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METABOLIN 25 (Kerp Ph.)'
);

-- line #21789
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METABOL 25 (Jagsonpal)',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METABOL 25 (Jagsonpal)'
);

-- line #21790
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONODIK 25 (Mefro Ph.)',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONODIK 25 (Mefro Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONODIK 50 (Mefro Ph.)',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONODIK 50 (Mefro Ph.)'
);

-- line #21791
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NANDROBOL 25 (Cadila Ph.)',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NANDROBOL 25 (Cadila Ph.)'
);

-- line #21792
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NANDRO 25 (Nitin Ph.)',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NANDRO 25 (Nitin Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NANDRO 50 (Nitin Ph.)',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NANDRO 50 (Nitin Ph.)'
);

-- line #21793
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOBOL 25 (Brooks Ph.)',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOBOL 25 (Brooks Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOBOL 50 (Brooks Ph.)',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOBOL 50 (Brooks Ph.)'
);

-- line #21794
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEURABOL 25 (Zydus A.)',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEURABOL 25 (Zydus A.)'
);

-- line #21795
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEUROPHEN 25 (Ind-Swift)',
	'Nandrolone Phenylpropionate',
	'AMP',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEUROPHEN 25 (Ind-Swift)'
);

-- line #21796
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITROBOL 25 (Biocare Rem.)',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITROBOL 25 (Biocare Rem.)'
);

-- line #21797
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVABOLIN 25 (Ophthal R.)',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVABOLIN 25 (Ophthal R.)'
);

-- line #21798
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCTOBOLIN 25 (Symbiotic)',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCTOBOLIN 25 (Symbiotic)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCTOBOLIN 50 (Symbiotic)',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCTOBOLIN 50 (Symbiotic)'
);

-- line #21799
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSTEM 25 (Lanark)',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSTEM 25 (Lanark)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSTEM 50 (Lanark)',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSTEM 50 (Lanark)'
);

-- line #21800
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROTOPHEN 25 (Unimarck)',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROTOPHEN 25 (Unimarck)'
);

-- line #21801
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROTOVILLIN 25 (Phytochem)',
	'Nandrolone Phenylpropionate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROTOVILLIN 25 (Phytochem)'
);

-- line #21802
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'NANOSOMAL Amphotericin', u'always_empty': u'', u'form': u'VIAL', u'brand': u'AMFITAS', u'strength_3': u'', u'company': u'Intas', u'unit': u''}

-- line #21803
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Naphazoline', u'always_empty': u'', u'form': u'', u'brand': u'BIO-DROP', u'strength_3': u'', u'company': u'Bio-Tech Opth.', u'unit': u''}

-- line #21804
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCUCEL 0.01 (F D C)',
	'Naphazoline',
	'EYE DPS',
	gm.nullify_empty_string('0.01')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCUCEL 0.01 (F D C)'
);

-- line #21805
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Naphazoline', u'always_empty': u'', u'form': u'EYE DPS', u'brand': u'RENOZOL', u'strength_3': u'', u'company': u'Pfiscar Ind.', u'unit': u''}

-- line #21806
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANTESVEL 250 (Martin & H.)',
	'Naproxen',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANTESVEL 250 (Martin & H.)'
);

-- line #21807
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARTAGEN 250 (Ranbaxy)',
	'Naproxen',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARTAGEN 250 (Ranbaxy)'
);

-- line #21808
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOVIBON 250 (Brown & B.)',
	'Naproxen',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOVIBON 250 (Brown & B.)'
);

-- line #21809
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NALYXAN 250 (HETERO HC.)',
	'Naproxen',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NALYXAN 250 (HETERO HC.)'
);

-- line #21810
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAPEXAR 750 (Rpg Life)',
	'NAPROXEN',
	'SR TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAPEXAR 750 (Rpg Life)'
);

-- line #21811
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAPRA-S 500 (Intas)',
	'Naproxen',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg(SOD.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAPRA-S 500 (Intas)'
);

-- line #21812
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'(SOD.)', u'strength_2': u'', u'substance': u'Naproxen', u'always_empty': u'', u'form': u'TAB', u'brand': u'NAPRA-S', u'strength_3': u'', u'company': u'Intas', u'unit': u''}

-- line #21813
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAPROSYN 10 (Rpg Life)',
	'Naproxen',
	'GEL',
	gm.nullify_empty_string('10')::numeric,
	'%W/W(ALCOHOL 1'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAPROSYN 10 (Rpg Life)'
);

-- line #21814
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAPROSYN 750 (Rpg Life)',
	'Naproxen',
	'SR TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAPROSYN 750 (Rpg Life)'
);

-- line #21815
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAPROSYN 125 (Rpg Life)',
	'Naproxen',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAPROSYN 125 (Rpg Life)'
);

-- line #21816
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAPROSYN 250 (Rpg Life)',
	'Naproxen',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAPROSYN 250 (Rpg Life)'
);

-- line #21817
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAPROSYN 500 (Rpg Life)',
	'Naproxen',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAPROSYN 500 (Rpg Life)'
);

-- line #21818
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAPRYN 250 (Themis)',
	'Naproxen',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAPRYN 250 (Themis)'
);

-- line #21819
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAPRYN 500 (Themis)',
	'Naproxen',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAPRYN 500 (Themis)'
);

-- line #21820
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAXEN 750 (Elder)',
	'Naproxen',
	'CR TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAXEN 750 (Elder)'
);

-- line #21821
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NARATREX 1 (Sun)',
	'NARATRIPTAN',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NARATREX 1 (Sun)'
);

-- line #21822
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NARATREX 2.5 (Sun)',
	'NARATRIPTAN',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NARATREX 2.5 (Sun)'
);

-- line #21823
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVINA EYE 50 (DIVINE LAB.)',
	'Natamycin',
	'DROPS',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVINA EYE 50 (DIVINE LAB.)'
);

-- line #21824
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELMYCIN 5 (Elder)',
	'Natamycin',
	'EYE DPS',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELMYCIN 5 (Elder)'
);

-- line #21825
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NATACIN 50 (Entod Ph.)',
	'Natamycin',
	'EYE DPS',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NATACIN 50 (Entod Ph.)'
);

-- line #21826
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NATADROPS 5 (Cipla)',
	'Natamycin',
	'DPS',
	gm.nullify_empty_string('5')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NATADROPS 5 (Cipla)'
);

-- line #21827
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Natamycin', u'always_empty': u'', u'form': u'VIAL', u'brand': u'NATAK', u'strength_3': u'', u'company': u'Pharmtak', u'unit': u''}

-- line #21828
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NATAMET 5 (Milmet)',
	'Natamycin',
	'SUS',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NATAMET 5 (Milmet)'
);

-- line #21829
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NATAONE EYE 5 (Elder)',
	'Natamycin',
	'DROPS',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NATAONE EYE 5 (Elder)'
);

-- line #21830
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NATASOL 5 (SENSES)',
	'Natamycin',
	'EYE DPS',
	gm.nullify_empty_string('5')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NATASOL 5 (SENSES)'
);

-- line #21831
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NATOPTIC 5 (F D C)',
	'Natamycin',
	'EYE DPS',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NATOPTIC 5 (F D C)'
);

-- line #21832
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Natamycin', u'always_empty': u'', u'form': u'EYE DPS', u'brand': u'PIMAFUCIN', u'strength_3': u'', u'company': u'Elder', u'unit': u''}

-- line #21833
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIMAFUCIN VAGINAL 100 (Elder)',
	'Natamycin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIMAFUCIN VAGINAL 100 (Elder)'
);

-- line #21834
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIMAFUSIN 5 (Elder)',
	'Natamycin',
	'EYE DPS',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIMAFUSIN 5 (Elder)'
);

-- line #21835
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIMAFUSIN VAG 1 (Elder)',
	'Natamycin',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIMAFUSIN VAG 1 (Elder)'
);

-- line #21836
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLINATE 60 (Healtheon)',
	'Nateglinide',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLINATE 60 (Healtheon)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLINATE 120 (Healtheon)',
	'Nateglinide',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLINATE 120 (Healtheon)'
);

-- line #21837
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NATELIDE 60 (Alembic)',
	'Nateglinide',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NATELIDE 60 (Alembic)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NATELIDE 120 (Alembic)',
	'Nateglinide',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NATELIDE 120 (Alembic)'
);

-- line #21838
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NATIZ 60 (Intas)',
	'Nateglinide',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NATIZ 60 (Intas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NATIZ 120 (Intas)',
	'Nateglinide',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NATIZ 120 (Intas)'
);

-- line #21839
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NDS 60 (Nucron Ph.)',
	'Nateglinide',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NDS 60 (Nucron Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NDS 120 (Nucron Ph.)',
	'Nateglinide',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NDS 120 (Nucron Ph.)'
);

-- line #21840
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100', u'strength_2': u'', u'substance': u'NATTOKINASE', u'always_empty': u'', u'form': u'', u'brand': u'CEROKINASE', u'strength_3': u'', u'company': u'ADVANCE VITAL', u'unit': u'mg'}

-- line #21841
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2000IU.', u'strength_2': u'', u'substance': u'NATTOKINASE', u'always_empty': u'', u'form': u'TAB', u'brand': u'OROKINASE', u'strength_3': u'', u'company': u'Nouveau', u'unit': u''}

-- line #21842
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'NATURAL GALACTOGOUGE', u'always_empty': u'', u'form': u'CAP', u'brand': u'ENLAC', u'strength_3': u'', u'company': u'Astrum Hc.', u'unit': u''}

-- line #21843
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.15G', u'strength_2': u'', u'substance': u'N-Butyl-Cyanoacrylate', u'always_empty': u'', u'form': u'AMP', u'brand': u'CUTSEAL', u'strength_3': u'', u'company': u'Rusan Hc', u'unit': u''}

-- line #21844
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.25G', u'strength_2': u'', u'substance': u'N-Butyl-Cyanoacrylate', u'always_empty': u'', u'form': u'INJ', u'brand': u'CUTSEAL', u'strength_3': u'', u'company': u'Rusan Hc', u'unit': u''}

-- line #21845
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.15ML', u'strength_2': u'', u'substance': u'N-Butyl-Cyanoacrylate', u'always_empty': u'', u'form': u'INJ', u'brand': u'DURACRYL', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #21846
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,25', u'strength_2': u'0.5;ML', u'substance': u'N-Butyl-Cyanoacrylate', u'always_empty': u'', u'form': u'INJ', u'brand': u'DURACRYL', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #21847
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NECTACRYL 0.25 (Dr.Reddy''S)',
	'N-Butyl-Cyanoacrylate',
	'AMP',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NECTACRYL 0.25 (Dr.Reddy''S)'
);

-- line #21848
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NECTACRYL 0.5 (Dr.Reddy''S)',
	'N-Butyl-Cyanoacrylate',
	'AMP',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NECTACRYL 0.5 (Dr.Reddy''S)'
);

-- line #21849
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NECTACRYL 1 (Dr.Reddy''S)',
	'N-Butyl-Cyanoacrylate',
	'AMP',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NECTACRYL 1 (Dr.Reddy''S)'
);

-- line #21850
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REKSEAL 0.15 (Rekvina)',
	'N-Butyl-Cyanoacrylate',
	'INJ',
	gm.nullify_empty_string('0.15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REKSEAL 0.15 (Rekvina)'
);

-- line #21851
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REKSEAL 0.25 (Rekvina)',
	'N-Butyl-Cyanoacrylate',
	'INJ',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REKSEAL 0.25 (Rekvina)'
);

-- line #21852
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REKSEAL 0.5 (Rekvina)',
	'N-Butyl-Cyanoacrylate',
	'INJ',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REKSEAL 0.5 (Rekvina)'
);

-- line #21853
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASIVOL 2.5 (AS PHARMA)',
	'NEBIVOLOL',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASIVOL 2.5 (AS PHARMA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASIVOL 5 (AS PHARMA)',
	'NEBIVOLOL',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASIVOL 5 (AS PHARMA)'
);

-- line #21854
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENVOLOL 2.5 (MOVA PH.)',
	'NEBIVOLOL',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENVOLOL 2.5 (MOVA PH.)'
);

-- line #21855
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENVOLOL 5 (MOVA PH.)',
	'NEBIVOLOL',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENVOLOL 5 (MOVA PH.)'
);

-- line #21856
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENBLOK 2.5 (ALEMBIC)',
	'NEBIVOLOL',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENBLOK 2.5 (ALEMBIC)'
);

-- line #21857
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENBLOK 5 (ALEMBIC)',
	'NEBIVOLOL',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENBLOK 5 (ALEMBIC)'
);

-- line #21858
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENDOLOL 5 (Genix Ph.)',
	'NEBIVOLOL',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENDOLOL 5 (Genix Ph.)'
);

-- line #21859
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEBEST 2.5 (U S V)',
	'NEBIVOLOL',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEBEST 2.5 (U S V)'
);

-- line #21860
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEBEST 5 (U S V)',
	'NEBIVOLOL',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEBEST 5 (U S V)'
);

-- line #21861
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEBICARD 10 (Torrent)',
	'NEBIVOLOL',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEBICARD 10 (Torrent)'
);

-- line #21862
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEBICARD 2.5 (Torrent)',
	'Nebivolol',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEBICARD 2.5 (Torrent)'
);

-- line #21863
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEBICARD 5 (Torrent)',
	'Nebivolol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEBICARD 5 (Torrent)'
);

-- line #21864
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEBICIP 2.5 (Cipla)',
	'NEBIVOLOL',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEBICIP 2.5 (Cipla)'
);

-- line #21865
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEBICIP 5 (Cipla)',
	'NEBIVOLOL',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEBICIP 5 (Cipla)'
);

-- line #21866
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEBILOL 2.5 (J.B.Chem.)',
	'NEBIVOLOL',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEBILOL 2.5 (J.B.Chem.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEBILOL 5 (J.B.Chem.)',
	'NEBIVOLOL',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEBILOL 5 (J.B.Chem.)'
);

-- line #21867
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEBILOL 2.5 (UNIQUE)',
	'NEBIVOLOL',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEBILOL 2.5 (UNIQUE)'
);

-- line #21868
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEBILOL 5 (UNIQUE)',
	'NEBIVOLOL',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEBILOL 5 (UNIQUE)'
);

-- line #21869
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEBILONG 2.5 (Micro Labs)',
	'NEBIVOLOL',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEBILONG 2.5 (Micro Labs)'
);

-- line #21870
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEBILONG 5 (Micro Labs)',
	'NEBIVOLOL',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEBILONG 5 (Micro Labs)'
);

-- line #21871
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEBIMAC 2.5 (Macleods)',
	'NEBIVOLOL',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEBIMAC 2.5 (Macleods)'
);

-- line #21872
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEBIMAC 3 (Macleods)',
	'NEBIVOLOL',
	'TAB',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEBIMAC 3 (Macleods)'
);

-- line #21873
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEBINEX 2.5 (GLENMARK)',
	'Nebivolol',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEBINEX 2.5 (GLENMARK)'
);

-- line #21874
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEBINEX 5 (Glenmark)',
	'NEBIVOLOL',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEBINEX 5 (Glenmark)'
);

-- line #21875
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEBIPIL 5 (Alkem)',
	'Nebivolol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEBIPIL 5 (Alkem)'
);

-- line #21876
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEBISTAR 10 (Lupin)',
	'NEBIVOLOL',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEBISTAR 10 (Lupin)'
);

-- line #21877
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEBISTAR 2.5 (Lupin)',
	'NEBIVOLOL',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEBISTAR 2.5 (Lupin)'
);

-- line #21878
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEBISTAR 5 (Lupin)',
	'NEBIVOLOL',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEBISTAR 5 (Lupin)'
);

-- line #21879
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEBITEN 2.5 (ANTHUS)',
	'NEBIVOLOL',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEBITEN 2.5 (ANTHUS)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEBITEN 5 (ANTHUS)',
	'NEBIVOLOL',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEBITEN 5 (ANTHUS)'
);

-- line #21880
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEBITIME 2.5 (Mankind)',
	'NEBIVOLOL',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEBITIME 2.5 (Mankind)'
);

-- line #21881
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEBITIME 5 (Mankind)',
	'NEBIVOLOL',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEBITIME 5 (Mankind)'
);

-- line #21882
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEBITROY 2.5 (Troikaa)',
	'NEBIVOLOL',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEBITROY 2.5 (Troikaa)'
);

-- line #21883
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEBITROY 5 (Troikaa)',
	'NEBIVOLOL',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEBITROY 5 (Troikaa)'
);

-- line #21884
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEBIVAS 2.5 (Intra Lab)',
	'NEBIVOLOL',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEBIVAS 2.5 (Intra Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEBIVAS 5 (Intra Lab)',
	'NEBIVOLOL',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEBIVAS 5 (Intra Lab)'
);

-- line #21885
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEBULA 2.5 (Zydus Med.)',
	'NEBIVOLOL',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEBULA 2.5 (Zydus Med.)'
);

-- line #21886
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEBULA 5 (Zydus Med.)',
	'NEBIVOLOL',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEBULA 5 (Zydus Med.)'
);

-- line #21887
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEBUNTA 2.5 (Ajanta Ph.)',
	'NEBIVOLOL',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEBUNTA 2.5 (Ajanta Ph.)'
);

-- line #21888
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEBUNTA 5 (Ajanta Ph.)',
	'NEBIVOLOL',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEBUNTA 5 (Ajanta Ph.)'
);

-- line #21889
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'NEBIVOLOL', u'always_empty': u'', u'form': u'', u'brand': u'NEVELOL', u'strength_3': u'', u'company': u'NEO CC.', u'unit': u''}

-- line #21890
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEVOL 2.5 (Medley)',
	'NEBIVOLOL',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEVOL 2.5 (Medley)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEVOL 5 (Medley)',
	'NEBIVOLOL',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEVOL 5 (Medley)'
);

-- line #21891
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIAVAS 2.5 (Ranbaxy)',
	'NEBIVOLOL',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIAVAS 2.5 (Ranbaxy)'
);

-- line #21892
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIAVAS 5 (Ranbaxy)',
	'NEBIVOLOL',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIAVAS 5 (Ranbaxy)'
);

-- line #21893
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NODON 10 (Cadila Ph.)',
	'NEBIVOLOL',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NODON 10 (Cadila Ph.)'
);

-- line #21894
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NODON 2.5 (Cadila Ph.)',
	'Nebivolol',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NODON 2.5 (Cadila Ph.)'
);

-- line #21895
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NODON 5 (Cadila Ph.)',
	'Nebivolol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NODON 5 (Cadila Ph.)'
);

-- line #21896
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUBETA 2.5 (Piramal Hc.)',
	'NEBIVOLOL',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUBETA 2.5 (Piramal Hc.)'
);

-- line #21897
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUBETA 5 (Piramal Hc.)',
	'NEBIVOLOL',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUBETA 5 (Piramal Hc.)'
);

-- line #21898
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NYFE 2.5 (AAMORB)',
	'NEBIVOLOL',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NYFE 2.5 (AAMORB)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NYFE 5 (AAMORB)',
	'NEBIVOLOL',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NYFE 5 (AAMORB)'
);

-- line #21899
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PINE 2.5 (Cadila Ph.)',
	'NEBIVOLOL',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PINE 2.5 (Cadila Ph.)'
);

-- line #21900
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PINE 5 (Cadila Ph.)',
	'NEBIVOLOL',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PINE 5 (Cadila Ph.)'
);

-- line #21901
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRENEEM 100 (Dabur Ph.)',
	'Neem Leaf Ext.',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRENEEM 100 (Dabur Ph.)'
);

-- line #21902
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEFOMAX 20 (Torrent)',
	'NEFOPAM HCL.',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEFOMAX 20 (Torrent)'
);

-- line #21903
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEFOMAX 30 (Torrent)',
	'NEFOPAM HCL.',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEFOMAX 30 (Torrent)'
);

-- line #21904
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMNEL 250 (Emcure)',
	'Nelfinavir',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMNEL 250 (Emcure)'
);

-- line #21905
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEIVEX 250 (Aurobindo)',
	'Nelfinavir',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEIVEX 250 (Aurobindo)'
);

-- line #21906
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NELFIN 625 (HETERO HC.)',
	'Nelfinavir',
	'TAB',
	gm.nullify_empty_string('625')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NELFIN 625 (HETERO HC.)'
);

-- line #21907
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEL 250 (Mcneil & A.)',
	'Nelfinavir',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEL 250 (Mcneil & A.)'
);

-- line #21908
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NELVIR 250 (Cipla)',
	'Nelfinavir',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NELVIR 250 (Cipla)'
);

-- line #21909
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEVIR 50 (EMCURE(ARV))',
	'Nelfinavir',
	'SUSP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEVIR 50 (EMCURE(ARV))'
);

-- line #21910
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEVIR 200 (EMCURE(ARV))',
	'Nelfinavir',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEVIR 200 (EMCURE(ARV))'
);

-- line #21911
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEV 200 (Mcneil & A.)',
	'Nelfinavir',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEV 200 (Mcneil & A.)'
);

-- line #21912
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RETRONEL 250 (Cytomed(Alkem))',
	'Nelfinavir',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RETRONEL 250 (Cytomed(Alkem))'
);

-- line #21913
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NILTAMIDE 150 (Zydus Bio.)',
	'NELTAMIDE',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NILTAMIDE 150 (Zydus Bio.)'
);

-- line #21914
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOMYCIN SULPHATE 350 (Unichem)',
	'NEOMYCIN SULPH.',
	'CAP',
	gm.nullify_empty_string('350')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOMYCIN SULPHATE 350 (Unichem)'
);

-- line #21915
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AISTIG 0.5 (ALEMBIC)',
	'Neostigmine',
	'INJ',
	gm.nullify_empty_string('0.5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AISTIG 0.5 (ALEMBIC)'
);

-- line #21916
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BEEMINE 0.5 (BIOMIICRON)',
	'Neostigmine',
	'AMP',
	gm.nullify_empty_string('0.5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BEEMINE 0.5 (BIOMIICRON)'
);

-- line #21917
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHOLSTIG 0.5 (Ind-Swift)',
	'Neostigmine',
	'INJ',
	gm.nullify_empty_string('0.5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHOLSTIG 0.5 (Ind-Swift)'
);

-- line #21918
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYOSTIGMIN 0.5 (Neon)',
	'Neostigmine',
	'INJ',
	gm.nullify_empty_string('0.5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYOSTIGMIN 0.5 (Neon)'
);

-- line #21919
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYOSTIGMIN 2.5 (Neon)',
	'Neostigmine',
	'INJ',
	gm.nullify_empty_string('2.5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYOSTIGMIN 2.5 (Neon)'
);

-- line #21920
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOMINE 0.5 (German R.)',
	'Neostigmine',
	'INJ',
	gm.nullify_empty_string('0.5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOMINE 0.5 (German R.)'
);

-- line #21921
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOSTIGMINE 0.5 (Nicholas)',
	'Neostigmine',
	'INJ',
	gm.nullify_empty_string('0.5')::numeric,
	'mg/5ML(METHYL SULPHATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOSTIGMINE 0.5 (Nicholas)'
);

-- line #21922
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,5', u'strength_2': u'', u'substance': u'Neostigmine', u'always_empty': u'', u'form': u'', u'brand': u'NEOTROY NEOSTIGMINE', u'strength_3': u'', u'company': u'Troikaa', u'unit': u'mg/ML(METHYL SULPHATE)'}

-- line #21923
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROSTIGMIN 0.5 (Nicholas)',
	'Neostigmine',
	'INJ',
	gm.nullify_empty_string('0.5')::numeric,
	'mg/ML(BROMIDE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROSTIGMIN 0.5 (Nicholas)'
);

-- line #21924
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROSTIGMIN 15 (Nicholas)',
	'Neostigmine',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg(BROMIDE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROSTIGMIN 15 (Nicholas)'
);

-- line #21925
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1', u'strength_2': u'', u'substance': u'NEPAFENAC', u'always_empty': u'', u'form': u'', u'brand': u'ALEMBIC AVANEP', u'strength_3': u'', u'company': u'ALEMBIC', u'unit': u'mg(0.005'}

-- line #21926
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,1', u'strength_2': u'', u'substance': u'NEPAFENAC', u'always_empty': u'', u'form': u'', u'brand': u'MICRONAC', u'strength_3': u'', u'company': u'Micro Labs', u'unit': u'%'}

-- line #21927
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEPALACT 0.1 (Sun)',
	'NEPAFENAC',
	'SUS',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEPALACT 0.1 (Sun)'
);

-- line #21928
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEVANAC OPHTHALMIC 0.1 (Alcon Lab)',
	'NEPAFENAC',
	'SUS',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEVANAC OPHTHALMIC 0.1 (Alcon Lab)'
);

-- line #21929
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEYPAC EYE 1 (Intas)',
	'NEPAFENAC',
	'DROPS',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEYPAC EYE 1 (Intas)'
);

-- line #21930
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NETICIN 200 (Samarth)',
	'Netilmicin Sulphate',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NETICIN 200 (Samarth)'
);

-- line #21931
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NETICIN 300 (Samarth)',
	'Netilmicin Sulphate',
	'INJ',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NETICIN 300 (Samarth)'
);

-- line #21932
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NETILCIN 100 (EXCELLA)',
	'Netilmicin Sulphate',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NETILCIN 100 (EXCELLA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NETILCIN 200 (EXCELLA)',
	'Netilmicin Sulphate',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NETILCIN 200 (EXCELLA)'
);

-- line #21933
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NETILCIN 300 (EXCELLA)',
	'Netilmicin Sulphate',
	'INJ',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NETILCIN 300 (EXCELLA)'
);

-- line #21934
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NETIZEN 200 (UNIMARK REM.)',
	'Netilmicin Sulphate',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NETIZEN 200 (UNIMARK REM.)'
);

-- line #21935
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NETIZEN 300 (UNIMARK REM.)',
	'Netilmicin Sulphate',
	'INJ',
	gm.nullify_empty_string('300')::numeric,
	'mg/3ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NETIZEN 300 (UNIMARK REM.)'
);

-- line #21936
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NETLY 100 (Phytochem)',
	'Netilmicin Sulphate',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NETLY 100 (Phytochem)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NETLY 200 (Phytochem)',
	'Netilmicin Sulphate',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NETLY 200 (Phytochem)'
);

-- line #21937
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NETLY 300 (Phytochem)',
	'Netilmicin Sulphate',
	'INJ',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NETLY 300 (Phytochem)'
);

-- line #21938
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NETMICIN 200 (United Bio.)',
	'Netilmicin Sulphate',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NETMICIN 200 (United Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NETMICIN 300 (United Bio.)',
	'Netilmicin Sulphate',
	'INJ',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NETMICIN 300 (United Bio.)'
);

-- line #21939
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NETMICIN 50 (United Bio.)',
	'Netilmicin Sulphate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NETMICIN 50 (United Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NETMICIN 100 (United Bio.)',
	'Netilmicin Sulphate',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NETMICIN 100 (United Bio.)'
);

-- line #21940
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NETROMAX 10 (Zuventus)',
	'Netilmicin Sulphate',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NETROMAX 10 (Zuventus)'
);

-- line #21941
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NETROMAX 150 (Zuventus)',
	'Netilmicin Sulphate',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NETROMAX 150 (Zuventus)'
);

-- line #21942
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NETROMAX 25 (Zuventus)',
	'Netilmicin Sulphate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NETROMAX 25 (Zuventus)'
);

-- line #21943
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NETROMAX 300 (Zuventus)',
	'Netilmicin Sulphate',
	'INJ',
	gm.nullify_empty_string('300')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NETROMAX 300 (Zuventus)'
);

-- line #21944
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NETROMAX 50 (Zuventus)',
	'Netilmicin Sulphate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NETROMAX 50 (Zuventus)'
);

-- line #21945
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NETROMYCIN 10 (Fulford)',
	'Netilmicin Sulphate',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NETROMYCIN 10 (Fulford)'
);

-- line #21946
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NETROMYCIN 200 (Fulford)',
	'Netilmicin Sulphate',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NETROMYCIN 200 (Fulford)'
);

-- line #21947
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NETROMYCIN 25 (Fulford)',
	'Netilmicin Sulphate',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NETROMYCIN 25 (Fulford)'
);

-- line #21948
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NETROMYCIN 300 (Fulford)',
	'Netilmicin Sulphate',
	'INJ',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NETROMYCIN 300 (Fulford)'
);

-- line #21949
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NETROMYCIN 50 (Fulford)',
	'Netilmicin Sulphate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NETROMYCIN 50 (Fulford)'
);

-- line #21950
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NETSPAN 10 (Cipla)',
	'Netilmicin Sulphate',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NETSPAN 10 (Cipla)'
);

-- line #21951
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NETSPAN 200 (Cipla)',
	'Netilmicin Sulphate',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NETSPAN 200 (Cipla)'
);

-- line #21952
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NETSPAN 300 (Cipla)',
	'Netilmicin Sulphate',
	'INJ',
	gm.nullify_empty_string('300')::numeric,
	'mg/3ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NETSPAN 300 (Cipla)'
);

-- line #21953
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NETSPAN 50 (Cipla)',
	'Netilmicin Sulphate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NETSPAN 50 (Cipla)'
);

-- line #21954
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'MONOCOMPONENT HUMAN INSULIN', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'', u'brand': u'ACTRAPID FLEX PEN', u'strength_3': u'', u'company': u'Novo Nordisk', u'unit': u'BIOSYNTHETIC'}

-- line #21955
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100IU.HIGHLY PURIF.HUMAN MONOCOMPONET NEUTRAL INS.', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'ACTRAPID HM PENFILL', u'strength_3': u'', u'company': u'Novo Nordisk', u'unit': u''}

-- line #21956
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40IU', u'strength_2': u'ML(PORK INSULIN)', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'ACTRAPID MC', u'strength_3': u'', u'company': u'Novo Nordisk', u'unit': u''}

-- line #21957
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'HIGHLY PRURIF.HUMAN MONO-COMPONENT NEUTRAL INSULIN', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'ACTRAPID NOVOLET', u'strength_3': u'', u'company': u'Novo Nordisk', u'unit': u''}

-- line #21958
-- ignoring line: field [strength_1] not numeric: >>>SOL(30<<<
-- {u'list_of_values_of_unknown_fields': [u'HUMAN-RDNA 100IU', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'SOL(30', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'BIOSULIN-30/70 CARTRDGE', u'strength_3': u'', u'company': u'INNOVA LIFESCI.', u'unit': u'%)+INSULIN INJ ISOPHANE (70'}

-- line #21959
-- ignoring line: field [strength_1] not numeric: >>>SOL(30<<<
-- {u'list_of_values_of_unknown_fields': [u'HUMAN-RDNA 40IU', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'SOL(30', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'BIOSULIN-30/70 IU', u'strength_3': u'', u'company': u'INNOVA LIFESCI.', u'unit': u'%)+INSULIN INJ ISOPHANE (70'}

-- line #21960
-- ignoring line: field [strength_1] not numeric: >>>SOL(50<<<
-- {u'list_of_values_of_unknown_fields': [u'HUMAN-RDNA 40IU', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'SOL(50', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'BIOSULIN-50/50 IU', u'strength_3': u'', u'company': u'INNOVA LIFESCI.', u'unit': u'%)+INSULIN INJ ISOPHANE (50'}

-- line #21961
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'INSULIN HUMAN RDNA ORIGIN : 40IU', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'BIOSULIN-N IU', u'strength_3': u'', u'company': u'INNOVA LIFESCI.', u'unit': u''}

-- line #21962
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'SOL EP. HUMAN RDNA: 40IU', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'BIOSULIN-R IU', u'strength_3': u'', u'company': u'INNOVA LIFESCI.', u'unit': u''}

-- line #21963
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'PURIFIED BOVINE INSULIN', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'V', u'brand': u'BOVINE FASTACT', u'strength_3': u'', u'company': u'U S V', u'unit': u''}

-- line #21964
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'PURIFIED BOVINE INSULIN', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'VIAL', u'brand': u'BOVINE LONGACT', u'strength_3': u'', u'company': u'U S V', u'unit': u''}

-- line #21965
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'PURIFIED BOVINE INSULIN', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'VIAL', u'brand': u'BOVINE-MIXACT', u'strength_3': u'', u'company': u'U S V', u'unit': u''}

-- line #21966
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40IU.', u'strength_2': u'100IU. HUMAN MONOCOMPONET NEUTRAL INSULIN', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'V', u'brand': u'HUMAN ACTRAPID', u'strength_3': u'', u'company': u'Novo Nordisk', u'unit': u''}

-- line #21967
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40IU.', u'strength_2': u'ML(HUMAN INSULIN RECOMBINANT DNA ORIGIN)', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'VIAL', u'brand': u'HUMANEXT-N', u'strength_3': u'', u'company': u'CADILA', u'unit': u''}

-- line #21968
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'MONOCOMPONENT HUMAN INSULIN', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'HUMAN FASTACT', u'strength_3': u'', u'company': u'U S V', u'unit': u''}

-- line #21969
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40IU.HUMAN MONOCOMPONENT ISOPHANE INSULIN(NPH)', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'HUMAN INSULATARD', u'strength_3': u'', u'company': u'Novo Nordisk', u'unit': u''}

-- line #21970
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100IU.HUMAN MONOCOMPONENT ISOPHANE INSULIN(NPH)', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'HUMAN INSULATARD IU', u'strength_3': u'', u'company': u'Novo Nordisk', u'unit': u''}

-- line #21971
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'HIGHLY PURIFIED HUMAN INSULIN', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'V', u'brand': u'HUMAN LONGACT', u'strength_3': u'', u'company': u'U S V', u'unit': u''}

-- line #21972
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'HIGHLY PURIFIED HUMAN INSULIN', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'VIAL', u'brand': u'HUMAN-MIXACT', u'strength_3': u'', u'company': u'U S V', u'unit': u''}

-- line #21973
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100IU.30', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'', u'brand': u'HUMAN MIXTARD IU', u'strength_3': u'', u'company': u'Novo Nordisk', u'unit': u'%AS SOLUBLE INS&70'}

-- line #21974
-- ignoring line: field [strength_1] not numeric: >>>100IU.50<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100IU.50', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'V', u'brand': u'HUMAN MIXTARD IU', u'strength_3': u'', u'company': u'Novo Nordisk', u'unit': u'%SOLUBLE INS.&50'}

-- line #21975
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'', u'brand': u'HUMAN MIXTARD', u'strength_3': u'', u'company': u'Novo Nordisk', u'unit': u'50'}

-- line #21976
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100IU', u'strength_2': u'ML', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'', u'brand': u'HUMAN MIXTARD PENFILL', u'strength_3': u'', u'company': u'Novo Nordisk', u'unit': u''}

-- line #21977
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40IU.', u'strength_2': u'100IU.;ML HUMAN MONOCOMPONENT', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'VIAL IU/100IU', u'brand': u'HUMAN MIXTARD', u'strength_3': u'', u'company': u'Novo Nordisk', u'unit': u''}

-- line #21978
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40IU.ML (HIGHLY PUR.HUMAN INS.ZINC SUS.)', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'', u'brand': u'HUMAN MONOTARD-V IU', u'strength_3': u'', u'company': u'Novo Nordisk', u'unit': u''}

-- line #21979
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40IU.', u'strength_2': u'ML.HIGHLY PURIF.PORCINE ISOPHANE INS.', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'VIAL', u'brand': u'HUMAN PRODICA', u'strength_3': u'', u'company': u'Nicholas', u'unit': u''}

-- line #21980
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40IU.', u'strength_2': u'ML.', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'VIAL', u'brand': u'HUMAN RAPIMIX', u'strength_3': u'', u'company': u'Nicholas', u'unit': u''}

-- line #21981
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40IU.', u'strength_2': u'ML.HIGHLY PURIF.PORCINE INS.ZINC SUS.', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'HUMAN ZINULIN', u'strength_3': u'', u'company': u'Nicholas', u'unit': u''}

-- line #21982
-- ignoring line: field [strength_1] not numeric: >>>100IU.50<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100IU.50', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'V', u'brand': u'HUMINSULIN :50', u'strength_3': u'', u'company': u'Eli Lilly', u'unit': u'%SOLUBLE INS&50'}

-- line #21983
-- ignoring line: field [strength_1] not numeric: >>>40IU.50<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40IU.50', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'V', u'brand': u'HUMINSULIN :50', u'strength_3': u'', u'company': u'Eli Lilly', u'unit': u'%SOLUBLE INS&50'}

-- line #21984
-- ignoring line: field [strength_1] not numeric: >>>100IU.30<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100IU.30', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'V100IU', u'brand': u'HUMINSULIN :70', u'strength_3': u'', u'company': u'Eli Lilly', u'unit': u'%SOLUBLE INS.&70'}

-- line #21985
-- ignoring line: field [strength_1] not numeric: >>>40IU.30<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40IU.30', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'V40IU', u'brand': u'HUMINSULIN :70', u'strength_3': u'', u'company': u'Eli Lilly', u'unit': u'%SOLUBLE INS&70'}

-- line #21986
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40IU.', u'strength_2': u'ML HUMAN INSULIN ZINC SUS.MONOCOMPONENT', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'V', u'brand': u'HUMINSULIN-L', u'strength_3': u'', u'company': u'Eli Lilly', u'unit': u''}

-- line #21987
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100IU.', u'strength_2': u'ML.HUMAN ISOPHANE INSULIN MONOCOMPONENT', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'VIAL', u'brand': u'HUMINSULIN-N', u'strength_3': u'', u'company': u'Eli Lilly', u'unit': u''}

-- line #21988
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40IU', u'strength_2': u'ML.HUMAN ISOPHANE INSULIN MONOCOMPONENT', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'VIAL', u'brand': u'HUMINSULIN-N', u'strength_3': u'', u'company': u'Eli Lilly', u'unit': u''}

-- line #21989
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100IU.HUMAN MONOCOMPONENT REGULAR INSULIN.', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'HUMINSULIN-R', u'strength_3': u'', u'company': u'Eli Lilly', u'unit': u''}

-- line #21990
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40IU.', u'strength_2': u'100IU.HUMAN MONOCOMPONENT REGULAR INS.', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'HUMINSULIN-R', u'strength_3': u'', u'company': u'Eli Lilly', u'unit': u''}

-- line #21991
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40IU.', u'strength_2': u'ML.HUMAN INSULIN EXT.ZINC SUS.', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'HUMINSULIN-U', u'strength_3': u'', u'company': u'Eli Lilly', u'unit': u''}

-- line #21992
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HUMSTARD 30 (Cadila Ph.)',
	'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin',
	'INJ',
	gm.nullify_empty_string('30')::numeric,
	'%AS SOLUBLE INSULIN&70'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HUMSTARD 30 (Cadila Ph.)'
);

-- line #21993
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40IU.', u'strength_2': u'ML.HIGHLY PUR.BOVINE PORCINE INS.ZINC SUS.', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'ILETIN-L', u'strength_3': u'', u'company': u'Eli Lilly', u'unit': u''}

-- line #21994
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40IU', u'strength_2': u'ML HIGHLY PUR.BOVINE PORCINE ISOPHANE INS.SUS', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'ILETIN-NPH', u'strength_3': u'', u'company': u'Eli Lilly', u'unit': u''}

-- line #21995
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'HIGHLY PURIFIED BOVINE PORCINE ISOPHANE 40IU.INSULIN', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'VIAL', u'brand': u'ILETIN-N', u'strength_3': u'', u'company': u'Eli Lilly', u'unit': u''}

-- line #21996
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40IU.HIGHLY PURIF.BOVINE PORCINE INSULIN', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'VIAL', u'brand': u'ILETIN-R', u'strength_3': u'', u'company': u'Eli Lilly', u'unit': u''}

-- line #21997
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ILETIN 30 (Eli Lilly)',
	'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin',
	'V',
	gm.nullify_empty_string('30')::numeric,
	'%AS SOLUBLE INSULIN&70'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ILETIN 30 (Eli Lilly)'
);

-- line #21998
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40IU. BIPHASIC ISOPHANE', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'', u'brand': u'INSUCARE-N IU/ML', u'strength_3': u'', u'company': u'Ranbaxy', u'unit': u''}

-- line #21999
-- ignoring line: field [strength_1] not numeric: >>>MIXTURE OF 30<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'MIXTURE OF 30', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'V', u'brand': u'INSUGEN-30/70', u'strength_3': u'', u'company': u'Biocon', u'unit': u'%SOLUBLE INS& 70'}

-- line #22000
-- ignoring line: field [strength_1] not numeric: >>>MIXTURE OF 50<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'MIXTURE OF 50', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'V', u'brand': u'INSUGEN-50/50', u'strength_3': u'', u'company': u'Biocon', u'unit': u'%SOLUBLE INS&50'}

-- line #22001
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100IU(HUMAN INSULIN)', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'', u'brand': u'INSUGEN IU/ML', u'strength_3': u'', u'company': u'Biocon', u'unit': u''}

-- line #22002
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40IU.', u'strength_2': u'ML ISOPHANE HUMAN INSULIN', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'INSUGEN-N', u'strength_3': u'', u'company': u'Biocon', u'unit': u''}

-- line #22003
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100IU(HUMAN INSULIN)', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'', u'brand': u'INSUGEN-N IU/ML', u'strength_3': u'', u'company': u'Biocon', u'unit': u''}

-- line #22004
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40IU.', u'strength_2': u'ML RECOMBINANT HUMAN(R-DNA)INSULIN SOLUBLE', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'INSUGEN-R', u'strength_3': u'', u'company': u'Biocon', u'unit': u''}

-- line #22005
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100IU(HUMAN INSULIN)', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'', u'brand': u'INSUGEN-R IU/ML', u'strength_3': u'', u'company': u'Biocon', u'unit': u''}

-- line #22006
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'MONOCOMPONENT HUMAN INSULIN', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'', u'brand': u'INSULATARD FLEX PEN', u'strength_3': u'', u'company': u'Novo Nordisk', u'unit': u'BIOSYNTHETIC'}

-- line #22007
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'ISOPHANE INS.SUS.(HUMAN MONOCOMPONENT)NPH', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'V', u'brand': u'INSULATARD HM PENFILL', u'strength_3': u'', u'company': u'Novo Nordisk', u'unit': u''}

-- line #22008
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40IU.', u'strength_2': u'ML.HIGHLY PURIF.ISOPHANE INSULIN PORCINE NPH', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'INSULATARD', u'strength_3': u'', u'company': u'Novo Nordisk', u'unit': u''}

-- line #22009
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'VIAL', u'brand': u'INSULATARD NOVOLET', u'strength_3': u'', u'company': u'Novo Nordisk', u'unit': u''}

-- line #22010
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40IU. CRYSTALLIN PROTAMINE INSULIN COMPLEX. PREPARED FROM BOVINE PANCREAS', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'', u'brand': u'INSULIN ISOPHANE', u'strength_3': u'', u'company': u'ABBOTT', u'unit': u''}

-- line #22011
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40IU.', u'strength_2': u'ML INSOLUBLE COMPLEX INSULIN', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'', u'brand': u'INSULIN PROTAMINE ZINC', u'strength_3': u'', u'company': u'ABBOTT', u'unit': u'PROTAMINE FROM BOVINE PANCREAS'}

-- line #22012
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40', u'strength_2': u'80;IU.7 PARTS OF INSULIN ZINC SUS.', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'', u'brand': u'INSULIN ZINC (LENTE)', u'strength_3': u'', u'company': u'ABBOTT', u'unit': u'MIXTURE OF 3 PARTS OF INSULINE'}

-- line #22013
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'0,06', u' %W/V - HUMANINSULINIP', u'PROTAMINE SULPHATE EP', u'PHENIL EP', u'', u'', u'', u'', u''], u'strength_1': u'100IU', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'', u'brand': u'INSUMAN BASAL "3 CARTRIDGES', u'strength_3': u'', u'company': u'SANOFI AV.', u'unit': u'0,318'}

-- line #22014
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40IU.ISOPHANE;INTERMEDIATE ACTING HUMAN INSULIN', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'INSUMAN BASAL', u'strength_3': u'', u'company': u'Sanofi Aventis', u'unit': u''}

-- line #22015
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'M-CRESOL', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100IU', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'', u'brand': u'INSUMAN RAPID "3 CARTRIDGES', u'strength_3': u'', u'company': u'SANOFI AV.', u'unit': u'0,27'}

-- line #22016
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40IU.NEUTRAL;SHORT ACTING HUMAN INSULIN', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'VIAL', u'brand': u'INSUMAN RAPID', u'strength_3': u'', u'company': u'Sanofi Aventis', u'unit': u''}

-- line #22017
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'MIXTURE OF 25', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'', u'brand': u"INSUMANS''S OPTISET", u'strength_3': u'', u'company': u'Sanofi Aventis', u'unit': u'% NEUTRAL &75'}

-- line #22018
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'MIXTURE OF 50', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'', u'brand': u"INSUMANS''S OPTISET", u'strength_3': u'', u'company': u'Sanofi Aventis', u'unit': u'% NEUTRAL &50'}

-- line #22019
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'', u'brand': u"INSUMANS''S RAPID OPTISET", u'strength_3': u'', u'company': u'Sanofi Aventis', u'unit': u''}

-- line #22020
-- ignoring line: field [strength_1] not numeric: >>>40IU.MIX. OF 50<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40IU.MIX. OF 50', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'V', u'brand': u'INSUMAN', u'strength_3': u'', u'company': u'Sanofi Aventis', u'unit': u'% NEUTRAL &50'}

-- line #22021
-- ignoring line: field [strength_1] not numeric: >>>MIXTURE OF 25<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'MIXTURE OF 25', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'V', u'brand': u'INSUMAN', u'strength_3': u'', u'company': u'Sanofi Aventis', u'unit': u'% NEUTRAL &75'}

-- line #22022
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100IU', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'', u'brand': u'LANTUS OPTISETS', u'strength_3': u'', u'company': u'Sanofi Aventis', u'unit': u''}

-- line #22023
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'300IU.', u'strength_2': u'ML INSULIN GLARGINE', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'', u'brand': u'LANTUS OPTISETS', u'strength_3': u'', u'company': u'Sanofi Aventis', u'unit': u''}

-- line #22024
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'GLARGINE(MONOCOMPONENT HUMAN INSULIN)', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'SOLOSTAR IU/ML INSULINE', u'brand': u'LANTUS', u'strength_3': u'', u'company': u'Aventis', u'unit': u''}

-- line #22025
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100IU.', u'strength_2': u'ML INSULIN GLARGINE', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'V', u'brand': u'LANTUS', u'strength_3': u'', u'company': u'Sanofi Aventis', u'unit': u''}

-- line #22026
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'401U', u'strength_2': u'ML', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'LENTARD-40', u'strength_3': u'', u'company': u'Novo Nordisk', u'unit': u''}

-- line #22027
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'400IU.', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'V', u'brand': u'LENTISULIN CPI', u'strength_3': u'', u'company': u'Cadila Ph.', u'unit': u''}

-- line #22028
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40IU', u'strength_2': u'ML(PORK INSULIN)', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'LENTISULIN HPI', u'strength_3': u'', u'company': u'Cadila', u'unit': u''}

-- line #22029
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'400IU.', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'LENTSULIN HPI', u'strength_3': u'', u'company': u'Cadila', u'unit': u''}

-- line #22030
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'HUMAN INSULIN(RDNA ORIGIN)USP 40IU.(30', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'', u'brand': u'LUPISULIN-M INS', u'strength_3': u'', u'company': u'Lupin', u'unit': u'%REGULAR INS. HUMAN NEUTRAL & 70& ISOPHANE INS.'}

-- line #22031
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'HUMAN INSULIN(RDNA ORIGIN)USP 40IU.(50', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'', u'brand': u'LUPISULIN-M INS', u'strength_3': u'', u'company': u'Lupin', u'unit': u'%REGULAR INS. HUMAN NEUTRAL & 50& ISOPHANE INS.'}

-- line #22032
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'HUMAN INSULIN(RDNA ORIGIN)USP 40IU.', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'', u'brand': u'LUPISULIN-N INS', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #22033
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'', u'brand': u'LUPISULIN PEN', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #22034
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'HUMAN INSULIN(RDNA ORIGIN)USP 40IU.', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'', u'brand': u'LUPISULIN-R INS', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #22035
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100IU.', u'strength_2': u'ML HUMAN MONOCOMOPONENT', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'', u'brand': u'MIXTARD HM PENFILL', u'strength_3': u'', u'company': u'Novo Nordisk', u'unit': u''}

-- line #22036
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100IU.PREMIXED BIPHASIC INSULIN', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'', u'brand': u'MIXTARD HM PENFILL', u'strength_3': u'', u'company': u'Novo Nordisk', u'unit': u''}

-- line #22037
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100IU', u'strength_2': u'ML', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'', u'brand': u'MIXTARD NOVOLET', u'strength_3': u'', u'company': u'Novo Nordisk', u'unit': u''}

-- line #22038
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'INSULINE', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'', u'brand': u'MIXTARD NOVOLET', u'strength_3': u'', u'company': u'Novo Nordisk', u'unit': u''}

-- line #22039
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'', u'brand': u'MIXTARD NOVOLET', u'strength_3': u'', u'company': u'Novo Nordisk', u'unit': u''}

-- line #22040
-- ignoring line: field [strength_1] not numeric: >>>40IU.30<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40IU.30', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'V', u'brand': u'MIXULIN HPI', u'strength_3': u'', u'company': u'Cadila Ph.', u'unit': u'%SOLUBLE INS&70'}

-- line #22041
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100IU.', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'V', u'brand': u'MIXULIN', u'strength_3': u'', u'company': u'Cadila Ph.', u'unit': u''}

-- line #22042
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'300U', u'strength_2': u'FLEXPEN', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'', u'brand': u'NOVOMIX FLEXPEN', u'strength_3': u'', u'company': u'Novo Nordisk', u'unit': u''}

-- line #22043
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'PREMIX ANALOQUE INSULIN ASPART (300IU. OF 30', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'', u'brand': u'NOVOMIX PENFILL', u'strength_3': u'', u'company': u'Novo Nordisk', u'unit': u'%)+(70'}

-- line #22044
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'300U', u'strength_2': u'FLEXPEN', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'', u'brand': u'NOVORAPID FLEXPEN', u'strength_3': u'', u'company': u'Novo Nordisk', u'unit': u''}

-- line #22045
-- ignoring line: field [strength_1] not numeric: >>>100U AS (3.5<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100U AS (3.5', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'NOVO RAPID IU', u'strength_3': u'', u'company': u'Novo Nordisk', u'unit': u'mg) INSULIN AS PART'}

-- line #22046
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'RAPID ACTING ANALOGUE INSULIN 300IU.', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'', u'brand': u'NOVORAPID PENFILL', u'strength_3': u'', u'company': u'Abbott', u'unit': u''}

-- line #22047
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'HUMAN INSULIN 14.44', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'', u'brand': u'ORAL RECOSULIN', u'strength_3': u'', u'company': u'Shreya', u'unit': u'mg SUSPENDED IN HFA 134 AN INERT AEROSOL PROPELLENT)'}

-- line #22048
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'PURIFIED PORCINE INSULIN', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'VIAL', u'brand': u'PORCINE MIXACT', u'strength_3': u'', u'company': u'U S V', u'unit': u''}

-- line #22049
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'PURIFIED PORCINE INSULIN', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'VIAL', u'brand': u'PROCINE-FASTACT', u'strength_3': u'', u'company': u'U S V', u'unit': u''}

-- line #22050
-- ignoring line: field [strength_1] not numeric: >>>M-CRESOL 0.16<<<
-- {u'list_of_values_of_unknown_fields': [u'PHENOL -.0065 ', u' %)', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'M-CRESOL 0.16', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'VIAL', u'brand': u'PRODICA', u'strength_3': u'', u'company': u'Nicholas', u'unit': u'%'}

-- line #22051
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'HIGHLY PURIFIED PORCINE PREMIXED BIPHASIC INSULIN 40IU.', u'strength_2': u'ML', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'RAPIMIX', u'strength_3': u'', u'company': u'Nicholas', u'unit': u''}

-- line #22052
-- ignoring line: field [strength_1] not numeric: >>>400IU.<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'400IU.', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'RAPISULIN-CPI', u'strength_3': u'', u'company': u'CADILA', u'unit': u'PORCINE INSULIN (CHROMATOGRAPHICALLY PURIFIED)'}

-- line #22053
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'400IU.(PORCINE INS.)', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'RAPISULIN HPI', u'strength_3': u'', u'company': u'Cadila', u'unit': u''}

-- line #22054
-- ignoring line: field [strength_1] not numeric: >>>NEUTRAL INSULIN SOLUBLE 40IU.<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'NEUTRAL INSULIN SOLUBLE 40IU.', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'RAPISULIN HPI', u'strength_3': u'', u'company': u'Cadila', u'unit': u'METHYLPARABEN 1'}

-- line #22055
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'30', u'strength_2': u'70 OF INSULIN HUMAN PH EUR', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'', u'brand': u'RECOSULIN-M CARTRIDGE', u'strength_3': u'', u'company': u'Shreya', u'unit': u'100IU ISOPHANE INS. (+ PRES.)'}

-- line #22056
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50', u'strength_2': u'50 OF INSULIN HUMAN PH EUR', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'', u'brand': u'RECOSULIN-M CARTRIDGE', u'strength_3': u'', u'company': u'Shreya', u'unit': u'100IU ISOPHANE INS. (+ PRES.)'}

-- line #22057
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100IU(+ PRES.) (HUMAN INSULIN PH EUR)', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'', u'brand': u'RECOSULIN-N CARTRIDGE', u'strength_3': u'', u'company': u'Shreya', u'unit': u''}

-- line #22058
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100IU+3', u'strength_2': u'', u'substance': u'Neutral Insulin/Isophane Insulin/Lente Insulin/Extended Insulin Zinc Sus./Premixed Biphasic Insulin', u'always_empty': u'', u'form': u'', u'brand': u'RECOSULIN-R CARTRIDGE', u'strength_3': u'', u'company': u'Shreya', u'unit': u'mg M-CRESOL PRES. (HUMAN INSULIN PH EUR)'}

-- line #22059
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEVACARE 200 (CHEMO HC.)',
	'Nevirapine',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEVACARE 200 (CHEMO HC.)'
);

-- line #22060
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEVE 200 (Le Sante)',
	'Nevirapine',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEVE 200 (Le Sante)'
);

-- line #22061
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEVIHOPE 200 (Macleods)',
	'Nevirapine',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEVIHOPE 200 (Macleods)'
);

-- line #22062
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEVIMUNE 100 (Cipla)',
	'Nevirapine',
	'ORAL SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEVIMUNE 100 (Cipla)'
);

-- line #22063
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEVIMUNE 200 (Cipla)',
	'Nevirapine',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEVIMUNE 200 (Cipla)'
);

-- line #22064
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEVIPAN 200 (Croslands)',
	'Nevirapine',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEVIPAN 200 (Croslands)'
);

-- line #22065
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEVIRETRO 200 (Cytomed(Alkem))',
	'Nevirapine',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEVIRETRO 200 (Cytomed(Alkem))'
);

-- line #22066
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEVIREX 200 (Aurobindo)',
	'Nevirapine',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEVIREX 200 (Aurobindo)'
);

-- line #22067
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEVIR 200 (Emcure)',
	'Nevirapine',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEVIR 200 (Emcure)'
);

-- line #22068
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEVIR 200 (Sain Med.)',
	'Nevirapine',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEVIR 200 (Sain Med.)'
);

-- line #22069
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEVIVIR 200 (HETERO HC)',
	'Nevirapine',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEVIVIR 200 (HETERO HC)'
);

-- line #22070
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEVIVIR 10 (HETERO HC)',
	'Nevirapine',
	'SOL',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEVIVIR 10 (HETERO HC)'
);

-- line #22071
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'NEWPRL', u'strength_2': u'', u'substance': u'NEWPRL', u'always_empty': u'', u'form': u'', u'brand': u'NEWPRL', u'strength_3': u'', u'company': u'NEWPRL', u'unit': u''}

-- line #22072
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'3-METIC', u'strength_3': u'', u'company': u'Bsp Ph.', u'unit': u''}

-- line #22073
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'3-PHASE', u'strength_3': u'', u'company': u'Dahlia Ph.', u'unit': u''}

-- line #22074
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB.', u'brand': u'3P', u'strength_3': u'', u'company': u'Kirti Works', u'unit': u''}

-- line #22075
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'COUGH SYR', u'brand': u'3-P T', u'strength_3': u'', u'company': u'Kirti Works', u'unit': u''}

-- line #22076
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'3TONE-TC', u'strength_3': u'', u'company': u'Embiotic Lab.', u'unit': u''}

-- line #22077
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'4 BONES', u'strength_3': u'', u'company': u'Universal', u'unit': u''}

-- line #22078
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'4-QUINO 250', u'strength_3': u'', u'company': u'Ambrosia', u'unit': u''}

-- line #22079
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'4-QUINO 500', u'strength_3': u'', u'company': u'Ambrosia', u'unit': u''}

-- line #22080
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'5% H.ALBUMIN (ISOTONIC)', u'strength_3': u'', u'company': u'Paviour Ph.', u'unit': u''}

-- line #22081
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'625 CLAV CARE', u'strength_3': u'', u'company': u'Ozone Ph.', u'unit': u''}

-- line #22082
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'7-ASE', u'strength_3': u'', u'company': u'Excel Ph.', u'unit': u''}

-- line #22083
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CRM', u'brand': u'7 MULTI EFECT FACE', u'strength_3': u'', u'company': u'OREVA DARMO.', u'unit': u''}

-- line #22084
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SHAMPOO', u'brand': u'8X', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #22085
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'A 2-Z GOLD', u'strength_3': u'', u'company': u'RADHE BIO.', u'unit': u''}

-- line #22086
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'A 2-Z GOLD', u'strength_3': u'', u'company': u'RADHE BIO.', u'unit': u''}

-- line #22087
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'A4U', u'strength_3': u'', u'company': u'Remedies', u'unit': u''}

-- line #22088
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'AA-HA', u'strength_3': u'', u'company': u'Leo Life', u'unit': u''}

-- line #22089
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'AA-HA', u'strength_3': u'', u'company': u'Leo Life', u'unit': u''}

-- line #22090
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'AAMEE-1', u'strength_3': u'', u'company': u'Bioplasma', u'unit': u''}

-- line #22091
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'VATI', u'brand': u'AAM PACHAN', u'strength_3': u'', u'company': u'NARNARAYAN', u'unit': u''}

-- line #22092
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'VATI', u'brand': u'AASHOGHNI', u'strength_3': u'', u'company': u'NARNARAYAN', u'unit': u''}

-- line #22093
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'A-ASHVINIKUMAR RAS', u'strength_3': u'', u'company': u'SHREE BAIDYA.', u'unit': u''}

-- line #22094
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'DPS', u'brand': u'ABDEC', u'strength_3': u'', u'company': u'Pfizer', u'unit': u''}

-- line #22095
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'F. DPS', u'brand': u'ABDEC', u'strength_3': u'', u'company': u'Pfizer', u'unit': u''}

-- line #22096
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'ABDEC', u'strength_3': u'', u'company': u'Pfizer', u'unit': u''}

-- line #22097
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'A-BEC', u'strength_3': u'', u'company': u'Emcure', u'unit': u''}

-- line #22098
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'ABHA', u'strength_3': u'', u'company': u'Vital Care', u'unit': u''}

-- line #22099
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ABHAYADI MODAK', u'strength_3': u'', u'company': u'ZANDU', u'unit': u''}

-- line #22100
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'ABHAYARISHTA', u'strength_3': u'', u'company': u'DABUR INDIA', u'unit': u''}

-- line #22101
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'ABHAYARISHTA', u'strength_3': u'', u'company': u'SANDU BRO.', u'unit': u''}

-- line #22102
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'ABHAYARISHTA', u'strength_3': u'', u'company': u'SHREE BAIDYA.', u'unit': u''}

-- line #22103
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ABHAYASAN', u'strength_3': u'', u'company': u'ZANDU', u'unit': u''}

-- line #22104
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'ABHRAK BHASMA (SHASTRAPUTI)', u'strength_3': u'', u'company': u'SHREE BAIDYA.', u'unit': u''}

-- line #22105
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'ABHRAK BHASMA (SHATPUTI)', u'strength_3': u'', u'company': u'SHREE BAIDYA.', u'unit': u''}

-- line #22106
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'ABHRAK BHASMA', u'strength_3': u'', u'company': u'SHREE BAIDYA.', u'unit': u''}

-- line #22107
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ABHRAK BHASMA', u'strength_3': u'', u'company': u'ZANDU', u'unit': u''}

-- line #22108
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'ABHYARISHTA', u'strength_3': u'', u'company': u'ZANDU', u'unit': u''}

-- line #22109
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ABID 250/500', u'strength_3': u'', u'company': u'Bharat Ph.', u'unit': u''}

-- line #22110
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP/SYR', u'brand': u'ABIPHOS', u'strength_3': u'', u'company': u'Shinto Org.', u'unit': u''}

-- line #22111
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'ABL', u'strength_3': u'', u'company': u'Malar Hc.', u'unit': u''}

-- line #22112
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ABROVIT CAL', u'strength_3': u'', u'company': u'Arbro Ph.', u'unit': u''}

-- line #22113
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ABROZYME MPS', u'strength_3': u'', u'company': u'Arbro Ph.', u'unit': u''}

-- line #22114
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'ABSOLUT 3G', u'strength_3': u'', u'company': u'Pharmed', u'unit': u''}

-- line #22115
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'ABSOLUT', u'strength_3': u'', u'company': u'Pharmed', u'unit': u''}

-- line #22116
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'ABSOLUT', u'strength_3': u'', u'company': u'Pharmed', u'unit': u''}

-- line #22117
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'AC 25', u'strength_3': u'', u'company': u'U S V', u'unit': u''}

-- line #22118
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'AC 50', u'strength_3': u'', u'company': u'U S V', u'unit': u''}

-- line #22119
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'ACAMPROL', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #22120
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'A-C ARE', u'strength_3': u'', u'company': u'AAN PHARMA', u'unit': u''}

-- line #22121
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TABS.', u'brand': u'A CARE', u'strength_3': u'', u'company': u'AAN PH.', u'unit': u''}

-- line #22122
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SOAP', u'brand': u'ACBAR', u'strength_3': u'', u'company': u'HERBOTICS', u'unit': u''}

-- line #22123
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ACCEMOL', u'strength_3': u'', u'company': u'Geno Ph.', u'unit': u''}

-- line #22124
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SOAP', u'brand': u'ACCLEAN', u'strength_3': u'', u'company': u'SIFAM PH.', u'unit': u''}

-- line #22125
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CRM', u'brand': u'ACCUFIX DENTURE', u'strength_3': u'', u'company': u'APPLEDENT ORAL', u'unit': u''}

-- line #22126
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'INJ', u'brand': u'ACCUZON PLUS 1.5', u'strength_3': u'', u'company': u'Macleods', u'unit': u''}

-- line #22127
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'INJ', u'brand': u'ACCUZON PLUS 375', u'strength_3': u'', u'company': u'Macleods', u'unit': u''}

-- line #22128
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'INJ', u'brand': u'ACCUZON PLUS 750', u'strength_3': u'', u'company': u'Macleods', u'unit': u''}

-- line #22129
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SOL. A', u'brand': u'ACD', u'strength_3': u'', u'company': u'Mount M.', u'unit': u''}

-- line #22130
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'ACDT', u'strength_3': u'', u'company': u'NIVCA', u'unit': u''}

-- line #22131
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'ACECITRON', u'strength_3': u'', u'company': u'ACE LAB.', u'unit': u''}

-- line #22132
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ACECLOACE-P', u'strength_3': u'', u'company': u'Parenteral', u'unit': u''}

-- line #22133
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ACECLOACE', u'strength_3': u'', u'company': u'Parenteral', u'unit': u''}

-- line #22134
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'DT/500 TAB', u'brand': u'ACEFAD 250', u'strength_3': u'', u'company': u'Redical', u'unit': u''}

-- line #22135
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYRUP', u'brand': u'ACEFER', u'strength_3': u'', u'company': u'ACE LAB.', u'unit': u''}

-- line #22136
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'F.', u'brand': u'ACEFULVIN', u'strength_3': u'', u'company': u'ACE LAB.', u'unit': u''}

-- line #22137
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'GEL SUS', u'brand': u'ACE', u'strength_3': u'', u'company': u'ACE LAB.', u'unit': u''}

-- line #22138
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'EXP.', u'brand': u'ACEHIST', u'strength_3': u'', u'company': u'ACE LAB.', u'unit': u''}

-- line #22139
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ACEJET-P', u'strength_3': u'', u'company': u'Themis Med.', u'unit': u''}

-- line #22140
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ACEJET', u'strength_3': u'', u'company': u'Themis Med.', u'unit': u''}

-- line #22141
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ACELIDE', u'strength_3': u'', u'company': u'Kapeetus', u'unit': u''}

-- line #22142
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'GEL', u'brand': u'ACELIFE', u'strength_3': u'', u'company': u'Leo Life', u'unit': u''}

-- line #22143
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'MR TAB', u'brand': u'ACELIFE', u'strength_3': u'', u'company': u'Leo Life', u'unit': u''}

-- line #22144
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ACELIFE PLUS', u'strength_3': u'', u'company': u'Leo Life', u'unit': u''}

-- line #22145
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ACELIFE', u'strength_3': u'', u'company': u'Leo Life', u'unit': u''}

-- line #22146
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'MR TAB', u'brand': u'ACELON', u'strength_3': u'', u'company': u'ACE LAB.', u'unit': u''}

-- line #22147
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TABS.', u'brand': u'ACEMETH', u'strength_3': u'', u'company': u'STAR PH.', u'unit': u''}

-- line #22148
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'GEL', u'brand': u'ACENAC', u'strength_3': u'', u'company': u'Medley', u'unit': u''}

-- line #22149
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SR TAB', u'brand': u'ACENAC', u'strength_3': u'', u'company': u'Medley', u'unit': u''}

-- line #22150
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ACEPAD', u'strength_3': u'', u'company': u'Tripada', u'unit': u''}

-- line #22151
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'ACEPLEX', u'strength_3': u'', u'company': u'ACE LAB.', u'unit': u''}

-- line #22152
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'ACEPRED 40MG', u'strength_3': u'', u'company': u'German R.', u'unit': u''}

-- line #22153
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'ACEPRED 80MG', u'strength_3': u'', u'company': u'German R.', u'unit': u''}

-- line #22154
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SOL', u'brand': u'ACEPTIK', u'strength_3': u'', u'company': u'RAMAN & WEIL', u'unit': u''}

-- line #22155
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'ACERON 12', u'strength_3': u'', u'company': u'ACE LAB.', u'unit': u''}

-- line #22156
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'LIQ', u'brand': u'ACERON 12', u'strength_3': u'', u'company': u'ACE LAB.', u'unit': u''}

-- line #22157
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ACERON PLUS', u'strength_3': u'', u'company': u'Cfl Ph.', u'unit': u''}

-- line #22158
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ACERON SP', u'strength_3': u'', u'company': u'Cfl Ph.', u'unit': u''}

-- line #22159
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ACERON', u'strength_3': u'', u'company': u'Cfl Ph.', u'unit': u''}

-- line #22160
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'INJ', u'brand': u'ACETAM', u'strength_3': u'', u'company': u'Monokem', u'unit': u''}

-- line #22161
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'ACETAM', u'strength_3': u'', u'company': u'ACE LAB.', u'unit': u''}

-- line #22162
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ACETHROMB 2', u'strength_3': u'', u'company': u'Suvik Hit.', u'unit': u''}

-- line #22163
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ACETHROMB 4', u'strength_3': u'', u'company': u'Suvik Hit.', u'unit': u''}

-- line #22164
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'ACETRIM', u'strength_3': u'', u'company': u'ACE LAB.', u'unit': u''}

-- line #22165
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'ACEVITA', u'strength_3': u'', u'company': u'ACE LAB.', u'unit': u''}

-- line #22166
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'LIQ', u'brand': u'ACEVITA', u'strength_3': u'', u'company': u'ACE LAB.', u'unit': u''}

-- line #22167
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'ACEVIT', u'strength_3': u'', u'company': u'Unimax Lab', u'unit': u''}

-- line #22168
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'LIQ', u'brand': u'ACEZYME', u'strength_3': u'', u'company': u'ACE LAB.', u'unit': u''}

-- line #22169
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ACFAST DPM', u'strength_3': u'', u'company': u'Kim Lab', u'unit': u''}

-- line #22170
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'GEL', u'brand': u'ACICAINE', u'strength_3': u'', u'company': u'Votary Lab', u'unit': u''}

-- line #22171
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'DPS', u'brand': u'ACICON', u'strength_3': u'', u'company': u'BACTOLAC', u'unit': u''}

-- line #22172
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB.', u'brand': u'ACIDINOL', u'strength_3': u'', u'company': u'Ban Lab', u'unit': u''}

-- line #22173
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'GEL', u'brand': u'ACIDOM-O', u'strength_3': u'', u'company': u'Hema Lab.', u'unit': u''}

-- line #22174
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ACIFIX FRUIT', u'strength_3': u'', u'company': u'Dial Ph.', u'unit': u''}

-- line #22175
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ACIFLO', u'strength_3': u'', u'company': u'Sunrise Ph.', u'unit': u''}

-- line #22176
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SUS', u'brand': u'ACIGON', u'strength_3': u'', u'company': u'Nicholas', u'unit': u''}

-- line #22177
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ACIGON', u'strength_3': u'', u'company': u'Nicholas', u'unit': u''}

-- line #22178
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ACILANS', u'strength_3': u'', u'company': u'Atrimed Ph.', u'unit': u''}

-- line #22179
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ACIMET', u'strength_3': u'', u'company': u'Trio Rem.', u'unit': u''}

-- line #22180
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ACIPAN 200/400', u'strength_3': u'', u'company': u'Panzer Ph.', u'unit': u''}

-- line #22181
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ACIPAN 800', u'strength_3': u'', u'company': u'Panzer Ph.', u'unit': u''}

-- line #22182
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ACIPANT 40', u'strength_3': u'', u'company': u'Bsp Ph.', u'unit': u''}

-- line #22183
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'DM TAB', u'brand': u'ACIPANT', u'strength_3': u'', u'company': u'Bsp Ph.', u'unit': u''}

-- line #22184
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'ACIPRAZ', u'strength_3': u'', u'company': u'Kapeetus', u'unit': u''}

-- line #22185
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'ACIPRAZ-D', u'strength_3': u'', u'company': u'Kapeetus', u'unit': u''}

-- line #22186
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'ACIREST', u'strength_3': u'', u'company': u'Surge Bio.', u'unit': u''}

-- line #22187
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'ACIREST-D', u'strength_3': u'', u'company': u'Surge Bio.', u'unit': u''}

-- line #22188
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'ACITRIN 10', u'strength_3': u'', u'company': u'Ipca', u'unit': u''}

-- line #22189
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'ACITRIN 25', u'strength_3': u'', u'company': u'Ipca', u'unit': u''}

-- line #22190
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ACIVOM', u'strength_3': u'', u'company': u'Sanjivani', u'unit': u''}

-- line #22191
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'GEL', u'brand': u'ACIZ', u'strength_3': u'', u'company': u'Ritz Ph.', u'unit': u''}

-- line #22192
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TOPICAL/CAP', u'brand': u'ACLEAR', u'strength_3': u'', u'company': u'Atrimed Ph.', u'unit': u''}

-- line #22193
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'GEL', u'brand': u'ACLIN', u'strength_3': u'', u'company': u'Albatross', u'unit': u''}

-- line #22194
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAPS', u'brand': u'ACLOX', u'strength_3': u'', u'company': u'ACE LAB.', u'unit': u''}

-- line #22195
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'ACLOX', u'strength_3': u'', u'company': u'ACE LAB.', u'unit': u''}

-- line #22196
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TABS.', u'brand': u'ACLOZ-P', u'strength_3': u'', u'company': u'KRUN & K.', u'unit': u''}

-- line #22197
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'ACMED FACE WASH', u'strength_3': u'', u'company': u'Ethicare', u'unit': u''}

-- line #22198
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'POUCH', u'brand': u'ACMED', u'strength_3': u'', u'company': u'Ethicare', u'unit': u''}

-- line #22199
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'ACNEDERM', u'strength_3': u'', u'company': u'UNIQ HERBAL', u'unit': u''}

-- line #22200
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SOAP/GEL', u'brand': u'ACNEGUARD', u'strength_3': u'', u'company': u'Pil', u'unit': u''}

-- line #22201
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'LOT', u'brand': u'ACNEMYCIN', u'strength_3': u'', u'company': u'Parry Ph.', u'unit': u''}

-- line #22202
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'OINT.', u'brand': u'ACNEMYCIN', u'strength_3': u'', u'company': u'Parry Ph.', u'unit': u''}

-- line #22203
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CRM', u'brand': u'ACNEQUIT', u'strength_3': u'', u'company': u'Parry Ph.', u'unit': u''}

-- line #22204
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'GEL', u'brand': u'ACNESOL-5', u'strength_3': u'', u'company': u'Parry Ph.', u'unit': u''}

-- line #22205
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SOAP', u'brand': u'ACNESTAL', u'strength_3': u'', u'company': u'BIOMEDICA', u'unit': u''}

-- line #22206
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAPS.', u'brand': u'ACNIDERM', u'strength_3': u'', u'company': u'UNIQ HERBAL', u'unit': u''}

-- line #22207
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'GEL', u'brand': u'ACNO', u'strength_3': u'', u'company': u'Ajanta Ph.', u'unit': u''}

-- line #22208
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'ACNOVIN', u'strength_3': u'', u'company': u'Vasu Ph.', u'unit': u''}

-- line #22209
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CRM', u'brand': u'ACNOVIN', u'strength_3': u'', u'company': u'Ban Lab', u'unit': u''}

-- line #22210
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CRM', u'brand': u'ACNOVIN', u'strength_3': u'', u'company': u'Vasu Ph.', u'unit': u''}

-- line #22211
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB.', u'brand': u'ACNOVIN', u'strength_3': u'', u'company': u'Ban Lab', u'unit': u''}

-- line #22212
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SOAP', u'brand': u'ACNO-X', u'strength_3': u'', u'company': u'AESTHETIX', u'unit': u''}

-- line #22213
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ACOVIT-M', u'strength_3': u'', u'company': u'Chemo Bio.', u'unit': u''}

-- line #22214
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'D.SYR', u'brand': u'ACROCEF', u'strength_3': u'', u'company': u'ACRON PH.', u'unit': u''}

-- line #22215
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'DT', u'brand': u'ACROTEX 50', u'strength_3': u'', u'company': u'Acron Ph.', u'unit': u''}

-- line #22216
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'ACTEVA', u'strength_3': u'', u'company': u'PULSE', u'unit': u''}

-- line #22217
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'DM CAP', u'brand': u'ACTEVA', u'strength_3': u'', u'company': u'PULSE', u'unit': u''}

-- line #22218
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ACTICOLD', u'strength_3': u'', u'company': u'Pharmed', u'unit': u''}

-- line #22219
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ACTIFLEX', u'strength_3': u'', u'company': u'Tanishq', u'unit': u''}

-- line #22220
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'ACTIGUT', u'strength_3': u'', u'company': u'Alembic', u'unit': u''}

-- line #22221
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SAC.', u'brand': u'ACTIGUT', u'strength_3': u'', u'company': u'Alembic', u'unit': u''}

-- line #22222
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'ACTILAC', u'strength_3': u'', u'company': u'Embiotic Lab.', u'unit': u''}

-- line #22223
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ACTILIFE', u'strength_3': u'', u'company': u'Apex Labs.', u'unit': u''}

-- line #22224
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR/TAB', u'brand': u'ACTIN', u'strength_3': u'', u'company': u'Serve Ph.', u'unit': u''}

-- line #22225
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP/LIQ.', u'brand': u'ACTIONER', u'strength_3': u'', u'company': u'Nexus', u'unit': u''}

-- line #22226
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'POW', u'brand': u'ACTIPRO', u'strength_3': u'', u'company': u'Aristo', u'unit': u''}

-- line #22227
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'POW.', u'brand': u'ACTIPRO', u'strength_3': u'', u'company': u'Embiotic Lab.', u'unit': u''}

-- line #22228
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'ACTIPRO', u'strength_3': u'', u'company': u'Active Hc.', u'unit': u''}

-- line #22229
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ACTIURT', u'strength_3': u'', u'company': u'Zoetic Ayur.', u'unit': u''}

-- line #22230
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'POW', u'brand': u'ACTIVE 25', u'strength_3': u'', u'company': u'Dalmia Ind.', u'unit': u''}

-- line #22231
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'PWD', u'brand': u'ACTIVE ENERGY', u'strength_3': u'', u'company': u'Active Hc.', u'unit': u''}

-- line #22232
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'ACTOL CAKE', u'strength_3': u'', u'company': u'Interpharm', u'unit': u''}

-- line #22233
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ACTROTAC 10/25', u'strength_3': u'', u'company': u'Ranbaxy', u'unit': u''}

-- line #22234
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'INJ', u'brand': u'ACUCORT 100', u'strength_3': u'', u'company': u'Macleods', u'unit': u''}

-- line #22235
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'INJ', u'brand': u'ACUCORT 250', u'strength_3': u'', u'company': u'Macleods', u'unit': u''}

-- line #22236
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'INJ', u'brand': u'ACUCORT 500', u'strength_3': u'', u'company': u'Macleods', u'unit': u''}

-- line #22237
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'LS EYE DPS', u'brand': u'ACULAR', u'strength_3': u'', u'company': u'Allergan', u'unit': u''}

-- line #22238
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CRM', u'brand': u'ACURA', u'strength_3': u'', u'company': u'Croslands', u'unit': u''}

-- line #22239
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'ACUTRIL', u'strength_3': u'', u'company': u'Skymax', u'unit': u''}

-- line #22240
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SAC.', u'brand': u'ACUTRIL', u'strength_3': u'', u'company': u'Skymax', u'unit': u''}

-- line #22241
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ACVINAC-P', u'strength_3': u'', u'company': u'NIVCA', u'unit': u''}

-- line #22242
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ACXIM 200', u'strength_3': u'', u'company': u'APPLEDENT ORAL', u'unit': u''}

-- line #22243
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SOAP', u'brand': u'ACZEE ANTI ACNE', u'strength_3': u'', u'company': u'OREVA DARMO.', u'unit': u''}

-- line #22244
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'LOT', u'brand': u'ACZEE ANTI PRURITIC', u'strength_3': u'', u'company': u'OREVA DARMO.', u'unit': u''}

-- line #22245
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'LOT', u'brand': u'ACZEE CLEAR SKIN', u'strength_3': u'', u'company': u'OREVA DARMO.', u'unit': u''}

-- line #22246
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'LOT', u'brand': u'ACZEE NON DRYING CLEANSING', u'strength_3': u'', u'company': u'OREVA DARMO.', u'unit': u''}

-- line #22247
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'ACZEE SCALP CLEANSER', u'strength_3': u'', u'company': u'OREVA DARMO.', u'unit': u''}

-- line #22248
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SOAP', u'brand': u'ACZEE SCRUB', u'strength_3': u'', u'company': u'OREVA DARMO.', u'unit': u''}

-- line #22249
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'GEL', u'brand': u'ADACLENE', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #22250
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ADBET', u'strength_3': u'', u'company': u'ADISON PH.', u'unit': u''}

-- line #22251
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'ADCAL', u'strength_3': u'', u'company': u'Admac Ph.', u'unit': u''}

-- line #22252
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ADCAPONE', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #22253
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'DT', u'brand': u'ADCEF', u'strength_3': u'', u'company': u'Torrent', u'unit': u''}

-- line #22254
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CF CAP', u'brand': u'ADCOB', u'strength_3': u'', u'company': u'Kinedex Hc.', u'unit': u''}

-- line #22255
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ADCOB-FM', u'strength_3': u'', u'company': u'Kinedex Hc.', u'unit': u''}

-- line #22256
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ADCOB', u'strength_3': u'', u'company': u'Kinedex Hc.', u'unit': u''}

-- line #22257
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ADDFIX-100', u'strength_3': u'', u'company': u'ADDPLUS', u'unit': u''}

-- line #22258
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ADDFLOX-500', u'strength_3': u'', u'company': u'ADDPLUS', u'unit': u''}

-- line #22259
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'ADD - FRESH TEAR', u'strength_3': u'', u'company': u'ADVENTUS', u'unit': u''}

-- line #22260
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'INJ', u'brand': u'ADDTHER', u'strength_3': u'', u'company': u'ADDPLUS', u'unit': u''}

-- line #22261
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'ADENOCOBAL', u'strength_3': u'', u'company': u'Heal All Ph.', u'unit': u''}

-- line #22262
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ADENO COBAL', u'strength_3': u'', u'company': u'Heal All Ph.', u'unit': u''}

-- line #22263
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'ADENOFER', u'strength_3': u'', u'company': u'Fourrts', u'unit': u''}

-- line #22264
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'FOAMING GEL', u'brand': u'ADERMA', u'strength_3': u'', u'company': u'Piramal Hc.', u'unit': u''}

-- line #22265
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'ADEX-P', u'strength_3': u'', u'company': u'ZION HC.', u'unit': u''}

-- line #22266
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAPE 10CM*4.5M', u'brand': u'ADHESIA', u'strength_3': u'', u'company': u'Stancare', u'unit': u''}

-- line #22267
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAPE 1.25CM*1M', u'brand': u'ADHESIA', u'strength_3': u'', u'company': u'Stancare', u'unit': u''}

-- line #22268
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAPE 1.25CM*4.5M', u'brand': u'ADHESIA', u'strength_3': u'', u'company': u'Stancare', u'unit': u''}

-- line #22269
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'F. TAB', u'brand': u'ADICE', u'strength_3': u'', u'company': u'ADISON PH.', u'unit': u''}

-- line #22270
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'LB CAP', u'brand': u'ADICLOX', u'strength_3': u'', u'company': u'ADISON PH.', u'unit': u''}

-- line #22271
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'ADICOFF', u'strength_3': u'', u'company': u'ADMIT', u'unit': u''}

-- line #22272
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ADIFLAM-M', u'strength_3': u'', u'company': u'ADISON PH.', u'unit': u''}

-- line #22273
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ADIFLAM', u'strength_3': u'', u'company': u'ADISON PH.', u'unit': u''}

-- line #22274
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'DPS', u'brand': u'ADIFOL', u'strength_3': u'', u'company': u'ADISON PH.', u'unit': u''}

-- line #22275
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ADILIP 10', u'strength_3': u'', u'company': u'Intas', u'unit': u''}

-- line #22276
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ADILOX 150', u'strength_3': u'', u'company': u'ADISON PH.', u'unit': u''}

-- line #22277
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'OD TAB', u'brand': u'ADILOX', u'strength_3': u'', u'company': u'ADISON PH.', u'unit': u''}

-- line #22278
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'DT / D.SYR', u'brand': u'ADIMOX 250', u'strength_3': u'', u'company': u'ADISON PH.', u'unit': u''}

-- line #22279
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ADINOL 25/50', u'strength_3': u'', u'company': u'ADISON PH.', u'unit': u''}

-- line #22280
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'AM TAB', u'brand': u'ADINOL', u'strength_3': u'', u'company': u'ADISON PH.', u'unit': u''}

-- line #22281
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'ADIS DISP.SYRINGES', u'strength_3': u'', u'company': u'Albert D.', u'unit': u''}

-- line #22282
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ADISPAR 200', u'strength_3': u'', u'company': u'ADISON PH.', u'unit': u''}

-- line #22283
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ADITHRAL 250/500', u'strength_3': u'', u'company': u'ADISON PH.', u'unit': u''}

-- line #22284
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SUS', u'brand': u'ADITHRAL', u'strength_3': u'', u'company': u'ADISON PH.', u'unit': u''}

-- line #22285
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'GEL', u'brand': u'ADITOP-C', u'strength_3': u'', u'company': u'Dermocare', u'unit': u''}

-- line #22286
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'GEL', u'brand': u'ADITOP', u'strength_3': u'', u'company': u'Dermocare', u'unit': u''}

-- line #22287
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'INFUSION SET', u'brand': u'ADIV-1', u'strength_3': u'', u'company': u'Albert D.', u'unit': u''}

-- line #22288
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'INFUSION SET', u'brand': u'ADIV-2', u'strength_3': u'', u'company': u'Albert D.', u'unit': u''}

-- line #22289
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'INFUSION SET', u'brand': u'ADIV-3', u'strength_3': u'', u'company': u'Albert D.', u'unit': u''}

-- line #22290
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u"ADIV-4 BLOOD DONOR''S SET", u'strength_3': u'', u'company': u'Albert D.', u'unit': u''}

-- line #22291
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ADIZONE 15', u'strength_3': u'', u'company': u'Parenteral', u'unit': u''}

-- line #22292
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ADIZONE 30', u'strength_3': u'', u'company': u'Parenteral', u'unit': u''}

-- line #22293
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'MR TAB', u'brand': u'ADIZOX', u'strength_3': u'', u'company': u'ADISON PH.', u'unit': u''}

-- line #22294
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'GEL', u'brand': u'ADJEL MOUTH', u'strength_3': u'', u'company': u'ADMIT', u'unit': u''}

-- line #22295
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'POW', u'brand': u'ADJUST', u'strength_3': u'', u'company': u'Hope Life', u'unit': u''}

-- line #22296
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ADJUST', u'strength_3': u'', u'company': u'Hope Life', u'unit': u''}

-- line #22297
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SUS', u'brand': u'ADLEX', u'strength_3': u'', u'company': u'ADISON PH.', u'unit': u''}

-- line #22298
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'DPS', u'brand': u'ADLIV', u'strength_3': u'', u'company': u'Albert D.', u'unit': u''}

-- line #22299
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'F. CAP', u'brand': u'ADLIV', u'strength_3': u'', u'company': u'Albert D.', u'unit': u''}

-- line #22300
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR.', u'brand': u'ADLIV', u'strength_3': u'', u'company': u'Albert D.', u'unit': u''}

-- line #22301
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ADMENTA 5', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #22302
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ADMICAL', u'strength_3': u'', u'company': u'Austere', u'unit': u''}

-- line #22303
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'OIL', u'brand': u'ADOIL MASSAGE', u'strength_3': u'', u'company': u'Trinicare', u'unit': u''}

-- line #22304
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'DPS', u'brand': u'ADOLATE', u'strength_3': u'', u'company': u'ADISON PH.', u'unit': u''}

-- line #22305
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'ADOLATE PLUS', u'strength_3': u'', u'company': u'ADISON PH.', u'unit': u''}

-- line #22306
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'DT', u'brand': u'ADOXY', u'strength_3': u'', u'company': u'Atopic Lab.', u'unit': u''}

-- line #22307
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'AD-PRED', u'strength_3': u'', u'company': u'ADISON PH.', u'unit': u''}

-- line #22308
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ADPRESS 0.25/0.5', u'strength_3': u'', u'company': u'ADISON PH.', u'unit': u''}

-- line #22309
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'POW', u'brand': u'AD-PRO', u'strength_3': u'', u'company': u'AMMACARE', u'unit': u''}

-- line #22310
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAPS.', u'brand': u'AD-RED', u'strength_3': u'', u'company': u'AMMACARE', u'unit': u''}

-- line #22311
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SG CAP', u'brand': u'ADTROL PLUS', u'strength_3': u'', u'company': u'WANBURY', u'unit': u''}

-- line #22312
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'A-DUGDHA BATI (SAN.)', u'strength_3': u'', u'company': u'SHREE BAIDYA.', u'unit': u''}

-- line #22313
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'A-DUGDHA BATI (SH)', u'strength_3': u'', u'company': u'SHREE BAIDYA.', u'unit': u''}

-- line #22314
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'ADVIT', u'strength_3': u'', u'company': u'Admac Ph.', u'unit': u''}

-- line #22315
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'AEGIS', u'strength_3': u'', u'company': u'ORION BIOTECH.', u'unit': u''}

-- line #22316
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'AERAND BHRUST HARDE CHURNA', u'strength_3': u'', u'company': u'NARNARAYAN', u'unit': u''}

-- line #22317
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'AERAND BHRUST HARDE', u'strength_3': u'', u'company': u'NARNARAYAN', u'unit': u''}

-- line #22318
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'AEROLIFE SPACER', u'strength_3': u'', u'company': u'German R.', u'unit': u''}

-- line #22319
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'AEROLOX-O', u'strength_3': u'', u'company': u'AERODEEP', u'unit': u''}

-- line #22320
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'DP CAP', u'brand': u'AEROVENT', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #22321
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'AEROVENT INH.', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #22322
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'AFDICOMPLEX', u'strength_3': u'', u'company': u'A.F.D.', u'unit': u''}

-- line #22323
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'AFD-MULTIVITAMIN', u'strength_3': u'', u'company': u'A.F.D.', u'unit': u''}

-- line #22324
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'AFFEN PLUS', u'strength_3': u'', u'company': u"Dr.Reddy''S", u'unit': u''}

-- line #22325
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'AFFEN', u'strength_3': u'', u'company': u"Dr.Reddy''S", u'unit': u''}

-- line #22326
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'AFLOX 200MG.TABS.', u'strength_3': u'', u'company': u'ALPS LAB.', u'unit': u''}

-- line #22327
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'AFLOX 400MG.TABS.', u'strength_3': u'', u'company': u'ALPS LAB.', u'unit': u''}

-- line #22328
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAPS.', u'brand': u'AFROVITA', u'strength_3': u'', u'company': u'UNIQ HERBAL', u'unit': u''}

-- line #22329
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'AGASTYA HARITAKI', u'strength_3': u'', u'company': u'SHREE BAIDYA.', u'unit': u''}

-- line #22330
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'AGEWIN', u'strength_3': u'', u'company': u'Medo Chem', u'unit': u''}

-- line #22331
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'AGICOLD', u'strength_3': u'', u'company': u'AGIO PH.', u'unit': u''}

-- line #22332
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'GRAN', u'brand': u'AGLOFIT', u'strength_3': u'', u'company': u'Aglowmed', u'unit': u''}

-- line #22333
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'POW.', u'brand': u'AGLOFIT GROW', u'strength_3': u'', u'company': u'Aglowmed', u'unit': u''}

-- line #22334
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'AGLOX', u'strength_3': u'', u'company': u'AERODEEP', u'unit': u''}

-- line #22335
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYP', u'brand': u'AGLOZYME-C', u'strength_3': u'', u'company': u'Aglowmed', u'unit': u''}

-- line #22336
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'DPS', u'brand': u'AGLOZYME', u'strength_3': u'', u'company': u'Aglowmed', u'unit': u''}

-- line #22337
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'AGNIKUMAR RAS', u'strength_3': u'', u'company': u'SHREE BAIDYA.', u'unit': u''}

-- line #22338
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'AGNIMUKH CHURNA', u'strength_3': u'', u'company': u'SHREE BAIDYA.', u'unit': u''}

-- line #22339
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'AGNISANDEEPAN RAS', u'strength_3': u'', u'company': u'SHREE BAIDYA.', u'unit': u''}

-- line #22340
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'AGNITUNDI RASA', u'strength_3': u'', u'company': u'ZANDU', u'unit': u''}

-- line #22341
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'VATI', u'brand': u'AGNITUNDI', u'strength_3': u'', u'company': u'NARNARAYAN', u'unit': u''}

-- line #22342
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'VATI', u'brand': u'AGNITUNDI', u'strength_3': u'', u'company': u'SHREE BAIDYA.', u'unit': u''}

-- line #22343
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'VATI', u'brand': u'AGNIVARDHAK', u'strength_3': u'', u'company': u'SHREE BAIDYA.', u'unit': u''}

-- line #22344
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'A-GRAHNIKAPAT RAS', u'strength_3': u'', u'company': u'SHREE BAIDYA.', u'unit': u''}

-- line #22345
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'GEL', u'brand': u'AIMSUN', u'strength_3': u'', u'company': u'Sunrise Ph.', u'unit': u''}

-- line #22346
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'AIMSUN PLUS', u'strength_3': u'', u'company': u'Sunrise Ph.', u'unit': u''}

-- line #22347
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'AIMSUN', u'strength_3': u'', u'company': u'Sunrise Ph.', u'unit': u''}

-- line #22348
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'AIRVANT', u'strength_3': u'', u'company': u'BSA PH.', u'unit': u''}

-- line #22349
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'AIR-VENT', u'strength_3': u'', u'company': u'Dial Ph.', u'unit': u''}

-- line #22350
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'AJAMODADI CHURNA', u'strength_3': u'', u'company': u'SANDU BRO.', u'unit': u''}

-- line #22351
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'AJAR', u'strength_3': u'', u'company': u'Concept', u'unit': u''}

-- line #22352
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'VATI', u'brand': u'A-JATIFALADI', u'strength_3': u'', u'company': u'SHREE BAIDYA.', u'unit': u''}

-- line #22353
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'VATI STAMBHAK', u'brand': u'A-JATIFALADI', u'strength_3': u'', u'company': u'SHREE BAIDYA.', u'unit': u''}

-- line #22354
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'AJMODADI CHURNA', u'strength_3': u'', u'company': u'NARNARAYAN', u'unit': u''}

-- line #22355
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'AJMODADI', u'strength_3': u'', u'company': u'NARNARAYAN', u'unit': u''}

-- line #22356
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYP', u'brand': u'AKAMAX', u'strength_3': u'', u'company': u'Overseas Hc.', u'unit': u''}

-- line #22357
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'A-KAMINIVIDRAVAN RAS', u'strength_3': u'', u'company': u'SHREE BAIDYA.', u'unit': u''}

-- line #22358
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'AKIK BHASMA', u'strength_3': u'', u'company': u'SHREE BAIDYA.', u'unit': u''}

-- line #22359
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'AKIK BHASMA', u'strength_3': u'', u'company': u'ZANDU', u'unit': u''}

-- line #22360
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'AKIK PISHTI', u'strength_3': u'', u'company': u'SHREE BAIDYA.', u'unit': u''}

-- line #22361
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'AKMASQ MASK/POUCH', u'strength_3': u'', u'company': u'Ethicare', u'unit': u''}

-- line #22362
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CA', u'brand': u'AKNECIA', u'strength_3': u'', u'company': u'ADMIT', u'unit': u''}

-- line #22363
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CA CRM', u'brand': u'AKNECIN', u'strength_3': u'', u'company': u'AMIDEEP', u'unit': u''}

-- line #22364
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'GEL', u'brand': u'AKNECIN', u'strength_3': u'', u'company': u'ADMIT', u'unit': u''}

-- line #22365
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'GEL', u'brand': u'AKNECIN', u'strength_3': u'', u'company': u'AMIDEEP', u'unit': u''}

-- line #22366
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'OINT', u'brand': u'AKNECIN', u'strength_3': u'', u'company': u'Mitshu', u'unit': u''}

-- line #22367
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'GEL', u'brand': u'AKNI', u'strength_3': u'', u'company': u'Serve Ph.', u'unit': u''}

-- line #22368
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYRUP', u'brand': u'A-KOF', u'strength_3': u'', u'company': u'ACE LAB.', u'unit': u''}

-- line #22369
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB/SYR', u'brand': u"A''KOF", u'strength_3': u'', u'company': u'YASHTRA HEALTH', u'unit': u''}

-- line #22370
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CRM', u'brand': u'AKPRE', u'strength_3': u'', u'company': u'SALVEO LIFE', u'unit': u''}

-- line #22371
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'AKTIVE SY', u'strength_3': u'', u'company': u'Trident Ph.', u'unit': u''}

-- line #22372
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'AL-1.25', u'strength_3': u'', u'company': u'Sunij', u'unit': u''}

-- line #22373
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'AL-2.5/5', u'strength_3': u'', u'company': u'Sunij', u'unit': u''}

-- line #22374
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALAM 0.25', u'strength_3': u'', u'company': u'Tanishq', u'unit': u''}

-- line #22375
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'F. CAP', u'brand': u'ALAMIN', u'strength_3': u'', u'company': u'Albert D.', u'unit': u''}

-- line #22376
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'ALAMIN FEZ', u'strength_3': u'', u'company': u'Albert D.', u'unit': u''}

-- line #22377
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'F. CAP', u'brand': u'ALAMIN-M', u'strength_3': u'', u'company': u'ALBERT DAVID', u'unit': u''}

-- line #22378
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'ALAMIN XTRA', u'strength_3': u'', u'company': u'Albert D.', u'unit': u''}

-- line #22379
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALAM-P', u'strength_3': u'', u'company': u'Tanishq', u'unit': u''}

-- line #22380
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SR 0.5 TAB', u'brand': u'ALAM', u'strength_3': u'', u'company': u'Tanishq', u'unit': u''}

-- line #22381
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SR TAB', u'brand': u'ALAM', u'strength_3': u'', u'company': u'Tanishq', u'unit': u''}

-- line #22382
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'ALA PLUS', u'strength_3': u'', u'company': u'ALEMBIC', u'unit': u''}

-- line #22383
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'AM TAB', u'brand': u'ALASPAN', u'strength_3': u'', u'company': u'Fulford', u'unit': u''}

-- line #22384
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'ALAXY 500MG.CAPS.', u'strength_3': u'', u'company': u'DAK PH.', u'unit': u''}

-- line #22385
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'KID TABS.', u'brand': u'ALAXY', u'strength_3': u'', u'company': u'DAK PH.', u'unit': u''}

-- line #22386
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'LOT', u'brand': u'ALBASCAB', u'strength_3': u'', u'company': u'Albatross', u'unit': u''}

-- line #22387
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'LOT', u'brand': u'ALBASCAN', u'strength_3': u'', u'company': u'Albatross', u'unit': u''}

-- line #22388
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALBA', u'strength_3': u'', u'company': u'Zetek Ph.', u'unit': u''}

-- line #22389
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALBE 400', u'strength_3': u'', u'company': u'Serve Ph.', u'unit': u''}

-- line #22390
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'ALBEDA', u'strength_3': u'', u'company': u'Mitshu', u'unit': u''}

-- line #22391
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALBEDA', u'strength_3': u'', u'company': u'Mitshu', u'unit': u''}

-- line #22392
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB/SUS', u'brand': u'ALBEE', u'strength_3': u'', u'company': u'Omega Ph.', u'unit': u''}

-- line #22393
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SUS', u'brand': u'ALBENDEX', u'strength_3': u'', u'company': u'TWILIGHT LIT.', u'unit': u''}

-- line #22394
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TABS.', u'brand': u'ALBEND', u'strength_3': u'', u'company': u'Brij Ph', u'unit': u''}

-- line #22395
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SUS', u'brand': u'ALBEN', u'strength_3': u'', u'company': u'Cataliq Lab.', u'unit': u''}

-- line #22396
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALBEN', u'strength_3': u'', u'company': u'Cataliq Lab.', u'unit': u''}

-- line #22397
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SUS', u'brand': u'ALBE', u'strength_3': u'', u'company': u'Serve Ph.', u'unit': u''}

-- line #22398
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB.', u'brand': u'ALBET', u'strength_3': u'', u'company': u'Bennet Ph.', u'unit': u''}

-- line #22399
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALBO-SANG', u'strength_3': u'', u'company': u'J & J DeChane', u'unit': u''}

-- line #22400
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'ALBRAN', u'strength_3': u'', u'company': u'UNITED FORM.', u'unit': u''}

-- line #22401
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'INJ', u'brand': u'ALBUMIN 20%', u'strength_3': u'', u'company': u'Synergy D.', u'unit': u''}

-- line #22402
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAPE 1.25CM*9.14M', u'brand': u'ALBUPORE', u'strength_3': u'', u'company': u'Smith+N.', u'unit': u''}

-- line #22403
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAPE 2.50CM*9.14M', u'brand': u'ALBUPORE', u'strength_3': u'', u'company': u'Smith+N.', u'unit': u''}

-- line #22404
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAPE 7.50CM*9.14M', u'brand': u'ALBUPORE', u'strength_3': u'', u'company': u'Smith+N.', u'unit': u''}

-- line #22405
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'INJ', u'brand': u'ALBUREL 20%', u'strength_3': u'', u'company': u'Reliance Life', u'unit': u''}

-- line #22406
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'INJ', u'brand': u'ALBUREL 5%', u'strength_3': u'', u'company': u'Reliance Life', u'unit': u''}

-- line #22407
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALCAL', u'strength_3': u'', u'company': u'Bergen', u'unit': u''}

-- line #22408
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALCARE', u'strength_3': u'', u'company': u'HALEDEW', u'unit': u''}

-- line #22409
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALCC', u'strength_3': u'', u'company': u'Bestochem', u'unit': u''}

-- line #22410
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'DM TAB', u'brand': u'ALCID', u'strength_3': u'', u'company': u'KALEON LAB.', u'unit': u''}

-- line #22411
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALCIDOL', u'strength_3': u'', u'company': u'AERODEEP', u'unit': u''}

-- line #22412
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'ALCIRIZ', u'strength_3': u'', u'company': u'Ritz Ph.', u'unit': u''}

-- line #22413
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALCOBAL', u'strength_3': u'', u'company': u'Obsurge', u'unit': u''}

-- line #22414
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'ALCOLIV 500', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #22415
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'ALCONIA', u'strength_3': u'', u'company': u'Alcare Lab.', u'unit': u''}

-- line #22416
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'ALCONIA', u'strength_3': u'', u'company': u'Alcare Lab.', u'unit': u''}

-- line #22417
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'ALCORED', u'strength_3': u'', u'company': u'Admac Ph.', u'unit': u''}

-- line #22418
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALCORT', u'strength_3': u'', u'company': u'Dial Ph.', u'unit': u''}

-- line #22419
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALCOXIB 120', u'strength_3': u'', u'company': u'Bergen', u'unit': u''}

-- line #22420
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALCOXIB 90', u'strength_3': u'', u'company': u'Bergen', u'unit': u''}

-- line #22421
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALCUM-A', u'strength_3': u'', u'company': u'Aust Ind.', u'unit': u''}

-- line #22422
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'ALCUM', u'strength_3': u'', u'company': u'Aust Ind.', u'unit': u''}

-- line #22423
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'ALDE-12', u'strength_3': u'', u'company': u'Alde Medi.', u'unit': u''}

-- line #22424
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'ALDE-12', u'strength_3': u'', u'company': u'Alde Medi.', u'unit': u''}

-- line #22425
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'ALDEVIT', u'strength_3': u'', u'company': u'Alde Medi.', u'unit': u''}

-- line #22426
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'DPS.', u'brand': u'ALDEVIT', u'strength_3': u'', u'company': u'Alde Medi.', u'unit': u''}

-- line #22427
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'GRAN\\.', u'brand': u'ALDEVIT', u'strength_3': u'', u'company': u'Alde Medi.', u'unit': u''}

-- line #22428
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR.', u'brand': u'ALDEVIT', u'strength_3': u'', u'company': u'Alde Medi.', u'unit': u''}

-- line #22429
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CRM', u'brand': u'ALDIDERM', u'strength_3': u'', u'company': u'Marc Lab', u'unit': u''}

-- line #22430
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB.', u'brand': u'ALDIS PLUS', u'strength_3': u'', u'company': u'ALPS LAB.', u'unit': u''}

-- line #22431
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALDOLAC BZ', u'strength_3': u'', u'company': u'Aldok Ph.', u'unit': u''}

-- line #22432
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TABS.', u'brand': u'ALDOLAC-BZ', u'strength_3': u'', u'company': u'AMMACARE', u'unit': u''}

-- line #22433
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALDOLAC', u'strength_3': u'', u'company': u'AMMACARE', u'unit': u''}

-- line #22434
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'ALDOSPAR-200MG.TABS.', u'strength_3': u'', u'company': u'AMMACARE', u'unit': u''}

-- line #22435
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TABS.', u'brand': u'ALDOSPAS', u'strength_3': u'', u'company': u'AMMACARE', u'unit': u''}

-- line #22436
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALDOSS', u'strength_3': u'', u'company': u'Chemo Bio.', u'unit': u''}

-- line #22437
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TABS.', u'brand': u'ALDOXY-DR', u'strength_3': u'', u'company': u'AMMACARE', u'unit': u''}

-- line #22438
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALDREN-10', u'strength_3': u'', u'company': u'Zydus Cadila', u'unit': u''}

-- line #22439
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALDREN 5', u'strength_3': u'', u'company': u'Zydus Cadila', u'unit': u''}

-- line #22440
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALDREN 70', u'strength_3': u'', u'company': u'Zydus Cadila', u'unit': u''}

-- line #22441
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'POW', u'brand': u'ALDRICH', u'strength_3': u'', u'company': u'Alde Medi.', u'unit': u''}

-- line #22442
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB.', u'brand': u'ALERMINE', u'strength_3': u'', u'company': u'Bsp Ph.', u'unit': u''}

-- line #22443
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP.', u'brand': u'ALERT', u'strength_3': u'', u'company': u'Ban Lab', u'unit': u''}

-- line #22444
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'ALERT', u'strength_3': u'', u'company': u'Vasu Ph.', u'unit': u''}

-- line #22445
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'OD TAB', u'brand': u'ALERTEN', u'strength_3': u'', u'company': u'Mdc Ph.', u'unit': u''}

-- line #22446
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'ALERTIN', u'strength_3': u'', u'company': u'TWILIGHT LIT.', u'unit': u''}

-- line #22447
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'ALERT', u'strength_3': u'', u'company': u'Vasu Ph.', u'unit': u''}

-- line #22448
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'ALETRITONE', u'strength_3': u'', u'company': u'Indo French', u'unit': u''}

-- line #22449
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALETRITONE', u'strength_3': u'', u'company': u'Indo French', u'unit': u''}

-- line #22450
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SF SYR', u'brand': u'ALEX', u'strength_3': u'', u'company': u'Glenmark', u'unit': u''}

-- line #22451
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'ALFA CALCIROL PLUS', u'strength_3': u'', u'company': u'Irm Ph.', u'unit': u''}

-- line #22452
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'ALFACALCIT', u'strength_3': u'', u'company': u'Heal All Ph.', u'unit': u''}

-- line #22453
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALFACOBAL', u'strength_3': u'', u'company': u'Hitech Form.', u'unit': u''}

-- line #22454
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALFA-HA', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #22455
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'GEL', u'brand': u'ALFA LINI', u'strength_3': u'', u'company': u'Himsail Rem.', u'unit': u''}

-- line #22456
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALFALOG', u'strength_3': u'', u'company': u'Rpg Life', u'unit': u''}

-- line #22457
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'LOT', u'brand': u'ALFA', u'strength_3': u'', u'company': u'Dermocare', u'unit': u''}

-- line #22458
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'INJ', u'brand': u'ALFARIZ PLUS', u'strength_3': u'', u'company': u'Ritz Ph.', u'unit': u''}

-- line #22459
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB/INJ', u'brand': u'ALFARIZ', u'strength_3': u'', u'company': u'Ritz Ph.', u'unit': u''}

-- line #22460
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALFASAFE', u'strength_3': u'', u'company': u'SAFE PH.', u'unit': u''}

-- line #22461
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYRUP', u'brand': u'ALFASENG', u'strength_3': u'', u'company': u'AMMACARE', u'unit': u''}

-- line #22462
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'ALFA SOFT', u'strength_3': u'', u'company': u'Soft Health', u'unit': u''}

-- line #22463
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'F. TAB.', u'brand': u'ALFATRIP', u'strength_3': u'', u'company': u'Mayo Hc.', u'unit': u''}

-- line #22464
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'F. TAB', u'brand': u'ALFATRIP', u'strength_3': u'', u'company': u'Novopharm', u'unit': u''}

-- line #22465
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR.', u'brand': u'ALFER-P', u'strength_3': u'', u'company': u'Alde Medi.', u'unit': u''}

-- line #22466
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'ALFIT', u'strength_3': u'', u'company': u'Health & Hygiene', u'unit': u''}

-- line #22467
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALGESIN-O', u'strength_3': u'', u'company': u'ALEMBIC', u'unit': u''}

-- line #22468
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'INJ', u'brand': u'ALGIBRA I.V.', u'strength_3': u'', u'company': u'Cfl Ph.', u'unit': u''}

-- line #22469
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALGIFLUX', u'strength_3': u'', u'company': u'Panacea', u'unit': u''}

-- line #22470
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'ALIANZ', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #22471
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALI-M', u'strength_3': u'', u'company': u'Mefro Ph.', u'unit': u''}

-- line #22472
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'GEL', u'brand': u'ALIN', u'strength_3': u'', u'company': u'Alive', u'unit': u''}

-- line #22473
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'ALINOR 100MG', u'strength_3': u'', u'company': u'VHB', u'unit': u''}

-- line #22474
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'ALINOR 25MG', u'strength_3': u'', u'company': u'VHB', u'unit': u''}

-- line #22475
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'ALINOR 50MG', u'strength_3': u'', u'company': u'VHB', u'unit': u''}

-- line #22476
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB.', u'brand': u'ALIRON', u'strength_3': u'', u'company': u'Kirti Works', u'unit': u''}

-- line #22477
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'POW', u'brand': u'ALIVE', u'strength_3': u'', u'company': u'Sysmed', u'unit': u''}

-- line #22478
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALIZA-M', u'strength_3': u'', u'company': u'Mefro Ph.', u'unit': u''}

-- line #22479
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'ALKA-5', u'strength_3': u'', u'company': u'Charak', u'unit': u''}

-- line #22480
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'ALKAA', u'strength_3': u'', u'company': u'ORSAL PH.', u'unit': u''}

-- line #22481
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYRUP', u'brand': u'ALKEMAX-MB6', u'strength_3': u'', u'company': u'OVERSEAS MED.', u'unit': u''}

-- line #22482
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'ALKEMZYME', u'strength_3': u'', u'company': u'Alkem', u'unit': u''}

-- line #22483
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYRUP', u'brand': u'ALKIN-K', u'strength_3': u'', u'company': u'Hema Lab.', u'unit': u''}

-- line #22484
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYRUP 100ML.', u'brand': u'ALKIN', u'strength_3': u'', u'company': u'Hema Lab.', u'unit': u''}

-- line #22485
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYRUP 200ML.', u'brand': u'ALKIN', u'strength_3': u'', u'company': u'Hema Lab.', u'unit': u''}

-- line #22486
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYRUP 450ML.', u'brand': u'ALKIN', u'strength_3': u'', u'company': u'Hema Lab.', u'unit': u''}

-- line #22487
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'ALKOF', u'strength_3': u'', u'company': u'KAPTAB', u'unit': u''}

-- line #22488
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'ALKOR', u'strength_3': u'', u'company': u'Corona', u'unit': u''}

-- line #22489
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALL 0.25', u'strength_3': u'', u'company': u'Elegant Rem.', u'unit': u''}

-- line #22490
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALL 0.5', u'strength_3': u'', u'company': u'Elegant Rem.', u'unit': u''}

-- line #22491
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'ALLAGE', u'strength_3': u'', u'company': u'ACE LAB.', u'unit': u''}

-- line #22492
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALLAM 0.25/0.5', u'strength_3': u'', u'company': u'Zorex Ph.', u'unit': u''}

-- line #22493
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'ALLAM 50MG.TABS.', u'strength_3': u'', u'company': u'Zorex Ph.', u'unit': u''}

-- line #22494
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALLENIL', u'strength_3': u'', u'company': u'Torrent', u'unit': u''}

-- line #22495
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'ALLERHIN D+', u'strength_3': u'', u'company': u'Embiotic Lab.', u'unit': u''}

-- line #22496
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALLERHIN', u'strength_3': u'', u'company': u'Embiotic Lab.', u'unit': u''}

-- line #22497
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB.', u'brand': u'ALLERIN', u'strength_3': u'', u'company': u'Ban Lab', u'unit': u''}

-- line #22498
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'ALLEROFF', u'strength_3': u'', u'company': u'Pacific Med.', u'unit': u''}

-- line #22499
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALLESTRON', u'strength_3': u'', u'company': u'ARGENTINE', u'unit': u''}

-- line #22500
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALLE', u'strength_3': u'', u'company': u'Kepsee', u'unit': u''}

-- line #22501
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALLOVIT', u'strength_3': u'', u'company': u'Astrazeneca', u'unit': u''}

-- line #22502
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'ALLOXI', u'strength_3': u'', u'company': u'Allure Rem.', u'unit': u''}

-- line #22503
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALLRITE-D', u'strength_3': u'', u'company': u'German R.', u'unit': u''}

-- line #22504
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TABS.', u'brand': u'ALLSET', u'strength_3': u'', u'company': u'MEDIWIN BIO', u'unit': u''}

-- line #22505
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'INJ', u'brand': u'ALL-V', u'strength_3': u'', u'company': u'Intracin', u'unit': u''}

-- line #22506
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'ALLVIT', u'strength_3': u'', u'company': u'SAFE PH.', u'unit': u''}

-- line #22507
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'ALMALIO', u'strength_3': u'', u'company': u'ZANDU', u'unit': u''}

-- line #22508
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALMANTIN 10', u'strength_3': u'', u'company': u'Solus', u'unit': u''}

-- line #22509
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALMANTIN 5', u'strength_3': u'', u'company': u'Solus', u'unit': u''}

-- line #22510
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALMIC', u'strength_3': u'', u'company': u'HALEDEW', u'unit': u''}

-- line #22511
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'LIQ', u'brand': u'ALOEONE', u'strength_3': u'', u'company': u'Calyx Bio.', u'unit': u''}

-- line #22512
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALOES COMPOUND', u'strength_3': u'', u'company': u'Alarsin', u'unit': u''}

-- line #22513
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CRM', u'brand': u'ALOESILK', u'strength_3': u'', u'company': u'Meyer Org.', u'unit': u''}

-- line #22514
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'ALOLIV', u'strength_3': u'', u'company': u'Bennet Ph.', u'unit': u''}

-- line #22515
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'ALOLIV', u'strength_3': u'', u'company': u'Bennet Ph.', u'unit': u''}

-- line #22516
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CRM', u'brand': u'ALONAP', u'strength_3': u'', u'company': u'Elder', u'unit': u''}

-- line #22517
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'GEL', u'brand': u'ALONURISH ACNE', u'strength_3': u'', u'company': u'Elder', u'unit': u''}

-- line #22518
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CRM', u'brand': u'ALONURISH AI', u'strength_3': u'', u'company': u'Elder', u'unit': u''}

-- line #22519
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CRM', u'brand': u'ALONURISH', u'strength_3': u'', u'company': u'Elder', u'unit': u''}

-- line #22520
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'ALONURISH FACE CLEANSER', u'strength_3': u'', u'company': u'Elder', u'unit': u''}

-- line #22521
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'LOT', u'brand': u'ALONURISH', u'strength_3': u'', u'company': u'Elder', u'unit': u''}

-- line #22522
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'ALONURISH SCALP CLEANSER', u'strength_3': u'', u'company': u'Elder', u'unit': u''}

-- line #22523
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'ALOPAKOF', u'strength_3': u'', u'company': u'Alopa Herbal', u'unit': u''}

-- line #22524
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYP', u'brand': u'ALOPAZYME', u'strength_3': u'', u'company': u'Alopa Herbal', u'unit': u''}

-- line #22525
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'POW', u'brand': u'ALOPROT-P', u'strength_3': u'', u'company': u'Alopa Herbal', u'unit': u''}

-- line #22526
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'ALORA FRESH', u'strength_3': u'', u'company': u'Pharma Drugs', u'unit': u''}

-- line #22527
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAPS.', u'brand': u'ALOX', u'strength_3': u'', u'company': u'AMMACARE', u'unit': u''}

-- line #22528
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'ALOXIN 200', u'strength_3': u'', u'company': u'Water Lilly', u'unit': u''}

-- line #22529
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'OZ TAB', u'brand': u'ALOXX', u'strength_3': u'', u'company': u'Delton Ph.', u'unit': u''}

-- line #22530
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CRM', u'brand': u'ALPAGON', u'strength_3': u'', u'company': u'AMIDEEP', u'unit': u''}

-- line #22531
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'OINT', u'brand': u'ALPAGON', u'strength_3': u'', u'company': u'Mitshu', u'unit': u''}

-- line #22532
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'ALPENAM 1G', u'strength_3': u'', u'company': u'MEGACARE', u'unit': u''}

-- line #22533
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'ALPHADINE SURG.SCRUB', u'strength_3': u'', u'company': u'Nicholas', u'unit': u''}

-- line #22534
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALPHALAN 2', u'strength_3': u'', u'company': u'Natco Ph.', u'unit': u''}

-- line #22535
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALPHALAN 5', u'strength_3': u'', u'company': u'Natco Ph.', u'unit': u''}

-- line #22536
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'ALPHA-ZE', u'strength_3': u'', u'company': u'Alembic', u'unit': u''}

-- line #22537
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALPICALM 0.25/0.5', u'strength_3': u'', u'company': u'NORIS HC.', u'unit': u''}

-- line #22538
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'ALPITONE', u'strength_3': u'', u'company': u'ZANDU', u'unit': u''}

-- line #22539
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'ALPOSE 0.25MG.TABS.', u'strength_3': u'', u'company': u'Hema Lab.', u'unit': u''}

-- line #22540
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'ALPOSE 0.50MG.TABS.', u'strength_3': u'', u'company': u'Hema Lab.', u'unit': u''}

-- line #22541
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'ALPOSE 1GM.TABS.', u'strength_3': u'', u'company': u'Hema Lab.', u'unit': u''}

-- line #22542
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'ALPRAM 0.5MG.TABS.', u'strength_3': u'', u'company': u'MACSOL', u'unit': u''}

-- line #22543
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'DPS', u'brand': u'ALPROVIT', u'strength_3': u'', u'company': u'Alkem', u'unit': u''}

-- line #22544
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'GRAN', u'brand': u'ALPROVIT', u'strength_3': u'', u'company': u'Alkem', u'unit': u''}

-- line #22545
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'POW', u'brand': u'ALPROVIT JR.', u'strength_3': u'', u'company': u'Alkem', u'unit': u''}

-- line #22546
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'ALPROVIT PLUS', u'strength_3': u'', u'company': u'Alkem', u'unit': u''}

-- line #22547
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'POW', u'brand': u'ALPROVIT', u'strength_3': u'', u'company': u'Alkem', u'unit': u''}

-- line #22548
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'ALPROVIT', u'strength_3': u'', u'company': u'Alkem', u'unit': u''}

-- line #22549
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALPRUM-K 250', u'strength_3': u'', u'company': u'Kepsee', u'unit': u''}

-- line #22550
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'ALPSBUTOL 200MG.TABS.', u'strength_3': u'', u'company': u'ALPS LAB.', u'unit': u''}

-- line #22551
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'ALPSBUTOL 400MG.TABS.', u'strength_3': u'', u'company': u'ALPS LAB.', u'unit': u''}

-- line #22552
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'ALPSBUTOL 600MG.TABS.', u'strength_3': u'', u'company': u'ALPS LAB.', u'unit': u''}

-- line #22553
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'ALPSBUTOL 800MG.TABS.', u'strength_3': u'', u'company': u'ALPS LAB.', u'unit': u''}

-- line #22554
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALQUIN 250/500', u'strength_3': u'', u'company': u'KALEON LAB.', u'unit': u''}

-- line #22555
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALRM', u'strength_3': u'', u'company': u'CETOXE LAB.', u'unit': u''}

-- line #22556
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALROXAL-150', u'strength_3': u'', u'company': u'AMMACARE', u'unit': u''}

-- line #22557
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'KID TAB', u'brand': u'ALROXAL', u'strength_3': u'', u'company': u'AMMACARE', u'unit': u''}

-- line #22558
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'INJ', u'brand': u'ALRUBIC 100', u'strength_3': u'', u'company': u'Cytomed(Alkem)', u'unit': u''}

-- line #22559
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALSIDO', u'strength_3': u'', u'company': u'Ambrosia', u'unit': u''}

-- line #22560
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'OD TAB', u'brand': u'ALTACEF', u'strength_3': u'', u'company': u'Glenmark', u'unit': u''}

-- line #22561
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALTILOX', u'strength_3': u'', u'company': u'Parenteral', u'unit': u''}

-- line #22562
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'ALTONE', u'strength_3': u'', u'company': u'Albert D.', u'unit': u''}

-- line #22563
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR.', u'brand': u'ALTRAZYME', u'strength_3': u'', u'company': u'Ultramark', u'unit': u''}

-- line #22564
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALTUS 0.25', u'strength_3': u'', u'company': u'Kapeetus', u'unit': u''}

-- line #22565
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALTUS 0.5', u'strength_3': u'', u'company': u'Kapeetus', u'unit': u''}

-- line #22566
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALUM 0.25/0.5', u'strength_3': u'', u'company': u'Sunrise Ph.', u'unit': u''}

-- line #22567
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SUS', u'brand': u'ALUPECTIN DGL', u'strength_3': u'', u'company': u'Bio-Drug', u'unit': u''}

-- line #22568
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SUS', u'brand': u'ALUPECTIN', u'strength_3': u'', u'company': u'Bio-Drug', u'unit': u''}

-- line #22569
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALURETIC', u'strength_3': u'', u'company': u'Alarsin', u'unit': u''}

-- line #22570
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'LIQ', u'brand': u'ALUSIL MPS', u'strength_3': u'', u'company': u'Arbro Ph.', u'unit': u''}

-- line #22571
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALUSIL MPS', u'strength_3': u'', u'company': u'Arbro Ph.', u'unit': u''}

-- line #22572
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB.', u'brand': u'ALUSOLONE 10', u'strength_3': u'', u'company': u'Kirti Works', u'unit': u''}

-- line #22573
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'ALUSOLONE 2.5MG.TABS.', u'strength_3': u'', u'company': u'Kirti Works', u'unit': u''}

-- line #22574
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'INJ', u'brand': u'ALUS-P 40', u'strength_3': u'', u'company': u'Glenmark', u'unit': u''}

-- line #22575
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'F. TABS.', u'brand': u'ALVIN', u'strength_3': u'', u'company': u'ALPS LAB.', u'unit': u''}

-- line #22576
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SUS', u'brand': u'ALWORM', u'strength_3': u'', u'company': u'Espee Form.', u'unit': u''}

-- line #22577
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALWORM', u'strength_3': u'', u'company': u'Espee Form.', u'unit': u''}

-- line #22578
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'ALZER', u'strength_3': u'', u'company': u'HETAL PH.', u'unit': u''}

-- line #22579
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALZIN', u'strength_3': u'', u'company': u'Austere', u'unit': u''}

-- line #22580
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALZOL 0.25/0.5', u'strength_3': u'', u'company': u'KALEON LAB.', u'unit': u''}

-- line #22581
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'AMALAKYADI CHURNA', u'strength_3': u'', u'company': u'SANDU BRO.', u'unit': u''}

-- line #22582
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'AMAL KI RASAYAN CHURNA', u'strength_3': u'', u'company': u'NARNARAYAN', u'unit': u''}

-- line #22583
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'POW', u'brand': u'AMALKI RASAYAN', u'strength_3': u'', u'company': u'SHREE BAIDYA.', u'unit': u''}

-- line #22584
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'AMALKI', u'strength_3': u'', u'company': u'Aimil Ph.', u'unit': u''}

-- line #22585
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'AMAR SUNDARI BATI', u'strength_3': u'', u'company': u'SHREE BAIDYA.', u'unit': u''}

-- line #22586
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'AMAR SUNDARI GUTIKA', u'strength_3': u'', u'company': u'DABUR INDIA', u'unit': u''}

-- line #22587
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'VATI', u'brand': u'AMAR SUNDARI', u'strength_3': u'', u'company': u'NARNARAYAN', u'unit': u''}

-- line #22588
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'AMAX-P', u'strength_3': u'', u'company': u'Iressia', u'unit': u''}

-- line #22589
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SR TAB', u'brand': u'AMAX', u'strength_3': u'', u'company': u'Iressia', u'unit': u''}

-- line #22590
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'AMAX', u'strength_3': u'', u'company': u'Iressia', u'unit': u''}

-- line #22591
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'AMBCET', u'strength_3': u'', u'company': u'Fourrts', u'unit': u''}

-- line #22592
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'AMBIDEXT 20', u'strength_3': u'', u'company': u'Crescent Th.', u'unit': u''}

-- line #22593
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'AMBIDEXT 30', u'strength_3': u'', u'company': u'Crescent Th.', u'unit': u''}

-- line #22594
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'AMBIMAP', u'strength_3': u'', u'company': u'MAHARISHI', u'unit': u''}

-- line #22595
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'AMBRODITE 25 PLUS', u'strength_3': u'', u'company': u'TABLETS I.', u'unit': u''}

-- line #22596
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'AMBROID', u'strength_3': u'', u'company': u'Kapeetus', u'unit': u''}

-- line #22597
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'AMBROSIA', u'strength_3': u'', u'company': u'A.F.D.', u'unit': u''}

-- line #22598
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'AMBROVIP-S', u'strength_3': u'', u'company': u'Vips Ph.', u'unit': u''}

-- line #22599
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'AMCLOREX', u'strength_3': u'', u'company': u'Zorex Ph.', u'unit': u''}

-- line #22600
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'A.M.DOPA', u'strength_3': u'', u'company': u'Dahlia Ph.', u'unit': u''}

-- line #22601
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'A-M DOPA', u'strength_3': u'', u'company': u'DAHLIA PH.', u'unit': u''}

-- line #22602
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'AMEER RAS', u'strength_3': u'', u'company': u'SHREE BAIDYA.', u'unit': u''}

-- line #22603
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'AMFECT 100/250/500', u'strength_3': u'', u'company': u'TWILIGHT LIT.', u'unit': u''}

-- line #22604
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'ORAL RINSE', u'brand': u'AMFLOR', u'strength_3': u'', u'company': u'Group Ph.', u'unit': u''}

-- line #22605
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'AMIFULL', u'strength_3': u'', u'company': u'BIONOVA', u'unit': u''}

-- line #22606
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'INJ', u'brand': u'AMIMAC 250MG', u'strength_3': u'', u'company': u'Ikon Rem', u'unit': u''}

-- line #22607
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'INJ', u'brand': u'AMINAT 500', u'strength_3': u'', u'company': u'Natco(Sp.)', u'unit': u''}

-- line #22608
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'INF.', u'brand': u'AMINOCORE 5-S PLUS', u'strength_3': u'', u'company': u'Claris L.', u'unit': u''}

-- line #22609
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'POW', u'brand': u'AMINOCRAT', u'strength_3': u'', u'company': u'CRATUS', u'unit': u''}

-- line #22610
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'INJ.', u'brand': u'AMINODRIP', u'strength_3': u'', u'company': u'Wockhardt', u'unit': u''}

-- line #22611
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'AMINO-FIT', u'strength_3': u'', u'company': u'Universal', u'unit': u''}

-- line #22612
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'AMINOFIT IUGR', u'strength_3': u'', u'company': u'Universal', u'unit': u''}

-- line #22613
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'AMINO-FIT', u'strength_3': u'', u'company': u'Universal', u'unit': u''}

-- line #22614
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'INF', u'brand': u'AMINOFUSION', u'strength_3': u'', u'company': u'TABLETS I.', u'unit': u''}

-- line #22615
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SUS', u'brand': u'AMINOL D.S.', u'strength_3': u'', u'company': u'Group Ph.', u'unit': u''}

-- line #22616
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'INJ.', u'brand': u'AMINOPLASMAL-L 5%', u'strength_3': u'', u'company': u'Wallace', u'unit': u''}

-- line #22617
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'INJ.', u'brand': u'AMINOPLASMAL- PAED', u'strength_3': u'', u'company': u'Wallace', u'unit': u''}

-- line #22618
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'AMINORICH', u'strength_3': u'', u'company': u'Stedman', u'unit': u''}

-- line #22619
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'DPS', u'brand': u'AMINORICH', u'strength_3': u'', u'company': u'Stedman', u'unit': u''}

-- line #22620
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'GRAN\\.', u'brand': u'AMINORICH', u'strength_3': u'', u'company': u'Stedman', u'unit': u''}

-- line #22621
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'AMINORICH GRN', u'strength_3': u'', u'company': u'Stedman', u'unit': u''}

-- line #22622
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'LIQ', u'brand': u'AMINORICH', u'strength_3': u'', u'company': u'Stedman', u'unit': u''}

-- line #22623
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'AMINOSTAR', u'strength_3': u'', u'company': u'INTRA(INVENTURE)', u'unit': u''}

-- line #22624
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'INF.', u'brand': u'AMINOSTERIL-N HEPA', u'strength_3': u'', u'company': u'Fresenius', u'unit': u''}

-- line #22625
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'AMINOVEN 10%', u'strength_3': u'', u'company': u'Fresenius', u'unit': u''}

-- line #22626
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'INFANT', u'brand': u'AMINOVEN 10%', u'strength_3': u'', u'company': u'Fresenius', u'unit': u''}

-- line #22627
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'AMINOVEN 5% 500ML BOTTLE', u'strength_3': u'', u'company': u'Fresenius', u'unit': u''}

-- line #22628
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'INFANT', u'brand': u'AMINOVEN 6%', u'strength_3': u'', u'company': u'Fresenius', u'unit': u''}

-- line #22629
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'INFANT 10% 100ML BOTTLE', u'brand': u'AMINOVEN', u'strength_3': u'', u'company': u'Fresenius', u'unit': u''}

-- line #22630
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'AMINOZYME', u'strength_3': u'', u'company': u'Stadmed', u'unit': u''}

-- line #22631
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'AMIPHEN 250/500', u'strength_3': u'', u'company': u'Espee Form.', u'unit': u''}

-- line #22632
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'KID TAB', u'brand': u'AMIPHEN', u'strength_3': u'', u'company': u'Espee Form.', u'unit': u''}

-- line #22633
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'AMIPRO', u'strength_3': u'', u'company': u'Medizone', u'unit': u''}

-- line #22634
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'F. CAP', u'brand': u'AMITONE', u'strength_3': u'', u'company': u'CHEMO HC.', u'unit': u''}

-- line #22635
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'AMI-Z', u'strength_3': u'', u'company': u'AIMCO PH.', u'unit': u''}

-- line #22636
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'AMLA CHURNA', u'strength_3': u'', u'company': u'NARNARAYAN', u'unit': u''}

-- line #22637
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'AMLA CHURNA', u'strength_3': u'', u'company': u'SHREE SHANKER', u'unit': u''}

-- line #22638
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'AMLANT', u'strength_3': u'', u'company': u'MAHARISHI', u'unit': u''}

-- line #22639
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'AMLAPITTANTAK LOHA', u'strength_3': u'', u'company': u'SHREE BAIDYA.', u'unit': u''}

-- line #22640
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'AMLAQER 2.5ML', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #22641
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'AMLA', u'strength_3': u'', u'company': u'NARNARAYAN', u'unit': u''}

-- line #22642
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'AMLA', u'strength_3': u'', u'company': u'SHREE SHANKER', u'unit': u''}

-- line #22643
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'AMLOCARE 5', u'strength_3': u'', u'company': u'Elegant Rem.', u'unit': u''}

-- line #22644
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'AT TAB', u'brand': u'AMLOCARE', u'strength_3': u'', u'company': u'Elegant Rem.', u'unit': u''}

-- line #22645
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'AMLOD-L', u'strength_3': u'', u'company': u'Acron Ph.', u'unit': u''}

-- line #22646
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'AMLOD', u'strength_3': u'', u'company': u'Acron Ph.', u'unit': u''}

-- line #22647
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'AMLONOR-5', u'strength_3': u'', u'company': u'NORIS HC.', u'unit': u''}

-- line #22648
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'AMLONOR-A', u'strength_3': u'', u'company': u'NORIS HC.', u'unit': u''}

-- line #22649
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'AMLOZONE 5', u'strength_3': u'', u'company': u'Ozone Ph.', u'unit': u''}

-- line #22650
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'INJ', u'brand': u'AMLOZONE', u'strength_3': u'', u'company': u'Ozone Ph.', u'unit': u''}

-- line #22651
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'DPS.', u'brand': u'AMLYCURE', u'strength_3': u'', u'company': u'Aimil Ph.', u'unit': u''}

-- line #22652
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'DS CAP', u'brand': u'AMLYCURE', u'strength_3': u'', u'company': u'Aimil Ph.', u'unit': u''}

-- line #22653
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'DS SYR', u'brand': u'AMLYCURE', u'strength_3': u'', u'company': u'Aimil Ph.', u'unit': u''}

-- line #22654
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR.', u'brand': u'AMLYCURE', u'strength_3': u'', u'company': u'Aimil Ph.', u'unit': u''}

-- line #22655
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TABLET', u'brand': u'AMLYCURE', u'strength_3': u'', u'company': u'Aimil Ph.', u'unit': u''}

-- line #22656
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'AMMTAB', u'strength_3': u'', u'company': u'Rhombus', u'unit': u''}

-- line #22657
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'AMNEE', u'strength_3': u'', u'company': u'KIRAL R.', u'unit': u''}

-- line #22658
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'AMOCLOX', u'strength_3': u'', u'company': u'Trident Ph.', u'unit': u''}

-- line #22659
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'AMOELIN', u'strength_3': u'', u'company': u'TWILIGHT LIT.', u'unit': u''}

-- line #22660
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'AMOLIN 250/500', u'strength_3': u'', u'company': u'Bennet Ph.', u'unit': u''}

-- line #22661
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'AMOLIN BP', u'strength_3': u'', u'company': u'Bennet Ph.', u'unit': u''}

-- line #22662
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'AMOLIN KID', u'strength_3': u'', u'company': u'Bennet Ph.', u'unit': u''}

-- line #22663
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'AMOLIV', u'strength_3': u'', u'company': u'AIMCO PH.', u'unit': u''}

-- line #22664
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'AMOLOX 100', u'strength_3': u'', u'company': u'Tripada', u'unit': u''}

-- line #22665
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'AMOLOX 50', u'strength_3': u'', u'company': u'Tripada', u'unit': u''}

-- line #22666
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'AMOTID 250/500', u'strength_3': u'', u'company': u'Kaptab', u'unit': u''}

-- line #22667
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'D.SYR', u'brand': u'AMOTID', u'strength_3': u'', u'company': u'Kaptab', u'unit': u''}

-- line #22668
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'F. TAB', u'brand': u'AMOTID', u'strength_3': u'', u'company': u'Kaptab', u'unit': u''}

-- line #22669
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'KID TAB', u'brand': u'AMOTID', u'strength_3': u'', u'company': u'Kaptab', u'unit': u''}

-- line #22670
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'AMOXTRIN 250/500', u'strength_3': u'', u'company': u'WISCON', u'unit': u''}

-- line #22671
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'D.SYR', u'brand': u'AMOXTRIN', u'strength_3': u'', u'company': u'Trends', u'unit': u''}

-- line #22672
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'KID TAB', u'brand': u'AMOXTRIN', u'strength_3': u'', u'company': u'Trends', u'unit': u''}

-- line #22673
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'AMOZ 250/500', u'strength_3': u'', u'company': u'Zorex Ph.', u'unit': u''}

-- line #22674
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'AMOZ-250MG.CAPS.', u'strength_3': u'', u'company': u'Zorex Ph.', u'unit': u''}

-- line #22675
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'DT/TAB', u'brand': u'AMOZ', u'strength_3': u'', u'company': u'Zorex Ph.', u'unit': u''}

-- line #22676
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'VATI', u'brand': u'AM PACHAN', u'strength_3': u'', u'company': u'SHREE SHANKER', u'unit': u''}

-- line #22677
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'AMPI 250', u'strength_3': u'', u'company': u'Patson', u'unit': u''}

-- line #22678
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'AMPI 500', u'strength_3': u'', u'company': u'Patson', u'unit': u''}

-- line #22679
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'LB CAP', u'brand': u'AMPILIN', u'strength_3': u'', u'company': u'HETERO HC.', u'unit': u''}

-- line #22680
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'KID TAB', u'brand': u'AMPIL', u'strength_3': u'', u'company': u'Omega Ph.', u'unit': u''}

-- line #22681
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAPS.', u'brand': u'AMPINEX', u'strength_3': u'', u'company': u'KRUN & K.', u'unit': u''}

-- line #22682
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'KID TABS.', u'brand': u'AMPINEX', u'strength_3': u'', u'company': u'KRUN & K.', u'unit': u''}

-- line #22683
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'LB 500MG.CAPS.', u'brand': u'AMPINEX', u'strength_3': u'', u'company': u'KRUN & K.', u'unit': u''}

-- line #22684
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'LB KID TABS.', u'brand': u'AMPINEX', u'strength_3': u'', u'company': u'KRUN & K.', u'unit': u''}

-- line #22685
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'INJ', u'brand': u'AMPIROK 1.5G', u'strength_3': u'', u'company': u'Astrum Hc.', u'unit': u''}

-- line #22686
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'INJ', u'brand': u'AMPIROK 750MG', u'strength_3': u'', u'company': u'Astrum Hc.', u'unit': u''}

-- line #22687
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'AMPISTAR-250MG.CAPS.', u'strength_3': u'', u'company': u'STAR PH.', u'unit': u''}

-- line #22688
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'AMPISTAR-500MG.CAPS.', u'strength_3': u'', u'company': u'STAR PH.', u'unit': u''}

-- line #22689
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'DT', u'brand': u'AMPIZ', u'strength_3': u'', u'company': u'Zorex Ph.', u'unit': u''}

-- line #22690
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'AMPROGYL 400MG.TABS.', u'strength_3': u'', u'company': u'STAR PH.', u'unit': u''}

-- line #22691
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'AMPROGYL COMPOUND', u'strength_3': u'', u'company': u'STAR PH.', u'unit': u''}

-- line #22692
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'AMPROZ', u'strength_3': u'', u'company': u'SALVEO LIFE', u'unit': u''}

-- line #22693
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'INJ.', u'brand': u'AMPY-12', u'strength_3': u'', u'company': u'Ophthal R.', u'unit': u''}

-- line #22694
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAPS. (500)', u'brand': u'AMREE', u'strength_3': u'', u'company': u'Aimil Ph.', u'unit': u''}

-- line #22695
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAPSULES', u'brand': u'AMREE', u'strength_3': u'', u'company': u'Aimil Ph.', u'unit': u''}

-- line #22696
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'GRAN\\.', u'brand': u'AMREE PLUS', u'strength_3': u'', u'company': u'Aimil Ph.', u'unit': u''}

-- line #22697
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'AMRITARISHTA', u'strength_3': u'', u'company': u'DABUR INDIA', u'unit': u''}

-- line #22698
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'AMRITARISHTA', u'strength_3': u'', u'company': u'SANDU BRO.', u'unit': u''}

-- line #22699
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'AMRITARISHTA', u'strength_3': u'', u'company': u'SHREE BAIDYA.', u'unit': u''}

-- line #22700
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'AMRITARISHTA', u'strength_3': u'', u'company': u'ZANDU', u'unit': u''}

-- line #22701
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'AMRUTAM CHURNA LAX', u'strength_3': u'', u'company': u'BSA PH.', u'unit': u''}

-- line #22702
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'POW', u'brand': u'AMRUTAM', u'strength_3': u'', u'company': u'BSA PH.', u'unit': u''}

-- line #22703
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'AMRUTAM', u'strength_3': u'', u'company': u'BSA PH.', u'unit': u''}

-- line #22704
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'AMRYCARD (500)', u'strength_3': u'', u'company': u'Aimil Ph.', u'unit': u''}

-- line #22705
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'AMRYCARD', u'strength_3': u'', u'company': u'Aimil Ph.', u'unit': u''}

-- line #22706
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'AMSARTAN', u'strength_3': u'', u'company': u'Concept', u'unit': u''}

-- line #22707
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'AMTAS-M 25', u'strength_3': u'', u'company': u'Intas', u'unit': u''}

-- line #22708
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'AMTAS-M 50', u'strength_3': u'', u'company': u'Intas', u'unit': u''}

-- line #22709
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'AMTIS', u'strength_3': u'', u'company': u'Claris L.', u'unit': u''}

-- line #22710
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'AMUST PLUS', u'strength_3': u'', u'company': u'Bipl(Radico Lab)', u'unit': u''}

-- line #22711
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'AMUST', u'strength_3': u'', u'company': u'Bipl(Radico Lab)', u'unit': u''}

-- line #22712
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'AMVATRI RAS', u'strength_3': u'', u'company': u'SHREE BAIDYA.', u'unit': u''}

-- line #22713
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP(500)', u'brand': u'AMYCORDIAL', u'strength_3': u'', u'company': u'Aimil Ph.', u'unit': u''}

-- line #22714
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'AMYCORDIAL', u'strength_3': u'', u'company': u'Aimil Ph.', u'unit': u''}

-- line #22715
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR.', u'brand': u'AMYCORDIAL', u'strength_3': u'', u'company': u'Aimil Ph.', u'unit': u''}

-- line #22716
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR.', u'brand': u'AMYRON', u'strength_3': u'', u'company': u'Aimil Ph.', u'unit': u''}

-- line #22717
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'AMYSTOP-G', u'strength_3': u'', u'company': u'Aimil Ph.', u'unit': u''}

-- line #22718
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'ANACIN PAIN BALM', u'strength_3': u'', u'company': u'Geoffrey M.', u'unit': u''}

-- line #22719
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'DT', u'brand': u'ANACLAR 125', u'strength_3': u'', u'company': u'TWILIGHT LIT.', u'unit': u''}

-- line #22720
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ANACLAR 250/500', u'strength_3': u'', u'company': u'TWILIGHT LIT.', u'unit': u''}

-- line #22721
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ANADECON', u'strength_3': u'', u'company': u'Ethicare', u'unit': u''}

-- line #22722
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'DT', u'brand': u'ANADON', u'strength_3': u'', u'company': u'HALEDEW', u'unit': u''}

-- line #22723
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'EYE DPS', u'brand': u'ANALAR', u'strength_3': u'', u'company': u'Pharmtak', u'unit': u''}

-- line #22724
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ANALCOS-S', u'strength_3': u'', u'company': u'Cosmos Rem.', u'unit': u''}

-- line #22725
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ANALCOS', u'strength_3': u'', u'company': u'Cosmos Rem.', u'unit': u''}

-- line #22726
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ANALGEC', u'strength_3': u'', u'company': u'Southsourne', u'unit': u''}

-- line #22727
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ANALGESIC', u'strength_3': u'', u'company': u'Southsourne', u'unit': u''}

-- line #22728
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ANAMAX-K', u'strength_3': u'', u'company': u'Bsp Ph.', u'unit': u''}

-- line #22729
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB.', u'brand': u'ANAMAX', u'strength_3': u'', u'company': u'Bsp Ph.', u'unit': u''}

-- line #22730
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'ANANDBHAIRAV RAS (JWAR)', u'strength_3': u'', u'company': u'SHREE BAIDYA.', u'unit': u''}

-- line #22731
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'ANANDBHAIRAV RAS (KAS)', u'strength_3': u'', u'company': u'SHREE BAIDYA.', u'unit': u''}

-- line #22732
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'ANANDBHAIRAV RAS', u'strength_3': u'', u'company': u'SHREE BAIDYA.', u'unit': u''}

-- line #22733
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CRM SHAMPOO', u'brand': u'ANAPHASE SIMULATIN &', u'strength_3': u'', u'company': u'Piramal Hc.', u'unit': u''}

-- line #22734
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ANASTIN 10/20', u'strength_3': u'', u'company': u'Mano', u'unit': u''}

-- line #22735
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'EXP', u'brand': u'ANAVIL', u'strength_3': u'', u'company': u'Ethicare', u'unit': u''}

-- line #22736
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'EXP', u'brand': u'ANAVIL JR.', u'strength_3': u'', u'company': u'Ethicare', u'unit': u''}

-- line #22737
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'DPS', u'brand': u'ANAZOLE NASAL', u'strength_3': u'', u'company': u'M.S.Opth.', u'unit': u''}

-- line #22738
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ANAZOX', u'strength_3': u'', u'company': u'Bsp Ph.', u'unit': u''}

-- line #22739
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ANCAL-500', u'strength_3': u'', u'company': u'Anikem Lab.', u'unit': u''}

-- line #22740
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'ANCARE', u'strength_3': u'', u'company': u'Vital Care', u'unit': u''}

-- line #22741
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'OINT', u'brand': u'ANCARE', u'strength_3': u'', u'company': u'Vital Care', u'unit': u''}

-- line #22742
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'EYE DPS', u'brand': u'ANC', u'strength_3': u'', u'company': u'Appasamy', u'unit': u''}

-- line #22743
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYRUP', u'brand': u'ANCIK', u'strength_3': u'', u'company': u'APCIK PH.', u'unit': u''}

-- line #22744
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TABS.', u'brand': u'ANCIK', u'strength_3': u'', u'company': u'APCIK PH.', u'unit': u''}

-- line #22745
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ANDEP 2/5', u'strength_3': u'', u'company': u'ADISON PH.', u'unit': u''}

-- line #22746
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'F. TAB', u'brand': u'ANDOX', u'strength_3': u'', u'company': u'Marc Lab', u'unit': u''}

-- line #22747
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ANDOX PLUS', u'strength_3': u'', u'company': u'Marc Lab', u'unit': u''}

-- line #22748
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB/SYR', u'brand': u'ANDOX', u'strength_3': u'', u'company': u'Marc Lab', u'unit': u''}

-- line #22749
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ANDROGARDIAN', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #22750
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CHEWTAB', u'brand': u'ANDROVIT', u'strength_3': u'', u'company': u'Chemech', u'unit': u''}

-- line #22751
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ANFLAREX', u'strength_3': u'', u'company': u'Zorex Ph.', u'unit': u''}

-- line #22752
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'INJ', u'brand': u'ANGINOX 40', u'strength_3': u'', u'company': u'German R.', u'unit': u''}

-- line #22753
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'INJ', u'brand': u'ANGINOX 60', u'strength_3': u'', u'company': u'German R.', u'unit': u''}

-- line #22754
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'ANGOORASAVA', u'strength_3': u'', u'company': u'ZANDU', u'unit': u''}

-- line #22755
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'ANICAL-D', u'strength_3': u'', u'company': u'Anikem Lab.', u'unit': u''}

-- line #22756
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'POW', u'brand': u'ANIFOL', u'strength_3': u'', u'company': u'Anikem Lab.', u'unit': u''}

-- line #22757
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'MR TAB', u'brand': u'ANILIDE', u'strength_3': u'', u'company': u'Anikem Lab.', u'unit': u''}

-- line #22758
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'ANIPRO', u'strength_3': u'', u'company': u'ANQUIS(SANCHEZ)', u'unit': u''}

-- line #22759
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'ANJIKA', u'strength_3': u'', u'company': u'BIRLA LIFE', u'unit': u''}

-- line #22760
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CRM', u'brand': u'ANNEE', u'strength_3': u'', u'company': u'Yash Ph.', u'unit': u''}

-- line #22761
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'ANOFER', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #22762
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'LIQ', u'brand': u'ANOFER', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #22763
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'EYE DPS', u'brand': u'ANOFLOX-D', u'strength_3': u'', u'company': u'M.S.Opth.', u'unit': u''}

-- line #22764
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'EYE DPS', u'brand': u'ANOFLOX', u'strength_3': u'', u'company': u'M.S.Opth.', u'unit': u''}

-- line #22765
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'ANONE', u'strength_3': u'', u'company': u'Paras Lab', u'unit': u''}

-- line #22766
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ANOX-M', u'strength_3': u'', u'company': u'NORIS HC.', u'unit': u''}

-- line #22767
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ANOX-M', u'strength_3': u'', u'company': u'Norris Med.', u'unit': u''}

-- line #22768
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'INJ', u'brand': u'ANPY-12', u'strength_3': u'', u'company': u'Ophthal R.', u'unit': u''}

-- line #22769
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'F. TABS.', u'brand': u'ANSET', u'strength_3': u'', u'company': u'Bennet Ph.', u'unit': u''}

-- line #22770
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'INJ', u'brand': u'ANSET-R', u'strength_3': u'', u'company': u'Bennet Ph.', u'unit': u''}

-- line #22771
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYRUP', u'brand': u'ANSET', u'strength_3': u'', u'company': u'Bennet Ph.', u'unit': u''}

-- line #22772
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CRM SPF 30', u'brand': u'ANSOLAR DAILY USE GEL', u'strength_3': u'', u'company': u'GSK', u'unit': u''}

-- line #22773
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'LOT SPF 60', u'brand': u'ANSOLAR', u'strength_3': u'', u'company': u'GSK', u'unit': u''}

-- line #22774
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ANSPAR', u'strength_3': u'', u'company': u'ANHOX HC.', u'unit': u''}

-- line #22775
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ANSPAZ', u'strength_3': u'', u'company': u'Zorex Ph.', u'unit': u''}

-- line #22776
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SUS', u'brand': u'ANTAGEL MPS', u'strength_3': u'', u'company': u'ACE LAB.', u'unit': u''}

-- line #22777
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ANTELEPTIN', u'strength_3': u'', u'company': u'Fourrts', u'unit': u''}

-- line #22778
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ANTI-AZE', u'strength_3': u'', u'company': u'Marsai Ph.', u'unit': u''}

-- line #22779
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ANTIBACT-1', u'strength_3': u'', u'company': u'Serve Ph.', u'unit': u''}

-- line #22780
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'DROPS', u'brand': u'ANTICOL', u'strength_3': u'', u'company': u'Rhombic', u'unit': u''}

-- line #22781
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB/SYR', u'brand': u'ANTICOLD', u'strength_3': u'', u'company': u'Patson', u'unit': u''}

-- line #22782
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TABS.', u'brand': u'ANTICOL', u'strength_3': u'', u'company': u'Rhombic', u'unit': u''}

-- line #22783
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'LIQ', u'brand': u'ANTICO PLUS', u'strength_3': u'', u'company': u'AXYZEN LIFE', u'unit': u''}

-- line #22784
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'INJ', u'brand': u'ANTI-D', u'strength_3': u'', u'company': u'Chemech', u'unit': u''}

-- line #22785
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CRM', u'brand': u'ANTIDOL', u'strength_3': u'', u'company': u'Omega Ph.', u'unit': u''}

-- line #22786
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ANTIDOL-D', u'strength_3': u'', u'company': u'Omega Ph.', u'unit': u''}

-- line #22787
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'ANTIDOL KID/TAB', u'strength_3': u'', u'company': u'Omega Ph.', u'unit': u''}

-- line #22788
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ANTIDOL N/NP', u'strength_3': u'', u'company': u'Omega Ph.', u'unit': u''}

-- line #22789
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'ANTIF 50/150/200', u'strength_3': u'', u'company': u'TWILIGHT LIT.', u'unit': u''}

-- line #22790
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'ANTIFLU', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #22791
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'KIT', u'brand': u'ANTIF-X', u'strength_3': u'', u'company': u'TWILIGHT LIT.', u'unit': u''}

-- line #22792
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'ANTIHIST SY', u'strength_3': u'', u'company': u'Mepro Ph', u'unit': u''}

-- line #22793
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ANTIHIST', u'strength_3': u'', u'company': u'Mepro Ph', u'unit': u''}

-- line #22794
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'INJ', u'brand': u'ANTI-MAL', u'strength_3': u'', u'company': u'NORIS HC.', u'unit': u''}

-- line #22795
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ANTIMAL', u'strength_3': u'', u'company': u'BAJAJ CONS.', u'unit': u''}

-- line #22796
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'LIQ/TAB', u'brand': u'ANTIO', u'strength_3': u'', u'company': u'Neuron Ph.', u'unit': u''}

-- line #22797
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'ANTIONEM', u'strength_3': u'', u'company': u'NEMI PH.', u'unit': u''}

-- line #22798
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ANTIPAR PLUS', u'strength_3': u'', u'company': u'Emcure', u'unit': u''}

-- line #22799
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ANTIPLAR PLUS', u'strength_3': u'', u'company': u'Nucron Ph.', u'unit': u''}

-- line #22800
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ANTIPLATT PLUS 150', u'strength_3': u'', u'company': u'Troikaa', u'unit': u''}

-- line #22801
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ANTIPLATT PLUS 75', u'strength_3': u'', u'company': u'Troikaa', u'unit': u''}

-- line #22802
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ANTIPLATT', u'strength_3': u'', u'company': u'Troikaa', u'unit': u''}

-- line #22803
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'VACCINE', u'brand': u'ANTI RABIES', u'strength_3': u'', u'company': u'GEN BIO.', u'unit': u''}

-- line #22804
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ANTOP-D', u'strength_3': u'', u'company': u'Kay Pee', u'unit': u''}

-- line #22805
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'ANTOX', u'strength_3': u'', u'company': u'TASMED', u'unit': u''}

-- line #22806
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'ANTOXID', u'strength_3': u'', u'company': u"Dr.Reddy''S", u'unit': u''}

-- line #22807
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'ANTOXID C.C.', u'strength_3': u'', u'company': u"Dr.Reddy''S", u'unit': u''}

-- line #22808
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'HC CAP', u'brand': u'ANTOXID', u'strength_3': u'', u'company': u"Dr.Reddy''S", u'unit': u''}

-- line #22809
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ANTOXY-2', u'strength_3': u'', u'company': u'Parenteral', u'unit': u''}

-- line #22810
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'F. CAP', u'brand': u'ANTOXYL', u'strength_3': u'', u'company': u'TABLETS I.', u'unit': u''}

-- line #22811
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'ANTWIN', u'strength_3': u'', u'company': u'Mercury Hc.', u'unit': u''}

-- line #22812
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'INJ', u'brand': u'ANURIN-12', u'strength_3': u'', u'company': u'Biocin Hc.', u'unit': u''}

-- line #22813
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'DPS', u'brand': u'ANVASE', u'strength_3': u'', u'company': u'Ajanta Ph.', u'unit': u''}

-- line #22814
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP/SYR', u'brand': u'ANVTT', u'strength_3': u'', u'company': u'Aust Ind.', u'unit': u''}

-- line #22815
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ANXIMIND', u'strength_3': u'', u'company': u'BAJAJ CONS.', u'unit': u''}

-- line #22816
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ANXIONIL 2', u'strength_3': u'', u'company': u'KONARK LIFE', u'unit': u''}

-- line #22817
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ANXOREN 0.25/0.5', u'strength_3': u'', u'company': u'TWILIGHT LIT.', u'unit': u''}

-- line #22818
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'ANZEN', u'strength_3': u'', u'company': u'Uni-Sank.', u'unit': u''}

-- line #22819
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'ANZITEN 0.25MG.TABS.', u'strength_3': u'', u'company': u'Bsp Ph.', u'unit': u''}

-- line #22820
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'', u'brand': u'ANZITEN 0.50MG.TABS.', u'strength_3': u'', u'company': u'Bsp Ph.', u'unit': u''}

-- line #22821
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'AO2', u'strength_3': u'', u'company': u'SYNOPSIS', u'unit': u''}

-- line #22822
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'DPS', u'brand': u'AOBRA', u'strength_3': u'', u'company': u'Bsp Ph.', u'unit': u''}

-- line #22823
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'DROPS', u'brand': u'AOBRA EYE', u'strength_3': u'', u'company': u'AGAAZ OPTH.', u'unit': u''}

-- line #22824
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'AOL', u'strength_3': u'', u'company': u'Appasamy', u'unit': u''}

-- line #22825
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'GEL', u'brand': u'APALENE-C', u'strength_3': u'', u'company': u'Elder', u'unit': u''}

-- line #22826
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'F. TAB', u'brand': u'APCAL', u'strength_3': u'', u'company': u'Ajanta Ph.', u'unit': u''}

-- line #22827
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'DX', u'brand': u'APDROP', u'strength_3': u'', u'company': u'Ajanta Ph.', u'unit': u''}

-- line #22828
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'APEZYME', u'strength_3': u'', u'company': u'Stallion', u'unit': u''}

-- line #22829
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CRM', u'brand': u'APGEL', u'strength_3': u'', u'company': u'H & H Ph.', u'unit': u''}

-- line #22830
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'APICARE', u'strength_3': u'', u'company': u'AZME HC.', u'unit': u''}

-- line #22831
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR.', u'brand': u'APIMORE', u'strength_3': u'', u'company': u'Cfl Ph.', u'unit': u''}

-- line #22832
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'APIZ-10', u'strength_3': u'', u'company': u'Relience Form.', u'unit': u''}

-- line #22833
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'EYE DPS', u'brand': u'APPAMIDE', u'strength_3': u'', u'company': u'Appasamy', u'unit': u''}

-- line #22834
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'EYE DPS', u'brand': u'APPATOBA', u'strength_3': u'', u'company': u'Appasamy', u'unit': u''}

-- line #22835
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'APPIZ', u'strength_3': u'', u'company': u'Pacific Med.', u'unit': u''}

-- line #22836
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'GEL', u'brand': u'APPLEDENT JUNIOR', u'strength_3': u'', u'company': u'APPLEDENT ORAL', u'unit': u''}

-- line #22837
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'DPS', u'brand': u'APPRI PLUS', u'strength_3': u'', u'company': u'Rhombus', u'unit': u''}

-- line #22838
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'APPRI PLUS', u'strength_3': u'', u'company': u'Rhombus', u'unit': u''}

-- line #22839
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'DROPS', u'brand': u'APPRITOL', u'strength_3': u'', u'company': u'Rhombic', u'unit': u''}

-- line #22840
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR.', u'brand': u'APPRITOL', u'strength_3': u'', u'company': u'Rhombic', u'unit': u''}

-- line #22841
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TABS.', u'brand': u'APPRITOL', u'strength_3': u'', u'company': u'Rhombic', u'unit': u''}

-- line #22842
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'EYE DPS', u'brand': u'APRED', u'strength_3': u'', u'company': u'Appasamy', u'unit': u''}

-- line #22843
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'EYE DPS', u'brand': u'APRED-O', u'strength_3': u'', u'company': u'Appasamy', u'unit': u''}

-- line #22844
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'APRIGAN', u'strength_3': u'', u'company': u'Rhombic', u'unit': u''}

-- line #22845
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYRUP', u'brand': u'APROCIK', u'strength_3': u'', u'company': u'APCIK PH.', u'unit': u''}

-- line #22846
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'APROGEST 100', u'strength_3': u'', u'company': u'Ajanta Ph.', u'unit': u''}

-- line #22847
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'APROGEST 200', u'strength_3': u'', u'company': u'Ajanta Ph.', u'unit': u''}

-- line #22848
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'A SHAKTI RAS', u'strength_3': u'', u'company': u'SHREE BAIDYA.', u'unit': u''}

-- line #22849
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'DROPS', u'brand': u'A TO-Z', u'strength_3': u'', u'company': u'Alkem', u'unit': u''}

-- line #22850
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'CAP', u'brand': u'A TO-Z GOLD', u'strength_3': u'', u'company': u'Alkem', u'unit': u''}

-- line #22851
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'DPS', u'brand': u'A TO-Z NS', u'strength_3': u'', u'company': u'Alkem', u'unit': u''}

-- line #22852
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYRUP', u'brand': u'A TO-Z NS', u'strength_3': u'', u'company': u'Alkem', u'unit': u''}

-- line #22853
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'A TO-Z NS', u'strength_3': u'', u'company': u'Alkem', u'unit': u''}

-- line #22854
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'SYR', u'brand': u'A TO-Z', u'strength_3': u'', u'company': u'Alkem', u'unit': u''}

-- line #22855
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'N.I.', u'always_empty': u'', u'form': u'TAB', u'brand': u'A TO-Z', u'strength_3': u'', u'company': u'Alkem', u'unit': u''}

-- line #22856
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHOLERGOL 30 (Inga)',
	'Nicergoline',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHOLERGOL 30 (Inga)'
);

-- line #22857
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NICERBIUM 30 (Synchro)',
	'Nicergoline',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NICERBIUM 30 (Synchro)'
);

-- line #22858
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NICLOSAN 500 (Gsk)',
	'Niclosamide',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NICLOSAN 500 (Gsk)'
);

-- line #22859
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AV-COR 5 (GRANDIX)',
	'Nicorandil',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AV-COR 5 (GRANDIX)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AV-COR 10 (GRANDIX)',
	'Nicorandil',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AV-COR 10 (GRANDIX)'
);

-- line #22860
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVCOR 5 (Grandix)',
	'Nicorandil',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVCOR 5 (Grandix)'
);

-- line #22861
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORANDIL 48 (SUN)',
	'Nicorandil',
	'VIAL',
	gm.nullify_empty_string('48')::numeric,
	'mg(LYOPHILISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORANDIL 48 (SUN)'
);

-- line #22862
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORFLO 10 (Wockhardt)',
	'Nicorandil',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORFLO 10 (Wockhardt)'
);

-- line #22863
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORFLO 5 (Wockhardt)',
	'Nicorandil',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORFLO 5 (Wockhardt)'
);

-- line #22864
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILNICON 5 (VHB)',
	'Nicorandil',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILNICON 5 (VHB)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILNICON 10 (VHB)',
	'Nicorandil',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILNICON 10 (VHB)'
);

-- line #22865
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUORANDIL 10 (Sai Mirra)',
	'NICORANDIL',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUORANDIL 10 (Sai Mirra)'
);

-- line #22866
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUORANDIL 5 (Sai Mirra)',
	'NICORANDIL',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUORANDIL 5 (Sai Mirra)'
);

-- line #22867
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'K-COR 10 (Macleods)',
	'Nicorandil',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'K-COR 10 (Macleods)'
);

-- line #22868
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'K-COR 5 (Macleods)',
	'Nicorandil',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'K-COR 5 (Macleods)'
);

-- line #22869
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KORANDIL 10 (Sun)',
	'Nicorandil',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KORANDIL 10 (Sun)'
);

-- line #22870
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KORANDIL 5 (Sun)',
	'Nicorandil',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KORANDIL 5 (Sun)'
);

-- line #22871
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NICODUCE 10 (Piramal Hc.)',
	'Nicorandil',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NICODUCE 10 (Piramal Hc.)'
);

-- line #22872
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NICODUCE 5 (Piramal Hc.)',
	'Nicorandil',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NICODUCE 5 (Piramal Hc.)'
);

-- line #22873
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NICOSTAR 10 (Lupin)',
	'Nicorandil',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NICOSTAR 10 (Lupin)'
);

-- line #22874
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NICOSTAR 5 (Lupin)',
	'Nicorandil',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NICOSTAR 5 (Lupin)'
);

-- line #22875
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIDIL-5 5 (Chemo Bio.)',
	'Nicorandil',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIDIL-5 5 (Chemo Bio.)'
);

-- line #22876
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIKORAN 10 (TORRENT)',
	'Nicorandil',
	'SR TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg(SR)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIKORAN 10 (TORRENT)'
);

-- line #22877
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIKORAN 20 (TORRENT)',
	'Nicorandil',
	'SR TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg(SR)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIKORAN 20 (TORRENT)'
);

-- line #22878
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIKORAN 10 (Torrent)',
	'Nicorandil',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIKORAN 10 (Torrent)'
);

-- line #22879
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIKORAN 5 (Torrent)',
	'Nicorandil',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIKORAN 5 (Torrent)'
);

-- line #22880
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIKORAN 2 (Torrent)',
	'Nicorandil',
	'VIAL IV',
	gm.nullify_empty_string('2')::numeric,
	'mg/48'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIKORAN 2 (Torrent)'
);

-- line #22881
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUCORIL IV 48 (Emcure)',
	'Nicorandil',
	'INJ',
	gm.nullify_empty_string('48')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUCORIL IV 48 (Emcure)'
);

-- line #22882
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUCORIL 10 (Emcure)',
	'Nicorandil',
	'OD TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUCORIL 10 (Emcure)'
);

-- line #22883
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUCORIL 5 (Nucron Ph.)',
	'Nicorandil',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUCORIL 5 (Nucron Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUCORIL 10 (Nucron Ph.)',
	'Nicorandil',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUCORIL 10 (Nucron Ph.)'
);

-- line #22884
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUKONDIL IV 48 (Emcure)',
	'Nicorandil',
	'INJ',
	gm.nullify_empty_string('48')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUKONDIL IV 48 (Emcure)'
);

-- line #22885
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICOVIT 250 (Glow derma)',
	'NICOTINAMIDE',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICOVIT 250 (Glow derma)'
);

-- line #22886
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NICOVAS 1000 (Micro Labs)',
	'NICOTINATE',
	'TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg(INOSITOL NICOTINATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NICOVAS 1000 (Micro Labs)'
);

-- line #22887
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NICOVAS 500 (Micro Labs)',
	'NICOTINATE',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg(INOSITOL NICOTINATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NICOVAS 500 (Micro Labs)'
);

-- line #22888
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2', u'strength_2': u'', u'substance': u'NICOTINE', u'always_empty': u'', u'form': u'', u'brand': u'NICOCHEW CHEWING GUM', u'strength_3': u'', u'company': u'Cipla', u'unit': u'mg'}

-- line #22889
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'4', u'strength_2': u'', u'substance': u'NICOTINE', u'always_empty': u'', u'form': u'', u'brand': u'NICOCHEW CHEWING GUM', u'strength_3': u'', u'company': u'Cipla', u'unit': u'mg'}

-- line #22890
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2', u'strength_2': u'', u'substance': u'NICOTINE', u'always_empty': u'', u'form': u'', u'brand': u'NICOGUM CHEWING GUM', u'strength_3': u'', u'company': u'Cipla', u'unit': u'mg(NICOTINE POLACRILEX)'}

-- line #22891
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'4', u'strength_2': u'', u'substance': u'NICOTINE', u'always_empty': u'', u'form': u'', u'brand': u'NICOGUM CHEWING GUM', u'strength_3': u'', u'company': u'Cipla', u'unit': u'mg(NICOTINE POLACRILEX)'}

-- line #22892
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2', u'strength_2': u'', u'substance': u'NICOTINE', u'always_empty': u'', u'form': u'', u'brand': u'NICOTEX-2 CHEWING GUM', u'strength_3': u'', u'company': u'Cipla', u'unit': u'mg(NICOTINE POLACRILEX)'}

-- line #22893
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'4', u'strength_2': u'', u'substance': u'NICOTINE', u'always_empty': u'', u'form': u'', u'brand': u'NICOTEX-4 CHEWING GUM', u'strength_3': u'', u'company': u'Cipla', u'unit': u'mg(NICOTINE POLACRILEX)'}

-- line #22894
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NRT SOFTGEL 1 (Elder)',
	'NICOTINE',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg(FROM NICOTINE POLACRILAX USP)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NRT SOFTGEL 1 (Elder)'
);

-- line #22895
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NRT SOFTGEL 2 (Elder)',
	'NICOTINE',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg(FROM NICOTINE POLACRILAX USP)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NRT SOFTGEL 2 (Elder)'
);

-- line #22896
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NRT SOFTGEL 4 (Elder)',
	'NICOTINE',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg(FROM NICOTINE POLACRILAX USP)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NRT SOFTGEL 4 (Elder)'
);

-- line #22897
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1', u'strength_2': u'', u'substance': u'NICOTINE', u'always_empty': u'', u'form': u'', u'brand': u'NULIFE CHW GUM', u'strength_3': u'', u'company': u'Elder', u'unit': u'mg'}

-- line #22898
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2', u'strength_2': u'', u'substance': u'NICOTINE', u'always_empty': u'', u'form': u'', u'brand': u'NULIFE CHW GUM', u'strength_3': u'', u'company': u'Elder', u'unit': u'mg'}

-- line #22899
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'4', u'strength_2': u'', u'substance': u'NICOTINE', u'always_empty': u'', u'form': u'', u'brand': u'NULIFE CHW GUM', u'strength_3': u'', u'company': u'Elder', u'unit': u'mg'}

-- line #22900
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'17,5', u'strength_2': u'', u'substance': u'Nicotine Transdermal', u'always_empty': u'', u'form': u'', u'brand': u'NICOTINELL TTS (30)', u'strength_3': u'', u'company': u'Novartis', u'unit': u'mg'}

-- line #22901
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'35', u'strength_2': u'', u'substance': u'Nicotine Transdermal', u'always_empty': u'', u'form': u'', u'brand': u'NICOTINELL TTS (30)', u'strength_3': u'', u'company': u'Novartis', u'unit': u'mg'}

-- line #22902
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'52,7', u'strength_2': u'', u'substance': u'Nicotine Transdermal', u'always_empty': u'', u'form': u'', u'brand': u'NICOTINELL TTS (30)', u'strength_3': u'', u'company': u'Novartis', u'unit': u'mg'}

-- line #22903
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERHDL 500 (U S V)',
	'Nicotinic Acid',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERHDL 500 (U S V)'
);

-- line #22904
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEASYN 375 (Torrent)',
	'Nicotinic Acid',
	'SR TAB',
	gm.nullify_empty_string('375')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEASYN 375 (Torrent)'
);

-- line #22905
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEASYN 500 (Torrent)',
	'Nicotinic Acid',
	'SR TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEASYN 500 (Torrent)'
);

-- line #22906
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIALIP 375 (Dr.Reddy''S)',
	'Nicotinic Acid',
	'TAB',
	gm.nullify_empty_string('375')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIALIP 375 (Dr.Reddy''S)'
);

-- line #22907
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIALIP 500 (Dr.Reddy''S)',
	'Nicotinic Acid',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIALIP 500 (Dr.Reddy''S)'
);

-- line #22908
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIATROY 500 (Troikaa)',
	'NICOTINIC ACID',
	'SR TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIATROY 500 (Troikaa)'
);

-- line #22909
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NICOCIN 375 (Ordain Hc.)',
	'Nicotinic Acid',
	'ER TAB',
	gm.nullify_empty_string('375')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NICOCIN 375 (Ordain Hc.)'
);

-- line #22910
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACETHROMB 1 (Suvik Hit.)',
	'NICOUMALONE',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACETHROMB 1 (Suvik Hit.)'
);

-- line #22911
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACETHROMB 3 (Suvik Hit.)',
	'NICOUMALONE',
	'TAB',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACETHROMB 3 (Suvik Hit.)'
);

-- line #22912
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADALAT OROS 30 (Bayer)',
	'Nifedipine',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADALAT OROS 30 (Bayer)'
);

-- line #22913
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'11,76', u'strength_2': u'', u'substance': u'Nifedipine', u'always_empty': u'', u'form': u'TAB', u'brand': u'ADALAT RETARD', u'strength_3': u'', u'company': u'Bayer', u'unit': u''}

-- line #22914
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADALAT RETARD 20 (Bayer)',
	'Nifedipine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADALAT RETARD 20 (Bayer)'
);

-- line #22915
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANGIBLOCK 10 (Alkem)',
	'Nifedipine',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANGIBLOCK 10 (Alkem)'
);

-- line #22916
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANGIBLOCK 5 (Alkem)',
	'Nifedipine',
	'CAP',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANGIBLOCK 5 (Alkem)'
);

-- line #22917
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANGIBLOCK 20 (Alkem)',
	'Nifedipine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANGIBLOCK 20 (Alkem)'
);

-- line #22918
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALBLOC 10 (Unisearch)',
	'Nifedipine',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALBLOC 10 (Unisearch)'
);

-- line #22919
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALBLOC-R 10 (Unichem)',
	'Nifedipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALBLOC-R 10 (Unichem)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALBLOC-R 20 (Unichem)',
	'Nifedipine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALBLOC-R 20 (Unichem)'
);

-- line #22920
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALCIGARD 10 (Torrent)',
	'Nifedipine',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALCIGARD 10 (Torrent)'
);

-- line #22921
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALCIGARD 5 (Torrent)',
	'Nifedipine',
	'CAP',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALCIGARD 5 (Torrent)'
);

-- line #22922
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALCIGARD RTD 10 (Torrent)',
	'Nifedipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALCIGARD RTD 10 (Torrent)'
);

-- line #22923
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALCIGARD RTD 20 (Torrent)',
	'Nifedipine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALCIGARD RTD 20 (Torrent)'
);

-- line #22924
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALNIF RETARD 10 (Cadila Ph.)',
	'Nifedipine',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALNIF RETARD 10 (Cadila Ph.)'
);

-- line #22925
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALNIF RETARD 20 (Cadila Ph.)',
	'Nifedipine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALNIF RETARD 20 (Cadila Ph.)'
);

-- line #22926
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDILAT 10 (Mano)',
	'Nifedipine',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDILAT 10 (Mano)'
);

-- line #22927
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDILAT 5 (Mano)',
	'Nifedipine',
	'CAP',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDILAT 5 (Mano)'
);

-- line #22928
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDIPINE 5 (Intas)',
	'Nifedipine',
	'CAP',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDIPINE 5 (Intas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDIPINE 10 (Intas)',
	'Nifedipine',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDIPINE 10 (Intas)'
);

-- line #22929
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDIPINE 20 (INTAS)',
	'Nifedipine',
	'SR TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg(SS)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDIPINE 20 (INTAS)'
);

-- line #22930
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDULES 5 (Nicholas)',
	'Nifedipine',
	'CAP',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDULES 5 (Nicholas)'
);

-- line #22931
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDULES 10 (Piramal Hc.)',
	'Nifedipine',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDULES 10 (Piramal Hc.)'
);

-- line #22932
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDULES RET 10 (Piramal Hc.)',
	'Nifedipine',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDULES RET 10 (Piramal Hc.)'
);

-- line #22933
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDULES RET 20 (Piramal Hc.)',
	'Nifedipine',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDULES RET 20 (Piramal Hc.)'
);

-- line #22934
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLBLOC-R 20 (Unichem)',
	'Nifedipine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLBLOC-R 20 (Unichem)'
);

-- line #22935
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPICOR 10 (Merck)',
	'Nifedipine',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPICOR 10 (Merck)'
);

-- line #22936
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPICOR 5 (Merck)',
	'Nifedipine',
	'CAP',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPICOR 5 (Merck)'
);

-- line #22937
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPICOR 10 (Merck)',
	'Nifedipine',
	'SR TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPICOR 10 (Merck)'
);

-- line #22938
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPICOR 20 (Merck)',
	'Nifedipine',
	'SR TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPICOR 20 (Merck)'
);

-- line #22939
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPIN 10 (Zydus Cadila)',
	'Nifedipine',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPIN 10 (Zydus Cadila)'
);

-- line #22940
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPIN 5 (Zydus Cadila)',
	'Nifedipine',
	'CAP',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPIN 5 (Zydus Cadila)'
);

-- line #22941
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPIN-R 20 (Zydus Cadila)',
	'Nifedipine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPIN-R 20 (Zydus Cadila)'
);

-- line #22942
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPIN-R 30 (Zydus Cadila)',
	'Nifedipine',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPIN-R 30 (Zydus Cadila)'
);

-- line #22943
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYOGARD 20 (Rpg Life)',
	'Nifedipine',
	'LA TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYOGARD 20 (Rpg Life)'
);

-- line #22944
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYOGARD 30 (Rpg Life)',
	'Nifedipine',
	'OD TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYOGARD 30 (Rpg Life)'
);

-- line #22945
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYOGARD 10 (Rpg Life)',
	'Nifedipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYOGARD 10 (Rpg Life)'
);

-- line #22946
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYOGARD 20 (Rpg Life)',
	'Nifedipine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYOGARD 20 (Rpg Life)'
);

-- line #22947
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYOGARD 5 (Rpg Life)',
	'Nifedipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYOGARD 5 (Rpg Life)'
);

-- line #22948
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'N-DIP 10 (Taurus Lab)',
	'Nifedipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'N-DIP 10 (Taurus Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'N-DIP 20 (Taurus Lab)',
	'Nifedipine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'N-DIP 20 (Taurus Lab)'
);

-- line #22949
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEEDIN 10 (Stadmed)',
	'Nifedipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEEDIN 10 (Stadmed)'
);

-- line #22950
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEEDIN 20 (Stadmed)',
	'Nifedipine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEEDIN 20 (Stadmed)'
);

-- line #22951
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NF-10/20-R 10 (Sunij)',
	'Nifedipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NF-10/20-R 10 (Sunij)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NF-10/20-R 20 (Sunij)',
	'Nifedipine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NF-10/20-R 20 (Sunij)'
);

-- line #22952
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NICARDIA 10 (Unique)',
	'Nifedipine',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NICARDIA 10 (Unique)'
);

-- line #22953
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NICARDIA 5 (Unique)',
	'Nifedipine',
	'CAP',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NICARDIA 5 (Unique)'
);

-- line #22954
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NICARDIA CD-RETARD 30 (J. B. Chem.)',
	'Nifedipine',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NICARDIA CD-RETARD 30 (J. B. Chem.)'
);

-- line #22955
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NICARDIA RETARD 10 (Unique)',
	'Nifedipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NICARDIA RETARD 10 (Unique)'
);

-- line #22956
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NICARDIA RETARD 20 (Unique)',
	'Nifedipine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NICARDIA RETARD 20 (Unique)'
);

-- line #22957
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NICARDIA RETARD 30 (Unique)',
	'Nifedipine',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NICARDIA RETARD 30 (Unique)'
);

-- line #22958
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NICARDIA 30 (J.B. CHEM)',
	'Nifedipine',
	'XL',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NICARDIA 30 (J.B. CHEM)'
);

-- line #22959
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIFCARD 10 (Intra Lab)',
	'Nifedipine',
	'SR TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIFCARD 10 (Intra Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIFCARD 20 (Intra Lab)',
	'Nifedipine',
	'SR TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIFCARD 20 (Intra Lab)'
);

-- line #22960
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIF-D 5 (Guj. Liq.)',
	'Nifedipine',
	'CAP',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIF-D 5 (Guj. Liq.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIF-D 10 (Guj. Liq.)',
	'Nifedipine',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIF-D 10 (Guj. Liq.)'
);

-- line #22961
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIFEDINE 10 (Piramal Hc.)',
	'Nifedipine',
	'SR TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIFEDINE 10 (Piramal Hc.)'
);

-- line #22962
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIFEDINE 20 (Piramal Hc.)',
	'Nifedipine',
	'SR TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIFEDINE 20 (Piramal Hc.)'
);

-- line #22963
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIFEDINE 10 (Piramal Hc.)',
	'Nifedipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIFEDINE 10 (Piramal Hc.)'
);

-- line #22964
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIFEDINE 5 (Piramal Hc.)',
	'Nifedipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIFEDINE 5 (Piramal Hc.)'
);

-- line #22965
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIFELAT 10 (Cipla)',
	'Nifedipine',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIFELAT 10 (Cipla)'
);

-- line #22966
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIFELAT 5 (Cipla)',
	'Nifedipine',
	'CAP',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIFELAT 5 (Cipla)'
);

-- line #22967
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIFELAT-R 20 (Cipla)',
	'Nifedipine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIFELAT-R 20 (Cipla)'
);

-- line #22968
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIFERIL-R 20 (U S V)',
	'Nifedipine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIFERIL-R 20 (U S V)'
);

-- line #22969
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10', u'strength_2': u'', u'substance': u'Nifedipine', u'always_empty': u'', u'form': u'', u'brand': u'NIFIDIP-10', u'strength_3': u'', u'company': u'DAHLIA PH.', u'unit': u'mg'}

-- line #22970
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'Nifedipine', u'always_empty': u'', u'form': u'', u'brand': u'NIFIDIP-20', u'strength_3': u'', u'company': u'DAHLIA PH.', u'unit': u'mg'}

-- line #22971
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIFI 10 (Hal)',
	'Nifedipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIFI 10 (Hal)'
);

-- line #22972
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIFI 5 (Hal)',
	'Nifedipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIFI 5 (Hal)'
);

-- line #22973
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLBLOCK 20 (Olcare)',
	'Nifedipine',
	'SR TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLBLOCK 20 (Olcare)'
);

-- line #22974
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLBLOCK 10 (Olcare)',
	'Nifedipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLBLOCK 10 (Olcare)'
);

-- line #22975
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLBLOCK 5 (Olcare)',
	'Nifedipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLBLOCK 5 (Olcare)'
);

-- line #22976
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ABINIM-B 100 (Alpic Bio.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg(IN BETA CYCLODEXT.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ABINIM-B 100 (Alpic Bio.)'
);

-- line #22977
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ABINIM 50 (Alpic Bio.)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ABINIM 50 (Alpic Bio.)'
);

-- line #22978
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTINIM 100 (Active Hc.)',
	'Nimesulide',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTINIM 100 (Active Hc.)'
);

-- line #22979
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADENIM 50 (Swiss Ph.)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADENIM 50 (Swiss Ph.)'
);

-- line #22980
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADENIM 100 (Swiss Ph.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADENIM 100 (Swiss Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADENIM 200 (Swiss Ph.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADENIM 200 (Swiss Ph.)'
);

-- line #22981
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AGLONIM 50 (Aglowmed)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AGLONIM 50 (Aglowmed)'
);

-- line #22982
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AGLONIM 100 (Aglowmed)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AGLONIM 100 (Aglowmed)'
);

-- line #22983
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANAFEBRIN 50 (Themis)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANAFEBRIN 50 (Themis)'
);

-- line #22984
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANAFEBRIN 100 (Themis)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANAFEBRIN 100 (Themis)'
);

-- line #22985
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANILIDE 100 (Anikem Lab.)',
	'Nimesulide',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANILIDE 100 (Anikem Lab.)'
);

-- line #22986
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANILIDE 50 (Anikem Lab.)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANILIDE 50 (Anikem Lab.)'
);

-- line #22987
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANSAID 50 (Smiles Inc.)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANSAID 50 (Smiles Inc.)'
);

-- line #22988
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANSAID 100 (Smiles Inc.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANSAID 100 (Smiles Inc.)'
);

-- line #22989
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANTIPEN 50 (Mimec)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANTIPEN 50 (Mimec)'
);

-- line #22990
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANTIPEN 100 (Mimec)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANTIPEN 100 (Mimec)'
);

-- line #22991
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARLUSIDE 100 (Sterkem Ph.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARLUSIDE 100 (Sterkem Ph.)'
);

-- line #22992
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARTHOGESIC 50 (D.R.John''S)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARTHOGESIC 50 (D.R.John''S)'
);

-- line #22993
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARTHOGESIC 50 (D.R.John''S)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARTHOGESIC 50 (D.R.John''S)'
);

-- line #22994
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARTHORID 100 (D.R.John''S)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARTHORID 100 (D.R.John''S)'
);

-- line #22995
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AURONIM 50 (Aurobindo)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AURONIM 50 (Aurobindo)'
);

-- line #22996
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AURONIM 100 (Aurobindo)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AURONIM 100 (Aurobindo)'
);

-- line #22997
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVINIM 50 (Avalanche)',
	'NIMESULIDE',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVINIM 50 (Avalanche)'
);

-- line #22998
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVINIM 100 (Avalanche)',
	'NIMESULIDE',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVINIM 100 (Avalanche)'
);

-- line #22999
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVOLIDE 100 (Shreeyam)',
	'Nimesulide',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVOLIDE 100 (Shreeyam)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVOLIDE 200 (Shreeyam)',
	'Nimesulide',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVOLIDE 200 (Shreeyam)'
);

-- line #23000
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVOLIDE 50 (Shreeyam)',
	'Nimesulide',
	'KID TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVOLIDE 50 (Shreeyam)'
);

-- line #23001
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BASELIDE 100 (Ultramark)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BASELIDE 100 (Ultramark)'
);

-- line #23002
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BESTOGESIC 100 (Bestochem)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg(IN BETA CYCLODEX.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BESTOGESIC 100 (Bestochem)'
);

-- line #23003
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BESTONIM 50 (ALICON PH.)',
	'Nimesulide',
	'SUSP',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BESTONIM 50 (ALICON PH.)'
);

-- line #23004
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BESTONIM 100 (ALICON PH.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BESTONIM 100 (ALICON PH.)'
);

-- line #23005
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETA NICIP 100 (Cipla)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg(BETACYCLODEXT. 10'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETA NICIP 100 (Cipla)'
);

-- line #23006
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIO-NIM 50 (Bio-Drug)',
	'Nimesulide',
	'KID TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIO-NIM 50 (Bio-Drug)'
);

-- line #23007
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIO-NIM 100 (Bio-Drug)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIO-NIM 100 (Bio-Drug)'
);

-- line #23008
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLISULIDE 100 (Bliss)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLISULIDE 100 (Bliss)'
);

-- line #23009
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BOFLAM 100 (Neon)',
	'Nimesulide',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BOFLAM 100 (Neon)'
);

-- line #23010
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRINIMO 50 (Briskon)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRINIMO 50 (Briskon)'
);

-- line #23011
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRINIMO 100 (Briskon)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRINIMO 100 (Briskon)'
);

-- line #23012
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANMET 100 (Candor Bio.)',
	'Nimesulide',
	'MD TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANMET 100 (Candor Bio.)'
);

-- line #23013
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANMET 50 (Candor Bio.)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANMET 50 (Candor Bio.)'
);

-- line #23014
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CASLIDE 100 (CASCA)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CASLIDE 100 (CASCA)'
);

-- line #23015
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CATANIM 100 (ANAND HC.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CATANIM 100 (ANAND HC.)'
);

-- line #23016
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CERALIDE 50 (UNIKID)',
	'Nimesulide',
	'MD TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CERALIDE 50 (UNIKID)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CERALIDE 100 (UNIKID)',
	'Nimesulide',
	'MD TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CERALIDE 100 (UNIKID)'
);

-- line #23017
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-NIM 100 (CORONA)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-NIM 100 (CORONA)'
);

-- line #23018
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORNIM 50 (Corona)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORNIM 50 (Corona)'
);

-- line #23019
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORNIM 100 (Corona)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORNIM 100 (Corona)'
);

-- line #23020
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CURANIM 100 (Curewel)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CURANIM 100 (Curewel)'
);

-- line #23021
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DENIM 200 (Maneesh)',
	'Nimesulide',
	'DS JIUICY TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg(IN BETA CYCLODEX.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DENIM 200 (Maneesh)'
);

-- line #23022
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DENIM JUICY 50 (Maneesh)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML(BETA CYCLODEXTRINE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DENIM JUICY 50 (Maneesh)'
);

-- line #23023
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DENIM-JUICY 100 (Maneesh)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg(BETA CYCLODEXTRINE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DENIM-JUICY 100 (Maneesh)'
);

-- line #23024
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DENIM KID JUICY 50 (Maneesh)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg(IN BETA CYCLODEX.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DENIM KID JUICY 50 (Maneesh)'
);

-- line #23025
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIPLONIM 0.01 (PHARMATECH)',
	'Nimesulide',
	'GEL',
	gm.nullify_empty_string('0.01')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIPLONIM 0.01 (PHARMATECH)'
);

-- line #23026
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIPLONIM 50 (PHARMATECH)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIPLONIM 50 (PHARMATECH)'
);

-- line #23027
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIPLONIM 100 (PHARMATECH)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIPLONIM 100 (PHARMATECH)'
);

-- line #23028
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIPLONIM 200 (PHARMATECH)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIPLONIM 200 (PHARMATECH)'
);

-- line #23029
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DISPAR-N 100 (Rekvina)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DISPAR-N 100 (Rekvina)'
);

-- line #23030
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLIDE 50 (Embiotic Lab.)',
	'Nimesulide',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLIDE 50 (Embiotic Lab.)'
);

-- line #23031
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLIDE 50 (Embiotic Lab.)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLIDE 50 (Embiotic Lab.)'
);

-- line #23032
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLIDE 100 (Embiotic Lab.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLIDE 100 (Embiotic Lab.)'
);

-- line #23033
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLNIM 100 (SHRI SWAMI)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLNIM 100 (SHRI SWAMI)'
);

-- line #23034
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLOID FLASH 100 (NOVARTIS)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLOID FLASH 100 (NOVARTIS)'
);

-- line #23035
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLOID 50 (NOVARTIS)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLOID 50 (NOVARTIS)'
);

-- line #23036
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLOID 50 (NOVARTIS)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLOID 50 (NOVARTIS)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLOID 100 (NOVARTIS)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLOID 100 (NOVARTIS)'
);

-- line #23037
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLONIM 200 (Varun Life)',
	'Nimesulide',
	'SR CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLONIM 200 (Varun Life)'
);

-- line #23038
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLONIM 50 (Bipl(Radico Lab))',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLONIM 50 (Bipl(Radico Lab))'
);

-- line #23039
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLONIM 200 (Bipl(Radico Lab))',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLONIM 200 (Bipl(Radico Lab))'
);

-- line #23040
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYNALID 100 (Unimax Lab)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYNALID 100 (Unimax Lab)'
);

-- line #23041
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELIDE 50 (Eden Hc.)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELIDE 50 (Eden Hc.)'
);

-- line #23042
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELIDE 100 (Eden Hc.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELIDE 100 (Eden Hc.)'
);

-- line #23043
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMESULIDE 50 (Emcure)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMESULIDE 50 (Emcure)'
);

-- line #23044
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMESULIDE 100 (Emcure)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMESULIDE 100 (Emcure)'
);

-- line #23045
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMESULIDE 200 (Emcure)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMESULIDE 200 (Emcure)'
);

-- line #23046
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Nimesulide', u'always_empty': u'', u'form': u'GEL', u'brand': u'EMSULIDE', u'strength_3': u'', u'company': u'Emcure', u'unit': u''}

-- line #23047
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMSULIDE 50 (Emcure)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMSULIDE 50 (Emcure)'
);

-- line #23048
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMSULIDE 100 (Emcure)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMSULIDE 100 (Emcure)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMSULIDE 200 (Emcure)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMSULIDE 200 (Emcure)'
);

-- line #23049
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'E-NIM 100 (MARLINE BIO.)',
	'Nimesulide',
	'MD TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'E-NIM 100 (MARLINE BIO.)'
);

-- line #23050
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESULIDE 100 (MEDISYS)',
	'Nimesulide',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESULIDE 100 (MEDISYS)'
);

-- line #23051
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESULIDE 50 (MEDISYS)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESULIDE 50 (MEDISYS)'
);

-- line #23052
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FENIM 50 (Runa Ph.)',
	'Nimesulide',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FENIM 50 (Runa Ph.)'
);

-- line #23053
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FENIM 100 (Runa Ph.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FENIM 100 (Runa Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FENIM 200 (Runa Ph.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FENIM 200 (Runa Ph.)'
);

-- line #23054
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Nimesulide', u'always_empty': u'', u'form': u'INJ', u'brand': u'FINLIDE', u'strength_3': u'', u'company': u'Finesse Ph.', u'unit': u''}

-- line #23055
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLEXULID 50 (Wanbury)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLEXULID 50 (Wanbury)'
);

-- line #23056
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLEXULID 100 (Wanbury)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLEXULID 100 (Wanbury)'
);

-- line #23057
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEEFLAM 50 (Group Ph.)',
	'Nimesulide',
	'KT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEEFLAM 50 (Group Ph.)'
);

-- line #23058
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEEFLAM 50 (Group Ph.)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEEFLAM 50 (Group Ph.)'
);

-- line #23059
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENLIDE 100 (Cadila Ph.)',
	'NIMESULIDE',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENLIDE 100 (Cadila Ph.)'
);

-- line #23060
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENSULIDE 100 (Genix Ph.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENSULIDE 100 (Genix Ph.)'
);

-- line #23061
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLONIM 100 (GLOBELA PH.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg(IN BETA CYCLODEXT.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLONIM 100 (GLOBELA PH.)'
);

-- line #23062
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLONIM 100 (Siesta)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLONIM 100 (Siesta)'
);

-- line #23063
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HOPNIM 100 (Hope Life)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HOPNIM 100 (Hope Life)'
);

-- line #23064
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KIND 100 (Radix Bio.)',
	'Nimesulide',
	'MD TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KIND 100 (Radix Bio.)'
);

-- line #23065
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Nimesulide', u'always_empty': u'', u'form': u'SUS', u'brand': u'LIDE', u'strength_3': u'', u'company': u'SANCHEZ LAB.', u'unit': u''}

-- line #23066
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIDE 100 (SANCHEZ LAB.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIDE 100 (SANCHEZ LAB.)'
);

-- line #23067
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUMIN 100 (Water Lilly)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUMIN 100 (Water Lilly)'
);

-- line #23068
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUMIN 200 (Water Lilly)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUMIN 200 (Water Lilly)'
);

-- line #23069
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Nimesulide', u'always_empty': u'', u'form': u'GEL', u'brand': u'LUPISULIDE', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #23070
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Nimesulide', u'always_empty': u'', u'form': u'TAB', u'brand': u'LUPISULIDE', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #23071
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANGOLIDE 50 (Dwd)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANGOLIDE 50 (Dwd)'
);

-- line #23072
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANGOLIDE 100 (Dwd)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANGOLIDE 100 (Dwd)'
);

-- line #23073
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANIM 50 (Maan)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANIM 50 (Maan)'
);

-- line #23074
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANIM 100 (Maan)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANIM 100 (Maan)'
);

-- line #23075
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANLIDE 50 (Shalman)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANLIDE 50 (Shalman)'
);

-- line #23076
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANLIDE 100 (Shalman)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANLIDE 100 (Shalman)'
);

-- line #23077
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAXIFLAM 50 (Kapl)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAXIFLAM 50 (Kapl)'
);

-- line #23078
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAXIFLAM 100 (Kapl)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAXIFLAM 100 (Kapl)'
);

-- line #23079
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAXULIDE 100 (MAX)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAXULIDE 100 (MAX)'
);

-- line #23080
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Nimesulide', u'always_empty': u'', u'form': u'SYR', u'brand': u'MAZETOL', u'strength_3': u'', u'company': u'Shrinivas', u'unit': u''}

-- line #23081
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MESULID 50 (Stadmed)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MESULID 50 (Stadmed)'
);

-- line #23082
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MESULID 100 (Stadmed)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MESULID 100 (Stadmed)'
);

-- line #23083
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILENIM MANGOTAB 50 (Geno Ph.)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILENIM MANGOTAB 50 (Geno Ph.)'
);

-- line #23084
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILENIM MANGOTAB 100 (Geno Ph.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILENIM MANGOTAB 100 (Geno Ph.)'
);

-- line #23085
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILENIM 50 (Geno Ph.)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILENIM 50 (Geno Ph.)'
);

-- line #23086
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MINISULE 100 (Maneesh)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MINISULE 100 (Maneesh)'
);

-- line #23087
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOMELID 50 (Nestor)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOMELID 50 (Nestor)'
);

-- line #23088
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOMELID 100 (Nestor)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOMELID 100 (Nestor)'
);

-- line #23089
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOGESIC 10 (Bal Ph.)',
	'Nimesulide',
	'GEL',
	gm.nullify_empty_string('10')::numeric,
	'mg/G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOGESIC 10 (Bal Ph.)'
);

-- line #23090
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOGESIC 50 (Bal Ph.)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOGESIC 50 (Bal Ph.)'
);

-- line #23091
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOGESIC 100 (Bal Ph.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOGESIC 100 (Bal Ph.)'
);

-- line #23092
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOVOLID 100 (MICRO B. & B.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOVOLID 100 (MICRO B. & B.)'
);

-- line #23093
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYLID 50 (Numarck Ph.)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYLID 50 (Numarck Ph.)'
);

-- line #23094
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYLID 100 (Numarck Ph.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYLID 100 (Numarck Ph.)'
);

-- line #23095
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYONAL 50 (Uni-Sank.)',
	'Nimesulide',
	'KID TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYONAL 50 (Uni-Sank.)'
);

-- line #23096
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYONAL 50 (Uni-Sank.)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYONAL 50 (Uni-Sank.)'
);

-- line #23097
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYONAL 100 (Uni-Sank.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYONAL 100 (Uni-Sank.)'
);

-- line #23098
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NALGIS 50 (VERITAZ)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NALGIS 50 (VERITAZ)'
);

-- line #23099
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NALGIS 100 (VERITAZ)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NALGIS 100 (VERITAZ)'
);

-- line #23100
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAMOSID 50 (TAJ PH.)',
	'Nimesulide',
	'SUSP',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAMOSID 50 (TAJ PH.)'
);

-- line #23101
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAMOSID 50 (TAJ PH.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAMOSID 50 (TAJ PH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAMOSID 100 (TAJ PH.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAMOSID 100 (TAJ PH.)'
);

-- line #23102
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAM 50 (Lincoln)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAM 50 (Lincoln)'
);

-- line #23103
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAM 100 (Lincoln)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAM 100 (Lincoln)'
);

-- line #23104
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAM 200 (Lincoln)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAM 200 (Lincoln)'
);

-- line #23105
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAP 50 (Cubit Hc.)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAP 50 (Cubit Hc.)'
);

-- line #23106
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAP 100 (Cubit Hc.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAP 100 (Cubit Hc.)'
);

-- line #23107
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEEDFAST 50 (Acme Ph)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEEDFAST 50 (Acme Ph)'
);

-- line #23108
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEEDFAST 100 (Acme Ph)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEEDFAST 100 (Acme Ph)'
);

-- line #23109
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100', u'strength_2': u'', u'substance': u'Nimesulide', u'always_empty': u'', u'form': u'', u'brand': u'NEEMTAB', u'strength_3': u'', u'company': u'AMEE PH.', u'unit': u'mg'}

-- line #23110
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEET JUNIOR 50 (MADHAV BIO.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEET JUNIOR 50 (MADHAV BIO.)'
);

-- line #23111
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NELSID 100 (Ind-Swift)',
	'Nimesulide',
	'MD TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NELSID 100 (Ind-Swift)'
);

-- line #23112
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NELSID 50 (Ind-Swift)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NELSID 50 (Ind-Swift)'
);

-- line #23113
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NELSID 100 (Ind-Swift)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'200'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NELSID 100 (Ind-Swift)'
);

-- line #23114
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEMAREX 100 (Ar-Ex Labs.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEMAREX 100 (Ar-Ex Labs.)'
);

-- line #23115
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEMIL 50 (Kramer)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEMIL 50 (Kramer)'
);

-- line #23116
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEMIL 100 (Kramer)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEMIL 100 (Kramer)'
);

-- line #23117
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEMLIDE 100 (NEMI PH.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEMLIDE 100 (NEMI PH.)'
);

-- line #23118
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEMON 50 (Chemo D.)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEMON 50 (Chemo D.)'
);

-- line #23119
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEMON 100 (Chemo D.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEMON 100 (Chemo D.)'
);

-- line #23120
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Nimesulide', u'always_empty': u'', u'form': u'TAB', u'brand': u'NEMO', u'strength_3': u'', u'company': u'NIVCA', u'unit': u''}

-- line #23121
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEMUNAC 50 (Lancer)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEMUNAC 50 (Lancer)'
);

-- line #23122
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEMUNAC 100 (Lancer)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEMUNAC 100 (Lancer)'
);

-- line #23123
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEMU 50 (Rhombus)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEMU 50 (Rhombus)'
);

-- line #23124
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEMU 100 (Rhombus)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEMU 100 (Rhombus)'
);

-- line #23125
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NENCY 50 (Zenon Hc.)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NENCY 50 (Zenon Hc.)'
);

-- line #23126
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NENCY 100 (Zenon Hc.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg(MD)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NENCY 100 (Zenon Hc.)'
);

-- line #23127
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOSAID -P 50 (Blue Cross)',
	'Nimesulide',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOSAID -P 50 (Blue Cross)'
);

-- line #23128
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOSAID 50 (Blue Cross)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOSAID 50 (Blue Cross)'
);

-- line #23129
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOSAID 100 (Blue Cross)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOSAID 100 (Blue Cross)'
);

-- line #23130
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEULIDE 50 (EAST WEST)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEULIDE 50 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEULIDE 100 (EAST WEST)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEULIDE 100 (EAST WEST)'
);

-- line #23131
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEULITE 100 (Indica)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEULITE 100 (Indica)'
);

-- line #23132
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEVIS 100 (ORION BIOTECH.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEVIS 100 (ORION BIOTECH.)'
);

-- line #23133
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEWLIDE 100 (Allure Rem.)',
	'Nimesulide',
	'CD TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEWLIDE 100 (Allure Rem.)'
);

-- line #23134
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEWLIDE 50 (Allure Rem.)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEWLIDE 50 (Allure Rem.)'
);

-- line #23135
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEW NICIP 100 (Cipla)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEW NICIP 100 (Cipla)'
);

-- line #23136
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEXUS 100 (Lexus)',
	'Nimesulide',
	'MD TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEXUS 100 (Lexus)'
);

-- line #23137
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEXUS 50 (Lexus)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEXUS 50 (Lexus)'
);

-- line #23138
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NICALID 50 (Replica)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NICALID 50 (Replica)'
);

-- line #23139
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NICALID 100 (Replica)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NICALID 100 (Replica)'
);

-- line #23140
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NICIP 100 (Cipla)',
	'Nimesulide',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NICIP 100 (Cipla)'
);

-- line #23141
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NICIP 50 (Cipla)',
	'Nimesulide',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NICIP 50 (Cipla)'
);

-- line #23142
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NICIP 1 (Cipla)',
	'Nimesulide',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NICIP 1 (Cipla)'
);

-- line #23143
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NICIP 100 (Cipla)',
	'Nimesulide',
	'MD TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NICIP 100 (Cipla)'
);

-- line #23144
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NICIP 50 (Cipla)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NICIP 50 (Cipla)'
);

-- line #23145
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NICIP 100 (Cipla)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NICIP 100 (Cipla)'
);

-- line #23146
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NICIP 200 (Cipla)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NICIP 200 (Cipla)'
);

-- line #23147
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50', u'strength_2': u'100;ML', u'substance': u'Nimesulide', u'always_empty': u'', u'form': u'MD TAB', u'brand': u'NICKY', u'strength_3': u'', u'company': u'CHEMO HC.', u'unit': u''}

-- line #23148
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIDAL 100 (J.P. HC.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIDAL 100 (J.P. HC.)'
);

-- line #23149
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NID 200 (Logos)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NID 200 (Logos)'
);

-- line #23150
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIKEE RD 100 (Kee Ph.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIKEE RD 100 (Kee Ph.)'
);

-- line #23151
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIKEE 50 (Kee Ph.)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIKEE 50 (Kee Ph.)'
);

-- line #23152
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIKEE 100 (Kee Ph.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIKEE 100 (Kee Ph.)'
);

-- line #23153
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NILE 1 (Intra Lab)',
	'Nimesulide',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NILE 1 (Intra Lab)'
);

-- line #23154
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NILE 50 (Intra Lab)',
	'Nimesulide',
	'MD TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg(IIN BETACYCLODXT.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NILE 50 (Intra Lab)'
);

-- line #23155
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NILE 50 (Intra Lab)',
	'Nimesulide',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NILE 50 (Intra Lab)'
);

-- line #23156
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NILE 100 (Intra Lab)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NILE 100 (Intra Lab)'
);

-- line #23157
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NILE 100 (Nordic Ph.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NILE 100 (Nordic Ph.)'
);

-- line #23158
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NILIDE 10 (Le Sante)',
	'Nimesulide',
	'GEL',
	gm.nullify_empty_string('10')::numeric,
	'mg/G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NILIDE 10 (Le Sante)'
);

-- line #23159
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NILIDE 50 (Le Sante)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NILIDE 50 (Le Sante)'
);

-- line #23160
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NILIDE 100 (Le Sante)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NILIDE 100 (Le Sante)'
);

-- line #23161
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NILUP 60 (LUPINOVA)',
	'Nimesulide',
	'SUSP',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NILUP 60 (LUPINOVA)'
);

-- line #23162
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NILUP 100 (LUPINOVA)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NILUP 100 (LUPINOVA)'
);

-- line #23163
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMACE 100 (Indu D.)',
	'Nimesulide',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMACE 100 (Indu D.)'
);

-- line #23164
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMAC 100 (Mac)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMAC 100 (Mac)'
);

-- line #23165
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMACT 50 (Indu D.)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMACT 50 (Indu D.)'
);

-- line #23166
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMACT 50 (Life Line)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMACT 50 (Life Line)'
);

-- line #23167
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMACT 100 (Life Line)',
	'Nimesulide',
	'TAB/DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMACT 100 (Life Line)'
);

-- line #23168
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMACT 100 (Indu D.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMACT 100 (Indu D.)'
);

-- line #23169
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMACT 100 (Life Line)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMACT 100 (Life Line)'
);

-- line #23170
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMAGYL 100 (AKUM(WELCARE))',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMAGYL 100 (AKUM(WELCARE))'
);

-- line #23171
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMAGYL -TD 200 (AKUM(WELCARE))',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMAGYL -TD 200 (AKUM(WELCARE))'
);

-- line #23172
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMAGYL -TD 50 (AKUM(WELCARE))',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMAGYL -TD 50 (AKUM(WELCARE))'
);

-- line #23173
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMAID 100 (Winsome Lab)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMAID 100 (Winsome Lab)'
);

-- line #23174
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMAIM 50 (AIMCO PH.)',
	'Nimesulide',
	'KID TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMAIM 50 (AIMCO PH.)'
);

-- line #23175
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMAIM 50 (AIMCO PH.)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMAIM 50 (AIMCO PH.)'
);

-- line #23176
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMAIM 100 (AIMCO PH.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMAIM 100 (AIMCO PH.)'
);

-- line #23177
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMASUL 100 (BIOGEN PH.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMASUL 100 (BIOGEN PH.)'
);

-- line #23178
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMAT 100 (Atoz Ph.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMAT 100 (Atoz Ph.)'
);

-- line #23179
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMBET 100 (Maneesh)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg(BETA CYCLODEXTRINE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMBET 100 (Maneesh)'
);

-- line #23180
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMBID 50 (Astrazeneca)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMBID 50 (Astrazeneca)'
);

-- line #23181
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMBID 100 (Astrazeneca)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMBID 100 (Astrazeneca)'
);

-- line #23182
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMBU 100 (Sienna Form.)',
	'Nimesulide',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMBU 100 (Sienna Form.)'
);

-- line #23183
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMBUS 50 (Maraceae)',
	'Nimesulide',
	'KID TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMBUS 50 (Maraceae)'
);

-- line #23184
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'60ML', u'strength_2': u'', u'substance': u'Nimesulide', u'always_empty': u'', u'form': u'SUSP', u'brand': u'NIMBUS', u'strength_3': u'', u'company': u'Moraceae', u'unit': u''}

-- line #23185
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMBUS 100 (Moraceae)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMBUS 100 (Moraceae)'
);

-- line #23186
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMCARE 50 (Alde Medi.)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMCARE 50 (Alde Medi.)'
);

-- line #23187
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMCARE 100 (Alde Medi.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMCARE 100 (Alde Medi.)'
);

-- line #23188
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMCET 25 (Svizera)',
	'Nimesulide',
	'DPS',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMCET 25 (Svizera)'
);

-- line #23189
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMCET 100 (Svizera)',
	'Nimesulide',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMCET 100 (Svizera)'
);

-- line #23190
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMCET 50 (Svizera)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMCET 50 (Svizera)'
);

-- line #23191
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMDAL 100 (DATLA)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMDAL 100 (DATLA)'
);

-- line #23192
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NI 100 (Meridian)',
	'Nimesulide',
	'MD TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NI 100 (Meridian)'
);

-- line #23193
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMDUS 50 (Zydus Cadila)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMDUS 50 (Zydus Cadila)'
);

-- line #23194
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMEB 50 (Taurus Lab)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMEB 50 (Taurus Lab)'
);

-- line #23195
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMEB 100 (Taurus Lab)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMEB 100 (Taurus Lab)'
);

-- line #23196
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMED 100 (Medoz Ph.)',
	'Nimesulide',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMED 100 (Medoz Ph.)'
);

-- line #23197
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMEGESIC 25 (Alembic)',
	'Nimesulide',
	'DPS',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMEGESIC 25 (Alembic)'
);

-- line #23198
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMEGESIC-IR 100 (Alembic)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg (I.R.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMEGESIC-IR 100 (Alembic)'
);

-- line #23199
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMEGESIC 50 (Alembic)',
	'Nimesulide',
	'KID TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMEGESIC 50 (Alembic)'
);

-- line #23200
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMEGESIC 200 (Alembic)',
	'Nimesulide',
	'OD TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMEGESIC 200 (Alembic)'
);

-- line #23201
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMEGESIC 50 (Alembic)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMEGESIC 50 (Alembic)'
);

-- line #23202
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMEGESIC 100 (Alembic)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMEGESIC 100 (Alembic)'
);

-- line #23203
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMEGESIC TRANS 10 (Alembic)',
	'Nimesulide',
	'GEL',
	gm.nullify_empty_string('10')::numeric,
	'mg/G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMEGESIC TRANS 10 (Alembic)'
);

-- line #23204
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMELID 50 (Cosmas Ph.)',
	'Nimesulide',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMELID 50 (Cosmas Ph.)'
);

-- line #23205
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMEL 50 (ACTO)',
	'Nimesulide',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMEL 50 (ACTO)'
);

-- line #23206
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMEL 100 (ACTO)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMEL 100 (ACTO)'
);

-- line #23207
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMEL 50 (SAFE PH.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMEL 50 (SAFE PH.)'
);

-- line #23208
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMENIL 100 (ROHVEESHPRA PH.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMENIL 100 (ROHVEESHPRA PH.)'
);

-- line #23209
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMENT 25 (Ascent Lab)',
	'Nimesulide',
	'DPS',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMENT 25 (Ascent Lab)'
);

-- line #23210
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMENT 50 (Ascent Lab)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMENT 50 (Ascent Lab)'
);

-- line #23211
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMENT 100 (Ascent Lab)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMENT 100 (Ascent Lab)'
);

-- line #23212
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'NIMESULIDE', u'always_empty': u'', u'form': u'DS TAB', u'brand': u'NIMERA', u'strength_3': u'', u'company': u'Tanishq', u'unit': u''}

-- line #23213
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'NIMESULIDE', u'always_empty': u'', u'form': u'SUS', u'brand': u'NIMERA', u'strength_3': u'', u'company': u'Tanishq', u'unit': u''}

-- line #23214
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'NIMESULIDE', u'always_empty': u'', u'form': u'TAB', u'brand': u'NIMERA', u'strength_3': u'', u'company': u'Tanishq', u'unit': u''}

-- line #23215
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMERIL 100 (Albert D.)',
	'Nimesulide',
	'MD',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMERIL 100 (Albert D.)'
);

-- line #23216
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMERIL 50 (Albert D.)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMERIL 50 (Albert D.)'
);

-- line #23217
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMERIL 100 (Albert D.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMERIL 100 (Albert D.)'
);

-- line #23218
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMERON 100 (Ronak Lab.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMERON 100 (Ronak Lab.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMERON 200 (Ronak Lab.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMERON 200 (Ronak Lab.)'
);

-- line #23219
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMER 100 (Remedy)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMER 100 (Remedy)'
);

-- line #23220
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMESEL 1 (Waves Bio.)',
	'Nimesulide',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMESEL 1 (Waves Bio.)'
);

-- line #23221
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMESEL 50 (Waves Bio.)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMESEL 50 (Waves Bio.)'
);

-- line #23222
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMESEL 100 (Waves Bio.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMESEL 100 (Waves Bio.)'
);

-- line #23223
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMESH 50 (Dial Ph.)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMESH 50 (Dial Ph.)'
);

-- line #23224
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMESH 100 (Dial Ph.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMESH 100 (Dial Ph.)'
);

-- line #23225
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMESON 100 (Unison)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMESON 100 (Unison)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMESON 200 (Unison)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMESON 200 (Unison)'
);

-- line #23226
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMETIC 100 (TALENT LAB.)',
	'Nimesulide',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMETIC 100 (TALENT LAB.)'
);

-- line #23227
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMETIC 1 (TALENT LAB.)',
	'Nimesulide',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMETIC 1 (TALENT LAB.)'
);

-- line #23228
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMETIC 100 (TALENT LAB.)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMETIC 100 (TALENT LAB.)'
);

-- line #23229
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMEXIN 50 (Biocin Hc.)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMEXIN 50 (Biocin Hc.)'
);

-- line #23230
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMEXIN 100 (Biocin Hc.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMEXIN 100 (Biocin Hc.)'
);

-- line #23231
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMEX 100 (Lanark)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMEX 100 (Lanark)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMEX 200 (Lanark)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMEX 200 (Lanark)'
);

-- line #23232
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMEZ 50 (Zota)',
	'Nimesulide',
	'DT/ TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMEZ 50 (Zota)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMEZ 100 (Zota)',
	'Nimesulide',
	'DT/ TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMEZ 100 (Zota)'
);

-- line #23233
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMEZOBID 100 (AASHRAY)',
	'Nimesulide',
	'MD TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMEZOBID 100 (AASHRAY)'
);

-- line #23234
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMEZ 50 (Zota)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMEZ 50 (Zota)'
);

-- line #23235
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMEZ 100 (Kaizen Ph.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMEZ 100 (Kaizen Ph.)'
);

-- line #23236
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMFAST 1 (Indon)',
	'Nimesulide',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMFAST 1 (Indon)'
);

-- line #23237
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMFAST 50 (Zydus Cadila)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMFAST 50 (Zydus Cadila)'
);

-- line #23238
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMFAST 100 (Zydus Cadila)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMFAST 100 (Zydus Cadila)'
);

-- line #23239
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMFORD 100 (Ronak Lab.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMFORD 100 (Ronak Lab.)'
);

-- line #23240
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMFRESH 100 (SMART LAB.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMFRESH 100 (SMART LAB.)'
);

-- line #23241
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Nimesulide', u'always_empty': u'', u'form': u'DPS', u'brand': u'NIMICA', u'strength_3': u'', u'company': u'Ipca', u'unit': u''}

-- line #23242
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMICA 100 (Ipca)',
	'Nimesulide',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMICA 100 (Ipca)'
);

-- line #23243
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMICA 50 (Ipca)',
	'Nimesulide',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMICA 50 (Ipca)'
);

-- line #23244
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMICA 1 (Ipca)',
	'Nimesulide',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMICA 1 (Ipca)'
);

-- line #23245
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMICA 50 (Ipca)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMICA 50 (Ipca)'
);

-- line #23246
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMID 50 (Devi Form.)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMID 50 (Devi Form.)'
);

-- line #23247
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMID 100 (Devi Form.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMID 100 (Devi Form.)'
);

-- line #23248
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMIK 50 (Kaiser Ph.)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMIK 50 (Kaiser Ph.)'
);

-- line #23249
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMIK 100 (Kaiser Ph.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMIK 100 (Kaiser Ph.)'
);

-- line #23250
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMIL 100 (Shaimil)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMIL 100 (Shaimil)'
);

-- line #23251
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMI 100 (Shreya)',
	'Nimesulide',
	'MD TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMI 100 (Shreya)'
);

-- line #23252
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMIND 100 (Indoco Rem.)',
	'Nimesulide',
	'CHEW TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMIND 100 (Indoco Rem.)'
);

-- line #23253
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMIND-CT 100 (Indoco Rem.)',
	'Nimesulide',
	'CHEW TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMIND-CT 100 (Indoco Rem.)'
);

-- line #23254
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMIND 50 (Indoco Rem.)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMIND 50 (Indoco Rem.)'
);

-- line #23255
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMIND 100 (Indoco Rem.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMIND 100 (Indoco Rem.)'
);

-- line #23256
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMIRAD 100 (Raddison Hc.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMIRAD 100 (Raddison Hc.)'
);

-- line #23257
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMIRAL 50 (Arvind Lab.)',
	'Nimesulide',
	'ORAL SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMIRAL 50 (Arvind Lab.)'
);

-- line #23258
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMIRAL 100 (Arvind Lab.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMIRAL 100 (Arvind Lab.)'
);

-- line #23259
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMI-RAPI 1 (Shreya)',
	'Nimesulide',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMI-RAPI 1 (Shreya)'
);

-- line #23260
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMI-RAPI 50 (Shreya)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMI-RAPI 50 (Shreya)'
);

-- line #23261
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMI-RAPI 100 (Shreya)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMI-RAPI 100 (Shreya)'
);

-- line #23262
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMI-RAPI 50 (Shreya)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMI-RAPI 50 (Shreya)'
);

-- line #23263
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMISH 100 (ANQUIS(SANCHEZ))',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMISH 100 (ANQUIS(SANCHEZ))'
);

-- line #23264
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIM-I 100 (Indian R.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIM-I 100 (Indian R.)'
);

-- line #23265
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMITAG 100 (SMENTAG PH.)',
	'Nimesulide',
	'MD TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMITAG 100 (SMENTAG PH.)'
);

-- line #23266
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMIT 100 (Merit Org.)',
	'Nimesulide',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMIT 100 (Merit Org.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMIT 200 (Merit Org.)',
	'Nimesulide',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMIT 200 (Merit Org.)'
);

-- line #23267
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMIZ 100 (Zota PH.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMIZ 100 (Zota PH.)'
);

-- line #23268
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMKUL 200 (Finecure)',
	'Nimesulide',
	'DS TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMKUL 200 (Finecure)'
);

-- line #23269
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMKUL 50 (Finecure)',
	'Nimesulide',
	'KT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMKUL 50 (Finecure)'
);

-- line #23270
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMKUL 50 (Finecure)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMKUL 50 (Finecure)'
);

-- line #23271
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMKUL 100 (Finecure)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMKUL 100 (Finecure)'
);

-- line #23272
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMLI 100 (Aronex Life)',
	'Nimesulide',
	'MD TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMLI 100 (Aronex Life)'
);

-- line #23273
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMLIN 50 (Stallion)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMLIN 50 (Stallion)'
);

-- line #23274
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMLIN 100 (Stallion)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMLIN 100 (Stallion)'
);

-- line #23275
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMLODI 200 (Ajanta Ph.)',
	'Nimesulide',
	'CR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMLODI 200 (Ajanta Ph.)'
);

-- line #23276
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMLODI 400 (Ajanta Ph.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMLODI 400 (Ajanta Ph.)'
);

-- line #23277
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMNAC 100 (Nac Int.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMNAC 100 (Nac Int.)'
);

-- line #23278
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMNOR 100 (Nordic Ph.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMNOR 100 (Nordic Ph.)'
);

-- line #23279
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMOBID 50 (Mapra)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMOBID 50 (Mapra)'
);

-- line #23280
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMOBID 100 (Mapra)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMOBID 100 (Mapra)'
);

-- line #23281
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMODEX 100 (Khandelwal)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMODEX 100 (Khandelwal)'
);

-- line #23282
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMODOL 50 (Aristo)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMODOL 50 (Aristo)'
);

-- line #23283
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMODOL 100 (Aristo)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg(BETA CYCLODEXTRIN)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMODOL 100 (Aristo)'
);

-- line #23284
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMORAL 100 (MORAL)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMORAL 100 (MORAL)'
);

-- line #23285
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMORAN 100 (RADHE BIO.)',
	'Nimesulide',
	'MD TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMORAN 100 (RADHE BIO.)'
);

-- line #23286
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMORAN-P 125 (RADHE BIO.)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMORAN-P 125 (RADHE BIO.)'
);

-- line #23287
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMORAN 50 (Perch)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMORAN 50 (Perch)'
);

-- line #23288
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMORAN 50 (RADHE BIO.)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMORAN 50 (RADHE BIO.)'
);

-- line #23289
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMORAN 100 (Perch)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMORAN 100 (Perch)'
);

-- line #23290
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMORIL 50 (Brussels)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMORIL 50 (Brussels)'
);

-- line #23291
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMORIL 100 (Brussels)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMORIL 100 (Brussels)'
);

-- line #23292
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMOS-B 100 (Charmos Bio.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg(IN BETACYCLODEXT.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMOS-B 100 (Charmos Bio.)'
);

-- line #23293
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMOSIS 50 (SYNOPSIS)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMOSIS 50 (SYNOPSIS)'
);

-- line #23294
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMOS 100 (Charmos Bio.)',
	'Nimesulide',
	'MD TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMOS 100 (Charmos Bio.)'
);

-- line #23295
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMOS 50 (Charmos Bio.)',
	'Nimesulide',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMOS 50 (Charmos Bio.)'
);

-- line #23296
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMOTAS 100 (Intas)',
	'Nimesulide',
	'CD DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMOTAS 100 (Intas)'
);

-- line #23297
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMOTAS 50 (Intas)',
	'Nimesulide',
	'KT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMOTAS 50 (Intas)'
);

-- line #23298
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMOTAS 50 (Intas)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMOTAS 50 (Intas)'
);

-- line #23299
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMPAC 25 (Sysmed)',
	'Nimesulide',
	'DPS',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMPAC 25 (Sysmed)'
);

-- line #23300
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMPIC IR 100 (Parenteral)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMPIC IR 100 (Parenteral)'
);

-- line #23301
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMPREX 100 (Seagull)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMPREX 100 (Seagull)'
);

-- line #23302
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMP 100 (R.B.REM.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMP 100 (R.B.REM.)'
);

-- line #23303
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMPUS 100 (Ampus Life)',
	'Nimesulide',
	'SG CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMPUS 100 (Ampus Life)'
);

-- line #23304
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMPUS 50 (Ampus Life)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMPUS 50 (Ampus Life)'
);

-- line #23305
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMRAS 100 (RASS HC.)',
	'Nimesulide',
	'MD TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMRAS 100 (RASS HC.)'
);

-- line #23306
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMROD 50 (Drakt Int.)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMROD 50 (Drakt Int.)'
);

-- line #23307
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMROD 50 (Drakt Int.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMROD 50 (Drakt Int.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMROD 100 (Drakt Int.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMROD 100 (Drakt Int.)'
);

-- line #23308
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMSAFE 50 (Fairdeal Res.)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMSAFE 50 (Fairdeal Res.)'
);

-- line #23309
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMSAFE 100 (Fairdeal Res.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMSAFE 100 (Fairdeal Res.)'
);

-- line #23310
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMSAID 100 (Medley)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMSAID 100 (Medley)'
);

-- line #23311
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMSA 100 (Prochem)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMSA 100 (Prochem)'
);

-- line #23312
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMSTAL 50 (Indchemie)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMSTAL 50 (Indchemie)'
);

-- line #23313
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMSTAL 100 (Indchemie)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMSTAL 100 (Indchemie)'
);

-- line #23314
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMTAZ 100 (Health Care)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMTAZ 100 (Health Care)'
);

-- line #23315
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMTAZ 100 (Health Care)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMTAZ 100 (Health Care)'
);

-- line #23316
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMTECH 100 (Macleods)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg(BETA CYCLODEXTRIN)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMTECH 100 (Macleods)'
);

-- line #23317
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMTOP 100 (Reliance)',
	'Nimesulide',
	'MD TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMTOP 100 (Reliance)'
);

-- line #23318
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMTOP 50 (Reliance)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMTOP 50 (Reliance)'
);

-- line #23319
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMTOP 100 (Reliance)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMTOP 100 (Reliance)'
);

-- line #23320
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMTUS 100 (APTUS PH.)',
	'Nimesulide',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMTUS 100 (APTUS PH.)'
);

-- line #23321
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMUBA 100 (Bennet Ph.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMUBA 100 (Bennet Ph.)'
);

-- line #23322
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMUBOL 100 (Om Bio.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMUBOL 100 (Om Bio.)'
);

-- line #23323
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMUFLAM 100 (Nicholas)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMUFLAM 100 (Nicholas)'
);

-- line #23324
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMUFLEX 100 (Nicholas)',
	'Nimesulide',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMUFLEX 100 (Nicholas)'
);

-- line #23325
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMUFLEX 50 (Nicholas)',
	'Nimesulide',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMUFLEX 50 (Nicholas)'
);

-- line #23326
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,01', u'strength_2': u'', u'substance': u'Nimesulide', u'always_empty': u'', u'form': u'GEL', u'brand': u'NIMUFLEX', u'strength_3': u'', u'company': u'Nicholas', u'unit': u''}

-- line #23327
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMUFLEX 50 (Nicholas)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMUFLEX 50 (Nicholas)'
);

-- line #23328
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMUFLEX 100 (Nicholas)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMUFLEX 100 (Nicholas)'
);

-- line #23329
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMULA 50 (Jarson Ph.)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMULA 50 (Jarson Ph.)'
);

-- line #23330
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMULA 100 (Jarson Ph.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMULA 100 (Jarson Ph.)'
);

-- line #23331
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMULEX FD 50 (Pharmed)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMULEX FD 50 (Pharmed)'
);

-- line #23332
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMULEX FD 100 (Pharmed)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMULEX FD 100 (Pharmed)'
);

-- line #23333
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMULID 200 (Panacea)',
	'Nimesulide',
	'DT TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMULID 200 (Panacea)'
);

-- line #23334
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMULID EF 100 (Panacea)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMULID EF 100 (Panacea)'
);

-- line #23335
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMULID 50 (Panacea)',
	'Nimesulide',
	'KT/MD',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMULID 50 (Panacea)'
);

-- line #23336
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMULID 50 (Panacea)',
	'Nimesulide',
	'MD KID TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMULID 50 (Panacea)'
);

-- line #23337
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMULID 100 (Panacea)',
	'Nimesulide',
	'MD TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMULID 100 (Panacea)'
);

-- line #23338
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMULID SAFE 75 (Panacea)',
	'Nimesulide',
	'INJECT',
	gm.nullify_empty_string('75')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMULID SAFE 75 (Panacea)'
);

-- line #23339
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMULID 50 (Panacea)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMULID 50 (Panacea)'
);

-- line #23340
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMULID 100 (Panacea)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMULID 100 (Panacea)'
);

-- line #23341
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10', u'strength_2': u'', u'substance': u'Nimesulide', u'always_empty': u'', u'form': u'', u'brand': u'NIMULID TRANSGEL', u'strength_3': u'', u'company': u'Panacea', u'unit': u'mg'}

-- line #23342
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMUPAIN 100 (Cipla)',
	'Nimesulide',
	'MD TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMUPAIN 100 (Cipla)'
);

-- line #23343
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMUPAIN 50 (Cipla)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMUPAIN 50 (Cipla)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMUPAIN 100 (Cipla)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMUPAIN 100 (Cipla)'
);

-- line #23344
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMUSAN 100 (Sresan Ph.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMUSAN 100 (Sresan Ph.)'
);

-- line #23345
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMUSOL 50 (Lark Lab)',
	'Nimesulide',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMUSOL 50 (Lark Lab)'
);

-- line #23346
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMUSOL 50 (Lark Lab)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMUSOL 50 (Lark Lab)'
);

-- line #23347
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMUSOL 100 (Lark Lab)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMUSOL 100 (Lark Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMUSOL 200 (Lark Lab)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMUSOL 200 (Lark Lab)'
);

-- line #23348
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMUSPA 100 (Indoco Rem.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMUSPA 100 (Indoco Rem.)'
);

-- line #23349
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMUSTAR 1 (INVISION)',
	'Nimesulide',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMUSTAR 1 (INVISION)'
);

-- line #23350
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMUSTAR 50 (INVISION)',
	'Nimesulide',
	'SUSP',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMUSTAR 50 (INVISION)'
);

-- line #23351
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMUSTAR 100 (INVISION)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMUSTAR 100 (INVISION)'
);

-- line #23352
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMU 50 (Life Line)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMU 50 (Life Line)'
);

-- line #23353
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMUSYP 50 (Centaur)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMUSYP 50 (Centaur)'
);

-- line #23354
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMU 100 (Life Line)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMU 100 (Life Line)'
);

-- line #23355
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMUTAB 100 (Centaur)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMUTAB 100 (Centaur)'
);

-- line #23356
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMUWIN 50 (Ipca)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMUWIN 50 (Ipca)'
);

-- line #23357
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMUZEN 100 (Zenith Hc.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMUZEN 100 (Zenith Hc.)'
);

-- line #23358
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMUZEN 200 (Zenith Hc.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMUZEN 200 (Zenith Hc.)'
);

-- line #23359
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMVAR 100 (Zota Hc.)',
	'Nimesulide',
	'MD TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMVAR 100 (Zota Hc.)'
);

-- line #23360
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMVEN 100 (VENSAT)',
	'Nimesulide',
	'MD TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMVEN 100 (VENSAT)'
);

-- line #23361
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMVISTA 50 (Cadila Ph.)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMVISTA 50 (Cadila Ph.)'
);

-- line #23362
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMVISTA 100 (Cadila Ph.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMVISTA 100 (Cadila Ph.)'
);

-- line #23363
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMVON MD 50 (Ajanta Ph.)',
	'Nimesulide',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMVON MD 50 (Ajanta Ph.)'
);

-- line #23364
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMY 100 (SUBHREK PH.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMY 100 (SUBHREK PH.)'
);

-- line #23365
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMZE 50 (Franklin)',
	'Nimesulide',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMZE 50 (Franklin)'
);

-- line #23366
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMZE 50 (Franklin)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMZE 50 (Franklin)'
);

-- line #23367
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMZE 100 (Franklin)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMZE 100 (Franklin)'
);

-- line #23368
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIPACE 100 (Fem care)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg(BETA CYCLODEXTRINE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIPACE 100 (Fem care)'
);

-- line #23369
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIPPY 50 (Baroque)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIPPY 50 (Baroque)'
);

-- line #23370
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIPPY 100 (Baroque)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIPPY 100 (Baroque)'
);

-- line #23371
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIQ 100 (Que Ph.)',
	'Nimesulide',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIQ 100 (Que Ph.)'
);

-- line #23372
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NISE 50 (Dr.Reddy''S)',
	'Nimesulide',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NISE 50 (Dr.Reddy''S)'
);

-- line #23373
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NISE 10 (Dr.Reddy''S)',
	'Nimesulide',
	'GEL',
	gm.nullify_empty_string('10')::numeric,
	'mg/G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NISE 10 (Dr.Reddy''S)'
);

-- line #23374
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Nimesulide', u'always_empty': u'', u'form': u'INJ', u'brand': u'NISE', u'strength_3': u'', u'company': u"Dr.Reddy''S", u'unit': u''}

-- line #23375
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NISE 50 (Dr.Reddy''S)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NISE 50 (Dr.Reddy''S)'
);

-- line #23376
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NISE 100 (Dr.Reddy''S)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NISE 100 (Dr.Reddy''S)'
);

-- line #23377
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NISULID 100 (PSYCOREM)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NISULID 100 (PSYCOREM)'
);

-- line #23378
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NISUL 100 (Arbro Ph.)',
	'Nimesulide',
	'MD TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NISUL 100 (Arbro Ph.)'
);

-- line #23379
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NISUL 50 (Arbro Ph.)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NISUL 50 (Arbro Ph.)'
);

-- line #23380
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NISUL 100 (Arbro Ph.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NISUL 100 (Arbro Ph.)'
);

-- line #23381
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Nimesulide', u'always_empty': u'', u'form': u'MD TAB', u'brand': u'NIT', u'strength_3': u'', u'company': u'TRIDENT PH.', u'unit': u''}

-- line #23382
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIXIA 25 (Wanbury)',
	'Nimesulide',
	'DPS',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIXIA 25 (Wanbury)'
);

-- line #23383
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIXIA 50 (Wanbury)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIXIA 50 (Wanbury)'
);

-- line #23384
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIXIA 100 (Wanbury)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIXIA 100 (Wanbury)'
);

-- line #23385
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIZER 50 (U S V)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIZER 50 (U S V)'
);

-- line #23386
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIZER 100 (U S V)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg(BETA CYCLODEXTRINE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIZER 100 (U S V)'
);

-- line #23387
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'N-LID 100 (Orchid Hc.)',
	'Nimesulide',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'N-LID 100 (Orchid Hc.)'
);

-- line #23388
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Nimesulide', u'always_empty': u'', u'form': u'GEL', u'brand': u'N-LID', u'strength_3': u'', u'company': u'Orchid Hc.', u'unit': u''}

-- line #23389
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'N-LID 50 (Orchid Hc.)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'N-LID 50 (Orchid Hc.)'
);

-- line #23390
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NMD 150 (GRANDIX)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NMD 150 (GRANDIX)'
);

-- line #23391
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NMD 50 (GRANDIX)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NMD 50 (GRANDIX)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NMD 100 (GRANDIX)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NMD 100 (GRANDIX)'
);

-- line #23392
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOBEL 100 (Mankind)',
	'Nimesulide',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg (BETA CYCLODEXTRINE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOBEL 100 (Mankind)'
);

-- line #23393
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOBEL 25 (Mankind)',
	'Nimesulide',
	'DPS',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOBEL 25 (Mankind)'
);

-- line #23394
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOBEL 50 (Mankind)',
	'Nimesulide',
	'KID TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOBEL 50 (Mankind)'
);

-- line #23395
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOBEL 100 (Mankind)',
	'Nimesulide',
	'MD TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOBEL 100 (Mankind)'
);

-- line #23396
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOBEL 50 (Mankind)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML(BETA CYCLODEXTRINE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOBEL 50 (Mankind)'
);

-- line #23397
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOBEL 100 (Mankind)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg/200'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOBEL 100 (Mankind)'
);

-- line #23398
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NODARD 100 (Cipla)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NODARD 100 (Cipla)'
);

-- line #23399
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOK 50 (Dr.Arvind Shah''S)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOK 50 (Dr.Arvind Shah''S)'
);

-- line #23400
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOPAIN 50 (Graf Lab.)',
	'Nimesulide',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOPAIN 50 (Graf Lab.)'
);

-- line #23401
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOPAIN 100 (Graf Lab.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOPAIN 100 (Graf Lab.)'
);

-- line #23402
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORSULID 1 (Norris Med.)',
	'Nimesulide',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORSULID 1 (Norris Med.)'
);

-- line #23403
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORSULID 50 (Norris Med.)',
	'Nimesulide',
	'SUS(*)',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORSULID 50 (Norris Med.)'
);

-- line #23404
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORSULID 100 (Norris Med.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORSULID 100 (Norris Med.)'
);

-- line #23405
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVOGESIC 50 (Glenmark)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVOGESIC 50 (Glenmark)'
);

-- line #23406
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVOGESIC 100 (Glenmark)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVOGESIC 100 (Glenmark)'
);

-- line #23407
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVOLID 1 (Brown & B.)',
	'Nimesulide',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVOLID 1 (Brown & B.)'
);

-- line #23408
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVOLID 50 (Brown & B.)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVOLID 50 (Brown & B.)'
);

-- line #23409
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVOLID 100 (Brown & B.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVOLID 100 (Brown & B.)'
);

-- line #23410
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'N-SIDE BETA 100 (Cfl Ph.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg (BETA CYCLODEXTRINE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'N-SIDE BETA 100 (Cfl Ph.)'
);

-- line #23411
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'N-SIDE 50 (Cfl Ph.)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'N-SIDE 50 (Cfl Ph.)'
);

-- line #23412
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'N-SIDE 100 (Cfl Ph.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'N-SIDE 100 (Cfl Ph.)'
);

-- line #23413
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUDIL 100 (Mamta Ph.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUDIL 100 (Mamta Ph.)'
);

-- line #23414
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUGESIC 100 (UNIMARK REM.)',
	'Nimesulide',
	'MD TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUGESIC 100 (UNIMARK REM.)'
);

-- line #23415
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUGESIC 50 (Unimarck)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUGESIC 50 (Unimarck)'
);

-- line #23416
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUGESIC 100 (Unimarck)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUGESIC 100 (Unimarck)'
);

-- line #23417
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NULEB 50 (Leben)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NULEB 50 (Leben)'
);

-- line #23418
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NULEB 100 (Leben)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NULEB 100 (Leben)'
);

-- line #23419
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NULIDE 100 (Allied Ch.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NULIDE 100 (Allied Ch.)'
);

-- line #23420
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NULIDE 100 (Neon)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NULIDE 100 (Neon)'
);

-- line #23421
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUMEL 50 (Elysium)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUMEL 50 (Elysium)'
);

-- line #23422
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUMEL 100 (Elysium)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUMEL 100 (Elysium)'
);

-- line #23423
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUMIDOL 100 (Ophthal R.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUMIDOL 100 (Ophthal R.)'
);

-- line #23424
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NYDE 50 (Patson)',
	'Nimesulide',
	'SUS/TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML/100'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NYDE 50 (Patson)'
);

-- line #23425
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLNIM 100 (Olcare)',
	'Nimesulide',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLNIM 100 (Olcare)'
);

-- line #23426
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLNIM 100 (Olcare)',
	'Nimesulide',
	'MD TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLNIM 100 (Olcare)'
);

-- line #23427
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLNIM 50 (Olcare)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLNIM 50 (Olcare)'
);

-- line #23428
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLNIM 100 (Olcare)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLNIM 100 (Olcare)'
);

-- line #23429
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLNIM 200 (Olcare)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLNIM 200 (Olcare)'
);

-- line #23430
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1', u'strength_2': u'', u'substance': u'Nimesulide', u'always_empty': u'', u'form': u'', u'brand': u'OLNIM TRANSGEL', u'strength_3': u'', u'company': u'Olcare', u'unit': u'%W/W'}

-- line #23431
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONALIDE 100 (Sayona)',
	'Nimesulide',
	'MD TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONALIDE 100 (Sayona)'
);

-- line #23432
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONIM 100 (Shreya)',
	'Nimesulide',
	'MD TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg(BETA CYCLODEXTRINE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONIM 100 (Shreya)'
);

-- line #23433
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONIM 50 (ARLOP PH.)',
	'Nimesulide',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONIM 50 (ARLOP PH.)'
);

-- line #23434
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONIM 100 (ARLOP PH.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONIM 100 (ARLOP PH.)'
);

-- line #23435
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPEL 50 (Stanford)',
	'Nimesulide',
	'KID TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPEL 50 (Stanford)'
);

-- line #23436
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPEL 100 (Stanford)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPEL 100 (Stanford)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPEL 200 (Stanford)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPEL 200 (Stanford)'
);

-- line #23437
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORNIM 50 (Dynamic)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORNIM 50 (Dynamic)'
);

-- line #23438
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORNIM 100 (Dynamic)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORNIM 100 (Dynamic)'
);

-- line #23439
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORTHOBID 1 (Nicholas)',
	'Nimesulide',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORTHOBID 1 (Nicholas)'
);

-- line #23440
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORTHOBID 50 (Nicholas)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORTHOBID 50 (Nicholas)'
);

-- line #23441
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORTHOBID 100 (Nicholas)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORTHOBID 100 (Nicholas)'
);

-- line #23442
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORTHOGESIC 50 (TWILIGHT LIT.)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORTHOGESIC 50 (TWILIGHT LIT.)'
);

-- line #23443
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORTHOGESIC 100 (TWILIGHT LIT.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORTHOGESIC 100 (TWILIGHT LIT.)'
);

-- line #23444
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSONIM 200 (Osper)',
	'Nimesulide',
	'MD TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSONIM 200 (Osper)'
);

-- line #23445
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSONIM 100 (Osper)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'200'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSONIM 100 (Osper)'
);

-- line #23446
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXIN 50 (Synokem)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXIN 50 (Synokem)'
);

-- line #23447
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXIN 100 (Synokem)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXIN 100 (Synokem)'
);

-- line #23448
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXIN 200 (Synokem)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXIN 200 (Synokem)'
);

-- line #23449
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANIM 200 (Panjon)',
	'Nimesulide',
	'CR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANIM 200 (Panjon)'
);

-- line #23450
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANIM 1 (Panjon)',
	'Nimesulide',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANIM 1 (Panjon)'
);

-- line #23451
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANIM 100 (Panjon)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANIM 100 (Panjon)'
);

-- line #23452
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANSULIDE-RD 100 (Rusan Hc)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANSULIDE-RD 100 (Rusan Hc)'
);

-- line #23453
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARALIDE 50 (Lenit Ph.)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARALIDE 50 (Lenit Ph.)'
);

-- line #23454
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARALIDE 100 (Lenit Ph.)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARALIDE 100 (Lenit Ph.)'
);

-- line #23455
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAS-IR 100 (Aquila)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg(I.R.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAS-IR 100 (Aquila)'
);

-- line #23456
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAS 100 (Aquila)',
	'Nimesulide',
	'MD TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAS 100 (Aquila)'
);

-- line #23457
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAS 50 (Aquila)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAS 50 (Aquila)'
);

-- line #23458
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAS 100 (Aquila)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAS 100 (Aquila)'
);

-- line #23459
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRONIM 50 (Unichem)',
	'Nimesulide',
	'KT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRONIM 50 (Unichem)'
);

-- line #23460
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRONIM QR 100 (Unichem)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRONIM QR 100 (Unichem)'
);

-- line #23461
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRONIM 50 (Unichem)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRONIM 50 (Unichem)'
);

-- line #23462
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRONIM 100 (Unichem)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRONIM 100 (Unichem)'
);

-- line #23463
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRONIM 200 (Unichem)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRONIM 200 (Unichem)'
);

-- line #23464
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYRANIM 50 (Saga Lab)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYRANIM 50 (Saga Lab)'
);

-- line #23465
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYRANIM 100 (Saga Lab)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYRANIM 100 (Saga Lab)'
);

-- line #23466
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYREXICARE 50 (Lifeon)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg;5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYREXICARE 50 (Lifeon)'
);

-- line #23467
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RALGESIC 100 (Shreya)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RALGESIC 100 (Shreya)'
);

-- line #23468
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REDFAST 50 (Marc Lab)',
	'Nimesulide',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REDFAST 50 (Marc Lab)'
);

-- line #23469
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REDFAST 100 (Marc Lab)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REDFAST 100 (Marc Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REDFAST 200 (Marc Lab)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REDFAST 200 (Marc Lab)'
);

-- line #23470
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REDYNISE 100 (DR. REDDY''S)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REDYNISE 100 (DR. REDDY''S)'
);

-- line #23471
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELIDE 50 (Regent)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELIDE 50 (Regent)'
);

-- line #23472
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELIDE 100 (Regent)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELIDE 100 (Regent)'
);

-- line #23473
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELISULIDE 50 (Jagdale)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELISULIDE 50 (Jagdale)'
);

-- line #23474
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELISULIDE 50 (Juggat)',
	'Nimesulide',
	'SUSP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELISULIDE 50 (Juggat)'
);

-- line #23475
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELISULIDE 100 (Jagdale)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELISULIDE 100 (Jagdale)'
);

-- line #23476
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REMULIDE 1 (Zydus Cadila)',
	'Nimesulide',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REMULIDE 1 (Zydus Cadila)'
);

-- line #23477
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REMULIDE 50 (Zydus Cadila)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REMULIDE 50 (Zydus Cadila)'
);

-- line #23478
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REMULIDE 100 (Zydus Cadila)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REMULIDE 100 (Zydus Cadila)'
);

-- line #23479
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIMS 50 (LUSTRE)',
	'Nimesulide',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIMS 50 (LUSTRE)'
);

-- line #23480
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIMS 100 (LUSTRE)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIMS 100 (LUSTRE)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIMS 200 (LUSTRE)',
	'Nimesulide',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIMS 200 (LUSTRE)'
);

-- line #23481
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MODIPIN 30 (Cadila Ph.)',
	'Nimodipine',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MODIPIN 30 (Cadila Ph.)'
);

-- line #23482
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MODIPIN 10 (Cadila Ph.)',
	'Nimodipine',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg/50ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MODIPIN 10 (Cadila Ph.)'
);

-- line #23483
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMOCER 30 (Synapse)',
	'Nimodipine',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMOCER 30 (Synapse)'
);

-- line #23484
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMODIP 10 (U S V)',
	'Nimodipine',
	'INF',
	gm.nullify_empty_string('10')::numeric,
	'mg/50ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMODIP 10 (U S V)'
);

-- line #23485
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMODIP 30 (U S V)',
	'Nimodipine',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMODIP 30 (U S V)'
);

-- line #23486
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMOTIDE 30 (Torrent)',
	'Nimodipine',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMOTIDE 30 (Torrent)'
);

-- line #23487
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMPOD 30 (Intas)',
	'Nimodipine',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMPOD 30 (Intas)'
);

-- line #23488
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOMAB EGFR 50 (Biocon)',
	'NIMOTUZUMAB',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOMAB EGFR 50 (Biocon)'
);

-- line #23489
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10', u'strength_2': u'20', u'substance': u'NIRPID INTRAVENOUS FAT EMULSION', u'always_empty': u'', u'form': u'', u'brand': u'NIRPID IV', u'strength_3': u'', u'company': u'NIRLIFE HEALTH', u'unit': u'%'}

-- line #23490
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEHULOX 200 (Heal All Ph.)',
	'NITAZOXANIDE',
	'DT/500 TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEHULOX 200 (Heal All Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEHULOX 500 (Heal All Ph.)',
	'NITAZOXANIDE',
	'DT/500 TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEHULOX 500 (Heal All Ph.)'
);

-- line #23491
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEHULOX 100 (Heal All Ph.)',
	'NITAZOXANIDE',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEHULOX 100 (Heal All Ph.)'
);

-- line #23492
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NETAZOX 100 (Ind-Swift)',
	'NITAZOXANIDE',
	'SUSP',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NETAZOX 100 (Ind-Swift)'
);

-- line #23493
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NETAZOX 200 (Ind-Swift)',
	'NITAZOXANIDE',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'500'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NETAZOX 200 (Ind-Swift)'
);

-- line #23494
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITACURE 100 (Alembic)',
	'NITAZOXANIDE',
	'D.SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITACURE 100 (Alembic)'
);

-- line #23495
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITACURE 200 (Alembic)',
	'NITAZOXANIDE',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITACURE 200 (Alembic)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITACURE 500 (Alembic)',
	'NITAZOXANIDE',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITACURE 500 (Alembic)'
);

-- line #23496
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10G', u'strength_2': u'30ML', u'substance': u'NITAZOXANIDE', u'always_empty': u'', u'form': u'D.SYR', u'brand': u'NITARID', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #23497
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITARID 200 (Cipla)',
	'NITAZOXANIDE',
	'DT/500 TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITARID 200 (Cipla)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITARID 500 (Cipla)',
	'NITAZOXANIDE',
	'DT/500 TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITARID 500 (Cipla)'
);

-- line #23498
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITAZET 200 (Glenmark)',
	'NITAZOXANIDE',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITAZET 200 (Glenmark)'
);

-- line #23499
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITAZET 100 (Glenmark)',
	'NITAZOXANIDE',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITAZET 100 (Glenmark)'
);

-- line #23500
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITAZET 500 (Glenmark)',
	'NITAZOXANIDE',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITAZET 500 (Glenmark)'
);

-- line #23501
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITZIX 100 (AAMORB)',
	'NITAZOXANIDE',
	'SUSP',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITZIX 100 (AAMORB)'
);

-- line #23502
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITZIX 500 (AAMORB)',
	'NITAZOXANIDE',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITZIX 500 (AAMORB)'
);

-- line #23503
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIZONIDE 200 (Lupin)',
	'NITAZOXANIDE',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIZONIDE 200 (Lupin)'
);

-- line #23504
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIZONIDE 100 (Lupin)',
	'NITAZOXANIDE',
	'SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIZONIDE 100 (Lupin)'
);

-- line #23505
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIZONIDE 500 (Lupin)',
	'NITAZOXANIDE',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIZONIDE 500 (Lupin)'
);

-- line #23506
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'NITAZOXANIDE', u'always_empty': u'', u'form': u'ORAL SUS', u'brand': u'NOZOA', u'strength_3': u'', u'company': u'Micro Nova', u'unit': u''}

-- line #23507
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOZOA 500 (Micro Nova)',
	'NITAZOXANIDE',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOZOA 500 (Micro Nova)'
);

-- line #23508
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BARONITE 5 (BARODA)',
	'Nitrazepam',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BARONITE 5 (BARODA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BARONITE 10 (BARODA)',
	'Nitrazepam',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BARONITE 10 (BARODA)'
);

-- line #23509
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DORMIN 5 (Synapse)',
	'Nitrazepam',
	'CAP',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DORMIN 5 (Synapse)'
);

-- line #23510
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DORMIN 10 (Synapse)',
	'Nitrazepam',
	'CAP/TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DORMIN 10 (Synapse)'
);

-- line #23511
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYPNONEX 5 (Nexus)',
	'Nitrazepam',
	'CAP',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYPNONEX 5 (Nexus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYPNONEX 10 (Nexus)',
	'Nitrazepam',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYPNONEX 10 (Nexus)'
);

-- line #23512
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYPNOPAM PLUS 10 (Rkg)',
	'Nitrazepam',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYPNOPAM PLUS 10 (Rkg)'
);

-- line #23513
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYPNORIL 10 (Reliance)',
	'Nitrazepam',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYPNORIL 10 (Reliance)'
);

-- line #23514
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYPNORIL 5 (Reliance)',
	'Nitrazepam',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYPNORIL 5 (Reliance)'
);

-- line #23515
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYPNOTEX 10 (P C INDIA)',
	'Nitrazepam',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYPNOTEX 10 (P C INDIA)'
);

-- line #23516
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYPNOTEX 5 (P C INDIA)',
	'Nitrazepam',
	'CAP',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYPNOTEX 5 (P C INDIA)'
);

-- line #23517
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INSOMIN 10 (PSYCOREM)',
	'Nitrazepam',
	'F. TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INSOMIN 10 (PSYCOREM)'
);

-- line #23518
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANONIT 10 (Mano)',
	'Nitrazepam',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANONIT 10 (Mano)'
);

-- line #23519
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANONIT 5 (Mano)',
	'Nitrazepam',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANONIT 5 (Mano)'
);

-- line #23520
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10', u'strength_2': u'', u'substance': u'Nitrazepam', u'always_empty': u'', u'form': u'', u'brand': u'MEDIPAM PLUS', u'strength_3': u'', u'company': u'MEDIFORECE', u'unit': u'mg'}

-- line #23521
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEZIN 10 (NAVNIDHI LIFE)',
	'Nitrazepam',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEZIN 10 (NAVNIDHI LIFE)'
);

-- line #23522
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIGAP 5 (Pil)',
	'Nitrazepam',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIGAP 5 (Pil)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIGAP 10 (Pil)',
	'Nitrazepam',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIGAP 10 (Pil)'
);

-- line #23523
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMAP 5 (LA DRUG)',
	'Nitrazepam',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMAP 5 (LA DRUG)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMAP 10 (LA DRUG)',
	'Nitrazepam',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMAP 10 (LA DRUG)'
);

-- line #23524
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIPAM 5 (LA DRUG)',
	'Nitrazepam',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIPAM 5 (LA DRUG)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIPAM 10 (LA DRUG)',
	'Nitrazepam',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIPAM 10 (LA DRUG)'
);

-- line #23525
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITAVAN 10 (Stadmed)',
	'Nitrazepam',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITAVAN 10 (Stadmed)'
);

-- line #23526
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITAVAN 5 (Stadmed)',
	'Nitrazepam',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITAVAN 5 (Stadmed)'
);

-- line #23527
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITCARE 5 (RECOUPE)',
	'Nitrazepam',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITCARE 5 (RECOUPE)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITCARE 10 (RECOUPE)',
	'Nitrazepam',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITCARE 10 (RECOUPE)'
);

-- line #23528
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITHRA 20 (EAST WEST)',
	'Nitrazepam',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITHRA 20 (EAST WEST)'
);

-- line #23529
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITHRA 5 (EAST WEST)',
	'Nitrazepam',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITHRA 5 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITHRA 10 (EAST WEST)',
	'Nitrazepam',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITHRA 10 (EAST WEST)'
);

-- line #23530
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITRAPAM 10 (S P Ph.)',
	'Nitrazepam',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITRAPAM 10 (S P Ph.)'
);

-- line #23531
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITRAVET 2.5 (A.F.D.)',
	'Nitrazepam',
	'DT',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITRAVET 2.5 (A.F.D.)'
);

-- line #23532
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITRAVET 10 (A.F.D.)',
	'Nitrazepam',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITRAVET 10 (A.F.D.)'
);

-- line #23533
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITRAVET 5 (A.F.D.)',
	'Nitrazepam',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITRAVET 5 (A.F.D.)'
);

-- line #23534
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITRAZ 5 (TRITON(CALYX))',
	'Nitrazepam',
	'SR TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITRAZ 5 (TRITON(CALYX))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITRAZ 10 (TRITON(CALYX))',
	'Nitrazepam',
	'SR TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITRAZ 10 (TRITON(CALYX))'
);

-- line #23535
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITRAZ 10 (NAVNIDHI LIFE)',
	'Nitrazepam',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITRAZ 10 (NAVNIDHI LIFE)'
);

-- line #23536
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITROFEN 10 (Theo Ph.)',
	'Nitrazepam',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITROFEN 10 (Theo Ph.)'
);

-- line #23537
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITROFEN 5 (Theo Ph.)',
	'Nitrazepam',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITROFEN 5 (Theo Ph.)'
);

-- line #23538
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITROSUN 10 (Sun)',
	'Nitrazepam',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITROSUN 10 (Sun)'
);

-- line #23539
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITROSUN 5 (Sun)',
	'Nitrazepam',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITROSUN 5 (Sun)'
);

-- line #23540
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITZY-10 10 (Zee Lab)',
	'Nitrazepam',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITZY-10 10 (Zee Lab)'
);

-- line #23541
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDIF 10 (Concept)',
	'Nitrendipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDIF 10 (Concept)'
);

-- line #23542
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDIF 20 (Concept)',
	'Nitrendipine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDIF 20 (Concept)'
);

-- line #23543
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITREPIN 10 (U S V)',
	'Nitrendipine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITREPIN 10 (U S V)'
);

-- line #23544
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITREPIN 20 (U S V)',
	'Nitrendipine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITREPIN 20 (U S V)'
);

-- line #23545
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FURADANTIN 25 (Gsk)',
	'Nitrofurantoin',
	'SUS',
	gm.nullify_empty_string('25')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FURADANTIN 25 (Gsk)'
);

-- line #23546
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FURADANTIN 100 (Gsk)',
	'Nitrofurantoin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FURADANTIN 100 (Gsk)'
);

-- line #23547
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FURADANTIN 50 (Gsk)',
	'Nitrofurantoin',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FURADANTIN 50 (Gsk)'
);

-- line #23548
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FURENT 100 (Ttk Hc.)',
	'Nitrofurantoin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FURENT 100 (Ttk Hc.)'
);

-- line #23549
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MARTIFUR - 100 (Walter B.)',
	'Nitrofurantoin',
	'MR',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MARTIFUR - 100 (Walter B.)'
);

-- line #23550
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MARTIFUR 100 (Walter B.)',
	'Nitrofurantoin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MARTIFUR 100 (Walter B.)'
);

-- line #23551
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NFTOR 100 (Torrent)',
	'Nitrofurantoin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NFTOR 100 (Torrent)'
);

-- line #23552
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIFTAS 100 (Intas)',
	'Nitrofurantoin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIFTAS 100 (Intas)'
);

-- line #23553
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIFTAS 50 (Intas)',
	'Nitrofurantoin',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIFTAS 50 (Intas)'
);

-- line #23554
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIFTRAN 100 (Ranbaxy)',
	'Nitrofurantoin',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIFTRAN 100 (Ranbaxy)'
);

-- line #23555
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIFTRAN 25 (Ranbaxy)',
	'Nitrofurantoin',
	'SUSP',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIFTRAN 25 (Ranbaxy)'
);

-- line #23556
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIFTY 100 (Wanbury)',
	'Nitrofurantoin',
	'SR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIFTY 100 (Wanbury)'
);

-- line #23557
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIFUTIN 100 (Ipca)',
	'Nitrofurantoin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIFUTIN 100 (Ipca)'
);

-- line #23558
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100', u'strength_2': u'', u'substance': u'Nitrofurantoin', u'always_empty': u'', u'form': u'', u'brand': u'NITOIN', u'strength_3': u'', u'company': u'STEADFAST MEDI.', u'unit': u'mg SR'}

-- line #23559
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITROFUR 100 (Wanbury)',
	'Nitrofurantoin',
	'SR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITROFUR 100 (Wanbury)'
);

-- line #23560
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITROSTAR 100 (AKUMENTIS HC.)',
	'Nitrofurantoin',
	'SR',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITROSTAR 100 (AKUMENTIS HC.)'
);

-- line #23561
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,2', u'strength_2': u'', u'substance': u'Nitrofurazone', u'always_empty': u'', u'form': u'', u'brand': u'EMFURAZONE', u'strength_3': u'', u'company': u'Emcure', u'unit': u'%W/W'}

-- line #23562
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FURACIN 0.2 (Gsk)',
	'Nitrofurazone',
	'CRM',
	gm.nullify_empty_string('0.2')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FURACIN 0.2 (Gsk)'
);

-- line #23563
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FURACIN 0.2 (Gsk)',
	'Nitrofurazone',
	'OINT',
	gm.nullify_empty_string('0.2')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FURACIN 0.2 (Gsk)'
);

-- line #23564
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FURACIN 0.2 (Gsk)',
	'Nitrofurazone',
	'POW',
	gm.nullify_empty_string('0.2')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FURACIN 0.2 (Gsk)'
);

-- line #23565
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYNIT 2.6 (TASMED)',
	'Nitroglycerine',
	'TAB',
	gm.nullify_empty_string('2.6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYNIT 2.6 (TASMED)'
);

-- line #23566
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYNIT 6.4 (TASMED)',
	'Nitroglycerine',
	'TAB',
	gm.nullify_empty_string('6.4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYNIT 6.4 (TASMED)'
);

-- line #23567
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GTN SORBITRATE 2.6 (Nicholas)',
	'Nitroglycerine',
	'CR',
	gm.nullify_empty_string('2.6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GTN SORBITRATE 2.6 (Nicholas)'
);

-- line #23568
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GTN SORBITRATE 6.4 (Nicholas)',
	'Nitroglycerine',
	'CR',
	gm.nullify_empty_string('6.4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GTN SORBITRATE 6.4 (Nicholas)'
);

-- line #23569
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONIT GTN 2.6 (Intas)',
	'Nitroglycerine',
	'TAB',
	gm.nullify_empty_string('2.6')::numeric,
	'mg C.R.'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONIT GTN 2.6 (Intas)'
);

-- line #23570
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONIT GTN 6.4 (Intas)',
	'Nitroglycerine',
	'TAB',
	gm.nullify_empty_string('6.4')::numeric,
	'mg C.R.'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONIT GTN 6.4 (Intas)'
);

-- line #23571
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NG CARE 25 (SYSTACARE)',
	'Nitroglycerine',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NG CARE 25 (SYSTACARE)'
);

-- line #23572
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIG 25 (Samarth)',
	'Nitroglycerine',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIG 25 (Samarth)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIG 50 (Samarth)',
	'Nitroglycerine',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIG 50 (Samarth)'
);

-- line #23573
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5', u'strength_2': u'10', u'substance': u'Nitroglycerine', u'always_empty': u'', u'form': u'', u'brand': u'NITRIDERM TTS PATCH', u'strength_3': u'', u'company': u'CH.Bhagat', u'unit': u'mg'}

-- line #23574
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITROCARD 25 (Csc Ph.)',
	'Nitroglycerine',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITROCARD 25 (Csc Ph.)'
);

-- line #23575
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITROCERIN 2.6 (Intra Lab)',
	'Nitroglycerine',
	'CR TAB',
	gm.nullify_empty_string('2.6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITROCERIN 2.6 (Intra Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITROCERIN 6.4 (Intra Lab)',
	'Nitroglycerine',
	'CR TAB',
	gm.nullify_empty_string('6.4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITROCERIN 6.4 (Intra Lab)'
);

-- line #23576
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'70 M. DOSE', u'strength_2': u'', u'substance': u'Nitroglycerine', u'always_empty': u'', u'form': u'SPRAY', u'brand': u'NITROCIN PEN', u'strength_3': u'', u'company': u'Samarth', u'unit': u''}

-- line #23577
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITROGEN 25 (NEW MEDICON)',
	'Nitroglycerine',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITROGEN 25 (NEW MEDICON)'
);

-- line #23578
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITROGLYCERINE 5 (Biochem)',
	'Nitroglycerine',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITROGLYCERINE 5 (Biochem)'
);

-- line #23579
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITROMACK RET 2.5 (Biochem)',
	'Nitroglycerine',
	'CAP',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITROMACK RET 2.5 (Biochem)'
);

-- line #23580
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITROMACK RET 5 (Biochem)',
	'Nitroglycerine',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITROMACK RET 5 (Biochem)'
);

-- line #23581
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITROPLUS 5 (Neon)',
	'Nitroglycerine',
	'AMP',
	gm.nullify_empty_string('5')::numeric,
	'mg (ABSOLUTE ALCOHOL 30'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITROPLUS 5 (Neon)'
);

-- line #23582
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DELFEN 5 (J.&J.)',
	'Nonylphenoxypolyethoxy-Ethanol',
	'CRM',
	gm.nullify_empty_string('5')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DELFEN 5 (J.&J.)'
);

-- line #23583
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADRENOR 4 (Samarth)',
	'Noradrenaline Bitartrate',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADRENOR 4 (Samarth)'
);

-- line #23584
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INFUNOR 2 (Cipla)',
	'Noradrenaline Bitartrate',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INFUNOR 2 (Cipla)'
);

-- line #23585
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IVCROS 2 (Neon)',
	'Noradrenaline Bitartrate',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IVCROS 2 (Neon)'
);

-- line #23586
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Noradrenaline Bitartrate', u'always_empty': u'', u'form': u'AMP', u'brand': u'NODRESOL', u'strength_3': u'', u'company': u'SG PH.', u'unit': u''}

-- line #23587
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORADERIN 4 (NEW MEDICON)',
	'Noradrenaline Bitartrate',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORADERIN 4 (NEW MEDICON)'
);

-- line #23588
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORAD 4 (Neon)',
	'Noradrenaline Bitartrate',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORAD 4 (Neon)'
);

-- line #23589
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I. CONC.', u'strength_2': u'', u'substance': u'Noradrenaline Bitartrate', u'always_empty': u'', u'form': u'INJ', u'brand': u'NORALIN', u'strength_3': u'', u'company': u'United Bio.', u'unit': u''}

-- line #23590
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Noradrenaline Bitartrate', u'always_empty': u'', u'form': u'INJ', u'brand': u'NORDREN', u'strength_3': u'', u'company': u'Vhb', u'unit': u''}

-- line #23591
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOREPIRIN 4 (CH.Bhagat)',
	'Noradrenaline Bitartrate',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOREPIRIN 4 (CH.Bhagat)'
);

-- line #23592
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORUP 2 (Kirti Works)',
	'Noradrenaline Bitartrate',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORUP 2 (Kirti Works)'
);

-- line #23593
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RADLINE 1 (ALEMBIC)',
	'Noradrenaline Bitartrate',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RADLINE 1 (ALEMBIC)'
);

-- line #23594
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADRONIS 4 (NEISS)',
	'NOREPINEPHRINE',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADRONIS 4 (NEISS)'
);

-- line #23595
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPINOR 4 (GEO PHARMA)',
	'NOREPINEPHRINE',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPINOR 4 (GEO PHARMA)'
);

-- line #23596
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOR-S 4 (SYSTACARE)',
	'NOREPINEPHRINE',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOR-S 4 (SYSTACARE)'
);

-- line #23597
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUBSEAL 5 (Dahlia Ph.)',
	'Norethindrone Acetate',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUBSEAL 5 (Dahlia Ph.)'
);

-- line #23598
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHINATE 5 (Systopic)',
	'Norethindrone Acetate',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHINATE 5 (Systopic)'
);

-- line #23599
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORETA HRT 1 (German R.)',
	'Norethindrone Acetate',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORETA HRT 1 (German R.)'
);

-- line #23600
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOSTRA 5 (Corona)',
	'Norethindrone Acetate',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOSTRA 5 (Corona)'
);

-- line #23601
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REGESTERONE HRT 1 (Novartis)',
	'Norethindrone Acetate',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REGESTERONE HRT 1 (Novartis)'
);

-- line #23602
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REGESTERONE 5 (Novartis)',
	'Norethindrone Acetate',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REGESTERONE 5 (Novartis)'
);

-- line #23603
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMENOVA 5 (Bal Ph.)',
	'Norethisterone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMENOVA 5 (Bal Ph.)'
);

-- line #23604
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COROLUT-N 5 (Corolla(Triton))',
	'Norethisterone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COROLUT-N 5 (Corolla(Triton))'
);

-- line #23605
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYCLOREG 5 (Jagsonpal)',
	'Norethisterone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYCLOREG 5 (Jagsonpal)'
);

-- line #23606
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUB-5 5 (Obsurge)',
	'Norethisterone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUB-5 5 (Obsurge)'
);

-- line #23607
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUBA-N 5 (Indosurge)',
	'Norethisterone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUBA-N 5 (Indosurge)'
);

-- line #23608
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUBOGEN 5 (Neu-Foreva)',
	'Norethisterone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUBOGEN 5 (Neu-Foreva)'
);

-- line #23609
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUBOLUT 5 (Stanmark)',
	'Norethisterone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUBOLUT 5 (Stanmark)'
);

-- line #23610
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5', u'strength_2': u'', u'substance': u'Norethisterone', u'always_empty': u'', u'form': u'', u'brand': u'ETHINORM-P', u'strength_3': u'', u'company': u'Bennet Ph.', u'unit': u'mg'}

-- line #23611
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHISONE-5 5 (Chemo Bio.)',
	'Norethisterone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHISONE-5 5 (Chemo Bio.)'
);

-- line #23612
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GYNABEST 5 (Bestochem)',
	'Norethisterone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GYNABEST 5 (Bestochem)'
);

-- line #23613
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GYNASET 5 (Mankind)',
	'Norethisterone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GYNASET 5 (Mankind)'
);

-- line #23614
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GYNUT-N 5 (Cipla)',
	'Norethisterone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GYNUT-N 5 (Cipla)'
);

-- line #23615
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HILNOR 5 (HIND. LATEX)',
	'Norethisterone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HILNOR 5 (HIND. LATEX)'
);

-- line #23616
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MENOR-N 5 (Evacare)',
	'Norethisterone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MENOR-N 5 (Evacare)'
);

-- line #23617
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MENSIL-N 5 (BIOMIICRON)',
	'Norethisterone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MENSIL-N 5 (BIOMIICRON)'
);

-- line #23618
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NC NORM-P 5 (Unicure)',
	'Norethisterone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NC NORM-P 5 (Unicure)'
);

-- line #23619
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORATE-A 5 (DEWCARE)',
	'Norethisterone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORATE-A 5 (DEWCARE)'
);

-- line #23620
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORATE 5 (DEWCARE)',
	'Norethisterone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORATE 5 (DEWCARE)'
);

-- line #23621
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOREN 5 (ROSE LABS)',
	'Norethisterone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOREN 5 (ROSE LABS)'
);

-- line #23622
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORETHISTERONE 5 (Atoz Ph.)',
	'Norethisterone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORETHISTERONE 5 (Atoz Ph.)'
);

-- line #23623
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORETH 5 (Taurus Lab)',
	'Norethisterone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORETH 5 (Taurus Lab)'
);

-- line #23624
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORGEST 5 (Micro Nova)',
	'Norethisterone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORGEST 5 (Micro Nova)'
);

-- line #23625
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORGLEN 5 (Glenmark)',
	'Norethisterone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORGLEN 5 (Glenmark)'
);

-- line #23626
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORISTERAT 200 (German R.)',
	'Norethisterone',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg(ENATATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORISTERAT 200 (German R.)'
);

-- line #23627
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORITIS 5 (Cadila Ph.)',
	'Norethisterone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORITIS 5 (Cadila Ph.)'
);

-- line #23628
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORLUT-N 5 (Cipla)',
	'Norethisterone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORLUT-N 5 (Cipla)'
);

-- line #23629
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORMIN 5 (PHARMIN)',
	'Norethisterone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORMIN 5 (PHARMIN)'
);

-- line #23630
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORPROGEST 5 (Colinz Lab)',
	'Norethisterone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORPROGEST 5 (Colinz Lab)'
);

-- line #23631
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOTERON 5 (LITTLE GREAVE)',
	'Norethisterone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOTERON 5 (LITTLE GREAVE)'
);

-- line #23632
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POSTPON 5 (EAST WEST)',
	'Norethisterone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POSTPON 5 (EAST WEST)'
);

-- line #23633
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIMIZED-N 5 (ZOTA)',
	'Norethisterone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIMIZED-N 5 (ZOTA)'
);

-- line #23634
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIMOLUT-N 5 (German R.)',
	'Norethisterone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIMOLUT-N 5 (German R.)'
);

-- line #23635
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIMONA-N 5 (Sayona)',
	'Norethisterone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIMONA-N 5 (Sayona)'
);

-- line #23636
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIMTOZ-N 5 (Atoz Ph.)',
	'Norethisterone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIMTOZ-N 5 (Atoz Ph.)'
);

-- line #23637
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIMVAR-N 5 (Zota Ph.)',
	'Norethisterone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIMVAR-N 5 (Zota Ph.)'
);

-- line #23638
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIMZED-N 5 (Zota PH.)',
	'Norethisterone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIMZED-N 5 (Zota PH.)'
);

-- line #23639
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRONOMORE 5 (AXYZEN LIFE)',
	'Norethisterone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRONOMORE 5 (AXYZEN LIFE)'
);

-- line #23640
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REGESTRONE 5 (Novartis)',
	'Norethisterone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REGESTRONE 5 (Novartis)'
);

-- line #23641
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELICALFIN 5 (German R.)',
	'Norethisterone',
	'DS TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELICALFIN 5 (German R.)'
);

-- line #23642
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RETON 5 (ST.MORRISON)',
	'Norethisterone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RETON 5 (ST.MORRISON)'
);

-- line #23643
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Norfloxacin', u'always_empty': u'', u'form': u'TAB', u'brand': u'ACTIFLOX-400', u'strength_3': u'', u'company': u'ALICON PH.', u'unit': u''}

-- line #23644
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALFLOX 0.3 (Alkem)',
	'Norfloxacin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALFLOX 0.3 (Alkem)'
);

-- line #23645
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALFLOX 100 (Alkem)',
	'Norfloxacin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALFLOX 100 (Alkem)'
);

-- line #23646
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALFLOX 400 (Alkem)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALFLOX 400 (Alkem)'
);

-- line #23647
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANQUIN 400 (HETERO HC.)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANQUIN 400 (HETERO HC.)'
);

-- line #23648
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANQUIN 800 (HETERO HC.)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANQUIN 800 (HETERO HC.)'
);

-- line #23649
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACIGYL 100 (Aristo)',
	'NORFLOXACIN',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACIGYL 100 (Aristo)'
);

-- line #23650
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACIGYL 400 (Aristo)',
	'NORFLOXACIN',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACIGYL 400 (Aristo)'
);

-- line #23651
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Norfloxacin', u'always_empty': u'', u'form': u'DPS', u'brand': u'BENOR-E', u'strength_3': u'', u'company': u'Brooks Ph.', u'unit': u''}

-- line #23652
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOFLOXIN 400 (Biochem)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOFLOXIN 400 (Biochem)'
);

-- line #23653
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIN-400 400 (Mamta Ph.)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIN-400 400 (Mamta Ph.)'
);

-- line #23654
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORFLOX 400 (Corona)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORFLOX 400 (Corona)'
);

-- line #23655
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DENAR 100 (Chemo D.)',
	'Norfloxacin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DENAR 100 (Chemo D.)'
);

-- line #23656
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'D-FLOX 400 (Dial Ph.)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'D-FLOX 400 (Dial Ph.)'
);

-- line #23657
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENTEROFLOX 400 (Dey''S)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENTEROFLOX 400 (Dey''S)'
);

-- line #23658
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUFLOX 0.3 (Kamron)',
	'Norfloxacin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUFLOX 0.3 (Kamron)'
);

-- line #23659
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EYEFLOX 0.3 (Ophthal R.)',
	'Norfloxacin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EYEFLOX 0.3 (Ophthal R.)'
);

-- line #23660
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FENOR 400 (FORTUNE HC.)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FENOR 400 (FORTUNE HC.)'
);

-- line #23661
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXAMAN 100 (Shalman)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXAMAN 100 (Shalman)'
);

-- line #23662
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXAQUIN-400 400 (Taurus Lab)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXAQUIN-400 400 (Taurus Lab)'
);

-- line #23663
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXAQUIN-N 400 (Themis)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXAQUIN-N 400 (Themis)'
);

-- line #23664
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXIREN 0.3 (Warren)',
	'Norfloxacin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXIREN 0.3 (Warren)'
);

-- line #23665
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOX 100 (Lark Lab)',
	'Norfloxacin',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOX 100 (Lark Lab)'
);

-- line #23666
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOX 400 (Lark Lab)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOX 400 (Lark Lab)'
);

-- line #23667
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXYNOR 400 (Norris Med.)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXYNOR 400 (Norris Med.)'
);

-- line #23668
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HARFLOX 0.3 (Taurus Lab)',
	'Norfloxacin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HARFLOX 0.3 (Taurus Lab)'
);

-- line #23669
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HARFLOX 400 (Taurus Lab)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HARFLOX 400 (Taurus Lab)'
);

-- line #23670
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYFLOX 400 (Trio Rem.)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYFLOX 400 (Trio Rem.)'
);

-- line #23671
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KILBAC 200 (Shaimil)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KILBAC 200 (Shaimil)'
);

-- line #23672
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KILBAC 400 (Shaimil)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KILBAC 400 (Shaimil)'
);

-- line #23673
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOXONE 0.3 (Brown & B.)',
	'Norfloxacin',
	'E/E DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOXONE 0.3 (Brown & B.)'
);

-- line #23674
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOXONE 400 (Brown & B.)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOXONE 400 (Brown & B.)'
);

-- line #23675
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACFLOX 0.3 (Mac)',
	'Norfloxacin',
	'EYE DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACFLOX 0.3 (Mac)'
);

-- line #23676
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDIFLOX 400 (Medico)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDIFLOX 400 (Medico)'
);

-- line #23677
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MERIFLOX 400 (Merind)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MERIFLOX 400 (Merind)'
);

-- line #23678
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEGAFLOX 400 (Zydus A.)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEGAFLOX 400 (Zydus A.)'
);

-- line #23679
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEONOX 200 (Neo Ph.)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEONOX 200 (Neo Ph.)'
);

-- line #23680
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NETERFLOX 400 (Dey''S)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NETERFLOX 400 (Dey''S)'
);

-- line #23681
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITDIN 100 (Lupin)',
	'Norfloxacin',
	'KT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITDIN 100 (Lupin)'
);

-- line #23682
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITDIN 400 (Lupin)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITDIN 400 (Lupin)'
);

-- line #23683
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOGIT 400 (Alde Medi.)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOGIT 400 (Alde Medi.)'
);

-- line #23684
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORABACTIN 3 (Ranbaxy)',
	'Norfloxacin',
	'EYE DPS',
	gm.nullify_empty_string('3')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORABACTIN 3 (Ranbaxy)'
);

-- line #23685
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORACE 400 (Jarson Ph.)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORACE 400 (Jarson Ph.)'
);

-- line #23686
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORALOX 400 (Jagsonpal)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORALOX 400 (Jagsonpal)'
);

-- line #23687
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORBACTIN 3 (Ranbaxy)',
	'Norfloxacin',
	'EYE DPS',
	gm.nullify_empty_string('3')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORBACTIN 3 (Ranbaxy)'
);

-- line #23688
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORBACTIN 200 (Ranbaxy)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORBACTIN 200 (Ranbaxy)'
);

-- line #23689
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORBACTIN 400 (Ranbaxy)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORBACTIN 400 (Ranbaxy)'
);

-- line #23690
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORBACTIN 800 (Ranbaxy)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORBACTIN 800 (Ranbaxy)'
);

-- line #23691
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORBID 100 (Alembic)',
	'Norfloxacin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORBID 100 (Alembic)'
);

-- line #23692
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORBID 200 (Alembic)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORBID 200 (Alembic)'
);

-- line #23693
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORBID 400 (Alembic)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORBID 400 (Alembic)'
);

-- line #23694
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORCAP 400 (Pharma synth)',
	'Norfloxacin',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORCAP 400 (Pharma synth)'
);

-- line #23695
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORCID 0.3 (Indus)',
	'Norfloxacin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORCID 0.3 (Indus)'
);

-- line #23696
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORCON 0.3 (Indiana O.)',
	'Norfloxacin',
	'E/E DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORCON 0.3 (Indiana O.)'
);

-- line #23697
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORDAC 0.3 (Sante V.)',
	'Norfloxacin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORDAC 0.3 (Sante V.)'
);

-- line #23698
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORDIP 0.3 (Pfiscar Ind.)',
	'Norfloxacin',
	'E/E DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORDIP 0.3 (Pfiscar Ind.)'
);

-- line #23699
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORFIL 400 (AIMCO PH.)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORFIL 400 (AIMCO PH.)'
);

-- line #23700
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORFLOXACIN 400 (Dopson Ph.)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORFLOXACIN 400 (Dopson Ph.)'
);

-- line #23701
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORFLOX 100 (Cipla)',
	'Norfloxacin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORFLOX 100 (Cipla)'
);

-- line #23702
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORFLOX 0.3 (Cipla)',
	'Norfloxacin',
	'E/E DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORFLOX 0.3 (Cipla)'
);

-- line #23703
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORFLOX 0.3 (Cipla)',
	'Norfloxacin',
	'OINT',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORFLOX 0.3 (Cipla)'
);

-- line #23704
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORFLOX 200 (Cipla)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg(LB)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORFLOX 200 (Cipla)'
);

-- line #23705
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORFLOX 400 (Cipla)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg(LB)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORFLOX 400 (Cipla)'
);

-- line #23706
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORFLOX 800 (Cipla)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORFLOX 800 (Cipla)'
);

-- line #23707
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORILET 100 (Dr.Reddy''S)',
	'Norfloxacin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORILET 100 (Dr.Reddy''S)'
);

-- line #23708
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORILET 0.3 (Dr.Reddy''S)',
	'Norfloxacin',
	'E/E DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORILET 0.3 (Dr.Reddy''S)'
);

-- line #23709
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORILET 200 (Dr.Reddy''S)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORILET 200 (Dr.Reddy''S)'
);

-- line #23710
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORILET 400 (Dr.Reddy''S)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORILET 400 (Dr.Reddy''S)'
);

-- line #23711
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORIN-400 400 (Intra Lab)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORIN-400 400 (Intra Lab)'
);

-- line #23712
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORKIN 400 (Arbro Ph.)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORKIN 400 (Arbro Ph.)'
);

-- line #23713
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORMAX 0.3 (Ipca)',
	'Norfloxacin',
	'E/E DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORMAX 0.3 (Ipca)'
);

-- line #23714
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORMAX 400 (Ipca)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORMAX 400 (Ipca)'
);

-- line #23715
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORMED 400 (Medicamen)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORMED 400 (Medicamen)'
);

-- line #23716
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORNIJ 100 (Sunij)',
	'Norfloxacin',
	'DT/400TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORNIJ 100 (Sunij)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORNIJ 400 (Sunij)',
	'Norfloxacin',
	'DT/400TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORNIJ 400 (Sunij)'
);

-- line #23717
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOROXIN 400 (Dynamic)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOROXIN 400 (Dynamic)'
);

-- line #23718
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORRIT 0.3 (Ind-Swift)',
	'Norfloxacin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORRIT 0.3 (Ind-Swift)'
);

-- line #23719
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORRIT 400 (Ind-Swift)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORRIT 400 (Ind-Swift)'
);

-- line #23720
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORSPAN 100 (Blue Cross)',
	'Norfloxacin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORSPAN 100 (Blue Cross)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORSPAN 200 (Blue Cross)',
	'Norfloxacin',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORSPAN 200 (Blue Cross)'
);

-- line #23721
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORSPAN 400 (Blue Cross)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORSPAN 400 (Blue Cross)'
);

-- line #23722
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORSTAR 400 (Cadila Ph.)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORSTAR 400 (Cadila Ph.)'
);

-- line #23723
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORTUM 100 (Profic)',
	'Norfloxacin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORTUM 100 (Profic)'
);

-- line #23724
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORTUM 400 (Profic)',
	'Norfloxacin',
	'DT',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORTUM 400 (Profic)'
);

-- line #23725
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOR-U 400 (Hal)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOR-U 400 (Hal)'
);

-- line #23726
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORVIT 0.3 (Prohealth)',
	'Norfloxacin',
	'E/E DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORVIT 0.3 (Prohealth)'
);

-- line #23727
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORZEN-E 0.3 (F D C)',
	'Norfloxacin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORZEN-E 0.3 (F D C)'
);

-- line #23728
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORZY 400 (Zee Lab)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORZY 400 (Zee Lab)'
);

-- line #23729
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOTOR 400 (SANCHEZ LAB.)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOTOR 400 (SANCHEZ LAB.)'
);

-- line #23730
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOX 400 (Finecure)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOX 400 (Finecure)'
);

-- line #23731
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'N-R FLOX 400 (Stallion)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'N-R FLOX 400 (Stallion)'
);

-- line #23732
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLFRON 400 (Neon)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLFRON 400 (Neon)'
);

-- line #23733
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONAFLOX 100 (Sayona)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONAFLOX 100 (Sayona)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONAFLOX 400 (Sayona)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONAFLOX 400 (Sayona)'
);

-- line #23734
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPTOFLOX 3 (Alkem)',
	'Norfloxacin',
	'DPS',
	gm.nullify_empty_string('3')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPTOFLOX 3 (Alkem)'
);

-- line #23735
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORCIN-400 400 (Olcare)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORCIN-400 400 (Olcare)'
);

-- line #23736
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORIFLOX 0.3 (Ophthal R.)',
	'Norfloxacin',
	'EYE DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORIFLOX 0.3 (Ophthal R.)'
);

-- line #23737
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PD-NOR 0.3 (Parenteral)',
	'Norfloxacin',
	'E/E DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PD-NOR 0.3 (Parenteral)'
);

-- line #23738
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POWERFLOX 100 (Cipla)',
	'Norfloxacin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POWERFLOX 100 (Cipla)'
);

-- line #23739
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROGEN 0.3 (Prohealth)',
	'Norfloxacin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROGEN 0.3 (Prohealth)'
);

-- line #23740
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINOBID 200 (Micro Nova)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINOBID 200 (Micro Nova)'
);

-- line #23741
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINOBID 400 (Micro Nova)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINOBID 400 (Micro Nova)'
);

-- line #23742
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINOLOX 400 (Kopran)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINOLOX 400 (Kopran)'
);

-- line #23743
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RENOR 400 (Aurobindo)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RENOR 400 (Aurobindo)'
);

-- line #23744
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'R-FLOX 400 (Reliance)',
	'Norfloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'R-FLOX 400 (Reliance)'
);

-- line #23745
-- ignoring line: field [strength_1] not numeric: >>>400+600<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'400+600', u'strength_2': u'', u'substance': u'Norfloxacin+Tinidazole', u'always_empty': u'', u'form': u'TAB', u'brand': u'FLOXAMAM-PB', u'strength_3': u'', u'company': u'Shalman', u'unit': u'mg'}

-- line #23746
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPIVAL 25 (PSYCOREM)',
	'Nortriptyline',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPIVAL 25 (PSYCOREM)'
);

-- line #23747
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOORI 25 (Crystal Ph.)',
	'Nortriptyline',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOORI 25 (Crystal Ph.)'
);

-- line #23748
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORDEP 25 (Orchid Hc.)',
	'Nortriptyline',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORDEP 25 (Orchid Hc.)'
);

-- line #23749
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORTIN 25 (LA DRUG)',
	'Nortriptyline',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORTIN 25 (LA DRUG)'
);

-- line #23750
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORTRIP 25 (Theo Ph.)',
	'Nortriptyline',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORTRIP 25 (Theo Ph.)'
);

-- line #23751
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIMOX 25 (Sun)',
	'Nortriptyline',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIMOX 25 (Sun)'
);

-- line #23752
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RENOR 25 (RECOUPE)',
	'Nortriptyline',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RENOR 25 (RECOUPE)'
);

-- line #23753
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHERANA COUGH 10 (ABBOTT)',
	'Noscapine',
	'LOZ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHERANA COUGH 10 (ABBOTT)'
);

-- line #23754
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'NOVOLIZER DEVICE', u'always_empty': u'', u'form': u'', u'brand': u'NOVOLIZER MDPI DEVICE', u'strength_3': u'', u'company': u'RESPICARE(GERMAN R.)', u'unit': u''}

-- line #23755
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'NUTRITINAL SUPPLEMENT PROTEINS WITH VITAMINS B-COMPLEX & IRON', u'always_empty': u'', u'form': u'POW', u'brand': u'PROSEAL', u'strength_3': u'', u'company': u'Intra Lab', u'unit': u''}

-- line #23756
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARLIDIN 6 (U S V)',
	'Nylidrin Hcl.',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARLIDIN 6 (U S V)'
);

-- line #23757
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500000U.', u'strength_2': u'', u'substance': u'Nystanin', u'always_empty': u'', u'form': u'TAB', u'brand': u'MYCOSTATIN', u'strength_3': u'', u'company': u'Nicholas', u'unit': u''}

-- line #23758
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100000U.', u'strength_2': u'', u'substance': u'Nystanin', u'always_empty': u'', u'form': u'TAB', u'brand': u'MYCOSTATIN VAG', u'strength_3': u'', u'company': u'Nicholas', u'unit': u''}

-- line #23759
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTIDE 100 (Samarth)',
	'Octreotide',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTIDE 100 (Samarth)'
);

-- line #23760
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTIDE 50 (Samarth)',
	'Octreotide',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTIDE 50 (Samarth)'
);

-- line #23761
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100MCG', u'strength_2': u'', u'substance': u'Octreotide', u'always_empty': u'', u'form': u'', u'brand': u'NEOCTIDE MCG', u'strength_3': u'', u'company': u'Neon', u'unit': u''}

-- line #23762
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50MCG', u'strength_2': u'', u'substance': u'Octreotide', u'always_empty': u'', u'form': u'', u'brand': u'NEOCTIDE MCG', u'strength_3': u'', u'company': u'Neon', u'unit': u''}

-- line #23763
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100MCG', u'strength_2': u'ML', u'substance': u'Octreotide', u'always_empty': u'', u'form': u'INJ', u'brand': u'OCTATE', u'strength_3': u'', u'company': u'VHB', u'unit': u''}

-- line #23764
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50MCG', u'strength_2': u'ML', u'substance': u'Octreotide', u'always_empty': u'', u'form': u'INJ', u'brand': u'OCTATE', u'strength_3': u'', u'company': u'VHB', u'unit': u''}

-- line #23765
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50', u'strength_2': u'100;MCG', u'substance': u'Octreotide', u'always_empty': u'', u'form': u'INJ', u'brand': u'OCTIDE', u'strength_3': u'ML', u'company': u'United Bio.', u'unit': u''}

-- line #23766
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100MCG', u'strength_2': u'', u'substance': u'Octreotide', u'always_empty': u'', u'form': u'AMP', u'brand': u'OCTOTIDE', u'strength_3': u'', u'company': u'Troikaa', u'unit': u''}

-- line #23767
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50MCG', u'strength_2': u'', u'substance': u'Octreotide', u'always_empty': u'', u'form': u'AMP', u'brand': u'OCTOTIDE', u'strength_3': u'', u'company': u'Troikaa', u'unit': u''}

-- line #23768
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCTRIDE DEPOT 10 (Sun)',
	'Octreotide',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg(PYPHOLISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCTRIDE DEPOT 10 (Sun)'
);

-- line #23769
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCTRIDE DEPOT 20 (Sun)',
	'Octreotide',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg(PYPHOLISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCTRIDE DEPOT 20 (Sun)'
);

-- line #23770
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100MCG', u'strength_2': u'ML', u'substance': u'Octreotide', u'always_empty': u'', u'form': u'INJ', u'brand': u'OCTRIDE', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #23771
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50MCG', u'strength_2': u'ML', u'substance': u'Octreotide', u'always_empty': u'', u'form': u'INJ', u'brand': u'OCTRIDE', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #23772
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100MCG', u'strength_2': u'ML', u'substance': u'Octreotide', u'always_empty': u'', u'form': u'VIAL', u'brand': u'OCTRONIS', u'strength_3': u'', u'company': u'NEISS', u'unit': u''}

-- line #23773
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50', u'strength_2': u'100;IU.', u'substance': u'Octreotide', u'always_empty': u'', u'form': u'INJ', u'brand': u'OTIDE', u'strength_3': u'', u'company': u'United Bio.', u'unit': u''}

-- line #23774
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'BIMT', u'strength_2': u'MBBT', u'substance': u'Octyl Methoxycinnamate', u'always_empty': u'', u'form': u'', u'brand': u'ESSGE-24', u'strength_3': u'VITE', u'company': u'Ochoa', u'unit': u''}

-- line #23775
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100MCG', u'strength_2': u'PATCH', u'substance': u'Oestradiol', u'always_empty': u'', u'form': u'', u'brand': u'ESTRADERM TTS PATCH', u'strength_3': u'', u'company': u'Novartis', u'unit': u''}

-- line #23776
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'25', u'strength_2': u'50;MCG', u'substance': u'Oestradiol', u'always_empty': u'', u'form': u'', u'brand': u'ESTRADERM TTS PATCH', u'strength_3': u'PATCH', u'company': u'Novartis', u'unit': u''}

-- line #23777
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHINORM-E 5 (Bennet Ph.)',
	'Oestradiol',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg(BENZOATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHINORM-E 5 (Bennet Ph.)'
);

-- line #23778
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EVALON-F 2 (Infar)',
	'Oestradiol',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EVALON-F 2 (Infar)'
);

-- line #23779
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EVALON 1 (Infar)',
	'Oestradiol',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EVALON 1 (Infar)'
);

-- line #23780
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10', u'strength_2': u'', u'substance': u'Oestradiol', u'always_empty': u'', u'form': u'', u'brand': u'PROGYNON DEPOT', u'strength_3': u'', u'company': u'German R.', u'unit': u'mg'}

-- line #23781
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'1-FLOX 50 (MEGAVISION)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '1-FLOX 50 (MEGAVISION)'
);

-- line #23782
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AFLOX 50 (Anikem Lab.)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AFLOX 50 (Anikem Lab.)'
);

-- line #23783
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AFLOX 200 (Anikem Lab.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AFLOX 200 (Anikem Lab.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AFLOX 400 (Anikem Lab.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AFLOX 400 (Anikem Lab.)'
);

-- line #23784
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AFLOX 200 (PSYCOREM)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AFLOX 200 (PSYCOREM)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AFLOX 400 (PSYCOREM)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AFLOX 400 (PSYCOREM)'
);

-- line #23785
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AGROFLOX 200 (ARGON(KHANDELWAL))',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AGROFLOX 200 (ARGON(KHANDELWAL))'
);

-- line #23786
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALDOF 200 (Aldok Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALDOF 200 (Aldok Ph.)'
);

-- line #23787
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALOF 100 (Admac Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALOF 100 (Admac Ph.)'
);

-- line #23788
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALOF 200 (Admac Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALOF 200 (Admac Ph.)'
);

-- line #23789
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALOX 200 (Aust Ind.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALOX 200 (Aust Ind.)'
);

-- line #23790
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPROXEN 200 (Alkem)',
	'Ofloxacin',
	'INF',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPROXEN 200 (Alkem)'
);

-- line #23791
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPROXEN 200 (Alkem)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPROXEN 200 (Alkem)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPROXEN 400 (Alkem)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPROXEN 400 (Alkem)'
);

-- line #23792
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALTOX 200 (Calyx Med.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALTOX 200 (Calyx Med.)'
);

-- line #23793
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANAFLOX 200 (Alliance Rem.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANAFLOX 200 (Alliance Rem.)'
);

-- line #23794
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANOFLOX 200 (REXUS PH.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANOFLOX 200 (REXUS PH.)'
);

-- line #23795
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AOF-ESTRA 400 (Aabtac Life)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AOF-ESTRA 400 (Aabtac Life)'
);

-- line #23796
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.(OPHTHALMIC SOL.)', u'strength_2': u'', u'substance': u'Ofloxacin', u'always_empty': u'', u'form': u'SUS', u'brand': u'AOF', u'strength_3': u'', u'company': u'Aabtac Life', u'unit': u''}

-- line #23797
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AOF 200 (Aabtac Life)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AOF 200 (Aabtac Life)'
);

-- line #23798
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AQLOX 200 (Aquila)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AQLOX 200 (Aquila)'
);

-- line #23799
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AROCIN 200 (ARLOP PH.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AROCIN 200 (ARLOP PH.)'
);

-- line #23800
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARVID 200 (Sv Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARVID 200 (Sv Ph.)'
);

-- line #23801
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATFLOX 200 (Atopic Lab.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATFLOX 200 (Atopic Lab.)'
);

-- line #23802
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATOFLOX 200 (Atoz Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATOFLOX 200 (Atoz Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATOFLOX 400 (Atoz Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATOFLOX 400 (Atoz Ph.)'
);

-- line #23803
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AUROFLOX 200 (Auroma Life)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AUROFLOX 200 (Auroma Life)'
);

-- line #23804
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVIFLOX 50 (Avalanche)',
	'OFLOXACIN',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVIFLOX 50 (Avalanche)'
);

-- line #23805
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVIFLOX 200 (Avalanche)',
	'OFLOXACIN',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVIFLOX 200 (Avalanche)'
);

-- line #23806
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXOF 400 (Ochoa)',
	'Ofloxacin',
	'OD TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXOF 400 (Ochoa)'
);

-- line #23807
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXOF 50 (Ochoa)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXOF 50 (Ochoa)'
);

-- line #23808
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXOF 100 (Ochoa)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXOF 100 (Ochoa)'
);

-- line #23809
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXOF 200 (Ochoa)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXOF 200 (Ochoa)'
);

-- line #23810
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACIFLOX 200 (GLOBELA PH.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACIFLOX 200 (GLOBELA PH.)'
);

-- line #23811
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACOFF 200 (ALPHA TH.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACOFF 200 (ALPHA TH.)'
);

-- line #23812
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACTER 50 (Cubit Hc.)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACTER 50 (Cubit Hc.)'
);

-- line #23813
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACTER 100 (Cubit Hc.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACTER 100 (Cubit Hc.)'
);

-- line #23814
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACTER 200 (Cubit Hc.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACTER 200 (Cubit Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACTER 400 (Cubit Hc.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACTER 400 (Cubit Hc.)'
);

-- line #23815
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACTIVID 0.3 (Cadex Lab)',
	'Ofloxacin',
	'E/E DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACTIVID 0.3 (Cadex Lab)'
);

-- line #23816
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACTIVID 50 (Cadex Lab)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACTIVID 50 (Cadex Lab)'
);

-- line #23817
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACTIVID 100 (Cadex Lab)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACTIVID 100 (Cadex Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACTIVID 200 (Cadex Lab)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACTIVID 200 (Cadex Lab)'
);

-- line #23818
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACTIVID 400 (Cadex Lab)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACTIVID 400 (Cadex Lab)'
);

-- line #23819
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACTOFF 200 (3A PHARMA.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACTOFF 200 (3A PHARMA.)'
);

-- line #23820
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACTOF 200 (Svizera)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACTOF 200 (Svizera)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACTOF 400 (Svizera)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACTOF 400 (Svizera)'
);

-- line #23821
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BEKKER 50 (POSITIF(AFIVE))',
	'Ofloxacin',
	'SUSP',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BEKKER 50 (POSITIF(AFIVE))'
);

-- line #23822
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BEKKER 200 (POSITIF(AFIVE))',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BEKKER 200 (POSITIF(AFIVE))'
);

-- line #23823
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENIFLOX 50 (Baroque)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENIFLOX 50 (Baroque)'
);

-- line #23824
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENIFLOX 200 (Baroque)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENIFLOX 200 (Baroque)'
);

-- line #23825
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BESTOFLOX 0.3 (Bestochem)',
	'Ofloxacin',
	'EYE DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BESTOFLOX 0.3 (Bestochem)'
);

-- line #23826
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BESTOFLOX 200 (Bestochem)',
	'Ofloxacin',
	'INF',
	gm.nullify_empty_string('200')::numeric,
	'mg/100ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BESTOFLOX 200 (Bestochem)'
);

-- line #23827
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BESTOFLOX 50 (Bestochem)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BESTOFLOX 50 (Bestochem)'
);

-- line #23828
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BESTOFLOX 100 (Bestochem)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BESTOFLOX 100 (Bestochem)'
);

-- line #23829
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BESTOFLOX 200 (Bestochem)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BESTOFLOX 200 (Bestochem)'
);

-- line #23830
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BESTOFLOX 400 (Bestochem)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BESTOFLOX 400 (Bestochem)'
);

-- line #23831
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIDOFLOX 200 (Kee Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIDOFLOX 200 (Kee Ph.)'
);

-- line #23832
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOBID 200 (Biosmith)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOBID 200 (Biosmith)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOBID 400 (Biosmith)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOBID 400 (Biosmith)'
);

-- line #23833
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOCIN 0 (Bio-Tech Opth.)',
	'Ofloxacin',
	'EYE DPS',
	gm.nullify_empty_string('0')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOCIN 0 (Bio-Tech Opth.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOCIN 3 (Bio-Tech Opth.)',
	'Ofloxacin',
	'EYE DPS',
	gm.nullify_empty_string('3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOCIN 3 (Bio-Tech Opth.)'
);

-- line #23834
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOFF 50 (Biochem)',
	'Ofloxacin',
	'INF',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOFF 50 (Biochem)'
);

-- line #23835
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOFF 50 (Biochem)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOFF 50 (Biochem)'
);

-- line #23836
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOFF 200 (Biochem)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOFF 200 (Biochem)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOFF 400 (Biochem)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOFF 400 (Biochem)'
);

-- line #23837
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIO FLO 200 (Bio-Drug)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIO FLO 200 (Bio-Drug)'
);

-- line #23838
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOVID 50 (Alpha Hc.)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOVID 50 (Alpha Hc.)'
);

-- line #23839
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOVID 200 (Alpha Hc.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOVID 200 (Alpha Hc.)'
);

-- line #23840
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOZ 200 (Biocin Hc.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOZ 200 (Biocin Hc.)'
);

-- line #23841
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,05', u'strength_2': u'', u'substance': u'Ofloxacin', u'always_empty': u'', u'form': u'', u'brand': u'BOFOX', u'strength_3': u'', u'company': u'BALAJI PH.', u'unit': u'mg'}

-- line #23842
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BROFLOX 200 (Briskon)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BROFLOX 200 (Briskon)'
);

-- line #23843
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRU-O 200 (Brawn Lab)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRU-O 200 (Brawn Lab)'
);

-- line #23844
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRU-O 400 (Brawn Lab)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRU-O 400 (Brawn Lab)'
);

-- line #23845
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CADOF 200 (Admac (CADMA))',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CADOF 200 (Admac (CADMA))'
);

-- line #23846
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANOCIN 100 (Candor Bio.)',
	'Ofloxacin',
	'KID TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANOCIN 100 (Candor Bio.)'
);

-- line #23847
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANOCIN 100 (Candor Bio.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANOCIN 100 (Candor Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANOCIN 200 (Candor Bio.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANOCIN 200 (Candor Bio.)'
);

-- line #23848
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CASFLOX 200 (CASCA)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CASFLOX 200 (CASCA)'
);

-- line #23849
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEOFLOX 200 (Destin Lab)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEOFLOX 200 (Destin Lab)'
);

-- line #23850
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-FLOX 200 (Corona)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-FLOX 200 (Corona)'
);

-- line #23851
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CG FLOX 400 (CMGBT)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CG FLOX 400 (CMGBT)'
);

-- line #23852
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHEKMET 200 (Piramal Hc.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHEKMET 200 (Piramal Hc.)'
);

-- line #23853
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHEKMET 400 (Piramal Hc.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHEKMET 400 (Piramal Hc.)'
);

-- line #23854
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CINOFLOX 200 (Medicine & Kure)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CINOFLOX 200 (Medicine & Kure)'
);

-- line #23855
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIOFF 200 (Caplet Ind.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIOFF 200 (Caplet Ind.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIOFF 400 (Caplet Ind.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIOFF 400 (Caplet Ind.)'
);

-- line #23856
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOFCIN 100 (Lark Labs)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/10ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOFCIN 100 (Lark Labs)'
);

-- line #23857
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOFCIN 200 (Lark Labs)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOFCIN 200 (Lark Labs)'
);

-- line #23858
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COFLOX 200 (Sain Med.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COFLOX 200 (Sain Med.)'
);

-- line #23859
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COZAN 200 (GENESIS)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COZAN 200 (GENESIS)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COZAN 400 (GENESIS)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COZAN 400 (GENESIS)'
);

-- line #23860
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUCIN 200 (Elfin Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUCIN 200 (Elfin Ph.)'
);

-- line #23861
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CURADEX 200 (Claris L.)',
	'Ofloxacin',
	'INF',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CURADEX 200 (Claris L.)'
);

-- line #23862
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAFOX 200 (SHRI SWAMI)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAFOX 200 (SHRI SWAMI)'
);

-- line #23863
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'D-CIN 200 (DIVINE LAB.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'D-CIN 200 (DIVINE LAB.)'
);

-- line #23864
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEFLOX 200 (Devi Form.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEFLOX 200 (Devi Form.)'
);

-- line #23865
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DENOF 50 (Bennet Ph.)',
	'Ofloxacin',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DENOF 50 (Bennet Ph.)'
);

-- line #23866
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DENOF 200 (Bennet Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DENOF 200 (Bennet Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DENOF 400 (Bennet Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DENOF 400 (Bennet Ph.)'
);

-- line #23867
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200', u'strength_2': u'', u'substance': u'Ofloxacin', u'always_empty': u'', u'form': u'', u'brand': u'DEXCURE', u'strength_3': u'', u'company': u'ABLAZE HC', u'unit': u'mg'}

-- line #23868
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIOFLOX 0.3 (Divine Life)',
	'Ofloxacin',
	'EYE DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIOFLOX 0.3 (Divine Life)'
);

-- line #23869
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIOFLOX 200 (Divine Life)',
	'Ofloxacin',
	'INF',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIOFLOX 200 (Divine Life)'
);

-- line #23870
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIOFLOX 50 (Divine Life)',
	'Ofloxacin',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIOFLOX 50 (Divine Life)'
);

-- line #23871
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIOFLOX 100 (Divine Life)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIOFLOX 100 (Divine Life)'
);

-- line #23872
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIOFLOX 200 (Divine Life)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIOFLOX 200 (Divine Life)'
);

-- line #23873
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIOFLOX 400 (Divine Life)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIOFLOX 400 (Divine Life)'
);

-- line #23874
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOACT 200 (MILMET)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOACT 200 (MILMET)'
);

-- line #23875
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOST 200 (Ornate Lab)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOST 200 (Ornate Lab)'
);

-- line #23876
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYNAFLO 200 (ARCUS LABS)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYNAFLO 200 (ARCUS LABS)'
);

-- line #23877
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ECOCIN 200 (Vasphar)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ECOCIN 200 (Vasphar)'
);

-- line #23878
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ECOLOX 200 (ANAND HC.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ECOLOX 200 (ANAND HC.)'
);

-- line #23879
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EDILOX 200 (Radix Bio.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EDILOX 200 (Radix Bio.)'
);

-- line #23880
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EEOF 200 (EOAN PH.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EEOF 200 (EOAN PH.)'
);

-- line #23881
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EFLOBID 200 (SPPL)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EFLOBID 200 (SPPL)'
);

-- line #23882
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'E-FLOX 200 (MARLINE BIO.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'E-FLOX 200 (MARLINE BIO.)'
);

-- line #23883
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELEFLOX 200 (ELEMENT PH.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELEFLOX 200 (ELEMENT PH.)'
);

-- line #23884
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELFLOX 200 (Phytochem)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELFLOX 200 (Phytochem)'
);

-- line #23885
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELOX 100 (Ethicare)',
	'Ofloxacin',
	'DT/200 TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELOX 100 (Ethicare)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELOX 200 (Ethicare)',
	'Ofloxacin',
	'DT/200 TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELOX 200 (Ethicare)'
);

-- line #23886
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMELFLOX 200 (Medico)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMELFLOX 200 (Medico)'
);

-- line #23887
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMUCIN 0.3 (Emcure)',
	'Ofloxacin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMUCIN 0.3 (Emcure)'
);

-- line #23888
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMUCIN 200 (Emcure)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMUCIN 200 (Emcure)'
);

-- line #23889
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENDIF 50 (Gcm Lab.)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENDIF 50 (Gcm Lab.)'
);

-- line #23890
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENDIF 200 (Gcm Lab.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENDIF 200 (Gcm Lab.)'
);

-- line #23891
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENTOF 0.3 (Dey''S)',
	'Ofloxacin',
	'E/E DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENTOF 0.3 (Dey''S)'
);

-- line #23892
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENTOF 200 (Dey''S)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENTOF 200 (Dey''S)'
);

-- line #23893
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENTOF 400 (Dey''S)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENTOF 400 (Dey''S)'
);

-- line #23894
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EOCIN 200 (Vasphar)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EOCIN 200 (Vasphar)'
);

-- line #23895
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUFOX 0.3 (Lupin)',
	'Ofloxacin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUFOX 0.3 (Lupin)'
);

-- line #23896
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUFOX 200 (Lupin)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUFOX 200 (Lupin)'
);

-- line #23897
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EVAFLOX 200 (Neu-Foreva)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EVAFLOX 200 (Neu-Foreva)'
);

-- line #23898
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EVAFLOX 400 (Neu-Foreva)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EVAFLOX 400 (Neu-Foreva)'
);

-- line #23899
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXOCIN 0.3 (Allergan)',
	'Ofloxacin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXOCIN 0.3 (Allergan)'
);

-- line #23900
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXOCINE 0.3 (Allergan)',
	'Ofloxacin',
	'EYE DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXOCINE 0.3 (Allergan)'
);

-- line #23901
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXO 200 (Shreeyam)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXO 200 (Shreeyam)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXO 400 (Shreeyam)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXO 400 (Shreeyam)'
);

-- line #23902
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EYLOX 0.3 (Solitaire)',
	'Ofloxacin',
	'E/E DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EYLOX 0.3 (Solitaire)'
);

-- line #23903
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FESTIVE 200 (Laborate)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FESTIVE 200 (Laborate)'
);

-- line #23904
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIBAC 200 (Calibar Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIBAC 200 (Calibar Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIBAC 400 (Calibar Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIBAC 400 (Calibar Ph.)'
);

-- line #23905
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLEX 50 (Siomond)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLEX 50 (Siomond)'
);

-- line #23906
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLEX 200 (Siomond)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLEX 200 (Siomond)'
);

-- line #23907
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Ofloxacin', u'always_empty': u'', u'form': u'EYE DROP', u'brand': u'FL', u'strength_3': u'', u'company': u'Royal', u'unit': u''}

-- line #23908
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOBACIN 50 (Saga Lab)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOBACIN 50 (Saga Lab)'
);

-- line #23909
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOBACIN 200 (Saga Lab)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOBACIN 200 (Saga Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOBACIN 400 (Saga Lab)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOBACIN 400 (Saga Lab)'
);

-- line #23910
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLODAL 50 (Dallas Ph.)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLODAL 50 (Dallas Ph.)'
);

-- line #23911
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOMIN 200 (Mefro Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOMIN 200 (Mefro Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOMIN 400 (Mefro Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOMIN 400 (Mefro Ph.)'
);

-- line #23912
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLORA 50 (Serve Ph.)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLORA 50 (Serve Ph.)'
);

-- line #23913
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLORA 200 (Serve Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLORA 200 (Serve Ph.)'
);

-- line #23914
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOROBID 200 (HAMPS BIO)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOROBID 200 (HAMPS BIO)'
);

-- line #23915
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOR 200 (RIYA REM.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOR 200 (RIYA REM.)'
);

-- line #23916
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLORYX 200 (Jrs Oryx.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLORYX 200 (Jrs Oryx.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLORYX 400 (Jrs Oryx.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLORYX 400 (Jrs Oryx.)'
);

-- line #23917
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOWMET 0.3 (Mercury Hc.)',
	'Ofloxacin',
	'EYE DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOWMET 0.3 (Mercury Hc.)'
);

-- line #23918
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Ofloxacin', u'always_empty': u'', u'form': u'INJ', u'brand': u'FLOWMET', u'strength_3': u'', u'company': u'Mercury Hc.', u'unit': u''}

-- line #23919
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOWMET 50 (Mercury Hc.)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOWMET 50 (Mercury Hc.)'
);

-- line #23920
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOWMET 200 (Mercury Hc.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOWMET 200 (Mercury Hc.)'
);

-- line #23921
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOW 200 (AUM PH.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOW 200 (AUM PH.)'
);

-- line #23922
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOW 200 (LA SERENA)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOW 200 (LA SERENA)'
);

-- line #23923
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXACE 200 (Integrated)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXACE 200 (Integrated)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXACE 400 (Integrated)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXACE 400 (Integrated)'
);

-- line #23924
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXADE 200 (Cascade)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXADE 200 (Cascade)'
);

-- line #23925
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXAQUIN 200 (Healthgaurd)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXAQUIN 200 (Healthgaurd)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXAQUIN 400 (Healthgaurd)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXAQUIN 400 (Healthgaurd)'
);

-- line #23926
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXAR 200 (Forgo Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXAR 200 (Forgo Ph.)'
);

-- line #23927
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXET 200 (Jaywin)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXET 200 (Jaywin)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXET 400 (Jaywin)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXET 400 (Jaywin)'
);

-- line #23928
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXIBID 200 (YASHTRA HEALTH)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXIBID 200 (YASHTRA HEALTH)'
);

-- line #23929
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXICONTIN O-400 400 (Modi Mundi)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXICONTIN O-400 400 (Modi Mundi)'
);

-- line #23930
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXICONTIN O-800 800 (Modi Mundi)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXICONTIN O-800 800 (Modi Mundi)'
);

-- line #23931
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXIL-O 0.3 (Ind-Swift)',
	'Ofloxacin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXIL-O 0.3 (Ind-Swift)'
);

-- line #23932
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXIN 200 (Samson)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXIN 200 (Samson)'
);

-- line #23933
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXODAY 50 (INVISION(INFALIFE))',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXODAY 50 (INVISION(INFALIFE))'
);

-- line #23934
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXODAY 100 (INVISION(INFALIFE))',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXODAY 100 (INVISION(INFALIFE))'
);

-- line #23935
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXOLE 50 (Cosmas Ph.)',
	'Ofloxacin',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXOLE 50 (Cosmas Ph.)'
);

-- line #23936
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXOLE 200 (Cosmas Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXOLE 200 (Cosmas Ph.)'
);

-- line #23937
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXO PLUS 200 (Zenith Hc.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXO PLUS 200 (Zenith Hc.)'
);

-- line #23938
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOX-O 200 (Arbro Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOX-O 200 (Arbro Ph.)'
);

-- line #23939
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOX-O 200 (Mark Rem.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOX-O 200 (Mark Rem.)'
);

-- line #23940
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXO 100 (Zenith Hc.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXO 100 (Zenith Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXO 400 (Zenith Hc.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXO 400 (Zenith Hc.)'
);

-- line #23941
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXUR 400 (Merind)',
	'Ofloxacin',
	'OD TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXUR 400 (Merind)'
);

-- line #23942
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXUR 100 (Merind)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXUR 100 (Merind)'
);

-- line #23943
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXUR 200 (Merind)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXUR 200 (Merind)'
);

-- line #23944
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXUR 400 (Merind)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXUR 400 (Merind)'
);

-- line #23945
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXY 200 (Atrimed Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXY 200 (Atrimed Ph.)'
);

-- line #23946
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXZEN 50 (Moraceae)',
	'Ofloxacin',
	'SUSP',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXZEN 50 (Moraceae)'
);

-- line #23947
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXZEN 100 (Moraceae)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXZEN 100 (Moraceae)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXZEN 200 (Moraceae)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXZEN 200 (Moraceae)'
);

-- line #23948
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOZE 200 (Zetek Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOZE 200 (Zetek Ph.)'
);

-- line #23949
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FL 50 (Royal Lab)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FL 50 (Royal Lab)'
);

-- line #23950
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FL 200 (Royal Lab)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FL 200 (Royal Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FL 400 (Royal Lab)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FL 400 (Royal Lab)'
);

-- line #23951
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOF-200 200 (BIOKIND HC.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOF-200 200 (BIOKIND HC.)'
);

-- line #23952
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOVEN 0.3 (VENSAT)',
	'Ofloxacin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOVEN 0.3 (VENSAT)'
);

-- line #23953
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOXCIN 3 (Monokem)',
	'Ofloxacin',
	'DPS',
	gm.nullify_empty_string('3')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOXCIN 3 (Monokem)'
);

-- line #23954
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOXCIN 200 (Monokem)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOXCIN 200 (Monokem)'
);

-- line #23955
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GALOXIN 200 (Galpha)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GALOXIN 200 (Galpha)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GALOXIN 400 (Galpha)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GALOXIN 400 (Galpha)'
);

-- line #23956
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENFLOX 200 (Cadila Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENFLOX 200 (Cadila Ph.)'
);

-- line #23957
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENOFLOX 50 (Genova)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENOFLOX 50 (Genova)'
);

-- line #23958
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENOFLOX 100 (Genova)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENOFLOX 100 (Genova)'
);

-- line #23959
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENOFLOX 200 (Genova)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENOFLOX 200 (Genova)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENOFLOX 400 (Genova)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENOFLOX 400 (Genova)'
);

-- line #23960
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLOFTY 0.3 (Globus)',
	'Ofloxacin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLOFTY 0.3 (Globus)'
);

-- line #23961
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLOFTY 100 (Globus)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLOFTY 100 (Globus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLOFTY 200 (Globus)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLOFTY 200 (Globus)'
);

-- line #23962
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLOFTY 400 (Globus)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLOFTY 400 (Globus)'
);

-- line #23963
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GYROCIN 200 (Lenit Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GYROCIN 200 (Lenit Ph.)'
);

-- line #23964
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GYROFLOX 200 (LACLIN)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GYROFLOX 200 (LACLIN)'
);

-- line #23965
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HANUFLOX 50 (Ravian)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HANUFLOX 50 (Ravian)'
);

-- line #23966
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HANUFLOX 100 (Ravian)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HANUFLOX 100 (Ravian)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HANUFLOX 200 (Ravian)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HANUFLOX 200 (Ravian)'
);

-- line #23967
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HARPOON 200 (Merck)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HARPOON 200 (Merck)'
);

-- line #23968
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HARPOON 400 (Merck)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HARPOON 400 (Merck)'
);

-- line #23969
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEXOFLO 200 (HEXAL PH.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEXOFLO 200 (HEXAL PH.)'
);

-- line #23970
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HICIN 200 (Hitech Form.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HICIN 200 (Hitech Form.)'
);

-- line #23971
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIT 50 (Elf Biomed)',
	'Ofloxacin',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIT 50 (Elf Biomed)'
);

-- line #23972
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIT 200 (Elf Biomed)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIT 200 (Elf Biomed)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIT 400 (Elf Biomed)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIT 400 (Elf Biomed)'
);

-- line #23973
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,3', u'strength_2': u'', u'substance': u'Ofloxacin', u'always_empty': u'', u'form': u'', u'brand': u'IFLOX E/D', u'strength_3': u'', u'company': u'VISION PH.', u'unit': u'%'}

-- line #23974
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INFLOBACT 400 (INVISION)',
	'Ofloxacin',
	'OD TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INFLOBACT 400 (INVISION)'
);

-- line #23975
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INFLOBACT 50 (INVISION)',
	'Ofloxacin',
	'SUSP',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INFLOBACT 50 (INVISION)'
);

-- line #23976
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INFLOBACT 200 (Intra(INVISION))',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INFLOBACT 200 (Intra(INVISION))'
);

-- line #23977
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INFLOBID 0.3 (Intra Lab)',
	'Ofloxacin',
	'E/E DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INFLOBID 0.3 (Intra Lab)'
);

-- line #23978
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INFLOBID 50 (Intra Lab)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INFLOBID 50 (Intra Lab)'
);

-- line #23979
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INFLOBID 200 (Intra Lab)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INFLOBID 200 (Intra Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INFLOBID 400 (Intra Lab)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INFLOBID 400 (Intra Lab)'
);

-- line #23980
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JETVID KID/200 100 (CHEMO HC.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JETVID KID/200 100 (CHEMO HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JETVID KID/200 200 (CHEMO HC.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JETVID KID/200 200 (CHEMO HC.)'
);

-- line #23981
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JFLO 0.3 (Om Bio.)',
	'Ofloxacin',
	'E/E DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JFLO 0.3 (Om Bio.)'
);

-- line #23982
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JFLO 200 (Om Bio.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JFLO 200 (Om Bio.)'
);

-- line #23983
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JONFLOX 200 (D.R.John''S)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JONFLOX 200 (D.R.John''S)'
);

-- line #23984
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JOX 100 (D.R.John''S)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JOX 100 (D.R.John''S)'
);

-- line #23985
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JOX 200 (D.R.John''S)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JOX 200 (D.R.John''S)'
);

-- line #23986
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JOX 400 (D.R.John''S)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JOX 400 (D.R.John''S)'
);

-- line #23987
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JPFLOX 200 (J.P.LIFE)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JPFLOX 200 (J.P.LIFE)'
);

-- line #23988
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KALOXUR 200 (Khushal Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KALOXUR 200 (Khushal Ph.)'
);

-- line #23989
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAFLOX 200 (DATLA)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAFLOX 200 (DATLA)'
);

-- line #23990
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEMOFF 100 (LEMON PH.)',
	'Ofloxacin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEMOFF 100 (LEMON PH.)'
);

-- line #23991
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEMOFF 200 (LEMON PH.)',
	'Ofloxacin',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEMOFF 200 (LEMON PH.)'
);

-- line #23992
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEXOF 100 (Lexus)',
	'Ofloxacin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEXOF 100 (Lexus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEXOF 200 (Lexus)',
	'Ofloxacin',
	'DT',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEXOF 200 (Lexus)'
);

-- line #23993
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEXOF 50 (Lexus)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEXOF 50 (Lexus)'
);

-- line #23994
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOF-200 200 (LUSTRE)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOF-200 200 (LUSTRE)'
);

-- line #23995
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOFT 200 (ADMAC (LEE BENZ))',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOFT 200 (ADMAC (LEE BENZ))'
);

-- line #23996
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOXIN 0.3 (Dynamic)',
	'Ofloxacin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOXIN 0.3 (Dynamic)'
);

-- line #23997
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOXIN 0.3 (Dynamic)',
	'Ofloxacin',
	'E/E DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOXIN 0.3 (Dynamic)'
);

-- line #23998
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOXIN 200 (Dynamic)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOXIN 200 (Dynamic)'
);

-- line #23999
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALOFLOX 50 (Malody Hc.)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALOFLOX 50 (Malody Hc.)'
);

-- line #24000
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALOFLOX 200 (Malody Hc.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALOFLOX 200 (Malody Hc.)'
);

-- line #24001
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALOFLOX 400 (Malody Hc.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALOFLOX 400 (Malody Hc.)'
);

-- line #24002
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGAFLOX 200 (Bliss)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGAFLOX 200 (Bliss)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGAFLOX 400 (Bliss)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGAFLOX 400 (Bliss)'
);

-- line #24003
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEUFLOX 200 (WILLOW)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEUFLOX 200 (WILLOW)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEUFLOX 400 (WILLOW)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEUFLOX 400 (WILLOW)'
);

-- line #24004
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICROF 200 (Mamta Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICROF 200 (Mamta Ph.)'
);

-- line #24005
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILOF 50 (Shaimil)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILOF 50 (Shaimil)'
);

-- line #24006
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILOF 100 (Shaimil)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILOF 100 (Shaimil)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILOF 200 (Shaimil)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILOF 200 (Shaimil)'
);

-- line #24007
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILOF 400 (Shaimil)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILOF 400 (Shaimil)'
);

-- line #24008
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MINIMAX 200 (Dial Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MINIMAX 200 (Dial Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MINIMAX 400 (Dial Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MINIMAX 400 (Dial Ph.)'
);

-- line #24009
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOFCARE 0.3 (MADHAV BIO.)',
	'Ofloxacin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOFCARE 0.3 (MADHAV BIO.)'
);

-- line #24010
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOFLOX 100 (Marc Lab)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOFLOX 100 (Marc Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOFLOX 200 (Marc Lab)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOFLOX 200 (Marc Lab)'
);

-- line #24011
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOFLOX 400 (Marc Lab)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOFLOX 400 (Marc Lab)'
);

-- line #24012
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOFLOX 200 (MODHIKE)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOFLOX 200 (MODHIKE)'
);

-- line #24013
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOFLOX 200 (Captab)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOFLOX 200 (Captab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOFLOX 400 (Captab)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOFLOX 400 (Captab)'
);

-- line #24014
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Ofloxacin', u'always_empty': u'', u'form': u'SUS', u'brand': u'NANO', u'strength_3': u'', u'company': u'AUGMENT REM.', u'unit': u''}

-- line #24015
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOBID 50 (Brussels)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOBID 50 (Brussels)'
);

-- line #24016
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOBID 200 (Brussels)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOBID 200 (Brussels)'
);

-- line #24017
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NESTOFLOX 200 (Nestor)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NESTOFLOX 200 (Nestor)'
);

-- line #24018
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIDA 50 (Unicure)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIDA 50 (Unicure)'
);

-- line #24019
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIDA 200 (Unicure)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIDA 200 (Unicure)'
);

-- line #24020
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIFLOX 200 (NAVNIDHI LIFE)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIFLOX 200 (NAVNIDHI LIFE)'
);

-- line #24021
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOFF 200 (Nitin Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOFF 200 (Nitin Ph.)'
);

-- line #24022
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORFIT 200 (NORTECH REM.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORFIT 200 (NORTECH REM.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORFIT 400 (NORTECH REM.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORFIT 400 (NORTECH REM.)'
);

-- line #24023
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVOFRAN 100 (Seagull)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVOFRAN 100 (Seagull)'
);

-- line #24024
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVOFRAN 200 (Seagull)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVOFRAN 200 (Seagull)'
);

-- line #24025
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVOFRAN 400 (Seagull)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVOFRAN 400 (Seagull)'
);

-- line #24026
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUFLEXIN 200 (Merit Org.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUFLEXIN 200 (Merit Org.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUFLEXIN 400 (Merit Org.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUFLEXIN 400 (Merit Org.)'
);

-- line #24027
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OA-100 100 (AARON HC.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OA-100 100 (AARON HC.)'
);

-- line #24028
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OA-200 200 (AARON HC.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OA-200 200 (AARON HC.)'
);

-- line #24029
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OA-400 400 (AARON HC.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OA-400 400 (AARON HC.)'
);

-- line #24030
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50', u'strength_2': u'', u'substance': u'Ofloxacin', u'always_empty': u'', u'form': u'', u'brand': u'OA-SUSP', u'strength_3': u'', u'company': u'AARON HC.', u'unit': u'mg'}

-- line #24031
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OBACTIN 100 (Meridian)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OBACTIN 100 (Meridian)'
);

-- line #24032
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OBACTIN 200 (Meridian)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OBACTIN 200 (Meridian)'
);

-- line #24033
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OBACT 100 (Allure Rem.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OBACT 100 (Allure Rem.)'
);

-- line #24034
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OBACT 200 (Allure Rem.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OBACT 200 (Allure Rem.)'
);

-- line #24035
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OBACT 200 (Biomax Bio.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OBACT 200 (Biomax Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OBACT 400 (Biomax Bio.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OBACT 400 (Biomax Bio.)'
);

-- line #24036
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OBID 400 (Ordain Hc.)',
	'Ofloxacin',
	'ER TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OBID 400 (Ordain Hc.)'
);

-- line #24037
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OBID 50 (Radicura)',
	'Ofloxacin',
	'SUSP',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OBID 50 (Radicura)'
);

-- line #24038
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OBID 200 (Radicura)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OBID 200 (Radicura)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OBID 400 (Radicura)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OBID 400 (Radicura)'
);

-- line #24039
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OBIT 200 (Malar Hc.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OBIT 200 (Malar Hc.)'
);

-- line #24040
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'O-CEBRAN 0.3 (Blue Cross)',
	'Ofloxacin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'O-CEBRAN 0.3 (Blue Cross)'
);

-- line #24041
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'O-CEBRAN 200 (Blue Cross)',
	'Ofloxacin',
	'FC TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'O-CEBRAN 200 (Blue Cross)'
);

-- line #24042
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'O-CEBRAN 200 (Blue Cross)',
	'Ofloxacin',
	'INF',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'O-CEBRAN 200 (Blue Cross)'
);

-- line #24043
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'O-CEBRAN 300 (Blue Cross)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'O-CEBRAN 300 (Blue Cross)'
);

-- line #24044
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'O-CEBRAN 400 (Blue Cross)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'O-CEBRAN 400 (Blue Cross)'
);

-- line #24045
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCENT 50 (Ascent Lab)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCENT 50 (Ascent Lab)'
);

-- line #24046
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCENT 200 (Ascent Lab)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCENT 200 (Ascent Lab)'
);

-- line #24047
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Ofloxacin', u'always_empty': u'', u'form': u'E/E DROPS', u'brand': u'O-CIN', u'strength_3': u'', u'company': u'DIVINE LAB.', u'unit': u''}

-- line #24048
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCIN 50 (GRANDIX)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCIN 50 (GRANDIX)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCIN 200 (GRANDIX)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCIN 200 (GRANDIX)'
);

-- line #24049
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCIZ 200 (Ritz Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCIZ 200 (Ritz Ph.)'
);

-- line #24050
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCUCIN 0.3 (Milmet)',
	'Ofloxacin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCUCIN 0.3 (Milmet)'
);

-- line #24051
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCULONE 0.3 (Yash Vision)',
	'Ofloxacin',
	'E/E DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCULONE 0.3 (Yash Vision)'
);

-- line #24052
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCUSTAR 0.3 (DREAM PH.)',
	'Ofloxacin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCUSTAR 0.3 (DREAM PH.)'
);

-- line #24053
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFACE 200 (ACE LAB.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFACE 200 (ACE LAB.)'
);

-- line #24054
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFACIN 50 (Indu D.)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFACIN 50 (Indu D.)'
);

-- line #24055
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFACIN 200 (Indu D.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFACIN 200 (Indu D.)'
);

-- line #24056
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFACIN 200 (Medizone)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFACIN 200 (Medizone)'
);

-- line #24057
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFAL -1 100 (Hi-Tec)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFAL -1 100 (Hi-Tec)'
);

-- line #24058
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFAL-2 200 (Hi-Tec)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFAL-2 200 (Hi-Tec)'
);

-- line #24059
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFAL-3 300 (Hi-Tec)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFAL-3 300 (Hi-Tec)'
);

-- line #24060
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFAL-4 400 (Hi-Tec)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFAL-4 400 (Hi-Tec)'
);

-- line #24061
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFAL 200 (Hi-Tec)',
	'Ofloxacin',
	'INF',
	gm.nullify_empty_string('200')::numeric,
	'mg/100ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFAL 200 (Hi-Tec)'
);

-- line #24062
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFAL 50 (Hi-Tec)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFAL 50 (Hi-Tec)'
);

-- line #24063
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFAN 200 (Norris Med.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFAN 200 (Norris Med.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFAN 400 (Norris Med.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFAN 400 (Norris Med.)'
);

-- line #24064
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Ofloxacin', u'always_empty': u'', u'form': u'EYE DPS', u'brand': u'OFAX', u'strength_3': u'', u'company': u'Optho Rem.', u'unit': u''}

-- line #24065
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFAXIN 100 (Stanford)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFAXIN 100 (Stanford)'
);

-- line #24066
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFAXIN 200 (Stanford)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFAXIN 200 (Stanford)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFAXIN 400 (Stanford)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFAXIN 400 (Stanford)'
);

-- line #24067
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFAX 100 (Alde Medi.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFAX 100 (Alde Medi.)'
);

-- line #24068
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFAX 200 (Alde Medi.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFAX 200 (Alde Medi.)'
);

-- line #24069
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFAX 400 (Alde Medi.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFAX 400 (Alde Medi.)'
);

-- line #24070
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFAX 200 (HETERO HC.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFAX 200 (HETERO HC.)'
);

-- line #24071
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFAX 200 (Mcneil & ARGUS)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFAX 200 (Mcneil & ARGUS)'
);

-- line #24072
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFAY 50 (Azime Hc.)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFAY 50 (Azime Hc.)'
);

-- line #24073
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFBRAKE 50 (RADHE BIO.)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFBRAKE 50 (RADHE BIO.)'
);

-- line #24074
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFBRAKE 200 (RADHE BIO.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFBRAKE 200 (RADHE BIO.)'
);

-- line #24075
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFCIN 200 (Alpic Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFCIN 200 (Alpic Ph.)'
);

-- line #24076
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFCIN 200 (Dynamic)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFCIN 200 (Dynamic)'
);

-- line #24077
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFC 200 (Paras Lab)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFC 200 (Paras Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFC 400 (Paras Lab)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFC 400 (Paras Lab)'
);

-- line #24078
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OF 100 (J. B. Chem.)',
	'Ofloxacin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OF 100 (J. B. Chem.)'
);

-- line #24079
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OF 0.3 (J. B. Chem.)',
	'Ofloxacin',
	'E/E DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OF 0.3 (J. B. Chem.)'
);

-- line #24080
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFFLOAD 100 (Nimbus Med.)',
	'Ofloxacin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFFLOAD 100 (Nimbus Med.)'
);

-- line #24081
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFFLOAD 200 (Nimbus Med.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFFLOAD 200 (Nimbus Med.)'
);

-- line #24082
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Ofloxacin', u'always_empty': u'', u'form': u'SUS', u'brand': u'OFF', u'strength_3': u'', u'company': u'MEDISYS', u'unit': u''}

-- line #24083
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFF 200 (MEDISYS)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFF 200 (MEDISYS)'
);

-- line #24084
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Ofloxacin', u'always_empty': u'', u'form': u'DPS', u'brand': u'OFIN', u'strength_3': u'', u'company': u'Finesse Ph.', u'unit': u''}

-- line #24085
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFIND 200 (Indica)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFIND 200 (Indica)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFIND 400 (Indica)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFIND 400 (Indica)'
);

-- line #24086
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFIN 3 (Oscar Rem.)',
	'Ofloxacin',
	'EYE DPS',
	gm.nullify_empty_string('3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFIN 3 (Oscar Rem.)'
);

-- line #24087
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OF 2 (J.B. CHEM)',
	'Ofloxacin',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OF 2 (J.B. CHEM)'
);

-- line #24088
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFIN 200 (Oscar Rem.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFIN 200 (Oscar Rem.)'
);

-- line #24089
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFIT 200 (National)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFIT 200 (National)'
);

-- line #24090
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLABIN 200 (Medispan)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLABIN 200 (Medispan)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLABIN 400 (Medispan)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLABIN 400 (Medispan)'
);

-- line #24091
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLACIN 0.3 (Micro V.)',
	'Ofloxacin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLACIN 0.3 (Micro V.)'
);

-- line #24092
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLACIN 400 (Micro Labs)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLACIN 400 (Micro Labs)'
);

-- line #24093
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLACIN 200 (Micro V.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLACIN 200 (Micro V.)'
);

-- line #24094
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLACT 200 (Health Care)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLACT 200 (Health Care)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLACT 400 (Health Care)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLACT 400 (Health Care)'
);

-- line #24095
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLA 100 (Khandelwal)',
	'Ofloxacin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLA 100 (Khandelwal)'
);

-- line #24096
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,2', u'strength_2': u'', u'substance': u'Ofloxacin', u'always_empty': u'', u'form': u'', u'brand': u'OFLAGARD IV', u'strength_3': u'', u'company': u'BIOMAX BIO.', u'unit': u'%'}

-- line #24097
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLAGARD 200 (Biomax Bio.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLAGARD 200 (Biomax Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLAGARD 400 (Biomax Bio.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLAGARD 400 (Biomax Bio.)'
);

-- line #24098
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLAMAK 50 (Makbro Hc.)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLAMAK 50 (Makbro Hc.)'
);

-- line #24099
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLAMAK 200 (Makbro Hc.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLAMAK 200 (Makbro Hc.)'
);

-- line #24100
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLAMAX 200 (Hamax Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLAMAX 200 (Hamax Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLAMAX 400 (Hamax Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLAMAX 400 (Hamax Ph.)'
);

-- line #24101
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLAMED 200 (Aglowmed)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLAMED 200 (Aglowmed)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLAMED 400 (Aglowmed)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLAMED 400 (Aglowmed)'
);

-- line #24102
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLA 400 (Khandelwal)',
	'Ofloxacin',
	'OD TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLA 400 (Khandelwal)'
);

-- line #24103
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLAR 200 (Arvind Lab.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLAR 200 (Arvind Lab.)'
);

-- line #24104
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLASON 200 (Jarson Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLASON 200 (Jarson Ph.)'
);

-- line #24105
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLAS 200 (SHRESHTHA)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLAS 200 (SHRESHTHA)'
);

-- line #24106
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Ofloxacin', u'always_empty': u'', u'form': u'SUS', u'brand': u'OFLA', u'strength_3': u'', u'company': u'Khandelwal', u'unit': u''}

-- line #24107
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLASWIFT 200 (Swift Med.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLASWIFT 200 (Swift Med.)'
);

-- line #24108
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200', u'strength_2': u'', u'substance': u'Ofloxacin', u'always_empty': u'', u'form': u'', u'brand': u'OFLATAB', u'strength_3': u'', u'company': u'CRATUS', u'unit': u'mg'}

-- line #24109
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLA 200 (Khandelwal)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLA 200 (Khandelwal)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLA 400 (Khandelwal)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLA 400 (Khandelwal)'
);

-- line #24110
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLATAB 50 (CRATUS)',
	'Ofloxacin',
	'SUSP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLATAB 50 (CRATUS)'
);

-- line #24111
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLATE 200 (Relish)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLATE 200 (Relish)'
);

-- line #24112
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLATE 400 (Relish)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLATE 400 (Relish)'
);

-- line #24113
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLATOON 100 (Camlin)',
	'Ofloxacin',
	'DS SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLATOON 100 (Camlin)'
);

-- line #24114
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLATOON 100 (Camlin)',
	'Ofloxacin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLATOON 100 (Camlin)'
);

-- line #24115
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLATOON 400 (Camlin)',
	'Ofloxacin',
	'OD TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLATOON 400 (Camlin)'
);

-- line #24116
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLATOON 50 (Camlin)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLATOON 50 (Camlin)'
);

-- line #24117
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLATOON 200 (Camlin)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLATOON 200 (Camlin)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLATOON 400 (Camlin)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLATOON 400 (Camlin)'
);

-- line #24118
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLAVID 100 (TRIGENESIS)',
	'Ofloxacin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLAVID 100 (TRIGENESIS)'
);

-- line #24119
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLAVID 200 (TRIGENESIS)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLAVID 200 (TRIGENESIS)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLAVID 400 (TRIGENESIS)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLAVID 400 (TRIGENESIS)'
);

-- line #24120
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLAZEN 200 (Kaizen Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLAZEN 200 (Kaizen Ph.)'
);

-- line #24121
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLED 200 (Gloled Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLED 200 (Gloled Ph.)'
);

-- line #24122
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLEEN 100 (Esken)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLEEN 100 (Esken)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLEEN 200 (Esken)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLEEN 200 (Esken)'
);

-- line #24123
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLEEN 400 (Esken)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLEEN 400 (Esken)'
);

-- line #24124
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLER 200 (Aristo)',
	'Ofloxacin',
	'INF',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLER 200 (Aristo)'
);

-- line #24125
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLER 200 (Aristo)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLER 200 (Aristo)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLER 400 (Aristo)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLER 400 (Aristo)'
);

-- line #24126
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLEXIN 200 (Meyer Org.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLEXIN 200 (Meyer Org.)'
);

-- line #24127
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLEXIN 400 (Meyer Org.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLEXIN 400 (Meyer Org.)'
);

-- line #24128
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLEX 100 (Finecure)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLEX 100 (Finecure)'
);

-- line #24129
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLEX 200 (Finecure)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLEX 200 (Finecure)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLEX 400 (Finecure)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLEX 400 (Finecure)'
);

-- line #24130
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLICT 50 (Active Hc.)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLICT 50 (Active Hc.)'
);

-- line #24131
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLICT 200 (Active Hc.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLICT 200 (Active Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLICT 400 (Active Hc.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLICT 400 (Active Hc.)'
);

-- line #24132
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLIK 200 (Remedy)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLIK 200 (Remedy)'
);

-- line #24133
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Ofloxacin', u'always_empty': u'', u'form': u'INF', u'brand': u'OFLIN', u'strength_3': u'', u'company': u'Zydus Cadila', u'unit': u''}

-- line #24134
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLIN 400 (Zydus Cadila)',
	'Ofloxacin',
	'OD',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLIN 400 (Zydus Cadila)'
);

-- line #24135
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLIN 100 (Zydus Cadila)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLIN 100 (Zydus Cadila)'
);

-- line #24136
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLIN 200 (Zydus Cadila)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLIN 200 (Zydus Cadila)'
);

-- line #24137
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLIN 400 (Zydus Cadila)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLIN 400 (Zydus Cadila)'
);

-- line #24138
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOBE 200 (Zydus Cadila)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOBE 200 (Zydus Cadila)'
);

-- line #24139
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOBID 50 (Olcare)',
	'Ofloxacin',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOBID 50 (Olcare)'
);

-- line #24140
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOBID 200 (Olcare)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOBID 200 (Olcare)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOBID 400 (Olcare)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOBID 400 (Olcare)'
);

-- line #24141
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOCEM 200 (Beckcem)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOCEM 200 (Beckcem)'
);

-- line #24142
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOCIN 200 (Candor Bio.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOCIN 200 (Candor Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOCIN 400 (Candor Bio.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOCIN 400 (Candor Bio.)'
);

-- line #24143
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOCIT 200 (CITIZEN LAB.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOCIT 200 (CITIZEN LAB.)'
);

-- line #24144
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOC 50 (Ultra Chiron)',
	'Ofloxacin',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOC 50 (Ultra Chiron)'
);

-- line #24145
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOC 200 (Ultra Chiron)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOC 200 (Ultra Chiron)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOC 400 (Ultra Chiron)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOC 400 (Ultra Chiron)'
);

-- line #24146
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOD 200 (LUCIFER & H.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOD 200 (LUCIFER & H.)'
);

-- line #24147
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLO 100 (Nordic Ph.)',
	'Ofloxacin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLO 100 (Nordic Ph.)'
);

-- line #24148
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOFAM 50 (SIFAM PH.)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOFAM 50 (SIFAM PH.)'
);

-- line #24149
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOFAM 200 (SIFAM PH.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOFAM 200 (SIFAM PH.)'
);

-- line #24150
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOFRESH 200 (SMART LAB.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOFRESH 200 (SMART LAB.)'
);

-- line #24151
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOGEN 200 (Antigen Hc.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOGEN 200 (Antigen Hc.)'
);

-- line #24152
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOGEN 200 (BIOGEN PH.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOGEN 200 (BIOGEN PH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOGEN 400 (BIOGEN PH.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOGEN 400 (BIOGEN PH.)'
);

-- line #24153
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOG 200 (Stalwart)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOG 200 (Stalwart)'
);

-- line #24154
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000', u'strength_2': u'', u'substance': u'Ofloxacin', u'always_empty': u'', u'form': u'', u'brand': u'OFLOKIND BOLUS', u'strength_3': u'', u'company': u'Mankind', u'unit': u'mg'}

-- line #24155
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOK 200 (KORES F.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOK 200 (KORES F.)'
);

-- line #24156
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOMAC 0.3 (Macleods)',
	'Ofloxacin',
	'E/E DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOMAC 0.3 (Macleods)'
);

-- line #24157
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOMAC 400 (Macleods)',
	'Ofloxacin',
	'OD TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOMAC 400 (Macleods)'
);

-- line #24158
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOMAC 100 (Macleods)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOMAC 100 (Macleods)'
);

-- line #24159
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOMAC 200 (Macleods)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOMAC 200 (Macleods)'
);

-- line #24160
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOMAC 300 (Macleods)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOMAC 300 (Macleods)'
);

-- line #24161
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOMAC 400 (Macleods)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOMAC 400 (Macleods)'
);

-- line #24162
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOMIL 50 (Glenmark)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOMIL 50 (Glenmark)'
);

-- line #24163
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOMIL 200 (Glenmark)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOMIL 200 (Glenmark)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOMIL 400 (Glenmark)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOMIL 400 (Glenmark)'
);

-- line #24164
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLONIX 200 (PHENIX PH.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLONIX 200 (PHENIX PH.)'
);

-- line #24165
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLON 50 (Suvik Hit.)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLON 50 (Suvik Hit.)'
);

-- line #24166
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLON 200 (Suvik Hit.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLON 200 (Suvik Hit.)'
);

-- line #24167
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOREN 0.3 (Indoco Rem.)',
	'Ofloxacin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOREN 0.3 (Indoco Rem.)'
);

-- line #24168
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOREN 100 (Indoco Rem.)',
	'Ofloxacin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOREN 100 (Indoco Rem.)'
);

-- line #24169
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOREN 200 (Indoco Rem.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOREN 200 (Indoco Rem.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOREN 400 (Indoco Rem.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOREN 400 (Indoco Rem.)'
);

-- line #24170
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLORON 50 (Ronak Lab.)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLORON 50 (Ronak Lab.)'
);

-- line #24171
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLORON 100 (Ronak Lab.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLORON 100 (Ronak Lab.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLORON 200 (Ronak Lab.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLORON 200 (Ronak Lab.)'
);

-- line #24172
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLORON 400 (Ronak Lab.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLORON 400 (Ronak Lab.)'
);

-- line #24173
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Ofloxacin', u'always_empty': u'', u'form': u'E/E DPS', u'brand': u'OFLOSAN', u'strength_3': u'', u'company': u'SANCHEZ LAB.', u'unit': u''}

-- line #24174
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Ofloxacin', u'always_empty': u'', u'form': u'SYR', u'brand': u'OFLOSAN', u'strength_3': u'', u'company': u'SANCHEZ LAB.', u'unit': u''}

-- line #24175
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOSAN 200 (SANCHEZ LAB.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOSAN 200 (SANCHEZ LAB.)'
);

-- line #24176
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOSTAR 0.3 (CADILA(GENSTAR))',
	'Ofloxacin',
	'EYE DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOSTAR 0.3 (CADILA(GENSTAR))'
);

-- line #24177
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOSTAR IV 200 (CADILA(GENSTAR))',
	'Ofloxacin',
	'INF',
	gm.nullify_empty_string('200')::numeric,
	'mg(+NACL 0.9'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOSTAR IV 200 (CADILA(GENSTAR))'
);

-- line #24178
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOSTAR 50 (CADILA(GENSTAR))',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOSTAR 50 (CADILA(GENSTAR))'
);

-- line #24179
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOSTAR 200 (CADILA(GENSTAR))',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOSTAR 200 (CADILA(GENSTAR))'
);

-- line #24180
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLO 50 (Nordic Ph.)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLO 50 (Nordic Ph.)'
);

-- line #24181
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLO 200 (Nordic Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLO 200 (Nordic Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLO 400 (Nordic Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLO 400 (Nordic Ph.)'
);

-- line #24182
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOTAG 200 (SMENTAG PH.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOTAG 200 (SMENTAG PH.)'
);

-- line #24183
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOTAS 0.3 (Intas)',
	'Ofloxacin',
	'EYE DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOTAS 0.3 (Intas)'
);

-- line #24184
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOTEC 100 (ACTO)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOTEC 100 (ACTO)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOTEC 200 (ACTO)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOTEC 200 (ACTO)'
);

-- line #24185
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOTEC 400 (ACTO)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOTEC 400 (ACTO)'
);

-- line #24186
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOTER 200 (GUJ. TE.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOTER 200 (GUJ. TE.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOTER 400 (GUJ. TE.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOTER 400 (GUJ. TE.)'
);

-- line #24187
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Ofloxacin', u'always_empty': u'', u'form': u'SYP', u'brand': u'OFLOTIC', u'strength_3': u'', u'company': u'NIVCA', u'unit': u''}

-- line #24188
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Ofloxacin', u'always_empty': u'', u'form': u'TAB', u'brand': u'OFLOTIC', u'strength_3': u'', u'company': u'NIVCA', u'unit': u''}

-- line #24189
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOVID 100 (TRIGENESIS)',
	'Ofloxacin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOVID 100 (TRIGENESIS)'
);

-- line #24190
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOVID 200 (TRIGENESIS)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOVID 200 (TRIGENESIS)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOVID 400 (TRIGENESIS)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOVID 400 (TRIGENESIS)'
);

-- line #24191
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOWIN 200 (Ikon Rem)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOWIN 200 (Ikon Rem)'
);

-- line #24192
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOXACIN 200 (TUNE PH.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOXACIN 200 (TUNE PH.)'
);

-- line #24193
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOXAIN 200 (Sain Med.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOXAIN 200 (Sain Med.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOXAIN 400 (Sain Med.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOXAIN 400 (Sain Med.)'
);

-- line #24194
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOX 100 (Protec)',
	'Ofloxacin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOX 100 (Protec)'
);

-- line #24195
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOX EYE 0.3 (Protec)',
	'Ofloxacin',
	'DROPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOX EYE 0.3 (Protec)'
);

-- line #24196
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOX 0.3 (Protec)',
	'Ofloxacin',
	'EYE OINT',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOX 0.3 (Protec)'
);

-- line #24197
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOXIBACT 200 (UNISEARCH HC.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOXIBACT 200 (UNISEARCH HC.)'
);

-- line #24198
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOXINA 100 (Southsourne)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOXINA 100 (Southsourne)'
);

-- line #24199
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOXINA 200 (Southsourne)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOXINA 200 (Southsourne)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOXINA 400 (Southsourne)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOXINA 400 (Southsourne)'
);

-- line #24200
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOX 200 (Protec)',
	'Ofloxacin',
	'INF',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOX 200 (Protec)'
);

-- line #24201
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOX 400 (Cipla)',
	'Ofloxacin',
	'OD TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOX 400 (Cipla)'
);

-- line #24202
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOX 400 (Cipla)',
	'Ofloxacin',
	'OD TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg(ER)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOX 400 (Cipla)'
);

-- line #24203
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100', u'strength_2': u'', u'substance': u'Ofloxacin', u'always_empty': u'', u'form': u'', u'brand': u'OFLOX REDIUSE', u'strength_3': u'', u'company': u'Protec', u'unit': u'mg/5ML'}

-- line #24204
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50', u'strength_2': u'', u'substance': u'Ofloxacin', u'always_empty': u'', u'form': u'', u'brand': u'OFLOX REDIUSE', u'strength_3': u'', u'company': u'Protec', u'unit': u'mg/5ML'}

-- line #24205
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOX 100 (Protec)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOX 100 (Protec)'
);

-- line #24206
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOX 200 (Protec)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOX 200 (Protec)'
);

-- line #24207
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOX 400 (Protec)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOX 400 (Protec)'
);

-- line #24208
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLOX 200 (ZOREX REM.)',
	'Ofloxacin',
	'ZR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLOX 200 (ZOREX REM.)'
);

-- line #24209
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFL 200 (Osho Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFL 200 (Osho Ph.)'
);

-- line #24210
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLXCIN 50 (Bombay T.)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLXCIN 50 (Bombay T.)'
);

-- line #24211
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLXCIN 100 (Bombay T.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLXCIN 100 (Bombay T.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLXCIN 200 (Bombay T.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLXCIN 200 (Bombay T.)'
);

-- line #24212
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFLXCIN 400 (Bombay T.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFLXCIN 400 (Bombay T.)'
);

-- line #24213
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Ofloxacin', u'always_empty': u'', u'form': u'DROP', u'brand': u'OFMAX', u'strength_3': u'', u'company': u'NIVCA', u'unit': u''}

-- line #24214
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFMIC 400 (Cosmic Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFMIC 400 (Cosmic Ph.)'
);

-- line #24215
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFMOS 50 (Charmos Bio.)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFMOS 50 (Charmos Bio.)'
);

-- line #24216
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFMOS 200 (Charmos Bio.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFMOS 200 (Charmos Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFMOS 400 (Charmos Bio.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFMOS 400 (Charmos Bio.)'
);

-- line #24217
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFNIJ 200 (Sunij)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFNIJ 200 (Sunij)'
);

-- line #24218
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFNIS 200 (NEISS)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFNIS 200 (NEISS)'
);

-- line #24219
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OF 400 (Unique)',
	'Ofloxacin',
	'OD TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OF 400 (Unique)'
);

-- line #24220
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OF 800 (Unique)',
	'Ofloxacin',
	'OD TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OF 800 (Unique)'
);

-- line #24221
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFO 50 (Nac Int.)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFO 50 (Nac Int.)'
);

-- line #24222
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFO 200 (Nac Int.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFO 200 (Nac Int.)'
);

-- line #24223
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFO 100 (Perk Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFO 100 (Perk Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFO 200 (Perk Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFO 200 (Perk Ph.)'
);

-- line #24224
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFOXIN 50 (Medley)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFOXIN 50 (Medley)'
);

-- line #24225
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFOXIN 200 (Medley)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFOXIN 200 (Medley)'
);

-- line #24226
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFOXIN 400 (Medley)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFOXIN 400 (Medley)'
);

-- line #24227
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFPAR 200 (PARAMOUNT HC.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFPAR 200 (PARAMOUNT HC.)'
);

-- line #24228
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFPIL 200 (Pil)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFPIL 200 (Pil)'
);

-- line #24229
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFRAN 200 (Siesta)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFRAN 200 (Siesta)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFRAN 400 (Siesta)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFRAN 400 (Siesta)'
);

-- line #24230
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFRAS 0.3 (RASS HC.)',
	'Ofloxacin',
	'E/E DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFRAS 0.3 (RASS HC.)'
);

-- line #24231
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFREE 200 (Green Cross)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFREE 200 (Green Cross)'
);

-- line #24232
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFREL 50 (Relax Ph.)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFREL 50 (Relax Ph.)'
);

-- line #24233
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFREL 100 (Relax Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFREL 100 (Relax Ph.)'
);

-- line #24234
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFREL 200 (Relax Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFREL 200 (Relax Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFREL 400 (Relax Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFREL 400 (Relax Ph.)'
);

-- line #24235
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Ofloxacin', u'always_empty': u'', u'form': u'DROP', u'brand': u'O-FRESH', u'strength_3': u'', u'company': u'SMART LAB.', u'unit': u''}

-- line #24236
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFRUN 50 (JARUN PH.)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFRUN 50 (JARUN PH.)'
);

-- line #24237
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFRUN 200 (JARUN PH.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFRUN 200 (JARUN PH.)'
);

-- line #24238
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFRUT 200 (Rut Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFRUT 200 (Rut Ph.)'
);

-- line #24239
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFSET 200 (Lancer)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFSET 200 (Lancer)'
);

-- line #24240
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFSI 50 (Carol Rem.)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFSI 50 (Carol Rem.)'
);

-- line #24241
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFSI 200 (Carol Rem.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFSI 200 (Carol Rem.)'
);

-- line #24242
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFSON 200 (Patson)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFSON 200 (Patson)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFSON 400 (Patson)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFSON 400 (Patson)'
);

-- line #24243
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFSPAN 100 (PHARMATECH)',
	'Ofloxacin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFSPAN 100 (PHARMATECH)'
);

-- line #24244
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFSPAN IV 200 (PHARMATECH)',
	'Ofloxacin',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg/100ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFSPAN IV 200 (PHARMATECH)'
);

-- line #24245
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFSPAN 50 (PHARMATECH)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFSPAN 50 (PHARMATECH)'
);

-- line #24246
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFSPAN 200 (PHARMATECH)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFSPAN 200 (PHARMATECH)'
);

-- line #24247
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFSPAN 400 (PHARMATECH)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFSPAN 400 (PHARMATECH)'
);

-- line #24248
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFSUN 400 (Sun Rise)',
	'Ofloxacin',
	'OD TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFSUN 400 (Sun Rise)'
);

-- line #24249
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFSUN 200 (Sun Rise)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFSUN 200 (Sun Rise)'
);

-- line #24250
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OF 50 (J.B. CHEM)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OF 50 (J.B. CHEM)'
);

-- line #24251
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OF 200 (J.B. CHEM)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OF 200 (J.B. CHEM)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OF 400 (J.B. CHEM)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OF 400 (J.B. CHEM)'
);

-- line #24252
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFTAR 200 (Varun Life)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFTAR 200 (Varun Life)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFTAR 400 (Varun Life)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFTAR 400 (Varun Life)'
);

-- line #24253
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFTEK 50 (Wanbury)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFTEK 50 (Wanbury)'
);

-- line #24254
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFTEK 100 (Wanbury)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFTEK 100 (Wanbury)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFTEK 200 (Wanbury)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFTEK 200 (Wanbury)'
);

-- line #24255
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFTEK 400 (Wanbury)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFTEK 400 (Wanbury)'
);

-- line #24256
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFTIC 200 (Merril Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFTIC 200 (Merril Ph.)'
);

-- line #24257
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFTUM 100 (Profic)',
	'OFLOXACIN',
	'DS SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFTUM 100 (Profic)'
);

-- line #24258
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFTUM 50 (Profic)',
	'OFLOXACIN',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFTUM 50 (Profic)'
);

-- line #24259
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFTUM 200 (Profic)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFTUM 200 (Profic)'
);

-- line #24260
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFTUM 400 (Profic)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFTUM 400 (Profic)'
);

-- line #24261
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFVEN 0.3 (VENSAT)',
	'Ofloxacin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFVEN 0.3 (VENSAT)'
);

-- line #24262
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFVEN 100 (VENSAT)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFVEN 100 (VENSAT)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFVEN 200 (VENSAT)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFVEN 200 (VENSAT)'
);

-- line #24263
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFVEN 400 (VENSAT)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFVEN 400 (VENSAT)'
);

-- line #24264
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFVISTA 100 (Elder)',
	'Ofloxacin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFVISTA 100 (Elder)'
);

-- line #24265
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFVISTA 200 (Elder)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFVISTA 200 (Elder)'
);

-- line #24266
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OFZAC 200 (TRUMAC)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OFZAC 200 (TRUMAC)'
);

-- line #24267
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OGIT 200 (COXSWAIN HC.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OGIT 200 (COXSWAIN HC.)'
);

-- line #24268
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OJEN 0.3 (Jenburkt)',
	'Ofloxacin',
	'EYE/EAR DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OJEN 0.3 (Jenburkt)'
);

-- line #24269
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OJEN 50 (Jenburkt)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OJEN 50 (Jenburkt)'
);

-- line #24270
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OJEN 200 (Jenburkt)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OJEN 200 (Jenburkt)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OJEN 400 (Jenburkt)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OJEN 400 (Jenburkt)'
);

-- line #24271
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OKAFLOX 200 (Cipla)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OKAFLOX 200 (Cipla)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OKAFLOX 400 (Cipla)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OKAFLOX 400 (Cipla)'
);

-- line #24272
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OKS 50 (Unimarck)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OKS 50 (Unimarck)'
);

-- line #24273
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OKS 200 (Unimarck)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OKS 200 (Unimarck)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OKS 400 (Unimarck)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OKS 400 (Unimarck)'
);

-- line #24274
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLE 200 (Stallion)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLE 200 (Stallion)'
);

-- line #24275
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLFI 200 (Ipca)',
	'Ofloxacin',
	'INF',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLFI 200 (Ipca)'
);

-- line #24276
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLFI 100 (Ipca)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLFI 100 (Ipca)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLFI 200 (Ipca)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLFI 200 (Ipca)'
);

-- line #24277
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLFI 400 (Ipca)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLFI 400 (Ipca)'
);

-- line #24278
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLFO 50 (Alpic Bio.)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLFO 50 (Alpic Bio.)'
);

-- line #24279
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLFO 200 (Alpic Bio.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLFO 200 (Alpic Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLFO 400 (Alpic Bio.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLFO 400 (Alpic Bio.)'
);

-- line #24280
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLIFE 100 (Life Line)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLIFE 100 (Life Line)'
);

-- line #24281
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLLY 200 (Apex Form.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLLY 200 (Apex Form.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLLY 400 (Apex Form.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLLY 400 (Apex Form.)'
);

-- line #24282
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLONE 200 (GLOBELA INC.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLONE 200 (GLOBELA INC.)'
);

-- line #24283
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLOX 0.3 (Cipla)',
	'Ofloxacin',
	'E/E DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLOX 0.3 (Cipla)'
);

-- line #24284
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLOXIN 200 (Fairdeal Res.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLOXIN 200 (Fairdeal Res.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLOXIN 400 (Fairdeal Res.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLOXIN 400 (Fairdeal Res.)'
);

-- line #24285
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100', u'strength_2': u'', u'substance': u'Ofloxacin', u'always_empty': u'', u'form': u'', u'brand': u'OLOX REDIUSE', u'strength_3': u'', u'company': u'Cipla', u'unit': u'mg'}

-- line #24286
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLOX 200 (Cipla)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLOX 200 (Cipla)'
);

-- line #24287
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLOX 400 (Cipla)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLOX 400 (Cipla)'
);

-- line #24288
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLPIT 100 (EPITOME)',
	'Ofloxacin',
	'DT TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLPIT 100 (EPITOME)'
);

-- line #24289
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLPIT 50 (EPITOME)',
	'Ofloxacin',
	'SUSP',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLPIT 50 (EPITOME)'
);

-- line #24290
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLPIT 200 (EPITOME)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLPIT 200 (EPITOME)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLPIT 400 (EPITOME)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLPIT 400 (EPITOME)'
);

-- line #24291
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OL 50 (Leben)',
	'Ofloxacin',
	'SUSS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OL 50 (Leben)'
);

-- line #24292
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OL 200 (Leben)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OL 200 (Leben)'
);

-- line #24293
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLTAUR 0.3 (Taurus Lab)',
	'Ofloxacin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLTAUR 0.3 (Taurus Lab)'
);

-- line #24294
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLTAUR 50 (Taurus Lab)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLTAUR 50 (Taurus Lab)'
);

-- line #24295
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLTAUR 200 (Taurus Lab)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLTAUR 200 (Taurus Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLTAUR 400 (Taurus Lab)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLTAUR 400 (Taurus Lab)'
);

-- line #24296
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMARK 200 (MEDIMARK)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMARK 200 (MEDIMARK)'
);

-- line #24297
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMEFLOX 0.3 (Entod Ph.)',
	'Ofloxacin',
	'EYE DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMEFLOX 0.3 (Entod Ph.)'
);

-- line #24298
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMET 200 (Mount M.)',
	'Ofloxacin',
	'INF',
	gm.nullify_empty_string('200')::numeric,
	'mg/100ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMET 200 (Mount M.)'
);

-- line #24299
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMET 200 (Mount M.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMET 200 (Mount M.)'
);

-- line #24300
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONET-400 400 (ORNATE PH.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONET-400 400 (ORNATE PH.)'
);

-- line #24301
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONFLOX 200 (Logos)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONFLOX 200 (Logos)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONFLOX 400 (Logos)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONFLOX 400 (Logos)'
);

-- line #24302
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ON 400 (Pharma Drugs)',
	'Ofloxacin',
	'OD TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ON 400 (Pharma Drugs)'
);

-- line #24303
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Ofloxacin', u'always_empty': u'', u'form': u'TAB', u'brand': u'ONYX-200', u'strength_3': u'', u'company': u'FLOURISH', u'unit': u''}

-- line #24304
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPAX 100 (Bipl(Radico Lab))',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPAX 100 (Bipl(Radico Lab))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPAX 200 (Bipl(Radico Lab))',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPAX 200 (Bipl(Radico Lab))'
);

-- line #24305
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPEQ 0.3 (HANBURYS)',
	'Ofloxacin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPEQ 0.3 (HANBURYS)'
);

-- line #24306
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPEQ 200 (HANBURYS)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPEQ 200 (HANBURYS)'
);

-- line #24307
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPLUS 200 (LEOLIFE)',
	'Ofloxacin',
	'INF',
	gm.nullify_empty_string('200')::numeric,
	'mg (SOD. CHL.900'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPLUS 200 (LEOLIFE)'
);

-- line #24308
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPTRA 200 (Reliance)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPTRA 200 (Reliance)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPTRA 400 (Reliance)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPTRA 400 (Reliance)'
);

-- line #24309
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'O-QUIN 200 (Burgeon Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'O-QUIN 200 (Burgeon Ph.)'
);

-- line #24310
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORAFLOX 200 (Jackson)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORAFLOX 200 (Jackson)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORAFLOX 400 (Jackson)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORAFLOX 400 (Jackson)'
);

-- line #24311
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORFLOX 200 (Soft Health)',
	'Ofloxacin',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORFLOX 200 (Soft Health)'
);

-- line #24312
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORFLOX 400 (SOFT HEALTH)',
	'Ofloxacin',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORFLOX 400 (SOFT HEALTH)'
);

-- line #24313
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORIBACT 0.3 (Ophthal R.)',
	'Ofloxacin',
	'EYE DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORIBACT 0.3 (Ophthal R.)'
);

-- line #24314
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORIBACT 200 (Ophthal R.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORIBACT 200 (Ophthal R.)'
);

-- line #24315
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORIFLOX 200 (Orison Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORIFLOX 200 (Orison Ph.)'
);

-- line #24316
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORIVID 0.3 (Biocin Hc.)',
	'Ofloxacin',
	'EYE DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORIVID 0.3 (Biocin Hc.)'
);

-- line #24317
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORIVID 50 (Biocin Hc.)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORIVID 50 (Biocin Hc.)'
);

-- line #24318
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORIVID 100 (Biocin Hc.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORIVID 100 (Biocin Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORIVID 200 (Biocin Hc.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORIVID 200 (Biocin Hc.)'
);

-- line #24319
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORIVID 400 (Biocin Hc.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORIVID 400 (Biocin Hc.)'
);

-- line #24320
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORIXA 50 (ORION BIOTECH.)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORIXA 50 (ORION BIOTECH.)'
);

-- line #24321
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORIXA 200 (ORION BIOTECH.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORIXA 200 (ORION BIOTECH.)'
);

-- line #24322
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORON 50 (Neuron Ph.)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORON 50 (Neuron Ph.)'
);

-- line #24323
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORON 200 (Neuron Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORON 200 (Neuron Ph.)'
);

-- line #24324
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'O''RON 200 (Neuron Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'O''RON 200 (Neuron Ph.)'
);

-- line #24325
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSANI 0.3 (Sanify)',
	'Ofloxacin',
	'EYE DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSANI 0.3 (Sanify)'
);

-- line #24326
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSANI 50 (Sanify)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSANI 50 (Sanify)'
);

-- line #24327
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSANI 400 (Sanify)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSANI 400 (Sanify)'
);

-- line #24328
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSHFLOX 200 (Oshin Lab)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSHFLOX 200 (Oshin Lab)'
);

-- line #24329
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Ofloxacin', u'always_empty': u'', u'form': u'EAR DPS', u'brand': u'OSIFLOX', u'strength_3': u'', u'company': u'Osper', u'unit': u''}

-- line #24330
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSIFLOX 200 (Osper)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSIFLOX 200 (Osper)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSIFLOX 400 (Osper)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSIFLOX 400 (Osper)'
);

-- line #24331
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSON-200/400 200 (Unison)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSON-200/400 200 (Unison)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSON-200/400 400 (Unison)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSON-200/400 400 (Unison)'
);

-- line #24332
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSTREAM 200 (MEDISTREAM)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSTREAM 200 (MEDISTREAM)'
);

-- line #24333
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSTREAM 400 (MEDISTREAM)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSTREAM 400 (MEDISTREAM)'
);

-- line #24334
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSUN 200 (SUNVIEW)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSUN 200 (SUNVIEW)'
);

-- line #24335
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSWEL 200 (L & V PH.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSWEL 200 (L & V PH.)'
);

-- line #24336
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200', u'strength_2': u'', u'substance': u'Ofloxacin', u'always_empty': u'', u'form': u'', u'brand': u'O-TAB', u'strength_3': u'', u'company': u'PROCURE', u'unit': u'mg'}

-- line #24337
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OTEK-O 0.3 (F D C)',
	'Ofloxacin',
	'EAR DROPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V(LIGNOCAINE HYDROCHLORIDE 2'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OTEK-O 0.3 (F D C)'
);

-- line #24338
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OTOX 200 (Franklin)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OTOX 200 (Franklin)'
);

-- line #24339
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OTRAS 50 (Biostrass)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OTRAS 50 (Biostrass)'
);

-- line #24340
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OTRAS 200 (Biostrass)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OTRAS 200 (Biostrass)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OTRAS 400 (Biostrass)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OTRAS 400 (Biostrass)'
);

-- line #24341
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OTRUM-200 200 (SPECTRUM HC.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OTRUM-200 200 (SPECTRUM HC.)'
);

-- line #24342
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Ofloxacin', u'always_empty': u'', u'form': u'EYE/EAR DPS', u'brand': u'OVEN', u'strength_3': u'', u'company': u'AXYZEN LIFE', u'unit': u''}

-- line #24343
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OVEN 50 (AXYZEN LIFE)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OVEN 50 (AXYZEN LIFE)'
);

-- line #24344
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OVEN 200 (AXYZEN LIFE)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OVEN 200 (AXYZEN LIFE)'
);

-- line #24345
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OVIPINE 50 (Zedip Form.)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OVIPINE 50 (Zedip Form.)'
);

-- line #24346
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OVIPINE 200 (Zedip Form.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OVIPINE 200 (Zedip Form.)'
);

-- line #24347
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OX-100 100 (Protec)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OX-100 100 (Protec)'
);

-- line #24348
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXACIN 0.3 (Shinto Org.)',
	'Ofloxacin',
	'EYE DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXACIN 0.3 (Shinto Org.)'
);

-- line #24349
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXACIN 200 (Maan)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXACIN 200 (Maan)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXACIN 400 (Maan)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXACIN 400 (Maan)'
);

-- line #24350
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXAFYNE 200 (BHUVID RES.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXAFYNE 200 (BHUVID RES.)'
);

-- line #24351
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXALIC 100 (Aronex Life)',
	'Ofloxacin',
	'DT TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXALIC 100 (Aronex Life)'
);

-- line #24352
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXALIC 50 (Aronex Life)',
	'OFLOXACIN',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXALIC 50 (Aronex Life)'
);

-- line #24353
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXALIC 200 (Aronex Life)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXALIC 200 (Aronex Life)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXALIC 400 (Aronex Life)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXALIC 400 (Aronex Life)'
);

-- line #24354
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXALIC 50 (Aronex Life)',
	'OFLOXACIN',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXALIC 50 (Aronex Life)'
);

-- line #24355
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXAL 200 (ANVIK BIO.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXAL 200 (ANVIK BIO.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXAL 400 (ANVIK BIO.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXAL 400 (ANVIK BIO.)'
);

-- line #24356
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXA 50 (Ravian)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXA 50 (Ravian)'
);

-- line #24357
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXA 100 (Ravian)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXA 100 (Ravian)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXA 200 (Ravian)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXA 200 (Ravian)'
);

-- line #24358
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXA 300 (Ravian)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXA 300 (Ravian)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXA 400 (Ravian)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXA 400 (Ravian)'
);

-- line #24359
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXCIN 200 (Uniroyal)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXCIN 200 (Uniroyal)'
);

-- line #24360
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXCURE 50 (Secure)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXCURE 50 (Secure)'
);

-- line #24361
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXCURE 200 (Secure)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXCURE 200 (Secure)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXCURE 400 (Secure)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXCURE 400 (Secure)'
);

-- line #24362
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXIFLOX 200 (AKUM(WELCARE))',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXIFLOX 200 (AKUM(WELCARE))'
);

-- line #24363
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Ofloxacin', u'always_empty': u'', u'form': u'EYE DPS', u'brand': u'OXIN', u'strength_3': u'', u'company': u'IVA REM.', u'unit': u''}

-- line #24364
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXIN 200 (Alar Lab.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXIN 200 (Alar Lab.)'
);

-- line #24365
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXIN 200 (Mars Rem.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXIN 200 (Mars Rem.)'
);

-- line #24366
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXIP 200 (Shalman)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXIP 200 (Shalman)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXIP 400 (Shalman)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXIP 400 (Shalman)'
);

-- line #24367
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200', u'strength_2': u'', u'substance': u'Ofloxacin', u'always_empty': u'', u'form': u'', u'brand': u'OXIT', u'strength_3': u'', u'company': u"DR. REDDY''S", u'unit': u'mg'}

-- line #24368
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXN 100 (Parasol)',
	'Ofloxacin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXN 100 (Parasol)'
);

-- line #24369
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXN 50 (Parasol)',
	'Ofloxacin',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXN 50 (Parasol)'
);

-- line #24370
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXN 200 (Parasol)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXN 200 (Parasol)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXN 400 (Parasol)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXN 400 (Parasol)'
);

-- line #24371
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXN 200 (Parasol)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXN 200 (Parasol)'
);

-- line #24372
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXO 0.3 (Ind-Swift)',
	'Ofloxacin',
	'DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXO 0.3 (Ind-Swift)'
);

-- line #24373
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXO 0.3 (Centaur)',
	'Ofloxacin',
	'E/E DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXO 0.3 (Centaur)'
);

-- line #24374
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Ofloxacin', u'always_empty': u'', u'form': u'SYR', u'brand': u'OXOISM', u'strength_3': u'', u'company': u'ARIAK BIO.', u'unit': u''}

-- line #24375
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXOISM 200 (ARIAK BIO.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXOISM 200 (ARIAK BIO.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXOISM 400 (ARIAK BIO.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXOISM 400 (ARIAK BIO.)'
);

-- line #24376
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXOP 0.3 (CENTUAR)',
	'Ofloxacin',
	'E/E DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXOP 0.3 (CENTUAR)'
);

-- line #24377
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXO 50 (Ind-Swift)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXO 50 (Ind-Swift)'
);

-- line #24378
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXO 200 (Ind-Swift)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXO 200 (Ind-Swift)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXO 400 (Ind-Swift)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXO 400 (Ind-Swift)'
);

-- line #24379
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXWAL 200 (Wallace)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXWAL 200 (Wallace)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXWAL 400 (Wallace)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXWAL 400 (Wallace)'
);

-- line #24380
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXY 200 (Runa Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXY 200 (Runa Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXY 400 (Runa Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXY 400 (Runa Ph.)'
);

-- line #24381
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OZA 200 (Sienna Form.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OZA 200 (Sienna Form.)'
);

-- line #24382
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OZEE 50 (Zest Ph.)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OZEE 50 (Zest Ph.)'
);

-- line #24383
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OZEE 200 (Zest Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OZEE 200 (Zest Ph.)'
);

-- line #24384
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANAFLOX 50 (Cataliq)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANAFLOX 50 (Cataliq)'
);

-- line #24385
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANAFLOX 200 (Cataliq)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANAFLOX 200 (Cataliq)'
);

-- line #24386
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PDON 200 (Pharma Drugs)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PDON 200 (Pharma Drugs)'
);

-- line #24387
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PED-O 100 (Brawn Lab)',
	'Ofloxacin',
	'DS SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PED-O 100 (Brawn Lab)'
);

-- line #24388
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PED-O 50 (Brawn Lab)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PED-O 50 (Brawn Lab)'
);

-- line #24389
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENTIS 100 (Bioguard Org.)',
	'Ofloxacin',
	'DS SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENTIS 100 (Bioguard Org.)'
);

-- line #24390
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENTIS 50 (Bioguard Org.)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENTIS 50 (Bioguard Org.)'
);

-- line #24391
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENTIS 200 (Bioguard Org.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENTIS 200 (Bioguard Org.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENTIS 300 (Bioguard Org.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENTIS 300 (Bioguard Org.)'
);

-- line #24392
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENTIS 400 (Bioguard Org.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENTIS 400 (Bioguard Org.)'
);

-- line #24393
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIFOXACIN 50 (Pifer Ph.)',
	'Ofloxacin',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIFOXACIN 50 (Pifer Ph.)'
);

-- line #24394
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIFOXACIN 200 (Pifer Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIFOXACIN 200 (Pifer Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIFOXACIN 400 (Pifer Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIFOXACIN 400 (Pifer Ph.)'
);

-- line #24395
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIK 200 (Sanjeevani Bio.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIK 200 (Sanjeevani Bio.)'
);

-- line #24396
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIN 50 (Medoz Ph.)',
	'Ofloxacin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIN 50 (Medoz Ph.)'
);

-- line #24397
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIN 200 (Medoz Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIN 200 (Medoz Ph.)'
);

-- line #24398
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIN 400 (Medoz Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIN 400 (Medoz Ph.)'
);

-- line #24399
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIRAFLOX 100 (Piramal Hc.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIRAFLOX 100 (Piramal Hc.)'
);

-- line #24400
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIRAFLOX 200 (Piramal Hc.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIRAFLOX 200 (Piramal Hc.)'
);

-- line #24401
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIRAFLOX 400 (Piramal Hc.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIRAFLOX 400 (Piramal Hc.)'
);

-- line #24402
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIOF 200 (Prisma Hc.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIOF 200 (Prisma Hc.)'
);

-- line #24403
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROMIFLOX 100 (Raddison Hc.)',
	'Ofloxacin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROMIFLOX 100 (Raddison Hc.)'
);

-- line #24404
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROMIFLOX 200 (Raddison Hc.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROMIFLOX 200 (Raddison Hc.)'
);

-- line #24405
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROVO 200 (SAACHI PH.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROVO 200 (SAACHI PH.)'
);

-- line #24406
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROVO 400 (SAACHI PH.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROVO 400 (SAACHI PH.)'
);

-- line #24407
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QSL 200 (Kamron)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QSL 200 (Kamron)'
);

-- line #24408
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QST 200 (SYNTRO HC.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QST 200 (SYNTRO HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QST 400 (SYNTRO HC.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QST 400 (SYNTRO HC.)'
);

-- line #24409
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUBID 200 (FLAMINGO PH.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUBID 200 (FLAMINGO PH.)'
);

-- line #24410
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINFLOX 200 (Smiles Inc.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINFLOX 200 (Smiles Inc.)'
);

-- line #24411
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q VID 200 (Que Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q VID 200 (Que Ph.)'
);

-- line #24412
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QXL-200 200 (Kamron)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QXL-200 200 (Kamron)'
);

-- line #24413
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QXT 200 (SYNTRO HC.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QXT 200 (SYNTRO HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QXT 400 (SYNTRO HC.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QXT 400 (SYNTRO HC.)'
);

-- line #24414
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RADIFLOX 200 (RADIUS HC.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RADIFLOX 200 (RADIUS HC.)'
);

-- line #24415
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RANOCIN 100 (Regent)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RANOCIN 100 (Regent)'
);

-- line #24416
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RANOCIN 200 (Regent)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RANOCIN 200 (Regent)'
);

-- line #24417
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REFLO 200 (Brooks Ph.)',
	'Ofloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REFLO 200 (Brooks Ph.)'
);

-- line #24418
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RENOX 0.3 (RENOVA HC.)',
	'Ofloxacin',
	'EYE DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RENOX 0.3 (RENOVA HC.)'
);

-- line #24419
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANZADEX 2.5 (Cadex Lab)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANZADEX 2.5 (Cadex Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANZADEX 5 (Cadex Lab)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANZADEX 5 (Cadex Lab)'
);

-- line #24420
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANZADEX 7.5 (Cadex Lab)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANZADEX 7.5 (Cadex Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANZADEX 10 (Cadex Lab)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANZADEX 10 (Cadex Lab)'
);

-- line #24421
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOZIPINE 5 (Rhombus)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOZIPINE 5 (Rhombus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOZIPINE 10 (Rhombus)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOZIPINE 10 (Rhombus)'
);

-- line #24422
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BOLINZ 2.5 (Biocin Hc.)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BOLINZ 2.5 (Biocin Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BOLINZ 5 (Biocin Hc.)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BOLINZ 5 (Biocin Hc.)'
);

-- line #24423
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BOLINZ 7.5 (Biocin Hc.)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BOLINZ 7.5 (Biocin Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BOLINZ 10 (Biocin Hc.)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BOLINZ 10 (Biocin Hc.)'
);

-- line #24424
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOPIN 5 (DAKSH)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOPIN 5 (DAKSH)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOPIN 7.5 (DAKSH)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOPIN 7.5 (DAKSH)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOPIN 10 (DAKSH)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOPIN 10 (DAKSH)'
);

-- line #24425
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JOLYON 10 (Lupin)',
	'Olanzapine',
	'MD TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JOLYON 10 (Lupin)'
);

-- line #24426
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JOLYON 15 (Lupin)',
	'Olanzapine',
	'MD TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JOLYON 15 (Lupin)'
);

-- line #24427
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JOLYON 5 (Lupin)',
	'Olanzapine',
	'MD TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JOLYON 5 (Lupin)'
);

-- line #24428
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JOLYON 7.5 (Lupin)',
	'Olanzapine',
	'MD TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JOLYON 7.5 (Lupin)'
);

-- line #24429
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JOYZOL 10 (Merind)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JOYZOL 10 (Merind)'
);

-- line #24430
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JOYZOL 2.5 (Merind)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JOYZOL 2.5 (Merind)'
);

-- line #24431
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JOYZOL 5 (Merind)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JOYZOL 5 (Merind)'
);

-- line #24432
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JOYZOL 7.5 (Merind)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JOYZOL 7.5 (Merind)'
);

-- line #24433
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANOPIN 15 (MOLEKULE)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANOPIN 15 (MOLEKULE)'
);

-- line #24434
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANOPIN 2.5 (MOLEKULE)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANOPIN 2.5 (MOLEKULE)'
);

-- line #24435
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANOPIN 5 (MOLEKULE)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANOPIN 5 (MOLEKULE)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANOPIN 10 (MOLEKULE)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANOPIN 10 (MOLEKULE)'
);

-- line #24436
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELTNOZ 10 (KIVI HC.)',
	'Olanzapine',
	'MD',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELTNOZ 10 (KIVI HC.)'
);

-- line #24437
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELTNOZ 5 (KIVI HC.)',
	'Olanzapine',
	'MD',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELTNOZ 5 (KIVI HC.)'
);

-- line #24438
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELTOLAN 15 (Pentacare)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELTOLAN 15 (Pentacare)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELTOLAN 20 (Pentacare)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELTOLAN 20 (Pentacare)'
);

-- line #24439
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELTOLAN 2.5 (Pentacare)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELTOLAN 2.5 (Pentacare)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELTOLAN 5 (Pentacare)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELTOLAN 5 (Pentacare)'
);

-- line #24440
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELTOLAN 7.5 (Pentacare)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELTOLAN 7.5 (Pentacare)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELTOLAN 10 (Pentacare)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELTOLAN 10 (Pentacare)'
);

-- line #24441
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOLENZA 2.5 (Merit Org.)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOLENZA 2.5 (Merit Org.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOLENZA 5 (Merit Org.)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOLENZA 5 (Merit Org.)'
);

-- line #24442
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOVAPIN 10 (MOVA PH.)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOVAPIN 10 (MOVA PH.)'
);

-- line #24443
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOVAPIN 5 (MOVA PH.)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOVAPIN 5 (MOVA PH.)'
);

-- line #24444
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OJOY 5 (MAYFLOWER IND.)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OJOY 5 (MAYFLOWER IND.)'
);

-- line #24445
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLACE 15 (LA DRUG)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg (M.D.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLACE 15 (LA DRUG)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLACE 20 (LA DRUG)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg (M.D.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLACE 20 (LA DRUG)'
);

-- line #24446
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLACE 2.5 (LA DRUG)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLACE 2.5 (LA DRUG)'
);

-- line #24447
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLACE 5 (LA DRUG)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLACE 5 (LA DRUG)'
);

-- line #24448
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLACE 7.5 (LA DRUG)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLACE 7.5 (LA DRUG)'
);

-- line #24449
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10', u'strength_2': u'', u'substance': u'Olanzapine', u'always_empty': u'', u'form': u'', u'brand': u'OLANCIA RAPITAB', u'strength_3': u'', u'company': u'Chemo Bio.', u'unit': u'mg'}

-- line #24450
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLANDUS 10 (Zydus N.S.)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLANDUS 10 (Zydus N.S.)'
);

-- line #24451
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLANDUS 2.5 (Zydus N.S.)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLANDUS 2.5 (Zydus N.S.)'
);

-- line #24452
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLANDUS 5 (Zydus N.S.)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLANDUS 5 (Zydus N.S.)'
);

-- line #24453
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLANDUS 7.5 (Zydus N.S.)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLANDUS 7.5 (Zydus N.S.)'
);

-- line #24454
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5', u'strength_2': u'', u'substance': u'Olanzapine', u'always_empty': u'', u'form': u'', u'brand': u'OLANEP-5', u'strength_3': u'', u'company': u'MEDIFORECE', u'unit': u'mg'}

-- line #24455
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2,5', u'strength_2': u'', u'substance': u'Olanzapine', u'always_empty': u'', u'form': u'', u'brand': u'OLANEX INSTAB', u'strength_3': u'', u'company': u'Ranbaxy', u'unit': u'mg'}

-- line #24456
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'7,5', u'strength_2': u'', u'substance': u'Olanzapine', u'always_empty': u'', u'form': u'', u'brand': u'OLANEX INSTAB', u'strength_3': u'', u'company': u'Ranbaxy', u'unit': u'mg'}

-- line #24457
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5', u'strength_2': u'10', u'substance': u'Olanzapine', u'always_empty': u'', u'form': u'', u'brand': u'OLANEX INSTAB', u'strength_3': u'', u'company': u'Solus', u'unit': u'mg'}

-- line #24458
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLANEX 10 (Solus)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLANEX 10 (Solus)'
);

-- line #24459
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLANEX 15 (Solus)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLANEX 15 (Solus)'
);

-- line #24460
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLANEX 2.5 (Solus)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLANEX 2.5 (Solus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLANEX 5 (Solus)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLANEX 5 (Solus)'
);

-- line #24461
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLANEX 7.5 (Solus)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLANEX 7.5 (Solus)'
);

-- line #24462
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLAN 10 (Synapse)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLAN 10 (Synapse)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLAN 15 (Synapse)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLAN 15 (Synapse)'
);

-- line #24463
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLAN 2.5 (Synapse)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLAN 2.5 (Synapse)'
);

-- line #24464
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLAN 5 (Synapse)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLAN 5 (Synapse)'
);

-- line #24465
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLANZAL 2.5 (ALPHA TH.)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLANZAL 2.5 (ALPHA TH.)'
);

-- line #24466
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLANZEE 2.5 (Vega Lab)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLANZEE 2.5 (Vega Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLANZEE 5 (Vega Lab)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLANZEE 5 (Vega Lab)'
);

-- line #24467
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLANZEE 7.5 (Vega Lab)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLANZEE 7.5 (Vega Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLANZEE 10 (Vega Lab)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLANZEE 10 (Vega Lab)'
);

-- line #24468
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLANZOTIC 10 (Glenmark)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLANZOTIC 10 (Glenmark)'
);

-- line #24469
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLANZOTIC 2.5 (Glenmark)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLANZOTIC 2.5 (Glenmark)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLANZOTIC 5 (Glenmark)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLANZOTIC 5 (Glenmark)'
);

-- line #24470
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLANZ 2.5 (Riasma Life)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLANZ 2.5 (Riasma Life)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLANZ 5 (Riasma Life)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLANZ 5 (Riasma Life)'
);

-- line #24471
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLANZ 7.5 (Riasma Life)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLANZ 7.5 (Riasma Life)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLANZ 10 (Riasma Life)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLANZ 10 (Riasma Life)'
);

-- line #24472
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLAPAX 2.5 (Relience Form.)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLAPAX 2.5 (Relience Form.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLAPAX 5 (Relience Form.)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLAPAX 5 (Relience Form.)'
);

-- line #24473
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLAPAX 7.5 (Relience Form.)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLAPAX 7.5 (Relience Form.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLAPAX 10 (Relience Form.)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLAPAX 10 (Relience Form.)'
);

-- line #24474
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLAPIN 10 (PSYCOREM)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLAPIN 10 (PSYCOREM)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLAPIN 15 (PSYCOREM)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLAPIN 15 (PSYCOREM)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLAPIN 20 (PSYCOREM)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLAPIN 20 (PSYCOREM)'
);

-- line #24475
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLAPIN 2.5 (PSYCOREM)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLAPIN 2.5 (PSYCOREM)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLAPIN 5 (PSYCOREM)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLAPIN 5 (PSYCOREM)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLAPIN 7.5 (PSYCOREM)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLAPIN 7.5 (PSYCOREM)'
);

-- line #24476
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLAP 15 (Vgr Bio.)',
	'Olanzapine',
	'MD TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLAP 15 (Vgr Bio.)'
);

-- line #24477
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLAP 5 (Vgr Bio.)',
	'Olanzapine',
	'MD TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLAP 5 (Vgr Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLAP 10 (Vgr Bio.)',
	'Olanzapine',
	'MD TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLAP 10 (Vgr Bio.)'
);

-- line #24478
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLASAC 2.5 (AMEE PH.)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLASAC 2.5 (AMEE PH.)'
);

-- line #24479
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLASAC 5 (AMEE PH.)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLASAC 5 (AMEE PH.)'
);

-- line #24480
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLAWELL 10 (NAVNIDHI LIFE)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLAWELL 10 (NAVNIDHI LIFE)'
);

-- line #24481
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLAWELL 5 (NAVNIDHI LIFE)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLAWELL 5 (NAVNIDHI LIFE)'
);

-- line #24482
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLEANZ 10 (Sun)',
	'Olanzapine',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLEANZ 10 (Sun)'
);

-- line #24483
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10', u'strength_2': u'', u'substance': u'Olanzapine', u'always_empty': u'', u'form': u'', u'brand': u'OLEANZ RAPITAB', u'strength_3': u'', u'company': u'Sun', u'unit': u'mg'}

-- line #24484
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2,5', u'strength_2': u'', u'substance': u'Olanzapine', u'always_empty': u'', u'form': u'', u'brand': u'OLEANZ RAPITAB', u'strength_3': u'', u'company': u'Sun', u'unit': u'mg'}

-- line #24485
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5', u'strength_2': u'', u'substance': u'Olanzapine', u'always_empty': u'', u'form': u'', u'brand': u'OLEANZ RAPITAB', u'strength_3': u'', u'company': u'Sun', u'unit': u'mg'}

-- line #24486
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'7,5', u'strength_2': u'', u'substance': u'Olanzapine', u'always_empty': u'', u'form': u'', u'brand': u'OLEANZ RAPITAB', u'strength_3': u'', u'company': u'Sun', u'unit': u'mg'}

-- line #24487
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLEANZ RAPITAB 15 (Sun)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLEANZ RAPITAB 15 (Sun)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLEANZ RAPITAB 20 (Sun)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLEANZ RAPITAB 20 (Sun)'
);

-- line #24488
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLEANZ 10 (Sun)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLEANZ 10 (Sun)'
);

-- line #24489
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLEANZ 2.5 (Sun)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLEANZ 2.5 (Sun)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLEANZ 5 (Sun)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLEANZ 5 (Sun)'
);

-- line #24490
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLEANZ 7.5 (Sun)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLEANZ 7.5 (Sun)'
);

-- line #24491
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLE 2.5 (S P Ph.)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLE 2.5 (S P Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLE 5 (S P Ph.)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLE 5 (S P Ph.)'
);

-- line #24492
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLE 7.5 (S P Ph.)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLE 7.5 (S P Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLE 10 (S P Ph.)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLE 10 (S P Ph.)'
);

-- line #24493
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLEXAR 10 (Cipla)',
	'Olanzapine',
	'MD',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLEXAR 10 (Cipla)'
);

-- line #24494
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLEXAR 15 (Cipla)',
	'Olanzapine',
	'MD',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLEXAR 15 (Cipla)'
);

-- line #24495
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLEXAR 5 (Cipla)',
	'Olanzapine',
	'MD',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLEXAR 5 (Cipla)'
);

-- line #24496
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLEXAR 2.5 (Protec)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLEXAR 2.5 (Protec)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLEXAR 5 (Protec)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLEXAR 5 (Protec)'
);

-- line #24497
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLEXAR 7.5 (Protec)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLEXAR 7.5 (Protec)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLEXAR 10 (Protec)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLEXAR 10 (Protec)'
);

-- line #24498
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLEXA 10 (Protec)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLEXA 10 (Protec)'
);

-- line #24499
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLEXA 2.5 (Protec)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLEXA 2.5 (Protec)'
);

-- line #24500
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLEXA 5 (Protec)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLEXA 5 (Protec)'
);

-- line #24501
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLEXA 7.5 (Protec)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLEXA 7.5 (Protec)'
);

-- line #24502
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLEZ 5 (Synokem)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLEZ 5 (Synokem)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLEZ 10 (Synokem)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLEZ 10 (Synokem)'
);

-- line #24503
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLINA 15 (Biocia Hc.)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLINA 15 (Biocia Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLINA 20 (Biocia Hc.)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLINA 20 (Biocia Hc.)'
);

-- line #24504
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLINA 5 (Biocia Hc.)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLINA 5 (Biocia Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLINA 10 (Biocia Hc.)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLINA 10 (Biocia Hc.)'
);

-- line #24505
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLIRAC 10 (RECOUPE)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLIRAC 10 (RECOUPE)'
);

-- line #24506
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLIRAC 5 (RECOUPE)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLIRAC 5 (RECOUPE)'
);

-- line #24507
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLITABS 2.5 (K.C. Lab)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLITABS 2.5 (K.C. Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLITABS 5 (K.C. Lab)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLITABS 5 (K.C. Lab)'
);

-- line #24508
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLITABS 7.5 (K.C. Lab)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLITABS 7.5 (K.C. Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLITABS 10 (K.C. Lab)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLITABS 10 (K.C. Lab)'
);

-- line #24509
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLIZA PET 10 (Intas)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLIZA PET 10 (Intas)'
);

-- line #24510
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLIZA PET 5 (Intas)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLIZA PET 5 (Intas)'
);

-- line #24511
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLIZA PET 7.5 (Intas)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLIZA PET 7.5 (Intas)'
);

-- line #24512
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLIZA 15 (Intas)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLIZA 15 (Intas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLIZA 20 (Intas)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLIZA 20 (Intas)'
);

-- line #24513
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLIZA 2.5 (Intas)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLIZA 2.5 (Intas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLIZA 5 (Intas)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLIZA 5 (Intas)'
);

-- line #24514
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLIZA 7.5 (Intas)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLIZA 7.5 (Intas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLIZA 10 (Intas)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLIZA 10 (Intas)'
);

-- line #24515
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLIZOY 10 (BCC HC.)',
	'Olanzapine',
	'MD TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLIZOY 10 (BCC HC.)'
);

-- line #24516
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLIZOY 5 (BCC HC.)',
	'Olanzapine',
	'MD TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLIZOY 5 (BCC HC.)'
);

-- line #24517
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLNAPRA 10 (CENTRA(USV))',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLNAPRA 10 (CENTRA(USV))'
);

-- line #24518
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLNAPRA 2.5 (CENTRA(USV))',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLNAPRA 2.5 (CENTRA(USV))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLNAPRA 5 (CENTRA(USV))',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLNAPRA 5 (CENTRA(USV))'
);

-- line #24519
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLNAPRA 7.5 (CENTRA(USV))',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLNAPRA 7.5 (CENTRA(USV))'
);

-- line #24520
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'15', u'strength_2': u'20', u'substance': u'Olanzapine', u'always_empty': u'', u'form': u'', u'brand': u'OLNAPRA', u'strength_3': u'', u'company': u'U S V', u'unit': u'mg'}

-- line #24521
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLPINE 5 (TASMED)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLPINE 5 (TASMED)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLPINE 10 (TASMED)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLPINE 10 (TASMED)'
);

-- line #24522
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLPIN 5 (NAVNIDHI LIFE)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLPIN 5 (NAVNIDHI LIFE)'
);

-- line #24523
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OL 5 (ROSE LABS)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OL 5 (ROSE LABS)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OL 10 (ROSE LABS)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OL 10 (ROSE LABS)'
);

-- line #24524
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLTAL 5 (TALENT LAB.)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLTAL 5 (TALENT LAB.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLTAL 10 (TALENT LAB.)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLTAL 10 (TALENT LAB.)'
);

-- line #24525
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLTHA-R 2.5 (SHINE PH.)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLTHA-R 2.5 (SHINE PH.)'
);

-- line #24526
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLTHA-R 5 (SHINE PH.)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLTHA-R 5 (SHINE PH.)'
);

-- line #24527
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLTHA 2.5 (SHINE PH.)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLTHA 2.5 (SHINE PH.)'
);

-- line #24528
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLZAP 5 (BARODA)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'10'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLZAP 5 (BARODA)'
);

-- line #24529
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONEX 15 (Theo Ph.)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONEX 15 (Theo Ph.)'
);

-- line #24530
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONEX 2.5 (Theo Ph.)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONEX 2.5 (Theo Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONEX 5 (Theo Ph.)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONEX 5 (Theo Ph.)'
);

-- line #24531
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONEX 7.5 (Theo Ph.)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONEX 7.5 (Theo Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONEX 10 (Theo Ph.)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONEX 10 (Theo Ph.)'
);

-- line #24532
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONZA 10 (Nicholas)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONZA 10 (Nicholas)'
);

-- line #24533
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONZA 2.5 (Nicholas)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONZA 2.5 (Nicholas)'
);

-- line #24534
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONZA 5 (Nicholas)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONZA 5 (Nicholas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONZA 7.5 (Nicholas)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONZA 7.5 (Nicholas)'
);

-- line #24535
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OOZ 5 (OREVA DARMO.)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OOZ 5 (OREVA DARMO.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OOZ 10 (OREVA DARMO.)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OOZ 10 (OREVA DARMO.)'
);

-- line #24536
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OOZ 5 (Zee Lab)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OOZ 5 (Zee Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OOZ 10 (Zee Lab)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OOZ 10 (Zee Lab)'
);

-- line #24537
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPIN 10 (TRITON(CALYX))',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPIN 10 (TRITON(CALYX))'
);

-- line #24538
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPIN 15 (TRITON(CALYX))',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPIN 15 (TRITON(CALYX))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPIN 20 (TRITON(CALYX))',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPIN 20 (TRITON(CALYX))'
);

-- line #24539
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPIN 2.5 (TRITON(CALYX))',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPIN 2.5 (TRITON(CALYX))'
);

-- line #24540
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPIN 5 (TRITON(CALYX))',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPIN 5 (TRITON(CALYX))'
);

-- line #24541
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPTICON 10 (Emcure)',
	'Olanzapine',
	'MD TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPTICON 10 (Emcure)'
);

-- line #24542
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPTICON 2.5 (Emcure)',
	'Olanzapine',
	'MD TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPTICON 2.5 (Emcure)'
);

-- line #24543
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OTRIVE 10 (STRIVE PH.)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OTRIVE 10 (STRIVE PH.)'
);

-- line #24544
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OTRIVE 5 (STRIVE PH.)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OTRIVE 5 (STRIVE PH.)'
);

-- line #24545
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OZACE 5 (Pil)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OZACE 5 (Pil)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OZACE 10 (Pil)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OZACE 10 (Pil)'
);

-- line #24546
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OZAP 2.5 (Finecure)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OZAP 2.5 (Finecure)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OZAP 5 (Finecure)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OZAP 5 (Finecure)'
);

-- line #24547
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OZAP 7.5 (Finecure)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OZAP 7.5 (Finecure)'
);

-- line #24548
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PINSUN 5 (Sunrise Rem.)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PINSUN 5 (Sunrise Rem.)'
);

-- line #24549
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POLO 20 (Hallmark)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POLO 20 (Hallmark)'
);

-- line #24550
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POLO 2.5 (Hallmark)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POLO 2.5 (Hallmark)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POLO 5 (Hallmark)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POLO 5 (Hallmark)'
);

-- line #24551
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POLO 7.5 (Hallmark)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POLO 7.5 (Hallmark)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POLO 10 (Hallmark)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POLO 10 (Hallmark)'
);

-- line #24552
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PSYCHOLANZ 15 (Ipca)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PSYCHOLANZ 15 (Ipca)'
);

-- line #24553
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PSYCHOLANZ 2.5 (Ipca)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'5'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PSYCHOLANZ 2.5 (Ipca)'
);

-- line #24554
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PSYCHOLANZ 7.5 (Ipca)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'10'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PSYCHOLANZ 7.5 (Ipca)'
);

-- line #24555
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PSYCHOZAP 2.5 (High Q)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'5'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PSYCHOZAP 2.5 (High Q)'
);

-- line #24556
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PSYCHOZAP 7.5 (High Q)',
	'Olanzapine',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'10'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PSYCHOZAP 7.5 (High Q)'
);

-- line #24557
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENITEC 20 (Gsk)',
	'OLMESARTAN',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENITEC 20 (Gsk)'
);

-- line #24558
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENITEC 40 (Gsk)',
	'OLMESARTAN',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENITEC 40 (Gsk)'
);

-- line #24559
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLARBI 20 (Sandoz)',
	'OLMESARTAN',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLARBI 20 (Sandoz)'
);

-- line #24560
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLARBI 40 (Sandoz)',
	'OLMESARTAN',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLARBI 40 (Sandoz)'
);

-- line #24561
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLAVANCE 20 (Ranbaxy)',
	'OLMESARTAN',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLAVANCE 20 (Ranbaxy)'
);

-- line #24562
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLAVANCE 40 (Ranbaxy)',
	'OLMESARTAN',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLAVANCE 40 (Ranbaxy)'
);

-- line #24563
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLMARK 10 (Intas)',
	'OLMESARTAN',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLMARK 10 (Intas)'
);

-- line #24564
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLMARK 20 (Intas)',
	'OLMESARTAN',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLMARK 20 (Intas)'
);

-- line #24565
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLMARK 40 (Intas)',
	'OLMESARTAN',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLMARK 40 (Intas)'
);

-- line #24566
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLMAT 20 (Micro Labs)',
	'OLMESARTAN',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLMAT 20 (Micro Labs)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLMAT 40 (Micro Labs)',
	'OLMESARTAN',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLMAT 40 (Micro Labs)'
);

-- line #24567
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLMAX 20 (Glenmark)',
	'OLMESARTAN',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLMAX 20 (Glenmark)'
);

-- line #24568
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLMECIP 20 (Cipla)',
	'OLMESARTAN',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLMECIP 20 (Cipla)'
);

-- line #24569
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLMECIP 40 (Cipla)',
	'OLMESARTAN',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLMECIP 40 (Cipla)'
);

-- line #24570
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLMEFAST 20 (Intra Lab)',
	'OLMESARTAN',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLMEFAST 20 (Intra Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLMEFAST 40 (Intra Lab)',
	'OLMESARTAN',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLMEFAST 40 (Intra Lab)'
);

-- line #24571
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLMENEX 20 (Nexus)',
	'OLMESARTAN',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLMENEX 20 (Nexus)'
);

-- line #24572
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLMESAFE 10 (Otsira)',
	'OLMESARTAN',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLMESAFE 10 (Otsira)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLMESAFE 20 (Otsira)',
	'OLMESARTAN',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLMESAFE 20 (Otsira)'
);

-- line #24573
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLMESAFE 40 (Otsira)',
	'OLMESARTAN',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLMESAFE 40 (Otsira)'
);

-- line #24574
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLMESAR 20 (Macleods)',
	'OLMESARTAN',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLMESAR 20 (Macleods)'
);

-- line #24575
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLMESAR 40 (Macleods)',
	'OLMESARTAN',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLMESAR 40 (Macleods)'
);

-- line #24576
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLMETOR 20 (TORRENT)',
	'OLMESARTAN',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLMETOR 20 (TORRENT)'
);

-- line #24577
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLMETOR 40 (TORRENT)',
	'OLMESARTAN',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLMETOR 40 (TORRENT)'
);

-- line #24578
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLMETRACK 20 (U S V)',
	'OLMESARTAN',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLMETRACK 20 (U S V)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLMETRACK 40 (U S V)',
	'OLMESARTAN',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLMETRACK 40 (U S V)'
);

-- line #24579
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLMEZEST 10 (SUN)',
	'OLMESARTAN',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLMEZEST 10 (SUN)'
);

-- line #24580
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLMEZEST 20 (Sun)',
	'OLMESARTAN',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLMEZEST 20 (Sun)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLMEZEST 40 (Sun)',
	'OLMESARTAN',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLMEZEST 40 (Sun)'
);

-- line #24581
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLMEZEST 40 (SUN)',
	'OLMESARTAN',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLMEZEST 40 (SUN)'
);

-- line #24582
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLMEZEST 5 (Sun)',
	'OLMESARTAN',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLMEZEST 5 (Sun)'
);

-- line #24583
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLMIGHTY 10 (Merck)',
	'OLMESARTAN',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg(MEDOXOMIL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLMIGHTY 10 (Merck)'
);

-- line #24584
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLMIGHTY 20 (Merck)',
	'OLMESARTAN',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg(MEDOXOMIL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLMIGHTY 20 (Merck)'
);

-- line #24585
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLMIN-10 10 (ERIS THER.)',
	'OLMESARTAN',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLMIN-10 10 (ERIS THER.)'
);

-- line #24586
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLMIN-20 20 (ERIS THER.)',
	'OLMESARTAN',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLMIN-20 20 (ERIS THER.)'
);

-- line #24587
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLMIN-40 40 (ERIS THER.)',
	'OLMESARTAN',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLMIN-40 40 (ERIS THER.)'
);

-- line #24588
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLMY 10 (Zydus Cadila)',
	'OLMESARTAN',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLMY 10 (Zydus Cadila)'
);

-- line #24589
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLMY 40 (Zydus Cadila)',
	'OLMESARTAN',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLMY 40 (Zydus Cadila)'
);

-- line #24590
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLMY 5 (Zydus Cadila)',
	'OLMESARTAN',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLMY 5 (Zydus Cadila)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLMY 20 (Zydus Cadila)',
	'OLMESARTAN',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLMY 20 (Zydus Cadila)'
);

-- line #24591
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLRASS 20 (Rpg Life)',
	'OLMESARTAN',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLRASS 20 (Rpg Life)'
);

-- line #24592
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLRASS 40 (Rpg Life)',
	'OLMESARTAN',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLRASS 40 (Rpg Life)'
);

-- line #24593
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLSAR 10 (Unichem)',
	'OLMESARTAN',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg(MEDOXMIL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLSAR 10 (Unichem)'
);

-- line #24594
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLSAR 20 (Unichem)',
	'OLMESARTAN',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg(MEDOXMIL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLSAR 20 (Unichem)'
);

-- line #24595
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLSAR 40 (Unichem)',
	'OLMESARTAN',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg(MEDOXMIL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLSAR 40 (Unichem)'
);

-- line #24596
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'OLMESARTAN', u'always_empty': u'', u'form': u'', u'brand': u'OLSERATAIN', u'strength_3': u'', u'company': u"Dr.Reddy''S", u'unit': u'mg'}

-- line #24597
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40', u'strength_2': u'', u'substance': u'OLMESARTAN', u'always_empty': u'', u'form': u'', u'brand': u'OLSERATAIN', u'strength_3': u'', u'company': u"Dr.Reddy''S", u'unit': u'mg'}

-- line #24598
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLWAYS 20 (Astrazeneca)',
	'OLMESARTAN',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLWAYS 20 (Astrazeneca)'
);

-- line #24599
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLWAYS 40 (Astrazeneca)',
	'OLMESARTAN',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLWAYS 40 (Astrazeneca)'
);

-- line #24600
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMSAR-20 20 (Alembic)',
	'OLMESARTAN',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMSAR-20 20 (Alembic)'
);

-- line #24601
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMSAR-40 40 (Alembic)',
	'OLMESARTAN',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMSAR-40 40 (Alembic)'
);

-- line #24602
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORTAN 20 (Ajanta Ph.)',
	'OLMESARTAN',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORTAN 20 (Ajanta Ph.)'
);

-- line #24603
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORTAN 40 (CDC)',
	'OLMESARTAN',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORTAN 40 (CDC)'
);

-- line #24604
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PINOM 10 (Lupin)',
	'OLMESARTAN',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PINOM 10 (Lupin)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PINOM 20 (Lupin)',
	'OLMESARTAN',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PINOM 20 (Lupin)'
);

-- line #24605
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PINOM 40 (Lupin)',
	'OLMESARTAN',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PINOM 40 (Lupin)'
);

-- line #24606
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RASOTAN 40 (Emcure)',
	'OLMESARTAN',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RASOTAN 40 (Emcure)'
);

-- line #24607
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALERCHECK 0.1 (Indoco Rem.)',
	'OLOPATADINE',
	'EYE DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALERCHECK 0.1 (Indoco Rem.)'
);

-- line #24608
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALERCHEK 0.1 (INDOCO(EXCEL))',
	'OLOPATADINE',
	'EYE DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALERCHEK 0.1 (INDOCO(EXCEL))'
);

-- line #24609
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALOVENT 5 (Ranbaxy)',
	'OLOPATADINE',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALOVENT 5 (Ranbaxy)'
);

-- line #24610
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AREST 0.1 (CENTAUR PH.)',
	'OLOPATADINE',
	'EYE DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AREST 0.1 (CENTAUR PH.)'
);

-- line #24611
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVIDINE EYE 1 (DIVINE LAB.)',
	'OLOPATADINE',
	'DROPS',
	gm.nullify_empty_string('1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVIDINE EYE 1 (DIVINE LAB.)'
);

-- line #24612
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYNOLAP 5 (SUN)',
	'OLOPATADINE',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYNOLAP 5 (SUN)'
);

-- line #24613
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IF2 1 (Cipla)',
	'OLOPATADINE',
	'EYE DPS',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IF2 1 (Cipla)'
);

-- line #24614
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NASOPAT % 0.6 (Ajanta Ph.)',
	'OLOPATADINE',
	'DPS',
	gm.nullify_empty_string('0.6')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NASOPAT % 0.6 (Ajanta Ph.)'
);

-- line #24615
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'O-DIN 0.5 (GRACE)',
	'OLOPATADINE',
	'EYE DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'O-DIN 0.5 (GRACE)'
);

-- line #24616
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLOBLU % W/V 0.1 (Lupin)',
	'OLOPATADINE',
	'EYE DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLOBLU % W/V 0.1 (Lupin)'
);

-- line #24617
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLOBLU % W/V 0.2 (Lupin)',
	'OLOPATADINE',
	'EYE DPS',
	gm.nullify_empty_string('0.2')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLOBLU % W/V 0.2 (Lupin)'
);

-- line #24618
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLODIN 1 (F D C)',
	'OLOPATADINE',
	'EYE DPS',
	gm.nullify_empty_string('1')::numeric,
	'mg(+BENZALKONIUM CHLORIDE 0.01'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLODIN 1 (F D C)'
);

-- line #24619
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLO 0.1 (Ind-Swift)',
	'OLOPATADINE',
	'EYE DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLO 0.1 (Ind-Swift)'
);

-- line #24620
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'600MCG', u'strength_2': u'', u'substance': u'OLOPATADINE', u'always_empty': u'', u'form': u'PACK', u'brand': u'OLOFAST', u'strength_3': u'', u'company': u'Intas', u'unit': u''}

-- line #24621
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLOPAT 1 (AJANTA PH.)',
	'OLOPATADINE',
	'EYE DPS',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLOPAT 1 (AJANTA PH.)'
);

-- line #24622
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLOPAT 2 (Ajanta Ph.)',
	'OLOPATADINE',
	'OD EYE DPS',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLOPAT 2 (Ajanta Ph.)'
);

-- line #24623
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLOPAT 5 (Ajanta Ph.)',
	'OLOPATADINE',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLOPAT 5 (Ajanta Ph.)'
);

-- line #24624
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLOPINE 1 (INTAS)',
	'OLOPATADINE',
	'EYE DPS',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLOPINE 1 (INTAS)'
);

-- line #24625
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLOTAK 1 (Pharmtak)',
	'OLOPATADINE',
	'EYE DPS',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLOTAK 1 (Pharmtak)'
);

-- line #24626
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLOTOP 1 (Sunways)',
	'OLOPATADINE',
	'DPS',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLOTOP 1 (Sunways)'
);

-- line #24627
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPAT 0.1 (DEWCARE)',
	'OLOPATADINE',
	'EYE DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPAT 0.1 (DEWCARE)'
);

-- line #24628
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPTIHIST-PAT 0.1 (Entod Ph.)',
	'OLOPATADINE',
	'EYE DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPTIHIST-PAT 0.1 (Entod Ph.)'
);

-- line #24629
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PATADAY 0.2 (Alcon Lab)',
	'OLOPATADINE',
	'SOL',
	gm.nullify_empty_string('0.2')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PATADAY 0.2 (Alcon Lab)'
);

-- line #24630
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PATADIN 5 (Ajanta Ph.)',
	'OLOPATADINE',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PATADIN 5 (Ajanta Ph.)'
);

-- line #24631
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PATANOL OPHTH 0.1 (Alcon Lab)',
	'OLOPATADINE',
	'SOL',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PATANOL OPHTH 0.1 (Alcon Lab)'
);

-- line #24632
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POLO 1 (Yash Ph.)',
	'OLOPATADINE',
	'EYE DPS',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POLO 1 (Yash Ph.)'
);

-- line #24633
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ABCID 20 (Arbro Ph.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ABCID 20 (Arbro Ph.)'
);

-- line #24634
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACICHEK 20 (Nicholas)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACICHEK 20 (Nicholas)'
);

-- line #24635
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACIDOF 20 (Chemo D.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACIDOF 20 (Chemo D.)'
);

-- line #24636
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACIDOZOLE 20 (Regent)',
	'Omeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACIDOZOLE 20 (Regent)'
);

-- line #24637
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACIGO 20 (Runa Ph.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACIGO 20 (Runa Ph.)'
);

-- line #24638
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACITOR 20 (BHUVID RES.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACITOR 20 (BHUVID RES.)'
);

-- line #24639
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADPRAZOLE 20 (Admac Ph.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADPRAZOLE 20 (Admac Ph.)'
);

-- line #24640
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPHACID 20 (Alpha Hc.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPHACID 20 (Alpha Hc.)'
);

-- line #24641
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMBICID 20 (Ophthal R.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMBICID 20 (Ophthal R.)'
);

-- line #24642
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANZO 20 (Aust Ind.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANZO 20 (Aust Ind.)'
);

-- line #24643
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AQZOLE 20 (Aquila)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AQZOLE 20 (Aquila)'
);

-- line #24644
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AUROZOLE 20 (Auroma Life)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AUROZOLE 20 (Auroma Life)'
);

-- line #24645
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVIZOL 20 (Avalanche)',
	'OMEPRAZOLE',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVIZOL 20 (Avalanche)'
);

-- line #24646
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZEOM 20 (ABLAZE HC)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZEOM 20 (ABLAZE HC)'
);

-- line #24647
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZOL 20 (D.R.John''S)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZOL 20 (D.R.John''S)'
);

-- line #24648
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZOLE 20 (D.R.John''S)',
	'Omeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZOLE 20 (D.R.John''S)'
);

-- line #24649
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BINACID 20 (Biocin Hc.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BINACID 20 (Biocin Hc.)'
);

-- line #24650
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOCID 40 (Biochem)',
	'OMEPRAZOLE',
	'CAP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOCID 40 (Biochem)'
);

-- line #24651
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOCID 10 (Biochem)',
	'Omeprazole',
	'EC GRAN CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg/20'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOCID 10 (Biochem)'
);

-- line #24652
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOCID 40 (Biochem)',
	'Omeprazole',
	'VIAL',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOCID 40 (Biochem)'
);

-- line #24653
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BONIPRAZ 20 (TWILIGHT LIT.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BONIPRAZ 20 (TWILIGHT LIT.)'
);

-- line #24654
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'Omeprazole', u'always_empty': u'', u'form': u'', u'brand': u'BROCID CAS', u'strength_3': u'', u'company': u'Growell', u'unit': u'mg'}

-- line #24655
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAPOCID 20 (P C INDIA)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAPOCID 20 (P C INDIA)'
);

-- line #24656
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAPOMEZEN 20 (ZENEX)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAPOMEZEN 20 (ZENEX)'
);

-- line #24657
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'Omeprazole', u'always_empty': u'', u'form': u'', u'brand': u'COMP', u'strength_3': u'', u'company': u'ARCUS LABS', u'unit': u'mg'}

-- line #24658
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COOLFRESH 20 (SMART LAB.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COOLFRESH 20 (SMART LAB.)'
);

-- line #24659
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COSZOL 10 (Cfl Ph.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg/20'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COSZOL 10 (Cfl Ph.)'
);

-- line #24660
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COZ 20 (Elfin Ph.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COZ 20 (Elfin Ph.)'
);

-- line #24661
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COZEP 10 (Nicholas)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COZEP 10 (Nicholas)'
);

-- line #24662
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COZEP 20 (Nicholas)',
	'Omeprazole',
	'EC GRAN',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COZEP 20 (Nicholas)'
);

-- line #24663
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-PRAZ 20 (Corona)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-PRAZ 20 (Corona)'
);

-- line #24664
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUCID 20 (Cubit Hc.)',
	'Omeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUCID 20 (Cubit Hc.)'
);

-- line #24665
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DATZOL 20 (DATLA)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DATZOL 20 (DATLA)'
);

-- line #24666
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEMO 20 (Medoz Ph.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEMO 20 (Medoz Ph.)'
);

-- line #24667
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIOCID-20 20 (Intra Lab)',
	'OMEPRAZOLE',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIOCID-20 20 (Intra Lab)'
);

-- line #24668
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMED 20 (Dynamic)',
	'Omeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMED 20 (Dynamic)'
);

-- line #24669
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DORCAN 20 (Candor Bio.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DORCAN 20 (Candor Bio.)'
);

-- line #24670
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ECSOM 20 (Ecstacy)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ECSOM 20 (Ecstacy)'
);

-- line #24671
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMOPAZ 20 (Alde Medi.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMOPAZ 20 (Alde Medi.)'
);

-- line #24672
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMSEC 20 (Emil Ph.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMSEC 20 (Emil Ph.)'
);

-- line #24673
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EZOL 20 (Moraceae)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EZOL 20 (Moraceae)'
);

-- line #24674
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'E-ZOLE 20 (MARLINE BIO.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'E-ZOLE 20 (MARLINE BIO.)'
);

-- line #24675
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FACT 20 (HAMPS BIO)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FACT 20 (HAMPS BIO)'
);

-- line #24676
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORZOLE 20 (Forgo Ph.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORZOLE 20 (Forgo Ph.)'
);

-- line #24677
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FYZOLE 20 (Phytochem)',
	'Omeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FYZOLE 20 (Phytochem)'
);

-- line #24678
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GASTRON 20 (Lessour)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GASTRON 20 (Lessour)'
);

-- line #24679
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENOM 20 (Genova)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENOM 20 (Genova)'
);

-- line #24680
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GOAL 20 (Dr.Arvind Shah''S)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GOAL 20 (Dr.Arvind Shah''S)'
);

-- line #24681
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HARIOM 20 (Armour Rem.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HARIOM 20 (Armour Rem.)'
);

-- line #24682
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INOM 20 (Indica)',
	'Omeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INOM 20 (Indica)'
);

-- line #24683
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEXID 20 (Cadex Lab)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEXID 20 (Cadex Lab)'
);

-- line #24684
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KIMOCID 20 (Kim Lab)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KIMOCID 20 (Kim Lab)'
);

-- line #24685
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEXCID 20 (Lexus)',
	'Omeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEXCID 20 (Lexus)'
);

-- line #24686
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEXZOL-20 20 (LEXMARK PH.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEXZOL-20 20 (LEXMARK PH.)'
);

-- line #24687
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOCACID 20 (Healthgaurd)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOCACID 20 (Healthgaurd)'
);

-- line #24688
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOKCID 20 (TASMED)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOKCID 20 (TASMED)'
);

-- line #24689
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOKIT 10 (Kopran)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg/20'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOKIT 10 (Kopran)'
);

-- line #24690
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOMAC 10 (Cipla)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg/20'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOMAC 10 (Cipla)'
);

-- line #24691
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOMECID 10 (Taurus Lab)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg/20'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOMECID 10 (Taurus Lab)'
);

-- line #24692
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOMECID 40 (Taurus Lab)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOMECID 40 (Taurus Lab)'
);

-- line #24693
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORESS 10 (Biological E.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg/20'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORESS 10 (Biological E.)'
);

-- line #24694
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSEC 10 (Emcure)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg/20'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSEC 10 (Emcure)'
);

-- line #24695
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUPOME 20 (Lupin)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUPOME 20 (Lupin)'
);

-- line #24696
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYOM 40 (LYKA LABS)',
	'Omeprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYOM 40 (LYKA LABS)'
);

-- line #24697
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAGO 20 (Rapross)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAGO 20 (Rapross)'
);

-- line #24698
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALO 20 (Malody Hc.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALO 20 (Malody Hc.)'
);

-- line #24699
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGAOM 20 (Hitech Form.)',
	'Omeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGAOM 20 (Hitech Form.)'
);

-- line #24700
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEPZOL 20 (Dial Ph.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEPZOL 20 (Dial Ph.)'
);

-- line #24701
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEZCOS 20 (Cosmic Ph.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEZCOS 20 (Cosmic Ph.)'
);

-- line #24702
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MO-MEZ 20 (MODHIKE)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MO-MEZ 20 (MODHIKE)'
);

-- line #24703
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOMEZ 40 (MODHIKE)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOMEZ 40 (MODHIKE)'
);

-- line #24704
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOCID 20 (Bioguard Org.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOCID 20 (Bioguard Org.)'
);

-- line #24705
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOZAC 10 (Marc Lab)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOZAC 10 (Marc Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOZAC 20 (Marc Lab)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOZAC 20 (Marc Lab)'
);

-- line #24706
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NISZOL 20 (NEISS)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NISZOL 20 (NEISS)'
);

-- line #24707
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOACID 20 (Beckcem)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOACID 20 (Beckcem)'
);

-- line #24708
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOCID 20 (Nac Int.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOCID 20 (Nac Int.)'
);

-- line #24709
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOGACID 20 (Cadila Ph.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOGACID 20 (Cadila Ph.)'
);

-- line #24710
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUOM 20 (Nulife)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUOM 20 (Nulife)'
);

-- line #24711
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCHIO 20 (Brooks Ph.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCHIO 20 (Brooks Ph.)'
);

-- line #24712
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCID 10 (Zydus Cadila)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCID 10 (Zydus Cadila)'
);

-- line #24713
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCID 20 (Zydus Cadila)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCID 20 (Zydus Cadila)'
);

-- line #24714
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCID 10 (Zydus Cadila)',
	'Omeprazole',
	'EC GRAN CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg/20'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCID 10 (Zydus Cadila)'
);

-- line #24715
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCID 40 (Zydus Cadila)',
	'Omeprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCID 40 (Zydus Cadila)'
);

-- line #24716
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCID QRS 20 (CADILA HC.)',
	'Omeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCID QRS 20 (CADILA HC.)'
);

-- line #24717
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODIZOL 20 (Radix Bio.)',
	'Omeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODIZOL 20 (Radix Bio.)'
);

-- line #24718
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLIT 10 (Irm Ph.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg/20'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLIT 10 (Irm Ph.)'
);

-- line #24719
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLLA 20 (Sienna Form.)',
	'Omeprazole',
	'MT CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg(MAG.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLLA 20 (Sienna Form.)'
);

-- line #24720
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLLA 20 (Sienna Form.)',
	'Omeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLLA 20 (Sienna Form.)'
);

-- line #24721
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLZOLE 20 (Olcare)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLZOLE 20 (Olcare)'
);

-- line #24722
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMAC 20 (Mdc Ph.)',
	'Omeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMAC 20 (Mdc Ph.)'
);

-- line #24723
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMAG 20 (Ordain Hc.)',
	'Omeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMAG 20 (Ordain Hc.)'
);

-- line #24724
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMAG 40 (Ordain Hc.)',
	'Omeprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMAG 40 (Ordain Hc.)'
);

-- line #24725
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMALCER 20 (Wockhardt)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMALCER 20 (Wockhardt)'
);

-- line #24726
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMAPIN 20 (Brawn Lab)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMAPIN 20 (Brawn Lab)'
);

-- line #24727
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMAX-20 20 (Cure Quick)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMAX-20 20 (Cure Quick)'
);

-- line #24728
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMCID 20 (Viva Labs.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMCID 20 (Viva Labs.)'
);

-- line #24729
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMCID 20 (Indu D.)',
	'Omeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMCID 20 (Indu D.)'
);

-- line #24730
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMCURE 20 (Finecure)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMCURE 20 (Finecure)'
);

-- line #24731
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMCURE 40 (Finecure)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMCURE 40 (Finecure)'
);

-- line #24732
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMEBA 20 (Hamax Ph.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMEBA 20 (Hamax Ph.)'
);

-- line #24733
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMEBLOC 20 (Kamron)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMEBLOC 20 (Kamron)'
);

-- line #24734
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMECER 20 (EAST WEST)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMECER 20 (EAST WEST)'
);

-- line #24735
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMECER 20 (Shantam Ph.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMECER 20 (Shantam Ph.)'
);

-- line #24736
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMECHAR 20 (Charmos Bio.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMECHAR 20 (Charmos Bio.)'
);

-- line #24737
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMECID 20 (AXYZEN LIFE)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMECID 20 (AXYZEN LIFE)'
);

-- line #24738
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMECID 20 (Saga Lab)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMECID 20 (Saga Lab)'
);

-- line #24739
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMECYG-DR 20 (TALENT LAB.)',
	'Omeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg (MAG.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMECYG-DR 20 (TALENT LAB.)'
);

-- line #24740
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMEDATE 20 (Ultramark)',
	'Omeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg(MAG.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMEDATE 20 (Ultramark)'
);

-- line #24741
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMED 20 (Dynamic)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMED 20 (Dynamic)'
);

-- line #24742
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMEDY 20 (Zedip Form.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMEDY 20 (Zedip Form.)'
);

-- line #24743
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMEFAM 20 (SIFAM PH.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMEFAM 20 (SIFAM PH.)'
);

-- line #24744
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMEGORD 20 (Medispan)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMEGORD 20 (Medispan)'
);

-- line #24745
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMEGRAN 20 (Macleods)',
	'Omeprazole',
	'SAC',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMEGRAN 20 (Macleods)'
);

-- line #24746
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMEKON 20 (Alliance Rem.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMEKON 20 (Alliance Rem.)'
);

-- line #24747
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMEKURE 20 (Medicine & Kure)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMEKURE 20 (Medicine & Kure)'
);

-- line #24748
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMEL-20 20 (Jagsonpal)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMEL-20 20 (Jagsonpal)'
);

-- line #24749
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMEL 20 (Elysium)',
	'Omeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMEL 20 (Elysium)'
);

-- line #24750
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMEM-20 20 (Anikem Lab.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMEM-20 20 (Anikem Lab.)'
);

-- line #24751
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMEMAX 10 (Alembic)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMEMAX 10 (Alembic)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMEMAX 20 (Alembic)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMEMAX 20 (Alembic)'
);

-- line #24752
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMENAT 20 (Natco Ph.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMENAT 20 (Natco Ph.)'
);

-- line #24753
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMENAT 40 (Natco Ph.)',
	'Omeprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMENAT 40 (Natco Ph.)'
);

-- line #24754
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMEN 20 (Adroit Hc.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMEN 20 (Adroit Hc.)'
);

-- line #24755
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMEP 20 (Bal Ph.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMEP 20 (Bal Ph.)'
);

-- line #24756
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OME-PPI 20 (Blue Cross)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OME-PPI 20 (Blue Cross)'
);

-- line #24757
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMEPRAL 10 (F D C)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg/20'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMEPRAL 10 (F D C)'
);

-- line #24758
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMEPRAZ 10 (Alkem)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg/20'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMEPRAZ 10 (Alkem)'
);

-- line #24759
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMEPREN 10 (Blue Cross)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg/20'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMEPREN 10 (Blue Cross)'
);

-- line #24760
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMEROX 20 (Shinto Org.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMEROX 20 (Shinto Org.)'
);

-- line #24761
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMESET 20 (UNISEARCH HC.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMESET 20 (UNISEARCH HC.)'
);

-- line #24762
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMESTAN 20 (Stanford)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMESTAN 20 (Stanford)'
);

-- line #24763
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMETAB 10 (Intas)',
	'Omeprazole',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg (MAG.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMETAB 10 (Intas)'
);

-- line #24764
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMETAB 20 (Intas)',
	'Omeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg (MAG.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMETAB 20 (Intas)'
);

-- line #24765
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMETROY 20 (Troikaa)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMETROY 20 (Troikaa)'
);

-- line #24766
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMEUS 20 (Zeus Hc.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMEUS 20 (Zeus Hc.)'
);

-- line #24767
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMEVAR 20 (Atoz Ph.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMEVAR 20 (Atoz Ph.)'
);

-- line #24768
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMEVAR 20 (Zota Hc.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMEVAR 20 (Zota Hc.)'
);

-- line #24769
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMEX 20 (Apex Form.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMEX 20 (Apex Form.)'
);

-- line #24770
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'Omeprazole', u'always_empty': u'', u'form': u'', u'brand': u'OMEZA INSTA', u'strength_3': u'', u'company': u"Dr.Reddy''S", u'unit': u'mg'}

-- line #24771
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMEZ 10 (Dr.Reddy''S)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg/20'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMEZ 10 (Dr.Reddy''S)'
);

-- line #24772
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMEZ 40 (Dr.Reddy''S)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMEZ 40 (Dr.Reddy''S)'
);

-- line #24773
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMEZ-FF 20 (Dr.Reddy''S)',
	'Omeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMEZ-FF 20 (Dr.Reddy''S)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMEZ-FF 40 (Dr.Reddy''S)',
	'Omeprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMEZ-FF 40 (Dr.Reddy''S)'
);

-- line #24774
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMEZ 40 (Dr.Reddy''S)',
	'Omeprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMEZ 40 (Dr.Reddy''S)'
);

-- line #24775
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Omeprazole', u'always_empty': u'', u'form': u'TAB', u'brand': u'OMEZ MUPS', u'strength_3': u'', u'company': u"Dr.Reddy''S", u'unit': u''}

-- line #24776
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMEZOL 20 (Alembic)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMEZOL 20 (Alembic)'
);

-- line #24777
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMEZOL 20 (FIRST CHOICE)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMEZOL 20 (FIRST CHOICE)'
);

-- line #24778
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMEZOLE 20 (PSYCOREM)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMEZOLE 20 (PSYCOREM)'
);

-- line #24779
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMGENIX 20 (Genix Ph.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMGENIX 20 (Genix Ph.)'
);

-- line #24780
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMICAP 20 (Micro Labs)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMICAP 20 (Micro Labs)'
);

-- line #24781
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMICAP 10 (Micro Labs)',
	'Omeprazole',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMICAP 10 (Micro Labs)'
);

-- line #24782
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMICIN 20 (Calibar Ph.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMICIN 20 (Calibar Ph.)'
);

-- line #24783
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMICOOL 20 (Intra(INVISION))',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMICOOL 20 (Intra(INVISION))'
);

-- line #24784
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMID-20 20 (Neuron Ph.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMID-20 20 (Neuron Ph.)'
);

-- line #24785
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMIG 20 (RASS HC.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMIG 20 (RASS HC.)'
);

-- line #24786
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'Omeprazole', u'always_empty': u'', u'form': u'', u'brand': u'OMIGOLD', u'strength_3': u'', u'company': u'Theo Ph.', u'unit': u'mg'}

-- line #24787
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMIKA 20 (AMIKA PH.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMIKA 20 (AMIKA PH.)'
);

-- line #24788
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMIK 20 (Khushal Ph.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMIK 20 (Khushal Ph.)'
);

-- line #24789
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMILOK 20 (Merit Org.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMILOK 20 (Merit Org.)'
);

-- line #24790
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMIN 20 (Vega Lab)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMIN 20 (Vega Lab)'
);

-- line #24791
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMIND 20 (Indoco Rem.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMIND 20 (Indoco Rem.)'
);

-- line #24792
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMINEM-20 20 (NEMI PH.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMINEM-20 20 (NEMI PH.)'
);

-- line #24793
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMIPAK 20 (Makbro Hc.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMIPAK 20 (Makbro Hc.)'
);

-- line #24794
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMIPAN 20 (PANTHER PH.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMIPAN 20 (PANTHER PH.)'
);

-- line #24795
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMIPARS 20 (Mars Rem.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMIPARS 20 (Mars Rem.)'
);

-- line #24796
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMIPEP 20 (Ikon Rem)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMIPEP 20 (Ikon Rem)'
);

-- line #24797
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMIPREX 20 (Kentreck)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMIPREX 20 (Kentreck)'
);

-- line #24798
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMI-Q 20 (Que Ph.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMI-Q 20 (Que Ph.)'
);

-- line #24799
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMISAL 20 (Salvo Hc.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMISAL 20 (Salvo Hc.)'
);

-- line #24800
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMIUP 20 (Ups Hc.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMIUP 20 (Ups Hc.)'
);

-- line #24801
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMIX 20 (Merril Ph.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMIX 20 (Merril Ph.)'
);

-- line #24802
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMIZAC 10 (Torrent)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMIZAC 10 (Torrent)'
);

-- line #24803
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMIZAC 20 (Torrent)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMIZAC 20 (Torrent)'
);

-- line #24804
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMIZAC 10 (Torrent)',
	'Omeprazole',
	'EC GRAN CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg/20'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMIZAC 10 (Torrent)'
);

-- line #24805
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMIZ 20 (Jarson Ph.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMIZ 20 (Jarson Ph.)'
);

-- line #24806
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMLAR 20 (Arvind Lab.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMLAR 20 (Arvind Lab.)'
);

-- line #24807
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMLIN 20 (Ampus Life)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMLIN 20 (Ampus Life)'
);

-- line #24808
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMLINK 10 (Lincoln)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMLINK 10 (Lincoln)'
);

-- line #24809
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMLINK 20 (Lincoln)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMLINK 20 (Lincoln)'
);

-- line #24810
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMNILUP 20 (Lupin)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMNILUP 20 (Lupin)'
);

-- line #24811
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMNIPEP 20 (Life Line)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMNIPEP 20 (Life Line)'
);

-- line #24812
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMOPRAL 20 (ALPHA TH.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMOPRAL 20 (ALPHA TH.)'
);

-- line #24813
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMO 20 (Sierra)',
	'Omeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMO 20 (Sierra)'
);

-- line #24814
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMPAR 20 (ARLOP PH.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMPAR 20 (ARLOP PH.)'
);

-- line #24815
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMPEC 20 (Makers)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMPEC 20 (Makers)'
);

-- line #24816
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMPEP 20 (Chemo Bio.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMPEP 20 (Chemo Bio.)'
);

-- line #24817
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMPER 20 (Rhombus)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMPER 20 (Rhombus)'
);

-- line #24818
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMPRAZ 20 (LAKSUN)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMPRAZ 20 (LAKSUN)'
);

-- line #24819
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMPREX 20 (Zorex Ph.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMPREX 20 (Zorex Ph.)'
);

-- line #24820
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMPRI-20 20 (ANAND HC.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMPRI-20 20 (ANAND HC.)'
);

-- line #24821
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMPRO 20 (DAVIDSON BROCKS)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMPRO 20 (DAVIDSON BROCKS)'
);

-- line #24822
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMREL 20 (Allure Rem.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMREL 20 (Allure Rem.)'
);

-- line #24823
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMRIZ 20 (Ritz Ph.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMRIZ 20 (Ritz Ph.)'
);

-- line #24824
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMS-20 20 (Monokem)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMS-20 20 (Monokem)'
);

-- line #24825
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMSY 20 (Indu D.)',
	'Omeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMSY 20 (Indu D.)'
);

-- line #24826
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMTEC 20 (Franklin)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMTEC 20 (Franklin)'
);

-- line #24827
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMVEN 20 (LAKSUN)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMVEN 20 (LAKSUN)'
);

-- line #24828
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMVIB 20 (VIBRANT PH.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMVIB 20 (VIBRANT PH.)'
);

-- line #24829
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'O''MY 20 (OXYGEN PH.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'O''MY 20 (OXYGEN PH.)'
);

-- line #24830
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMYGEN-20 20 (BIOGEN PH.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMYGEN-20 20 (BIOGEN PH.)'
);

-- line #24831
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMYPAX 20 (Bipl(Radico Lab))',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMYPAX 20 (Bipl(Radico Lab))'
);

-- line #24832
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMZ 20 (Parasol)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMZ 20 (Parasol)'
);

-- line #24833
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMZEC-20 20 (NIVCA)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMZEC-20 20 (NIVCA)'
);

-- line #24834
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMZEE 20 (Zenon Hc.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMZEE 20 (Zenon Hc.)'
);

-- line #24835
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONAZOLE 20 (Sayona)',
	'Omeprazole',
	'F. CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONAZOLE 20 (Sayona)'
);

-- line #24836
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Omeprazole', u'always_empty': u'', u'form': u'CAP', u'brand': u'ONCE', u'strength_3': u'', u'company': u'SAFE PH.', u'unit': u''}

-- line #24837
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONOCID 20 (Lark Lab)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONOCID 20 (Lark Lab)'
);

-- line #24838
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONTO 20 (Aronex Life)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONTO 20 (Aronex Life)'
);

-- line #24839
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPAR 20 (Paras Lab)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPAR 20 (Paras Lab)'
);

-- line #24840
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPAZ 10 (Aglowmed)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPAZ 10 (Aglowmed)'
);

-- line #24841
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPAZ 10 (Aglowmed)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg/20'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPAZ 10 (Aglowmed)'
);

-- line #24842
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPAZ 20 (Aglowmed)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPAZ 20 (Aglowmed)'
);

-- line #24843
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPEL 20 (Medopharm)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPEL 20 (Medopharm)'
);

-- line #24844
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPEL 40 (Gufic Bio.)',
	'Omeprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPEL 40 (Gufic Bio.)'
);

-- line #24845
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPEP 20 (Shantha Bio.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPEP 20 (Shantha Bio.)'
);

-- line #24846
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPERA-20 20 (Ascent Lab)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPERA-20 20 (Ascent Lab)'
);

-- line #24847
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPPI 20 (Blue Cross)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPPI 20 (Blue Cross)'
);

-- line #24848
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPRAZEN-20 20 (Zenith Hc.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPRAZEN-20 20 (Zenith Hc.)'
);

-- line #24849
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OP-ZOLE 20 (UNITED LIFE)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OP-ZOLE 20 (UNITED LIFE)'
);

-- line #24850
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORAZ 20 (Osper)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORAZ 20 (Osper)'
);

-- line #24851
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORDOM 10 (Bestochem)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORDOM 10 (Bestochem)'
);

-- line #24852
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OREL-20 20 (Relish)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OREL-20 20 (Relish)'
);

-- line #24853
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORIK 20 (Lanark)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORIK 20 (Lanark)'
);

-- line #24854
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORIO 20 (Siesta)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORIO 20 (Siesta)'
);

-- line #24855
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSEC 20 (Logos)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSEC 20 (Logos)'
);

-- line #24856
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSKAR 20 (Mankind)',
	'Omeprazole',
	'AT TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg(MAG.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSKAR 20 (Mankind)'
);

-- line #24857
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSKAR 20 (LIFESTAR)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSKAR 20 (LIFESTAR)'
);

-- line #24858
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OTAB 20 (G.Nine Form.)',
	'Omeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OTAB 20 (G.Nine Form.)'
);

-- line #24859
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OZEST 20 (ASTER PH.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OZEST 20 (ASTER PH.)'
);

-- line #24860
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OZL 20 (Medizone)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OZL 20 (Medizone)'
);

-- line #24861
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OZO 20 (Ind-Swift)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OZO 20 (Ind-Swift)'
);

-- line #24862
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'O-ZOLE 20 (Cosmas Ph.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'O-ZOLE 20 (Cosmas Ph.)'
);

-- line #24863
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OZO 20 (Ind-Swift)',
	'Omeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OZO 20 (Ind-Swift)'
);

-- line #24864
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEPZER-O 20 (HANBURYS)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEPZER-O 20 (HANBURYS)'
);

-- line #24865
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PETZOL 20 (Ethilex Hc.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PETZOL 20 (Ethilex Hc.)'
);

-- line #24866
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEZO 10 (Life Line)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEZO 10 (Life Line)'
);

-- line #24867
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEZO 20 (Life Line)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEZO 20 (Life Line)'
);

-- line #24868
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIFOMZ 20 (Pifer Ph.)',
	'Omeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIFOMZ 20 (Pifer Ph.)'
);

-- line #24869
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIRAZOLE 20 (Nicholas)',
	'Omeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIRAZOLE 20 (Nicholas)'
);

-- line #24870
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PPI-20 20 (Bio-Drug)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PPI-20 20 (Bio-Drug)'
);

-- line #24871
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRACID-20 20 (ROHVEESHPRA PH.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRACID-20 20 (ROHVEESHPRA PH.)'
);

-- line #24872
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRILOSID 10 (TAJ PH.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRILOSID 10 (TAJ PH.)'
);

-- line #24873
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRILOSID 20 (TAJ PH.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRILOSID 20 (TAJ PH.)'
);

-- line #24874
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRILOSID 40 (TAJ PH.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRILOSID 40 (TAJ PH.)'
);

-- line #24875
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRILOSID 40 (TAJ PH.)',
	'Omeprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRILOSID 40 (TAJ PH.)'
);

-- line #24876
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIOM 20 (ORION BIOTECH.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIOM 20 (ORION BIOTECH.)'
);

-- line #24877
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROBITOR 20 (STERLING)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROBITOR 20 (STERLING)'
);

-- line #24878
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROCID 20 (Pil)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROCID 20 (Pil)'
);

-- line #24879
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROCID 20 (Triton Hc.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROCID 20 (Triton Hc.)'
);

-- line #24880
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROHIBIN 20 (Leben)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROHIBIN 20 (Leben)'
);

-- line #24881
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROMISEC 10 (Aristo)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROMISEC 10 (Aristo)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROMISEC 20 (Aristo)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROMISEC 20 (Aristo)'
);

-- line #24882
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROSAP 20 (Integrated)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROSAP 20 (Integrated)'
);

-- line #24883
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROTOLOC 20 (U S V)',
	'Omeprazole',
	'EC CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg/40'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROTOLOC 20 (U S V)'
);

-- line #24884
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROTOSEC 20 (Symbiotic)',
	'Omeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROTOSEC 20 (Symbiotic)'
);

-- line #24885
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROTOZ 20 (SOFT HEALTH)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROTOZ 20 (SOFT HEALTH)'
);

-- line #24886
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROZ 20 (Lancer)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROZ 20 (Lancer)'
);

-- line #24887
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROZ 20 (Mamta Ph.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROZ 20 (Mamta Ph.)'
);

-- line #24888
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROZEX 20 (Synokem)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROZEX 20 (Synokem)'
);

-- line #24889
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROZIN 20 (Kee Ph.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROZIN 20 (Kee Ph.)'
);

-- line #24890
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROZOL 10 (Sain Med.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROZOL 10 (Sain Med.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROZOL 20 (Sain Med.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROZOL 20 (Sain Med.)'
);

-- line #24891
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RECID 20 (Remedy)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RECID 20 (Remedy)'
);

-- line #24892
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REGPERI 20 (Sanify)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REGPERI 20 (Sanify)'
);

-- line #24893
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESEC 20 (Merind)',
	'Omeprazole',
	'EC CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESEC 20 (Merind)'
);

-- line #24894
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESTOCID 20 (Indilina Ph.)',
	'Omeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESTOCID 20 (Indilina Ph.)'
);

-- line #24895
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADOM-O 2 (Admac Ph.)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADOM-O 2 (Admac Ph.)'
);

-- line #24896
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AFON 4 (GENESIS)',
	'Ondansetron',
	'MD TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AFON 4 (GENESIS)'
);

-- line #24897
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPON 2 (Alpic Rem.)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPON 2 (Alpic Rem.)'
);

-- line #24898
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPON 2 (Alpic Rem.)',
	'Ondansetron',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPON 2 (Alpic Rem.)'
);

-- line #24899
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPON 4 (Alpic Rem.)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPON 4 (Alpic Rem.)'
);

-- line #24900
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALSET 2 (Alpha Lab)',
	'Ondansetron',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALSET 2 (Alpha Lab)'
);

-- line #24901
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALSET 4 (Alpha Lab)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALSET 4 (Alpha Lab)'
);

-- line #24902
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMICARE 2 (ARMAZONE)',
	'Ondansetron',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMICARE 2 (ARMAZONE)'
);

-- line #24903
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANSET 8 (Bennet Ph.)',
	'Ondansetron',
	'F. TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANSET 8 (Bennet Ph.)'
);

-- line #24904
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANSET 2 (Bennet Ph.)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANSET 2 (Bennet Ph.)'
);

-- line #24905
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Ondansetron', u'always_empty': u'', u'form': u'MD TAB', u'brand': u'ANSET', u'strength_3': u'', u'company': u'Bennet Ph.', u'unit': u''}

-- line #24906
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANSET 2 (Bennet Ph.)',
	'Ondansetron',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANSET 2 (Bennet Ph.)'
);

-- line #24907
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANSET 4 (Bennet Ph.)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANSET 4 (Bennet Ph.)'
);

-- line #24908
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASTRON 2 (AERO LIFE)',
	'Ondansetron',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASTRON 2 (AERO LIFE)'
);

-- line #24909
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXISET 2 (AXIS LIFE)',
	'Ondansetron',
	'SUSP',
	gm.nullify_empty_string('2')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXISET 2 (AXIS LIFE)'
);

-- line #24910
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACK NORM 2 (BIOMIICRON)',
	'Ondansetron',
	'AMP',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACK NORM 2 (BIOMIICRON)'
);

-- line #24911
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-GRIN 4 (NICON)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-GRIN 4 (NICON)'
);

-- line #24912
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-GRIN 4 (NICON)',
	'Ondansetron',
	'MD TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-GRIN 4 (NICON)'
);

-- line #24913
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-GRIN 4 (NICON)',
	'Ondansetron',
	'SUS',
	gm.nullify_empty_string('4')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-GRIN 4 (NICON)'
);

-- line #24914
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DANOTRAN FLASH ORO 4 (Ranbaxy)',
	'Ondansetron',
	'DT',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DANOTRAN FLASH ORO 4 (Ranbaxy)'
);

-- line #24915
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DELTRON-2 ODT 2 (DELVIN)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DELTRON-2 ODT 2 (DELVIN)'
);

-- line #24916
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DELTRON-4 OD-T 4 (DELVIN)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DELTRON-4 OD-T 4 (DELVIN)'
);

-- line #24917
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DELTRON-8 ODT 8 (DELVIN)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DELTRON-8 ODT 8 (DELVIN)'
);

-- line #24918
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIMPY-O 2 (Group Ph.)',
	'Ondansetron',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg/5ML(BENZOCAINE 20'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIMPY-O 2 (Group Ph.)'
);

-- line #24919
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DISETRON 4 (GLOBELA PH.)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DISETRON 4 (GLOBELA PH.)'
);

-- line #24920
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMI-UP 2 (Lincoln)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMI-UP 2 (Lincoln)'
);

-- line #24921
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMI-UP 2 (Lincoln)',
	'Ondansetron',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMI-UP 2 (Lincoln)'
);

-- line #24922
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMI-UP 4 (Lincoln)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMI-UP 4 (Lincoln)'
);

-- line #24923
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'D-TRON 2 (DIVINE LAB.)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'D-TRON 2 (DIVINE LAB.)'
);

-- line #24924
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMBITRON 2 (UMBILICAL PH.)',
	'Ondansetron',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMBITRON 2 (UMBILICAL PH.)'
);

-- line #24925
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMERAN 8 (Biological E.)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMERAN 8 (Biological E.)'
);

-- line #24926
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMERAN 2 (Biological)',
	'Ondansetron',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMERAN 2 (Biological)'
);

-- line #24927
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMERAN 4 (Biological E.)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMERAN 4 (Biological E.)'
);

-- line #24928
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMERAN 8 (Biological E.)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMERAN 8 (Biological E.)'
);

-- line #24929
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMESAFE 2 (Wallace)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMESAFE 2 (Wallace)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMESAFE 4 (Wallace)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMESAFE 4 (Wallace)'
);

-- line #24930
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMESAFE 2 (Wallace)',
	'Ondansetron',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMESAFE 2 (Wallace)'
);

-- line #24931
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMESAFE 4 (Wallace)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMESAFE 4 (Wallace)'
);

-- line #24932
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMESET 2 (Cipla)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMESET 2 (Cipla)'
);

-- line #24933
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMESET 2 (Cipla)',
	'Ondansetron',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMESET 2 (Cipla)'
);

-- line #24934
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMESET 4 (Cipla)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMESET 4 (Cipla)'
);

-- line #24935
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMESET 8 (Cipla)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMESET 8 (Cipla)'
);

-- line #24936
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMESTAL-O 2 (Saga Lab)',
	'Ondansetron',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMESTAL-O 2 (Saga Lab)'
);

-- line #24937
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMESTAL-O 4 (Saga Lab)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMESTAL-O 4 (Saga Lab)'
);

-- line #24938
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMETOP 2 (Eg Ph.)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMETOP 2 (Eg Ph.)'
);

-- line #24939
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMIGO 4 (Zuventus)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMIGO 4 (Zuventus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMIGO 8 (Zuventus)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMIGO 8 (Zuventus)'
);

-- line #24940
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMIGO 2 (Zuventus)',
	'Ondansetron',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMIGO 2 (Zuventus)'
);

-- line #24941
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMIGO 4 (Zuventus)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMIGO 4 (Zuventus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMIGO 8 (Zuventus)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMIGO 8 (Zuventus)'
);

-- line #24942
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMILOK 2 (SYNOPSIS)',
	'Ondansetron',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMILOK 2 (SYNOPSIS)'
);

-- line #24943
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMILOK 4 (SYNOPSIS)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMILOK 4 (SYNOPSIS)'
);

-- line #24944
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMITINO 2 (Cachet)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMITINO 2 (Cachet)'
);

-- line #24945
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMITINO 2 (Cachet)',
	'Ondansetron',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMITINO 2 (Cachet)'
);

-- line #24946
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMITINO 4 (Cachet)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg (MD)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMITINO 4 (Cachet)'
);

-- line #24947
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMITRON 2 (Criticare)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMITRON 2 (Criticare)'
);

-- line #24948
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMITRON 4 (Criticare)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMITRON 4 (Criticare)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMITRON 8 (Criticare)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMITRON 8 (Criticare)'
);

-- line #24949
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMITUS 4 (ICARUS)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMITUS 4 (ICARUS)'
);

-- line #24950
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMITUS 4 (ICARUS)',
	'Ondansetron',
	'MD TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMITUS 4 (ICARUS)'
);

-- line #24951
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMITUS 2 (ICARUS)',
	'Ondansetron',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMITUS 2 (ICARUS)'
);

-- line #24952
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMNIL 2 (VILBERRY HC.)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMNIL 2 (VILBERRY HC.)'
);

-- line #24953
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMNIL 4 (VILBERRY HC.)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMNIL 4 (VILBERRY HC.)'
);

-- line #24954
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMNIL 8 (VILBERRY HC.)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMNIL 8 (VILBERRY HC.)'
);

-- line #24955
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMNIL 4 (VILBERRY HC.)',
	'Ondansetron',
	'MD TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMNIL 4 (VILBERRY HC.)'
);

-- line #24956
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMNIL 2 (VILBERRY HC.)',
	'Ondansetron',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMNIL 2 (VILBERRY HC.)'
);

-- line #24957
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMRIL 4 (FLOURISH)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMRIL 4 (FLOURISH)'
);

-- line #24958
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMSET 4 (Cipla)',
	'Ondansetron',
	'AMP',
	gm.nullify_empty_string('4')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMSET 4 (Cipla)'
);

-- line #24959
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMSETRON 2 (Sun)',
	'Ondansetron',
	'AMP',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMSETRON 2 (Sun)'
);

-- line #24960
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMSETRON 2 (Sun)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMSETRON 2 (Sun)'
);

-- line #24961
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMSETRON 4 (Sun)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMSETRON 4 (Sun)'
);

-- line #24962
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMSETRON 8 (Sun)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMSETRON 8 (Sun)'
);

-- line #24963
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2', u'strength_2': u'', u'substance': u'Ondansetron', u'always_empty': u'', u'form': u'', u'brand': u'EMTRON', u'strength_3': u'', u'company': u'AGIO PH.', u'unit': u'mg'}

-- line #24964
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'4', u'strength_2': u'', u'substance': u'Ondansetron', u'always_empty': u'', u'form': u'', u'brand': u'EMTRON', u'strength_3': u'', u'company': u'AGIO PH.', u'unit': u'mg'}

-- line #24965
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMTRON 4 (AGIO PH.)',
	'Ondansetron',
	'MD TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMTRON 4 (AGIO PH.)'
);

-- line #24966
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMTRON 4 (Aglo)',
	'Ondansetron',
	'MD TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMTRON 4 (Aglo)'
);

-- line #24967
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Ondansetron', u'always_empty': u'', u'form': u'SYR', u'brand': u'EMTRON', u'strength_3': u'', u'company': u'AGIO PH.', u'unit': u''}

-- line #24968
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMTRON 4 (Aglo)',
	'Ondansetron',
	'SYR',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMTRON 4 (Aglo)'
);

-- line #24969
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMYRA 2 (AUGMENT REM.)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMYRA 2 (AUGMENT REM.)'
);

-- line #24970
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMYRA 4 (AUGMENT REM.)',
	'Ondansetron',
	'MD TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMYRA 4 (AUGMENT REM.)'
);

-- line #24971
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETERNA IM/IV 2 (Blue Cross)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETERNA IM/IV 2 (Blue Cross)'
);

-- line #24972
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETERNA 2 (Blue Cross)',
	'Ondansetron',
	'MD INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETERNA 2 (Blue Cross)'
);

-- line #24973
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETERNA 4 (Blue Cross)',
	'Ondansetron',
	'MD TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETERNA 4 (Blue Cross)'
);

-- line #24974
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETERNA 2 (Blue Cross)',
	'Ondansetron',
	'SYRUP',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETERNA 2 (Blue Cross)'
);

-- line #24975
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLATRON 2 (LITTLE GREAVE)',
	'Ondansetron',
	'DPS',
	gm.nullify_empty_string('2')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLATRON 2 (LITTLE GREAVE)'
);

-- line #24976
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLATRON 2 (LITTLE GREAVE)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLATRON 2 (LITTLE GREAVE)'
);

-- line #24977
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLATRON 4 (LITTLE GREAVE)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLATRON 4 (LITTLE GREAVE)'
);

-- line #24978
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FODINO 2 (Forgo Ph.)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FODINO 2 (Forgo Ph.)'
);

-- line #24979
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLENDAN 2 (Glenmark)',
	'Ondansetron',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLENDAN 2 (Glenmark)'
);

-- line #24980
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLENDAN 4 (Glenmark)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLENDAN 4 (Glenmark)'
);

-- line #24981
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GYSET 4 (GYNOB PH.)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GYSET 4 (GYNOB PH.)'
);

-- line #24982
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALOSET 2 (HALO MEDI.)',
	'Ondansetron',
	'SUS',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALOSET 2 (HALO MEDI.)'
);

-- line #24983
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Ondansetron', u'always_empty': u'', u'form': u'INJ', u'brand': u'KAMIGO', u'strength_3': u'', u'company': u'KAMSONS PH.', u'unit': u''}

-- line #24984
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KSET 4 (KPL LIFE)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KSET 4 (KPL LIFE)'
);

-- line #24985
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KSET 2 (KPL LIFE)',
	'Ondansetron',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KSET 2 (KPL LIFE)'
);

-- line #24986
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KSET 4 (KPL LIFE)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KSET 4 (KPL LIFE)'
);

-- line #24987
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'K-TRON 2 (Kapl)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'K-TRON 2 (Kapl)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'K-TRON 4 (Kapl)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'K-TRON 4 (Kapl)'
);

-- line #24988
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'K-TRON 2 (Kapl)',
	'Ondansetron',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'K-TRON 2 (Kapl)'
);

-- line #24989
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'K-TRON 4 (Kapl)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'K-TRON 4 (Kapl)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'K-TRON 8 (Kapl)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'K-TRON 8 (Kapl)'
);

-- line #24990
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2ML', u'strength_2': u'', u'substance': u'Ondansetron', u'always_empty': u'', u'form': u'', u'brand': u'LECENTRON', u'strength_3': u'', u'company': u'LEMON PH.', u'unit': u''}

-- line #24991
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'4ML', u'strength_2': u'', u'substance': u'Ondansetron', u'always_empty': u'', u'form': u'', u'brand': u'LECENTRON', u'strength_3': u'', u'company': u'LEMON PH.', u'unit': u''}

-- line #24992
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'30ML', u'strength_2': u'', u'substance': u'Ondansetron', u'always_empty': u'', u'form': u'SYP', u'brand': u'LECENTRON', u'strength_3': u'', u'company': u'LEMON PH.', u'unit': u''}

-- line #24993
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LECENTRON 4 (LEMON PH.)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LECENTRON 4 (LEMON PH.)'
);

-- line #24994
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUPISETRON 2 (Kapl)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUPISETRON 2 (Kapl)'
);

-- line #24995
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUPISETRON 4 (Kapl)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUPISETRON 4 (Kapl)'
);

-- line #24996
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUPISETRON 4 (Kapl)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUPISETRON 4 (Kapl)'
);

-- line #24997
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONDAN 2 (MODHIKE)',
	'Ondansetron',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONDAN 2 (MODHIKE)'
);

-- line #24998
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONDAN 4 (MODHIKE)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONDAN 4 (MODHIKE)'
);

-- line #24999
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYTIC 4 (VENUS REM.)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYTIC 4 (VENUS REM.)'
);

-- line #25000
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYTIC 4 (Venus Rem.)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYTIC 4 (Venus Rem.)'
);

-- line #25001
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYTIC 4 (VENUS REM.)',
	'Ondansetron',
	'MD TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYTIC 4 (VENUS REM.)'
);

-- line #25002
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYTIC 2 (VENUS REM.)',
	'Ondansetron',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYTIC 2 (VENUS REM.)'
);

-- line #25003
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAUCID 2 (Piramal Hc.)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAUCID 2 (Piramal Hc.)'
);

-- line #25004
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAUCID 2 (Piramal Hc.)',
	'Ondansetron',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAUCID 2 (Piramal Hc.)'
);

-- line #25005
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAUCID 4 (Piramal Hc.)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAUCID 4 (Piramal Hc.)'
);

-- line #25006
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAUCID 2 (Piramal Hc.)',
	'Ondansetron',
	'VIAL',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAUCID 2 (Piramal Hc.)'
);

-- line #25007
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAUSEHEXT 2 (SANOFI AV.)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAUSEHEXT 2 (SANOFI AV.)'
);

-- line #25008
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAUSEHEXT 4 (SANOFI AV.)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAUSEHEXT 4 (SANOFI AV.)'
);

-- line #25009
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Ondansetron', u'always_empty': u'', u'form': u'INJ', u'brand': u'NAUSIDA', u'strength_3': u'', u'company': u'BIOKIND HC.', u'unit': u''}

-- line #25010
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAUSIDA 4 (BIOKIND HC.)',
	'Ondansetron',
	'MD TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAUSIDA 4 (BIOKIND HC.)'
);

-- line #25011
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAUSITROY 4 (Troikaa)',
	'Ondansetron',
	'MD TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAUSITROY 4 (Troikaa)'
);

-- line #25012
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAUSITROY 2 (Torrent)',
	'Ondansetron',
	'SYRUP',
	gm.nullify_empty_string('2')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAUSITROY 2 (Torrent)'
);

-- line #25013
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2', u'strength_2': u'', u'substance': u'Ondansetron', u'always_empty': u'', u'form': u'', u'brand': u'NAUSITROY', u'strength_3': u'', u'company': u'Troikaa', u'unit': u'mg/ML'}

-- line #25014
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAVOSET 2 (Intracin)',
	'Ondansetron',
	'AMP',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAVOSET 2 (Intracin)'
);

-- line #25015
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOMIT 2 (Neon)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOMIT 2 (Neon)'
);

-- line #25016
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOMIT 4 (Neon)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOMIT 4 (Neon)'
);

-- line #25017
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOMIT 8 (Neon)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOMIT 8 (Neon)'
);

-- line #25018
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEUSET 2 (NEEL REM.)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEUSET 2 (NEEL REM.)'
);

-- line #25019
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEUSET 4 (NEEL REM.)',
	'Ondansetron',
	'MD TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEUSET 4 (NEEL REM.)'
);

-- line #25020
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Ondansetron', u'always_empty': u'', u'form': u'SYP', u'brand': u'NEUSET', u'strength_3': u'', u'company': u'NEEL REM.', u'unit': u''}

-- line #25021
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVATRON 2 (Radicura)',
	'Ondansetron',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVATRON 2 (Radicura)'
);

-- line #25022
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVATRON 2 (Radicura)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVATRON 2 (Radicura)'
);

-- line #25023
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVON 2 (SUBHREK PH.)',
	'Ondansetron',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVON 2 (SUBHREK PH.)'
);

-- line #25024
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVON 4 (SUBHREK PH.)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVON 4 (SUBHREK PH.)'
);

-- line #25025
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUSET 2 (Sun)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUSET 2 (Sun)'
);

-- line #25026
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODANSE 2 (Indchemie)',
	'Ondansetron',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODANSE 2 (Indchemie)'
);

-- line #25027
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODANSE 4 (Indchemie)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODANSE 4 (Indchemie)'
);

-- line #25028
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODDS UP 2 (Medopharm)',
	'Ondansetron',
	'SYP',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODDS UP 2 (Medopharm)'
);

-- line #25029
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODDS UP 4 (Medopharm)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODDS UP 4 (Medopharm)'
);

-- line #25030
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OKIBAN 2 (RADHE BIO.)',
	'Ondansetron',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OKIBAN 2 (RADHE BIO.)'
);

-- line #25031
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLEX 4 (Lexus)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLEX 4 (Lexus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLEX 8 (Lexus)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLEX 8 (Lexus)'
);

-- line #25032
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMIT 4 (ALPHA TH.)',
	'Ondansetron',
	'MD TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMIT 4 (ALPHA TH.)'
);

-- line #25033
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMNISET 2 (Cipla)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMNISET 2 (Cipla)'
);

-- line #25034
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMNISET 4 (Cipla)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMNISET 4 (Cipla)'
);

-- line #25035
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONCODEN 2 (Torrent)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONCODEN 2 (Torrent)'
);

-- line #25036
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONCODEN 4 (Torrent)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONCODEN 4 (Torrent)'
);

-- line #25037
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONCODEN 8 (Torrent)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONCODEN 8 (Torrent)'
);

-- line #25038
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OND-2 2 (Bestochem)',
	'Ondansetron',
	'VIAL',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OND-2 2 (Bestochem)'
);

-- line #25039
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONDA-4 4 (SIFAM PH.)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONDA-4 4 (SIFAM PH.)'
);

-- line #25040
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Ondansetron', u'always_empty': u'', u'form': u'DROPS', u'brand': u'ONDAC', u'strength_3': u'', u'company': u'NIVCA', u'unit': u''}

-- line #25041
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONDACE 4 (CMC)',
	'Ondansetron',
	'MD TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONDACE 4 (CMC)'
);

-- line #25042
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONDACIT 2 (CITIZEN LAB.)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONDACIT 2 (CITIZEN LAB.)'
);

-- line #25043
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Ondansetron', u'always_empty': u'', u'form': u'MD TAB (ALU)', u'brand': u'ONDAC', u'strength_3': u'', u'company': u'NIVCA', u'unit': u''}

-- line #25044
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Ondansetron', u'always_empty': u'', u'form': u'TAB (BLISTER)', u'brand': u'ONDAC', u'strength_3': u'', u'company': u'NIVCA', u'unit': u''}

-- line #25045
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Ondansetron', u'always_empty': u'', u'form': u'FC TAB', u'brand': u'ONDAI', u'strength_3': u'', u'company': u'SINKHAI', u'unit': u''}

-- line #25046
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONDAMAC 2 (MACLEODS)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONDAMAC 2 (MACLEODS)'
);

-- line #25047
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONDAMAC 4 (Macleods)',
	'Ondansetron',
	'MD TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONDAMAC 4 (Macleods)'
);

-- line #25048
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONDAMAC ORAL 2 (MACLEODS)',
	'Ondansetron',
	'SOL',
	gm.nullify_empty_string('2')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONDAMAC ORAL 2 (MACLEODS)'
);

-- line #25049
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONDAMAC 4 (MACLEODS)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONDAMAC 4 (MACLEODS)'
);

-- line #25050
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONDA-MEX 4 (DR. MEXI LIFE)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONDA-MEX 4 (DR. MEXI LIFE)'
);

-- line #25051
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONDANZ 2 (Elder)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONDANZ 2 (Elder)'
);

-- line #25052
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONDANZ 4 (Elder)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg/4ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONDANZ 4 (Elder)'
);

-- line #25053
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONDANZ 2 (Elder)',
	'Ondansetron',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONDANZ 2 (Elder)'
);

-- line #25054
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONDANZ 4 (Elder)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONDANZ 4 (Elder)'
);

-- line #25055
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONDANZ 8 (Elder)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONDANZ 8 (Elder)'
);

-- line #25056
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONDA-Q 4 (Que Ph.)',
	'Ondansetron',
	'MD TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONDA-Q 4 (Que Ph.)'
);

-- line #25057
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONDARAIN 2 (RAINVIS PH.)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONDARAIN 2 (RAINVIS PH.)'
);

-- line #25058
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONDARAIN 4 (RAINVIS PH.)',
	'Ondansetron',
	'MD TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONDARAIN 4 (RAINVIS PH.)'
);

-- line #25059
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONDARAIN 2 (RAINVIS PH.)',
	'Ondansetron',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONDARAIN 2 (RAINVIS PH.)'
);

-- line #25060
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONDARAIN 2 (RAINVIS PH.)',
	'Ondansetron',
	'VIAL',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONDARAIN 2 (RAINVIS PH.)'
);

-- line #25061
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONDAR 4 (Rhombus)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONDAR 4 (Rhombus)'
);

-- line #25062
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONDAR 5 (Zota)',
	'Ondansetron',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONDAR 5 (Zota)'
);

-- line #25063
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Ondansetron', u'always_empty': u'', u'form': u'TAB/SYR', u'brand': u'ONDAR', u'strength_3': u'', u'company': u'Rhombus', u'unit': u''}

-- line #25064
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Ondansetron', u'always_empty': u'', u'form': u'TAB', u'brand': u'ONDAR', u'strength_3': u'', u'company': u'Zota', u'unit': u''}

-- line #25065
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONDART 4 (Shantha Bio.)',
	'Ondansetron',
	'DT',
	gm.nullify_empty_string('4')::numeric,
	'mg (ORO)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONDART 4 (Shantha Bio.)'
);

-- line #25066
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONDART 8 (Shantha Bio.)',
	'Ondansetron',
	'DT',
	gm.nullify_empty_string('8')::numeric,
	'mg (ORO)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONDART 8 (Shantha Bio.)'
);

-- line #25067
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONDAVOM 4 (Global Med.)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONDAVOM 4 (Global Med.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONDAVOM 8 (Global Med.)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONDAVOM 8 (Global Med.)'
);

-- line #25068
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONDAVOM 4 (Global Med.)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONDAVOM 4 (Global Med.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONDAVOM 8 (Global Med.)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONDAVOM 8 (Global Med.)'
);

-- line #25069
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONDAYZ 4 (INNOWAYZ PH.)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONDAYZ 4 (INNOWAYZ PH.)'
);

-- line #25070
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONDEM 2 (Alkem)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONDEM 2 (Alkem)'
);

-- line #25071
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Ondansetron', u'always_empty': u'', u'form': u'SYR', u'brand': u'ONDEM', u'strength_3': u'', u'company': u'Bergen', u'unit': u''}

-- line #25072
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONDEM 4 (Alkem)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONDEM 4 (Alkem)'
);

-- line #25073
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONDEM 8 (Alkem)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONDEM 8 (Alkem)'
);

-- line #25074
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONDENT 2 (HAMPS BIO)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONDENT 2 (HAMPS BIO)'
);

-- line #25075
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Ondansetron', u'always_empty': u'', u'form': u'INJ/SYR', u'brand': u'ONDET', u'strength_3': u'', u'company': u'Neuron Ph.', u'unit': u''}

-- line #25076
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONDET 4 (Neuron Ph.)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONDET 4 (Neuron Ph.)'
);

-- line #25077
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OND 4 (Bestochem)',
	'Ondansetron',
	'MD TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OND 4 (Bestochem)'
);

-- line #25078
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Ondansetron', u'always_empty': u'', u'form': u'DPS', u'brand': u'ONDO', u'strength_3': u'', u'company': u'AXYZEN LIFE', u'unit': u''}

-- line #25079
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONDON 4 (Bipl(Radico Lab))',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONDON 4 (Bipl(Radico Lab))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONDON 8 (Bipl(Radico Lab))',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONDON 8 (Bipl(Radico Lab))'
);

-- line #25080
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONDO 4 (AXYZEN LIFE)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONDO 4 (AXYZEN LIFE)'
);

-- line #25081
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONDOT 2 (Siomond)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONDOT 2 (Siomond)'
);

-- line #25082
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONDOT 4 (TALENT LAB.)',
	'Ondansetron',
	'TAB/SYR',
	gm.nullify_empty_string('4')::numeric,
	'mg/4'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONDOT 4 (TALENT LAB.)'
);

-- line #25083
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OND 2 (Bestochem)',
	'Ondansetron',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OND 2 (Bestochem)'
);

-- line #25084
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OND 4 (Bestochem)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OND 4 (Bestochem)'
);

-- line #25085
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONDY 2 (Austere)',
	'Ondansetron',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONDY 2 (Austere)'
);

-- line #25086
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONDY 4 (GLOBELA INC.)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONDY 4 (GLOBELA INC.)'
);

-- line #25087
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONEEDA 2 (Yash Ph.)',
	'Ondansetron',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONEEDA 2 (Yash Ph.)'
);

-- line #25088
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONKAM 2 (Kamron)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONKAM 2 (Kamron)'
);

-- line #25089
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONKAM 4 (Kamron)',
	'Ondansetron',
	'MD TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONKAM 4 (Kamron)'
);

-- line #25090
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONKAM 2 (Kamron)',
	'Ondansetron',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONKAM 2 (Kamron)'
);

-- line #25091
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONKAM 4 (Kamron)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONKAM 4 (Kamron)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONKAM 8 (Kamron)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONKAM 8 (Kamron)'
);

-- line #25092
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONLAND 2 (L & V PH.)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONLAND 2 (L & V PH.)'
);

-- line #25093
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONLAND 4 (L & V PH.)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONLAND 4 (L & V PH.)'
);

-- line #25094
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONMED 4 (Medoz Ph.)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONMED 4 (Medoz Ph.)'
);

-- line #25095
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Ondansetron', u'always_empty': u'', u'form': u'SUS/DPS', u'brand': u'ONMED', u'strength_3': u'', u'company': u'Medoz Ph.', u'unit': u''}

-- line #25096
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONMED 4 (Medoz Ph.)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONMED 4 (Medoz Ph.)'
);

-- line #25097
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONO 2 (Samarth)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONO 2 (Samarth)'
);

-- line #25098
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONO 4 (Samarth)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONO 4 (Samarth)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONO 8 (Samarth)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONO 8 (Samarth)'
);

-- line #25099
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONSETT 2 (Cadila Ph.)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONSETT 2 (Cadila Ph.)'
);

-- line #25100
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONSETT 4 (Cadila Ph.)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONSETT 4 (Cadila Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONSETT 8 (Cadila Ph.)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONSETT 8 (Cadila Ph.)'
);

-- line #25101
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONSITE 4 (BIOSEARCH PH.)',
	'Ondansetron',
	'MD TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONSITE 4 (BIOSEARCH PH.)'
);

-- line #25102
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONSTAL 8 (Stallion)',
	'Ondansetron',
	'F. TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONSTAL 8 (Stallion)'
);

-- line #25103
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Ondansetron', u'always_empty': u'', u'form': u'INJ', u'brand': u'ONSTAL', u'strength_3': u'', u'company': u'Stallion', u'unit': u''}

-- line #25104
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Ondansetron', u'always_empty': u'', u'form': u'SUS', u'brand': u'ONSTAL', u'strength_3': u'', u'company': u'Stallion', u'unit': u''}

-- line #25105
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONSTAL 4 (Stallion)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONSTAL 4 (Stallion)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONSTAL 8 (Stallion)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONSTAL 8 (Stallion)'
);

-- line #25106
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONSTAL 4 (Stallion)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONSTAL 4 (Stallion)'
);

-- line #25107
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONSTAR 4 (CELON(REVILON))',
	'Ondansetron',
	'AMP',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONSTAR 4 (CELON(REVILON))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONSTAR 8 (CELON(REVILON))',
	'Ondansetron',
	'AMP',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONSTAR 8 (CELON(REVILON))'
);

-- line #25108
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONSTAR 4 (CELON(REVILON))',
	'Ondansetron',
	'MD TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONSTAR 4 (CELON(REVILON))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONSTAR 8 (CELON(REVILON))',
	'Ondansetron',
	'MD TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONSTAR 8 (CELON(REVILON))'
);

-- line #25109
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONSTOP 2 (AUGMENT REM.)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONSTOP 2 (AUGMENT REM.)'
);

-- line #25110
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONSTOP 2 (AUGMENT REM.)',
	'Ondansetron',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONSTOP 2 (AUGMENT REM.)'
);

-- line #25111
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'4', u'strength_2': u'', u'substance': u'Ondansetron', u'always_empty': u'', u'form': u'', u'brand': u'ONTEX', u'strength_3': u'', u'company': u'TEXUS PH.', u'unit': u'mg'}

-- line #25112
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONTIC 2 (Corona)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONTIC 2 (Corona)'
);

-- line #25113
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONTRON 4 (ORION BIOTECH.)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONTRON 4 (ORION BIOTECH.)'
);

-- line #25114
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORIO 4 (Sienna Form.)',
	'Ondansetron',
	'MD TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORIO 4 (Sienna Form.)'
);

-- line #25115
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OROTON 2 (MEDHEAL PH.)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OROTON 2 (MEDHEAL PH.)'
);

-- line #25116
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSENT 4 (Calibar Ph.)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSENT 4 (Calibar Ph.)'
);

-- line #25117
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSENT 4 (Calibar Ph.)',
	'Ondansetron',
	'SYR',
	gm.nullify_empty_string('4')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSENT 4 (Calibar Ph.)'
);

-- line #25118
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSETRON 2 (Dr.Reddy''S)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSETRON 2 (Dr.Reddy''S)'
);

-- line #25119
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSETRON 4 (Dr.Reddy''S)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSETRON 4 (Dr.Reddy''S)'
);

-- line #25120
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSETRON 8 (Dr.Reddy''S)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSETRON 8 (Dr.Reddy''S)'
);

-- line #25121
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSET 2 (MEDLEY)',
	'Ondansetron',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSET 2 (MEDLEY)'
);

-- line #25122
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSET 4 (MEDLEY)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSET 4 (MEDLEY)'
);

-- line #25123
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSETT 4 (Finecure)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSETT 4 (Finecure)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSETT 8 (Finecure)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSETT 8 (Finecure)'
);

-- line #25124
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSTRON 2 (Aabtac Life)',
	'Ondansetron',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSTRON 2 (Aabtac Life)'
);

-- line #25125
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSTRON 4 (Aabtac Life)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSTRON 4 (Aabtac Life)'
);

-- line #25126
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OZOTRON 2 (Ozone Ph.)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OZOTRON 2 (Ozone Ph.)'
);

-- line #25127
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OZOTRON 2 (Ozone Ph.)',
	'Ondansetron',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OZOTRON 2 (Ozone Ph.)'
);

-- line #25128
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OZOTRON 4 (Ozone Ph.)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OZOTRON 4 (Ozone Ph.)'
);

-- line #25129
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERISET 2 (Ipca)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERISET 2 (Ipca)'
);

-- line #25130
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERISET 2 (IPCA LAB.)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERISET 2 (IPCA LAB.)'
);

-- line #25131
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERISET 4 (Ipca)',
	'Ondansetron',
	'MD TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERISET 4 (Ipca)'
);

-- line #25132
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERISET 4 (Ipca)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERISET 4 (Ipca)'
);

-- line #25133
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERISET 8 (Ipca)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERISET 8 (Ipca)'
);

-- line #25134
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHYTIC 2 (Prohealth)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHYTIC 2 (Prohealth)'
);

-- line #25135
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PONV 2 (ALEMBIC)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PONV 2 (ALEMBIC)'
);

-- line #25136
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROSPECT 2 (Skymax)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROSPECT 2 (Skymax)'
);

-- line #25137
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROSPECT 2 (Skymax)',
	'Ondansetron',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROSPECT 2 (Skymax)'
);

-- line #25138
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROSPECT 4 (Skymax)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROSPECT 4 (Skymax)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROSPECT 8 (Skymax)',
	'Ondansetron',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROSPECT 8 (Skymax)'
);

-- line #25139
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'P-SET 2 (PHARMATECH)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'P-SET 2 (PHARMATECH)'
);

-- line #25140
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'4', u'strength_2': u'', u'substance': u'Ondansetron', u'always_empty': u'', u'form': u'', u'brand': u'QUICK SET', u'strength_3': u'', u'company': u'ECON HC.', u'unit': u'mg'}

-- line #25141
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RANIDOM-ON 2 (Mankind)',
	'Ondansetron',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RANIDOM-ON 2 (Mankind)'
);

-- line #25142
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Ondansetron', u'always_empty': u'', u'form': u'SOL', u'brand': u'RB SETRON', u'strength_3': u'', u'company': u'R.B.REM.', u'unit': u''}

-- line #25143
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'OPHTHALMIC POST OPERATIVE PAD', u'always_empty': u'', u'form': u'', u'brand': u'CATPAD', u'strength_3': u'', u'company': u'Centaur', u'unit': u''}

-- line #25144
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'ORAL REHYDRATION SALTS', u'always_empty': u'', u'form': u'PWD', u'brand': u'APILYTE', u'strength_3': u'', u'company': u'ALICON PH.', u'unit': u''}

-- line #25145
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'ORAL REHYDRATION SALTS', u'always_empty': u'', u'form': u'', u'brand': u'ELECT-ORS', u'strength_3': u'', u'company': u'Nicholas', u'unit': u''}

-- line #25146
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALUPENT 10 (German R.)',
	'Orciprenaline',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALUPENT 10 (German R.)'
);

-- line #25147
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALUPENT 0.5 (German R.)',
	'Orciprenaline Sulphate',
	'INJ',
	gm.nullify_empty_string('0.5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALUPENT 0.5 (German R.)'
);

-- line #25148
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALUPENT 10 (German R.)',
	'Orciprenaline Sulphate',
	'SYR',
	gm.nullify_empty_string('10')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALUPENT 10 (German R.)'
);

-- line #25149
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COBESE 120 (RANBAXY)',
	'ORLISTAT',
	'CAP',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COBESE 120 (RANBAXY)'
);

-- line #25150
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COBESE 60 (Ranbaxy)',
	'ORLISTAT',
	'CAP',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COBESE 60 (Ranbaxy)'
);

-- line #25151
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPOCUT 120 (Lupin)',
	'ORLISTAT',
	'CAP',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPOCUT 120 (Lupin)'
);

-- line #25152
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPOCUT 60 (Lupin)',
	'ORLISTAT',
	'CAP',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPOCUT 60 (Lupin)'
);

-- line #25153
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPOPHAGE 120 (Franco I.)',
	'ORLISTAT',
	'CAP',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPOPHAGE 120 (Franco I.)'
);

-- line #25154
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPOPHAGE 60 (Franco I.)',
	'ORLISTAT',
	'CAP',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPOPHAGE 60 (Franco I.)'
);

-- line #25155
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOFAT 120 (Dwd)',
	'ORLISTAT',
	'CAP',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOFAT 120 (Dwd)'
);

-- line #25156
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OBELIT 120 (Intas)',
	'ORLISTAT',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OBELIT 120 (Intas)'
);

-- line #25157
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'120', u'strength_2': u'', u'substance': u'ORLISTAT', u'always_empty': u'', u'form': u'', u'brand': u'OBITROL', u'strength_3': u'', u'company': u'Micro Labs', u'unit': u'mg'}

-- line #25158
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLISAT 120 (Biocon)',
	'ORLISTAT',
	'CAP',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLISAT 120 (Biocon)'
);

-- line #25159
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLISAT 60 (Biocon)',
	'ORLISTAT',
	'CAP',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLISAT 60 (Biocon)'
);

-- line #25160
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORLE 120 (Emcure)',
	'ORLISTAT',
	'CAP',
	gm.nullify_empty_string('120')::numeric,
	'mg((AS PALLETS 50'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORLE 120 (Emcure)'
);

-- line #25161
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORLE 60 (Emcure)',
	'ORLISTAT',
	'CAP',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORLE 60 (Emcure)'
);

-- line #25162
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORLICA 120 (TORRENT)',
	'ORLISTAT',
	'CAP',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORLICA 120 (TORRENT)'
);

-- line #25163
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORLICA 60 (Torrent)',
	'ORLISTAT',
	'CAP',
	gm.nullify_empty_string('60')::numeric,
	'mg(AS PELLETS 50'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORLICA 60 (Torrent)'
);

-- line #25164
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORLIMAC 120 (Macleods)',
	'ORLISTAT',
	'CAP',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORLIMAC 120 (Macleods)'
);

-- line #25165
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORLISAVE 120 (ERIS LIFE)',
	'ORLISTAT',
	'CAP',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORLISAVE 120 (ERIS LIFE)'
);

-- line #25166
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORLISAVE 60 (ERIS LIFE)',
	'ORLISTAT',
	'CAP',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORLISAVE 60 (ERIS LIFE)'
);

-- line #25167
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORLITROY 60 (Troikaa)',
	'ORLISTAT',
	'CAP',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORLITROY 60 (Troikaa)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORLITROY 120 (Troikaa)',
	'ORLISTAT',
	'CAP',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORLITROY 120 (Troikaa)'
);

-- line #25168
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'O STAT 120 (Aristo)',
	'ORLISTAT',
	'CAP',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'O STAT 120 (Aristo)'
);

-- line #25169
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'O STAT 60 (Aristo)',
	'ORLISTAT',
	'CAP',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'O STAT 60 (Aristo)'
);

-- line #25170
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REESHAPE 60 (Meyer Org.)',
	'ORLISTAT',
	'CAP',
	gm.nullify_empty_string('60')::numeric,
	'120'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REESHAPE 60 (Meyer Org.)'
);

-- line #25171
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESHAPE 60 (Meyer Org.)',
	'ORLISTAT',
	'CAP',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESHAPE 60 (Meyer Org.)'
);

-- line #25172
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVEX 60 (HIND. LATEX)',
	'Ormeloxifene',
	'DS TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVEX 60 (HIND. LATEX)'
);

-- line #25173
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVEX 30 (HIND. LATEX)',
	'Ormeloxifene',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVEX 30 (HIND. LATEX)'
);

-- line #25174
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AGIFLO 125 (AGIO PH.)',
	'Ornidazole',
	'OZ SUSP',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AGIFLO 125 (AGIO PH.)'
);

-- line #25175
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.5G', u'strength_2': u'100ML', u'substance': u'Ornidazole', u'always_empty': u'', u'form': u'INF', u'brand': u'DAZOLIC', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #25176
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAZOLIC 500 (Sun)',
	'Ornidazole',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAZOLIC 500 (Sun)'
);

-- line #25177
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENTAMIZOLE PLUS 500 (Abbott)',
	'Ornidazole',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENTAMIZOLE PLUS 500 (Abbott)'
);

-- line #25178
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENTAMIZOLE PLUS 500 (Abbott)',
	'Ornidazole',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENTAMIZOLE PLUS 500 (Abbott)'
);

-- line #25179
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GIRO 500 (Panacea)',
	'Ornidazole',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GIRO 500 (Panacea)'
);

-- line #25180
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HORN 500 (Dey''S)',
	'Ornidazole',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HORN 500 (Dey''S)'
);

-- line #25181
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METROGYL 10 (Lekar)',
	'ORNIDAZOLE',
	'GEL',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METROGYL 10 (Lekar)'
);

-- line #25182
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIDAZOLE 500 (Sipra Rem.)',
	'Ornidazole',
	'INF',
	gm.nullify_empty_string('500')::numeric,
	'mg/100ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIDAZOLE 500 (Sipra Rem.)'
);

-- line #25183
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIDAZOLE 500 (Sipra Rem.)',
	'Ornidazole',
	'INFUSION',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIDAZOLE 500 (Sipra Rem.)'
);

-- line #25184
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIDAZOLE 500 (Sipra Rem.)',
	'Ornidazole',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIDAZOLE 500 (Sipra Rem.)'
);

-- line #25185
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONIDAZ 500 (Medley)',
	'Ornidazole',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONIDAZ 500 (Medley)'
);

-- line #25186
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONIZ 500 (Stadmed)',
	'Ornidazole',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONIZ 500 (Stadmed)'
);

-- line #25187
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORD 500 (Ind-Swift)',
	'Ornidazole',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORD 500 (Ind-Swift)'
);

-- line #25188
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORMED 500 (Zee Lab)',
	'Ornidazole',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORMED 500 (Zee Lab)'
);

-- line #25189
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORNIDA 125 (Aristo)',
	'Ornidazole',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORNIDA 125 (Aristo)'
);

-- line #25190
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORNIDA 500 (Aristo)',
	'Ornidazole',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORNIDA 500 (Aristo)'
);

-- line #25191
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORNIMAX 500 (Obsurge)',
	'Ornidazole',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORNIMAX 500 (Obsurge)'
);

-- line #25192
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORNI 500 (Zydus Cadila)',
	'Ornidazole',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORNI 500 (Zydus Cadila)'
);

-- line #25193
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Ornidazole', u'always_empty': u'', u'form': u'', u'brand': u'ORNITEC IV', u'strength_3': u'', u'company': u'BIOMAX BIO.', u'unit': u''}

-- line #25194
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORNIZEN 500 (Sun)',
	'Ornidazole',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORNIZEN 500 (Sun)'
);

-- line #25195
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORTINI 500 (MERCK SP.)',
	'Ornidazole',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORTINI 500 (MERCK SP.)'
);

-- line #25196
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORPHIPAL 50 (GSK)',
	'Orphenadrine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORPHIPAL 50 (GSK)'
);

-- line #25197
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUVIR 30 (HETERO HC.)',
	'OSALTAMAVIR',
	'CAP',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUVIR 30 (HETERO HC.)'
);

-- line #25198
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUVIR 45 (HETERO HC.)',
	'OSALTAMAVIR',
	'CAP',
	gm.nullify_empty_string('45')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUVIR 45 (HETERO HC.)'
);

-- line #25199
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUVIR 12 (HETERO HC.)',
	'OSALTAMAVIR',
	'D.SYR',
	gm.nullify_empty_string('12')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUVIR 12 (HETERO HC.)'
);

-- line #25200
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUHALT 75 (Ranbaxy)',
	'OSELTAMIVIR',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUHALT 75 (Ranbaxy)'
);

-- line #25201
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELDACH 50 (CELON(VIVILON))',
	'OXALIPLATIN',
	'VIAL',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELDACH 50 (CELON(VIVILON))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELDACH 100 (CELON(VIVILON))',
	'OXALIPLATIN',
	'VIAL',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELDACH 100 (CELON(VIVILON))'
);

-- line #25202
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COLODACH 50 (AMRONCO)',
	'OXALIPLATIN',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COLODACH 50 (AMRONCO)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COLODACH 100 (AMRONCO)',
	'OXALIPLATIN',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COLODACH 100 (AMRONCO)'
);

-- line #25203
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DACOTIN 50 (Dr.Reddy''S)',
	'OXALIPLATIN',
	'VIAL',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DACOTIN 50 (Dr.Reddy''S)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DACOTIN 100 (Dr.Reddy''S)',
	'OXALIPLATIN',
	'VIAL',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DACOTIN 100 (Dr.Reddy''S)'
);

-- line #25204
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLENOXAL 50 (ONKOS(GLENMARK))',
	'OXALIPLATIN',
	'VIAL',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLENOXAL 50 (ONKOS(GLENMARK))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLENOXAL 100 (ONKOS(GLENMARK))',
	'OXALIPLATIN',
	'VIAL',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLENOXAL 100 (ONKOS(GLENMARK))'
);

-- line #25205
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KINAPLAT 2 (ONCOCARE)',
	'OXALIPLATIN',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KINAPLAT 2 (ONCOCARE)'
);

-- line #25206
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGAPLAT 100 (Alkem)',
	'OXALIPLATIN',
	'VIAL',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGAPLAT 100 (Alkem)'
);

-- line #25207
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGAPLAT 50 (Alkem)',
	'OXALIPLATIN',
	'VIAL',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGAPLAT 50 (Alkem)'
);

-- line #25208
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METAPLATIN 100 (Parenteral)',
	'OXALIPLATIN',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg(LYOPHILIZED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METAPLATIN 100 (Parenteral)'
);

-- line #25209
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METAPLATIN 50 (Parenteral)',
	'OXALIPLATIN',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg(LYOPHILIZED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METAPLATIN 50 (Parenteral)'
);

-- line #25210
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXALISPERA 100 (Indoco Rem.)',
	'OXALIPLATIN',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXALISPERA 100 (Indoco Rem.)'
);

-- line #25211
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXALISPERA 2 (Indoco Rem.)',
	'OXALIPLATIN',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXALISPERA 2 (Indoco Rem.)'
);

-- line #25212
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXALIZEN 100 (ZEN LIFE)',
	'OXALIPLATIN',
	'INJ INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXALIZEN 100 (ZEN LIFE)'
);

-- line #25213
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXALIZEN 50 (ZEN LIFE)',
	'OXALIPLATIN',
	'INJ INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXALIZEN 50 (ZEN LIFE)'
);

-- line #25214
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXICHEMO 2 (Lupin)',
	'OXALIPLATIN',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXICHEMO 2 (Lupin)'
);

-- line #25215
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXITOZ 100 (INTAS BIO.)',
	'OXALIPLATIN',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXITOZ 100 (INTAS BIO.)'
);

-- line #25216
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXITOZ 50 (INTAS BIO.)',
	'OXALIPLATIN',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXITOZ 50 (INTAS BIO.)'
);

-- line #25217
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXITRUST-50 50 (Panacea)',
	'OXALIPLATIN',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXITRUST-50 50 (Panacea)'
);

-- line #25218
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXITRUST 100 (Panacea)',
	'OXALIPLATIN',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXITRUST 100 (Panacea)'
);

-- line #25219
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXPLA 100 (ZYDUS ONC.)',
	'OXALIPLATIN',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXPLA 100 (ZYDUS ONC.)'
);

-- line #25220
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXPLA 200 (ZYDUS ONC.)',
	'OXALIPLATIN',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXPLA 200 (ZYDUS ONC.)'
);

-- line #25221
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXPLA 50 (ZYDUS ONC.)',
	'OXALIPLATIN',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXPLA 50 (ZYDUS ONC.)'
);

-- line #25222
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLATLOC-AS 100 (Shantha Bio.)',
	'OXALIPLATIN',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLATLOC-AS 100 (Shantha Bio.)'
);

-- line #25223
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLATOXIN 50 (Shantha Bio.)',
	'OXALIPLATIN',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'100'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLATOXIN 50 (Shantha Bio.)'
);

-- line #25224
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACPROX 600 (Macleods)',
	'OXAPROZIN',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACPROX 600 (Macleods)'
);

-- line #25225
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXAPRO 600 (Zuventus)',
	'OXAPROZIN',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXAPRO 600 (Zuventus)'
);

-- line #25226
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANXOZAP 10 (Sun)',
	'Oxazepam',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANXOZAP 10 (Sun)'
);

-- line #25227
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANXOZAP 15 (Sun)',
	'Oxazepam',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANXOZAP 15 (Sun)'
);

-- line #25228
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANXOZAP 30 (Sun)',
	'Oxazepam',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANXOZAP 30 (Sun)'
);

-- line #25229
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARBOX 150 (SYNAPSE)',
	'OXCARBAZEPINE',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARBOX 150 (SYNAPSE)'
);

-- line #25230
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARBOX 300 (SYNAPSE)',
	'OXCARBAZEPINE',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARBOX 300 (SYNAPSE)'
);

-- line #25231
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARBOX 600 (SYNAPSE)',
	'OXCARBAZEPINE',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARBOX 600 (SYNAPSE)'
);

-- line #25232
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EURESTA 300 (CENTRA(USV))',
	'OXCARBAZEPINE',
	'SR TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EURESTA 300 (CENTRA(USV))'
);

-- line #25233
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EURESTA 600 (CENTRA(USV))',
	'OXCARBAZEPINE',
	'SR TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EURESTA 600 (CENTRA(USV))'
);

-- line #25234
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EURESTA 150 (USV C)',
	'OXCARBAZEPINE',
	'SR TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EURESTA 150 (USV C)'
);

-- line #25235
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOVAX 300 (LUPIN)',
	'OXCARBAZEPINE',
	'OD TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOVAX 300 (LUPIN)'
);

-- line #25236
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOVAX 600 (LUPIN)',
	'OXCARBAZEPINE',
	'OD TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOVAX 600 (LUPIN)'
);

-- line #25237
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOVAX 150 (LUPIN)',
	'OXCARBAZEPINE',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOVAX 150 (LUPIN)'
);

-- line #25238
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOVAX 300 (LUPIN)',
	'OXCARBAZEPINE',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOVAX 300 (LUPIN)'
);

-- line #25239
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOVAX 600 (LUPIN)',
	'OXCARBAZEPINE',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOVAX 600 (LUPIN)'
);

-- line #25240
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEZALOG 150 (LA DRUG)',
	'OXCARBAZEPINE',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEZALOG 150 (LA DRUG)'
);

-- line #25241
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEZALOG 300 (LA DRUG)',
	'OXCARBAZEPINE',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEZALOG 300 (LA DRUG)'
);

-- line #25242
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEZALOG 600 (LA DRUG)',
	'OXCARBAZEPINE',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEZALOG 600 (LA DRUG)'
);

-- line #25243
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NICTAL 150 (Ipca)',
	'OXCARBAZEPINE',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NICTAL 150 (Ipca)'
);

-- line #25244
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NICTAL 300 (Ipca)',
	'OXCARBAZEPINE',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NICTAL 300 (Ipca)'
);

-- line #25245
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NICTAL 600 (Ipca)',
	'OXCARBAZEPINE',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NICTAL 600 (Ipca)'
);

-- line #25246
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLEPTAL 150 (Torrent)',
	'Oxcarbazepine',
	'DT',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLEPTAL 150 (Torrent)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLEPTAL 300 (Torrent)',
	'Oxcarbazepine',
	'DT',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLEPTAL 300 (Torrent)'
);

-- line #25247
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLEPTAL 450 (Torrent)',
	'Oxcarbazepine',
	'DT',
	gm.nullify_empty_string('450')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLEPTAL 450 (Torrent)'
);

-- line #25248
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLEPTAL 450 (TORRENT)',
	'OXCARBAZEPINE',
	'OD TAB',
	gm.nullify_empty_string('450')::numeric,
	'mg(SR)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLEPTAL 450 (TORRENT)'
);

-- line #25249
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLEPTAL 900 (TORRENT)',
	'OXCARBAZEPINE',
	'OD TAB',
	gm.nullify_empty_string('900')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLEPTAL 900 (TORRENT)'
);

-- line #25250
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLEPTAL 600 (Torrent)',
	'Oxcarbazepine',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLEPTAL 600 (Torrent)'
);

-- line #25251
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSCAR 150 (Theo Ph.)',
	'OXCARBAZEPINE',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSCAR 150 (Theo Ph.)'
);

-- line #25252
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSCAR 300 (Theo Ph.)',
	'OXCARBAZEPINE',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSCAR 300 (Theo Ph.)'
);

-- line #25253
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSCAR 600 (Theo Ph.)',
	'OXCARBAZEPINE',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSCAR 600 (Theo Ph.)'
);

-- line #25254
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXANA 150 (PSYCOREM)',
	'OXCARBAZEPINE',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXANA 150 (PSYCOREM)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXANA 300 (PSYCOREM)',
	'OXCARBAZEPINE',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXANA 300 (PSYCOREM)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXANA 600 (PSYCOREM)',
	'OXCARBAZEPINE',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXANA 600 (PSYCOREM)'
);

-- line #25255
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXCARB 150 (Protec)',
	'Oxcarbazepine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXCARB 150 (Protec)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXCARB 300 (Protec)',
	'Oxcarbazepine',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXCARB 300 (Protec)'
);

-- line #25256
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXCARB 600 (Protec)',
	'Oxcarbazepine',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXCARB 600 (Protec)'
);

-- line #25257
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXCAZO 150 (Unichem)',
	'OXCARBAZEPINE',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXCAZO 150 (Unichem)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXCAZO 300 (Unichem)',
	'OXCARBAZEPINE',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXCAZO 300 (Unichem)'
);

-- line #25258
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXEMAZETOL 150 (Piramal Hc.)',
	'OXCARBAZEPINE',
	'SR TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXEMAZETOL 150 (Piramal Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXEMAZETOL 300 (Piramal Hc.)',
	'OXCARBAZEPINE',
	'SR TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXEMAZETOL 300 (Piramal Hc.)'
);

-- line #25259
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXEMAZETOL 600 (Piramal Hc.)',
	'OXCARBAZEPINE',
	'SR TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXEMAZETOL 600 (Piramal Hc.)'
);

-- line #25260
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXEP 150 (Nicholas)',
	'Oxcarbazepine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXEP 150 (Nicholas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXEP 300 (Nicholas)',
	'Oxcarbazepine',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXEP 300 (Nicholas)'
);

-- line #25261
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXEP 600 (Nicholas)',
	'Oxcarbazepine',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXEP 600 (Nicholas)'
);

-- line #25262
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'150', u'strength_2': u'', u'substance': u'Oxcarbazepine', u'always_empty': u'', u'form': u'', u'brand': u'OXEPTAL', u'strength_3': u'', u'company': u'Zydus N.S.', u'unit': u'mg'}

-- line #25263
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'300', u'strength_2': u'', u'substance': u'Oxcarbazepine', u'always_empty': u'', u'form': u'', u'brand': u'OXEPTAL', u'strength_3': u'', u'company': u'Zydus N.S.', u'unit': u'mg'}

-- line #25264
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'600', u'strength_2': u'', u'substance': u'Oxcarbazepine', u'always_empty': u'', u'form': u'', u'brand': u'OXEPTAL', u'strength_3': u'', u'company': u'Zydus N.S.', u'unit': u'mg'}

-- line #25265
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXETOL 150 (Sun)',
	'Oxcarbazepine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXETOL 150 (Sun)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXETOL 300 (Sun)',
	'Oxcarbazepine',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXETOL 300 (Sun)'
);

-- line #25266
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXETOL 450 (Sun)',
	'Oxcarbazepine',
	'TAB',
	gm.nullify_empty_string('450')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXETOL 450 (Sun)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXETOL 600 (Sun)',
	'Oxcarbazepine',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXETOL 600 (Sun)'
);

-- line #25267
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXETOL 150 (SUN)',
	'OXCARBAZEPINE',
	'XR TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXETOL 150 (SUN)'
);

-- line #25268
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXETOL 300 (SUN)',
	'OXCARBAZEPINE',
	'XR TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXETOL 300 (SUN)'
);

-- line #25269
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXETOL 450 (Sun)',
	'OXCARBAZEPINE',
	'XR TAB',
	gm.nullify_empty_string('450')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXETOL 450 (Sun)'
);

-- line #25270
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXETOL 600 (SUN)',
	'OXCARBAZEPINE',
	'XR TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXETOL 600 (SUN)'
);

-- line #25271
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXINE 150 (SYKOCURE)',
	'OXCARBAZEPINE',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXINE 150 (SYKOCURE)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXINE 300 (SYKOCURE)',
	'OXCARBAZEPINE',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXINE 300 (SYKOCURE)'
);

-- line #25272
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OX MAZETOL 150 (Piramal Hc.)',
	'OXCARBAZEPINE',
	'ER TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OX MAZETOL 150 (Piramal Hc.)'
);

-- line #25273
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OX MAZETOL 300 (Piramal Hc.)',
	'OXCARBAZEPINE',
	'ER TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OX MAZETOL 300 (Piramal Hc.)'
);

-- line #25274
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXMAZETOL 150 (Piramal Hc.)',
	'OXCARBAZEPINE',
	'OD TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXMAZETOL 150 (Piramal Hc.)'
);

-- line #25275
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXMAZETOL 300 (Piramal Hc.)',
	'OXCARBAZEPINE',
	'OD TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXMAZETOL 300 (Piramal Hc.)'
);

-- line #25276
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXMAZETOL 600 (Piramal Hc.)',
	'OXCARBAZEPINE',
	'OD TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXMAZETOL 600 (Piramal Hc.)'
);

-- line #25277
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OX-MAZETOL 150 (Piramal Hc.)',
	'Oxcarbazepine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OX-MAZETOL 150 (Piramal Hc.)'
);

-- line #25278
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OX-MAZETOL 300 (Piramal Hc.)',
	'Oxcarbazepine',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OX-MAZETOL 300 (Piramal Hc.)'
);

-- line #25279
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OX-MAZETOL 600 (Piramal Hc.)',
	'Oxcarbazepine',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OX-MAZETOL 600 (Piramal Hc.)'
);

-- line #25280
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OX MEZETOL 600 (Piramal Hc.)',
	'OXCARBAZEPINE',
	'ER TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OX MEZETOL 600 (Piramal Hc.)'
);

-- line #25281
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXRATE 300 (Wockhardt)',
	'OXCARBAZEPINE',
	'OD TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXRATE 300 (Wockhardt)'
);

-- line #25282
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXRATE 600 (Wockhardt)',
	'OXCARBAZEPINE',
	'OD TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXRATE 600 (Wockhardt)'
);

-- line #25283
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXRATE 150 (Merind)',
	'Oxcarbazepine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXRATE 150 (Merind)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXRATE 300 (Merind)',
	'Oxcarbazepine',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXRATE 300 (Merind)'
);

-- line #25284
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXRATE 600 (Merind)',
	'Oxcarbazepine',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXRATE 600 (Merind)'
);

-- line #25285
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXRING 150 (Alkem)',
	'OXCARBAZEPINE',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXRING 150 (Alkem)'
);

-- line #25286
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OZONTHINE 60 (Shreya)',
	'Oxidation Prod.Of Essence Of Terebenthine',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OZONTHINE 60 (Shreya)'
);

-- line #25287
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OZOTHINE 12 (Shreya)',
	'Oxidation Prod.Of Essence Of Terebenthine',
	'SYR',
	gm.nullify_empty_string('12')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OZOTHINE 12 (Shreya)'
);

-- line #25288
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OZOTHINE 60 (Shreya)',
	'Oxidation Prod.Of Essence Of Terebenthine',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OZOTHINE 60 (Shreya)'
);

-- line #25289
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYSTRAN 2.5 (Intas)',
	'Oxybutynin',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYSTRAN 2.5 (Intas)'
);

-- line #25290
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYSTRAN 5 (Intas)',
	'Oxybutynin',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYSTRAN 5 (Intas)'
);

-- line #25291
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOCTURIN 2.5 (Elder)',
	'Oxybutynin',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOCTURIN 2.5 (Elder)'
);

-- line #25292
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOCTURIN 5 (Elder)',
	'Oxybutynin',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOCTURIN 5 (Elder)'
);

-- line #25293
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXYBUTIN 2.5 (Troikaa)',
	'Oxybutynin',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXYBUTIN 2.5 (Troikaa)'
);

-- line #25294
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXYBUTIN 5 (Troikaa)',
	'Oxybutynin',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXYBUTIN 5 (Troikaa)'
);

-- line #25295
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXYSPAS 2.5 (Cipla)',
	'Oxybutynin',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXYSPAS 2.5 (Cipla)'
);

-- line #25296
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXYSPAS 5 (Cipla)',
	'Oxybutynin',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXYSPAS 5 (Cipla)'
);

-- line #25297
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ILDAMEN 4 (German R.)',
	'Oxyfedrine',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ILDAMEN 4 (German R.)'
);

-- line #25298
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ILDAMEN 24 (German R.)',
	'Oxyfedrine',
	'TAB',
	gm.nullify_empty_string('24')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ILDAMEN 24 (German R.)'
);

-- line #25299
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ILDAMEN 8 (German R.)',
	'Oxyfedrine',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ILDAMEN 8 (German R.)'
);

-- line #25300
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CODYLEX NASAL 0.5 (A.F.D.)',
	'Oxymetazoline Hcl.',
	'DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CODYLEX NASAL 0.5 (A.F.D.)'
);

-- line #25301
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,5', u'strength_2': u'', u'substance': u'Oxymetazoline Hcl.', u'always_empty': u'', u'form': u'', u'brand': u'FEBREX PLUS NSDPS', u'strength_3': u'', u'company': u'Indoco Rem.', u'unit': u'%'}

-- line #25302
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAXTRA NASAL 0.05 (Zuventus)',
	'Oxymetazoline Hcl.',
	'DPS',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAXTRA NASAL 0.05 (Zuventus)'
);

-- line #25303
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METZOL NASAL 0.1 (Solitaire)',
	'Oxymetazoline Hcl.',
	'DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METZOL NASAL 0.1 (Solitaire)'
);

-- line #25304
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NASELIN 0.05 (Cipla)',
	'Oxymetazoline Hcl.',
	'DPS',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NASELIN 0.05 (Cipla)'
);

-- line #25305
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NASIVION MINI 0.01 (Merck)',
	'Oxymetazoline Hcl.',
	'DPS',
	gm.nullify_empty_string('0.01')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NASIVION MINI 0.01 (Merck)'
);

-- line #25306
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NASIVION MOIST 0.5 (Merck)',
	'Oxymetazoline Hcl.',
	'NASAL SPRAY ADULT',
	gm.nullify_empty_string('0.5')::numeric,
	'mg(50'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NASIVION MOIST 0.5 (Merck)'
);

-- line #25307
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u' % BENZYL ALCOHOL)', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.05(0.05', u'strength_2': u'', u'substance': u'Oxymetazoline Hcl.', u'always_empty': u'', u'form': u'', u'brand': u'NASIVION NO DRIP', u'strength_3': u'', u'company': u'Merck', u'unit': u'% BENZALKONIUM CHL.'}

-- line #25308
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NASIVION PAED 0.025 (Merck)',
	'Oxymetazoline Hcl.',
	'SOL',
	gm.nullify_empty_string('0.025')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NASIVION PAED 0.025 (Merck)'
);

-- line #25309
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NASIVION 0.05 (Merck)',
	'Oxymetazoline Hcl.',
	'SOL',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NASIVION 0.05 (Merck)'
);

-- line #25310
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,5', u'strength_2': u'', u'substance': u'Oxymetazoline Hcl.', u'always_empty': u'', u'form': u'', u'brand': u'NEW NASIVION CARA ADULT', u'strength_3': u'', u'company': u'Merck', u'unit': u'mg(IN BUFFERED AQ. SOL.)'}

-- line #25311
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,25', u'strength_2': u'', u'substance': u'Oxymetazoline Hcl.', u'always_empty': u'', u'form': u'', u'brand': u'NEW NASIVION CARA PAED', u'strength_3': u'', u'company': u'Merck', u'unit': u'mg(IN BUFFERED AQ. SOL.)'}

-- line #25312
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEW NASIVION CARE ADULT NASAL 0.5 (Merck)',
	'Oxymetazoline Hcl.',
	'DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEW NASIVION CARE ADULT NASAL 0.5 (Merck)'
);

-- line #25313
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEW NASIVION CARE PAEDIATRIC NASAL 0.25 (Merck)',
	'Oxymetazoline Hcl.',
	'DPS',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEW NASIVION CARE PAEDIATRIC NASAL 0.25 (Merck)'
);

-- line #25314
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OTRIVIN-O 0.5 (Novartis)',
	'Oxymetazoline Hcl.',
	'SOLN',
	gm.nullify_empty_string('0.5')::numeric,
	'% W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OTRIVIN-O 0.5 (Novartis)'
);

-- line #25315
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXYLIN 0.025 (Allergan)',
	'Oxymetazoline Hcl.',
	'EYE DPS',
	gm.nullify_empty_string('0.025')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXYLIN 0.025 (Allergan)'
);

-- line #25316
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,05', u'strength_2': u'', u'substance': u'Oxymetazoline Hcl.', u'always_empty': u'', u'form': u'', u'brand': u'OXYSPRAY', u'strength_3': u'', u'company': u'RESPICARE(GERMAN R.)', u'unit': u'%W/V'}

-- line #25317
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RHINOJET 0.5 (Merck)',
	'Oxymetazoline Hcl.',
	'NASAL SPRAY',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RHINOJET 0.5 (Merck)'
);

-- line #25318
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RINOX (PAEDIATRIC) % 0.25 (Micro Nova)',
	'Oxymetazoline Hcl.',
	'SOL',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RINOX (PAEDIATRIC) % 0.25 (Micro Nova)'
);

-- line #25319
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RINOX % 0.5 (Micro Nova)',
	'Oxymetazoline Hcl.',
	'SOL',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RINOX % 0.5 (Micro Nova)'
);

-- line #25320
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADROYD 5 (PFIZER)',
	'Oxymetholone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADROYD 5 (PFIZER)'
);

-- line #25321
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXY-TRIACTIN 100 (Pharmed)',
	'Oxyphenbutazone',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXY-TRIACTIN 100 (Pharmed)'
);

-- line #25322
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANTRENYL DUPLEX 10 (Novartis)',
	'Oxyphenonium',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANTRENYL DUPLEX 10 (Novartis)'
);

-- line #25323
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANTRENYL 5 (Novartis)',
	'Oxyphenonium',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANTRENYL 5 (Novartis)'
);

-- line #25324
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Oxytetracycline', u'always_empty': u'', u'form': u'INJ', u'brand': u'BETETRA', u'strength_3': u'', u'company': u'Brooks Ph.', u'unit': u''}

-- line #25325
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXTER 250 (Ind-Swift)',
	'Oxytetracycline',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXTER 250 (Ind-Swift)'
);

-- line #25326
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXTER 50 (Pfizer)',
	'Oxytetracycline',
	'VIAL',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXTER 50 (Pfizer)'
);

-- line #25327
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXYTERACIN 50 (Jagsonpal)',
	'Oxytetracycline',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXYTERACIN 50 (Jagsonpal)'
);

-- line #25328
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXYTETRACYCLINE 500 (Pfizer)',
	'Oxytetracycline',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXYTETRACYCLINE 500 (Pfizer)'
);

-- line #25329
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXYTETRACYCLINE 500 (Wockhardt)',
	'Oxytetracycline',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXYTETRACYCLINE 500 (Wockhardt)'
);

-- line #25330
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXYTETRACYCLINE 30 (Pfizer)',
	'Oxytetracycline',
	'OINT',
	gm.nullify_empty_string('30')::numeric,
	'mg/G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXYTETRACYCLINE 30 (Pfizer)'
);

-- line #25331
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Oxytetracycline', u'always_empty': u'', u'form': u'V', u'brand': u'OXYTETRACYCLINE', u'strength_3': u'', u'company': u'Wockhardt', u'unit': u''}

-- line #25332
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5IU', u'strength_2': u'', u'substance': u'Oxytocin', u'always_empty': u'', u'form': u'INJ', u'brand': u'EMTOCIN', u'strength_3': u'', u'company': u'M.M. Labs', u'unit': u''}

-- line #25333
-- ignoring line: field [strength_1] not numeric: >>>5IU<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5IU', u'strength_2': u'ML(0.5', u'substance': u'Oxytocin', u'always_empty': u'', u'form': u'INJ', u'brand': u'EVATOCIN', u'strength_3': u'', u'company': u'Neon', u'unit': u'% CHLORBUTOL)'}

-- line #25334
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5IU', u'strength_2': u'ML', u'substance': u'Oxytocin', u'always_empty': u'', u'form': u'INJ', u'brand': u'FOETOCIN', u'strength_3': u'', u'company': u'Ttk Hc.', u'unit': u''}

-- line #25335
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5IU', u'strength_2': u'ML', u'substance': u'Oxytocin', u'always_empty': u'', u'form': u'INJ', u'brand': u'GYNOTOCIN', u'strength_3': u'', u'company': u'Svizera', u'unit': u''}

-- line #25336
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5IU', u'strength_2': u'ML', u'substance': u'Oxytocin', u'always_empty': u'', u'form': u'AMP', u'brand': u'INDOX', u'strength_3': u'', u'company': u'Ind-Swift', u'unit': u''}

-- line #25337
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5IU', u'strength_2': u'ML', u'substance': u'Oxytocin', u'always_empty': u'', u'form': u'INJ', u'brand': u'LABOTOCIN', u'strength_3': u'', u'company': u'TWILIGHT LIT.', u'unit': u''}

-- line #25338
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5IU', u'strength_2': u'ML', u'substance': u'Oxytocin', u'always_empty': u'', u'form': u'INJ', u'brand': u'MERITOCIN', u'strength_3': u'', u'company': u'Mercury', u'unit': u''}

-- line #25339
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5IU', u'strength_2': u'ML', u'substance': u'Oxytocin', u'always_empty': u'', u'form': u'INJ', u'brand': u'OXCIN', u'strength_3': u'', u'company': u'ROSE LABS', u'unit': u''}

-- line #25340
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5IU.', u'strength_2': u'5ML', u'substance': u'Oxytocin', u'always_empty': u'', u'form': u'INJ', u'brand': u'OXYBRO', u'strength_3': u'', u'company': u'Cadila Ph.', u'unit': u''}

-- line #25341
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1ML INJ', u'strength_2': u'', u'substance': u'Oxytocin', u'always_empty': u'', u'form': u'INJ', u'brand': u'OXYSTAR', u'strength_3': u'', u'company': u'Cadila Ph.', u'unit': u''}

-- line #25342
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5IU', u'strength_2': u'ML', u'substance': u'Oxytocin', u'always_empty': u'', u'form': u'INJ', u'brand': u'OXYTON-5', u'strength_3': u'', u'company': u'Inga', u'unit': u''}

-- line #25343
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5IU', u'strength_2': u'', u'substance': u'Oxytocin', u'always_empty': u'', u'form': u'INJ', u'brand': u'PARTOCIN IU', u'strength_3': u'', u'company': u'Astrazeneca', u'unit': u''}

-- line #25344
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5IU.', u'strength_2': u'ML', u'substance': u'Oxytocin', u'always_empty': u'', u'form': u'INJ', u'brand': u'PFISCOCIN', u'strength_3': u'', u'company': u'Pfiscar Ind.', u'unit': u''}

-- line #25345
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5UNITS', u'strength_2': u'0.5ML', u'substance': u'Oxytocin', u'always_empty': u'', u'form': u'AMP', u'brand': u'PITOCIN', u'strength_3': u'', u'company': u'Pfizer', u'unit': u''}

-- line #25346
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5UNITS', u'strength_2': u'ML', u'substance': u'Oxytocin', u'always_empty': u'', u'form': u'AMP', u'brand': u'PITOCIN', u'strength_3': u'', u'company': u'Pfizer', u'unit': u''}

-- line #25347
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10IU', u'strength_2': u'ML', u'substance': u'Oxytocin', u'always_empty': u'', u'form': u'INJ', u'brand': u'PITOCIN', u'strength_3': u'', u'company': u'Pfizer', u'unit': u''}

-- line #25348
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5IU.', u'strength_2': u'ML', u'substance': u'Oxytocin', u'always_empty': u'', u'form': u'INJ', u'brand': u'PRESTOCIN-5', u'strength_3': u'', u'company': u'Indus', u'unit': u''}

-- line #25349
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200', u'strength_2': u'', u'substance': u'OZAGRET HCL', u'always_empty': u'', u'form': u'', u'brand': u'OZAFLO', u'strength_3': u'', u'company': u'Macleods', u'unit': u'mg'}

-- line #25350
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBUPAX 100 (Natco Ph.)',
	'PACLITAXEL',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg(PACLITAXEL ALBUMIN)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBUPAX 100 (Natco Ph.)'
);

-- line #25351
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALTAXEL 100 (Cytomed(Alkem))',
	'PACLITAXEL',
	'VIAL',
	gm.nullify_empty_string('100')::numeric,
	'mg/16.7ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALTAXEL 100 (Cytomed(Alkem))'
);

-- line #25352
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALTAXEL 260 (Cytomed(Alkem))',
	'PACLITAXEL',
	'VIAL',
	gm.nullify_empty_string('260')::numeric,
	'mg/43.34ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALTAXEL 260 (Cytomed(Alkem))'
);

-- line #25353
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALTAXEL 300 (Cytomed(Alkem))',
	'PACLITAXEL',
	'VIAL',
	gm.nullify_empty_string('300')::numeric,
	'mg/50ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALTAXEL 300 (Cytomed(Alkem))'
);

-- line #25354
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALTAXEL 30 (Cytomed(Alkem))',
	'PACLITAXEL',
	'VIAL',
	gm.nullify_empty_string('30')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALTAXEL 30 (Cytomed(Alkem))'
);

-- line #25355
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMTAX 30 (AMRONCO)',
	'PACLITAXEL',
	'INJ',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMTAX 30 (AMRONCO)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMTAX 100 (AMRONCO)',
	'PACLITAXEL',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMTAX 100 (AMRONCO)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMTAX 260 (AMRONCO)',
	'PACLITAXEL',
	'INJ',
	gm.nullify_empty_string('260')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMTAX 260 (AMRONCO)'
);

-- line #25356
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETAXEL 100 (Biological E.)',
	'Paclitaxel',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/17ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETAXEL 100 (Biological E.)'
);

-- line #25357
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETAXEL 30 (Biological E.)',
	'Paclitaxel',
	'INJ',
	gm.nullify_empty_string('30')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETAXEL 30 (Biological E.)'
);

-- line #25358
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELTAX 100 (CELON(VIVILON))',
	'PACLITAXEL',
	'VIAL',
	gm.nullify_empty_string('100')::numeric,
	'mg/16.7ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELTAX 100 (CELON(VIVILON))'
);

-- line #25359
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELTAX 250 (CELON(VIVILON))',
	'PACLITAXEL',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg/41.7ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELTAX 250 (CELON(VIVILON))'
);

-- line #25360
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELTAX 260 (CELON(VIVILON))',
	'PACLITAXEL',
	'VIAL',
	gm.nullify_empty_string('260')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELTAX 260 (CELON(VIVILON))'
);

-- line #25361
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELTAX 300 (CELON(VIVILON))',
	'PACLITAXEL',
	'VIAL',
	gm.nullify_empty_string('300')::numeric,
	'mg/50ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELTAX 300 (CELON(VIVILON))'
);

-- line #25362
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELTAX 30 (CELON(VIVILON))',
	'PACLITAXEL',
	'VIAL',
	gm.nullify_empty_string('30')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELTAX 30 (CELON(VIVILON))'
);

-- line #25363
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLIXEL 100 (RANBAXY (S.S.))',
	'Paclitaxel',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLIXEL 100 (RANBAXY (S.S.))'
);

-- line #25364
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLIXEL 300 (RANBAXY (S.S.))',
	'Paclitaxel',
	'INJ',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLIXEL 300 (RANBAXY (S.S.))'
);

-- line #25365
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLIXEL 30 (RANBAXY (S.S.))',
	'Paclitaxel',
	'INJ',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLIXEL 30 (RANBAXY (S.S.))'
);

-- line #25366
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYTAX 100 (Intas)',
	'Paclitaxel',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/16.7ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYTAX 100 (Intas)'
);

-- line #25367
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYTAX 30 (Intas)',
	'Paclitaxel',
	'INJ',
	gm.nullify_empty_string('30')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYTAX 30 (Intas)'
);

-- line #25368
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYTAX 200 (Intas)',
	'Paclitaxel',
	'VIAL',
	gm.nullify_empty_string('200')::numeric,
	'mg/33.4ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYTAX 200 (Intas)'
);

-- line #25369
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYTAX 300 (Intas)',
	'Paclitaxel',
	'VIAL',
	gm.nullify_empty_string('300')::numeric,
	'mg/50ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYTAX 300 (Intas)'
);

-- line #25370
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENEXOL 100 (Lupin)',
	'PACLITAXEL',
	'PM',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENEXOL 100 (Lupin)'
);

-- line #25371
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENEXOL 30 (Lupin)',
	'PACLITAXEL',
	'PM',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENEXOL 30 (Lupin)'
);

-- line #25372
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MITOTAX 100 (Dr.Reddy''S)',
	'PACLITAXEL',
	'VIAL',
	gm.nullify_empty_string('100')::numeric,
	'mg/16.7ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MITOTAX 100 (Dr.Reddy''S)'
);

-- line #25373
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MITOTAX 250 (Dr.Reddy''S)',
	'PACLITAXEL',
	'VIAL',
	gm.nullify_empty_string('250')::numeric,
	'mg/41.7ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MITOTAX 250 (Dr.Reddy''S)'
);

-- line #25374
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MITOTAX 300 (Dr.Reddy''S)',
	'PACLITAXEL',
	'VIAL',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MITOTAX 300 (Dr.Reddy''S)'
);

-- line #25375
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MITOTAX 30 (Dr.Reddy''S)',
	'PACLITAXEL',
	'VIAL',
	gm.nullify_empty_string('30')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MITOTAX 30 (Dr.Reddy''S)'
);

-- line #25376
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOTAXL 100 (Vhb)',
	'Paclitaxel',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/16.67ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOTAXL 100 (Vhb)'
);

-- line #25377
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOTAXL 30 (Vhb)',
	'Paclitaxel',
	'INJ',
	gm.nullify_empty_string('30')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOTAXL 30 (Vhb)'
);

-- line #25378
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOTAXL 260 (Vhb)',
	'Paclitaxel',
	'VIAL',
	gm.nullify_empty_string('260')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOTAXL 260 (Vhb)'
);

-- line #25379
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONCOTAXEL 260 (Sun)',
	'Paclitaxel',
	'VIAL',
	gm.nullify_empty_string('260')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONCOTAXEL 260 (Sun)'
);

-- line #25380
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PACLIPAR 100 (Parenteral)',
	'PACLITAXEL',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/16.7ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PACLIPAR 100 (Parenteral)'
);

-- line #25381
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PACLIPAR 260 (Parenteral)',
	'PACLITAXEL',
	'INJ',
	gm.nullify_empty_string('260')::numeric,
	'mg/43.4ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PACLIPAR 260 (Parenteral)'
);

-- line #25382
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PACLIPAR 300 (Parenteral)',
	'PACLITAXEL',
	'INJ',
	gm.nullify_empty_string('300')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PACLIPAR 300 (Parenteral)'
);

-- line #25383
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PACLITAX 100 (Cipla)',
	'Paclitaxel',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PACLITAX 100 (Cipla)'
);

-- line #25384
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PACLITAX 260 (Cipla)',
	'Paclitaxel',
	'INJ',
	gm.nullify_empty_string('260')::numeric,
	'mg/43.3ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PACLITAX 260 (Cipla)'
);

-- line #25385
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PACLITAX 30 (Cipla)',
	'Paclitaxel',
	'INJ',
	gm.nullify_empty_string('30')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PACLITAX 30 (Cipla)'
);

-- line #25386
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PACLITERO 100 (HETERO HC.)',
	'PACLITAXEL',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PACLITERO 100 (HETERO HC.)'
);

-- line #25387
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PACLITERO 260 (HETERO HC.)',
	'PACLITAXEL',
	'INJ',
	gm.nullify_empty_string('260')::numeric,
	'mg/43.4ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PACLITERO 260 (HETERO HC.)'
);

-- line #25388
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PACLITERO 30 (HETERO HC.)',
	'PACLITAXEL',
	'INJ',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PACLITERO 30 (HETERO HC.)'
);

-- line #25389
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PACLITRUST 100 (Panacea)',
	'PACLITAXEL',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PACLITRUST 100 (Panacea)'
);

-- line #25390
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PACLITRUST 260 (Panacea)',
	'PACLITAXEL',
	'INJ',
	gm.nullify_empty_string('260')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PACLITRUST 260 (Panacea)'
);

-- line #25391
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PACLITRUST 30 (Panacea)',
	'PACLITAXEL',
	'INJ',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PACLITRUST 30 (Panacea)'
);

-- line #25392
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PACLIZEN 100 (ZEN LIFE)',
	'PACLITAXEL',
	'INJ INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/16.7ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PACLIZEN 100 (ZEN LIFE)'
);

-- line #25393
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PACLIZEN 260 (ZEN LIFE)',
	'PACLITAXEL',
	'INJ INJ',
	gm.nullify_empty_string('260')::numeric,
	'mg/43.4ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PACLIZEN 260 (ZEN LIFE)'
);

-- line #25394
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PACLIZEN 30 (ZEN LIFE)',
	'PACLITAXEL',
	'INJ INJ',
	gm.nullify_empty_string('30')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PACLIZEN 30 (ZEN LIFE)'
);

-- line #25395
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAXYTOL 100 (Shantha Bio.)',
	'PACLITAXEL',
	'VIAL',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAXYTOL 100 (Shantha Bio.)'
);

-- line #25396
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAXYTOL 260 (Shantha Bio.)',
	'PACLITAXEL',
	'VIAL',
	gm.nullify_empty_string('260')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAXYTOL 260 (Shantha Bio.)'
);

-- line #25397
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAXYTOL 30 (Shantha Bio.)',
	'PACLITAXEL',
	'VIAL',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAXYTOL 30 (Shantha Bio.)'
);

-- line #25398
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PETAXEL 6 (Biochem)',
	'Paclitaxel',
	'V',
	gm.nullify_empty_string('6')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PETAXEL 6 (Biochem)'
);

-- line #25399
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PALTRON 0.25 (Ranbaxy S.Sp.)',
	'PALANOSETRON',
	'VIAL',
	gm.nullify_empty_string('0.25')::numeric,
	'mg(HCL.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PALTRON 0.25 (Ranbaxy S.Sp.)'
);

-- line #25400
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASPIRE 3 (Piramal Hc.)',
	'PALIPERIDONE',
	'XR TAB',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASPIRE 3 (Piramal Hc.)'
);

-- line #25401
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASPIRE 6 (Piramal Hc.)',
	'PALIPERIDONE',
	'XR TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASPIRE 6 (Piramal Hc.)'
);

-- line #25402
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASPIRE 9 (Piramal Hc.)',
	'PALIPERIDONE',
	'XR TAB',
	gm.nullify_empty_string('9')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASPIRE 9 (Piramal Hc.)'
);

-- line #25403
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PALIDO 3 (Torrent)',
	'PALIPERIDONE',
	'OD TAB',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PALIDO 3 (Torrent)'
);

-- line #25404
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PALIDO 6 (Torrent)',
	'PALIPERIDONE',
	'OD TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PALIDO 6 (Torrent)'
);

-- line #25405
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PALIDO 9 (Torrent)',
	'PALIPERIDONE',
	'OD TAB',
	gm.nullify_empty_string('9')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PALIDO 9 (Torrent)'
);

-- line #25406
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PALIP 1.5 (Intas)',
	'PALIPERIDONE',
	'XR TAB',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PALIP 1.5 (Intas)'
);

-- line #25407
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PALIP 3 (Intas)',
	'PALIPERIDONE',
	'XR TAB',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PALIP 3 (Intas)'
);

-- line #25408
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PALIP 6 (Intas)',
	'PALIPERIDONE',
	'XR TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PALIP 6 (Intas)'
);

-- line #25409
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PALIP 9 (Intas)',
	'PALIPERIDONE',
	'XR TAB',
	gm.nullify_empty_string('9')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PALIP 9 (Intas)'
);

-- line #25410
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PALIRIS 3 (Sun)',
	'PALIPERIDONE',
	'TAB',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PALIRIS 3 (Sun)'
);

-- line #25411
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PALIRIS 6 (Sun)',
	'PALIPERIDONE',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PALIRIS 6 (Sun)'
);

-- line #25412
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PALIRIS 9 (Sun)',
	'PALIPERIDONE',
	'TAB',
	gm.nullify_empty_string('9')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PALIRIS 9 (Sun)'
);

-- line #25413
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PALIVEGA 3 (Zydus N.S.)',
	'PALIPERIDONE',
	'TAB',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PALIVEGA 3 (Zydus N.S.)'
);

-- line #25414
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PALIVEGA 6 (Zydus N.S.)',
	'PALIPERIDONE',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PALIVEGA 6 (Zydus N.S.)'
);

-- line #25415
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PALIVEGA 9 (Zydus N.S.)',
	'PALIPERIDONE',
	'TAB',
	gm.nullify_empty_string('9')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PALIVEGA 9 (Zydus N.S.)'
);

-- line #25416
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMCECAD 0.25 (ONCOCARE)',
	'PALONOSETRON',
	'INJ',
	gm.nullify_empty_string('0.25')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMCECAD 0.25 (ONCOCARE)'
);

-- line #25417
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PALNOX 0.25 (Glenmark)',
	'PALONOSETRON',
	'VIAL',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PALNOX 0.25 (Glenmark)'
);

-- line #25418
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50MCG', u'strength_2': u'ML', u'substance': u'PALONOSETRON', u'always_empty': u'', u'form': u'INJ', u'brand': u'PALONEW', u'strength_3': u'', u'company': u'SUN', u'unit': u''}

-- line #25419
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PALOSTAR 0.25 (LUPIN)',
	'PALONOSETRON',
	'INJ',
	gm.nullify_empty_string('0.25')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PALOSTAR 0.25 (LUPIN)'
);

-- line #25420
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PALOZAC 0.5 (Ajanta Ph.)',
	'PALONOSETRON',
	'CAP',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PALOZAC 0.5 (Ajanta Ph.)'
);

-- line #25421
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PALZEN 0.25 (DR. REDDY''S)',
	'PALONOSETRON',
	'INJ',
	gm.nullify_empty_string('0.25')::numeric,
	'mg/50ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PALZEN 0.25 (DR. REDDY''S)'
);

-- line #25422
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PALZEN 0.25 (Dr.Reddy''S)',
	'PALONOSETRON',
	'VIAL',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PALZEN 0.25 (Dr.Reddy''S)'
);

-- line #25423
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AREDIA 15 (Novartis)',
	'pamidronate',
	'INJ',
	gm.nullify_empty_string('15')::numeric,
	'mg(LYPHOLISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AREDIA 15 (Novartis)'
);

-- line #25424
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AREDIA 30 (Novartis)',
	'pamidronate',
	'INJ',
	gm.nullify_empty_string('30')::numeric,
	'mg(LYPHOLISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AREDIA 30 (Novartis)'
);

-- line #25425
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AREDIA 60 (Novartis)',
	'pamidronate',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg(LYPHOLISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AREDIA 60 (Novartis)'
);

-- line #25426
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AREDRONET 30 (Sun)',
	'pamidronate',
	'INJ',
	gm.nullify_empty_string('30')::numeric,
	'mg(LYPHOLISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AREDRONET 30 (Sun)'
);

-- line #25427
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AREDRONET 90 (Sun)',
	'pamidronate',
	'INJ',
	gm.nullify_empty_string('90')::numeric,
	'mg(LYPHOLISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AREDRONET 90 (Sun)'
);

-- line #25428
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BONAPAM 30 (Cytomed(Alkem))',
	'pamidronate',
	'VIAL',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BONAPAM 30 (Cytomed(Alkem))'
);

-- line #25429
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BONAPAM 60 (Cytomed(Alkem))',
	'pamidronate',
	'VIAL',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BONAPAM 60 (Cytomed(Alkem))'
);

-- line #25430
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BONAPAM 90 (Cytomed(Alkem))',
	'pamidronate',
	'VIAL',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BONAPAM 90 (Cytomed(Alkem))'
);

-- line #25431
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAMIDRIA 30 (Cipla)',
	'pamidronate',
	'INJ',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAMIDRIA 30 (Cipla)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAMIDRIA 60 (Cipla)',
	'pamidronate',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAMIDRIA 60 (Cipla)'
);

-- line #25432
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAMIDRIA 90 (Cipla)',
	'pamidronate',
	'INJ',
	gm.nullify_empty_string('90')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAMIDRIA 90 (Cipla)'
);

-- line #25433
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CREON 300 (Solvay Ph.)',
	'Pancreatin',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CREON 300 (Solvay Ph.)'
);

-- line #25434
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CREON 400 (Solvay Ph.)',
	'Pancreatin',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CREON 400 (Solvay Ph.)'
);

-- line #25435
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIGEPLEX 500 (Shreya)',
	'Pancreatin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIGEPLEX 500 (Shreya)'
);

-- line #25436
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250', u'strength_2': u'', u'substance': u'Pancreatin', u'always_empty': u'', u'form': u'', u'brand': u'ENZAR-HS', u'strength_3': u'', u'company': u'Elder', u'unit': u'mg'}

-- line #25437
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FESTAL-N 212.5 (Sanofi Aventis)',
	'Pancreatin',
	'TAB',
	gm.nullify_empty_string('212.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FESTAL-N 212.5 (Sanofi Aventis)'
);

-- line #25438
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANKREON 212.5 (Solvay Ph.)',
	'Pancreatin',
	'TAB',
	gm.nullify_empty_string('212.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANKREON 212.5 (Solvay Ph.)'
);

-- line #25439
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANSTAL-N 212.5 (Cipla)',
	'Pancreatin',
	'TAB',
	gm.nullify_empty_string('212.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANSTAL-N 212.5 (Cipla)'
);

-- line #25440
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANZYNORM HS 265 (German R.)',
	'Pancreatin',
	'TAB',
	gm.nullify_empty_string('265')::numeric,
	'mg(EQ. LIPASE 25000U.'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANZYNORM HS 265 (German R.)'
);

-- line #25441
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANZYNORM-N 125 (German R.)',
	'Pancreatin',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANZYNORM-N 125 (German R.)'
);

-- line #25442
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENEMAR 2 (Dolphin)',
	'Pancuronium',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENEMAR 2 (Dolphin)'
);

-- line #25443
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FANCURON 2 (Globus)',
	'Pancuronium',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FANCURON 2 (Globus)'
);

-- line #25444
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOCURON 2 (Neon)',
	'Pancuronium',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOCURON 2 (Neon)'
);

-- line #25445
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANCONIUM 2 (Khandelwal)',
	'Pancuronium',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANCONIUM 2 (Khandelwal)'
);

-- line #25446
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANCOR 2 (Csc Ph.)',
	'Pancuronium',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANCOR 2 (Csc Ph.)'
);

-- line #25447
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANCURONIUM BROMIDE 2 (Nicholas)',
	'Pancuronium',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANCURONIUM BROMIDE 2 (Nicholas)'
);

-- line #25448
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANURON 2 (Troikaa)',
	'Pancuronium',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANURON 2 (Troikaa)'
);

-- line #25449
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAVULON 2 (Infar)',
	'Pancuronium',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAVULON 2 (Infar)'
);

-- line #25450
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACIBAN IV 40 (Cadila Ph.)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACIBAN IV 40 (Cadila Ph.)'
);

-- line #25451
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACIHALT 40 (Sipra Rem.)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg/100ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACIHALT 40 (Sipra Rem.)'
);

-- line #25452
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACIHALT 40 (Sipra Rem.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACIHALT 40 (Sipra Rem.)'
);

-- line #25453
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADPANTA 40 (ADVENTUS)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADPANTA 40 (ADVENTUS)'
);

-- line #25454
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPENTA-IV 40 (Alpic Rem.)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPENTA-IV 40 (Alpic Rem.)'
);

-- line #25455
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPENTA 20 (Alpic Rem.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPENTA 20 (Alpic Rem.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPENTA 40 (Alpic Rem.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPENTA 40 (Alpic Rem.)'
);

-- line #25456
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMPEN 40 (HEALTH BIO.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMPEN 40 (HEALTH BIO.)'
);

-- line #25457
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANTOREZ 40 (Ronak Lab.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANTOREZ 40 (Ronak Lab.)'
);

-- line #25458
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANTOZOLE 40 (Alpha Hc.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANTOZOLE 40 (Alpha Hc.)'
);

-- line #25459
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APEN 40 (Aust Ind.)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APEN 40 (Aust Ind.)'
);

-- line #25460
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APRILIA 40 (SLANEY HC.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APRILIA 40 (SLANEY HC.)'
);

-- line #25461
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASOPRAZOLE 40 (AS PHARMA)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASOPRAZOLE 40 (AS PHARMA)'
);

-- line #25462
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASPAN 40 (ASTER PH.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASPAN 40 (ASTER PH.)'
);

-- line #25463
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Pantoprazole', u'always_empty': u'', u'form': u'INJ', u'brand': u'AXYPENT', u'strength_3': u'', u'company': u'AXYZEN LIFE', u'unit': u''}

-- line #25464
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXYPENT 40 (AXYZEN LIFE)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXYPENT 40 (AXYZEN LIFE)'
);

-- line #25465
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZEPANTO 40 (ABLAZE HC)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZEPANTO 40 (ABLAZE HC)'
);

-- line #25466
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BEEPAN 40 (HAMPS BIO)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BEEPAN 40 (HAMPS BIO)'
);

-- line #25467
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BELYCOOL 40 (Windlas)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BELYCOOL 40 (Windlas)'
);

-- line #25468
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40', u'strength_2': u'', u'substance': u'Pantoprazole', u'always_empty': u'', u'form': u'', u'brand': u'BIGPAN', u'strength_3': u'', u'company': u'SHINCE PH.', u'unit': u'mg'}

-- line #25469
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BUS 40 (NODYSIS PH.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BUS 40 (NODYSIS PH.)'
);

-- line #25470
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BUS 40 (NODYSIS PH.)',
	'Pantoprazole',
	'VIAL',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BUS 40 (NODYSIS PH.)'
);

-- line #25471
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANOZOL 40 (Candor Bio.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANOZOL 40 (Candor Bio.)'
);

-- line #25472
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONTROSEC 40 (Embiotic Lab.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONTROSEC 40 (Embiotic Lab.)'
);

-- line #25473
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COOL PAN 40 (MINOVA)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COOL PAN 40 (MINOVA)'
);

-- line #25474
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DACID 40 (Destin Lab)',
	'Pantoprazole',
	'PZ TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DACID 40 (Destin Lab)'
);

-- line #25475
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPENT 40 (Brooks Ph.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPENT 40 (Brooks Ph.)'
);

-- line #25476
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPRAZOLE 40 (Devi Form.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPRAZOLE 40 (Devi Form.)'
);

-- line #25477
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIGENE TOTAL 40 (ABBOTT)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIGENE TOTAL 40 (ABBOTT)'
);

-- line #25478
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIPENT 40 (Divine Life)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIPENT 40 (Divine Life)'
);

-- line #25479
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLPAN-40 40 (DOLPHIN PH.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLPAN-40 40 (DOLPHIN PH.)'
);

-- line #25480
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DONAZOLE 40 (Medoz Ph.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DONAZOLE 40 (Medoz Ph.)'
);

-- line #25481
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DRICID 40 (Badrivas)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg(SOD.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DRICID 40 (Badrivas)'
);

-- line #25482
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40', u'strength_2': u'', u'substance': u'Pantoprazole', u'always_empty': u'', u'form': u'', u'brand': u'ERACID IV', u'strength_3': u'', u'company': u'Svizera', u'unit': u'mg'}

-- line #25483
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERACID 20 (Svizera)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERACID 20 (Svizera)'
);

-- line #25484
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERACID 40 (Svizera)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERACID 40 (Svizera)'
);

-- line #25485
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Pantoprazole', u'always_empty': u'', u'form': u'', u'brand': u'ESTOP IV', u'strength_3': u'', u'company': u'Swayam Hc.', u'unit': u''}

-- line #25486
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUTO 40 (Zedip Form.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUTO 40 (Zedip Form.)'
);

-- line #25487
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FISKER 40 (Medicamen)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FISKER 40 (Medicamen)'
);

-- line #25488
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOZOLE 40 (Forgo Ph.)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOZOLE 40 (Forgo Ph.)'
);

-- line #25489
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FULPAN 40 (AZINE HC.)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FULPAN 40 (AZINE HC.)'
);

-- line #25490
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FULPAN 40 (Azime Hc.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FULPAN 40 (Azime Hc.)'
);

-- line #25491
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GALOCID 40 (Galpha)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg/V.'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GALOCID 40 (Galpha)'
);

-- line #25492
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GALOCID 40 (Galpha)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GALOCID 40 (Galpha)'
);

-- line #25493
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GERIPAN 40 (GERRYSUN PH.)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GERIPAN 40 (GERRYSUN PH.)'
);

-- line #25494
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40', u'strength_2': u'', u'substance': u'Pantoprazole', u'always_empty': u'', u'form': u'', u'brand': u'GLANPAN IV', u'strength_3': u'', u'company': u'Gland Ph.', u'unit': u'mg'}

-- line #25495
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLOPAN 40 (GLOBELA INC.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLOPAN 40 (GLOBELA INC.)'
);

-- line #25496
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G PAN 40 (Gufic Bio.)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G PAN 40 (Gufic Bio.)'
);

-- line #25497
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIPERPAN 40 (Juggat)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIPERPAN 40 (Juggat)'
);

-- line #25498
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYZOLE-P 40 (Obsurge)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYZOLE-P 40 (Obsurge)'
);

-- line #25499
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INFLAGESIC PLUS 40 (Themis Ph.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INFLAGESIC PLUS 40 (Themis Ph.)'
);

-- line #25500
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INNOTOP 40 (INNOVA LIFESCI.)',
	'PANTOPRAZOle',
	'AMP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INNOTOP 40 (INNOVA LIFESCI.)'
);

-- line #25501
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IPEN-40 40 (Izen Ph.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IPEN-40 40 (Izen Ph.)'
);

-- line #25502
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JOPAN 40 (D.R.John''S)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JOPAN 40 (D.R.John''S)'
);

-- line #25503
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KENTOCID 40 (Cadex Lab)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KENTOCID 40 (Cadex Lab)'
);

-- line #25504
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KENTOCID 40 (Cadex Lab)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KENTOCID 40 (Cadex Lab)'
);

-- line #25505
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAPANTO 40 (CORE GESTRA)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAPANTO 40 (CORE GESTRA)'
);

-- line #25506
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAPANTO 40 (CORE GESTRA)',
	'Pantoprazole',
	'VIAL',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAPANTO 40 (CORE GESTRA)'
);

-- line #25507
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAPENT 40 (Logos)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAPENT 40 (Logos)'
);

-- line #25508
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOK-ACID 40 (Venus Rem.)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOK-ACID 40 (Venus Rem.)'
);

-- line #25509
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOXID 40 (HETERO HC.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOXID 40 (HETERO HC.)'
);

-- line #25510
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUPIPAN 20 (Lupin)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUPIPAN 20 (Lupin)'
);

-- line #25511
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUPIPAN 40 (LUpin)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUPIPAN 40 (LUpin)'
);

-- line #25512
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYPAN 40 (LYKA LABS)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYPAN 40 (LYKA LABS)'
);

-- line #25513
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40', u'strength_2': u'', u'substance': u'Pantoprazole', u'always_empty': u'', u'form': u'', u'brand': u'MATPAN', u'strength_3': u'', u'company': u'MATRIX LIFE', u'unit': u'mg'}

-- line #25514
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOD PAN 40 (MODHIKE)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOD PAN 40 (MODHIKE)'
);

-- line #25515
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'40', u'substance': u'Pantoprazole', u'always_empty': u'', u'form': u'', u'brand': u'MOPANT', u'strength_3': u'', u'company': u'MOVA PH.', u'unit': u'mg'}

-- line #25516
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'M-P Z 40 (Merit Org.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'M-P Z 40 (Merit Org.)'
);

-- line #25517
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEWPAN 40 (Ferring Ph.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEWPAN 40 (Ferring Ph.)'
);

-- line #25518
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEWPAN 40 (Ferring Ph.)',
	'Pantoprazole',
	'VIAL',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEWPAN 40 (Ferring Ph.)'
);

-- line #25519
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEWPEN 40 (Dr.Arvind Shah''S)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEWPEN 40 (Dr.Arvind Shah''S)'
);

-- line #25520
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEXPAN IV 20 (Zuventus)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg(S(-))'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEXPAN IV 20 (Zuventus)'
);

-- line #25521
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEXPAN 20 (Zuventus)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEXPAN 20 (Zuventus)'
);

-- line #25522
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITZOLE 40 (Nitin Ph.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITZOLE 40 (Nitin Ph.)'
);

-- line #25523
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NODYS 40 (Biostrass)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NODYS 40 (Biostrass)'
);

-- line #25524
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40', u'strength_2': u'', u'substance': u'Pantoprazole', u'always_empty': u'', u'form': u'', u'brand': u'NORMOCID IV', u'strength_3': u'', u'company': u'FLAMINGO PH.', u'unit': u'mg'}

-- line #25525
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOSTROM 40 (Mankind)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOSTROM 40 (Mankind)'
);

-- line #25526
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NP-40 40 (NORTECH REM.)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NP-40 40 (NORTECH REM.)'
);

-- line #25527
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NP-40 40 (NORTECH REM.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NP-40 40 (NORTECH REM.)'
);

-- line #25528
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Pantoprazole', u'always_empty': u'', u'form': u'TAB', u'brand': u'NP', u'strength_3': u'', u'company': u'NORTECH REM.', u'unit': u''}

-- line #25529
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NULCER 40 (COXSWAIN HC.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NULCER 40 (COXSWAIN HC.)'
);

-- line #25530
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OD 40 (Hope Life)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OD 40 (Hope Life)'
);

-- line #25531
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMESEL 40 (Elf Biomed)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMESEL 40 (Elf Biomed)'
);

-- line #25532
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORITOP 40 (ORION BIOTECH.)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg(LYMPHOLIZED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORITOP 40 (ORION BIOTECH.)'
);

-- line #25533
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORITOP 40 (ORION BIOTECH.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORITOP 40 (ORION BIOTECH.)'
);

-- line #25534
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSEPAN 40 (ROSE LABS)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSEPAN 40 (ROSE LABS)'
);

-- line #25535
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSHPAN 40 (Oshin Lab)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSHPAN 40 (Oshin Lab)'
);

-- line #25536
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSIPAN-40 40 (ANABIOSIS)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSIPAN-40 40 (ANABIOSIS)'
);

-- line #25537
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'P21 40 (Lupin)',
	'Pantoprazole',
	'INF',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'P21 40 (Lupin)'
);

-- line #25538
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'P2I FAST 40 (Lupin)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'P2I FAST 40 (Lupin)'
);

-- line #25539
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'P2I 40 (Lupin)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'P2I 40 (Lupin)'
);

-- line #25540
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'P-40 40 (Adison Lab)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'P-40 40 (Adison Lab)'
);

-- line #25541
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PACID 40 (PROCURE)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PACID 40 (PROCURE)'
);

-- line #25542
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PALEO 40 (Malody Hc.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PALEO 40 (Malody Hc.)'
);

-- line #25543
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PALIO 40 (Dwd)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PALIO 40 (Dwd)'
);

-- line #25544
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAMEM-40 40 (Anikem Lab.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAMEM-40 40 (Anikem Lab.)'
);

-- line #25545
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40', u'strength_2': u'', u'substance': u'Pantoprazole', u'always_empty': u'', u'form': u'', u'brand': u'PANASTA IV', u'strength_3': u'', u'company': u'ERIS LIFE', u'unit': u'mg'}

-- line #25546
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANASTA 20 (ERIS LIFE)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANASTA 20 (ERIS LIFE)'
);

-- line #25547
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40', u'strength_2': u'', u'substance': u'Pantoprazole', u'always_empty': u'', u'form': u'', u'brand': u'PANBEST IV', u'strength_3': u'', u'company': u'ZOLTIN HC.', u'unit': u'mg'}

-- line #25548
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANBID 40 (Sbeed Hc.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANBID 40 (Sbeed Hc.)'
);

-- line #25549
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANBLOC 40 (TABLETS I.)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANBLOC 40 (TABLETS I.)'
);

-- line #25550
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANBLOC 40 (TABLETS I.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANBLOC 40 (TABLETS I.)'
);

-- line #25551
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANBUFF 40 (Biochem)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANBUFF 40 (Biochem)'
);

-- line #25552
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANCID 40 (Auroma Life)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANCID 40 (Auroma Life)'
);

-- line #25553
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANCYTOP 40 (TOPMAN)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANCYTOP 40 (TOPMAN)'
);

-- line #25554
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANDA 40 (Makbro Hc.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANDA 40 (Makbro Hc.)'
);

-- line #25555
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANDAT 40 (DATLA)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANDAT 40 (DATLA)'
);

-- line #25556
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40', u'strength_2': u'', u'substance': u'Pantoprazole', u'always_empty': u'', u'form': u'', u'brand': u'PANDIFF IV', u'strength_3': u'', u'company': u'Piramal Hc.', u'unit': u'mg'}

-- line #25557
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANDIFF 40 (NPIL)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANDIFF 40 (NPIL)'
);

-- line #25558
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANDOL 40 (Idol Bio.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANDOL 40 (Idol Bio.)'
);

-- line #25559
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANDON 40 (Osper)',
	'Pantoprazole',
	'VIAL',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANDON 40 (Osper)'
);

-- line #25560
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANDO 20 (Integrated)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANDO 20 (Integrated)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANDO 40 (Integrated)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANDO 40 (Integrated)'
);

-- line #25561
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANFAST 40 (Sanat)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANFAST 40 (Sanat)'
);

-- line #25562
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANFAST 40 (Sanat)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANFAST 40 (Sanat)'
);

-- line #25563
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40', u'strength_2': u'', u'substance': u'Pantoprazole', u'always_empty': u'', u'form': u'', u'brand': u'PANFIRST IV', u'strength_3': u'', u'company': u'SINSAN PH.', u'unit': u'mg'}

-- line #25564
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANFIRST 40 (SINSAN PH.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANFIRST 40 (SINSAN PH.)'
);

-- line #25565
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANFREE 40 (MIRAGE PH.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANFREE 40 (MIRAGE PH.)'
);

-- line #25566
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANGARD 40 (STADCHEM)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANGARD 40 (STADCHEM)'
);

-- line #25567
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANGLAN 40 (Gland Ph.)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANGLAN 40 (Gland Ph.)'
);

-- line #25568
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40', u'strength_2': u'', u'substance': u'Pantoprazole', u'always_empty': u'', u'form': u'', u'brand': u'PANGOLD', u'strength_3': u'', u'company': u'Theo Ph.', u'unit': u'mg'}

-- line #25569
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANGY 40 (Indu D.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANGY 40 (Indu D.)'
);

-- line #25570
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANHEAL 40 (MEDHEAL PH.)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANHEAL 40 (MEDHEAL PH.)'
);

-- line #25571
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANICON 40 (NICON)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANICON 40 (NICON)'
);

-- line #25572
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANIDO IV 40 (SHINE PH.)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANIDO IV 40 (SHINE PH.)'
);

-- line #25573
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANIDO 40 (SHINE PH.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANIDO 40 (SHINE PH.)'
);

-- line #25574
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAN 40 (Alkem)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAN 40 (Alkem)'
);

-- line #25575
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAN 40 (ALKEM)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAN 40 (ALKEM)'
);

-- line #25576
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANIV 40 (Alkem)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg(LYOPHILIZED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANIV 40 (Alkem)'
);

-- line #25577
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANKAI 40 (Osper)',
	'Pantoprazole',
	'EC TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANKAI 40 (Osper)'
);

-- line #25578
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANKAI 40 (Osper)',
	'Pantoprazole',
	'VIAL',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANKAI 40 (Osper)'
);

-- line #25579
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANLOC 40 (Mark Rem.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANLOC 40 (Mark Rem.)'
);

-- line #25580
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANMAX 40 (Biomax Bio.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANMAX 40 (Biomax Bio.)'
);

-- line #25581
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANOD 40 (YASHTRA HEALTH)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANOD 40 (YASHTRA HEALTH)'
);

-- line #25582
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANOPAZ 40 (Aglowmed)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANOPAZ 40 (Aglowmed)'
);

-- line #25583
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANOPAZ 40 (Aglowmed)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANOPAZ 40 (Aglowmed)'
);

-- line #25584
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANOR 40 (TRUMAC)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANOR 40 (TRUMAC)'
);

-- line #25585
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANOTROY 20 (Troikaa)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANOTROY 20 (Troikaa)'
);

-- line #25586
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANOTROY 40 (Troikaa)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANOTROY 40 (Troikaa)'
);

-- line #25587
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANPAC 40 (ACTO)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANPAC 40 (ACTO)'
);

-- line #25588
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANPAC 40 (ACTO)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANPAC 40 (ACTO)'
);

-- line #25589
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANPLUS 40 (ALEMBIC)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANPLUS 40 (ALEMBIC)'
);

-- line #25590
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANPLUS 40 (Alembic)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANPLUS 40 (Alembic)'
);

-- line #25591
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANPOT 40 (AKESISS)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANPOT 40 (AKESISS)'
);

-- line #25592
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANPOT 20 (AKESISS)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANPOT 20 (AKESISS)'
);

-- line #25593
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANPOT 40 (AKESISS)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANPOT 40 (AKESISS)'
);

-- line #25594
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANPRA 40 (Shinto Org.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANPRA 40 (Shinto Org.)'
);

-- line #25595
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANPRA 40 (Shinto BIOTEC)',
	'Pantoprazole',
	'VIAL',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANPRA 40 (Shinto BIOTEC)'
);

-- line #25596
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANPRAZ 40 (Synapse)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANPRAZ 40 (Synapse)'
);

-- line #25597
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANPROZOLE 40 (CH.Bhagat)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANPROZOLE 40 (CH.Bhagat)'
);

-- line #25598
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANPURE IV 20 (Emcure)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg(S(-))'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANPURE IV 20 (Emcure)'
);

-- line #25599
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANPURE 20 (Emcure)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg(S-PANTO)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANPURE 20 (Emcure)'
);

-- line #25600
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANROLE 40 (Brawn Lab)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANROLE 40 (Brawn Lab)'
);

-- line #25601
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANROLE 40 (SHRUSTI PH.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANROLE 40 (SHRUSTI PH.)'
);

-- line #25602
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANSAFE 40 (UNI OR.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANSAFE 40 (UNI OR.)'
);

-- line #25603
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANSA 40 (Zuventus)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANSA 40 (Zuventus)'
);

-- line #25604
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANSA 40 (Zuventus)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANSA 40 (Zuventus)'
);

-- line #25605
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANSEC IV 40 (Cipla)',
	'Pantoprazole',
	'VIAL',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANSEC IV 40 (Cipla)'
);

-- line #25606
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANSPED 40 (Torrent)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANSPED 40 (Torrent)'
);

-- line #25607
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANSPEED 20 (Torrent)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg(SOD.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANSPEED 20 (Torrent)'
);

-- line #25608
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANSPEED 40 (Torrent)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg(SOD.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANSPEED 40 (Torrent)'
);

-- line #25609
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANSTA 20 (ERIS LIFE)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANSTA 20 (ERIS LIFE)'
);

-- line #25610
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANSTORM 40 (Novagen Ph.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANSTORM 40 (Novagen Ph.)'
);

-- line #25611
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAN 20 (Alkem)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAN 20 (Alkem)'
);

-- line #25612
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAN 20 (ALKEM)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAN 20 (ALKEM)'
);

-- line #25613
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAN 40 (Alkem)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAN 40 (Alkem)'
);

-- line #25614
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAN 40 (ALKEM)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAN 40 (ALKEM)'
);

-- line #25615
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40', u'strength_2': u'', u'substance': u'Pantoprazole', u'always_empty': u'', u'form': u'', u'brand': u'PANTABIT IV', u'strength_3': u'', u'company': u'Cubit Hc.', u'unit': u'mg'}

-- line #25616
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTABIT 40 (Cubit Hc.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTABIT 40 (Cubit Hc.)'
);

-- line #25617
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTABOL 40 (Meridian)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTABOL 40 (Meridian)'
);

-- line #25618
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTAB 20 (Reliance)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTAB 20 (Reliance)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTAB 40 (Reliance)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTAB 40 (Reliance)'
);

-- line #25619
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTACHEK 40 (Euphoric)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTACHEK 40 (Euphoric)'
);

-- line #25620
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTACID 40 (Patson)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTACID 40 (Patson)'
);

-- line #25621
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTACOD 40 (CODEX DRUGS)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTACOD 40 (CODEX DRUGS)'
);

-- line #25622
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTACT 40 (Active Hc.)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTACT 40 (Active Hc.)'
);

-- line #25623
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTACT 20 (Active Hc.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTACT 20 (Active Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTACT 40 (Active Hc.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTACT 40 (Active Hc.)'
);

-- line #25624
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTADAL 40 (Dallas Ph.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTADAL 40 (Dallas Ph.)'
);

-- line #25625
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTAGARD 40 (Mdc Ph.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTAGARD 40 (Mdc Ph.)'
);

-- line #25626
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTAGON 20 (Piramal Hc.)',
	'Pantoprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTAGON 20 (Piramal Hc.)'
);

-- line #25627
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTAGON 40 (Piramal Hc.)',
	'Pantoprazole',
	'CAP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTAGON 40 (Piramal Hc.)'
);

-- line #25628
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTAGON 40 (Ordain Hc.)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg/V.'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTAGON 40 (Ordain Hc.)'
);

-- line #25629
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTAGON 40 (AUM PH.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTAGON 40 (AUM PH.)'
);

-- line #25630
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTAGON 20 (Ordain Hc.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTAGON 20 (Ordain Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTAGON 40 (Ordain Hc.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTAGON 40 (Ordain Hc.)'
);

-- line #25631
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTAKIND FAST 40 (Mankind)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTAKIND FAST 40 (Mankind)'
);

-- line #25632
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTAKIND 40 (Mankind)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg(+FFS AMP. OF SOD.CHL. 10ML)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTAKIND 40 (Mankind)'
);

-- line #25633
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTAKIND 40 (Mankind)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTAKIND 40 (Mankind)'
);

-- line #25634
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTAN 40 (TITAN HC.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTAN 40 (TITAN HC.)'
);

-- line #25635
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTAQ 40 (Aquila)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTAQ 40 (Aquila)'
);

-- line #25636
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40', u'strength_2': u'', u'substance': u'Pantoprazole', u'always_empty': u'', u'form': u'', u'brand': u'PANTARIN', u'strength_3': u'', u'company': u'ORIAN PH.', u'unit': u'mg'}

-- line #25637
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTAROL 40 (Royal)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTAROL 40 (Royal)'
);

-- line #25638
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTAROL 40 (Royal)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTAROL 40 (Royal)'
);

-- line #25639
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTARON 40 (Vega Lab)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTARON 40 (Vega Lab)'
);

-- line #25640
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Pantoprazole', u'always_empty': u'', u'form': u'TAB', u'brand': u'PANTAR', u'strength_3': u'', u'company': u'R.B.REM.', u'unit': u''}

-- line #25641
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTARUN 40 (JARUN PH.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTARUN 40 (JARUN PH.)'
);

-- line #25642
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40', u'strength_2': u'', u'substance': u'Pantoprazole', u'always_empty': u'', u'form': u'', u'brand': u'PANTASAFE', u'strength_3': u'', u'company': u'SAFE CURE', u'unit': u'mg'}

-- line #25643
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40', u'strength_2': u'', u'substance': u'Pantoprazole', u'always_empty': u'', u'form': u'', u'brand': u'PANTASET IV', u'strength_3': u'', u'company': u'STAUNCH', u'unit': u'mg'}

-- line #25644
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTASET 40 (STAUNCH)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTASET 40 (STAUNCH)'
);

-- line #25645
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTASTIC 40 (Wanbury)',
	'Pantoprazole',
	'CAP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTASTIC 40 (Wanbury)'
);

-- line #25646
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTASTIC IV 40 (Wanbury)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTASTIC IV 40 (Wanbury)'
);

-- line #25647
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTAVIS-IV 40 (AVIS LIFE)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTAVIS-IV 40 (AVIS LIFE)'
);

-- line #25648
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTAZ 40 (Medley)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTAZ 40 (Medley)'
);

-- line #25649
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTECH 40 (PHARMATECH)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTECH 40 (PHARMATECH)'
);

-- line #25650
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTEC 20 (Concept)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTEC 20 (Concept)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTEC 40 (Concept)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTEC 40 (Concept)'
);

-- line #25651
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTEN 40 (TENGEE)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTEN 40 (TENGEE)'
);

-- line #25652
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTER 40 (LUSTRE)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTER 40 (LUSTRE)'
);

-- line #25653
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTEX 40 (Nexus)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTEX 40 (Nexus)'
);

-- line #25654
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTEZ 40 (Atrimed Ph.)',
	'Pantoprazole',
	'CAP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTEZ 40 (Atrimed Ph.)'
);

-- line #25655
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTIAC 40 (Ikon Rem)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTIAC 40 (Ikon Rem)'
);

-- line #25656
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTICA 40 (Indica)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTICA 40 (Indica)'
);

-- line #25657
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTICER 40 (J.P. HC.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTICER 40 (J.P. HC.)'
);

-- line #25658
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTICER 40 (J.P.LIFE)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTICER 40 (J.P.LIFE)'
);

-- line #25659
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTIME 40 (Votary Lab)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTIME 40 (Votary Lab)'
);

-- line #25660
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTIN-FR 40 (GENX)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg(+SOD. BICARB.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTIN-FR 40 (GENX)'
);

-- line #25661
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTIN 20 (GENX)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTIN 20 (GENX)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTIN 40 (GENX)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTIN 40 (GENX)'
);

-- line #25662
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTIN 40 (GENX)',
	'Pantoprazole',
	'VIAL',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTIN 40 (GENX)'
);

-- line #25663
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40', u'strength_2': u'', u'substance': u'Pantoprazole', u'always_empty': u'', u'form': u'', u'brand': u'PANTIUM IV', u'strength_3': u'', u'company': u'Intas', u'unit': u'mg'}

-- line #25664
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTIUM 20 (Intas)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTIUM 20 (Intas)'
);

-- line #25665
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTIUM 40 (Intas)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTIUM 40 (Intas)'
);

-- line #25666
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTOBEER 40 (ABEER PH.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTOBEER 40 (ABEER PH.)'
);

-- line #25667
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTOCAR 40 (Eros Ph.)',
	'Pantoprazole',
	'EC INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTOCAR 40 (Eros Ph.)'
);

-- line #25668
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTOCAR 40 (Eros Ph.)',
	'Pantoprazole',
	'EC TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTOCAR 40 (Eros Ph.)'
);

-- line #25669
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTOCAR 40 (Carsyon)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTOCAR 40 (Carsyon)'
);

-- line #25670
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Pantoprazole', u'always_empty': u'', u'form': u'TAB', u'brand': u'PANTOCA -', u'strength_3': u'', u'company': u'NIVCA', u'unit': u''}

-- line #25671
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTOCID 20 (Sun)',
	'Pantoprazole',
	'EC TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg/40'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTOCID 20 (Sun)'
);

-- line #25672
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTOCID FAST 20 (SUN)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTOCID FAST 20 (SUN)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTOCID FAST 40 (SUN)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTOCID FAST 40 (SUN)'
);

-- line #25673
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Pantoprazole', u'always_empty': u'', u'form': u'INF', u'brand': u'PANTOCID IV', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #25674
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Pantoprazole', u'always_empty': u'', u'form': u'KIT TAB', u'brand': u'PANTOCID', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #25675
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTOCIP 40 (Cipla)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTOCIP 40 (Cipla)'
);

-- line #25676
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTOCON 40 (WELSTAR LS.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTOCON 40 (WELSTAR LS.)'
);

-- line #25677
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTODAC 20 (Zydus Cadila)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg/40'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTODAC 20 (Zydus Cadila)'
);

-- line #25678
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Pantoprazole', u'always_empty': u'', u'form': u'V', u'brand': u'PANTODAC', u'strength_3': u'', u'company': u'Zydus Cadila', u'unit': u''}

-- line #25679
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTOFAM 40 (SIFAM PH.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTOFAM 40 (SIFAM PH.)'
);

-- line #25680
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTOFIN 40 (Finesse Ph.)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTOFIN 40 (Finesse Ph.)'
);

-- line #25681
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTOFIN 40 (QCHECK)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTOFIN 40 (QCHECK)'
);

-- line #25682
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTOFIN 20 (QCHECK)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTOFIN 20 (QCHECK)'
);

-- line #25683
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTOFIN 40 (QCHECK)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTOFIN 40 (QCHECK)'
);

-- line #25684
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTOFIX IV 40 (Bal Ph.)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg(LYOPHILIZED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTOFIX IV 40 (Bal Ph.)'
);

-- line #25685
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTOFIX 20 (Bal Ph.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTOFIX 20 (Bal Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTOFIX 40 (Bal Ph.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTOFIX 40 (Bal Ph.)'
);

-- line #25686
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTOGEM 40 (GENETIC PH.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTOGEM 40 (GENETIC PH.)'
);

-- line #25687
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTO 40 (Sienna Form.)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTO 40 (Sienna Form.)'
);

-- line #25688
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40', u'strength_2': u'', u'substance': u'Pantoprazole', u'always_empty': u'', u'form': u'', u'brand': u'PANTO IV', u'strength_3': u'', u'company': u'Grandix', u'unit': u'mg(ANHYDR.)'}

-- line #25689
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTO IV 40 (SYNER MED.)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg(SOD. CHL.10ML)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTO IV 40 (SYNER MED.)'
);

-- line #25690
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTOJACK 40 (Jackson)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTOJACK 40 (Jackson)'
);

-- line #25691
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTOJACK 40 (Jackson)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTOJACK 40 (Jackson)'
);

-- line #25692
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40', u'strength_2': u'', u'substance': u'Pantoprazole', u'always_empty': u'', u'form': u'', u'brand': u'PANTOK-40', u'strength_3': u'', u'company': u'HALO MEDI.', u'unit': u'mg'}

-- line #25693
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40', u'strength_2': u'', u'substance': u'Pantoprazole', u'always_empty': u'', u'form': u'', u'brand': u'PANTOKAM IV', u'strength_3': u'', u'company': u'KAMSONS PH.', u'unit': u'mg'}

-- line #25694
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40', u'strength_2': u'', u'substance': u'Pantoprazole', u'always_empty': u'', u'form': u'', u'brand': u'PANTOKAM', u'strength_3': u'', u'company': u'KAMSONS PH.', u'unit': u'mg'}

-- line #25695
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTOLAX 40 (Helax Hc.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTOLAX 40 (Helax Hc.)'
);

-- line #25696
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTOLOC 40 (AVINASH)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTOLOC 40 (AVINASH)'
);

-- line #25697
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTOL 40 (Siomond)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTOL 40 (Siomond)'
);

-- line #25698
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTOLUP 20 (Lupin)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTOLUP 20 (Lupin)'
);

-- line #25699
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTOLUP 40 (Lupin)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTOLUP 40 (Lupin)'
);

-- line #25700
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTOMAL 40 (Malcom Ph.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTOMAL 40 (Malcom Ph.)'
);

-- line #25701
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTOMAS 40 (Cosmas Ph.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTOMAS 40 (Cosmas Ph.)'
);

-- line #25702
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40', u'strength_2': u'', u'substance': u'Pantoprazole', u'always_empty': u'', u'form': u'', u'brand': u'PANTOM', u'strength_3': u'', u'company': u'GRANDIX', u'unit': u'mg'}

-- line #25703
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTOMIL 40 (Shaimil)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTOMIL 40 (Shaimil)'
);

-- line #25704
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTOMIL 40 (Shaimil)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTOMIL 40 (Shaimil)'
);

-- line #25705
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTOM 40 (Om Bio.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTOM 40 (Om Bio.)'
);

-- line #25706
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTONEM 40 (NEMI PH.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTONEM 40 (NEMI PH.)'
);

-- line #25707
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTONIS 40 (NEISS)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTONIS 40 (NEISS)'
);

-- line #25708
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTONIS 40 (NEISS)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTONIS 40 (NEISS)'
);

-- line #25709
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTONIX 40 (PHENIX PH.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTONIX 40 (PHENIX PH.)'
);

-- line #25710
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTOPEP 20 (HETERO HC.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTOPEP 20 (HETERO HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTOPEP 40 (HETERO HC.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTOPEP 40 (HETERO HC.)'
);

-- line #25711
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTOP FAST 20 (Aristo)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTOP FAST 20 (Aristo)'
);

-- line #25712
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTOP FAST 40 (Aristo)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTOP FAST 40 (Aristo)'
);

-- line #25713
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTOPIK 40 (Aarpik Ph.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTOPIK 40 (Aarpik Ph.)'
);

-- line #25714
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTOP 40 (Aristo)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg/V.'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTOP 40 (Aristo)'
);

-- line #25715
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTOP IT 40 (Aristo)',
	'Pantoprazole',
	'CAP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTOP IT 40 (Aristo)'
);

-- line #25716
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTOPRIL 40 (Ultramark)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTOPRIL 40 (Ultramark)'
);

-- line #25717
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTOP 20 (Aristo)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTOP 20 (Aristo)'
);

-- line #25718
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTOP 40 (Aristo)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTOP 40 (Aristo)'
);

-- line #25719
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTORIV 40 (Bpl Ph.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTORIV 40 (Bpl Ph.)'
);

-- line #25720
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTOSEC 20 (Cipla)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTOSEC 20 (Cipla)'
);

-- line #25721
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTOSEC 40 (Cipla)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTOSEC 40 (Cipla)'
);

-- line #25722
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTOSIG 40 (SIGNOVA)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTOSIG 40 (SIGNOVA)'
);

-- line #25723
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTOSIG 40 (SIGNOVA)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTOSIG 40 (SIGNOVA)'
);

-- line #25724
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTOSPIN-IV 40 (Cerspin)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTOSPIN-IV 40 (Cerspin)'
);

-- line #25725
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40', u'strength_2': u'', u'substance': u'Pantoprazole', u'always_empty': u'', u'form': u'', u'brand': u'PANTOSYN', u'strength_3': u'', u'company': u'SYNAGE LC.', u'unit': u'mg'}

-- line #25726
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTOTAB 40 (Micro Labs)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTOTAB 40 (Micro Labs)'
);

-- line #25727
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTO 40 (Sienna Form.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTO 40 (Sienna Form.)'
);

-- line #25728
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Pantoprazole', u'always_empty': u'', u'form': u'TAB', u'brand': u'PANTO', u'strength_3': u'', u'company': u'SYNER MED.', u'unit': u''}

-- line #25729
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTOTAB 40 (Micro Nova)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTOTAB 40 (Micro Nova)'
);

-- line #25730
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTOVAR 40 (Zota Hc.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTOVAR 40 (Zota Hc.)'
);

-- line #25731
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40', u'strength_2': u'', u'substance': u'Pantoprazole', u'always_empty': u'', u'form': u'', u'brand': u'PANTOVEL', u'strength_3': u'', u'company': u'Kinedex Hc.', u'unit': u'mg'}

-- line #25732
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTOWELL 40 (Helax Hc.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTOWELL 40 (Helax Hc.)'
);

-- line #25733
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTOWIN 40 (Jaywin)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTOWIN 40 (Jaywin)'
);

-- line #25734
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTOZOLE 40 (PSYCOREM)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTOZOLE 40 (PSYCOREM)'
);

-- line #25735
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTOZOL 40 (Aronex Life)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTOZOL 40 (Aronex Life)'
);

-- line #25736
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTOZOL 40 (Aronex Life)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTOZOL 40 (Aronex Life)'
);

-- line #25737
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTOZ 40 (Theo Ph.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTOZ 40 (Theo Ph.)'
);

-- line #25738
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTRA 40 (NUTRAMEDICA)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTRA 40 (NUTRAMEDICA)'
);

-- line #25739
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTRA 40 (NUTRAMEDICA)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTRA 40 (NUTRAMEDICA)'
);

-- line #25740
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTROZ 40 (Hamax Ph.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTROZ 40 (Hamax Ph.)'
);

-- line #25741
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTROZ 40 (CELON(REVILON))',
	'Pantoprazole',
	'VIAL',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTROZ 40 (CELON(REVILON))'
);

-- line #25742
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTRY 40 (VENSAT)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTRY 40 (VENSAT)'
);

-- line #25743
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTRY 40 (VENSAT)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTRY 40 (VENSAT)'
);

-- line #25744
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTULE 40 (ICON DRUGS)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTULE 40 (ICON DRUGS)'
);

-- line #25745
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANTUS 40 (Zeus Hc.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANTUS 40 (Zeus Hc.)'
);

-- line #25746
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANUM 40 (J.B.Chem.)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANUM 40 (J.B.Chem.)'
);

-- line #25747
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Pantoprazole', u'always_empty': u'', u'form': u'INJ', u'brand': u'PANUM IV', u'strength_3': u'', u'company': u'AUSTER', u'unit': u''}

-- line #25748
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANUM 40 (AUSTER)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANUM 40 (AUSTER)'
);

-- line #25749
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANUM 40 (J.B.Chem.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANUM 40 (J.B.Chem.)'
);

-- line #25750
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'WITH ZINC CAMOSINE', u'strength_2': u'', u'substance': u'Pantoprazole', u'always_empty': u'', u'form': u'CAP', u'brand': u'PANUM-Z', u'strength_3': u'', u'company': u'J.B. CHEM', u'unit': u''}

-- line #25751
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANVISTA 20 (Elder)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANVISTA 20 (Elder)'
);

-- line #25752
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANVISTA 40 (Elder)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANVISTA 40 (Elder)'
);

-- line #25753
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANVO 40 (BAJAJ MEDI.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANVO 40 (BAJAJ MEDI.)'
);

-- line #25754
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANZAC 40 (AGIO PH.)',
	'Pantoprazole',
	'CAP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANZAC 40 (AGIO PH.)'
);

-- line #25755
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANZAC 40 (Aglo)',
	'Pantoprazole',
	'EC TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANZAC 40 (Aglo)'
);

-- line #25756
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50', u'strength_2': u'', u'substance': u'Pantoprazole', u'always_empty': u'', u'form': u'', u'brand': u'PANZEC IV', u'strength_3': u'', u'company': u'HBC LIFESCIENCE', u'unit': u'mg'}

-- line #25757
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANZEC 40 (HBC LIFESCIENCE)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANZEC 40 (HBC LIFESCIENCE)'
);

-- line #25758
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANZEL 40 (Zee Lab)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANZEL 40 (Zee Lab)'
);

-- line #25759
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANZEN 40 (Kaizen Ph.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANZEN 40 (Kaizen Ph.)'
);

-- line #25760
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANZO 40 (Astrum Hc.)',
	'Pantoprazole',
	'CAP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANZO 40 (Astrum Hc.)'
);

-- line #25761
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANZOL 20 (Sain Med.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANZOL 20 (Sain Med.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANZOL 40 (Sain Med.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANZOL 40 (Sain Med.)'
);

-- line #25762
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANZOL 40 (Vantage)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANZOL 40 (Vantage)'
);

-- line #25763
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARIDON 40 (Symbiosis Lab.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARIDON 40 (Symbiosis Lab.)'
);

-- line #25764
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PASURE 20 (Albert D.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PASURE 20 (Albert D.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PASURE 40 (Albert D.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PASURE 40 (Albert D.)'
);

-- line #25765
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAVE IV 40 (BIOMAX BIO.)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAVE IV 40 (BIOMAX BIO.)'
);

-- line #25766
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAVE 40 (BIOMAX BIO.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAVE 40 (BIOMAX BIO.)'
);

-- line #25767
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAZES-40 40 (Dey''S)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAZES-40 40 (Dey''S)'
);

-- line #25768
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PCENT 40 (ASCENT REM.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PCENT 40 (ASCENT REM.)'
);

-- line #25769
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PDZOLE-IV 40 (Pharma Drugs)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PDZOLE-IV 40 (Pharma Drugs)'
);

-- line #25770
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PD-ZOLE 40 (Pharma Drugs)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PD-ZOLE 40 (Pharma Drugs)'
);

-- line #25771
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Pantoprazole', u'always_empty': u'', u'form': u'TAB', u'brand': u'PENKOOL', u'strength_3': u'', u'company': u'RASS HC.', u'unit': u''}

-- line #25772
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENKOOL 40 (RASS HC.)',
	'Pantoprazole',
	'VIAL',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENKOOL 40 (RASS HC.)'
);

-- line #25773
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENSOL 40 (Arvind Lab.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENSOL 40 (Arvind Lab.)'
);

-- line #25774
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENSTAL 40 (Stallion)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENSTAL 40 (Stallion)'
);

-- line #25775
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENSTAL 20 (Stallion)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENSTAL 20 (Stallion)'
);

-- line #25776
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENSTAL 40 (Stallion)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENSTAL 40 (Stallion)'
);

-- line #25777
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENSTAR 20 (Stallion)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENSTAR 20 (Stallion)'
);

-- line #25778
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENTA-40 40 (Intra Lab)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENTA-40 40 (Intra Lab)'
);

-- line #25779
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENTA-40 40 (Intra Lab)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENTA-40 40 (Intra Lab)'
);

-- line #25780
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENTACEL 40 (XCEL LABS)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENTACEL 40 (XCEL LABS)'
);

-- line #25781
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENTACHAR 20 (Charmos Bio.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENTACHAR 20 (Charmos Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENTACHAR 40 (Charmos Bio.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENTACHAR 40 (Charmos Bio.)'
);

-- line #25782
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENTAGO 40 (Runa Ph.)',
	'Pantoprazole',
	'CAP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENTAGO 40 (Runa Ph.)'
);

-- line #25783
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENTAGON 40 (Ind-Swift)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENTAGON 40 (Ind-Swift)'
);

-- line #25784
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENTALINK 40 (Lincoln)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENTALINK 40 (Lincoln)'
);

-- line #25785
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENTALOC 40 (Cadila Ph.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENTALOC 40 (Cadila Ph.)'
);

-- line #25786
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENTAPAR 40 (Vivid Bio.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENTAPAR 40 (Vivid Bio.)'
);

-- line #25787
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'PANTOPRAZOLE', u'always_empty': u'', u'form': u'', u'brand': u'PENTAPURE IV', u'strength_3': u'', u'company': u'STERLING PH.', u'unit': u''}

-- line #25788
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40', u'strength_2': u'', u'substance': u'Pantoprazole', u'always_empty': u'', u'form': u'', u'brand': u'PENTAPURE', u'strength_3': u'', u'company': u'STERLING', u'unit': u'mg'}

-- line #25789
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENTASTAR 40 (Cfl Ph.)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENTASTAR 40 (Cfl Ph.)'
);

-- line #25790
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENTASTAR 20 (Cfl Ph.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENTASTAR 20 (Cfl Ph.)'
);

-- line #25791
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENTASTAR 40 (Cfl Ph.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENTASTAR 40 (Cfl Ph.)'
);

-- line #25792
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENTASTAR 40 (Cfl Ph.)',
	'Pantoprazole',
	'V',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENTASTAR 40 (Cfl Ph.)'
);

-- line #25793
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENTA 40 (ANAND HC.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENTA 40 (ANAND HC.)'
);

-- line #25794
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENTA 40 (Cataliq Lab.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENTA 40 (Cataliq Lab.)'
);

-- line #25795
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENT-AV 40 (Taurus Lab)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg(LYPHYLLIZED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENT-AV 40 (Taurus Lab)'
);

-- line #25796
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENT-AV 40 (Taurus Lab)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENT-AV 40 (Taurus Lab)'
);

-- line #25797
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENTINOZ 40 (INNOWAYZ PH.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENTINOZ 40 (INNOWAYZ PH.)'
);

-- line #25798
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENTISAN 40 (SANCHEZ LAB.)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENTISAN 40 (SANCHEZ LAB.)'
);

-- line #25799
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENTISAN 40 (SANCHEZ LAB.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENTISAN 40 (SANCHEZ LAB.)'
);

-- line #25800
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENTIUM 40 (Intas)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENTIUM 40 (Intas)'
);

-- line #25801
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENTIUM 40 (Intas)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENTIUM 40 (Intas)'
);

-- line #25802
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENTOAT 40 (Atoz Ph.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENTOAT 40 (Atoz Ph.)'
);

-- line #25803
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENTOD 40 (TALENT LAB.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENTOD 40 (TALENT LAB.)'
);

-- line #25804
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENTONA 40 (Sayona)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENTONA 40 (Sayona)'
);

-- line #25805
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENTOPEN 20 (Morepen)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENTOPEN 20 (Morepen)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENTOPEN 40 (Morepen)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENTOPEN 40 (Morepen)'
);

-- line #25806
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENTORID 40 (Biosmith)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENTORID 40 (Biosmith)'
);

-- line #25807
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENTOVAR 40 (Zota Hc.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENTOVAR 40 (Zota Hc.)'
);

-- line #25808
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENTOZED 40 (Zota Ph.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENTOZED 40 (Zota Ph.)'
);

-- line #25809
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40', u'strength_2': u'', u'substance': u'Pantoprazole', u'always_empty': u'', u'form': u'', u'brand': u'PENTRA IV', u'strength_3': u'', u'company': u'Rhombus', u'unit': u'mg'}

-- line #25810
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENTRA 40 (Rhombus)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENTRA 40 (Rhombus)'
);

-- line #25811
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENTS 40 (SHRESHTHA)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENTS 40 (SHRESHTHA)'
);

-- line #25812
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENZOLE 40 (Shalman)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENZOLE 40 (Shalman)'
);

-- line #25813
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENZOTAS 40 (TASMED)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENZOTAS 40 (TASMED)'
);

-- line #25814
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEPCARE 40 (Finecure)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEPCARE 40 (Finecure)'
);

-- line #25815
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEPCET 40 (G.Nine Form.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEPCET 40 (G.Nine Form.)'
);

-- line #25816
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEPCINOVA 40 (Pulse Ph.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEPCINOVA 40 (Pulse Ph.)'
);

-- line #25817
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEPMARK 40 (Unimarck)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg(SOD.SEQUIHYDRT.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEPMARK 40 (Unimarck)'
);

-- line #25818
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEPNIL 40 (Sanify)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEPNIL 40 (Sanify)'
);

-- line #25819
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEPTAC 40 (BARODA)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEPTAC 40 (BARODA)'
);

-- line #25820
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEPTA 40 (Chemo D.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEPTA 40 (Chemo D.)'
);

-- line #25821
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEPTICOOL 20 (Intra(INVISION))',
	'Pantoprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEPTICOOL 20 (Intra(INVISION))'
);

-- line #25822
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEPTICOOL 40 (Intra(INVISION))',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEPTICOOL 40 (Intra(INVISION))'
);

-- line #25823
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEPTICOOL 40 (Intra(INVISION))',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEPTICOOL 40 (Intra(INVISION))'
);

-- line #25824
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERFAME 40 (Dexter Lab)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERFAME 40 (Dexter Lab)'
);

-- line #25825
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40', u'strength_2': u'', u'substance': u'PANtoprazole', u'always_empty': u'', u'form': u'', u'brand': u'PETIOL', u'strength_3': u'', u'company': u'VILBERRY HC.', u'unit': u'mg'}

-- line #25826
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIFCID 40 (Pifer Ph.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIFCID 40 (Pifer Ph.)'
);

-- line #25827
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PINTEL 40 (LITTLE GREAVE)',
	'Pantoprazole',
	'VIAL',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PINTEL 40 (LITTLE GREAVE)'
);

-- line #25828
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40', u'strength_2': u'', u'substance': u'Pantoprazole', u'always_empty': u'', u'form': u'', u'brand': u'PLAZO', u'strength_3': u'', u'company': u'DASTOOR PH.', u'unit': u'mg'}

-- line #25829
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PNX 40 (Healthcare)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PNX 40 (Healthcare)'
);

-- line #25830
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PNX 40 (Health Care)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PNX 40 (Health Care)'
);

-- line #25831
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PNZ 40 (Cachet)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PNZ 40 (Cachet)'
);

-- line #25832
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PNZ 40 (Bantom)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PNZ 40 (Bantom)'
);

-- line #25833
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PNZ 20 (Cachet)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PNZ 20 (Cachet)'
);

-- line #25834
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PNZ 20 (Cachet)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg/40'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PNZ 20 (Cachet)'
);

-- line #25835
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PNZ 40 (Cachet)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PNZ 40 (Cachet)'
);

-- line #25836
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'NA', u'strength_2': u'', u'substance': u'Pantoprazole', u'always_empty': u'', u'form': u'VIAL', u'brand': u'PNZ', u'strength_3': u'', u'company': u'Cachet', u'unit': u''}

-- line #25837
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'P 40 (SHRRISHTI HC.)',
	'Pantoprazole',
	'OD TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'P 40 (SHRRISHTI HC.)'
);

-- line #25838
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POLE 40 (Triton Hc.)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POLE 40 (Triton Hc.)'
);

-- line #25839
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POLE-M 40 (Triton Hc.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POLE-M 40 (Triton Hc.)'
);

-- line #25840
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POL 40 (Malar Hc.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POL 40 (Malar Hc.)'
);

-- line #25841
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PPI 40 (Chemo Bio.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PPI 40 (Chemo Bio.)'
);

-- line #25842
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'P-PPI 40 (Blue Cross)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg(SOD.CHL. AS DILUENT 10ML)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'P-PPI 40 (Blue Cross)'
);

-- line #25843
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'P-PPI 40 (Blue Cross)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'P-PPI 40 (Blue Cross)'
);

-- line #25844
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PPX-40 40 (LEXMARK PH.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PPX-40 40 (LEXMARK PH.)'
);

-- line #25845
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRAIZE 20 (Ipca)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRAIZE 20 (Ipca)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRAIZE 40 (Ipca)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRAIZE 40 (Ipca)'
);

-- line #25846
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRAPER 40 (Ultra Chiron)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRAPER 40 (Ultra Chiron)'
);

-- line #25847
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Pantoprazole', u'always_empty': u'', u'form': u'', u'brand': u'PRAZ-INJ', u'strength_3': u'', u'company': u'ENRICH PH.', u'unit': u''}

-- line #25848
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRAZOCID 20 (Saga Lab)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRAZOCID 20 (Saga Lab)'
);

-- line #25849
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRAZOCID 40 (Saga Lab)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRAZOCID 40 (Saga Lab)'
);

-- line #25850
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRAZOLE-40 40 (AERO LIFE)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRAZOLE-40 40 (AERO LIFE)'
);

-- line #25851
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRAZOSAN 40 (Sanjivani)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRAZOSAN 40 (Sanjivani)'
);

-- line #25852
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRAZO 40 (Astrazeneca)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRAZO 40 (Astrazeneca)'
);

-- line #25853
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRAZO 40 (PERK PH.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRAZO 40 (PERK PH.)'
);

-- line #25854
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRAZO 40 (Sierra)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRAZO 40 (Sierra)'
);

-- line #25855
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRAZOTEL 40 (Comed)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRAZOTEL 40 (Comed)'
);

-- line #25856
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRAZ 40 (ENRICH PH.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRAZ 40 (ENRICH PH.)'
);

-- line #25857
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40', u'strength_2': u'', u'substance': u'Pantoprazole', u'always_empty': u'', u'form': u'', u'brand': u'PREDOM IV', u'strength_3': u'', u'company': u'Bestochem', u'unit': u'mg'}

-- line #25858
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRESTO 40 (Medicorp)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRESTO 40 (Medicorp)'
);

-- line #25859
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRESTO 40 (Medicorp)',
	'PANtoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRESTO 40 (Medicorp)'
);

-- line #25860
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROLOC 40 (Comed)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROLOC 40 (Comed)'
);

-- line #25861
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROMPT 40 (Skymax)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg(ANHYD.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROMPT 40 (Skymax)'
);

-- line #25862
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROPANZ 40 (ICARUS)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROPANZ 40 (ICARUS)'
);

-- line #25863
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROPANZ 40 (ICARUS)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROPANZ 40 (ICARUS)'
);

-- line #25864
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROPLUS 40 (Lexus)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROPLUS 40 (Lexus)'
);

-- line #25865
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROTAP 40 (Prohealth)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROTAP 40 (Prohealth)'
);

-- line #25866
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROTERA FAST 40 (LUPIN)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROTERA FAST 40 (LUPIN)'
);

-- line #25867
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROTOCENT 20 (Crescent Th.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROTOCENT 20 (Crescent Th.)'
);

-- line #25868
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROTOCENT 40 (Crescent Th.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROTOCENT 40 (Crescent Th.)'
);

-- line #25869
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROTOCHEK 40 (Ipca)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg(A: PANTOPRAZOLE SODIUM SESQUIHYDRATE BP EQ TO PANTOPRAZOLE 40'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROTOCHEK 40 (Ipca)'
);

-- line #25870
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROTOCHEK 40 (Ipca)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROTOCHEK 40 (Ipca)'
);

-- line #25871
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROTOCHEK 40 (Ipca)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg (SOD.SEQUIHYDRATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROTOCHEK 40 (Ipca)'
);

-- line #25872
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROTOPAN 20 (EAST WEST)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROTOPAN 20 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROTOPAN 40 (EAST WEST)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROTOPAN 40 (EAST WEST)'
);

-- line #25873
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROTOPAN 40 (EAST WEST)',
	'Pantoprazole',
	'VIAL',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROTOPAN 40 (EAST WEST)'
);

-- line #25874
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PTP-40 40 (NAMAS)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PTP-40 40 (NAMAS)'
);

-- line #25875
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PT-ZOLE 40 (UNITED LIFE)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PT-ZOLE 40 (UNITED LIFE)'
);

-- line #25876
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PTZ 40 (Cerspin Hc.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PTZ 40 (Cerspin Hc.)'
);

-- line #25877
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PULSER 40 (Vivid Bio.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PULSER 40 (Vivid Bio.)'
);

-- line #25878
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'P-ZOLE 40 (Zenon Hc.)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg(SOD.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'P-ZOLE 40 (Zenon Hc.)'
);

-- line #25879
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PZOLE 40 (Graf Lab.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PZOLE 40 (Graf Lab.)'
);

-- line #25880
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'P-ZOLE 40 (Zenon Hc.)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'P-ZOLE 40 (Zenon Hc.)'
);

-- line #25881
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PZ 40 (National)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PZ 40 (National)'
);

-- line #25882
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RECAZOL 40 (UNIMARK REM.)',
	'Pantoprazole',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RECAZOL 40 (UNIMARK REM.)'
);

-- line #25883
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REFNOK 40 (Medizone)',
	'Pantoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REFNOK 40 (Medizone)'
);

-- line #25884
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RETORT 40 (Nimbus Med.)',
	'Pantoprazole',
	'CAP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RETORT 40 (Nimbus Med.)'
);

-- line #25885
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'R PAN 40 (Ranbaxy)',
	'PANtoprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'R PAN 40 (Ranbaxy)'
);

-- line #25886
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Papaverine Hcl.', u'always_empty': u'', u'form': u'VIAL', u'brand': u'PAPARIN', u'strength_3': u'', u'company': u'Troikaa', u'unit': u''}

-- line #25887
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PABATAB 500 (Shalaks)',
	'Para-Aminobenzoic Acid',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PABATAB 500 (Shalaks)'
);

-- line #25888
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARAMINOL 10 (Franco I.)',
	'Para-Aminobenzoic Acid',
	'OINT',
	gm.nullify_empty_string('10')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARAMINOL 10 (Franco I.)'
);

-- line #25889
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'A-125 125 (Adventure)',
	'Paracetamol',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'A-125 125 (Adventure)'
);

-- line #25890
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACETAMOL 250 (TRIDENT PH.)',
	'Paracetamol',
	'DS SUS',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACETAMOL 250 (TRIDENT PH.)'
);

-- line #25891
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADMOL 125 (Ethicare)',
	'Paracetamol',
	'DT/600TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADMOL 125 (Ethicare)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADMOL 650 (Ethicare)',
	'Paracetamol',
	'DT/600TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADMOL 650 (Ethicare)'
);

-- line #25892
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALCOCIN 250 (ALICON PH.)',
	'Paracetamol',
	'SUSP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALCOCIN 250 (ALICON PH.)'
);

-- line #25893
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALCOCIN 500 (ALICON PH.)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALCOCIN 500 (ALICON PH.)'
);

-- line #25894
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALGINA 650 (Geno Ph.)',
	'Paracetamol',
	'SUSP',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALGINA 650 (Geno Ph.)'
);

-- line #25895
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALGINA 125 (Geno Ph.)',
	'Paracetamol',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5 ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALGINA 125 (Geno Ph.)'
);

-- line #25896
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALGINA 500 (Geno Ph.)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALGINA 500 (Geno Ph.)'
);

-- line #25897
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALGINA 650 (Geno Ph.)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALGINA 650 (Geno Ph.)'
);

-- line #25898
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALICE 125 (Ind-Swift)',
	'Paracetamol',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALICE 125 (Ind-Swift)'
);

-- line #25899
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALICE 500 (Ind-Swift)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALICE 500 (Ind-Swift)'
);

-- line #25900
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALLY 10 (GOA FORMU.)',
	'Paracetamol',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALLY 10 (GOA FORMU.)'
);

-- line #25901
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMINOL 150 (Group Ph.)',
	'Paracetamol',
	'DROPS',
	gm.nullify_empty_string('150')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMINOL 150 (Group Ph.)'
);

-- line #25902
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMINOL-HS 650 (Group Ph.)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMINOL-HS 650 (Group Ph.)'
);

-- line #25903
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMINOPHEN 100 (AUSTRALIAN)',
	'Paracetamol',
	'DROPS',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMINOPHEN 100 (AUSTRALIAN)'
);

-- line #25904
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMOL 650 (AMGOAL PH.)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMOL 650 (AMGOAL PH.)'
);

-- line #25905
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANAMOL 125 (Bliss)',
	'Paracetamol',
	'SUPPOSITORIES',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANAMOL 125 (Bliss)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANAMOL 250 (Bliss)',
	'Paracetamol',
	'SUPPOSITORIES',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANAMOL 250 (Bliss)'
);

-- line #25906
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANETOL 1 (Abbott)',
	'PARACETAMOL',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'%W/V INFUSION'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANETOL 1 (Abbott)'
);

-- line #25907
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Paracetamol', u'always_empty': u'', u'form': u'DPS', u'brand': u'APYRIC', u'strength_3': u'', u'company': u'Patson', u'unit': u''}

-- line #25908
-- ignoring line: field [strength_1] not numeric: >>>N.I.<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'250', u'substance': u'Paracetamol', u'always_empty': u'', u'form': u'TAB/SYR', u'brand': u'APYRIC', u'strength_3': u'', u'company': u'Patson', u'unit': u'mg/5ML'}

-- line #25909
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATAMOL-O 650 (Maan)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATAMOL-O 650 (Maan)'
);

-- line #25910
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATAMOL-R 500 (Maan)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATAMOL-R 500 (Maan)'
);

-- line #25911
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATAMOL 250 (Maan)',
	'Paracetamol',
	'SUS',
	gm.nullify_empty_string('250')::numeric,
	'mg/ 5 ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATAMOL 250 (Maan)'
);

-- line #25912
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATEMP 125 (GH PH.)',
	'Paracetamol',
	'DPS',
	gm.nullify_empty_string('125')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATEMP 125 (GH PH.)'
);

-- line #25913
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATEMP 250 (GH PH.)',
	'Paracetamol',
	'SUS',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATEMP 250 (GH PH.)'
);

-- line #25914
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATEMP 650 (GH PH.)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATEMP 650 (GH PH.)'
);

-- line #25915
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BABYGESIC 100 (Meyer Org.)',
	'Paracetamol',
	'DPS',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BABYGESIC 100 (Meyer Org.)'
);

-- line #25916
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BAMBITI 125 (Dey''S)',
	'Paracetamol',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BAMBITI 125 (Dey''S)'
);

-- line #25917
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BEPAMOL 125 (Biological E.)',
	'Paracetamol',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BEPAMOL 125 (Biological E.)'
);

-- line #25918
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BEPAMOL 500 (Biological E.)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BEPAMOL 500 (Biological E.)'
);

-- line #25919
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'ACETAMINOPHEN', u'strength_2': u'', u'substance': u'Paracetamol', u'always_empty': u'', u'form': u'SUS', u'brand': u'BIOPYRIN', u'strength_3': u'', u'company': u'Biochem', u'unit': u''}

-- line #25920
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLUEMOL 125 (BLUE WINGS)',
	'Paracetamol',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLUEMOL 125 (BLUE WINGS)'
);

-- line #25921
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALPOL 150 (Gsk)',
	'Paracetamol',
	'DPS',
	gm.nullify_empty_string('150')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALPOL 150 (Gsk)'
);

-- line #25922
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALPOL 120 (Gsk)',
	'Paracetamol',
	'SUS',
	gm.nullify_empty_string('120')::numeric,
	'mg/5 ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALPOL 120 (Gsk)'
);

-- line #25923
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALPOL 250 (GSK)',
	'Paracetamol',
	'SUSP',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALPOL 250 (GSK)'
);

-- line #25924
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALPOL 500 (Gsk)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALPOL 500 (Gsk)'
);

-- line #25925
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALPOL 650 (Gsk)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALPOL 650 (Gsk)'
);

-- line #25926
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10', u'strength_2': u'', u'substance': u'PARACETAMOL', u'always_empty': u'', u'form': u'', u'brand': u'CALRIDOL', u'strength_3': u'', u'company': u'VENUS REM.', u'unit': u'mg'}

-- line #25927
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANOL 500 (Runa Ph.)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANOL 500 (Runa Ph.)'
);

-- line #25928
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEMOL INGA 125 (Inga)',
	'Paracetamol',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5 ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEMOL INGA 125 (Inga)'
);

-- line #25929
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEMOL INGA 500 (Inga)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEMOL INGA 500 (Inga)'
);

-- line #25930
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CENTAMOL 125 (Centaur)',
	'Paracetamol',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CENTAMOL 125 (Centaur)'
);

-- line #25931
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CENTAMOL 250 (Centaur)',
	'Paracetamol',
	'SUSP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CENTAMOL 250 (Centaur)'
);

-- line #25932
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETA 125 (Medoz Ph.)',
	'Paracetamol',
	'DPS',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETA 125 (Medoz Ph.)'
);

-- line #25933
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Paracetamol', u'always_empty': u'', u'form': u'SUS', u'brand': u'CETAMOL', u'strength_3': u'', u'company': u'Indica', u'unit': u''}

-- line #25934
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETANIL 125 (Dabur Ph.)',
	'Paracetamol',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETANIL 125 (Dabur Ph.)'
);

-- line #25935
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETANIL 500 (Dabur Ph.)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETANIL 500 (Dabur Ph.)'
);

-- line #25936
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETA 1000 (Medoz Ph.)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETA 1000 (Medoz Ph.)'
);

-- line #25937
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETA 650 (Medoz Ph.)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETA 650 (Medoz Ph.)'
);

-- line #25938
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETMAOL 650 (Indica)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETMAOL 650 (Indica)'
);

-- line #25939
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETNOL 100 (GRANDIX)',
	'Paracetamol',
	'DPS',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML (APPROX 20 DPS)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETNOL 100 (GRANDIX)'
);

-- line #25940
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETNOL 250 (GRANDIX)',
	'Paracetamol',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETNOL 250 (GRANDIX)'
);

-- line #25941
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETNOL 250 (GRANDIX)',
	'Paracetamol',
	'SUS',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETNOL 250 (GRANDIX)'
);

-- line #25942
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COFAMOL 125 (Cfl Ph.)',
	'Paracetamol',
	'KT TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COFAMOL 125 (Cfl Ph.)'
);

-- line #25943
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COFAMOL 250 (Cfl Ph.)',
	'Paracetamol',
	'SUS',
	gm.nullify_empty_string('250')::numeric,
	'mg/ 5 ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COFAMOL 250 (Cfl Ph.)'
);

-- line #25944
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COFAMOL 500 (Cfl Ph.)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COFAMOL 500 (Cfl Ph.)'
);

-- line #25945
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COFAMOL 650 (Cfl Ph.)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COFAMOL 650 (Cfl Ph.)'
);

-- line #25946
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COMOXYL 125 (Remedies)',
	'Paracetamol',
	'F. TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg/5 ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COMOXYL 125 (Remedies)'
);

-- line #25947
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COMPAIN 500 (Remedies)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COMPAIN 500 (Remedies)'
);

-- line #25948
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CROCIN 150 (Gsk)',
	'Paracetamol',
	'DPS',
	gm.nullify_empty_string('150')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CROCIN 150 (Gsk)'
);

-- line #25949
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CROCIN 240 (Gsk)',
	'Paracetamol',
	'DS SYR',
	gm.nullify_empty_string('240')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CROCIN 240 (Gsk)'
);

-- line #25950
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CROCIN QUICK 500 (Gsk)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CROCIN QUICK 500 (Gsk)'
);

-- line #25951
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CROCIN 125 (Gsk)',
	'Paracetamol',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5 ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CROCIN 125 (Gsk)'
);

-- line #25952
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CROCIN 1000 (Gsk)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CROCIN 1000 (Gsk)'
);

-- line #25953
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CROCIN 500 (Gsk)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CROCIN 500 (Gsk)'
);

-- line #25954
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CROPARA 125 (SHALAKS)',
	'Paracetamol',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CROPARA 125 (SHALAKS)'
);

-- line #25955
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DCMOL 125 (Dcm Lab)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DCMOL 125 (Dcm Lab)'
);

-- line #25956
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DCMOL 250 (Dcm Lab)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DCMOL 250 (Dcm Lab)'
);

-- line #25957
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DETANIL 125 (Dabur Ph.)',
	'Paracetamol',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DETANIL 125 (Dabur Ph.)'
);

-- line #25958
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DISPAR KID/500 300 (Rekvina)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DISPAR KID/500 300 (Rekvina)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DISPAR KID/500 500 (Rekvina)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DISPAR KID/500 500 (Rekvina)'
);

-- line #25959
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DISPIRIN PARACETAMOL 500 (Reckitt B.)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DISPIRIN PARACETAMOL 500 (Reckitt B.)'
);

-- line #25960
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLIPRANE 125 (Nicholas)',
	'Paracetamol',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLIPRANE 125 (Nicholas)'
);

-- line #25961
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLIPRANE 500 (Nicholas)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLIPRANE 500 (Nicholas)'
);

-- line #25962
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLIZA 650 (Ranbaxy)',
	'PARACETAMOL',
	'ER TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg(ACETAMI.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLIZA 650 (Ranbaxy)'
);

-- line #25963
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLODART 120 (Juggat)',
	'Paracetamol',
	'SUS',
	gm.nullify_empty_string('120')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLODART 120 (Juggat)'
);

-- line #25964
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLO 100 (Micro Labs)',
	'Paracetamol',
	'DPS',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLO 100 (Micro Labs)'
);

-- line #25965
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLOMIN 250 (PHARMIN)',
	'Paracetamol',
	'SUS',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLOMIN 250 (PHARMIN)'
);

-- line #25966
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLOPAR 100 (Micro Labs)',
	'Paracetamol',
	'DPS',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLOPAR 100 (Micro Labs)'
);

-- line #25967
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLOPAR 125 (Micro Labs)',
	'Paracetamol',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLOPAR 125 (Micro Labs)'
);

-- line #25968
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLOPAR 250 (Micro Labs)',
	'Paracetamol',
	'SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLOPAR 250 (Micro Labs)'
);

-- line #25969
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLOPAR 650 (Micro Labs)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLOPAR 650 (Micro Labs)'
);

-- line #25970
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLO 156.25 (Micro Labs)',
	'Paracetamol',
	'SUS',
	gm.nullify_empty_string('156.25')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLO 156.25 (Micro Labs)'
);

-- line #25971
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLO 250 (Micro Labs)',
	'Paracetamol',
	'SUS',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLO 250 (Micro Labs)'
);

-- line #25972
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLO 500 (Micro Labs)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLO 500 (Micro Labs)'
);

-- line #25973
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLO 650 (Micro Labs)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLO 650 (Micro Labs)'
);

-- line #25974
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMBIPERA 250 (UMBILICAL PH.)',
	'Paracetamol',
	'SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMBIPERA 250 (UMBILICAL PH.)'
);

-- line #25975
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500', u'strength_2': u'', u'substance': u'Paracetamol', u'always_empty': u'', u'form': u'', u'brand': u'EPOMOL JAR', u'strength_3': u'', u'company': u'Epoch Ph.', u'unit': u'mg'}

-- line #25976
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUPYRIC 250 (Euphoric)',
	'Paracetamol',
	'KT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUPYRIC 250 (Euphoric)'
);

-- line #25977
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUPYRIC 125 (Euphoric)',
	'Paracetamol',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5 ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUPYRIC 125 (Euphoric)'
);

-- line #25978
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUPYRIC 500 (Euphoric)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUPYRIC 500 (Euphoric)'
);

-- line #25979
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EZEEPARA 125 (Nicholas)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EZEEPARA 125 (Nicholas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EZEEPARA 250 (Nicholas)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EZEEPARA 250 (Nicholas)'
);

-- line #25980
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'PARACETAMOL', u'always_empty': u'', u'form': u'SYRUP', u'brand': u'F DOWN', u'strength_3': u'', u'company': u'SYNER MED.', u'unit': u''}

-- line #25981
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'F-DOWN 650 (SYNER MED.)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'F-DOWN 650 (SYNER MED.)'
);

-- line #25982
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEBEX 125 (Drakt Int.)',
	'Paracetamol',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEBEX 125 (Drakt Int.)'
);

-- line #25983
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEBREX 650 (Indoco Rem.)',
	'Paracetamol',
	'ER TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEBREX 650 (Indoco Rem.)'
);

-- line #25984
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEBREX 250 (Indoco Rem.)',
	'Paracetamol',
	'SUS',
	gm.nullify_empty_string('250')::numeric,
	'mg/5 ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEBREX 250 (Indoco Rem.)'
);

-- line #25985
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEBREX 125 (Indoco Rem.)',
	'Paracetamol',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5 ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEBREX 125 (Indoco Rem.)'
);

-- line #25986
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEBREX 500 (Indoco Rem.)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEBREX 500 (Indoco Rem.)'
);

-- line #25987
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEBREX 650 (Indoco Rem.)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEBREX 650 (Indoco Rem.)'
);

-- line #25988
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEBRIMOL 150 (Serve Ph.)',
	'Paracetamol',
	'DPS',
	gm.nullify_empty_string('150')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEBRIMOL 150 (Serve Ph.)'
);

-- line #25989
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEBRIMOL 125 (Serve Ph.)',
	'Paracetamol',
	'KID TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEBRIMOL 125 (Serve Ph.)'
);

-- line #25990
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEBRIMOL 125 (Serve Ph.)',
	'Paracetamol',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEBRIMOL 125 (Serve Ph.)'
);

-- line #25991
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEBRIMOL 250 (Serve Ph.)',
	'Paracetamol',
	'SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEBRIMOL 250 (Serve Ph.)'
);

-- line #25992
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEBRIMOL 500 (Serve Ph.)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEBRIMOL 500 (Serve Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEBRIMOL 650 (Serve Ph.)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEBRIMOL 650 (Serve Ph.)'
);

-- line #25993
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEBRINIL 150 (Svizera)',
	'Paracetamol',
	'AMP INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEBRINIL 150 (Svizera)'
);

-- line #25994
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEBRINIL 100 (Svizera)',
	'Paracetamol',
	'DPS',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEBRINIL 100 (Svizera)'
);

-- line #25995
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEBRINIL 250 (Svizera)',
	'Paracetamol',
	'SUSP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEBRINIL 250 (Svizera)'
);

-- line #25996
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEBRINIL 125 (Svizera)',
	'Paracetamol',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEBRINIL 125 (Svizera)'
);

-- line #25997
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEBRINIL 650 (Svizera)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEBRINIL 650 (Svizera)'
);

-- line #25998
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEBRINIL 150 (Svizera)',
	'Paracetamol',
	'VIAL',
	gm.nullify_empty_string('150')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEBRINIL 150 (Svizera)'
);

-- line #25999
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FENACE 125 (INVISION)',
	'Paracetamol',
	'SUSP',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FENACE 125 (INVISION)'
);

-- line #26000
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FENACE 500 (INVISION)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'600'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FENACE 500 (INVISION)'
);

-- line #26001
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEPAMOL 650 (VENSAT)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEPAMOL 650 (VENSAT)'
);

-- line #26002
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEPANIL 125 (VERITAZ)',
	'Paracetamol',
	'LIQ',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEPANIL 125 (VERITAZ)'
);

-- line #26003
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEPANIL 250 (VERITAZ)',
	'Paracetamol',
	'LIQ',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEPANIL 250 (VERITAZ)'
);

-- line #26004
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEPANIL 500 (VERITAZ)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEPANIL 500 (VERITAZ)'
);

-- line #26005
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEPANIL 650 (VERITAZ)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEPANIL 650 (VERITAZ)'
);

-- line #26006
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEP 650 (MADHAV BIO.)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEP 650 (MADHAV BIO.)'
);

-- line #26007
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERAMOL 250 (Fairdeal Res.)',
	'Paracetamol',
	'SUS',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERAMOL 250 (Fairdeal Res.)'
);

-- line #26008
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEVAGO 100 (Cipla)',
	'Paracetamol',
	'DPS',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEVAGO 100 (Cipla)'
);

-- line #26009
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEVAGO 250 (Cipla)',
	'Paracetamol',
	'DS SUS',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEVAGO 250 (Cipla)'
);

-- line #26010
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEVAGO 120 (Cipla)',
	'Paracetamol',
	'SUS',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEVAGO 120 (Cipla)'
);

-- line #26011
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEVASTIN 150 (Vasphar)',
	'Paracetamol',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEVASTIN 150 (Vasphar)'
);

-- line #26012
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEVASTIN 125 (TABLETS I.)',
	'Paracetamol',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEVASTIN 125 (TABLETS I.)'
);

-- line #26013
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEVASTIN 500 (TABLETS I.)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEVASTIN 500 (TABLETS I.)'
);

-- line #26014
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEVASTIN 650 (TABLETS I.)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEVASTIN 650 (TABLETS I.)'
);

-- line #26015
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEVEDOT 100 (INVISION(INFALIFE))',
	'Paracetamol',
	'DPS',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEVEDOT 100 (INVISION(INFALIFE))'
);

-- line #26016
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEVEDOT 125 (INVISION(INFALIFE))',
	'Paracetamol',
	'SUSP',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEVEDOT 125 (INVISION(INFALIFE))'
);

-- line #26017
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEVEDOT 250 (INVISION(INFALIFE))',
	'Paracetamol',
	'SUSP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEVEDOT 250 (INVISION(INFALIFE))'
);

-- line #26018
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEVERPOL 500 (BIOGEN PH.)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEVERPOL 500 (BIOGEN PH.)'
);

-- line #26019
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEVINO 125 (Austere)',
	'Paracetamol',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEVINO 125 (Austere)'
);

-- line #26020
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEVRIDOL 650 (LASOR PH.)',
	'Paracetamol',
	'ER TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEVRIDOL 650 (LASOR PH.)'
);

-- line #26021
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEVRIDOL 150 (LASOR PH.)',
	'Paracetamol',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg(BENZYL ALCOHOL 2'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEVRIDOL 150 (LASOR PH.)'
);

-- line #26022
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEVRIDOL-I 1000 (Zuventus)',
	'Paracetamol',
	'V',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEVRIDOL-I 1000 (Zuventus)'
);

-- line #26023
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEVRIDOL 120 (LASOR PH.)',
	'Paracetamol',
	'SUSP',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEVRIDOL 120 (LASOR PH.)'
);

-- line #26024
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEVRIDOL 250 (LASOR PH.)',
	'Paracetamol',
	'SUSP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEVRIDOL 250 (LASOR PH.)'
);

-- line #26025
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEVRIL 650 (MEYER ORG.)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEVRIL 650 (MEYER ORG.)'
);

-- line #26026
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'F-NIL 650 (LAKSUN)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'F-NIL 650 (LAKSUN)'
);

-- line #26027
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FPMOL 650 (FINE BIO-SC.)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FPMOL 650 (FINE BIO-SC.)'
);

-- line #26028
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENMOLE 125 (Cadila Ph.)',
	'Paracetamol',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENMOLE 125 (Cadila Ph.)'
);

-- line #26029
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENMOLE 50 (Cadila Ph.)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENMOLE 50 (Cadila Ph.)'
);

-- line #26030
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRENO 650 (CHEMO HC.)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRENO 650 (CHEMO HC.)'
);

-- line #26031
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HISTACOLD 125 (MINOVA)',
	'Paracetamol',
	'SUSP',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HISTACOLD 125 (MINOVA)'
);

-- line #26032
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYDROX-L 125 (Samson)',
	'Paracetamol',
	'CAP',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYDROX-L 125 (Samson)'
);

-- line #26033
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IFIMOL 125 (Unique)',
	'Paracetamol',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IFIMOL 125 (Unique)'
);

-- line #26034
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IFIMOL 500 (Unique)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IFIMOL 500 (Unique)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IFIMOL 650 (Unique)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IFIMOL 650 (Unique)'
);

-- line #26035
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'60ML', u'strength_2': u'', u'substance': u'PARACETAMOL', u'always_empty': u'', u'form': u'SUSP', u'brand': u'INFADIL', u'strength_3': u'', u'company': u'SHINCE PH.', u'unit': u''}

-- line #26036
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100ML', u'strength_2': u'', u'substance': u'Paracetamol', u'always_empty': u'', u'form': u'', u'brand': u'INFUPAR', u'strength_3': u'', u'company': u'UNIMARK REM.', u'unit': u''}

-- line #26037
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JAGCIN 125 (Jagsonpal)',
	'Paracetamol',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JAGCIN 125 (Jagsonpal)'
);

-- line #26038
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JAGCIN 500 (Jagsonpal)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JAGCIN 500 (Jagsonpal)'
);

-- line #26039
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Paracetamol', u'always_empty': u'', u'form': u'DS SUSP', u'brand': u'JUNIMOL', u'strength_3': u'', u'company': u'Elder', u'unit': u''}

-- line #26040
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JUNIMOL RDS 240 (Elder)',
	'Paracetamol',
	'DS SYR',
	gm.nullify_empty_string('240')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JUNIMOL RDS 240 (Elder)'
);

-- line #26041
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'170', u'strength_2': u'', u'substance': u'Paracetamol', u'always_empty': u'', u'form': u'', u'brand': u'JUNIMOL RDS', u'strength_3': u'', u'company': u'Elder', u'unit': u'mg'}

-- line #26042
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250', u'strength_2': u'', u'substance': u'Paracetamol', u'always_empty': u'', u'form': u'', u'brand': u'JUNIMOL RDS', u'strength_3': u'', u'company': u'Elder', u'unit': u'mg'}

-- line #26043
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'80', u'strength_2': u'', u'substance': u'Paracetamol', u'always_empty': u'', u'form': u'', u'brand': u'JUNIMOL RDS', u'strength_3': u'', u'company': u'Elder', u'unit': u'mg'}

-- line #26044
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JUNIMOL RDS 250 (Elder)',
	'Paracetamol',
	'SUPP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JUNIMOL RDS 250 (Elder)'
);

-- line #26045
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JUNIMOL RDS 120 (Elder)',
	'Paracetamol',
	'SUS',
	gm.nullify_empty_string('120')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JUNIMOL RDS 120 (Elder)'
);

-- line #26046
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JUNIMOL RDS 80 (Elder)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JUNIMOL RDS 80 (Elder)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JUNIMOL RDS 170 (Elder)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('170')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JUNIMOL RDS 170 (Elder)'
);

-- line #26047
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KELVIN 120 (Leben)',
	'Paracetamol',
	'SUS',
	gm.nullify_empty_string('120')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KELVIN 120 (Leben)'
);

-- line #26048
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KELVIN 500 (Leben)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KELVIN 500 (Leben)'
);

-- line #26049
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEMCIN 650 (Synokem)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEMCIN 650 (Synokem)'
);

-- line #26050
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KOPRA 150 (Kosha Lab.)',
	'Paracetamol',
	'DPS',
	gm.nullify_empty_string('150')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KOPRA 150 (Kosha Lab.)'
);

-- line #26051
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KOPRA 125 (Kosha Lab.)',
	'Paracetamol',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KOPRA 125 (Kosha Lab.)'
);

-- line #26052
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KOPRA 160 (Kosha Lab.)',
	'Paracetamol',
	'SUS',
	gm.nullify_empty_string('160')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KOPRA 160 (Kosha Lab.)'
);

-- line #26053
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KOPRA 250 (Kosha Lab.)',
	'Paracetamol',
	'SUS',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KOPRA 250 (Kosha Lab.)'
);

-- line #26054
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KOPRA 500 (Kosha Lab.)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KOPRA 500 (Kosha Lab.)'
);

-- line #26055
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KOPRA 650 (Kosha Lab.)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KOPRA 650 (Kosha Lab.)'
);

-- line #26056
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KROCETAMOL 150 (Nestor)',
	'Paracetamol',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KROCETAMOL 150 (Nestor)'
);

-- line #26057
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANOL 100 (HETERO HC.)',
	'Paracetamol',
	'DPS',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML(ACETAMINO)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANOL 100 (HETERO HC.)'
);

-- line #26058
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANOL 240 (HETERO HC.)',
	'Paracetamol',
	'DS SUS',
	gm.nullify_empty_string('240')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANOL 240 (HETERO HC.)'
);

-- line #26059
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANOL 240 (HETERO HC.)',
	'PARAcetamol',
	'DS SUS',
	gm.nullify_empty_string('240')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANOL 240 (HETERO HC.)'
);

-- line #26060
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANOL 125 (HETERO HC.)',
	'Paracetamol',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANOL 125 (HETERO HC.)'
);

-- line #26061
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANOL 650 (HETERO HC.)',
	'Paracetamol',
	'ER CAPLET',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANOL 650 (HETERO HC.)'
);

-- line #26062
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANOL JR 500 (HETERO HC.)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg(ACETAMINO E.R.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANOL JR 500 (HETERO HC.)'
);

-- line #26063
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANOL 650 (HETERO HC.)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANOL 650 (HETERO HC.)'
);

-- line #26064
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LARKIN 125 (Lark Labs)',
	'Paracetamol',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LARKIN 125 (Lark Labs)'
);

-- line #26065
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LARKIN 500 (Lark Labs)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LARKIN 500 (Lark Labs)'
);

-- line #26066
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LENOL 650 (HETERO HC.)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LENOL 650 (HETERO HC.)'
);

-- line #26067
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LITKING 250 (Bestochem)',
	'Paracetamol',
	'SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LITKING 250 (Bestochem)'
);

-- line #26068
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOTEMP 150 (R.B.)',
	'Paracetamol',
	'DPS',
	gm.nullify_empty_string('150')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOTEMP 150 (R.B.)'
);

-- line #26069
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOTEMP 250 (R.B.)',
	'Paracetamol',
	'SUS',
	gm.nullify_empty_string('250')::numeric,
	'mg/5 ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOTEMP 250 (R.B.)'
);

-- line #26070
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOTEMP 650 (R.B.)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOTEMP 650 (R.B.)'
);

-- line #26071
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUPIPARA 150 (Lupin)',
	'Paracetamol',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUPIPARA 150 (Lupin)'
);

-- line #26072
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUPIPARA 125 (Lupin)',
	'Paracetamol',
	'SUSP',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUPIPARA 125 (Lupin)'
);

-- line #26073
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALIDENS 500 (Nicholas)',
	'Paracetamol',
	'DS SUS',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALIDENS 500 (Nicholas)'
);

-- line #26074
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALIDENS 125 (Nicholas)',
	'Paracetamol',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALIDENS 125 (Nicholas)'
);

-- line #26075
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALIDENS 500 (Nicholas)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALIDENS 500 (Nicholas)'
);

-- line #26076
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALIDENS 650 (Nicholas)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALIDENS 650 (Nicholas)'
);

-- line #26077
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MATMOL 150 (ANIMATE HC.)',
	'PARACetamol',
	'DROPS',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MATMOL 150 (ANIMATE HC.)'
);

-- line #26078
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.125G', u'strength_2': u'', u'substance': u'Paracetamol', u'always_empty': u'', u'form': u'SUS', u'brand': u'MATMOL', u'strength_3': u'', u'company': u'ANIMATE HC.', u'unit': u''}

-- line #26079
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.250G', u'strength_2': u'', u'substance': u'Paracetamol', u'always_empty': u'', u'form': u'SUS', u'brand': u'MATMOL', u'strength_3': u'', u'company': u'ANIMATE HC.', u'unit': u''}

-- line #26080
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDALGIN 125 (Medoz Ph.)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDALGIN 125 (Medoz Ph.)'
);

-- line #26081
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDALGIN 500 (Medoz Ph.)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDALGIN 500 (Medoz Ph.)'
);

-- line #26082
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDOMOL 100 (Medopharm)',
	'Paracetamol',
	'DPS',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDOMOL 100 (Medopharm)'
);

-- line #26083
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Paracetamol', u'always_empty': u'', u'form': u'DS SYR', u'brand': u'MEDOMOL', u'strength_3': u'', u'company': u'Medopharm', u'unit': u''}

-- line #26084
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDOMOL 150 (Medopharm)',
	'Paracetamol',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDOMOL 150 (Medopharm)'
);

-- line #26085
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDOMOL 125 (Medopharm)',
	'Paracetamol',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5 ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDOMOL 125 (Medopharm)'
);

-- line #26086
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDOMOL 250 (Medopharm)',
	'Paracetamol',
	'SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg/5 ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDOMOL 250 (Medopharm)'
);

-- line #26087
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDOMOL 125 (Medopharm)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDOMOL 125 (Medopharm)'
);

-- line #26088
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDOMOL 300 (Medopharm)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDOMOL 300 (Medopharm)'
);

-- line #26089
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDOMOL 500 (Medopharm)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDOMOL 500 (Medopharm)'
);

-- line #26090
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDOMOL 650 (Medopharm)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDOMOL 650 (Medopharm)'
);

-- line #26091
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MERIDOL 650 (Unimarck)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MERIDOL 650 (Unimarck)'
);

-- line #26092
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METACIN 150 (Themis)',
	'Paracetamol',
	'DPS',
	gm.nullify_empty_string('150')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METACIN 150 (Themis)'
);

-- line #26093
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METACIN 150 (Themis Ph.)',
	'Paracetamol',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg(BENZYL ALCOHOL 2'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METACIN 150 (Themis Ph.)'
);

-- line #26094
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.250GM', u'strength_2': u'', u'substance': u'Paracetamol', u'always_empty': u'', u'form': u'SUS', u'brand': u'METACIN SOORSAA', u'strength_3': u'', u'company': u'Themis', u'unit': u''}

-- line #26095
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METACIN 125 (Themis)',
	'Paracetamol',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METACIN 125 (Themis)'
);

-- line #26096
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METACIN 500 (Themis)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METACIN 500 (Themis)'
);

-- line #26097
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METALGIN 125 (Mount M.)',
	'Paracetamol',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5 ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METALGIN 125 (Mount M.)'
);

-- line #26098
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METALGIN 500 (Mount M.)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METALGIN 500 (Mount M.)'
);

-- line #26099
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METAPLUS 650 (Themis)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METAPLUS 650 (Themis)'
);

-- line #26100
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICROMOL-F 650 (Southsourne)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICROMOL-F 650 (Southsourne)'
);

-- line #26101
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICROMOL KID 125 (Southsourne)',
	'Paracetamol',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICROMOL KID 125 (Southsourne)'
);

-- line #26102
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICROMOL-P 300 (Southsourne)',
	'Paracetamol',
	'DT',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICROMOL-P 300 (Southsourne)'
);

-- line #26103
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICROMOL 250 (Southsourne)',
	'Paracetamol',
	'SUS',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICROMOL 250 (Southsourne)'
);

-- line #26104
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICROMOL 500 (Southsourne)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICROMOL 500 (Southsourne)'
);

-- line #26105
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MINO 125 (RHINE BIO.)',
	'Paracetamol',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MINO 125 (RHINE BIO.)'
);

-- line #26106
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MINO 500 (RHINE BIO.)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MINO 500 (RHINE BIO.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MINO 650 (RHINE BIO.)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MINO 650 (RHINE BIO.)'
);

-- line #26107
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOLEX 100 (WYNBURG PH.)',
	'Paracetamol',
	'DROP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOLEX 100 (WYNBURG PH.)'
);

-- line #26108
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOL 150 (Gufic Bio.)',
	'Paracetamol',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOL 150 (Gufic Bio.)'
);

-- line #26109
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOMOL 150 (Neon)',
	'Paracetamol',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOMOL 150 (Neon)'
);

-- line #26110
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOMOL 250 (Neon)',
	'Paracetamol',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOMOL 250 (Neon)'
);

-- line #26111
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NICETAMOL 250 (Dr.Reddy''S)',
	'Paracetamol',
	'SUS',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NICETAMOL 250 (Dr.Reddy''S)'
);

-- line #26112
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMOL 250 (Hema Lab)',
	'Paracetamol',
	'SUSP TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMOL 250 (Hema Lab)'
);

-- line #26113
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMSAID-P 125 (Medley)',
	'Paracetamol',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMSAID-P 125 (Medley)'
);

-- line #26114
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIMSAID-P 250 (Medley)',
	'Paracetamol',
	'SUS',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIMSAID-P 250 (Medley)'
);

-- line #26115
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'N-MOL 100 (Nippon Siy.)',
	'Paracetamol',
	'DPS',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'N-MOL 100 (Nippon Siy.)'
);

-- line #26116
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'N-MOL 250 (Nippon Siy.)',
	'Paracetamol',
	'SUS',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'N-MOL 250 (Nippon Siy.)'
);

-- line #26117
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOFIVA 500 (AGIO PH.)',
	'PARACETAMOL',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOFIVA 500 (AGIO PH.)'
);

-- line #26118
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOFIVA 650 (AGIO PH.)',
	'PARACETAMOL',
	'TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOFIVA 650 (AGIO PH.)'
);

-- line #26119
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'650', u'strength_2': u'', u'substance': u'Paracetamol', u'always_empty': u'', u'form': u'', u'brand': u'OPARA SEMI', u'strength_3': u'', u'company': u'Wallace', u'unit': u'mg'}

-- line #26120
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPARA 1000 (Wallace)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPARA 1000 (Wallace)'
);

-- line #26121
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250', u'strength_2': u'', u'substance': u'Paracetamol', u'always_empty': u'', u'form': u'', u'brand': u'ORANEGEMOL', u'strength_3': u'', u'company': u'Panacea', u'unit': u'mg'}

-- line #26122
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORCIN 150 (Ornate Ph.)',
	'Paracetamol',
	'DROPS',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORCIN 150 (Ornate Ph.)'
);

-- line #26123
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OYUP 125 (UNIKID)',
	'Paracetamol',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OYUP 125 (UNIKID)'
);

-- line #26124
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'P-125/250 125 (Apex Labs.)',
	'Paracetamol',
	'DT',
	gm.nullify_empty_string('125')::numeric,
	'mg/250'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'P-125/250 125 (Apex Labs.)'
);

-- line #26125
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'P-125 125 (Apex Labs.)',
	'Paracetamol',
	'DPS',
	gm.nullify_empty_string('125')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'P-125 125 (Apex Labs.)'
);

-- line #26126
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'P-125 125 (Apex Labs.)',
	'Paracetamol',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5 ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'P-125 125 (Apex Labs.)'
);

-- line #26127
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'P-250 250 (Apex Labs.)',
	'Paracetamol',
	'SUS',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'P-250 250 (Apex Labs.)'
);

-- line #26128
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'P-500/650 500 (Apex Labs.)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'P-500/650 500 (Apex Labs.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'P-500/650 650 (Apex Labs.)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'P-500/650 650 (Apex Labs.)'
);

-- line #26129
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAAR 250 (Baroque)',
	'Paracetamol',
	'SUS',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAAR 250 (Baroque)'
);

-- line #26130
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAAR 650 (Baroque)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAAR 650 (Baroque)'
);

-- line #26131
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PACEET 250 (DEASEEN PH.)',
	'Paracetamol',
	'SUSP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PACEET 250 (DEASEEN PH.)'
);

-- line #26132
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PACIMOL 100 (Ipca)',
	'PARACETAMOL',
	'DROPS',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PACIMOL 100 (Ipca)'
);

-- line #26133
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PACIMOL 250 (Ipca)',
	'Paracetamol',
	'DS SUS',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PACIMOL 250 (Ipca)'
);

-- line #26134
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PACIMOL 125 (Ipca)',
	'Paracetamol',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5 ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PACIMOL 125 (Ipca)'
);

-- line #26135
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PACIMOL 500 (Ipca)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PACIMOL 500 (Ipca)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PACIMOL 650 (Ipca)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PACIMOL 650 (Ipca)'
);

-- line #26136
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PACIMOL 500 (Ipca)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PACIMOL 500 (Ipca)'
);

-- line #26137
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAMOL 1000 (Finecure)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAMOL 1000 (Finecure)'
);

-- line #26138
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAMOL 500 (Finecure)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAMOL 500 (Finecure)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAMOL 650 (Finecure)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAMOL 650 (Finecure)'
);

-- line #26139
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANACT 150 (Dwd)',
	'Paracetamol',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANACT 150 (Dwd)'
);

-- line #26140
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANACT 125 (Dwd)',
	'Paracetamol',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANACT 125 (Dwd)'
);

-- line #26141
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANACT 250 (Dwd)',
	'Paracetamol',
	'SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANACT 250 (Dwd)'
);

-- line #26142
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANACT 500 (Dwd)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANACT 500 (Dwd)'
);

-- line #26143
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANACT 150 (Dwd)',
	'Paracetamol',
	'VIAL',
	gm.nullify_empty_string('150')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANACT 150 (Dwd)'
);

-- line #26144
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANDON 125 (Emil Ph.)',
	'Paracetamol',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANDON 125 (Emil Ph.)'
);

-- line #26145
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANDON 500 (Emil Ph.)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANDON 500 (Emil Ph.)'
);

-- line #26146
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARABEER 650 (ABEER PH.)',
	'PARACETAMOL',
	'TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARABEER 650 (ABEER PH.)'
);

-- line #26147
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARACETAMOL RECTAL 170 (Zydus VACC.)',
	'Paracetamol',
	'SUPP',
	gm.nullify_empty_string('170')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARACETAMOL RECTAL 170 (Zydus VACC.)'
);

-- line #26148
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARACETAMOL RECTAL 80 (Zydus VACC.)',
	'Paracetamol',
	'SUPP',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARACETAMOL RECTAL 80 (Zydus VACC.)'
);

-- line #26149
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARACETANAL 80 (Zydus)',
	'Paracetamol',
	'SUPP',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARACETANAL 80 (Zydus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARACETANAL 170 (Zydus)',
	'Paracetamol',
	'SUPP',
	gm.nullify_empty_string('170')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARACETANAL 170 (Zydus)'
);

-- line #26150
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARACIN 150 (Stadmed)',
	'Paracetamol',
	'DPS',
	gm.nullify_empty_string('150')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARACIN 150 (Stadmed)'
);

-- line #26151
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARACIN 125 (Stadmed)',
	'Paracetamol',
	'KT',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARACIN 125 (Stadmed)'
);

-- line #26152
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARACIN 125 (Stadmed)',
	'Paracetamol',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5 ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARACIN 125 (Stadmed)'
);

-- line #26153
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARACIN 500 (Stadmed)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARACIN 500 (Stadmed)'
);

-- line #26154
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARACIP 500 (Cipla)',
	'Paracetamol',
	'CAPLET',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARACIP 500 (Cipla)'
);

-- line #26155
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARACIP 150 (Cipla)',
	'Paracetamol',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARACIP 150 (Cipla)'
);

-- line #26156
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000', u'strength_2': u'', u'substance': u'Paracetamol', u'always_empty': u'', u'form': u'', u'brand': u'PARACIP IV', u'strength_3': u'', u'company': u'Cipla', u'unit': u'mg'}

-- line #26157
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARACIP RND 500 (Cipla)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARACIP RND 500 (Cipla)'
);

-- line #26158
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARACIP 150 (Cipla)',
	'Paracetamol',
	'SYR',
	gm.nullify_empty_string('150')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARACIP 150 (Cipla)'
);

-- line #26159
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARACIP 500 (Cipla)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARACIP 500 (Cipla)'
);

-- line #26160
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARACIP 650 (Cipla)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARACIP 650 (Cipla)'
);

-- line #26161
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARACRAT 250 (CRATUS)',
	'Paracetamol',
	'SUS',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARACRAT 250 (CRATUS)'
);

-- line #26162
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARACRAT 500 (CRATUS)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARACRAT 500 (CRATUS)'
);

-- line #26163
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000', u'strength_2': u'', u'substance': u'Paracetamol', u'always_empty': u'', u'form': u'', u'brand': u'PARADRIP', u'strength_3': u'', u'company': u'STEADFAST MEDI.', u'unit': u'mg/100ML'}

-- line #26164
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARAFAM 250 (SIFAM PH.)',
	'Paracetamol',
	'SUS',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARAFAM 250 (SIFAM PH.)'
);

-- line #26165
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARAFAST 100 (Cipla)',
	'Paracetamol',
	'DROPS',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARAFAST 100 (Cipla)'
);

-- line #26166
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARAFAST 120 (Cipla)',
	'Paracetamol',
	'SUS',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARAFAST 120 (Cipla)'
);

-- line #26167
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARAFAST 500 (Cipla)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARAFAST 500 (Cipla)'
);

-- line #26168
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARAFEB 125 (Lenit Ph.)',
	'Paracetamol',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARAFEB 125 (Lenit Ph.)'
);

-- line #26169
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARAFIZZ 1000 (Cipla)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARAFIZZ 1000 (Cipla)'
);

-- line #26170
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARAFIZZ 650 (Cipla)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARAFIZZ 650 (Cipla)'
);

-- line #26171
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARAGET 125 (Chemo Ph.)',
	'Paracetamol',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARAGET 125 (Chemo Ph.)'
);

-- line #26172
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARAGLOW 100 (Aglowmed)',
	'Paracetamol',
	'DPS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARAGLOW 100 (Aglowmed)'
);

-- line #26173
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARAGLOW 120 (Aglowmed)',
	'Paracetamol',
	'SUS',
	gm.nullify_empty_string('120')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARAGLOW 120 (Aglowmed)'
);

-- line #26174
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARAGLOW 500 (Aglowmed)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARAGLOW 500 (Aglowmed)'
);

-- line #26175
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARALDIM 250 (Fourrts)',
	'Paracetamol',
	'SUS',
	gm.nullify_empty_string('250')::numeric,
	'mg/5 ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARALDIM 250 (Fourrts)'
);

-- line #26176
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARALIFE 125 (Lifeon)',
	'Paracetamol',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARALIFE 125 (Lifeon)'
);

-- line #26177
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARALIFE 500 (Lifeon)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARALIFE 500 (Lifeon)'
);

-- line #26178
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARAMAX 250 (HBC LIFESCIENCE)',
	'Paracetamol',
	'SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARAMAX 250 (HBC LIFESCIENCE)'
);

-- line #26179
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Paracetamol', u'always_empty': u'', u'form': u'MD TAB', u'brand': u'PARAMOUTH', u'strength_3': u'', u'company': u'SUN', u'unit': u''}

-- line #26180
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARASOL 500 (Intas)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARASOL 500 (Intas)'
);

-- line #26181
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARATOL 500 (Bipl(Radico Lab))',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARATOL 500 (Bipl(Radico Lab))'
);

-- line #26182
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARATOP 650 (Dial Ph.)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARATOP 650 (Dial Ph.)'
);

-- line #26183
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARAVIB 100 (VIBRANT PH.)',
	'Paracetamol',
	'DPS',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARAVIB 100 (VIBRANT PH.)'
);

-- line #26184
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARAVIB 250 (VIBRANT PH.)',
	'Paracetamol',
	'SUS',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARAVIB 250 (VIBRANT PH.)'
);

-- line #26185
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARAVIB 650 (VIBRANT PH.)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARAVIB 650 (VIBRANT PH.)'
);

-- line #26186
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARAXEN 250 (AXYZEN LIFE)',
	'PAracetamol',
	'SUS',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARAXEN 250 (AXYZEN LIFE)'
);

-- line #26187
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARAXEN 650 (AXYZEN LIFE)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARAXEN 650 (AXYZEN LIFE)'
);

-- line #26188
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARAXOL 125 (Perk Ph.)',
	'Paracetamol',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARAXOL 125 (Perk Ph.)'
);

-- line #26189
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARAZET 300 (Goodrich)',
	'Paracetamol',
	'KID TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARAZET 300 (Goodrich)'
);

-- line #26190
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARAZINE 500 (Albert D.)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARAZINE 500 (Albert D.)'
);

-- line #26191
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARIX 250 (Active Hc.)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARIX 250 (Active Hc.)'
);

-- line #26192
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PA 1000 (Lincoln)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PA 1000 (Lincoln)'
);

-- line #26193
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PATMIN 125 (R.B.)',
	'Paracetamol',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PATMIN 125 (R.B.)'
);

-- line #26194
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PATMIN 500 (R.B.)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PATMIN 500 (R.B.)'
);

-- line #26195
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAXIMOL 150 (Indus)',
	'Paracetamol',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAXIMOL 150 (Indus)'
);

-- line #26196
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAXOL 125 (Comed)',
	'Paracetamol',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAXOL 125 (Comed)'
);

-- line #26197
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEDIMOL 120 (NEO)',
	'Paracetamol',
	'SUS',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEDIMOL 120 (NEO)'
);

-- line #26198
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEDIMOL 250 (NEO)',
	'Paracetamol',
	'SUS',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEDIMOL 250 (NEO)'
);

-- line #26199
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEMOL 250 (Charmos Bio.)',
	'Paracetamol',
	'SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEMOL 250 (Charmos Bio.)'
);

-- line #26200
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEMOL 650 (Charmos Bio.)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEMOL 650 (Charmos Bio.)'
);

-- line #26201
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERFALGAN 10 (BRISTOL)',
	'Paracetamol',
	'SOLN',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERFALGAN 10 (BRISTOL)'
);

-- line #26202
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PFC 150 (Alde Medi.)',
	'Paracetamol',
	'DPS',
	gm.nullify_empty_string('150')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PFC 150 (Alde Medi.)'
);

-- line #26203
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PFC 125 (Alde Medi.)',
	'Paracetamol',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PFC 125 (Alde Medi.)'
);

-- line #26204
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PF 150 (Candor Bio.)',
	'Paracetamol',
	'DPS',
	gm.nullify_empty_string('150')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PF 150 (Candor Bio.)'
);

-- line #26205
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIDIMOL 10 (Parenteral)',
	'PARACETAMOL',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIDIMOL 10 (Parenteral)'
);

-- line #26206
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIDIMOL 650 (Parenteral)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIDIMOL 650 (Parenteral)'
);

-- line #26207
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLUSMOL 150 (PLUS INDIA)',
	'Paracetamol',
	'AMP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLUSMOL 150 (PLUS INDIA)'
);

-- line #26208
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLUSMOL 650 (PLUS INDIA)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLUSMOL 650 (PLUS INDIA)'
);

-- line #26209
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POLO 250 (LUSTRE)',
	'Paracetamol',
	'SUS',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POLO 250 (LUSTRE)'
);

-- line #26210
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POLO 500 (LUSTRE)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POLO 500 (LUSTRE)'
);

-- line #26211
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POLO 650 (LUSTRE)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POLO 650 (LUSTRE)'
);

-- line #26212
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIMOSUL 125 (UNISEARCH HC.)',
	'Paracetamol',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIMOSUL 125 (UNISEARCH HC.)'
);

-- line #26213
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIMOSUL 500 (UNISEARCH HC.)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIMOSUL 500 (UNISEARCH HC.)'
);

-- line #26214
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIMOSUL 650 (UNISEARCH HC.)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIMOSUL 650 (UNISEARCH HC.)'
);

-- line #26215
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRODOL 240 (Radicura)',
	'Paracetamol',
	'DS SUSP',
	gm.nullify_empty_string('240')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRODOL 240 (Radicura)'
);

-- line #26216
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRODOL 125 (Radicura)',
	'Paracetamol',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRODOL 125 (Radicura)'
);

-- line #26217
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRODOL 500 (Radicura)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'600'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRODOL 500 (Radicura)'
);

-- line #26218
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'125', u'strength_2': u'', u'substance': u'Paracetamol', u'always_empty': u'', u'form': u'', u'brand': u'PROPAR SY', u'strength_3': u'', u'company': u'Mars Rem.', u'unit': u'mg'}

-- line #26219
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROPAR 650 (Mars Rem.)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROPAR 650 (Mars Rem.)'
);

-- line #26220
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PR 500 (UNI OR.)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'600'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PR 500 (UNI OR.)'
);

-- line #26221
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PT-650 650 (Votary Lab)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PT-650 650 (Votary Lab)'
);

-- line #26222
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'PARACETAMOL', u'always_empty': u'', u'form': u'INJ', u'brand': u'PYREMOL-IV', u'strength_3': u'', u'company': u'ALEMBIC', u'unit': u''}

-- line #26223
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Paracetamol', u'always_empty': u'', u'form': u'DPS', u'brand': u'PYREX', u'strength_3': u'', u'company': u'SANCHEZ LAB.', u'unit': u''}

-- line #26224
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYREXON 100 (Wockhardt)',
	'Paracetamol',
	'DPS',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYREXON 100 (Wockhardt)'
);

-- line #26225
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYREXON 650 (Wockhardt)',
	'Paracetamol',
	'DT',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYREXON 650 (Wockhardt)'
);

-- line #26226
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYREXON 250 (Wockhardt)',
	'Paracetamol',
	'F. SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYREXON 250 (Wockhardt)'
);

-- line #26227
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYREXON 125 (Wockhardt)',
	'Paracetamol',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYREXON 125 (Wockhardt)'
);

-- line #26228
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYRIGESIC 150 (East India)',
	'Paracetamol',
	'DPS',
	gm.nullify_empty_string('150')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYRIGESIC 150 (East India)'
);

-- line #26229
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYRIGESIC 100 (East India)',
	'PARACETAMOL',
	'DROPS SUSP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYRIGESIC 100 (East India)'
);

-- line #26230
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYRIGESIC 250 (East India)',
	'Paracetamol',
	'DS SUSP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYRIGESIC 250 (East India)'
);

-- line #26231
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYRIGESIC 125 (East India)',
	'Paracetamol',
	'SUSP',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYRIGESIC 125 (East India)'
);

-- line #26232
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYRIGESIC 125 (East India)',
	'Paracetamol',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5 ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYRIGESIC 125 (East India)'
);

-- line #26233
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Paracetamol', u'always_empty': u'', u'form': u'TAB', u'brand': u'PYRIGESIC', u'strength_3': u'', u'company': u'East India', u'unit': u''}

-- line #26234
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYRIGESIC 500 (East India)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYRIGESIC 500 (East India)'
);

-- line #26235
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYRIGESIC 650 (East India)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYRIGESIC 650 (East India)'
);

-- line #26236
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYRIL 250 (Neuron Ph.)',
	'Paracetamol',
	'SUS',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYRIL 250 (Neuron Ph.)'
);

-- line #26237
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYRINIL 125 (Dr.Arvind Shah''S)',
	'Paracetamol',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYRINIL 125 (Dr.Arvind Shah''S)'
);

-- line #26238
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYRITEC 250 (Ikon Rem)',
	'Paracetamol',
	'DS SUS',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYRITEC 250 (Ikon Rem)'
);

-- line #26239
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYRITEC 120 (Ikon Rem)',
	'Paracetamol',
	'SUS',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYRITEC 120 (Ikon Rem)'
);

-- line #26240
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REEMOL 125 (Remedy)',
	'Paracetamol',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REEMOL 125 (Remedy)'
);

-- line #26241
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REEMOL 500 (Remedy)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REEMOL 500 (Remedy)'
);

-- line #26242
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REGAMOL 500 (Bal Ph.)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REGAMOL 500 (Bal Ph.)'
);

-- line #26243
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REGAMOL 650 (Bal Ph.)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('650')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REGAMOL 650 (Bal Ph.)'
);

-- line #26244
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELIPYRIN 300 (Reliance)',
	'Paracetamol',
	'KID TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELIPYRIN 300 (Reliance)'
);

-- line #26245
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RETHARMA PAED 100 (Maneesh)',
	'Paracetamol',
	'DPS',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RETHARMA PAED 100 (Maneesh)'
);

-- line #26246
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RETHERMA 125 (Maneesh)',
	'Paracetamol',
	'SUS',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RETHERMA 125 (Maneesh)'
);

-- line #26247
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RETHERMA 250 (Maneesh)',
	'Paracetamol',
	'SUS',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RETHERMA 250 (Maneesh)'
);

-- line #26248
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RETOL 500 (Olcare)',
	'Paracetamol',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RETOL 500 (Olcare)'
);

-- line #26249
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOVAL-P 40 (Biochem)',
	'PARECOXIB',
	'VIAL',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOVAL-P 40 (Biochem)'
);

-- line #26250
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAMROX 20 (Active Hc.)',
	'PARECOXIB',
	'DT TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAMROX 20 (Active Hc.)'
);

-- line #26251
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAMSUN 40 (LAKSUN)',
	'PARECOXIB',
	'AMP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAMSUN 40 (LAKSUN)'
);

-- line #26252
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAMSUN 20 (LAKSUN)',
	'PARECOXIB',
	'DT TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAMSUN 20 (LAKSUN)'
);

-- line #26253
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40', u'strength_2': u'', u'substance': u'Parecoxib', u'always_empty': u'', u'form': u'', u'brand': u'PAROXIB IV', u'strength_3': u'', u'company': u'Intas', u'unit': u'mg'}

-- line #26254
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRAXIS 40 (Lupin)',
	'Parecoxib',
	'VIAL',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRAXIS 40 (Lupin)'
);

-- line #26255
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REVALDO-P 40 (Zydus Cadila)',
	'Parecoxib',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REVALDO-P 40 (Zydus Cadila)'
);

-- line #26256
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3200 I.U.(HEPARIN SOD.)', u'strength_2': u'', u'substance': u'PARNAPARIN', u'always_empty': u'', u'form': u'INJ', u'brand': u'FLUXUM IU', u'strength_3': u'', u'company': u'U S V', u'unit': u''}

-- line #26257
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'6400 I.U.(HEPARIN SOD.)', u'strength_2': u'', u'substance': u'PARNAPARIN', u'always_empty': u'', u'form': u'INJ', u'brand': u'FLUXUM IU', u'strength_3': u'', u'company': u'U S V', u'unit': u''}

-- line #26258
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPAXIL 12.5 (Alkem)',
	'Paroxetine',
	'CR TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPAXIL 12.5 (Alkem)'
);

-- line #26259
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPAXIL 25 (Alkem)',
	'Paroxetine',
	'CR TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPAXIL 25 (Alkem)'
);

-- line #26260
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPAXIL 37.5 (Alkem)',
	'Paroxetine',
	'CR TAB',
	gm.nullify_empty_string('37.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPAXIL 37.5 (Alkem)'
);

-- line #26261
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPROX 10 (Ind-Swift)',
	'Paroxetine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPROX 10 (Ind-Swift)'
);

-- line #26262
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXITINE PR 10 (PSYCOREM)',
	'Paroxetine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXITINE PR 10 (PSYCOREM)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXITINE PR 20 (PSYCOREM)',
	'Paroxetine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXITINE PR 20 (PSYCOREM)'
);

-- line #26263
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXITINE PR 30 (PSYCOREM)',
	'Paroxetine',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXITINE PR 30 (PSYCOREM)'
);

-- line #26264
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANEX 12.5 (Micro Labs)',
	'Paroxetine',
	'CR TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANEX 12.5 (Micro Labs)'
);

-- line #26265
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANEX 25 (Micro Labs)',
	'Paroxetine',
	'CR TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANEX 25 (Micro Labs)'
);

-- line #26266
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANEX 10 (Synapse)',
	'Paroxetine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANEX 10 (Synapse)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANEX 20 (Synapse)',
	'Paroxetine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANEX 20 (Synapse)'
);

-- line #26267
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARADISE 12.5 (Torrent)',
	'Paroxetine',
	'XR TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARADISE 12.5 (Torrent)'
);

-- line #26268
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARADISE 25 (Torrent)',
	'Paroxetine',
	'XR TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARADISE 25 (Torrent)'
);

-- line #26269
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARADISE 37.5 (Torrent)',
	'Paroxetine',
	'XR TAB',
	gm.nullify_empty_string('37.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARADISE 37.5 (Torrent)'
);

-- line #26270
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARI 12.5 (Ipca)',
	'Paroxetine',
	'CR TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARI 12.5 (Ipca)'
);

-- line #26271
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARI 25 (Ipca)',
	'Paroxetine',
	'CR TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARI 25 (Ipca)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARI 37.5 (Ipca)',
	'Paroxetine',
	'CR TAB',
	gm.nullify_empty_string('37.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARI 37.5 (Ipca)'
);

-- line #26272
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARI 10 (Ipca)',
	'Paroxetine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARI 10 (Ipca)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARI 20 (Ipca)',
	'Paroxetine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARI 20 (Ipca)'
);

-- line #26273
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARI 30 (Ipca)',
	'Paroxetine',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARI 30 (Ipca)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARI 40 (Ipca)',
	'Paroxetine',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARI 40 (Ipca)'
);

-- line #26274
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAROCEN 12.5 (U S V)',
	'Paroxetine',
	'CR',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAROCEN 12.5 (U S V)'
);

-- line #26275
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAROCEN 25 (U S V)',
	'Paroxetine',
	'CR',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAROCEN 25 (U S V)'
);

-- line #26276
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAROCEN 37.5 (U S V)',
	'Paroxetine',
	'CR',
	gm.nullify_empty_string('37.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAROCEN 37.5 (U S V)'
);

-- line #26277
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAROTIN 12.5 (Cipla)',
	'Paroxetine',
	'CR TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAROTIN 12.5 (Cipla)'
);

-- line #26278
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAROTIN 25 (Cipla)',
	'Paroxetine',
	'CR TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAROTIN 25 (Cipla)'
);

-- line #26279
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAROTIN 37.5 (Cipla)',
	'Paroxetine',
	'CR TAB',
	gm.nullify_empty_string('37.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAROTIN 37.5 (Cipla)'
);

-- line #26280
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAROTIN 10 (Cipla)',
	'Paroxetine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAROTIN 10 (Cipla)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAROTIN 20 (Cipla)',
	'Paroxetine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAROTIN 20 (Cipla)'
);

-- line #26281
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAROTIN 30 (Cipla)',
	'Paroxetine',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAROTIN 30 (Cipla)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAROTIN 40 (Cipla)',
	'Paroxetine',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAROTIN 40 (Cipla)'
);

-- line #26282
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAXIDEP 12.5 (Sun)',
	'Paroxetine',
	'CR TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAXIDEP 12.5 (Sun)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAXIDEP 25 (Sun)',
	'Paroxetine',
	'CR TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAXIDEP 25 (Sun)'
);

-- line #26283
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAXIDEP 37.5 (Sun)',
	'Paroxetine',
	'CR TAB',
	gm.nullify_empty_string('37.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAXIDEP 37.5 (Sun)'
);

-- line #26284
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PETIN 12.5 (MOLEKULE)',
	'Paroxetine',
	'CR TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PETIN 12.5 (MOLEKULE)'
);

-- line #26285
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PETIN 25 (MOLEKULE)',
	'Paroxetine',
	'CR TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PETIN 25 (MOLEKULE)'
);

-- line #26286
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PETIN 37.5 (MOLEKULE)',
	'Paroxetine',
	'CR TAB',
	gm.nullify_empty_string('37.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PETIN 37.5 (MOLEKULE)'
);

-- line #26287
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEXEP 12.5 (Intas)',
	'Paroxetine',
	'CR TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEXEP 12.5 (Intas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEXEP 25 (Intas)',
	'Paroxetine',
	'CR TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEXEP 25 (Intas)'
);

-- line #26288
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEXEP 37.5 (Intas)',
	'Paroxetine',
	'CR TAB',
	gm.nullify_empty_string('37.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEXEP 37.5 (Intas)'
);

-- line #26289
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEXEP 10 (Intas)',
	'Paroxetine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEXEP 10 (Intas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEXEP 20 (Intas)',
	'Paroxetine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEXEP 20 (Intas)'
);

-- line #26290
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEXEP 30 (Intas)',
	'Paroxetine',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEXEP 30 (Intas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEXEP 40 (Intas)',
	'Paroxetine',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEXEP 40 (Intas)'
);

-- line #26291
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PXT 10 (D.R.John''S)',
	'Paroxetine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PXT 10 (D.R.John''S)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PXT 20 (D.R.John''S)',
	'Paroxetine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PXT 20 (D.R.John''S)'
);

-- line #26292
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAXIT 10 (Ranbaxy)',
	'Paroxetine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAXIT 10 (Ranbaxy)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAXIT 20 (Ranbaxy)',
	'Paroxetine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAXIT 20 (Ranbaxy)'
);

-- line #26293
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAXIT 30 (Ranbaxy)',
	'Paroxetine',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAXIT 30 (Ranbaxy)'
);

-- line #26294
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAZFLO 500 (Cipla)',
	'PAZUFLOXACIN',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAZFLO 500 (Cipla)'
);

-- line #26295
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAZUBID 500 (Zydus Cad.)',
	'PAZUFLOXACIN',
	'INF',
	gm.nullify_empty_string('500')::numeric,
	'mg/100ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAZUBID 500 (Zydus Cad.)'
);

-- line #26296
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYCLOX 400 (Chemo D.)',
	'Pefloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg(MESY.DIHYDR.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYCLOX 400 (Chemo D.)'
);

-- line #26297
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXAQUIN-P 400 (Themis)',
	'Pefloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXAQUIN-P 400 (Themis)'
);

-- line #26298
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXOL 400 (Olcare)',
	'Pefloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXOL 400 (Olcare)'
);

-- line #26299
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOX-P 400 (Arbro Ph.)',
	'Pefloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOX-P 400 (Arbro Ph.)'
);

-- line #26300
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Pefloxacin', u'always_empty': u'', u'form': u'INF', u'brand': u'IFIPEF', u'strength_3': u'', u'company': u'Unique', u'unit': u''}

-- line #26301
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IFIPEF 400 (Unique)',
	'Pefloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IFIPEF 400 (Unique)'
);

-- line #26302
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEPLOX-400 400 (Medico)',
	'Pefloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEPLOX-400 400 (Medico)'
);

-- line #26303
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEBACT 400 (Nicholas)',
	'Pefloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEBACT 400 (Nicholas)'
);

-- line #26304
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEBID 400 (Indchemie)',
	'Pefloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEBID 400 (Indchemie)'
);

-- line #26305
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PECURE 400 (Novamed)',
	'Pefloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PECURE 400 (Novamed)'
);

-- line #26306
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEFAN 400 (Bombay T.)',
	'Pefloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEFAN 400 (Bombay T.)'
);

-- line #26307
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEFBID 400 (Alembic)',
	'Pefloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEFBID 400 (Alembic)'
);

-- line #26308
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Pefloxacin', u'always_empty': u'', u'form': u'INF', u'brand': u'PEFCIN', u'strength_3': u'', u'company': u'Torrent', u'unit': u''}

-- line #26309
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEFCIN 400 (Torrent)',
	'Pefloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEFCIN 400 (Torrent)'
);

-- line #26310
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEFLOBID 100 (Cadila Ph.)',
	'Pefloxacin',
	'INF',
	gm.nullify_empty_string('100')::numeric,
	'mg/50ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEFLOBID 100 (Cadila Ph.)'
);

-- line #26311
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEFLOBID 400 (Cadila Ph.)',
	'Pefloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEFLOBID 400 (Cadila Ph.)'
);

-- line #26312
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEFOCIN 400 (Pharmacia)',
	'Pefloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEFOCIN 400 (Pharmacia)'
);

-- line #26313
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEFRAN 400 (Biochem)',
	'Pefloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEFRAN 400 (Biochem)'
);

-- line #26314
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PELOX 400 (Wockhardt)',
	'Pefloxacin',
	'INF',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PELOX 400 (Wockhardt)'
);

-- line #26315
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PELOX 200 (Wockhardt)',
	'Pefloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg(MESY.DIHYDR.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PELOX 200 (Wockhardt)'
);

-- line #26316
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PELOX 400 (Wockhardt)',
	'Pefloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg(MESY.DIHYDR.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PELOX 400 (Wockhardt)'
);

-- line #26317
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERFLOX 400 (Dolphin)',
	'Pefloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERFLOX 400 (Dolphin)'
);

-- line #26318
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERTI 400 (Dr.Reddy''S)',
	'Pefloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERTI 400 (Dr.Reddy''S)'
);

-- line #26319
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEZE 400 (Zee Lab)',
	'Pefloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEZE 400 (Zee Lab)'
);

-- line #26320
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Pefloxacin', u'always_empty': u'', u'form': u'INFUSION', u'brand': u'PIFLASYN', u'strength_3': u'', u'company': u'Nicholas', u'unit': u''}

-- line #26321
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIFLASYN 400 (Nicholas)',
	'Pefloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIFLASYN 400 (Nicholas)'
);

-- line #26322
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIF 400 (Unichem)',
	'Pefloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIF 400 (Unichem)'
);

-- line #26323
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLX-400 400 (Aurobindo)',
	'Pefloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLX-400 400 (Aurobindo)'
);

-- line #26324
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROFLOX 0.3 (Protec)',
	'Pefloxacin',
	'EYE DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROFLOX 0.3 (Protec)'
);

-- line #26325
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROFLOX 400 (Protec)',
	'Pefloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROFLOX 400 (Protec)'
);

-- line #26326
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUCIN 400 (Aristo)',
	'Pefloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUCIN 400 (Aristo)'
);

-- line #26327
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'137.144G(ORAL SOL.)', u'strength_2': u'', u'substance': u'PEG 3350 WITH ELECTOLYTE', u'always_empty': u'', u'form': u'SOL', u'brand': u'RAPILAC ORAL', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #26328
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACUGEN 0.3 (Pfizer)',
	'PEGAPTANIB SODIUM',
	'VIAL',
	gm.nullify_empty_string('0.3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACUGEN 0.3 (Pfizer)'
);

-- line #26329
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEGIHEP 120 (Zydus Cadila)',
	'PEGINATERFERON',
	'INJ',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEGIHEP 120 (Zydus Cadila)'
);

-- line #26330
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEGIHEP 50 (Zydus Cadila)',
	'PEGINATERFERON',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEGIHEP 50 (Zydus Cadila)'
);

-- line #26331
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEGIHEP 80 (Zydus Cadila)',
	'PEGINATERFERON',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEGIHEP 80 (Zydus Cadila)'
);

-- line #26332
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'PEGYLATED R-HUMAN GRANULOCYTE STIMULATING FACTOR', u'always_empty': u'', u'form': u'INJ', u'brand': u'PEGFIL', u'strength_3': u'', u'company': u'Natco Ph.', u'unit': u''}

-- line #26333
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALIMTA GM 106.4 (Eli Lilly)',
	'PEMETIEXED',
	'INJ',
	gm.nullify_empty_string('106.4')::numeric,
	'mg (DISODIUM MANNITOL PH. EUR. AS BULKING AGENT'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALIMTA GM 106.4 (Eli Lilly)'
);

-- line #26334
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALIMTA 500 (Eli Lilly)',
	'PEMETIEXED',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg (DISODIUM MANNITOL PH. EUR. AS BULKING AGENT'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALIMTA 500 (Eli Lilly)'
);

-- line #26335
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEMECAD 500 (Cadila)',
	'PEMETREXED',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEMECAD 500 (Cadila)'
);

-- line #26336
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEMECAD 100 (Cadila Ph.)',
	'PEMETREXED',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEMECAD 100 (Cadila Ph.)'
);

-- line #26337
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEMGEM 100 (Dr.Reddy''S)',
	'PEMETREXED',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEMGEM 100 (Dr.Reddy''S)'
);

-- line #26338
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEMGEM 500 (Dr.Reddy''S)',
	'PEMETREXED',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEMGEM 500 (Dr.Reddy''S)'
);

-- line #26339
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEMMET 500 (INTAS BIO.)',
	'PEMETREXED',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEMMET 500 (INTAS BIO.)'
);

-- line #26340
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLUEMET 100 (Piramal Hc.)',
	'PEMETREXED',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLUEMET 100 (Piramal Hc.)'
);

-- line #26341
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLUEMET 500 (Piramal Hc.)',
	'PEMETREXED',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLUEMET 500 (Piramal Hc.)'
);

-- line #26342
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUMAP 20 (Torrent)',
	'Penfluridol',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUMAP 20 (Torrent)'
);

-- line #26343
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUMP 20 (Torrent)',
	'Penfluridol',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUMP 20 (Torrent)'
);

-- line #26344
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200(2LAC U)', u'strength_2': u'', u'substance': u'Penicillin G Pot.', u'always_empty': u'', u'form': u'TAB', u'brand': u'PENCIP', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #26345
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'400(4LAC U)', u'strength_2': u'', u'substance': u'Penicillin G Pot.', u'always_empty': u'', u'form': u'TAB', u'brand': u'PENCIP', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #26346
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'800(8LAC U)', u'strength_2': u'', u'substance': u'Penicillin G Pot.', u'always_empty': u'', u'form': u'TAB', u'brand': u'PENCIP', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #26347
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200(2LAC U)', u'strength_2': u'', u'substance': u'Penicillin G Pot.', u'always_empty': u'', u'form': u'TAB', u'brand': u'PENTIDS', u'strength_3': u'', u'company': u'Nicholas', u'unit': u''}

-- line #26348
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'400(4LAC U)', u'strength_2': u'', u'substance': u'Penicillin G Pot.', u'always_empty': u'', u'form': u'TAB', u'brand': u'PENTIDS', u'strength_3': u'', u'company': u'Nicholas', u'unit': u''}

-- line #26349
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'800(8LAC U)', u'strength_2': u'', u'substance': u'Penicillin G Pot.', u'always_empty': u'', u'form': u'TAB', u'brand': u'PENTIDS', u'strength_3': u'', u'company': u'Nicholas', u'unit': u''}

-- line #26350
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5LAC', u'strength_2': u'10LAC', u'substance': u'Penicillin G Sod.', u'always_empty': u'', u'form': u'INJ', u'brand': u'BENZYL PENICILLIN', u'strength_3': u'', u'company': u'Alembic', u'unit': u''}

-- line #26351
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KAYPEN 125 (Hal)',
	'Penicillin V',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KAYPEN 125 (Hal)'
);

-- line #26352
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KAYPEN 250 (Hal)',
	'Penicillin V',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KAYPEN 250 (Hal)'
);

-- line #26353
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENIVORAL -F 65 (Franco I.)',
	'Penicillin V',
	'TAB',
	gm.nullify_empty_string('65')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENIVORAL -F 65 (Franco I.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENIVORAL -F 130 (Franco I.)',
	'Penicillin V',
	'TAB',
	gm.nullify_empty_string('130')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENIVORAL -F 130 (Franco I.)'
);

-- line #26354
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDILATE 15 (Gsk)',
	'PENTAErythrityl Tetranitrate',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDILATE 15 (Gsk)'
);

-- line #26355
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDILATE 5 (Gsk)',
	'PENTAErythrityl Tetranitrate',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDILATE 5 (Gsk)'
);

-- line #26356
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERITRATE 10 (Warner)',
	'PENTAErythrityl Tetranitrate',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERITRATE 10 (Warner)'
);

-- line #26357
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERITRATE 80 (Warner)',
	'PENTAErythrityl Tetranitrate',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERITRATE 80 (Warner)'
);

-- line #26358
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLOWIN 30 (Brown & B.)',
	'Pentazocine',
	'INJ',
	gm.nullify_empty_string('30')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLOWIN 30 (Brown & B.)'
);

-- line #26359
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORTSTAR 30 (Cadila Ph.)',
	'Pentazocine',
	'INJ',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORTSTAR 30 (Cadila Ph.)'
);

-- line #26360
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORTWIN 30 (Ranbaxy)',
	'Pentazocine',
	'INJ',
	gm.nullify_empty_string('30')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORTWIN 30 (Ranbaxy)'
);

-- line #26361
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORTWIN 25 (Ranbaxy)',
	'Pentazocine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg(HCL.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORTWIN 25 (Ranbaxy)'
);

-- line #26362
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENTAWIN 30 (Biochem)',
	'Pentazocine',
	'INJ',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENTAWIN 30 (Biochem)'
);

-- line #26363
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENTAZOCINE 30 (Biochem)',
	'Pentazocine',
	'INJ',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENTAZOCINE 30 (Biochem)'
);

-- line #26364
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENTAZOCINE 30 (Neon)',
	'Pentazocine',
	'INJ',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENTAZOCINE 30 (Neon)'
);

-- line #26365
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENZYL 30 (Svizera)',
	'Pentazocine',
	'INJ',
	gm.nullify_empty_string('30')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENZYL 30 (Svizera)'
);

-- line #26366
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENZYL 30 (Svizera)',
	'Pentazocine',
	'VIAL',
	gm.nullify_empty_string('30')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENZYL 30 (Svizera)'
);

-- line #26367
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'P-ZOCINE 30 (Csc Ph.)',
	'Pentazocine',
	'INJ',
	gm.nullify_empty_string('30')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'P-ZOCINE 30 (Csc Ph.)'
);

-- line #26368
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIDDOF 30 (Neon)',
	'Pentazocine',
	'INJ',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIDDOF 30 (Neon)'
);

-- line #26369
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERYTAL 400 (Zydus Cadila)',
	'Pentoxifylline',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERYTAL 400 (Zydus Cadila)'
);

-- line #26370
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLEXITAL 20 (Sun)',
	'Pentoxifylline',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLEXITAL 20 (Sun)'
);

-- line #26371
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLEXITAL 400 (Sun)',
	'Pentoxifylline',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLEXITAL 400 (Sun)'
);

-- line #26372
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOWPENT 20 (Abbott)',
	'Pentoxifylline',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOWPENT 20 (Abbott)'
);

-- line #26373
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOWPENT 400 (Abbott)',
	'Pentoxifylline',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOWPENT 400 (Abbott)'
);

-- line #26374
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KINETAL 20 (Protec)',
	'Pentoxifylline',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KINETAL 20 (Protec)'
);

-- line #26375
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KINETAL 400 (Protec)',
	'Pentoxifylline',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KINETAL 400 (Protec)'
);

-- line #26376
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENTOVAS 400 (Lincoln)',
	'Pentoxifylline',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENTOVAS 400 (Lincoln)'
);

-- line #26377
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RB FLEX 20 (Torrent)',
	'Pentoxifylline',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RB FLEX 20 (Torrent)'
);

-- line #26378
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RB FLEX 400 (Torrent)',
	'Pentoxifylline',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RB FLEX 400 (Torrent)'
);

-- line #26379
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ECOMINT 180 (Gsk)',
	'Peppermint Oil',
	'CAP',
	gm.nullify_empty_string('180')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ECOMINT 180 (Gsk)'
);

-- line #26380
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERLIDE 0.05 (Chemech)',
	'PERGOLIDE',
	'TAB',
	gm.nullify_empty_string('0.05')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERLIDE 0.05 (Chemech)'
);

-- line #26381
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONAPE 2 (Lupin)',
	'Perindopril',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONAPE 2 (Lupin)'
);

-- line #26382
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONAPE 4 (Lupin)',
	'Perindopril',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONAPE 4 (Lupin)'
);

-- line #26383
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COVERSYL 2 (Serdia)',
	'Perindopril',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COVERSYL 2 (Serdia)'
);

-- line #26384
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COVERSYL 4 (Serdia)',
	'Perindopril',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COVERSYL 4 (Serdia)'
);

-- line #26385
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COVERSYL 8 (Serdia)',
	'Perindopril',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COVERSYL 8 (Serdia)'
);

-- line #26386
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EVIPER 2 (TORRENT)',
	'Perindopril',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EVIPER 2 (TORRENT)'
);

-- line #26387
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EVIPER 4 (TORRENT)',
	'Perindopril',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EVIPER 4 (TORRENT)'
);

-- line #26388
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERIGARD 2 (Glenmark)',
	'Perindopril',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERIGARD 2 (Glenmark)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERIGARD 4 (Glenmark)',
	'Perindopril',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERIGARD 4 (Glenmark)'
);

-- line #26389
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERIHART 2 (Franco I.)',
	'Perindopril',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERIHART 2 (Franco I.)'
);

-- line #26390
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERIHART 4 (Franco I.)',
	'Perindopril',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERIHART 4 (Franco I.)'
);

-- line #26391
-- ignoring line: field [strength_1] not numeric: >>>5 (SODIUM METHYL PARABEN IP 0.2<<<
-- {u'list_of_values_of_unknown_fields': [u' % W/V)', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5 (SODIUM METHYL PARABEN IP 0.2', u'strength_2': u'', u'substance': u'Permethrin', u'always_empty': u'', u'form': u'LOT', u'brand': u'AL P-THRIN', u'strength_3': u'', u'company': u'ALKEM', u'unit': u'% W/V'}

-- line #26392
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Permethrin', u'always_empty': u'', u'form': u'PM SOAP', u'brand': u'AMRED', u'strength_3': u'', u'company': u'ADVENTUS', u'unit': u''}

-- line #26393
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLEARKIN 5 (Ind-Swift)',
	'Permethrin',
	'CRM',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLEARKIN 5 (Ind-Swift)'
);

-- line #26394
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DERMETHRIN 50 (Galderma)',
	'Permethrin',
	'CRM',
	gm.nullify_empty_string('50')::numeric,
	'mg/G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DERMETHRIN 50 (Galderma)'
);

-- line #26395
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELDERMIS SMITE 5 (Elder)',
	'Permethrin',
	'CRM',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELDERMIS SMITE 5 (Elder)'
);

-- line #26396
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Permethrin', u'always_empty': u'', u'form': u'CRM', u'brand': u'ELICE', u'strength_3': u'', u'company': u'OREVA DARMO.', u'unit': u''}

-- line #26397
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELICE 5 (Zee Lab)',
	'Permethrin',
	'LOT',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELICE 5 (Zee Lab)'
);

-- line #26398
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Permethrin', u'always_empty': u'', u'form': u'SOAP', u'brand': u'ELICE', u'strength_3': u'', u'company': u'OREVA DARMO.', u'unit': u''}

-- line #26399
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GAMA-P 1 (Mahavir Ent.)',
	'Permethrin',
	'SOAP',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GAMA-P 1 (Mahavir Ent.)'
);

-- line #26400
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KERALICE 10 (Fem care)',
	'Permethrin',
	'CRM',
	gm.nullify_empty_string('10')::numeric,
	'mg/GM'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KERALICE 10 (Fem care)'
);

-- line #26401
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MITYSCAB 5 (Fem Care)',
	'Permethrin',
	'CRM',
	gm.nullify_empty_string('5')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MITYSCAB 5 (Fem Care)'
);

-- line #26402
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5', u'strength_2': u'', u'substance': u'Permethrin', u'always_empty': u'', u'form': u'', u'brand': u'NEDEX-5 BAR', u'strength_3': u'', u'company': u'Elder', u'unit': u'%W/W'}

-- line #26403
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5', u'strength_2': u'', u'substance': u'Permethrin', u'always_empty': u'', u'form': u'', u'brand': u'NEDEX BAR', u'strength_3': u'', u'company': u'Elder', u'unit': u'%'}

-- line #26404
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOLICE RINSE 10 (Lark Labs)',
	'Permethrin',
	'CRM',
	gm.nullify_empty_string('10')::numeric,
	'mg/G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOLICE RINSE 10 (Lark Labs)'
);

-- line #26405
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOSCAB 5 (ETHINEXT PHARMA)',
	'Permethrin',
	'LOT',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOSCAB 5 (ETHINEXT PHARMA)'
);

-- line #26406
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLICE 10 (Olcare)',
	'Permethrin',
	'LOT',
	gm.nullify_empty_string('10')::numeric,
	'mg/G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLICE 10 (Olcare)'
);

-- line #26407
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLMITE 50 (Olcare)',
	'Permethrin',
	'CRM',
	gm.nullify_empty_string('50')::numeric,
	'mg/G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLMITE 50 (Olcare)'
);

-- line #26408
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAXIB 5 (Glenmark)',
	'Permethrin',
	'CRM GM',
	gm.nullify_empty_string('5')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAXIB 5 (Glenmark)'
);

-- line #26409
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEDIMITE 5 (Dermocare)',
	'Permethrin',
	'LOT',
	gm.nullify_empty_string('5')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEDIMITE 5 (Dermocare)'
);

-- line #26410
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERIN 10 (PSYCOREM)',
	'Permethrin',
	'CRM',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERIN 10 (PSYCOREM)'
);

-- line #26411
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERIN 50 (PSYCOREM)',
	'Permethrin',
	'CRM',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERIN 50 (PSYCOREM)'
);

-- line #26412
-- ignoring line: field [strength_1] not numeric: >>>75G(WITH NEEM OIL<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75G(WITH NEEM OIL', u'strength_2': u'', u'substance': u'Permethrin', u'always_empty': u'', u'form': u'SOAP', u'brand': u'PERINIX', u'strength_3': u'', u'company': u'AMORB(SIOUX)', u'unit': u'CAMPHOR)'}

-- line #26413
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERIN 5 (PSYCOREM)',
	'Permethrin',
	'LOT',
	gm.nullify_empty_string('5')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERIN 5 (PSYCOREM)'
);

-- line #26414
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERLICE 1 (Galderma)',
	'Permethrin',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERLICE 1 (Galderma)'
);

-- line #26415
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERMARID 5 (Micro Labs)',
	'Permethrin',
	'CRM',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERMARID 5 (Micro Labs)'
);

-- line #26416
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERMARID % 1 (Micro Labs)',
	'Permethrin',
	'LOT',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERMARID % 1 (Micro Labs)'
);

-- line #26417
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'30G', u'strength_2': u'', u'substance': u'Permethrin', u'always_empty': u'', u'form': u'LOT', u'brand': u'PERMARID', u'strength_3': u'', u'company': u'PSYCOREM', u'unit': u''}

-- line #26418
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERMEBIOL 5 (Piramal Hc.)',
	'Permethrin',
	'CRM',
	gm.nullify_empty_string('5')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERMEBIOL 5 (Piramal Hc.)'
);

-- line #26419
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERMED 5 (MED MANOR)',
	'Permethrin',
	'GEL',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERMED 5 (MED MANOR)'
);

-- line #26420
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERMED 5 (MED MANOR)',
	'Permethrin',
	'LOT',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERMED 5 (MED MANOR)'
);

-- line #26421
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.00W', u'strength_2': u'W', u'substance': u'Permethrin', u'always_empty': u'', u'form': u'SOAP', u'brand': u'PERMED', u'strength_3': u'', u'company': u'MED MANOR', u'unit': u''}

-- line #26422
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERMICA 5 (NIVCA)',
	'Permethrin',
	'OINT',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERMICA 5 (NIVCA)'
);

-- line #26423
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Permethrin', u'always_empty': u'', u'form': u'SOAP', u'brand': u'PERMICA', u'strength_3': u'', u'company': u'NIVCA', u'unit': u''}

-- line #26424
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERMIN 5 (Tripada BIO.)',
	'Permethrin',
	'CRM/SOAP',
	gm.nullify_empty_string('5')::numeric,
	'%/1'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERMIN 5 (Tripada BIO.)'
);

-- line #26425
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Permethrin', u'always_empty': u'', u'form': u'SOAP', u'brand': u'PERMINEC', u'strength_3': u'', u'company': u'KENTOSSA PH.', u'unit': u''}

-- line #26426
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERMIN 5 (Tripada BIO.)',
	'Permethrin',
	'LOT',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERMIN 5 (Tripada BIO.)'
);

-- line #26427
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERMISKIN 5 (Intra(INVISION))',
	'Permethrin',
	'CRM',
	gm.nullify_empty_string('5')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERMISKIN 5 (Intra(INVISION))'
);

-- line #26428
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERMISKIN 5 (Intra(INVISION))',
	'Permethrin',
	'LOT',
	gm.nullify_empty_string('5')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERMISKIN 5 (Intra(INVISION))'
);

-- line #26429
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERMISKIN 1 (Intra(INVISION))',
	'Permethrin',
	'SOAP',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERMISKIN 1 (Intra(INVISION))'
);

-- line #26430
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERMITE 5 (Galderma)',
	'Permethrin',
	'CRM',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERMITE 5 (Galderma)'
);

-- line #26431
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERMOM 5 (OMNI LIFE)',
	'Permethrin',
	'LOT',
	gm.nullify_empty_string('5')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERMOM 5 (OMNI LIFE)'
);

-- line #26432
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEROSCAB 5 (LIFESTAR)',
	'Permethrin',
	'CRM',
	gm.nullify_empty_string('5')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEROSCAB 5 (LIFESTAR)'
);

-- line #26433
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEROSCAB 5 (LIFESTAR)',
	'Permethrin',
	'LOT',
	gm.nullify_empty_string('5')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEROSCAB 5 (LIFESTAR)'
);

-- line #26434
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERSURE 50 (Sunways)',
	'Permethrin',
	'CRM',
	gm.nullify_empty_string('50')::numeric,
	'mg/G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERSURE 50 (Sunways)'
);

-- line #26435
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLITE 5 (GLOWDERMA)',
	'Permethrin',
	'CRM',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLITE 5 (GLOWDERMA)'
);

-- line #26436
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'P-SCAB 5 (Mark India)',
	'Permethrin',
	'LOT',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'P-SCAB 5 (Mark India)'
);

-- line #26437
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REMET 50 (KIVI LABS)',
	'Permethrin',
	'CRM',
	gm.nullify_empty_string('50')::numeric,
	'mg/G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REMET 50 (KIVI LABS)'
);

-- line #26438
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PETHIDINE HCL 100 (Haffkine)',
	'Pethidine',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PETHIDINE HCL 100 (Haffkine)'
);

-- line #26439
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PETHIDINE HCL 50 (Haffkine)',
	'Pethidine',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PETHIDINE HCL 50 (Haffkine)'
);

-- line #26440
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PETHIDINE 50 (Neon)',
	'Pethidine',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PETHIDINE 50 (Neon)'
);

-- line #26441
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMYLOFIX 500 (Ochoa)',
	'PHASEOLUS VULGARIS',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMYLOFIX 500 (Ochoa)'
);

-- line #26442
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FETANOR 10 (Samarth)',
	'Phenatolamine Mesylate',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FETANOR 10 (Samarth)'
);

-- line #26443
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYRIDACTIL 500 (Ethnor)',
	'Phenazopyridine',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYRIDACTIL 500 (Ethnor)'
);

-- line #26444
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYRIDIUM 200 (Pfizer)',
	'Phenazopyridine',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYRIDIUM 200 (Pfizer)'
);

-- line #26445
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DBI TD 25 (U S V)',
	'Phenformin',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DBI TD 25 (U S V)'
);

-- line #26446
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DBI-TD 50 (U S V)',
	'Phenformin',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DBI-TD 50 (U S V)'
);

-- line #26447
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DINDEVAN 50 (Biological E.)',
	'Phenindione',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DINDEVAN 50 (Biological E.)'
);

-- line #26448
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALERGEX 22.75 (Jawa Ph.)',
	'Pheniramine Maleate',
	'INJ',
	gm.nullify_empty_string('22.75')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALERGEX 22.75 (Jawa Ph.)'
);

-- line #26449
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVIL 22.75 (Sanofi Aventis)',
	'Pheniramine Maleate',
	'INJ',
	gm.nullify_empty_string('22.75')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVIL 22.75 (Sanofi Aventis)'
);

-- line #26450
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVIL INJ 22.75 (Sanofi Aventis)',
	'Pheniramine Maleate',
	'V',
	gm.nullify_empty_string('22.75')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVIL INJ 22.75 (Sanofi Aventis)'
);

-- line #26451
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVIL 75 (Sanofi Aventis)',
	'Pheniramine Maleate',
	'RETARD DRA(R)',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVIL 75 (Sanofi Aventis)'
);

-- line #26452
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVIL 15 (Sanofi Aventis)',
	'Pheniramine Maleate',
	'SYR',
	gm.nullify_empty_string('15')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVIL 15 (Sanofi Aventis)'
);

-- line #26453
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVIL 25 (Sanofi Aventis)',
	'Pheniramine Maleate',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVIL 25 (Sanofi Aventis)'
);

-- line #26454
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVIL 50 (Sanofi Aventis)',
	'Pheniramine Maleate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVIL 50 (Sanofi Aventis)'
);

-- line #26455
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHENAL 22.75 (Ind-Swift)',
	'Pheniramine Maleate',
	'INJ',
	gm.nullify_empty_string('22.75')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHENAL 22.75 (Ind-Swift)'
);

-- line #26456
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHENCIP 22.75 (Cipla)',
	'Pheniramine Maleate',
	'INJ',
	gm.nullify_empty_string('22.75')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHENCIP 22.75 (Cipla)'
);

-- line #26457
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHENIRAMINE 75 (Sanofi Aventis)',
	'Pheniramine Maleate',
	'RETARD DRAG',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHENIRAMINE 75 (Sanofi Aventis)'
);

-- line #26458
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BARBEE 30 (Ind-Swift)',
	'Phenobarbital',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BARBEE 30 (Ind-Swift)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BARBEE 60 (Ind-Swift)',
	'Phenobarbital',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BARBEE 60 (Ind-Swift)'
);

-- line #26459
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHENETONE 30 (Cipla)',
	'Phenobarbital',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHENETONE 30 (Cipla)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHENETONE 60 (Cipla)',
	'Phenobarbital',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHENETONE 60 (Cipla)'
);

-- line #26460
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BARBITAL 30 (Theo Ph.)',
	'Phenobarbitone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BARBITAL 30 (Theo Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BARBITAL 60 (Theo Ph.)',
	'Phenobarbitone',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BARBITAL 60 (Theo Ph.)'
);

-- line #26461
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BARBIT 60 (Tripada)',
	'Phenobarbitone',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BARBIT 60 (Tripada)'
);

-- line #26462
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMGARD 15 (Medopharm)',
	'Phenobarbitone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMGARD 15 (Medopharm)'
);

-- line #26463
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMGARD 30 (Medopharm)',
	'Phenobarbitone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMGARD 30 (Medopharm)'
);

-- line #26464
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMGARD 60 (Medopharm)',
	'Phenobarbitone',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMGARD 60 (Medopharm)'
);

-- line #26465
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPIBAR 30 (Rkg)',
	'Phenobarbitone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPIBAR 30 (Rkg)'
);

-- line #26466
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPINIL 30 (Inga)',
	'Phenobarbitone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPINIL 30 (Inga)'
);

-- line #26467
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPINIL 60 (Inga)',
	'Phenobarbitone',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPINIL 60 (Inga)'
);

-- line #26468
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPITAN 30 (Reliance)',
	'Phenobarbitone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'60'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPITAN 30 (Reliance)'
);

-- line #26469
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FENOBARB 200 (Samarth)',
	'Phenobarbitone',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FENOBARB 200 (Samarth)'
);

-- line #26470
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FENOBARB 20 (Samarth LIFE)',
	'Phenobarbitone',
	'SYR',
	gm.nullify_empty_string('20')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FENOBARB 20 (Samarth LIFE)'
);

-- line #26471
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FENOBARB 30 (Samarth)',
	'Phenobarbitone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FENOBARB 30 (Samarth)'
);

-- line #26472
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FENOBARB 60 (Samarth)',
	'Phenobarbitone',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FENOBARB 60 (Samarth)'
);

-- line #26473
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G-30/60 30 (Healthgaurd)',
	'Phenobarbitone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G-30/60 30 (Healthgaurd)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G-30/60 60 (Healthgaurd)',
	'Phenobarbitone',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G-30/60 60 (Healthgaurd)'
);

-- line #26474
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GARDENAL 20 (Nicholas)',
	'Phenobarbitone',
	'SYR',
	gm.nullify_empty_string('20')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GARDENAL 20 (Nicholas)'
);

-- line #26475
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GARDENAL 30 (Nicholas)',
	'Phenobarbitone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GARDENAL 30 (Nicholas)'
);

-- line #26476
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GARDENAL 60 (Nicholas)',
	'Phenobarbitone',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GARDENAL 60 (Nicholas)'
);

-- line #26477
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUMINALETTES 15 (Bayer)',
	'Phenobarbitone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUMINALETTES 15 (Bayer)'
);

-- line #26478
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUMINAL 30 (Bayer)',
	'Phenobarbitone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUMINAL 30 (Bayer)'
);

-- line #26479
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEDINAL 20 (Kirti Works)',
	'Phenobarbitone',
	'SYR',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEDINAL 20 (Kirti Works)'
);

-- line #26480
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHENOBARBITONE 200 (Samarth)',
	'Phenobarbitone',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHENOBARBITONE 200 (Samarth)'
);

-- line #26481
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHENOBARBITONE SODIUM 200 (Abbott)',
	'Phenobarbitone',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHENOBARBITONE SODIUM 200 (Abbott)'
);

-- line #26482
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHENOBARB 30 (Intas)',
	'Phenobarbitone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHENOBARB 30 (Intas)'
);

-- line #26483
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHENOBARB 60 (Intas)',
	'Phenobarbitone',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHENOBARB 60 (Intas)'
);

-- line #26484
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JAGLAX 280 (Jagsonpal)',
	'Phenolphthalein',
	'CHEWTAB',
	gm.nullify_empty_string('280')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JAGLAX 280 (Jagsonpal)'
);

-- line #26485
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FENOBEN 50 (CELON(REVILON))',
	'Phenoxybenzamine',
	'VIAL',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FENOBEN 50 (CELON(REVILON))'
);

-- line #26486
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FENOXENE 10 (Samarth)',
	'Phenoxybenzamine',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FENOXENE 10 (Samarth)'
);

-- line #26487
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FENOXENE 50 (Samarth)',
	'Phenoxybenzamine',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FENOXENE 50 (Samarth)'
);

-- line #26488
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FENTANOR 10 (Samarth)',
	'Phentolamine Mesylate',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FENTANOR 10 (Samarth)'
);

-- line #26489
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHENTOSOL 10 (SG PH.)',
	'Phentolamine Mesylate',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHENTOSOL 10 (SG PH.)'
);

-- line #26490
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EFROSYN % 10 (Indus)',
	'Phenylephrine Hcl.',
	'DPS',
	gm.nullify_empty_string('10')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EFROSYN % 10 (Indus)'
);

-- line #26491
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EFROSYN % 5 (Indus)',
	'Phenylephrine Hcl.',
	'DPS',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EFROSYN % 5 (Indus)'
);

-- line #26492
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FENCEL 10 (CELON(REVILON))',
	'Phenylephrine Hcl.',
	'AMP',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FENCEL 10 (CELON(REVILON))'
);

-- line #26493
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FRENIN 10 (Samarth)',
	'Phenylephrine Hcl.',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg/1ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FRENIN 10 (Samarth)'
);

-- line #26494
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEFRISOL 10 (SG PH.)',
	'Phenylephrine Hcl.',
	'AMP',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEFRISOL 10 (SG PH.)'
);

-- line #26495
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10', u'strength_2': u'', u'substance': u'Phenylephrine Hcl.', u'always_empty': u'', u'form': u'', u'brand': u'PHENPRES', u'strength_3': u'', u'company': u'Neon', u'unit': u'mg'}

-- line #26496
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHENSOL-10 10 (SENSES)',
	'Phenylephrine Hcl.',
	'EYE DPS',
	gm.nullify_empty_string('10')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHENSOL-10 10 (SENSES)'
);

-- line #26497
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHENYLEPHRINE HCL 10 (Indiana O.)',
	'Phenylephrine Hcl.',
	'SOL',
	gm.nullify_empty_string('10')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHENYLEPHRINE HCL 10 (Indiana O.)'
);

-- line #26498
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PUPILETTO 10 (Bell Ph.)',
	'Phenylephrine Hcl.',
	'F. DPS',
	gm.nullify_empty_string('10')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PUPILETTO 10 (Bell Ph.)'
);

-- line #26499
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FENTOIN 100 (Sun)',
	'Phenytoin',
	'ER CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FENTOIN 100 (Sun)'
);

-- line #26500
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELETOIN 50 (Intas)',
	'Phenytoin Sodium',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg+PROPYLENE GLYCO 40V/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELETOIN 50 (Intas)'
);

-- line #26501
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELETOIN 100 (Intas)',
	'Phenytoin Sodium',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELETOIN 100 (Intas)'
);

-- line #26502
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELETOIN 300 (Intas)',
	'Phenytoin Sodium',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELETOIN 300 (Intas)'
);

-- line #26503
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-TOCIN 300 (CENTRA(USV))',
	'Phenytoin Sodium',
	'ER',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-TOCIN 300 (CENTRA(USV))'
);

-- line #26504
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-TOIN 100 (CENTRA(USV))',
	'Phenytoin Sodium',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-TOIN 100 (CENTRA(USV))'
);

-- line #26505
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-TOIN 50 (CENTRA(USV))',
	'Phenytoin Sodium',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-TOIN 50 (CENTRA(USV))'
);

-- line #26506
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILANTIN 50 (Pfizer)',
	'Phenytoin Sodium',
	'AMP',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILANTIN 50 (Pfizer)'
);

-- line #26507
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILANTIN 100 (Pfizer)',
	'Phenytoin Sodium',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILANTIN 100 (Pfizer)'
);

-- line #26508
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILANTIN 25 (Pfizer)',
	'Phenytoin Sodium',
	'CAP',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILANTIN 25 (Pfizer)'
);

-- line #26509
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DILANTIN 25 (Pfizer)',
	'Phenytoin Sodium',
	'SUS',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DILANTIN 25 (Pfizer)'
);

-- line #26510
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPICENT 100 (Crescent Th.)',
	'Phenytoin Sodium',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPICENT 100 (Crescent Th.)'
);

-- line #26511
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPICURE 100 (Indilina Ph.)',
	'Phenytoin Sodium',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPICURE 100 (Indilina Ph.)'
);

-- line #26512
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPILEPTIN 100 (Idpl)',
	'Phenytoin Sodium',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPILEPTIN 100 (Idpl)'
);

-- line #26513
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPISOL 100 (Pil)',
	'Phenytoin Sodium',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPISOL 100 (Pil)'
);

-- line #26514
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPITAB 100 (EAST WEST)',
	'Phenytoin Sodium',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPITAB 100 (EAST WEST)'
);

-- line #26515
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPSOD 50 (SHINE PH.)',
	'Phenytoin Sodium',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPSOD 50 (SHINE PH.)'
);

-- line #26516
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPSOD 100 (SHINE PH.)',
	'Phenytoin Sodium',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPSOD 100 (SHINE PH.)'
);

-- line #26517
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPSOLIN 25 (Zydus N.S.)',
	'Phenytoin Sodium',
	'AMP',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPSOLIN 25 (Zydus N.S.)'
);

-- line #26518
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPSOLIN 300 (Zydus N.S.)',
	'Phenytoin Sodium',
	'ER CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPSOLIN 300 (Zydus N.S.)'
);

-- line #26519
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPSOLIN 100 (Zydus N.S.)',
	'Phenytoin Sodium',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPSOLIN 100 (Zydus N.S.)'
);

-- line #26520
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPSOLIN 100 (Zydus N.S.)',
	'Phenytoin Sodium',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPSOLIN 100 (Zydus N.S.)'
);

-- line #26521
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPSOLIN 50 (Zydus N.S.)',
	'Phenytoin Sodium',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPSOLIN 50 (Zydus N.S.)'
);

-- line #26522
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPTOIN 50 (Abbott)',
	'Phenytoin Sodium',
	'AMP',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPTOIN 50 (Abbott)'
);

-- line #26523
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPTOIN 30 (ABBOTT)',
	'Phenytoin Sodium',
	'SUS',
	gm.nullify_empty_string('30')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPTOIN 30 (ABBOTT)'
);

-- line #26524
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPTOIN 100 (ABBOTT)',
	'Phenytoin Sodium',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPTOIN 100 (ABBOTT)'
);

-- line #26525
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPTOIN 50 (ABBOTT)',
	'Phenytoin Sodium',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPTOIN 50 (ABBOTT)'
);

-- line #26526
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESPSOLEP 100 (Tripada Hc.)',
	'Phenytoin Sodium',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESPSOLEP 100 (Tripada Hc.)'
);

-- line #26527
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MTOIN 100 (Medopharm)',
	'Phenytoin Sodium',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MTOIN 100 (Medopharm)'
);

-- line #26528
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MTOIN 25 (Medopharm)',
	'Phenytoin Sodium',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MTOIN 25 (Medopharm)'
);

-- line #26529
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MTOIN 50 (Medopharm)',
	'Phenytoin Sodium',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MTOIN 50 (Medopharm)'
);

-- line #26530
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUTOIN 100 (MINOVA(PSYCHONOVA))',
	'Phenytoin Sodium',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUTOIN 100 (MINOVA(PSYCHONOVA))'
);

-- line #26531
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHALIN 50 (MOLEKULE)',
	'Phenytoin Sodium',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHALIN 50 (MOLEKULE)'
);

-- line #26532
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHALIN 100 (MOLEKULE)',
	'Phenytoin Sodium',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHALIN 100 (MOLEKULE)'
);

-- line #26533
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHALIN 300 (MOLEKULE)',
	'Phenytoin Sodium',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHALIN 300 (MOLEKULE)'
);

-- line #26534
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHALIN 50 (MOLEKULE)',
	'Phenytoin Sodium',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHALIN 50 (MOLEKULE)'
);

-- line #26535
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHENSO 100 (Rkg)',
	'Phenytoin Sodium',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHENSO 100 (Rkg)'
);

-- line #26536
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHENTIN 100 (S P Ph.)',
	'Phenytoin Sodium',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHENTIN 100 (S P Ph.)'
);

-- line #26537
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHENYKEM 300 (Alkem)',
	'Phenytoin Sodium',
	'ER CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHENYKEM 300 (Alkem)'
);

-- line #26538
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHENYKEM 50 (Alkem)',
	'Phenytoin Sodium',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHENYKEM 50 (Alkem)'
);

-- line #26539
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHENYKEM 100 (Alkem)',
	'Phenytoin Sodium',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHENYKEM 100 (Alkem)'
);

-- line #26540
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHENYKEM 300 (Alkem)',
	'Phenytoin Sodium',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHENYKEM 300 (Alkem)'
);

-- line #26541
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHENYTOIN 100 (Samarth)',
	'Phenytoin Sodium',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHENYTOIN 100 (Samarth)'
);

-- line #26542
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50', u'strength_2': u'', u'substance': u'Phenytoin Sodium', u'always_empty': u'', u'form': u'', u'brand': u'PHENYTO-S', u'strength_3': u'', u'company': u'A.F.D.', u'unit': u'mg'}

-- line #26543
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHENYTO-S 100 (A.F.D.)',
	'Phenytoin Sodium',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHENYTO-S 100 (A.F.D.)'
);

-- line #26544
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHETOIN 100 (Reliance)',
	'Phenytoin Sodium',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHETOIN 100 (Reliance)'
);

-- line #26545
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PNA 100 (Mano)',
	'Phenytoin Sodium',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PNA 100 (Mano)'
);

-- line #26546
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PNA 200 (Mano)',
	'Phenytoin Sodium',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PNA 200 (Mano)'
);

-- line #26547
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PNA 50 (Mano)',
	'Phenytoin Sodium',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PNA 50 (Mano)'
);

-- line #26548
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAPITOIN 50 (Emcure)',
	'Phenytoin Sodium',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAPITOIN 50 (Emcure)'
);

-- line #26549
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAAT-80 240 (Piramal Hc.)',
	'Phospholipids',
	'TAB',
	gm.nullify_empty_string('240')::numeric,
	'mg(PHOSPHOLIPIDS FRACTION FROM PIG LUNG 240'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAAT-80 240 (Piramal Hc.)'
);

-- line #26550
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'240', u'strength_2': u'', u'substance': u'Phospholipids', u'always_empty': u'', u'form': u'', u'brand': u'CUROSURF', u'strength_3': u'', u'company': u'Piramal Hc.', u'unit': u'mg(PHOSPHOLIPIDS FRACTION FROM PIG LUNG 240'}

-- line #26551
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESSEL COMPOUND 175 (Nicholas)',
	'Phospholipids',
	'CAP',
	gm.nullify_empty_string('175')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESSEL COMPOUND 175 (Nicholas)'
);

-- line #26552
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESSENTIALE-L 175 (Nicholas)',
	'Phospholipids',
	'CAP',
	gm.nullify_empty_string('175')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESSENTIALE-L 175 (Nicholas)'
);

-- line #26553
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIVAGE 175 (Aristo)',
	'Phospholipids',
	'CAP',
	gm.nullify_empty_string('175')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIVAGE 175 (Aristo)'
);

-- line #26554
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIVINTACT 262.5 (Panjon)',
	'Phospholipids',
	'CAP',
	gm.nullify_empty_string('262.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIVINTACT 262.5 (Panjon)'
);

-- line #26555
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIVOPHOS SOFGEL 175 (Elder)',
	'Phospholipids',
	'CAP',
	gm.nullify_empty_string('175')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIVOPHOS SOFGEL 175 (Elder)'
);

-- line #26556
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'27', u'strength_2': u'', u'substance': u'Phospholipids', u'always_empty': u'', u'form': u'', u'brand': u'NEOSURF', u'strength_3': u'', u'company': u'Cipla', u'unit': u'mg'}

-- line #26557
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROESSEN 600 (Piramal Hc.)',
	'Phospholipids',
	'CAP',
	gm.nullify_empty_string('600')::numeric,
	'mg(LACITHIN)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROESSEN 600 (Piramal Hc.)'
);

-- line #26558
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROESSEN SOFTGEL 300 (Piramal Hc.)',
	'Phospholipids',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg(LECITHIN 600'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROESSEN SOFTGEL 300 (Piramal Hc.)'
);

-- line #26559
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'300', u'strength_2': u'', u'substance': u'Phospholipids', u'always_empty': u'', u'form': u'', u'brand': u'PROESSEN SOFTGEL', u'strength_3': u'', u'company': u'Piramal Hc.', u'unit': u'mg(LECITHIN 600'}

-- line #26560
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIVOMARK 125 (Mark India)',
	'PHYLLANTHUS AMARUS EXTRACT',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIVOMARK 125 (Mark India)'
);

-- line #26561
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIVOMARK 500 (Mark India)',
	'PHYLLANTHUS AMARUS EXTRACT',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIVOMARK 500 (Mark India)'
);

-- line #26562
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INJEK 1 (Neon)',
	'Phytomenadione',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INJEK 1 (Neon)'
);

-- line #26563
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KENADION 1 (Samarth)',
	'Phytomenadione',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KENADION 1 (Samarth)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KENADION 10 (Samarth)',
	'Phytomenadione',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KENADION 10 (Samarth)'
);

-- line #26564
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KENADION 10 (Samarth)',
	'Phytomenadione',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KENADION 10 (Samarth)'
);

-- line #26565
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'K-WIN 1 (Mercury)',
	'Phytomenadione',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'mg/0.5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'K-WIN 1 (Mercury)'
);

-- line #26566
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANDRE CARPINE 0.5 (Intas)',
	'Pilocarpine',
	'AMP',
	gm.nullify_empty_string('0.5')::numeric,
	'% WITHOUT PRESERVATIVE'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANDRE CARPINE 0.5 (Intas)'
);

-- line #26567
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARPINE 0.05 (Intas)',
	'Pilocarpine',
	'DPS',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARPINE 0.05 (Intas)'
);

-- line #26568
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARPINOL 0.5 (Sunways)',
	'Pilocarpine',
	'DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARPINOL 0.5 (Sunways)'
);

-- line #26569
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARPO-MIOTIC 2 (Bell Ph.)',
	'Pilocarpine',
	'DPS',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARPO-MIOTIC 2 (Bell Ph.)'
);

-- line #26570
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOCARP 2 (Cadila Ph.)',
	'Pilocarpine',
	'DPS',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOCARP 2 (Cadila Ph.)'
);

-- line #26571
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PILAGAN 2 (Allergan)',
	'Pilocarpine',
	'DPS',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PILAGAN 2 (Allergan)'
);

-- line #26572
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PILOCAR 1 (F D C)',
	'Pilocarpine',
	'DPS',
	gm.nullify_empty_string('1')::numeric,
	'%/2'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PILOCAR 1 (F D C)'
);

-- line #26573
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PILODROPS 2 (Micro V.)',
	'Pilocarpine',
	'EYE DPS',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PILODROPS 2 (Micro V.)'
);

-- line #26574
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PILOMAX 2 (Milmet)',
	'Pilocarpine',
	'DPS',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PILOMAX 2 (Milmet)'
);

-- line #26575
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PILOPRESS 2 (Centaur)',
	'Pilocarpine',
	'DPS',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PILOPRESS 2 (Centaur)'
);

-- line #26576
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELIDEL 1 (Novartis)',
	'PIMECROLIMUS',
	'TUBE',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELIDEL 1 (Novartis)'
);

-- line #26577
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10', u'strength_2': u'', u'substance': u'PIMECROLIMUS', u'always_empty': u'', u'form': u'', u'brand': u'PACROMA', u'strength_3': u'', u'company': u'AVECIA', u'unit': u'mg'}

-- line #26578
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10', u'strength_2': u'', u'substance': u'PIMECROLIMUS', u'always_empty': u'', u'form': u'', u'brand': u'PICON', u'strength_3': u'', u'company': u'Biocon', u'unit': u'mg'}

-- line #26579
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'PIMECROLIMUS', u'always_empty': u'', u'form': u'', u'brand': u'PICON', u'strength_3': u'', u'company': u'BIOCON LTD.', u'unit': u''}

-- line #26580
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LARAP 2 (LA DRUG)',
	'Pimozide',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LARAP 2 (LA DRUG)'
);

-- line #26581
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LARAP 4 (LA DRUG)',
	'Pimozide',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LARAP 4 (LA DRUG)'
);

-- line #26582
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDIP 2 (Medico)',
	'Pimozide',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDIP 2 (Medico)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDIP 4 (Medico)',
	'Pimozide',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDIP 4 (Medico)'
);

-- line #26583
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOZIDE 2 (Group Ph.)',
	'Pimozide',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOZIDE 2 (Group Ph.)'
);

-- line #26584
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOZIDE 4 (Group Ph.)',
	'Pimozide',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOZIDE 4 (Group Ph.)'
);

-- line #26585
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOZEP 2 (Intas)',
	'Pimozide',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOZEP 2 (Intas)'
);

-- line #26586
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOZEP 4 (Intas)',
	'Pimozide',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOZEP 4 (Intas)'
);

-- line #26587
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEURAP 2 (Torrent)',
	'Pimozide',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEURAP 2 (Torrent)'
);

-- line #26588
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEURAP 4 (Torrent)',
	'Pimozide',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEURAP 4 (Torrent)'
);

-- line #26589
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORAP 2 (Ethnor)',
	'Pimozide',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORAP 2 (Ethnor)'
);

-- line #26590
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORAP 4 (Ethnor)',
	'Pimozide',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORAP 4 (Ethnor)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORAP 10 (Ethnor)',
	'Pimozide',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORAP 10 (Ethnor)'
);

-- line #26591
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIMODAC 2 (Zydus A.)',
	'Pimozide',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIMODAC 2 (Zydus A.)'
);

-- line #26592
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIMODAC 4 (Zydus A.)',
	'Pimozide',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIMODAC 4 (Zydus A.)'
);

-- line #26593
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIMO 2 (Mano)',
	'Pimozide',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIMO 2 (Mano)'
);

-- line #26594
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIMO 4 (Mano)',
	'Pimozide',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIMO 4 (Mano)'
);

-- line #26595
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELDICET 50 (Infar)',
	'Pinaverium Brom.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELDICET 50 (Infar)'
);

-- line #26596
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOGLITA 15 (Biochem)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOGLITA 15 (Biochem)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOGLITA 30 (Biochem)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOGLITA 30 (Biochem)'
);

-- line #26597
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPEL 15 (Zee Lab)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPEL 15 (Zee Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPEL 30 (Zee Lab)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPEL 30 (Zee Lab)'
);

-- line #26598
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIAGLIT 15 (Biochem)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIAGLIT 15 (Biochem)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIAGLIT 30 (Biochem)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIAGLIT 30 (Biochem)'
);

-- line #26599
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIAVISTA 15 (Dr.Reddy''S)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIAVISTA 15 (Dr.Reddy''S)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIAVISTA 30 (Dr.Reddy''S)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIAVISTA 30 (Dr.Reddy''S)'
);

-- line #26600
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIBIZONE 15 (Novartis)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIBIZONE 15 (Novartis)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIBIZONE 30 (Novartis)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIBIZONE 30 (Novartis)'
);

-- line #26601
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GELITARIS 15 (ERIS LIFE)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GELITARIS 15 (ERIS LIFE)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GELITARIS 30 (ERIS LIFE)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GELITARIS 30 (ERIS LIFE)'
);

-- line #26602
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLITARIS 15 (ERIS LIFE)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLITARIS 15 (ERIS LIFE)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLITARIS 30 (ERIS LIFE)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLITARIS 30 (ERIS LIFE)'
);

-- line #26603
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLITA 15 (Stadmed)',
	'PIOGLITAZONE',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLITA 15 (Stadmed)'
);

-- line #26604
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLITA 30 (Stadmed)',
	'PIOGLITAZONE',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLITA 30 (Stadmed)'
);

-- line #26605
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLITO 15 (Medley)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLITO 15 (Medley)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLITO 30 (Medley)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLITO 30 (Medley)'
);

-- line #26606
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLITTER 15 (Ind-Swift)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLITTER 15 (Ind-Swift)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLITTER 30 (Ind-Swift)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLITTER 30 (Ind-Swift)'
);

-- line #26607
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIZONE 15 (Zydus Cadila)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIZONE 15 (Zydus Cadila)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIZONE 30 (Zydus Cadila)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIZONE 30 (Zydus Cadila)'
);

-- line #26608
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUFIT 15 (Ind-Swift)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUFIT 15 (Ind-Swift)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUFIT 30 (Ind-Swift)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUFIT 30 (Ind-Swift)'
);

-- line #26609
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G-TASE 15 (Unisearch)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G-TASE 15 (Unisearch)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G-TASE 30 (Unisearch)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G-TASE 30 (Unisearch)'
);

-- line #26610
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'K-PIO 15 (Blue Cross)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'K-PIO 15 (Blue Cross)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'K-PIO 30 (Blue Cross)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'K-PIO 30 (Blue Cross)'
);

-- line #26611
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LITA 15 (Intra Lab)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LITA 15 (Intra Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LITA 30 (Intra Lab)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LITA 30 (Intra Lab)'
);

-- line #26612
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOGIT 15 (XENON(KHANDELWAL))',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOGIT 15 (XENON(KHANDELWAL))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOGIT 30 (XENON(KHANDELWAL))',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOGIT 30 (XENON(KHANDELWAL))'
);

-- line #26613
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OGLO 15 (Panacea)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OGLO 15 (Panacea)'
);

-- line #26614
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OGLO 30 (Panacea)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OGLO 30 (Panacea)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OGLO 45 (Panacea)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('45')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OGLO 45 (Panacea)'
);

-- line #26615
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPAM 15 (Wockhardt)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPAM 15 (Wockhardt)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPAM 30 (Wockhardt)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPAM 30 (Wockhardt)'
);

-- line #26616
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PATH 15 (Lupin)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PATH 15 (Lupin)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PATH 30 (Lupin)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PATH 30 (Lupin)'
);

-- line #26617
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAZO 15 (SHINE PH.)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAZO 15 (SHINE PH.)'
);

-- line #26618
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAZO 30 (SHINE PH.)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAZO 30 (SHINE PH.)'
);

-- line #26619
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEPAR 15 (Healtheon)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEPAR 15 (Healtheon)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEPAR 30 (Healtheon)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEPAR 30 (Healtheon)'
);

-- line #26620
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PGLIT 15 (Chemech)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PGLIT 15 (Chemech)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PGLIT 30 (Chemech)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PGLIT 30 (Chemech)'
);

-- line #26621
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'P-GLITZ 15 (Cipla)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'P-GLITZ 15 (Cipla)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'P-GLITZ 30 (Cipla)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'P-GLITZ 30 (Cipla)'
);

-- line #26622
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PG 15 (ORDAIN HC.)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PG 15 (ORDAIN HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PG 30 (ORDAIN HC.)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PG 30 (ORDAIN HC.)'
);

-- line #26623
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIOBITZ-15 15 (BEATZ LIFESCI.)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIOBITZ-15 15 (BEATZ LIFESCI.)'
);

-- line #26624
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Pioglitazone', u'always_empty': u'', u'form': u'', u'brand': u'PIOCARE', u'strength_3': u'', u'company': u'NEO CC.', u'unit': u''}

-- line #26625
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIODART 15 (Biocon)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIODART 15 (Biocon)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIODART 30 (Biocon)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIODART 30 (Biocon)'
);

-- line #26626
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIOGLAR 15 (Stancare)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIOGLAR 15 (Stancare)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIOGLAR 30 (Stancare)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIOGLAR 30 (Stancare)'
);

-- line #26627
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIOGLAZ 15 (EAST WEST)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIOGLAZ 15 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIOGLAZ 30 (EAST WEST)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIOGLAZ 30 (EAST WEST)'
);

-- line #26628
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIOGLIT 15 (Sun)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIOGLIT 15 (Sun)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIOGLIT 30 (Sun)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIOGLIT 30 (Sun)'
);

-- line #26629
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIOGLU 15 (Emcure)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIOGLU 15 (Emcure)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIOGLU 30 (Emcure)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIOGLU 30 (Emcure)'
);

-- line #26630
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIO-G 15 (Indi Ph.)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIO-G 15 (Indi Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIO-G 30 (Indi Ph.)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIO-G 30 (Indi Ph.)'
);

-- line #26631
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIOKAP 15 (Kapl)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIOKAP 15 (Kapl)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIOKAP 30 (Kapl)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIOKAP 30 (Kapl)'
);

-- line #26632
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIOKIND 15 (Mankind)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIOKIND 15 (Mankind)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIOKIND 30 (Mankind)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIOKIND 30 (Mankind)'
);

-- line #26633
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIOLEM 15 (Alembic)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIOLEM 15 (Alembic)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIOLEM 30 (Alembic)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIOLEM 30 (Alembic)'
);

-- line #26634
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIOLET 15 (Intas)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIOLET 15 (Intas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIOLET 30 (Intas)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIOLET 30 (Intas)'
);

-- line #26635
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIOLI 15 (Life Med.)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIOLI 15 (Life Med.)'
);

-- line #26636
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIOLI 30 (Life Med.)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIOLI 30 (Life Med.)'
);

-- line #26637
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIOMED 15 (Comed)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIOMED 15 (Comed)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIOMED 30 (Comed)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIOMED 30 (Comed)'
);

-- line #26638
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIONEER 15 (Olcare)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIONEER 15 (Olcare)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIONEER 30 (Olcare)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIONEER 30 (Olcare)'
);

-- line #26639
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIONEER 45 (Olcare)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('45')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIONEER 45 (Olcare)'
);

-- line #26640
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIONORM 15 (Carsyon)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIONORM 15 (Carsyon)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIONORM 30 (Carsyon)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIONORM 30 (Carsyon)'
);

-- line #26641
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIOPED 15 (Torrent)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIOPED 15 (Torrent)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIOPED 30 (Torrent)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIOPED 30 (Torrent)'
);

-- line #26642
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIO-Q 15 (QCHECK)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIO-Q 15 (QCHECK)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIO-Q 30 (QCHECK)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIO-Q 30 (QCHECK)'
);

-- line #26643
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIOREST 15 (Bal Ph.)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIOREST 15 (Bal Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIOREST 30 (Bal Ph.)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIOREST 30 (Bal Ph.)'
);

-- line #26644
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIOSAFE 15 (Otsira)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIOSAFE 15 (Otsira)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIOSAFE 30 (Otsira)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIOSAFE 30 (Otsira)'
);

-- line #26645
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIOSTAR 15 (Aglowmed)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIOSTAR 15 (Aglowmed)'
);

-- line #26646
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIOSYS 15 (Systopic)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIOSYS 15 (Systopic)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIOSYS 30 (Systopic)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIOSYS 30 (Systopic)'
);

-- line #26647
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIO SYS 15 (Systopic)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIO SYS 15 (Systopic)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIO SYS 30 (Systopic)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIO SYS 30 (Systopic)'
);

-- line #26648
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIOTAB 15 (Marc Lab)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIOTAB 15 (Marc Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIOTAB 30 (Marc Lab)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIOTAB 30 (Marc Lab)'
);

-- line #26649
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIOTAZ 15 (Rpg Life)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIOTAZ 15 (Rpg Life)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIOTAZ 30 (Rpg Life)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIOTAZ 30 (Rpg Life)'
);

-- line #26650
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIOTOP 15 (Kopran)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIOTOP 15 (Kopran)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIOTOP 30 (Kopran)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIOTOP 30 (Kopran)'
);

-- line #26651
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIOTROL 15 (Argus)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIOTROL 15 (Argus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIOTROL 30 (Argus)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIOTROL 30 (Argus)'
);

-- line #26652
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIOTYX 15 (TRITON(CALYX))',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIOTYX 15 (TRITON(CALYX))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIOTYX 30 (TRITON(CALYX))',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIOTYX 30 (TRITON(CALYX))'
);

-- line #26653
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIOZED 15 (Ipca)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIOZED 15 (Ipca)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIOZED 30 (Ipca)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIOZED 30 (Ipca)'
);

-- line #26654
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIOZIT 15 (Indoco Rem.)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIOZIT 15 (Indoco Rem.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIOZIT 30 (Indoco Rem.)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIOZIT 30 (Indoco Rem.)'
);

-- line #26655
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIOZONE 15 (Nicholas)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIOZONE 15 (Nicholas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIOZONE 30 (Nicholas)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIOZONE 30 (Nicholas)'
);

-- line #26656
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIOZ 15 (U S V)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIOZ 15 (U S V)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIOZ 30 (U S V)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIOZ 30 (U S V)'
);

-- line #26657
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIOZULIN 15 (Cadila Ph.)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIOZULIN 15 (Cadila Ph.)'
);

-- line #26658
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIOZULIN 30 (Cadila Ph.)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIOZULIN 30 (Cadila Ph.)'
);

-- line #26659
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'7,5', u'strength_2': u'', u'substance': u'Pioglitazone', u'always_empty': u'', u'form': u'', u'brand': u'PIOZ', u'strength_3': u'', u'company': u'USV (CONQUER)', u'unit': u'mg'}

-- line #26660
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIZORAD 15 (Radius)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIZORAD 15 (Radius)'
);

-- line #26661
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIZORAD 30 (Radius)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIZORAD 30 (Radius)'
);

-- line #26662
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POKR 15 (AAMORB(XEENA))',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POKR 15 (AAMORB(XEENA))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POKR 30 (AAMORB(XEENA))',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POKR 30 (AAMORB(XEENA))'
);

-- line #26663
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POZITIV 15 (Franco I.)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POZITIV 15 (Franco I.)'
);

-- line #26664
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POZITIV 30 (Franco I.)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POZITIV 30 (Franco I.)'
);

-- line #26665
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRECITROL 15 (Merck)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRECITROL 15 (Merck)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRECITROL 30 (Merck)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRECITROL 30 (Merck)'
);

-- line #26666
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYE 15 (GRANDIX)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYE 15 (GRANDIX)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYE 30 (GRANDIX)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYE 30 (GRANDIX)'
);

-- line #26667
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RADIZONE 15 (Radicura)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RADIZONE 15 (Radicura)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RADIZONE 30 (Radicura)',
	'Pioglitazone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RADIZONE 30 (Radicura)'
);

-- line #26668
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIPTAL 5 (Chemage)',
	'Pipenzolate Methylbrom.',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIPTAL 5 (Chemage)'
);

-- line #26669
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1', u'strength_2': u'2;G', u'substance': u'Piperacillin', u'always_empty': u'', u'form': u'INJ', u'brand': u'PIPLIN', u'strength_3': u'', u'company': u'CH.Bhagat', u'unit': u''}

-- line #26670
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIPLIN 4 (CH.Bhagat)',
	'Piperacillin',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIPLIN 4 (CH.Bhagat)'
);

-- line #26671
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1', u'strength_2': u'2;G', u'substance': u'Piperacillin', u'always_empty': u'', u'form': u'INJ', u'brand': u'PIPRACILIN', u'strength_3': u'', u'company': u'Csc Ph.', u'unit': u''}

-- line #26672
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'4G', u'strength_2': u'', u'substance': u'Piperacillin', u'always_empty': u'', u'form': u'INJ', u'brand': u'PIPRACILIN', u'strength_3': u'', u'company': u'Csc Ph.', u'unit': u''}

-- line #26673
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2G', u'strength_2': u'', u'substance': u'Piperacillin', u'always_empty': u'', u'form': u'INJ', u'brand': u'PIPRACIL', u'strength_3': u'', u'company': u'Wyeth', u'unit': u''}

-- line #26674
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'4G', u'strength_2': u'', u'substance': u'Piperacillin', u'always_empty': u'', u'form': u'INJ', u'brand': u'PIPRACIL', u'strength_3': u'', u'company': u'Wyeth', u'unit': u''}

-- line #26675
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1', u'strength_2': u'2;G', u'substance': u'Piperacillin', u'always_empty': u'', u'form': u'INJ', u'brand': u'PIPRALIN', u'strength_3': u'', u'company': u'United Bio.', u'unit': u''}

-- line #26676
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'4G', u'strength_2': u'', u'substance': u'Piperacillin', u'always_empty': u'', u'form': u'INJ', u'brand': u'PIPRALIN', u'strength_3': u'', u'company': u'United Bio.', u'unit': u''}

-- line #26677
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1', u'strength_2': u'2;G', u'substance': u'Piperacillin', u'always_empty': u'', u'form': u'INJ', u'brand': u'PIPRAPEN', u'strength_3': u'', u'company': u'F D C', u'unit': u''}

-- line #26678
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'4G', u'strength_2': u'', u'substance': u'Piperacillin', u'always_empty': u'', u'form': u'INJ', u'brand': u'PIPRAPEN', u'strength_3': u'', u'company': u'F D C', u'unit': u''}

-- line #26679
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1', u'strength_2': u'2;G', u'substance': u'Piperacillin', u'always_empty': u'', u'form': u'INJ', u'brand': u'PIPREX', u'strength_3': u'', u'company': u'Samarth', u'unit': u''}

-- line #26680
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'4G', u'strength_2': u'', u'substance': u'Piperacillin', u'always_empty': u'', u'form': u'INJ', u'brand': u'PIPREX', u'strength_3': u'', u'company': u'Samarth LIFE', u'unit': u''}

-- line #26681
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'30ML', u'strength_2': u'', u'substance': u'Piperazine', u'always_empty': u'', u'form': u'SYR', u'brand': u'AVIZINE', u'strength_3': u'', u'company': u'TAJ PH.', u'unit': u''}

-- line #26682
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVIZINE 500 (TAJ PH.)',
	'Piperazine',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVIZINE 500 (TAJ PH.)'
);

-- line #26683
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIPERAZINE CITRATE 750 (Gsk)',
	'Piperazine',
	'SYR',
	gm.nullify_empty_string('750')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIPERAZINE CITRATE 750 (Gsk)'
);

-- line #26684
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIPERAZINE CITR 750 (Gsk)',
	'Piperazine',
	'SYR',
	gm.nullify_empty_string('750')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIPERAZINE CITR 750 (Gsk)'
);

-- line #26685
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIPERAZINE PHOSPHATE 500 (Gsk)',
	'Piperazine',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIPERAZINE PHOSPHATE 500 (Gsk)'
);

-- line #26686
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARDUAN 2 (Themis)',
	'Pipercuronium',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARDUAN 2 (Themis)'
);

-- line #26687
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALCETAM 100 (Pentacare)',
	'Piracetam',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALCETAM 100 (Pentacare)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALCETAM 200 (Pentacare)',
	'Piracetam',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALCETAM 200 (Pentacare)'
);

-- line #26688
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALCETAM 400 (Pentacare)',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALCETAM 400 (Pentacare)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALCETAM 800 (Pentacare)',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALCETAM 800 (Pentacare)'
);

-- line #26689
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALCITAM 400 (Dial Ph.)',
	'Piracetam',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALCITAM 400 (Dial Ph.)'
);

-- line #26690
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMCETAM 400 (Ampus Life)',
	'Piracetam',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMCETAM 400 (Ampus Life)'
);

-- line #26691
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMCETAM 200 (Ampus Life)',
	'Piracetam',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMCETAM 200 (Ampus Life)'
);

-- line #26692
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMCETAM 500 (Ampus Life)',
	'Piracetam',
	'SYR',
	gm.nullify_empty_string('500')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMCETAM 500 (Ampus Life)'
);

-- line #26693
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMCETAM 800 (Ampus Life)',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMCETAM 800 (Ampus Life)'
);

-- line #26694
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Piracetam', u'always_empty': u'', u'form': u'VIAL', u'brand': u'AMRITAM', u'strength_3': u'', u'company': u'HEALTH BIO.', u'unit': u''}

-- line #26695
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXCETA-800 800 (AXYZEN LIFE)',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXCETA-800 800 (AXYZEN LIFE)'
);

-- line #26696
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRENTOR 400 (Zee Lab)',
	'Piracetam',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRENTOR 400 (Zee Lab)'
);

-- line #26697
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRETNOR 200 (OREVA DARMO.)',
	'Piracetam',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRETNOR 200 (OREVA DARMO.)'
);

-- line #26698
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRETNOR 800 (OREVA DARMO.)',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRETNOR 800 (OREVA DARMO.)'
);

-- line #26699
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEACT 400 (Crescent Th.)',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEACT 400 (Crescent Th.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEACT 800 (Crescent Th.)',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEACT 800 (Crescent Th.)'
);

-- line #26700
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CERABOL BRAIN 500 (Bipl(Radico Lab))',
	'Piracetam',
	'TONIC',
	gm.nullify_empty_string('500')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CERABOL BRAIN 500 (Bipl(Radico Lab))'
);

-- line #26701
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CERABOL 800 (Bipl(Radico Lab))',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CERABOL 800 (Bipl(Radico Lab))'
);

-- line #26702
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CERECETAM 200 (Intas)',
	'Piracetam',
	'INJ (60 )',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CERECETAM 200 (Intas)'
);

-- line #26703
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CERECETAM 200 (Intas)',
	'Piracetam',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg/15ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CERECETAM 200 (Intas)'
);

-- line #26704
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1 GM', u'strength_2': u'5 ML', u'substance': u'Piracetam', u'always_empty': u'', u'form': u'SUS', u'brand': u'CERECETAM', u'strength_3': u'', u'company': u'Intas', u'unit': u''}

-- line #26705
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'5ML', u'substance': u'Piracetam', u'always_empty': u'', u'form': u'SUSP', u'brand': u'CERECETAM', u'strength_3': u'', u'company': u'Intas', u'unit': u''}

-- line #26706
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CERECETAM 1200 (Intas)',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('1200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CERECETAM 1200 (Intas)'
);

-- line #26707
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CERECETAM 400 (Intas)',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CERECETAM 400 (Intas)'
);

-- line #26708
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CERECETAM 800 (Intas)',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CERECETAM 800 (Intas)'
);

-- line #26709
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEREMAX 400 (STADCHEM)',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEREMAX 400 (STADCHEM)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEREMAX 800 (STADCHEM)',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEREMAX 800 (STADCHEM)'
);

-- line #26710
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETAM 200 (Taurus Lab)',
	'Piracetam',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETAM 200 (Taurus Lab)'
);

-- line #26711
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETAM 500 (Taurus Lab)',
	'Piracetam',
	'SUS',
	gm.nullify_empty_string('500')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETAM 500 (Taurus Lab)'
);

-- line #26712
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETAM 400 (Taurus Lab)',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETAM 400 (Taurus Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETAM 800 (Taurus Lab)',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETAM 800 (Taurus Lab)'
);

-- line #26713
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETASMO 400 (Riasma Life)',
	'Piracetam',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETASMO 400 (Riasma Life)'
);

-- line #26714
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETASMO 500 (Riasma Life)',
	'Piracetam',
	'SYR',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETASMO 500 (Riasma Life)'
);

-- line #26715
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CETASMO 800 (Riasma Life)',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CETASMO 800 (Riasma Life)'
);

-- line #26716
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COGMAX 400 (Vgr Bio.)',
	'Piracetam',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COGMAX 400 (Vgr Bio.)'
);

-- line #26717
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COGMAX 800 (Vgr Bio.)',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COGMAX 800 (Vgr Bio.)'
);

-- line #26718
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COGNIX 200 (GRANDIX)',
	'Piracetam',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COGNIX 200 (GRANDIX)'
);

-- line #26719
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FINCETAM 100 (Finesse Ph.)',
	'Piracetam',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FINCETAM 100 (Finesse Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FINCETAM 200 (Finesse Ph.)',
	'Piracetam',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FINCETAM 200 (Finesse Ph.)'
);

-- line #26720
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FINCETAM 500 (Finesse Ph.)',
	'Piracetam',
	'SYR',
	gm.nullify_empty_string('500')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FINCETAM 500 (Finesse Ph.)'
);

-- line #26721
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORCETAM 400 (MEDIFORECE)',
	'Piracetam',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORCETAM 400 (MEDIFORECE)'
);

-- line #26722
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MINCETAM 800 (PSYCOREM)',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MINCETAM 800 (PSYCOREM)'
);

-- line #26723
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MINDCET 500 (SUBHREK PH.)',
	'Piracetam',
	'SYR',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MINDCET 500 (SUBHREK PH.)'
);

-- line #26724
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MINDCET 400 (SUBHREK PH.)',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MINDCET 400 (SUBHREK PH.)'
);

-- line #26725
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAM 800 (ROSE LABS)',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAM 800 (ROSE LABS)'
);

-- line #26726
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOPIRAM 1000 (Neon)',
	'Piracetam',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOPIRAM 1000 (Neon)'
);

-- line #26727
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEUCET 200 (Royal)',
	'Piracetam',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEUCET 200 (Royal)'
);

-- line #26728
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEUCET 500 (Royal Lab)',
	'Piracetam',
	'SYR',
	gm.nullify_empty_string('500')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEUCET 500 (Royal Lab)'
);

-- line #26729
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEUCET 800 (Royal Lab)',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEUCET 800 (Royal Lab)'
);

-- line #26730
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEUROCETAM 400 (Brown & B.)',
	'Piracetam',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEUROCETAM 400 (Brown & B.)'
);

-- line #26731
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEUROCETAM 200 (Brown & B.)',
	'Piracetam',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEUROCETAM 200 (Brown & B.)'
);

-- line #26732
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEUROCETAM 500 (Brown & B.)',
	'Piracetam',
	'SYR',
	gm.nullify_empty_string('500')::numeric,
	'mg/5 ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEUROCETAM 500 (Brown & B.)'
);

-- line #26733
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEUROCETAM 800 (Brown & B.)',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEUROCETAM 800 (Brown & B.)'
);

-- line #26734
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEUROFIT 400 (SHINE PH.)',
	'Piracetam',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEUROFIT 400 (SHINE PH.)'
);

-- line #26735
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEUROFIT 800 (SHINE PH.)',
	'Piracetam',
	'F. TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEUROFIT 800 (SHINE PH.)'
);

-- line #26736
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEUROFIT 200 (SHINE PH.)',
	'Piracetam',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEUROFIT 200 (SHINE PH.)'
);

-- line #26737
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEUROFIT 1200 (SHINE PH.)',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('1200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEUROFIT 1200 (SHINE PH.)'
);

-- line #26738
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEUROPIL 400 (PSYCOREM)',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEUROPIL 400 (PSYCOREM)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEUROPIL 800 (PSYCOREM)',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEUROPIL 800 (PSYCOREM)'
);

-- line #26739
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEUROSPAM 400 (Arbro Ph.)',
	'Piracetam',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEUROSPAM 400 (Arbro Ph.)'
);

-- line #26740
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEUROSPAM 100 (Arbro Ph.)',
	'Piracetam',
	'SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEUROSPAM 100 (Arbro Ph.)'
);

-- line #26741
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEUROX 500 (Apex Form.)',
	'Piracetam',
	'SYR',
	gm.nullify_empty_string('500')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEUROX 500 (Apex Form.)'
);

-- line #26742
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NICETAM 500 (Reliance)',
	'Piracetam',
	'SYR',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NICETAM 500 (Reliance)'
);

-- line #26743
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NICETAM 400 (Reliance)',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NICETAM 400 (Reliance)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NICETAM 800 (Reliance)',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NICETAM 800 (Reliance)'
);

-- line #26744
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOOTROPIL 400 (Ucb India)',
	'Piracetam',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOOTROPIL 400 (Ucb India)'
);

-- line #26745
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOOTROPIL 200 (Ucb India)',
	'Piracetam',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg/15ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOOTROPIL 200 (Ucb India)'
);

-- line #26746
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOOTROPIL 100 (Ucb India)',
	'Piracetam',
	'SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOOTROPIL 100 (Ucb India)'
);

-- line #26747
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOOTROPIL 800 (Ucb India)',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOOTROPIL 800 (Ucb India)'
);

-- line #26748
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORCETAM 400 (Reliance)',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORCETAM 400 (Reliance)'
);

-- line #26749
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORMABRAIN 400 (Torrent)',
	'Piracetam',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORMABRAIN 400 (Torrent)'
);

-- line #26750
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORMABRAIN 200 (Torrent)',
	'Piracetam',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg/15 ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORMABRAIN 200 (Torrent)'
);

-- line #26751
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORMABRAIN 100 (Torrent)',
	'Piracetam',
	'SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORMABRAIN 100 (Torrent)'
);

-- line #26752
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORMABRAIN 1200 (TORRENT)',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('1200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORMABRAIN 1200 (TORRENT)'
);

-- line #26753
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORMABRAIN 800 (Torrent)',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORMABRAIN 800 (Torrent)'
);

-- line #26754
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORMAN 500 (AIMCO PH.)',
	'Piracetam',
	'SYR',
	gm.nullify_empty_string('500')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORMAN 500 (AIMCO PH.)'
);

-- line #26755
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORMAN 400 (AIMCO PH.)',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORMAN 400 (AIMCO PH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORMAN 800 (AIMCO PH.)',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORMAN 800 (AIMCO PH.)'
);

-- line #26756
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORMENTA 400 (Makers)',
	'Piracetam',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORMENTA 400 (Makers)'
);

-- line #26757
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORMENTA 500 (Makers)',
	'Piracetam',
	'SYR',
	gm.nullify_empty_string('500')::numeric,
	'mg/5 ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORMENTA 500 (Makers)'
);

-- line #26758
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORMENTA 800 (Makers)',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORMENTA 800 (Makers)'
);

-- line #26759
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUPIC 400 (LA DRUG)',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUPIC 400 (LA DRUG)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUPIC 800 (LA DRUG)',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUPIC 800 (LA DRUG)'
);

-- line #26760
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUTAM 400 (MOLEKULE)',
	'Piracetam',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUTAM 400 (MOLEKULE)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUTAM 800 (MOLEKULE)',
	'Piracetam',
	'CAP',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUTAM 800 (MOLEKULE)'
);

-- line #26761
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUTAM 200 (MOLEKULE)',
	'Piracetam',
	'INF',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUTAM 200 (MOLEKULE)'
);

-- line #26762
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUTAM 200 (MOLEKULE)',
	'Piracetam',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUTAM 200 (MOLEKULE)'
);

-- line #26763
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUTAM 500 (MOLEKULE)',
	'Piracetam',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUTAM 500 (MOLEKULE)'
);

-- line #26764
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUTAM 500 (MOLEKULE)',
	'Piracetam',
	'SYR',
	gm.nullify_empty_string('500')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUTAM 500 (MOLEKULE)'
);

-- line #26765
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUTAM 1200 (MOLEKULE)',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('1200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUTAM 1200 (MOLEKULE)'
);

-- line #26766
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUTAM 800 (MOLEKULE)',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUTAM 800 (MOLEKULE)'
);

-- line #26767
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUTAN 500 (MOLEKULE)',
	'Piracetam',
	'SYRUP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUTAN 500 (MOLEKULE)'
);

-- line #26768
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLCITAM 400 (Olcare)',
	'Piracetam',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLCITAM 400 (Olcare)'
);

-- line #26769
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLCITAM 500 (Olcare)',
	'Piracetam',
	'SYR',
	gm.nullify_empty_string('500')::numeric,
	'mg/10 ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLCITAM 500 (Olcare)'
);

-- line #26770
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OROTAM 200 (RISHAB(OROCHEM))',
	'Piracetam',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OROTAM 200 (RISHAB(OROCHEM))'
);

-- line #26771
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OROTAM 500 (RISHAB(OROCHEM))',
	'Piracetam',
	'SYR',
	gm.nullify_empty_string('500')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OROTAM 500 (RISHAB(OROCHEM))'
);

-- line #26772
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OROTAM 800 (RISHAB(OROCHEM))',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OROTAM 800 (RISHAB(OROCHEM))'
);

-- line #26773
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PC-4/8 4 (Theo Ph.)',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PC-4/8 4 (Theo Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PC-4/8 8 (Theo Ph.)',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PC-4/8 8 (Theo Ph.)'
);

-- line #26774
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Piracetam', u'always_empty': u'', u'form': u'INJ', u'brand': u'PC', u'strength_3': u'', u'company': u'Theo Ph.', u'unit': u''}

-- line #26775
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PDNEURO 800 (Pharma Drugs)',
	'Piracetam',
	'SYR',
	gm.nullify_empty_string('800')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PDNEURO 800 (Pharma Drugs)'
);

-- line #26776
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PDNEURO 800 (Pharma Drugs)',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PDNEURO 800 (Pharma Drugs)'
);

-- line #26777
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Piracetam', u'always_empty': u'', u'form': u'SYR', u'brand': u'PIE', u'strength_3': u'', u'company': u"D.R.John''S", u'unit': u''}

-- line #26778
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIE 800 (D.R.John''S)',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIE 800 (D.R.John''S)'
);

-- line #26779
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIRABEL 500 (Marksans)',
	'Piracetam',
	'SYR',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIRABEL 500 (Marksans)'
);

-- line #26780
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIRABEL 1200 (Marksans)',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('1200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIRABEL 1200 (Marksans)'
);

-- line #26781
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIRABEL 400 (Marksans)',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIRABEL 400 (Marksans)'
);

-- line #26782
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIRABEL 800 (Marksans)',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIRABEL 800 (Marksans)'
);

-- line #26783
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIRACAS 800 (CASCA)',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIRACAS 800 (CASCA)'
);

-- line #26784
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIRAC 400 (Orchid Hc.)',
	'Piracetam',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIRAC 400 (Orchid Hc.)'
);

-- line #26785
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIRACER 200 (Global Med.)',
	'Piracetam',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIRACER 200 (Global Med.)'
);

-- line #26786
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIRACET 800 (Arvind Lab.)',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIRACET 800 (Arvind Lab.)'
);

-- line #26787
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIRAC 800 (Orchid Hc.)',
	'Piracetam',
	'INJ',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIRAC 800 (Orchid Hc.)'
);

-- line #26788
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIRAC 500 (Orchid Hc.)',
	'Piracetam',
	'SYR',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIRAC 500 (Orchid Hc.)'
);

-- line #26789
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIRAC 800 (Orchid Hc.)',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIRAC 800 (Orchid Hc.)'
);

-- line #26790
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIRAMAX 500 (Biomax Bio.)',
	'Piracetam',
	'SYR',
	gm.nullify_empty_string('500')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIRAMAX 500 (Biomax Bio.)'
);

-- line #26791
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIRAMAX 400 (Biomax Bio.)',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIRAMAX 400 (Biomax Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIRAMAX 800 (Biomax Bio.)',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIRAMAX 800 (Biomax Bio.)'
);

-- line #26792
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIRAMENT 100 (Ipca)',
	'Piracetam',
	'SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIRAMENT 100 (Ipca)'
);

-- line #26793
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIRAMENT 1200 (Ipca)',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('1200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIRAMENT 1200 (Ipca)'
);

-- line #26794
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIRAMENT 400 (Ipca)',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIRAMENT 400 (Ipca)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIRAMENT 800 (Ipca)',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIRAMENT 800 (Ipca)'
);

-- line #26795
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIRANIS 200 (NEISS)',
	'Piracetam',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIRANIS 200 (NEISS)'
);

-- line #26796
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIRA 1200 (EAST WEST)',
	'Piracetam',
	'OD TAB',
	gm.nullify_empty_string('1200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIRA 1200 (EAST WEST)'
);

-- line #26797
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIRA 500 (EAST WEST)',
	'Piracetam',
	'SYR',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIRA 500 (EAST WEST)'
);

-- line #26798
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIRA 400 (EAST WEST)',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIRA 400 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIRA 800 (EAST WEST)',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIRA 800 (EAST WEST)'
);

-- line #26799
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIRATAB 800 (Marc Lab)',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIRATAB 800 (Marc Lab)'
);

-- line #26800
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIRATAM 400 (GSK)',
	'Piracetam',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIRATAM 400 (GSK)'
);

-- line #26801
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIRATAM 100 (GSK)',
	'Piracetam',
	'SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIRATAM 100 (GSK)'
);

-- line #26802
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PITAM 400 (Chemo Bio.)',
	'Piracetam',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PITAM 400 (Chemo Bio.)'
);

-- line #26803
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PITAM 1200 (Chemo Bio.)',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('1200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PITAM 1200 (Chemo Bio.)'
);

-- line #26804
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PITAM 800 (Chemo Bio.)',
	'Piracetam',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PITAM 800 (Chemo Bio.)'
);

-- line #26805
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'800', u'strength_2': u'', u'substance': u'Piracetam', u'always_empty': u'', u'form': u'', u'brand': u'RACETAM', u'strength_3': u'', u'company': u'IP HC.', u'unit': u'mg'}

-- line #26806
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RACETAM 500 (IP HC.)',
	'Piracetam',
	'SYR',
	gm.nullify_empty_string('500')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RACETAM 500 (IP HC.)'
);

-- line #26807
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIDA 20 (Euphoric)',
	'Piroxicam',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIDA 20 (Euphoric)'
);

-- line #26808
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BREXIC 10 (Wockhardt)',
	'Piroxicam',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BREXIC 10 (Wockhardt)'
);

-- line #26809
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BREXIC 20 (Wockhardt)',
	'Piroxicam',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BREXIC 20 (Wockhardt)'
);

-- line #26810
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BREXIC 20 (Wockhardt)',
	'Piroxicam',
	'DT',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BREXIC 20 (Wockhardt)'
);

-- line #26811
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAMPAR 20 (Shinto Org.)',
	'Piroxicam',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAMPAR 20 (Shinto Org.)'
);

-- line #26812
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYCLADOL 20 (Croslands)',
	'Piroxicam',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg(BETA CYCLODEXTRINE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYCLADOL 20 (Croslands)'
);

-- line #26813
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DISCAM 20 (Unimax Lab)',
	'Piroxicam',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DISCAM 20 (Unimax Lab)'
);

-- line #26814
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLCARE 20 (Olcare)',
	'Piroxicam',
	'DT TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLCARE 20 (Olcare)'
);

-- line #26815
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLOCARE 20 (Indus)',
	'Piroxicam',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLOCARE 20 (Indus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLOCARE 40 (Indus)',
	'Piroxicam',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLOCARE 40 (Indus)'
);

-- line #26816
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Piroxicam', u'always_empty': u'', u'form': u'INJ', u'brand': u'DOLOCARE', u'strength_3': u'', u'company': u'VENSAT', u'unit': u''}

-- line #26817
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLOCARE 20 (VENSAT)',
	'Piroxicam',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLOCARE 20 (VENSAT)'
);

-- line #26818
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLOCIP 20 (Cipla)',
	'Piroxicam',
	'DT',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLOCIP 20 (Cipla)'
);

-- line #26819
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLODIL 40 (MADHAV BIO.)',
	'Piroxicam',
	'AMP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLODIL 40 (MADHAV BIO.)'
);

-- line #26820
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLOKAM 20 (Cadila Ph.)',
	'Piroxicam',
	'DT',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLOKAM 20 (Cadila Ph.)'
);

-- line #26821
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLOKEM 20 (CHEMO HC.)',
	'Piroxicam',
	'MD TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLOKEM 20 (CHEMO HC.)'
);

-- line #26822
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLOLUP 20 (Lupin)',
	'Piroxicam',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLOLUP 20 (Lupin)'
);

-- line #26823
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLONEX 20 (Pfizer)',
	'Piroxicam',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLONEX 20 (Pfizer)'
);

-- line #26824
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLONEX 20 (Pfizer)',
	'Piroxicam',
	'DT',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLONEX 20 (Pfizer)'
);

-- line #26825
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLONEX 0.5 (Pfizer)',
	'Piroxicam',
	'GEL',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLONEX 0.5 (Pfizer)'
);

-- line #26826
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLONEX 20 (Pfizer)',
	'Piroxicam',
	'INJ(1 ML)',
	gm.nullify_empty_string('20')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLONEX 20 (Pfizer)'
);

-- line #26827
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLONEX 20 (Pfizer)',
	'Piroxicam',
	'INJ(2 ML)',
	gm.nullify_empty_string('20')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLONEX 20 (Pfizer)'
);

-- line #26828
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLOSWIFT 20 (Ind-Swift)',
	'Piroxicam',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLOSWIFT 20 (Ind-Swift)'
);

-- line #26829
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLOSWIFT 20 (Ind-Swift)',
	'Piroxicam',
	'DT',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLOSWIFT 20 (Ind-Swift)'
);

-- line #26830
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLOSWIFT 2 (Ind-Swift)',
	'Piroxicam',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLOSWIFT 2 (Ind-Swift)'
);

-- line #26831
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUPOX 20 (Bennet Ph.)',
	'Piroxicam',
	'DT',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUPOX 20 (Bennet Ph.)'
);

-- line #26832
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUPOX 40 (Bennet Ph.)',
	'Piroxicam',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUPOX 40 (Bennet Ph.)'
);

-- line #26833
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ECWIN 0.5 (Alembic)',
	'Piroxicam',
	'GEL',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ECWIN 0.5 (Alembic)'
);

-- line #26834
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FELCAM 20 (Sun)',
	'Piroxicam',
	'DT',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FELCAM 20 (Sun)'
);

-- line #26835
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FELCAM 0.5 (Sun)',
	'Piroxicam',
	'GEL',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FELCAM 0.5 (Sun)'
);

-- line #26836
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FELDEX 20 (Sun)',
	'Piroxicam',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FELDEX 20 (Sun)'
);

-- line #26837
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INFLAVAN 10 (Khandelwal)',
	'Piroxicam',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INFLAVAN 10 (Khandelwal)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INFLAVAN 20 (Khandelwal)',
	'Piroxicam',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INFLAVAN 20 (Khandelwal)'
);

-- line #26838
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IROX 20 (Ultramark)',
	'Piroxicam',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IROX 20 (Ultramark)'
);

-- line #26839
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEMONEX 20 (Chemo D.)',
	'Piroxicam',
	'DT',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEMONEX 20 (Chemo D.)'
);

-- line #26840
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELOXI 20 (Bal Ph.)',
	'Piroxicam',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELOXI 20 (Bal Ph.)'
);

-- line #26841
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICROPEC 20 (Dr.Reddy''S)',
	'Piroxicam',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICROPEC 20 (Dr.Reddy''S)'
);

-- line #26842
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MINICAM 20 (Blue Cross)',
	'Piroxicam',
	'DT',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MINICAM 20 (Blue Cross)'
);

-- line #26843
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,5', u'strength_2': u'', u'substance': u'Piroxicam', u'always_empty': u'', u'form': u'', u'brand': u'MINICAM-GEL', u'strength_3': u'', u'company': u'Blue Cross', u'unit': u'%'}

-- line #26844
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOBICAM 20 (Cipla)',
	'Piroxicam',
	'DT',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOBICAM 20 (Cipla)'
);

-- line #26845
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Piroxicam', u'always_empty': u'', u'form': u'GEL', u'brand': u'MOBICAM', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #26846
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOBIDIN 20 (Centaur)',
	'Piroxicam',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOBIDIN 20 (Centaur)'
);

-- line #26847
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MODACT 20 (Merind)',
	'Piroxicam',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MODACT 20 (Merind)'
);

-- line #26848
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOVEN 0.5 (Ipca)',
	'Piroxicam',
	'GEL',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOVEN 0.5 (Ipca)'
);

-- line #26849
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOVON-20 20 (Ipca)',
	'Piroxicam',
	'CAP/DT',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOVON-20 20 (Ipca)'
);

-- line #26850
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOVON 20 (Ipca)',
	'Piroxicam',
	'DT',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOVON 20 (Ipca)'
);

-- line #26851
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOVON 0.5 (Ipca)',
	'Piroxicam',
	'GEL',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOVON 0.5 (Ipca)'
);

-- line #26852
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NESPREX 20 (Nestor)',
	'Piroxicam',
	'DT',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NESPREX 20 (Nestor)'
);

-- line #26853
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEXICAM 20 (Brooks Ph.)',
	'Piroxicam',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEXICAM 20 (Brooks Ph.)'
);

-- line #26854
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODD 20 (Logos)',
	'Piroxicam',
	'DT',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODD 20 (Logos)'
);

-- line #26855
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXYCAM 40 (Solitaire)',
	'Piroxicam',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXYCAM 40 (Solitaire)'
);

-- line #26856
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAM 20 (EAST WEST)',
	'Piroxicam',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAM 20 (EAST WEST)'
);

-- line #26857
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAM 20 (EAST WEST)',
	'Piroxicam',
	'DT',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAM 20 (EAST WEST)'
);

-- line #26858
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANCAM 1 (TALENT LAB.)',
	'Piroxicam',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANCAM 1 (TALENT LAB.)'
);

-- line #26859
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANOROX 20 (Ultramark)',
	'Piroxicam',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANOROX 20 (Ultramark)'
);

-- line #26860
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERICAM 10 (Zydus A.)',
	'Piroxicam',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERICAM 10 (Zydus A.)'
);

-- line #26861
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERICAM 20 (Zydus A.)',
	'Piroxicam',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERICAM 20 (Zydus A.)'
);

-- line #26862
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PINIJ 20 (Sunij)',
	'Piroxicam',
	'DT',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PINIJ 20 (Sunij)'
);

-- line #26863
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIODEX 20 (Intra Lab)',
	'Piroxicam',
	'DT',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIODEX 20 (Intra Lab)'
);

-- line #26864
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIRICAM 10 (Zydus Cadila)',
	'Piroxicam',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIRICAM 10 (Zydus Cadila)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIRICAM 20 (Zydus Cadila)',
	'Piroxicam',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIRICAM 20 (Zydus Cadila)'
);

-- line #26865
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIRON 20 (Patson)',
	'Piroxicam',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIRON 20 (Patson)'
);

-- line #26866
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIROX 10 (Cipla)',
	'Piroxicam',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIROX 10 (Cipla)'
);

-- line #26867
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIROX 20 (Cipla)',
	'Piroxicam',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIROX 20 (Cipla)'
);

-- line #26868
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIROX 20 (Cipla)',
	'Piroxicam',
	'DT',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIROX 20 (Cipla)'
);

-- line #26869
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIROX 0.5 (Cipla)',
	'Piroxicam',
	'GEL',
	gm.nullify_empty_string('0.5')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIROX 0.5 (Cipla)'
);

-- line #26870
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIROXIAT 40 (Atoz Ph.)',
	'Piroxicam',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIROXIAT 40 (Atoz Ph.)'
);

-- line #26871
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Piroxicam', u'always_empty': u'', u'form': u'AMP', u'brand': u'PIROXINA', u'strength_3': u'', u'company': u'Sayona', u'unit': u''}

-- line #26872
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIROXINA 20 (Sayona)',
	'Piroxicam',
	'DT',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIROXINA 20 (Sayona)'
);

-- line #26873
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIROX 20 (Cipla)',
	'Piroxicam',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIROX 20 (Cipla)'
);

-- line #26874
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIROXIVAR 40 (Zota Ph.)',
	'Piroxicam',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIROXIVAR 40 (Zota Ph.)'
);

-- line #26875
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIROXIZED 40 (ZOTA)',
	'Piroxicam',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIROXIZED 40 (ZOTA)'
);

-- line #26876
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROXYC-FT 10 (Emcure)',
	'Piroxicam',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROXYC-FT 10 (Emcure)'
);

-- line #26877
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROXYC 0.5 (Emcure)',
	'Piroxicam',
	'GEL',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROXYC 0.5 (Emcure)'
);

-- line #26878
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROXY 20 (Dial Ph.)',
	'Piroxicam',
	'DT',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROXY 20 (Dial Ph.)'
);

-- line #26879
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40', u'strength_2': u'', u'substance': u'Piroxicam', u'always_empty': u'', u'form': u'', u'brand': u'PROXYM PATCH', u'strength_3': u'', u'company': u'Emcure', u'unit': u'mg'}

-- line #26880
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYRAS 40 (RASS HC.)',
	'Piroxicam',
	'AMP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYRAS 40 (RASS HC.)'
);

-- line #26881
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYRAS 20 (RASS HC.)',
	'Piroxicam',
	'DT TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYRAS 20 (RASS HC.)'
);

-- line #26882
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'(BETA CYCLODEXTRINE)', u'strength_2': u'', u'substance': u'Piroxicam', u'always_empty': u'', u'form': u'TAB', u'brand': u'PYRODEX', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #26883
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOVAS 1 (Ipca)',
	'PITAVASTATIN',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOVAS 1 (Ipca)'
);

-- line #26884
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOVAS 2 (Ipca)',
	'PITAVASTATIN',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOVAS 2 (Ipca)'
);

-- line #26885
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5', u'strength_2': u'', u'substance': u'PLASMA FRACTION(HUMAN)', u'always_empty': u'', u'form': u'', u'brand': u'PLASMANATE', u'strength_3': u'', u'company': u'Bharat S.', u'unit': u'% - 12.5G'}

-- line #26886
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'PNEUMOCOCCAL CONJUGATED VACCINE', u'always_empty': u'', u'form': u'VACCINE', u'brand': u'PREVENAR', u'strength_3': u'', u'company': u'WYETH', u'unit': u''}

-- line #26887
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'PNEUMOCOCCAL VACCINE', u'always_empty': u'', u'form': u'INJ', u'brand': u'PNEUMO', u'strength_3': u'', u'company': u'Aventis Pas.', u'unit': u''}

-- line #26888
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'PNEUMOCOCCAL VACCINE', u'always_empty': u'', u'form': u'INJ', u'brand': u'PNU-IMMUNE', u'strength_3': u'', u'company': u'Wyeth', u'unit': u''}

-- line #26889
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONDYLINE 5 (Elder)',
	'Podophyllotoxin',
	'SOL',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONDYLINE 5 (Elder)'
);

-- line #26890
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'Podophyllum Resin', u'always_empty': u'', u'form': u'', u'brand': u'PODOWART PAINT', u'strength_3': u'', u'company': u'Shalaks', u'unit': u'%'}

-- line #26891
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COSANOL 20 (Mano Ph.)',
	'Policosanol',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COSANOL 20 (Mano Ph.)'
);

-- line #26892
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COSANOL 5 (Mano Ph.)',
	'Policosanol',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COSANOL 5 (Mano Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COSANOL 10 (Mano Ph.)',
	'Policosanol',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COSANOL 10 (Mano Ph.)'
);

-- line #26893
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POLICHOL 5 (Pharmed)',
	'Policosanol',
	'CAP',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POLICHOL 5 (Pharmed)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POLICHOL 10 (Pharmed)',
	'Policosanol',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POLICHOL 10 (Pharmed)'
);

-- line #26894
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'360', u'strength_2': u'', u'substance': u'Policresulin', u'always_empty': u'', u'form': u'', u'brand': u'ALBOTHYL CONC', u'strength_3': u'', u'company': u'Glat', u'unit': u'mg/G'}

-- line #26895
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBOTHYL 18 (Glat)',
	'Policresulin',
	'TUBE',
	gm.nullify_empty_string('18')::numeric,
	'mg/G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBOTHYL 18 (Glat)'
);

-- line #26896
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AETHOXYSKLEROL 3 (Walter B.)',
	'Polidocanol',
	'AMP',
	gm.nullify_empty_string('3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AETHOXYSKLEROL 3 (Walter B.)'
);

-- line #26897
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASKLEROL 3 (Samarth)',
	'Polidocanol',
	'INJ',
	gm.nullify_empty_string('3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASKLEROL 3 (Samarth)'
);

-- line #26898
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'INACTIVATED POLIMYELITIS VACCINE INACTIVATED SALK POLIO VIRUS TYPE 1:40 D ANTIGEN UNITS INACTIVATED SALK POLIO VIRUS TYPE 2:8D ANTIGEN UNITS', u'strength_2': u'', u'substance': u'Polio Vaccine', u'always_empty': u'', u'form': u'VIAL', u'brand': u'ERAPOL', u'strength_3': u'', u'company': u'Biolgical', u'unit': u''}

-- line #26899
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Polio Vaccine', u'always_empty': u'', u'form': u'VACCINE', u'brand': u'OPV', u'strength_3': u'', u'company': u'Aventis Pas.', u'unit': u''}

-- line #26900
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Polio Vaccine', u'always_empty': u'', u'form': u'', u'brand': u'ORAL POLIO', u'strength_3': u'', u'company': u'Aventis Pas.', u'unit': u''}

-- line #26901
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Polio Vaccine', u'always_empty': u'', u'form': u'', u'brand': u'ORAL POLIO', u'strength_3': u'', u'company': u'Haffkine', u'unit': u''}

-- line #26902
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Polio Vaccine', u'always_empty': u'', u'form': u'', u'brand': u'ORAL POLIO', u'strength_3': u'', u'company': u'Panacea', u'unit': u''}

-- line #26903
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Polio Vaccine', u'always_empty': u'', u'form': u'VACCINE', u'brand': u'POLIOMYELITIS', u'strength_3': u'', u'company': u'Biomed', u'unit': u''}

-- line #26904
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Polio Vaccine', u'always_empty': u'', u'form': u'', u'brand': u'POLIO SABIN(ORAL)', u'strength_3': u'', u'company': u'Gsk', u'unit': u''}

-- line #26905
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'ENHANCED INACTIVATED POLIOMYELITIS VACCINE', u'strength_2': u'', u'substance': u'Polio Vaccine', u'always_empty': u'', u'form': u'VACCINE', u'brand': u'POLPROTEC', u'strength_3': u'', u'company': u'Chiron Pan.', u'unit': u''}

-- line #26906
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIQUIFILM TEARS 1.4 (Allergan)',
	'Polivinyl Alcohol',
	'DPS',
	gm.nullify_empty_string('1.4')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIQUIFILM TEARS 1.4 (Allergan)'
);

-- line #26907
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PVA TEARS 1.4 (Sante V.)',
	'Polivinyl Alcohol',
	'DPS',
	gm.nullify_empty_string('1.4')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PVA TEARS 1.4 (Sante V.)'
);

-- line #26908
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARBOCIUM 625 (Ajanta Ph.)',
	'Polycarbophil',
	'TAB',
	gm.nullify_empty_string('625')::numeric,
	'mg(CALCIUM)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARBOCIUM 625 (Ajanta Ph.)'
);

-- line #26909
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIBOTAB 500 (Torrent)',
	'Polycarbophil',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIBOTAB 500 (Torrent)'
);

-- line #26910
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUCOMOIST 2 (PROTEC THER.)',
	'Polycarbophil',
	'GEL',
	gm.nullify_empty_string('2')::numeric,
	'%/G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUCOMOIST 2 (PROTEC THER.)'
);

-- line #26911
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REJOIS VAG 2 (Astrazeneca)',
	'Polycarbophil',
	'GEL',
	gm.nullify_empty_string('2')::numeric,
	'%/G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REJOIS VAG 2 (Astrazeneca)'
);

-- line #26912
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AEROMYCIN 500 (Astrum Hc.)',
	'Polymyxin B Sulph.',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'000U.'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AEROMYCIN 500 (Astrum Hc.)'
);

-- line #26913
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500000U.', u'strength_2': u'', u'substance': u'Polymyxin B Sulph.', u'always_empty': u'', u'form': u'V', u'brand': u'AEROSPORIN', u'strength_3': u'', u'company': u'Gsk', u'unit': u''}

-- line #26914
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500000U.', u'strength_2': u'', u'substance': u'Polymyxin B Sulph.', u'always_empty': u'', u'form': u'VIAL', u'brand': u'POLY-B', u'strength_3': u'', u'company': u'Samarth', u'unit': u''}

-- line #26915
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500000U.', u'strength_2': u'', u'substance': u'Polymyxin B Sulph.', u'always_empty': u'', u'form': u'', u'brand': u'POLY-MXB LAC UNIT', u'strength_3': u'', u'company': u'Bharat S.', u'unit': u''}

-- line #26916
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500000IU', u'strength_2': u'', u'substance': u'Polymyxin B Sulph.', u'always_empty': u'', u'form': u'VIAL', u'brand': u'POLYXX', u'strength_3': u'', u'company': u'CELON(REVILON)', u'unit': u''}

-- line #26917
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1', u'strength_2': u'', u'substance': u'POLYTAR', u'always_empty': u'', u'form': u'', u'brand': u'POLYTAR BAR', u'strength_3': u'', u'company': u'Elder', u'unit': u'%'}

-- line #26918
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u' %', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'7.3+CARRAGEENAN USNF 0.91', u'strength_2': u'', u'substance': u'Polyvinyl Alcohol', u'always_empty': u'', u'form': u'', u'brand': u'HYDROHEAL (5X5CM)', u'strength_3': u'', u'company': u"DR. REDDY''S", u'unit': u'%'}

-- line #26919
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KAY-CIEL 500 (Stadmed)',
	'Potassium Chloride',
	'LIQ',
	gm.nullify_empty_string('500')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KAY-CIEL 500 (Stadmed)'
);

-- line #26920
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'K CARD 600 (Wockhardt)',
	'Potassium Chloride',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'K CARD 600 (Wockhardt)'
);

-- line #26921
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.5G', u'strength_2': u'15ML', u'substance': u'Potassium Chloride', u'always_empty': u'', u'form': u'SYR', u'brand': u'KEYLYTE', u'strength_3': u'', u'company': u'Wallace', u'unit': u''}

-- line #26922
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'K-GRAD 600 (Wockhardt)',
	'Potassium Chloride',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'K-GRAD 600 (Wockhardt)'
);

-- line #26923
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.5G', u'strength_2': u'15ML', u'substance': u'Potassium Chloride', u'always_empty': u'', u'form': u'SYR', u'brand': u'P-CHLOR', u'strength_3': u'', u'company': u'Ind-Swift', u'unit': u''}

-- line #26924
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.5G', u'strength_2': u'15ML', u'substance': u'Potassium Chloride', u'always_empty': u'', u'form': u'SYR', u'brand': u'POTASOL', u'strength_3': u'', u'company': u'Indoco Rem.', u'unit': u''}

-- line #26925
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POTCL 150 (Neon)',
	'Potassium Chloride',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POTCL 150 (Neon)'
);

-- line #26926
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.5G', u'strength_2': u'15ML', u'substance': u'Potassium Chloride', u'always_empty': u'', u'form': u'LIQ', u'brand': u'POTKLOR', u'strength_3': u'', u'company': u'Walter B.', u'unit': u''}

-- line #26927
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POTRELEASE 600 (Natco Ph.)',
	'Potassium Chloride',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POTRELEASE 600 (Natco Ph.)'
);

-- line #26928
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1', u'strength_2': u'', u'substance': u'Potassium IODINE', u'always_empty': u'', u'form': u'', u'brand': u'MEGARINSE', u'strength_3': u'', u'company': u'Group Ph.', u'unit': u'%W/W'}

-- line #26929
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Pot.Nit.', u'always_empty': u'', u'form': u'MOUTH WASH', u'brand': u'ACCENT', u'strength_3': u'', u'company': u'Zee Lab', u'unit': u''}

-- line #26930
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Pot.Nit.', u'always_empty': u'', u'form': u'TOOTH PASTE', u'brand': u'ACCENT', u'strength_3': u'', u'company': u'Zee Lab', u'unit': u''}

-- line #26931
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AQUADENT-K 5 (Intra Lab)',
	'Pot.Nit.',
	'TOOTH PASTE',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AQUADENT-K 5 (Intra Lab)'
);

-- line #26932
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5', u'strength_2': u'', u'substance': u'Pot.Nit.', u'always_empty': u'', u'form': u'', u'brand': u'CUREDENT-K PASTE', u'strength_3': u'', u'company': u'Cure Quick', u'unit': u'%'}

-- line #26933
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DENCARE 5 (VENSAT)',
	'Pot.Nit.',
	'T-PASTE',
	gm.nullify_empty_string('5')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DENCARE 5 (VENSAT)'
);

-- line #26934
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Pot.Nit.', u'always_empty': u'', u'form': u'TOOTH PASTE', u'brand': u'DENOPOT', u'strength_3': u'', u'company': u'Sanify', u'unit': u''}

-- line #26935
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Pot.Nit.', u'always_empty': u'', u'form': u'TOOTH PASTE', u'brand': u'DENTRA-K', u'strength_3': u'', u'company': u'Intra Lab', u'unit': u''}

-- line #26936
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DENTRA 5 (Intra Lab)',
	'Pot.Nit.',
	'TOOTH PASTE',
	gm.nullify_empty_string('5')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DENTRA 5 (Intra Lab)'
);

-- line #26937
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5', u'strength_2': u'', u'substance': u'Pot.Nit.', u'always_empty': u'', u'form': u'', u'brand': u'DESFLOR TOOTHPASTE', u'strength_3': u'', u'company': u"D.R.John''S", u'unit': u'%W/V'}

-- line #26938
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5', u'strength_2': u'', u'substance': u'Pot.Nit.', u'always_empty': u'', u'form': u'', u'brand': u'DONOSEAL TOOTHPASTE', u'strength_3': u'', u'company': u'Fourrts', u'unit': u'%'}

-- line #26939
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'IN FLAVOURED BASE', u'strength_2': u'', u'substance': u'Pot.Nit.', u'always_empty': u'', u'form': u'TOOTH PASTE', u'brand': u'EMOFORM', u'strength_3': u'', u'company': u'Jl Morison', u'unit': u''}

-- line #26940
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'K-DENT 5 (Centaur)',
	'Pot.Nit.',
	'GEL',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'K-DENT 5 (Centaur)'
);

-- line #26941
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEDENT 5 (Lexus)',
	'Pot.Nit.',
	'TOOTH PASTE',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEDENT 5 (Lexus)'
);

-- line #26942
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAGDENT-K 5 (Magnus Bio.)',
	'Pot.Nit.',
	'TOOTH PASTE',
	gm.nullify_empty_string('5')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAGDENT-K 5 (Magnus Bio.)'
);

-- line #26943
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5', u'strength_2': u'', u'substance': u'Pot.Nit.', u'always_empty': u'', u'form': u'', u'brand': u'MENTHODIN-P', u'strength_3': u'', u'company': u'TALENT LAB.', u'unit': u'%W/W'}

-- line #26944
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5', u'strength_2': u'', u'substance': u'Pot.Nit.', u'always_empty': u'', u'form': u'', u'brand': u'NUDENT PASTE', u'strength_3': u'', u'company': u'MICRO LABS', u'unit': u'%'}

-- line #26945
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5', u'strength_2': u'', u'substance': u'Pot.Nit.', u'always_empty': u'', u'form': u'', u'brand': u'PLUS-K PASTE', u'strength_3': u'', u'company': u'Runa Ph.', u'unit': u'%'}

-- line #26946
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5', u'strength_2': u'', u'substance': u'Pot.Nit.', u'always_empty': u'', u'form': u'', u'brand': u'PLUS-K PASTE', u'strength_3': u'', u'company': u'Runa Ph.', u'unit': u'%W/W'}

-- line #26947
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYOGIN-K 5 (Unimarck)',
	'Pot.Nit.',
	'TOOTH PASTE',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYOGIN-K 5 (Unimarck)'
);

-- line #26948
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AGLODINE 5 (Aglowmed)',
	'Povidone Iodine',
	'OINT',
	gm.nullify_empty_string('5')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AGLODINE 5 (Aglowmed)'
);

-- line #26949
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPHADINE 1 (Piramal Hc.)',
	'Povidone Iodine',
	'GARGLE',
	gm.nullify_empty_string('1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPHADINE 1 (Piramal Hc.)'
);

-- line #26950
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPHADINE 5 (Nicholas)',
	'Povidone Iodine',
	'OINT',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPHADINE 5 (Nicholas)'
);

-- line #26951
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPHADINE 5 (Nicholas)',
	'Povidone Iodine',
	'POW',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPHADINE 5 (Nicholas)'
);

-- line #26952
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPHADINE 5 (Nicholas)',
	'Povidone Iodine',
	'SOL',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPHADINE 5 (Nicholas)'
);

-- line #26953
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPHADINE 5 (Nicholas)',
	'Povidone Iodine',
	'VAGINAL PESSARIES',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPHADINE 5 (Nicholas)'
);

-- line #26954
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPHADIN RF 5 (Piramal Hc.)',
	'Povidone Iodine',
	'OINT',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPHADIN RF 5 (Piramal Hc.)'
);

-- line #26955
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BALVIDINE 5 (Bal Ph.)',
	'Povidone Iodine',
	'OINT/SOL',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BALVIDINE 5 (Bal Ph.)'
);

-- line #26956
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Povidone Iodine', u'always_empty': u'', u'form': u'CRM', u'brand': u'BATODINE', u'strength_3': u'', u'company': u'NIVCA', u'unit': u''}

-- line #26957
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETADAL 5 (Alive)',
	'Povidone Iodine',
	'OINT',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETADAL 5 (Alive)'
);

-- line #26958
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETADAL 5 (Alive)',
	'Povidone Iodine',
	'SOL',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETADAL 5 (Alive)'
);

-- line #26959
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETADINE AD 4 (Win-Medicare)',
	'Povidone Iodine',
	'SOL',
	gm.nullify_empty_string('4')::numeric,
	'%(A.D.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETADINE AD 4 (Win-Medicare)'
);

-- line #26960
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETADINE 5 (Win Medicare)',
	'Povidone Iodine',
	'CRM',
	gm.nullify_empty_string('5')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETADINE 5 (Win Medicare)'
);

-- line #26961
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETADINE 1 (Win-Medicare)',
	'Povidone Iodine',
	'GARGLE',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETADINE 1 (Win-Medicare)'
);

-- line #26962
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETADINE 2 (Win-Medicare)',
	'Povidone Iodine',
	'GARGLE',
	gm.nullify_empty_string('2')::numeric,
	'%W/V (8.38'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETADINE 2 (Win-Medicare)'
);

-- line #26963
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETADINE 5 (Win-Medicare)',
	'Povidone Iodine',
	'OINT',
	gm.nullify_empty_string('5')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETADINE 5 (Win-Medicare)'
);

-- line #26964
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10', u'strength_2': u'', u'substance': u'Povidone Iodine', u'always_empty': u'', u'form': u'', u'brand': u'BETADINE PAINT', u'strength_3': u'', u'company': u'Win Medicare', u'unit': u'%W/W'}

-- line #26965
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200', u'strength_2': u'', u'substance': u'Povidone Iodine', u'always_empty': u'', u'form': u'', u'brand': u'BETADINE PESS', u'strength_3': u'', u'company': u'Win-Medicare', u'unit': u'mg'}

-- line #26966
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETADINE 5 (Win-Medicare)',
	'Povidone Iodine',
	'POW',
	gm.nullify_empty_string('5')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETADINE 5 (Win-Medicare)'
);

-- line #26967
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETADINE STD-L 5 (Win-Medicare)',
	'Povidone Iodine',
	'SOL',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETADINE STD-L 5 (Win-Medicare)'
);

-- line #26968
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETADINE STD 10 (Win-Medicare)',
	'Povidone Iodine',
	'SOL %',
	gm.nullify_empty_string('10')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETADINE STD 10 (Win-Medicare)'
);

-- line #26969
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETADINE STD 5 (Win-Medicare)',
	'Povidone Iodine',
	'SOL',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETADINE STD 5 (Win-Medicare)'
);

-- line #26970
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETADINE SURG SCRUB 7.5 (Win-Medicare)',
	'Povidone Iodine',
	'SOL500',
	gm.nullify_empty_string('7.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETADINE SURG SCRUB 7.5 (Win-Medicare)'
);

-- line #26971
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETADINE SURG SCRUB 7.5 (Win-Medicare)',
	'Povidone Iodine',
	'SOL',
	gm.nullify_empty_string('7.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETADINE SURG SCRUB 7.5 (Win-Medicare)'
);

-- line #26972
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETAKIND 2 (Mankind)',
	'Povidone Iodine',
	'GARGLE',
	gm.nullify_empty_string('2')::numeric,
	'%W/V(0.2'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETAKIND 2 (Mankind)'
);

-- line #26973
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1', u'strength_2': u'', u'substance': u'Povidone Iodine', u'always_empty': u'', u'form': u'', u'brand': u'BETAKIND GARLGE', u'strength_3': u'', u'company': u'Mankind', u'unit': u'%W/V'}

-- line #26974
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIODINE 5 (Alpha Hc.)',
	'Povidone Iodine',
	'OINT',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIODINE 5 (Alpha Hc.)'
);

-- line #26975
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAVIDON 0.1 (Greenco Bio.)',
	'Povidone Iodine',
	'MOUTHWASH',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAVIDON 0.1 (Greenco Bio.)'
);

-- line #26976
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10', u'strength_2': u'20;G', u'substance': u'Povidone Iodine', u'always_empty': u'', u'form': u'OINT', u'brand': u'CIPLADINE', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #26977
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPLADINE 5 (Cipla)',
	'Povidone Iodine',
	'POW',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPLADINE 5 (Cipla)'
);

-- line #26978
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPLADINE 5 (Cipla)',
	'Povidone Iodine',
	'SOL',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPLADINE 5 (Cipla)'
);

-- line #26979
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COVIDON 0.5 (Greenco Bio.)',
	'Povidone Iodine',
	'SOL',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COVIDON 0.5 (Greenco Bio.)'
);

-- line #26980
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COVIDON TOPICAL 1 (Greenco Bio.)',
	'Povidone Iodine',
	'OINT',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COVIDON TOPICAL 1 (Greenco Bio.)'
);

-- line #26981
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DERZ % 10 (Stedman)',
	'Povidone Iodine',
	'SOL',
	gm.nullify_empty_string('10')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DERZ % 10 (Stedman)'
);

-- line #26982
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Povidone Iodine', u'always_empty': u'', u'form': u'OINT', u'brand': u'DIVIDONE', u'strength_3': u'', u'company': u'DIVINE LAB.', u'unit': u''}

-- line #26983
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DONE 5 (ROSE LABS)',
	'Povidone Iodine',
	'OINT',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DONE 5 (ROSE LABS)'
);

-- line #26984
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DRESS-UP 5 (AUGMENT REM.)',
	'Povidone Iodine',
	'OINT',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DRESS-UP 5 (AUGMENT REM.)'
);

-- line #26985
-- ignoring line: field [strength_1] not numeric: >>>10W<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10W', u'strength_2': u'W(1.0', u'substance': u'Povidone Iodine', u'always_empty': u'', u'form': u'OINT', u'brand': u'DREZ %', u'strength_3': u'', u'company': u'Stedman', u'unit': u'%W/V IODINE)'}

-- line #26986
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DREZ % 10 (Stedman)',
	'Povidone Iodine',
	'SOL',
	gm.nullify_empty_string('10')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DREZ % 10 (Stedman)'
);

-- line #26987
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYNADIN % 10 (Dynamic)',
	'Povidone Iodine',
	'SOL',
	gm.nullify_empty_string('10')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYNADIN % 10 (Dynamic)'
);

-- line #26988
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYNADIN 5 (Dynamic)',
	'Povidone Iodine',
	'SOL',
	gm.nullify_empty_string('5')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYNADIN 5 (Dynamic)'
);

-- line #26989
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ECOSEPTIC 5 (Helios Ph.)',
	'Povidone Iodine',
	'OZ',
	gm.nullify_empty_string('5')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ECOSEPTIC 5 (Helios Ph.)'
);

-- line #26990
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMYDINE 5 (Emil Ph.)',
	'Povidone Iodine',
	'OINT',
	gm.nullify_empty_string('5')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMYDINE 5 (Emil Ph.)'
);

-- line #26991
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENODINE-S 5 (Emcure)',
	'Povidone Iodine',
	'OINT',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENODINE-S 5 (Emcure)'
);

-- line #26992
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEALFAST 5 (Kinedex Hc.)',
	'Povidone Iodine',
	'OINT',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEALFAST 5 (Kinedex Hc.)'
);

-- line #26993
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'7,5', u'strength_2': u'', u'substance': u'Povidone Iodine', u'always_empty': u'', u'form': u'', u'brand': u'HEALFAST SCRUB', u'strength_3': u'', u'company': u'Kinedex Hc', u'unit': u'%W/V'}

-- line #26994
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEALFAST 10 (Kinedex Hc.)',
	'Povidone Iodine',
	'SOL',
	gm.nullify_empty_string('10')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEALFAST 10 (Kinedex Hc.)'
);

-- line #26995
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEALOL 5 (SH PH.)',
	'Povidone Iodine',
	'OINT',
	gm.nullify_empty_string('5')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEALOL 5 (SH PH.)'
);

-- line #26996
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEALOL 5 (SH PH.)',
	'Povidone Iodine',
	'POW',
	gm.nullify_empty_string('5')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEALOL 5 (SH PH.)'
);

-- line #26997
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEALOL 5 (SH PH.)',
	'Povidone Iodine',
	'SOLU',
	gm.nullify_empty_string('5')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEALOL 5 (SH PH.)'
);

-- line #26998
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IOCANDIM 5 (Candor Bio.)',
	'Povidone Iodine',
	'OINT',
	gm.nullify_empty_string('5')::numeric,
	'%;W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IOCANDIM 5 (Candor Bio.)'
);

-- line #26999
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IOCANDIM 5 (Candor Bio.)',
	'Povidone Iodine',
	'SOL',
	gm.nullify_empty_string('5')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IOCANDIM 5 (Candor Bio.)'
);

-- line #27000
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IODOLAN 1 (East India)',
	'Povidone Iodine',
	'GARGLE',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IODOLAN 1 (East India)'
);

-- line #27001
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IODOLAN 5 (East India)',
	'Povidone Iodine',
	'OINT',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IODOLAN 5 (East India)'
);

-- line #27002
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IODOLAN 5 (East India)',
	'Povidone Iodine',
	'SOL',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IODOLAN 5 (East India)'
);

-- line #27003
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IOPREP 1 (J. & J.)',
	'Povidone Iodine',
	'SOL',
	gm.nullify_empty_string('1')::numeric,
	'%(SOD.IODIDE SURFACTANT BASE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IOPREP 1 (J. & J.)'
);

-- line #27004
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEXIDONE 5 (Cadex Lab)',
	'Povidone Iodine',
	'OINT',
	gm.nullify_empty_string('5')::numeric,
	'%;W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEXIDONE 5 (Cadex Lab)'
);

-- line #27005
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAKDINE 5 (Shalaks)',
	'Povidone Iodine',
	'SOL',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAKDINE 5 (Shalaks)'
);

-- line #27006
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'L-DON 1 (LUSTRE)',
	'Povidone Iodine',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'L-DON 1 (LUSTRE)'
);

-- line #27007
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LODOLAN 5 (East India)',
	'Povidone Iodine',
	'OINT/SOLN',
	gm.nullify_empty_string('5')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LODOLAN 5 (East India)'
);

-- line #27008
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'15G', u'strength_2': u'', u'substance': u'Povidone Iodine', u'always_empty': u'', u'form': u'OINT', u'brand': u'MEDIDINE', u'strength_3': u'', u'company': u'HANDS PH.', u'unit': u''}

-- line #27009
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METROKIND-PV 5 (LIFESTAR)',
	'Povidone Iodine',
	'OINT',
	gm.nullify_empty_string('5')::numeric,
	'%W/W(AVAILABLE IODINE 0.5'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METROKIND-PV 5 (LIFESTAR)'
);

-- line #27010
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICRODINE 5 (Centaur)',
	'Povidone Iodine',
	'DPS',
	gm.nullify_empty_string('5')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICRODINE 5 (Centaur)'
);

-- line #27011
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICRODINE 5 (Centaur)',
	'Povidone Iodine',
	'OINT',
	gm.nullify_empty_string('5')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICRODINE 5 (Centaur)'
);

-- line #27012
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICRODINE 5 (Centaur)',
	'Povidone Iodine',
	'SOL',
	gm.nullify_empty_string('5')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICRODINE 5 (Centaur)'
);

-- line #27013
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICROSHIELD PVP-P/S 10 (J.&J.)',
	'Povidone Iodine',
	'SOL100',
	gm.nullify_empty_string('10')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICROSHIELD PVP-P/S 10 (J.&J.)'
);

-- line #27014
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICROSHIELD PVP P/S 10 (J.&J.)',
	'Povidone Iodine',
	'SOL500',
	gm.nullify_empty_string('10')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICROSHIELD PVP P/S 10 (J.&J.)'
);

-- line #27015
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICROSHIELD PVP 7.5 (J.&J.)',
	'Povidone Iodine',
	'SOL',
	gm.nullify_empty_string('7.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICROSHIELD PVP 7.5 (J.&J.)'
);

-- line #27016
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MISODINE 5 (Varun Life)',
	'Povidone Iodine',
	'OINT',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MISODINE 5 (Varun Life)'
);

-- line #27017
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NESTOINE 5 (Nestor)',
	'Povidone Iodine',
	'OINT',
	gm.nullify_empty_string('5')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NESTOINE 5 (Nestor)'
);

-- line #27018
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEXIDIN 5 (Biocin Hc.)',
	'Povidone Iodine',
	'OINT',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEXIDIN 5 (Biocin Hc.)'
);

-- line #27019
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVADIN 5 (Genova)',
	'Povidone Iodine',
	'SOL',
	gm.nullify_empty_string('5')::numeric,
	'%;W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVADIN 5 (Genova)'
);

-- line #27020
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLDINE 5 (Olcare)',
	'Povidone Iodine',
	'CRM',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLDINE 5 (Olcare)'
);

-- line #27021
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLDINE 5 (Olcare)',
	'Povidone Iodine',
	'SOL',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLDINE 5 (Olcare)'
);

-- line #27022
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OVIDINE 5 (Ind-Swift)',
	'Povidone Iodine',
	'CRM/OINT',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OVIDINE 5 (Ind-Swift)'
);

-- line #27023
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OVIDINE 5 (Ind-Swift)',
	'Povidone Iodine',
	'OINT',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OVIDINE 5 (Ind-Swift)'
);

-- line #27024
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OVIDINE 5 (Ind-Swift)',
	'Povidone Iodine',
	'POW',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OVIDINE 5 (Ind-Swift)'
);

-- line #27025
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OVIDINE 5 (Ind-Swift)',
	'Povidone Iodine',
	'SOL',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OVIDINE 5 (Ind-Swift)'
);

-- line #27026
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'P-DON 5 (Intra Lab)',
	'Povidone Iodine',
	'OINT',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'P-DON 5 (Intra Lab)'
);

-- line #27027
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'P-D WEL 5 (WELABLE PH.)',
	'Povidone Iodine',
	'CRM',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'P-D WEL 5 (WELABLE PH.)'
);

-- line #27028
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERKADINE 5 (Perk Ph.)',
	'Povidone Iodine',
	'OINT',
	gm.nullify_empty_string('5')::numeric,
	'%;W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERKADINE 5 (Perk Ph.)'
);

-- line #27029
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERKADINE 5 (Perk Ph.)',
	'Povidone Iodine',
	'SOL',
	gm.nullify_empty_string('5')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERKADINE 5 (Perk Ph.)'
);

-- line #27030
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIODIN 1 (Gsk)',
	'Povidone Iodine',
	'MOUTHWASH',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIODIN 1 (Gsk)'
);

-- line #27031
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIODIN 5 (Gsk)',
	'Povidone Iodine',
	'OINT',
	gm.nullify_empty_string('5')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIODIN 5 (Gsk)'
);

-- line #27032
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIODIN 5 (Gsk)',
	'Povidone Iodine',
	'SOL',
	gm.nullify_empty_string('5')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIODIN 5 (Gsk)'
);

-- line #27033
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIVIPOL 5 (Ar-Ex Labs.)',
	'Povidone Iodine',
	'OINT',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIVIPOL 5 (Ar-Ex Labs.)'
);

-- line #27034
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIVIPOL 5 (Ar-Ex Labs.)',
	'Povidone Iodine',
	'SOL',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIVIPOL 5 (Ar-Ex Labs.)'
);

-- line #27035
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200', u'strength_2': u'', u'substance': u'Povidone Iodine', u'always_empty': u'', u'form': u'', u'brand': u'PIVIPOL-V T', u'strength_3': u'', u'company': u'Ar-Ex Labs.', u'unit': u'mg'}

-- line #27036
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLOR 1 (D.R.John''S)',
	'Povidone Iodine',
	'GARGLE',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLOR 1 (D.R.John''S)'
);

-- line #27037
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PODINE 5 (Karlin)',
	'Povidone Iodine',
	'OINT',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PODINE 5 (Karlin)'
);

-- line #27038
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Povidone Iodine', u'always_empty': u'', u'form': u'LOT', u'brand': u'PODONE', u'strength_3': u'', u'company': u'AXYZEN LIFE', u'unit': u''}

-- line #27039
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Povidone Iodine', u'always_empty': u'', u'form': u'OINT', u'brand': u'PODONE', u'strength_3': u'', u'company': u'AXYZEN LIFE', u'unit': u''}

-- line #27040
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PORIDIP 5 (Tripada BIO.)',
	'Povidone Iodine',
	'OINT',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PORIDIP 5 (Tripada BIO.)'
);

-- line #27041
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POVICIDAL 5 (Cadila Ph.)',
	'Povidone Iodine',
	'GEL',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POVICIDAL 5 (Cadila Ph.)'
);

-- line #27042
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POVICIDAL 5 (Cadila Ph.)',
	'Povidone Iodine',
	'OINT',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POVICIDAL 5 (Cadila Ph.)'
);

-- line #27043
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POVICIDAL 5 (Cadila Ph.)',
	'Povidone Iodine',
	'SOL',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POVICIDAL 5 (Cadila Ph.)'
);

-- line #27044
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POVIDAX 5 (Unique)',
	'Povidone Iodine',
	'MOUTH WASH',
	gm.nullify_empty_string('5')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POVIDAX 5 (Unique)'
);

-- line #27045
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POVIDAX % 10 (Unique)',
	'Povidone Iodine',
	'SOLN',
	gm.nullify_empty_string('10')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POVIDAX % 10 (Unique)'
);

-- line #27046
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POVIDAX % 5 (Unique)',
	'Povidone Iodine',
	'SOLN',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POVIDAX % 5 (Unique)'
);

-- line #27047
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POVIDEZ 5 (Neuron Ph.)',
	'Povidone Iodine',
	'OINT',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POVIDEZ 5 (Neuron Ph.)'
);

-- line #27048
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POVIDINE 1 (Stadmed)',
	'Povidone Iodine',
	'GARGLE',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POVIDINE 1 (Stadmed)'
);

-- line #27049
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POVIDINE 5 (Stadmed)',
	'Povidone Iodine',
	'OINT',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POVIDINE 5 (Stadmed)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POVIDINE 10 (Stadmed)',
	'Povidone Iodine',
	'OINT',
	gm.nullify_empty_string('10')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POVIDINE 10 (Stadmed)'
);

-- line #27050
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POVIDINE 5 (Stadmed)',
	'Povidone Iodine',
	'SOL',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POVIDINE 5 (Stadmed)'
);

-- line #27051
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200', u'strength_2': u'', u'substance': u'Povidone Iodine', u'always_empty': u'', u'form': u'', u'brand': u'POVIDINE-V PESS', u'strength_3': u'', u'company': u'Stadmed', u'unit': u'mg'}

-- line #27052
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POVID 5 (Bliss)',
	'Povidone Iodine',
	'OINT',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POVID 5 (Bliss)'
);

-- line #27053
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POVIDONE IODINE 10 (NPIL)',
	'Povidone Iodine',
	'SOL %',
	gm.nullify_empty_string('10')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POVIDONE IODINE 10 (NPIL)'
);

-- line #27054
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POVIDONE IODINE 5 (NPIL)',
	'Povidone Iodine',
	'SOL %',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POVIDONE IODINE 5 (NPIL)'
);

-- line #27055
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POVIDONE IODINE 7.5 (NPIL)',
	'Povidone Iodine',
	'SOL %',
	gm.nullify_empty_string('7.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POVIDONE IODINE 7.5 (NPIL)'
);

-- line #27056
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POVID 5 (Bliss)',
	'Povidone Iodine',
	'SOL',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POVID 5 (Bliss)'
);

-- line #27057
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POVID 200 (Bliss)',
	'Povidone Iodine',
	'VAGPESSARIES',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POVID 200 (Bliss)'
);

-- line #27058
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POVIN 5 (Intra Lab)',
	'Povidone Iodine',
	'OINT',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POVIN 5 (Intra Lab)'
);

-- line #27059
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Povidone Iodine', u'always_empty': u'', u'form': u'OINT', u'brand': u'POVIROM', u'strength_3': u'', u'company': u'Rhombus', u'unit': u''}

-- line #27060
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POVIRON 5 (Ronak Lab.)',
	'Povidone Iodine',
	'OINT',
	gm.nullify_empty_string('5')::numeric,
	'%;W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POVIRON 5 (Ronak Lab.)'
);

-- line #27061
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Povidone Iodine', u'always_empty': u'', u'form': u'OINT', u'brand': u'POVISAN', u'strength_3': u'', u'company': u'SANCHEZ LAB.', u'unit': u''}

-- line #27062
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POVISTAR 5 (Intra(INVISION))',
	'Povidone Iodine',
	'OINT',
	gm.nullify_empty_string('5')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POVISTAR 5 (Intra(INVISION))'
);

-- line #27063
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROVICREAM 5 (TALENT LAB.)',
	'Povidone Iodine',
	'CRM',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROVICREAM 5 (TALENT LAB.)'
);

-- line #27064
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Povidone Iodine', u'always_empty': u'', u'form': u'CRM', u'brand': u'PROVIFRESH', u'strength_3': u'', u'company': u'SMART LAB.', u'unit': u''}

-- line #27065
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'2-PAM-I 500 (Vhb)',
	'Pralidoxime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg/20ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '2-PAM-I 500 (Vhb)'
);

-- line #27066
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALDOPAM 500 (Samarth)',
	'Pralidoxime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALDOPAM 500 (Samarth)'
);

-- line #27067
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CBC PAM 500 (CH.Bhagat)',
	'Pralidoxime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CBC PAM 500 (CH.Bhagat)'
);

-- line #27068
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Pralidoxime', u'always_empty': u'', u'form': u'INJ', u'brand': u'CLOPAM', u'strength_3': u'', u'company': u'CH.Bhagat', u'unit': u''}

-- line #27069
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOPAM 500 (CH.Bhagat)',
	'Pralidoxime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg/1G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOPAM 500 (CH.Bhagat)'
);

-- line #27070
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G(WITH 20 ML SOLVENT)', u'strength_2': u'', u'substance': u'Pralidoxime', u'always_empty': u'', u'form': u'INJ', u'brand': u'LYPHE', u'strength_3': u'', u'company': u'Vhb', u'unit': u''}

-- line #27071
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOPAM 500 (Troikaa)',
	'Pralidoxime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg PAM'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOPAM 500 (Troikaa)'
);

-- line #27072
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Pralidoxime', u'always_empty': u'', u'form': u'VIAL', u'brand': u'NISPAM', u'strength_3': u'', u'company': u'Neiss', u'unit': u''}

-- line #27073
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAM-A 500 (Panacea)',
	'Pralidoxime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAM-A 500 (Panacea)'
);

-- line #27074
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAM-A KOREA 500 (SG PH.)',
	'Pralidoxime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAM-A KOREA 500 (SG PH.)'
);

-- line #27075
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRALIDOX 500 (Csc Ph.)',
	'Pralidoxime',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRALIDOX 500 (Csc Ph.)'
);

-- line #27076
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOVEXOL 0.25 (Lupin)',
	'PRAMIPEXOLE DIHCL.',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOVEXOL 0.25 (Lupin)'
);

-- line #27077
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOVEXOL 0.5 (Lupin)',
	'PRAMIPEXOLE DIHCL.',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOVEXOL 0.5 (Lupin)'
);

-- line #27078
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOVEXOL 1 (Lupin)',
	'PRAMIPEXOLE DIHCL.',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOVEXOL 1 (Lupin)'
);

-- line #27079
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARPEX 0.125 (ZYDUS N.S.)',
	'PRAMIPEXOLE DIHCL.',
	'TAB',
	gm.nullify_empty_string('0.125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARPEX 0.125 (ZYDUS N.S.)'
);

-- line #27080
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARPEX 0.25 (ZYDUS N.S.)',
	'PRAMIPEXOLE DIHCL.',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARPEX 0.25 (ZYDUS N.S.)'
);

-- line #27081
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,125', u'strength_2': u'', u'substance': u'PRAMIPEXOLE DIHCL.', u'always_empty': u'', u'form': u'', u'brand': u'PIRAMITREM', u'strength_3': u'', u'company': u'Ucb India', u'unit': u'mg'}

-- line #27082
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,25', u'strength_2': u'', u'substance': u'PRAMIPEXOLE DIHCL.', u'always_empty': u'', u'form': u'', u'brand': u'PIRAMITREM', u'strength_3': u'', u'company': u'Ucb India', u'unit': u'mg'}

-- line #27083
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,5', u'strength_2': u'', u'substance': u'PRAMIPEXOLE DIHCL.', u'always_empty': u'', u'form': u'', u'brand': u'PIRAMITREM', u'strength_3': u'', u'company': u'Ucb India', u'unit': u'mg'}

-- line #27084
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1', u'strength_2': u'', u'substance': u'PRAMIPEXOLE DIHCL.', u'always_empty': u'', u'form': u'', u'brand': u'PIRAMITREM', u'strength_3': u'', u'company': u'Ucb India', u'unit': u'mg'}

-- line #27085
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRAMIPEX 0.375 (Sun)',
	'PRAMIPEXOLE DIHCL.',
	'ER TAB',
	gm.nullify_empty_string('0.375')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRAMIPEX 0.375 (Sun)'
);

-- line #27086
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRAMIPEX 0.75 (Sun)',
	'PRAMIPEXOLE DIHCL.',
	'ER TAB',
	gm.nullify_empty_string('0.75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRAMIPEX 0.75 (Sun)'
);

-- line #27087
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRAMIXOLE 0.125 (Solus)',
	'PRAMIPEXOLE DIHCL.',
	'TAB',
	gm.nullify_empty_string('0.125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRAMIXOLE 0.125 (Solus)'
);

-- line #27088
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRAMIXOLE 0.25 (Solus)',
	'PRAMIPEXOLE DIHCL.',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRAMIXOLE 0.25 (Solus)'
);

-- line #27089
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRAMIXOLE 0.5 (Solus)',
	'PRAMIPEXOLE DIHCL.',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRAMIXOLE 0.5 (Solus)'
);

-- line #27090
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRAMIXOLE 1.5 (Solus)',
	'PRAMIPEXOLE DIHCL.',
	'TAB',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRAMIXOLE 1.5 (Solus)'
);

-- line #27091
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRAMIXOLE 1 (Solus)',
	'PRAMIPEXOLE DIHCL.',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRAMIXOLE 1 (Solus)'
);

-- line #27092
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARPEX 0.5 (CADILA HC.)',
	'PRAMIPEXOLE',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARPEX 0.5 (CADILA HC.)'
);

-- line #27093
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARPEX 1.5 (CADILA HC.)',
	'PRAMIPEXOLE',
	'TAB',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARPEX 1.5 (CADILA HC.)'
);

-- line #27094
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARPEX 1 (CADILA HC.)',
	'PRAMIPEXOLE',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARPEX 1 (CADILA HC.)'
);

-- line #27095
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRAMIROL 0.26 (Intas)',
	'PRAMIPEXOLE',
	'SR TAB',
	gm.nullify_empty_string('0.26')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRAMIROL 0.26 (Intas)'
);

-- line #27096
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRAMIROL 0.52 (Intas)',
	'PRAMIPEXOLE',
	'SR TAB',
	gm.nullify_empty_string('0.52')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRAMIROL 0.52 (Intas)'
);

-- line #27097
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRAMIROL 1.05 (Intas)',
	'PRAMIPEXOLE',
	'SR TAB',
	gm.nullify_empty_string('1.05')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRAMIROL 1.05 (Intas)'
);

-- line #27098
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRAMIROL 2.1 (Intas)',
	'PRAMIPEXOLE',
	'SR TAB',
	gm.nullify_empty_string('2.1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRAMIROL 2.1 (Intas)'
);

-- line #27099
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRAMIROL 3.15 (Intas)',
	'PRAMIPEXOLE',
	'SR TAB',
	gm.nullify_empty_string('3.15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRAMIROL 3.15 (Intas)'
);

-- line #27100
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APAGREL 10 (Intas)',
	'PRASUGREL',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APAGREL 10 (Intas)'
);

-- line #27101
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APAGREL 5 (Intas)',
	'PRASUGREL',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APAGREL 5 (Intas)'
);

-- line #27102
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APLET 10 (Glenmark)',
	'PRASUGREL',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APLET 10 (Glenmark)'
);

-- line #27103
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APLET 5 (Glenmark)',
	'PRASUGREL',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APLET 5 (Glenmark)'
);

-- line #27104
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EFIPLAT 10 (Sun)',
	'PRASUGREL',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EFIPLAT 10 (Sun)'
);

-- line #27105
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EFIPLAT 5 (Sun)',
	'PRASUGREL',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EFIPLAT 5 (Sun)'
);

-- line #27106
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INNOGREL 100 (INNOVA LIFESCI.)',
	'PRASUGREL',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INNOGREL 100 (INNOVA LIFESCI.)'
);

-- line #27107
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10', u'strength_2': u'', u'substance': u'PRASUGREL', u'always_empty': u'', u'form': u'', u'brand': u'PANGREL-10', u'strength_3': u'', u'company': u'Panacea', u'unit': u'mg'}

-- line #27108
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5', u'strength_2': u'', u'substance': u'PRASUGREL', u'always_empty': u'', u'form': u'', u'brand': u'PANGREL-5', u'strength_3': u'', u'company': u'Panacea', u'unit': u'mg'}

-- line #27109
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANGREL 10 (Panacea)',
	'PRASUGREL',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANGREL 10 (Panacea)'
);

-- line #27110
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANGREL 5 (Panacea)',
	'PRASUGREL',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANGREL 5 (Panacea)'
);

-- line #27111
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10', u'strength_2': u'', u'substance': u'PRASUGREL', u'always_empty': u'', u'form': u'', u'brand': u'PASUGEN', u'strength_3': u'', u'company': u'Unichem', u'unit': u'mg'}

-- line #27112
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5', u'strength_2': u'', u'substance': u'PRASUGREL', u'always_empty': u'', u'form': u'', u'brand': u'PASUGEN', u'strength_3': u'', u'company': u'Unichem', u'unit': u'mg'}

-- line #27113
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRAMIPEX 1.5 (Sun)',
	'PRASUGREL',
	'ER TAB',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRAMIPEX 1.5 (Sun)'
);

-- line #27114
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRAMIPEX 3 (Sun)',
	'PRASUGREL',
	'ER TAB',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRAMIPEX 3 (Sun)'
);

-- line #27115
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10', u'strength_2': u'', u'substance': u'PRASUGREL', u'always_empty': u'', u'form': u'', u'brand': u'PRASACT', u'strength_3': u'', u'company': u'Biocon', u'unit': u'mg'}

-- line #27116
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5', u'strength_2': u'', u'substance': u'PRASUGREL', u'always_empty': u'', u'form': u'', u'brand': u'PRASACT', u'strength_3': u'', u'company': u'Biocon', u'unit': u'mg'}

-- line #27117
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10', u'strength_2': u'', u'substance': u'PRASUGREL', u'always_empty': u'', u'form': u'', u'brand': u'PRASITA', u'strength_3': u'', u'company': u'Ranbaxy', u'unit': u'mg'}

-- line #27118
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5', u'strength_2': u'', u'substance': u'PRASUGREL', u'always_empty': u'', u'form': u'', u'brand': u'PRASITA', u'strength_3': u'', u'company': u'Ranbaxy', u'unit': u'mg'}

-- line #27119
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRASUDIN 10 (ERIS LIFE)',
	'PRASUGREL',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRASUDIN 10 (ERIS LIFE)'
);

-- line #27120
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRASUDIN 5 (ERIS LIFE)',
	'PRASUGREL',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRASUDIN 5 (ERIS LIFE)'
);

-- line #27121
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRASUDOC 10 (Lupin)',
	'PRASUGREL',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRASUDOC 10 (Lupin)'
);

-- line #27122
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRASUDOC 5 (Lupin)',
	'PRASUGREL',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRASUDOC 5 (Lupin)'
);

-- line #27123
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRASUGRIN 10 (ZYDUS MEDICA)',
	'PRASUGREL',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRASUGRIN 10 (ZYDUS MEDICA)'
);

-- line #27124
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRASUGRIN 5 (ZYDUS MEDICA)',
	'PRASUGREL',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRASUGRIN 5 (ZYDUS MEDICA)'
);

-- line #27125
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRASULET 10 (Micro Labs)',
	'PRASUGREL',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRASULET 10 (Micro Labs)'
);

-- line #27126
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRASULET 5 (Micro Labs)',
	'PRASUGREL',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRASULET 5 (Micro Labs)'
);

-- line #27127
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRASUMAX 10 (Emcure)',
	'PRASUGREL',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRASUMAX 10 (Emcure)'
);

-- line #27128
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRASUMAX 5 (Emcure)',
	'PRASUGREL',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRASUMAX 5 (Emcure)'
);

-- line #27129
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRASUREL 10 (Macleods)',
	'PRASUGREL',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRASUREL 10 (Macleods)'
);

-- line #27130
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRASUREL 5 (Macleods)',
	'PRASUGREL',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRASUREL 5 (Macleods)'
);

-- line #27131
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10', u'strength_2': u'', u'substance': u'PRASUGREL', u'always_empty': u'', u'form': u'', u'brand': u'PRASUSAFE', u'strength_3': u'', u'company': u'MSN LAB.', u'unit': u'mg'}

-- line #27132
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5', u'strength_2': u'', u'substance': u'PRASUGREL', u'always_empty': u'', u'form': u'', u'brand': u'PRASUSAFE', u'strength_3': u'', u'company': u'MSN LAB.', u'unit': u'mg'}

-- line #27133
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRASU 10 (Alembic)',
	'PRASUGREL',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRASU 10 (Alembic)'
);

-- line #27134
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRASU 5 (Alembic)',
	'PRASUGREL',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRASU 5 (Alembic)'
);

-- line #27135
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRASUVAS 10 (Cipla)',
	'PRASUGREL',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRASUVAS 10 (Cipla)'
);

-- line #27136
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRASUVAS 5 (Cipla)',
	'PRASUGREL',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRASUVAS 5 (Cipla)'
);

-- line #27137
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRASUVIX 10 (Ajanta Ph.)',
	'PRASUGREL',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRASUVIX 10 (Ajanta Ph.)'
);

-- line #27138
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRASUVIX 5 (Ajanta Ph.)',
	'PRASUGREL',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRASUVIX 5 (Ajanta Ph.)'
);

-- line #27139
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRAX 10 (Torrent)',
	'PRASUGREL',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRAX 10 (Torrent)'
);

-- line #27140
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRAX 5 (Torrent)',
	'PRASUGREL',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRAX 5 (Torrent)'
);

-- line #27141
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REDIGREL 10 (DR. REDDY''S)',
	'PRASUGREL',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REDIGREL 10 (DR. REDDY''S)'
);

-- line #27142
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REDIGREL 5 (DR. REDDY''S)',
	'PRASUGREL',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REDIGREL 5 (DR. REDDY''S)'
);

-- line #27143
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRASTATIN 10 (Emcure)',
	'Pravastatin Sodium',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRASTATIN 10 (Emcure)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRASTATIN 20 (Emcure)',
	'Pravastatin Sodium',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRASTATIN 20 (Emcure)'
);

-- line #27144
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRAVATOR 10 (Ranbaxy Cv)',
	'Pravastatin Sodium',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRAVATOR 10 (Ranbaxy Cv)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRAVATOR 20 (Ranbaxy Cv)',
	'Pravastatin Sodium',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRAVATOR 20 (Ranbaxy Cv)'
);

-- line #27145
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYSTICIDE 500 (Merck)',
	'Praziquantel',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYSTICIDE 500 (Merck)'
);

-- line #27146
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DISTOCIDE 600 (Vhb)',
	'Praziquantel',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DISTOCIDE 600 (Vhb)'
);

-- line #27147
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRAZINE 600 (Vhb)',
	'Praziquantel',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRAZINE 600 (Vhb)'
);

-- line #27148
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRAZISAN 600 (CH.Bhagat)',
	'Praziquantel',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRAZISAN 600 (CH.Bhagat)'
);

-- line #27149
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYBER 2.5 (R.B.)',
	'Prazosin',
	'CR CAP',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYBER 2.5 (R.B.)'
);

-- line #27150
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYBER 5 (R.B.)',
	'Prazosin',
	'CR CAP',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYBER 5 (R.B.)'
);

-- line #27151
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MINIPRESS 2.5 (Pfizer)',
	'Prazosin',
	'XL GITS TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MINIPRESS 2.5 (Pfizer)'
);

-- line #27152
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MINIPRESS 5 (Pfizer)',
	'Prazosin',
	'XL GITS TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MINIPRESS 5 (Pfizer)'
);

-- line #27153
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MINIPRESS 2.5 (Pfizer)',
	'Prazosin',
	'XL TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MINIPRESS 2.5 (Pfizer)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MINIPRESS 5 (Pfizer)',
	'Prazosin',
	'XL TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MINIPRESS 5 (Pfizer)'
);

-- line #27154
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRACEPT 2.5 (Lupin)',
	'Prazosin',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRACEPT 2.5 (Lupin)'
);

-- line #27155
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRACEPT 5 (Lupin)',
	'Prazosin',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRACEPT 5 (Lupin)'
);

-- line #27156
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRAZOCIP 1 (Cipla)',
	'Prazosin',
	'XL TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRAZOCIP 1 (Cipla)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRAZOCIP 2.5 (Cipla)',
	'Prazosin',
	'XL TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRAZOCIP 2.5 (Cipla)'
);

-- line #27157
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRAZOCIP 5 (Cipla)',
	'Prazosin',
	'XL TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRAZOCIP 5 (Cipla)'
);

-- line #27158
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRAZOPILL 2.5 (Intas)',
	'Prazosin',
	'XL TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRAZOPILL 2.5 (Intas)'
);

-- line #27159
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRAZOPILL 5 (Intas)',
	'Prazosin',
	'XL TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRAZOPILL 5 (Intas)'
);

-- line #27160
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRAZOPRESS 1 (Sun)',
	'Prazosin',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRAZOPRESS 1 (Sun)'
);

-- line #27161
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRAZOPRESS 2 (Sun)',
	'Prazosin',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRAZOPRESS 2 (Sun)'
);

-- line #27162
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRAZOPRESS 2.5 (Sun)',
	'Prazosin',
	'XL TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRAZOPRESS 2.5 (Sun)'
);

-- line #27163
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRAZOPRESS 5 (Sun)',
	'Prazosin',
	'XL TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRAZOPRESS 5 (Sun)'
);

-- line #27164
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RENOPRESS 2.5 (LA RENON)',
	'Prazosin',
	'XL TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RENOPRESS 2.5 (LA RENON)'
);

-- line #27165
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RENOPRESS 5 (LA RENON)',
	'Prazosin',
	'XL TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RENOPRESS 5 (LA RENON)'
);

-- line #27166
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DERMATOP 2.5 (Sanofi Aventis)',
	'Prednicarbate',
	'CRM',
	gm.nullify_empty_string('2.5')::numeric,
	'mg/G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DERMATOP 2.5 (Sanofi Aventis)'
);

-- line #27167
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTICORT 10 (Overseas Hc.)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTICORT 10 (Overseas Hc.)'
);

-- line #27168
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTICORT 20 (Overseas Hc.)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTICORT 20 (Overseas Hc.)'
);

-- line #27169
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTICORT 5 (Overseas Hc.)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTICORT 5 (Overseas Hc.)'
);

-- line #27170
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTO-PRED 16 (Ferring Ph.)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('16')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTO-PRED 16 (Ferring Ph.)'
);

-- line #27171
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTO-PRED 4 (Ferring Ph.)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTO-PRED 4 (Ferring Ph.)'
);

-- line #27172
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANESOLIN 20 (Neon)',
	'Prednisolone',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANESOLIN 20 (Neon)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANESOLIN 30 (Neon)',
	'Prednisolone',
	'INJ',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANESOLIN 30 (Neon)'
);

-- line #27173
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANESOLIN 40 (Neon)',
	'Prednisolone',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANESOLIN 40 (Neon)'
);

-- line #27174
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AQUAPRED 1 (Micro V.)',
	'Prednisolone',
	'EYE DPS',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AQUAPRED 1 (Micro V.)'
);

-- line #27175
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BESONE 15 (Bestochem)',
	'Prednisolone',
	'F. SYR',
	gm.nullify_empty_string('15')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BESONE 15 (Bestochem)'
);

-- line #27176
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BESONE 5 (Bestochem)',
	'Prednisolone',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BESONE 5 (Bestochem)'
);

-- line #27177
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOCORTIL 20 (Bioguard Org.)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOCORTIL 20 (Bioguard Org.)'
);

-- line #27178
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOCORTIL 5 (Bioguard Org.)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOCORTIL 5 (Bioguard Org.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOCORTIL 10 (Bioguard Org.)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOCORTIL 10 (Bioguard Org.)'
);

-- line #27179
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BISOLON 5 (Bipl(Radico Lab))',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BISOLON 5 (Bipl(Radico Lab))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BISOLON 10 (Bipl(Radico Lab))',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BISOLON 10 (Bipl(Radico Lab))'
);

-- line #27180
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CECORT 40 (COMED CHEM.)',
	'Prednisolone',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CECORT 40 (COMED CHEM.)'
);

-- line #27181
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DELSONE 10 (Pil)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DELSONE 10 (Pil)'
);

-- line #27182
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DELSONE 20 (Pil)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DELSONE 20 (Pil)'
);

-- line #27183
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DELSONE 30 (Pil)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DELSONE 30 (Pil)'
);

-- line #27184
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DELSONE 40 (Pil)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DELSONE 40 (Pil)'
);

-- line #27185
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DELSONE 5 (Pil)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DELSONE 5 (Pil)'
);

-- line #27186
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DELTACORTRIL 10 (Pfizer)',
	'Prednisolone',
	'F. TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DELTACORTRIL 10 (Pfizer)'
);

-- line #27187
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DELTACORTRIL 5 (Pfizer)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DELTACORTRIL 5 (Pfizer)'
);

-- line #27188
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPOSET 40 (VHB)',
	'Prednisolone',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPOSET 40 (VHB)'
);

-- line #27189
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPOSET 80 (VHB)',
	'Prednisolone',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPOSET 80 (VHB)'
);

-- line #27190
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DISPRED 0.1 (J. B. Chem.)',
	'Prednisolone',
	'EYE DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%(ACET.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DISPRED 0.1 (J. B. Chem.)'
);

-- line #27191
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'ACETATE', u'strength_2': u'', u'substance': u'Prednisolone', u'always_empty': u'', u'form': u'DROPS', u'brand': u'DIVIPRED EYE', u'strength_3': u'', u'company': u'DIVINE LAB.', u'unit': u''}

-- line #27192
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELCORT 10 (Captab)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELCORT 10 (Captab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELCORT 20 (Captab)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELCORT 20 (Captab)'
);

-- line #27193
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELPRED 20 (Lancer)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELPRED 20 (Lancer)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELPRED 40 (Lancer)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELPRED 40 (Lancer)'
);

-- line #27194
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELPRED 5 (Lancer)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELPRED 5 (Lancer)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELPRED 10 (Lancer)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELPRED 10 (Lancer)'
);

-- line #27195
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMSOLONE 10 (Medopharm)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMSOLONE 10 (Medopharm)'
);

-- line #27196
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMSOLONE 20 (Medopharm)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMSOLONE 20 (Medopharm)'
);

-- line #27197
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMSOLONE 2.5 (Medopharm)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMSOLONE 2.5 (Medopharm)'
);

-- line #27198
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMSOLONE 40 (Medopharm)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMSOLONE 40 (Medopharm)'
);

-- line #27199
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMSOLONE 5 (Medopharm)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMSOLONE 5 (Medopharm)'
);

-- line #27200
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORCE 10 (Vasphar)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORCE 10 (Vasphar)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORCE 20 (Vasphar)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORCE 20 (Vasphar)'
);

-- line #27201
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GB-PRED AC 10 (Greenco Bio.)',
	'Prednisolone',
	'EYE DPS',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GB-PRED AC 10 (Greenco Bio.)'
);

-- line #27202
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GB-PRED 1 (Greenco Bio.)',
	'Prednisolone',
	'EYE DPS',
	gm.nullify_empty_string('1')::numeric,
	'%W/V (SOD.PHOS.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GB-PRED 1 (Greenco Bio.)'
);

-- line #27203
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HOSTACORTIN-H 5 (Sanofi Aventis)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HOSTACORTIN-H 5 (Sanofi Aventis)'
);

-- line #27204
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMMUPRESS 20 (Symbiotic)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMMUPRESS 20 (Symbiotic)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMMUPRESS 40 (Symbiotic)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMMUPRESS 40 (Symbiotic)'
);

-- line #27205
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMMUPRESS 5 (Symbiotic)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMMUPRESS 5 (Symbiotic)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMMUPRESS 10 (Symbiotic)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMMUPRESS 10 (Symbiotic)'
);

-- line #27206
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDOCORT 20 (Indo-Reh Ph.)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDOCORT 20 (Indo-Reh Ph.)'
);

-- line #27207
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDOCORT 5 (Indo-Reh Ph.)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDOCORT 5 (Indo-Reh Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDOCORT 10 (Indo-Reh Ph.)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDOCORT 10 (Indo-Reh Ph.)'
);

-- line #27208
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Prednisolone', u'always_empty': u'', u'form': u'F. SUSP', u'brand': u'KIDPRED', u'strength_3': u'', u'company': u'Nicholas', u'unit': u''}

-- line #27209
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Prednisolone', u'always_empty': u'', u'form': u'SUSP', u'brand': u'KIDPRED', u'strength_3': u'', u'company': u'Nicholas', u'unit': u''}

-- line #27210
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANCEPRED 20 (Lancer)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANCEPRED 20 (Lancer)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANCEPRED 40 (Lancer)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANCEPRED 40 (Lancer)'
);

-- line #27211
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANCEPRED 5 (Lancer)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANCEPRED 5 (Lancer)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANCEPRED 10 (Lancer)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANCEPRED 10 (Lancer)'
);

-- line #27212
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDSOLONE 1 (MEDITRINA PH.)',
	'Prednisolone',
	'EYE DPS',
	gm.nullify_empty_string('1')::numeric,
	'%(ACET.);W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDSOLONE 1 (MEDITRINA PH.)'
);

-- line #27213
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELSONE 4 (Pil)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELSONE 4 (Pil)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELSONE 16 (Pil)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('16')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELSONE 16 (Pil)'
);

-- line #27214
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MESOLONE 10 (Medicamen)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MESOLONE 10 (Medicamen)'
);

-- line #27215
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MESOLONE 5 (Medicamen)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MESOLONE 5 (Medicamen)'
);

-- line #27216
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOCORTIL 10 (Marc Lab)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOCORTIL 10 (Marc Lab)'
);

-- line #27217
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOCORTIL 20 (Marc Lab)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOCORTIL 20 (Marc Lab)'
);

-- line #27218
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOCORTIL 40 (Marc Lab)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOCORTIL 40 (Marc Lab)'
);

-- line #27219
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOCORTIL 5 (Marc Lab)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOCORTIL 5 (Marc Lab)'
);

-- line #27220
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MPA 40 (CH.Bhagat)',
	'Prednisolone',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MPA 40 (CH.Bhagat)'
);

-- line #27221
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MPA 80 (CH.Bhagat)',
	'Prednisolone',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MPA 80 (CH.Bhagat)'
);

-- line #27222
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUCORT-F 10 (Discovery M.)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUCORT-F 10 (Discovery M.)'
);

-- line #27223
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUCORT-F 20 (Discovery M.)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUCORT-F 20 (Discovery M.)'
);

-- line #27224
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUCORT-F 40 (Discovery M.)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUCORT-F 40 (Discovery M.)'
);

-- line #27225
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUCORT 10 (Mankind)',
	'Prednisolone',
	'F. TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUCORT 10 (Mankind)'
);

-- line #27226
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUCORT-P 5 (Discovery M.)',
	'Prednisolone',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUCORT-P 5 (Discovery M.)'
);

-- line #27227
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUCORT 5 (Discovery M.)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUCORT 5 (Discovery M.)'
);

-- line #27228
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUCORT 5 (Mankind)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUCORT 5 (Mankind)'
);

-- line #27229
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMNACORTIL 10 (Macleods)',
	'Prednisolone',
	'MD TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMNACORTIL 10 (Macleods)'
);

-- line #27230
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMNACORTIL 5 (Macleods)',
	'Prednisolone',
	'MD TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMNACORTIL 5 (Macleods)'
);

-- line #27231
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMNACORTIL 10 (Macleods)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMNACORTIL 10 (Macleods)'
);

-- line #27232
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMNACORTIL 20 (Macleods)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMNACORTIL 20 (Macleods)'
);

-- line #27233
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMNACORTIL 2.5 (Macleods)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMNACORTIL 2.5 (Macleods)'
);

-- line #27234
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMNACORTIL 30 (Macleods)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMNACORTIL 30 (Macleods)'
);

-- line #27235
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMNACORTIL 40 (Macleods)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMNACORTIL 40 (Macleods)'
);

-- line #27236
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMNACORTIL 5 (Macleods)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMNACORTIL 5 (Macleods)'
);

-- line #27237
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEDNISOL 10 (Ochoa)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEDNISOL 10 (Ochoa)'
);

-- line #27238
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEDNISOL 20 (Ochoa)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEDNISOL 20 (Ochoa)'
);

-- line #27239
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEDNISOL 40 (Ochoa)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEDNISOL 40 (Ochoa)'
);

-- line #27240
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEDNISOL 5 (Ochoa)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEDNISOL 5 (Ochoa)'
);

-- line #27241
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRADO 5 (P C INDIA)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRADO 5 (P C INDIA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRADO 10 (P C INDIA)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRADO 10 (P C INDIA)'
);

-- line #27242
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREDACE 1 (Micro V.)',
	'Prednisolone',
	'DPS',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREDACE 1 (Micro V.)'
);

-- line #27243
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1', u'strength_2': u'', u'substance': u'Prednisolone', u'always_empty': u'', u'form': u'', u'brand': u'PREDACE-LD', u'strength_3': u'', u'company': u'Micro V.', u'unit': u'%'}

-- line #27244
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRED ACETATE 1 (Allergan)',
	'Prednisolone',
	'DPS',
	gm.nullify_empty_string('1')::numeric,
	'%(ACETATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRED ACETATE 1 (Allergan)'
);

-- line #27245
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREDCIP 5 (Cipla)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREDCIP 5 (Cipla)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREDCIP 10 (Cipla)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREDCIP 10 (Cipla)'
);

-- line #27246
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRED 1 (Allergan)',
	'Prednisolone',
	'F.',
	gm.nullify_empty_string('1')::numeric,
	'%(ACETATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRED 1 (Allergan)'
);

-- line #27247
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREDILONE 20 (Parasol)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREDILONE 20 (Parasol)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREDILONE 30 (Parasol)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREDILONE 30 (Parasol)'
);

-- line #27248
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREDILONE 40 (Parasol)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREDILONE 40 (Parasol)'
);

-- line #27249
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREDILONE 5 (Parasol)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREDILONE 5 (Parasol)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREDILONE 10 (Parasol)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREDILONE 10 (Parasol)'
);

-- line #27250
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREDINGA 5 (Inga)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREDINGA 5 (Inga)'
);

-- line #27251
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREDLONE 20 (Osper)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREDLONE 20 (Osper)'
);

-- line #27252
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREDLY 10 (Ind-Swift)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREDLY 10 (Ind-Swift)'
);

-- line #27253
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREDLY 20 (Ind-Swift)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREDLY 20 (Ind-Swift)'
);

-- line #27254
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREDLY 5 (Ind-Swift)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREDLY 5 (Ind-Swift)'
);

-- line #27255
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREDMET 10 (Milmet)',
	'Prednisolone',
	'DPS',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML(ACET.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREDMET 10 (Milmet)'
);

-- line #27256
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1', u'strength_2': u'', u'substance': u'Prednisolone', u'always_empty': u'', u'form': u'', u'brand': u'PREDMET', u'strength_3': u'', u'company': u'Sun', u'unit': u'% ACETATE'}

-- line #27257
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1', u'strength_2': u'', u'substance': u'Prednisolone', u'always_empty': u'', u'form': u'', u'brand': u'PREDNIN A', u'strength_3': u'', u'company': u'Sunways', u'unit': u'%(ACET.)'}

-- line #27258
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREDNISAFE 5 (Yash Ph.)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREDNISAFE 5 (Yash Ph.)'
);

-- line #27259
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREDNISOL ACETATE 10 (Allergan)',
	'Prednisolone',
	'EYE DPS',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREDNISOL ACETATE 10 (Allergan)'
);

-- line #27260
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREDNISOLONE ACET 0.1 (Allergan)',
	'Prednisolone',
	'DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%(ACET.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREDNISOLONE ACET 0.1 (Allergan)'
);

-- line #27261
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1', u'strength_2': u'', u'substance': u'Prednisolone', u'always_empty': u'', u'form': u'', u'brand': u'PREDNISOLONE', u'strength_3': u'', u'company': u'Alcon Lab', u'unit': u'%W/V(ACETATE)'}

-- line #27262
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREDNISOLONE 40 (Wyeth)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREDNISOLONE 40 (Wyeth)'
);

-- line #27263
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREDNISOLONE 5 (Wyeth)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREDNISOLONE 5 (Wyeth)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREDNISOLONE 10 (Wyeth)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREDNISOLONE 10 (Wyeth)'
);

-- line #27264
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREDNITOP 20 (Ind-Swift)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREDNITOP 20 (Ind-Swift)'
);

-- line #27265
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREDNITOP 5 (Ind-Swift)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREDNITOP 5 (Ind-Swift)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREDNITOP 10 (Ind-Swift)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREDNITOP 10 (Ind-Swift)'
);

-- line #27266
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREDONE 0.1 (Cipla)',
	'Prednisolone',
	'EYE DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREDONE 0.1 (Cipla)'
);

-- line #27267
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREDONE 15 (Cipla)',
	'Prednisolone',
	'F. SYR',
	gm.nullify_empty_string('15')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREDONE 15 (Cipla)'
);

-- line #27268
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREDONE 5 (Cipla)',
	'Prednisolone',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREDONE 5 (Cipla)'
);

-- line #27269
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREDS 10 (Appasamy)',
	'Prednisolone',
	'EYE DPS',
	gm.nullify_empty_string('10')::numeric,
	'mg(ACET.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREDS 10 (Appasamy)'
);

-- line #27270
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREDYL 0.1 (Ind-Swift)',
	'Prednisolone',
	'DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%(ACET.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREDYL 0.1 (Ind-Swift)'
);

-- line #27271
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREE 10 (Zee Lab)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREE 10 (Zee Lab)'
);

-- line #27272
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREMISOL 16 (MOLEKULE)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('16')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREMISOL 16 (MOLEKULE)'
);

-- line #27273
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREMISOL 4 (MOLEKULE)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREMISOL 4 (MOLEKULE)'
);

-- line #27274
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRESOL 4 (ROSE LABS)',
	'Prednisolone',
	'TABS',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRESOL 4 (ROSE LABS)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRESOL 16 (ROSE LABS)',
	'Prednisolone',
	'TABS',
	gm.nullify_empty_string('16')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRESOL 16 (ROSE LABS)'
);

-- line #27275
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRID 10 (Samarth)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRID 10 (Samarth)'
);

-- line #27276
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRID 20 (Samarth)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRID 20 (Samarth)'
);

-- line #27277
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRID 40 (Samarth)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRID 40 (Samarth)'
);

-- line #27278
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRID 5 (Samarth)',
	'Prednisolone',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRID 5 (Samarth)'
);

-- line #27279
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RENISOL 5 (Intas)',
	'Prednisolone',
	'DPS',
	gm.nullify_empty_string('5')::numeric,
	'%(ACETATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RENISOL 5 (Intas)'
);

-- line #27280
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RENISONE 10 (Intas)',
	'Prednisolone',
	'EYE DPS',
	gm.nullify_empty_string('10')::numeric,
	'mg(ACET.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RENISONE 10 (Intas)'
);

-- line #27281
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVERTZ 150 (Dr.Reddy''S)',
	'PREGABALIN',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVERTZ 150 (Dr.Reddy''S)'
);

-- line #27282
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVERTZ 75 (Dr.Reddy''S)',
	'PREGABALIN',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVERTZ 75 (Dr.Reddy''S)'
);

-- line #27283
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESGABA 150 (Emcure)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESGABA 150 (Emcure)'
);

-- line #27284
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESGABA 75 (Emcure)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESGABA 75 (Emcure)'
);

-- line #27285
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESVIGA 150 (USV CENTRA)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESVIGA 150 (USV CENTRA)'
);

-- line #27286
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESVIGA 75 (USV CENTRA)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESVIGA 75 (USV CENTRA)'
);

-- line #27287
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GALINERVE 150 (SUN)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GALINERVE 150 (SUN)'
);

-- line #27288
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GALINERVE 75 (SUN)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GALINERVE 75 (SUN)'
);

-- line #27289
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GB-LIN 75 (MEDIVA(ALKEM))',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GB-LIN 75 (MEDIVA(ALKEM))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GB-LIN 150 (MEDIVA(ALKEM))',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GB-LIN 150 (MEDIVA(ALKEM))'
);

-- line #27290
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INRICA 150 (Panacea)',
	'PREGABALIN',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INRICA 150 (Panacea)'
);

-- line #27291
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INRICA 75 (Panacea)',
	'PREGABALIN',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INRICA 75 (Panacea)'
);

-- line #27292
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JUBLIN 75 (D.R.John''S)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('75')::numeric,
	'150'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JUBLIN 75 (D.R.John''S)'
);

-- line #27293
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYRICA 150 (Pfizer)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYRICA 150 (Pfizer)'
);

-- line #27294
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYRICA 75 (Pfizer)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYRICA 75 (Pfizer)'
);

-- line #27295
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAXGALIN 150 (Sun)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAXGALIN 150 (Sun)'
);

-- line #27296
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAXGALIN 50 (SUN)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAXGALIN 50 (SUN)'
);

-- line #27297
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAXGALIN 75 (Sun)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAXGALIN 75 (Sun)'
);

-- line #27298
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAXGALIN 100 (Sun)',
	'PREGABALIN',
	'ER',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAXGALIN 100 (Sun)'
);

-- line #27299
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEUGABA 150 (Sun)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEUGABA 150 (Sun)'
);

-- line #27300
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEUGABA 75 (Sun)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEUGABA 75 (Sun)'
);

-- line #27301
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEUGABA 150 (Sun)',
	'PREGABALIN',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEUGABA 150 (Sun)'
);

-- line #27302
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEUGALIN 150 (Solus)',
	'PREGABALIN',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEUGALIN 150 (Solus)'
);

-- line #27303
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEUGALIN 300 (Solus)',
	'PREGABALIN',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEUGALIN 300 (Solus)'
);

-- line #27304
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEUGALIN 75 (Solus)',
	'PREGABALIN',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEUGALIN 75 (Solus)'
);

-- line #27305
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEUPREG 75 (Intra Lab)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEUPREG 75 (Intra Lab)'
);

-- line #27306
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEUROKEM 150 (Alkem)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEUROKEM 150 (Alkem)'
);

-- line #27307
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEUROKEM 75 (Alkem)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEUROKEM 75 (Alkem)'
);

-- line #27308
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVA 150 (Cipla)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVA 150 (Cipla)'
);

-- line #27309
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVA 75 (Cipla)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVA 75 (Cipla)'
);

-- line #27310
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVA 75 (Cipla)',
	'PREGABALIN',
	'SR TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVA 75 (Cipla)'
);

-- line #27311
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NURAMED 150 (Zydus Med.)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NURAMED 150 (Zydus Med.)'
);

-- line #27312
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NURAMED 75 (Zydus Med.)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NURAMED 75 (Zydus Med.)'
);

-- line #27313
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUROGAB 150 (Macleods)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUROGAB 150 (Macleods)'
);

-- line #27314
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERNUROLIN 150 (Franco I.)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERNUROLIN 150 (Franco I.)'
);

-- line #27315
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERNUROLIN 75 (Franco I.)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERNUROLIN 75 (Franco I.)'
);

-- line #27316
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEVESCA 150 (U S V)',
	'PREGABALIN',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEVESCA 150 (U S V)'
);

-- line #27317
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEVESCA 75 (U S V)',
	'PREGABALIN',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEVESCA 75 (U S V)'
);

-- line #27318
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREBAXE 150 (Cipla)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREBAXE 150 (Cipla)'
);

-- line #27319
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREBAXE 75 (Cipla)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREBAXE 75 (Cipla)'
);

-- line #27320
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGABA 75 (Neu-Foreva)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGABA 75 (Neu-Foreva)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGABA 150 (Neu-Foreva)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGABA 150 (Neu-Foreva)'
);

-- line #27321
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGABA 75 (Neu Foreva)',
	'PREGABALIN',
	'SR TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGABA 75 (Neu Foreva)'
);

-- line #27322
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGABA 50 (Neu Foreva)',
	'PREGABALIN',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGABA 50 (Neu Foreva)'
);

-- line #27323
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGAB 75 (Torrent)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGAB 75 (Torrent)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGAB 150 (Torrent)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGAB 150 (Torrent)'
);

-- line #27324
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGABID 150 (Intas)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGABID 150 (Intas)'
);

-- line #27325
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGABID 25 (INTAS)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGABID 25 (INTAS)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGABID 50 (INTAS)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGABID 50 (INTAS)'
);

-- line #27326
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGABID 300 (Intas)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGABID 300 (Intas)'
);

-- line #27327
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGABID 75 (Intas)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGABID 75 (Intas)'
);

-- line #27328
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGABID 100 (Intas)',
	'PREGABALIN',
	'OD TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGABID 100 (Intas)'
);

-- line #27329
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGABID 150 (Intas)',
	'PREGABALIN',
	'OD TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGABID 150 (Intas)'
);

-- line #27330
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGABIN 150 (MOLEKULE)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGABIN 150 (MOLEKULE)'
);

-- line #27331
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75', u'strength_2': u'', u'substance': u'PREGABALIN', u'always_empty': u'', u'form': u'CAP', u'brand': u'PREGABIN', u'strength_3': u'', u'company': u'MOLEKULE', u'unit': u''}

-- line #27332
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGACENT 75 (Crescent Th.)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGACENT 75 (Crescent Th.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGACENT 150 (Crescent Th.)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGACENT 150 (Crescent Th.)'
);

-- line #27333
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGACON 75 (Torrent)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGACON 75 (Torrent)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGACON 150 (Torrent)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGACON 150 (Torrent)'
);

-- line #27334
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGADOC 150 (Lupin)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGADOC 150 (Lupin)'
);

-- line #27335
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGADOC 75 (Lupin)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGADOC 75 (Lupin)'
);

-- line #27336
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGADOC 150 (Lupin)',
	'PREGABALIN',
	'SR TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGADOC 150 (Lupin)'
);

-- line #27337
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGADOC 75 (Lupin)',
	'PREGABALIN',
	'SR TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGADOC 75 (Lupin)'
);

-- line #27338
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGALIN 100 (TORRENT)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGALIN 100 (TORRENT)'
);

-- line #27339
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGALIN 200 (TORRENT)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGALIN 200 (TORRENT)'
);

-- line #27340
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGALIN 50 (Torrent)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGALIN 50 (Torrent)'
);

-- line #27341
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGALIN 75 (Torrent)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGALIN 75 (Torrent)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGALIN 150 (Torrent)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGALIN 150 (Torrent)'
);

-- line #27342
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGALIN 150 (Torrent)',
	'PREGABALIN',
	'SR TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGALIN 150 (Torrent)'
);

-- line #27343
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGALIN 75 (Torrent)',
	'PREGABALIN',
	'SR TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGALIN 75 (Torrent)'
);

-- line #27344
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGANERVE 75 (EAST WEST)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGANERVE 75 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGANERVE 100 (EAST WEST)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGANERVE 100 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGANERVE 150 (EAST WEST)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGANERVE 150 (EAST WEST)'
);

-- line #27345
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGASTAR 150 (Lupin)',
	'PREGABALIN',
	'OD TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGASTAR 150 (Lupin)'
);

-- line #27346
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGASTAR 75 (Lupin)',
	'PREGABALIN',
	'OD TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGASTAR 75 (Lupin)'
);

-- line #27347
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGEB 100 (Torrent)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGEB 100 (Torrent)'
);

-- line #27348
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGEB 150 (Torrent)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGEB 150 (Torrent)'
);

-- line #27349
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGEB 200 (Torrent)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGEB 200 (Torrent)'
);

-- line #27350
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGEB 300 (Torrent)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGEB 300 (Torrent)'
);

-- line #27351
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGEB 75 (Torrent)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGEB 75 (Torrent)'
);

-- line #27352
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGEB 150 (Torrent)',
	'PREGABALIN',
	'OD TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGEB 150 (Torrent)'
);

-- line #27353
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGEB 75 (Torrent)',
	'PREGABALIN',
	'OD TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGEB 75 (Torrent)'
);

-- line #27354
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREJUNATE 75 (MOLEKULE)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREJUNATE 75 (MOLEKULE)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREJUNATE 150 (MOLEKULE)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREJUNATE 150 (MOLEKULE)'
);

-- line #27355
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRELIN 150 (Intas)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRELIN 150 (Intas)'
);

-- line #27356
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRELIN 75 (Intas)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRELIN 75 (Intas)'
);

-- line #27357
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRENEUROLIN 75 (Franco I.)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRENEUROLIN 75 (Franco I.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRENEUROLIN 150 (Franco I.)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRENEUROLIN 150 (Franco I.)'
);

-- line #27358
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROAGE 75 (ALLENGE)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROAGE 75 (ALLENGE)'
);

-- line #27359
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRYNERVE 150 (Alkem)',
	'PREGABALIN',
	'OD TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRYNERVE 150 (Alkem)'
);

-- line #27360
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRYNERVE 75 (Alkem)',
	'PREGABALIN',
	'OD TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRYNERVE 75 (Alkem)'
);

-- line #27361
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RECOBAL 150 (Wockhardt)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RECOBAL 150 (Wockhardt)'
);

-- line #27362
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RECOBAL 75 (Wockhardt)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RECOBAL 75 (Wockhardt)'
);

-- line #27363
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESENZ 150 (Mano Ph.)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESENZ 150 (Mano Ph.)'
);

-- line #27364
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESENZ 75 (Mano Ph.)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESENZ 75 (Mano Ph.)'
);

-- line #27365
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REVLIN 150 (ERIS THER.)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REVLIN 150 (ERIS THER.)'
);

-- line #27366
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REVLIN 75 (ERIS THER.)',
	'PREGABALIN',
	'CAP',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REVLIN 75 (ERIS THER.)'
);

-- line #27367
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'pregnancy test', u'always_empty': u'', u'form': u'', u'brand': u'CLEARVIEW EASY HCG', u'strength_3': u'', u'company': u'J.&J.', u'unit': u''}

-- line #27368
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'pregnancy test', u'always_empty': u'', u'form': u'KIT', u'brand': u'PREGTEST', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #27369
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'pregnancy test', u'always_empty': u'', u'form': u'', u'brand': u'P-TEST CARD', u'strength_3': u'', u'company': u'HIND. LATEX', u'unit': u''}

-- line #27370
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRAMIROL 1.5 (Intas)',
	'PREMIPEXOLE',
	'TAB',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRAMIROL 1.5 (Intas)'
);

-- line #27371
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRAMIROL 1 (Intas)',
	'PREMIPEXOLE',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRAMIROL 1 (Intas)'
);

-- line #27372
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRENOXID 100 (Khandelwal)',
	'Prenoxdiazine Hcl.',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRENOXID 100 (Khandelwal)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRENOXID 200 (Khandelwal)',
	'Prenoxdiazine Hcl.',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRENOXID 200 (Khandelwal)'
);

-- line #27373
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERGACAP 214 (Mercury)',
	'Prepared Ergot',
	'CAP',
	gm.nullify_empty_string('214')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERGACAP 214 (Mercury)'
);

-- line #27374
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PGTEB 270 (Kaiser Ph.)',
	'Prepared Ergot',
	'TAB',
	gm.nullify_empty_string('270')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PGTEB 270 (Kaiser Ph.)'
);

-- line #27375
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESTIMULEN 225 (SPPL)',
	'PRETHCAMIDE',
	'AMP',
	gm.nullify_empty_string('225')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESTIMULEN 225 (SPPL)'
);

-- line #27376
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESTIMULEN 15 (SPPL)',
	'PRETHCAMIDE',
	'DPS',
	gm.nullify_empty_string('15')::numeric,
	'mg/100ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESTIMULEN 15 (SPPL)'
);

-- line #27377
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100', u'strength_2': u'', u'substance': u'PRETHCAMIDE', u'always_empty': u'', u'form': u'', u'brand': u'RESTIMULEN PEARLS', u'strength_3': u'', u'company': u'SPPL', u'unit': u'mg'}

-- line #27378
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIRFENEX 200 (Cipla)',
	'PRIFENIDONE',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIRFENEX 200 (Cipla)'
);

-- line #27379
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEOPRIME 15 (LEO)',
	'Primaquin',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEOPRIME 15 (LEO)'
);

-- line #27380
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEOPRIME 2.5 (LEO)',
	'Primaquin',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEOPRIME 2.5 (LEO)'
);

-- line #27381
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEOPRIME 7.5 (LEO)',
	'Primaquin',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEOPRIME 7.5 (LEO)'
);

-- line #27382
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALIRID 15 (Ipca)',
	'Primaquin',
	'DS TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALIRID 15 (Ipca)'
);

-- line #27383
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALIRID 2.5 (Ipca)',
	'Primaquin',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALIRID 2.5 (Ipca)'
);

-- line #27384
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALIRID 7.5 (Ipca)',
	'Primaquin',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALIRID 7.5 (Ipca)'
);

-- line #27385
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALQUINE 15 (Ind-Swift)',
	'Primaquin',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALQUINE 15 (Ind-Swift)'
);

-- line #27386
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALQUINE 2.5 (Ind-Swift)',
	'Primaquin',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALQUINE 2.5 (Ind-Swift)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALQUINE 7.5 (Ind-Swift)',
	'Primaquin',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALQUINE 7.5 (Ind-Swift)'
);

-- line #27387
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIMAQUIN 7.5 (SHINCE)',
	'Primaquin',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIMAQUIN 7.5 (SHINCE)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIMAQUIN 15 (SHINCE)',
	'Primaquin',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIMAQUIN 15 (SHINCE)'
);

-- line #27388
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PMQ-INGA 15 (Inga)',
	'Primaquin',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PMQ-INGA 15 (Inga)'
);

-- line #27389
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PMQ-INGA 2.5 (Inga)',
	'Primaquin',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PMQ-INGA 2.5 (Inga)'
);

-- line #27390
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PMQ-INGA 7.5 (Inga)',
	'Primaquin',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PMQ-INGA 7.5 (Inga)'
);

-- line #27391
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PMQ 15 (Inga)',
	'Primaquin',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PMQ 15 (Inga)'
);

-- line #27392
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PMQ 2.5 (Inga)',
	'Primaquin',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PMQ 2.5 (Inga)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PMQ 7.5 (Inga)',
	'Primaquin',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PMQ 7.5 (Inga)'
);

-- line #27393
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PQUINE 7.5 (CH.Bhagat)',
	'Primaquin',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PQUINE 7.5 (CH.Bhagat)'
);

-- line #27394
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'P-QUIN 15 (Fairdeal Res.)',
	'Primaquin',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'P-QUIN 15 (Fairdeal Res.)'
);

-- line #27395
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'P-QUIN 2.5 (Fairdeal Res.)',
	'Primaquin',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'P-QUIN 2.5 (Fairdeal Res.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'P-QUIN 7.5 (Fairdeal Res.)',
	'Primaquin',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'P-QUIN 7.5 (Fairdeal Res.)'
);

-- line #27396
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIMACARE 15 (Olcare)',
	'Primaquin',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIMACARE 15 (Olcare)'
);

-- line #27397
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIMACARE 7.5 (Olcare)',
	'Primaquin',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIMACARE 7.5 (Olcare)'
);

-- line #27398
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIMACIP 15 (Cipla)',
	'Primaquin',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIMACIP 15 (Cipla)'
);

-- line #27399
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIMACIP 7.5 (Cipla)',
	'Primaquin',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIMACIP 7.5 (Cipla)'
);

-- line #27400
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIMALEX 15 (LEXICA)',
	'Primaquin',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIMALEX 15 (LEXICA)'
);

-- line #27401
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIMALEX 7.5 (LEXICA)',
	'Primaquin',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIMALEX 7.5 (LEXICA)'
);

-- line #27402
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIMALINE 7.5 (Unicure)',
	'Primaquin',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIMALINE 7.5 (Unicure)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIMALINE 15 (Unicure)',
	'Primaquin',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIMALINE 15 (Unicure)'
);

-- line #27403
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIMAX 7.5 (Healthgaurd)',
	'Primaquin',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIMAX 7.5 (Healthgaurd)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIMAX 15 (Healthgaurd)',
	'Primaquin',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIMAX 15 (Healthgaurd)'
);

-- line #27404
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PVRTAB 15 (WISCON)',
	'Primaquin',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PVRTAB 15 (WISCON)'
);

-- line #27405
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYSOLINE 250 (Nicholas)',
	'Primidone',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYSOLINE 250 (Nicholas)'
);

-- line #27406
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENCID 500 (Geno Ph.)',
	'Probenecid',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENCID 500 (Geno Ph.)'
);

-- line #27407
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2.5BILL.(NOT LESS THAN)', u'strength_2': u'', u'substance': u'PROBIOTICS', u'always_empty': u'', u'form': u'CAP', u'brand': u'LACFID', u'strength_3': u'', u'company': u'Serum Int.', u'unit': u''}

-- line #27408
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.25BILL.(NOT LESS THAN)', u'strength_2': u'', u'substance': u'PROBIOTICS', u'always_empty': u'', u'form': u'SAC', u'brand': u'LACFID', u'strength_3': u'', u'company': u'Serum Int.', u'unit': u''}

-- line #27409
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRONESTYL 100 (Nicholas)',
	'Procainamide',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRONESTYL 100 (Nicholas)'
);

-- line #27410
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRONESTYL 250 (Nicholas)',
	'Procainamide',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRONESTYL 250 (Nicholas)'
);

-- line #27411
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDICARB 20 (German R.)',
	'PROCARBAZINE',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDICARB 20 (German R.)'
);

-- line #27412
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDICARB 50 (German R.)',
	'PROCARBAZINE',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDICARB 50 (German R.)'
);

-- line #27413
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOZINE 50 (Cytomed(Alkem))',
	'PROCARBAZINE',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOZINE 50 (Cytomed(Alkem))'
);

-- line #27414
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'P CARZINE 50 (Vhb)',
	'PROCARBAZINE',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'P CARZINE 50 (Vhb)'
);

-- line #27415
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACUVERT 5 (Solvay Ph.)',
	'Prochlorperazine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACUVERT 5 (Solvay Ph.)'
);

-- line #27416
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BUKATEL 3 (Panacea)',
	'Prochlorperazine',
	'TAB',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BUKATEL 3 (Panacea)'
);

-- line #27417
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COMPTIL 12.5 (WISCON)',
	'Prochlorperazine',
	'INJ',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COMPTIL 12.5 (WISCON)'
);

-- line #27418
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COMPTIL 5 (WISCON)',
	'Prochlorperazine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COMPTIL 5 (WISCON)'
);

-- line #27419
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMEX 12.5 (Depone)',
	'Prochlorperazine',
	'INJ',
	gm.nullify_empty_string('12.5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMEX 12.5 (Depone)'
);

-- line #27420
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMEX 5 (Depone)',
	'Prochlorperazine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMEX 5 (Depone)'
);

-- line #27421
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMIDOXYN 12.5 (Shreya)',
	'Prochlorperazine',
	'INJ',
	gm.nullify_empty_string('12.5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMIDOXYN 12.5 (Shreya)'
);

-- line #27422
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMIDOXYN 5 (Shreya)',
	'Prochlorperazine',
	'MD TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMIDOXYN 5 (Shreya)'
);

-- line #27423
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMIDOXYN 5 (Shreya)',
	'Prochlorperazine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMIDOXYN 5 (Shreya)'
);

-- line #27424
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMIKIND 5 (Mankind)',
	'Prochlorperazine',
	'MD TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMIKIND 5 (Mankind)'
);

-- line #27425
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMIKIND 5 (Mankind)',
	'Prochlorperazine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMIKIND 5 (Mankind)'
);

-- line #27426
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMIT 5 (Shalman)',
	'Prochlorperazine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMIT 5 (Shalman)'
);

-- line #27427
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INGAMETIL 5 (Inga)',
	'Prochlorperazine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INGAMETIL 5 (Inga)'
);

-- line #27428
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDITIL 5 (HANDS PH.)',
	'Prochlorperazine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDITIL 5 (HANDS PH.)'
);

-- line #27429
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSET 5 (Zee Lab)',
	'Prochlorperazine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSET 5 (Zee Lab)'
);

-- line #27430
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROCTIL 5 (Tripada)',
	'Prochlorperazine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROCTIL 5 (Tripada)'
);

-- line #27431
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Prochlorperazine', u'always_empty': u'', u'form': u'TAB', u'brand': u'PROMETIL', u'strength_3': u'', u'company': u'Rhombus', u'unit': u''}

-- line #27432
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DINE 5 (Mano)',
	'Procyclidine Hcl.',
	'AMP',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DINE 5 (Mano)'
);

-- line #27433
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DINE 2.5 (Mano)',
	'Procyclidine Hcl.',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DINE 2.5 (Mano)'
);

-- line #27434
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DINE 5 (Mano)',
	'Procyclidine Hcl.',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DINE 5 (Mano)'
);

-- line #27435
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEMADRIN 2.5 (Gsk)',
	'Procyclidine Hcl.',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEMADRIN 2.5 (Gsk)'
);

-- line #27436
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEMADRIN 5 (Gsk)',
	'Procyclidine Hcl.',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEMADRIN 5 (Gsk)'
);

-- line #27437
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MODIN 2.5 (MOVA PH.)',
	'Procyclidine Hcl.',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MODIN 2.5 (MOVA PH.)'
);

-- line #27438
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MODIN 5 (MOVA PH.)',
	'Procyclidine Hcl.',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MODIN 5 (MOVA PH.)'
);

-- line #27439
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCYL-5 5 (Zenith Ph.)',
	'Procyclidine Hcl.',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCYL-5 5 (Zenith Ph.)'
);

-- line #27440
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PACIDIN 2.5 (Triton Hc.)',
	'Procyclidine Hcl.',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PACIDIN 2.5 (Triton Hc.)'
);

-- line #27441
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PACIDIN 5 (Triton Hc.)',
	'Procyclidine Hcl.',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PACIDIN 5 (Triton Hc.)'
);

-- line #27442
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROCLID 5 (Tripada Hc.)',
	'Procyclidine Hcl.',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROCLID 5 (Tripada Hc.)'
);

-- line #27443
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRODINE 2.5 (Vgr Bio.)',
	'Procyclidine Hcl.',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRODINE 2.5 (Vgr Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRODINE 5 (Vgr Bio.)',
	'Procyclidine Hcl.',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRODINE 5 (Vgr Bio.)'
);

-- line #27444
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALGEST 100 (Cadila Ph.)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALGEST 100 (Cadila Ph.)'
);

-- line #27445
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALGEST 200 (Cadila Ph.)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALGEST 200 (Cadila Ph.)'
);

-- line #27446
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALGEST 100 (Cadila Ph.)',
	'Progesterone',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALGEST 100 (Cadila Ph.)'
);

-- line #27447
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPREG 100 (ALMET)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPREG 100 (ALMET)'
);

-- line #27448
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANPEE 50 (Aust Ind.)',
	'Progesterone',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANPEE 50 (Aust Ind.)'
);

-- line #27449
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100', u'strength_2': u'', u'substance': u'Progesterone', u'always_empty': u'', u'form': u'', u'brand': u'APIGEST', u'strength_3': u'', u'company': u'APICAL HC.', u'unit': u'mg'}

-- line #27450
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200', u'strength_2': u'', u'substance': u'Progesterone', u'always_empty': u'', u'form': u'', u'brand': u'APIGEST', u'strength_3': u'', u'company': u'APICAL HC.', u'unit': u'mg'}

-- line #27451
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AURICH 100 (Emcure)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AURICH 100 (Emcure)'
);

-- line #27452
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AURICH 200 (Emcure)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AURICH 200 (Emcure)'
);

-- line #27453
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AURICH 100 (Emcure)',
	'Progesterone',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AURICH 100 (Emcure)'
);

-- line #27454
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BELGEST 100 (BLUBELL)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BELGEST 100 (BLUBELL)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BELGEST 200 (BLUBELL)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BELGEST 200 (BLUBELL)'
);

-- line #27455
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BESAFE 50 (Solitaire)',
	'Progesterone',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BESAFE 50 (Solitaire)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BESAFE 100 (Solitaire)',
	'Progesterone',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BESAFE 100 (Solitaire)'
);

-- line #27456
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOPROGEST 100 (Chemo Bio.)',
	'Progesterone',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg(NATURAL MICRONISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOPROGEST 100 (Chemo Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOPROGEST 200 (Chemo Bio.)',
	'Progesterone',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg(NATURAL MICRONISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOPROGEST 200 (Chemo Bio.)'
);

-- line #27457
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELOGEST 100 (CELON)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELOGEST 100 (CELON)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELOGEST 200 (CELON)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELOGEST 200 (CELON)'
);

-- line #27458
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-HOP 300 (Corona)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-HOP 300 (Corona)'
);

-- line #27459
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-HOP 400 (Corona)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-HOP 400 (Corona)'
);

-- line #27460
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100', u'strength_2': u'', u'substance': u'Progesterone', u'always_empty': u'', u'form': u'', u'brand': u'C-HOP SOFTULES', u'strength_3': u'', u'company': u'Corona', u'unit': u'mg(NATURAL MICRONISED)'}

-- line #27461
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200', u'strength_2': u'', u'substance': u'Progesterone', u'always_empty': u'', u'form': u'', u'brand': u'C-HOP SOFTULES', u'strength_3': u'', u'company': u'Corona', u'unit': u'mg(NATURAL MICRONISED)'}

-- line #27462
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONEST 100 (VHB)',
	'Progesterone',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONEST 100 (VHB)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONEST 200 (VHB)',
	'Progesterone',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONEST 200 (VHB)'
);

-- line #27463
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONEST 300 (VHB)',
	'Progesterone',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONEST 300 (VHB)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONEST 400 (VHB)',
	'Progesterone',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONEST 400 (VHB)'
);

-- line #27464
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORION-NP 100 (Win-Medicare)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORION-NP 100 (Win-Medicare)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORION-NP 200 (Win-Medicare)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORION-NP 200 (Win-Medicare)'
);

-- line #27465
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CRINONE 8 (VHB)',
	'Progesterone',
	'GEL',
	gm.nullify_empty_string('8')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CRINONE 8 (VHB)'
);

-- line #27466
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYGEST 100 (Inga)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYGEST 100 (Inga)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYGEST 200 (Inga)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYGEST 200 (Inga)'
);

-- line #27467
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYGEST 400 (Inga)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYGEST 400 (Inga)'
);

-- line #27468
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUBAGEST 100 (Glenmark)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg(NATURAL MICRONISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUBAGEST 100 (Glenmark)'
);

-- line #27469
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUBAGEST 200 (Glenmark)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg(NATURAL MICRONISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUBAGEST 200 (Glenmark)'
);

-- line #27470
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUBAGEST 300 (GLENMARK)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUBAGEST 300 (GLENMARK)'
);

-- line #27471
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUBAGEST 400 (GLENMARK)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUBAGEST 400 (GLENMARK)'
);

-- line #27472
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUBAGEST 400 (Glenmark)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg(NATURAL MICRONISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUBAGEST 400 (Glenmark)'
);

-- line #27473
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUBAGEST 8 (Glenmark)',
	'Progesterone',
	'GEL',
	gm.nullify_empty_string('8')::numeric,
	'% W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUBAGEST 8 (Glenmark)'
);

-- line #27474
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUBAGEST 100 (Glenmark)',
	'Progesterone',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/2ML(+ BENZYL ALCOHOL 200'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUBAGEST 100 (Glenmark)'
);

-- line #27475
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUBAGEST 200 (Glenmark)',
	'Progesterone',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg/2ML(+ BENZYL ALCOHOL 400'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUBAGEST 200 (Glenmark)'
);

-- line #27476
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Progesterone', u'always_empty': u'', u'form': u'AMP', u'brand': u'DUROGEST', u'strength_3': u'', u'company': u'DAKSH', u'unit': u''}

-- line #27477
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EGERIA 100 (Ochoa)',
	'Progesterone',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EGERIA 100 (Ochoa)'
);

-- line #27478
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EGERIA 200 (Ochoa)',
	'Progesterone',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EGERIA 200 (Ochoa)'
);

-- line #27479
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENDOGEST 100 (Cipla)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENDOGEST 100 (Cipla)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENDOGEST 200 (Cipla)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENDOGEST 200 (Cipla)'
);

-- line #27480
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENDOGEST 300 (Cipla)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg(MICRONISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENDOGEST 300 (Cipla)'
);

-- line #27481
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENDOGEST 50 (Cipla)',
	'Progesterone',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENDOGEST 50 (Cipla)'
);

-- line #27482
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHINORM-P 50 (Bennet Ph.)',
	'Progesterone',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHINORM-P 50 (Bennet Ph.)'
);

-- line #27483
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETS 100 (Emcure)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETS 100 (Emcure)'
);

-- line #27484
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETS 200 (Emcure)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETS 200 (Emcure)'
);

-- line #27485
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETS 400 (Emcure)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETS 400 (Emcure)'
);

-- line #27486
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100', u'strength_2': u'200;ML', u'substance': u'Progesterone', u'always_empty': u'', u'form': u'INJ', u'brand': u'ETS', u'strength_3': u'', u'company': u'Emcure', u'unit': u''}

-- line #27487
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUGEST 100 (Samarth)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUGEST 100 (Samarth)'
);

-- line #27488
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUGEST 200 (Samarth)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUGEST 200 (Samarth)'
);

-- line #27489
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EVAGEST 100 (Evacare)',
	'Progesterone',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg(NATURAL MICRONISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EVAGEST 100 (Evacare)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EVAGEST 200 (Evacare)',
	'Progesterone',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg(NATURAL MICRONISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EVAGEST 200 (Evacare)'
);

-- line #27490
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EVAMONE 100 (RADHE BIO.)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EVAMONE 100 (RADHE BIO.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EVAMONE 200 (RADHE BIO.)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EVAMONE 200 (RADHE BIO.)'
);

-- line #27491
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EVEN 100 (Rekvina)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EVEN 100 (Rekvina)'
);

-- line #27492
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EVEN 200 (Rekvina)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EVEN 200 (Rekvina)'
);

-- line #27493
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEOTOVEL 50 (Kinedex Hc.)',
	'Progesterone',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEOTOVEL 50 (Kinedex Hc.)'
);

-- line #27494
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERTI-100 100 (Royal)',
	'Progesterone',
	'SOFT GEL',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERTI-100 100 (Royal)'
);

-- line #27495
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERTI 200 (Royal Lab)',
	'Progesterone',
	'SG CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg(NATURAL MICRONISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERTI 200 (Royal Lab)'
);

-- line #27496
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIRMUP 100 (Nicholas)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIRMUP 100 (Nicholas)'
);

-- line #27497
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIRMUP 200 (Nicholas)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIRMUP 200 (Nicholas)'
);

-- line #27498
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FULGEST 100 (Micro Nova)',
	'Progesterone',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FULGEST 100 (Micro Nova)'
);

-- line #27499
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FULGEST 200 (Micro Nova)',
	'Progesterone',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FULGEST 200 (Micro Nova)'
);

-- line #27500
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GES-ONE 100 (RASS HC.)',
	'Progesterone',
	'AMP',
	gm.nullify_empty_string('100')::numeric,
	'500'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GES-ONE 100 (RASS HC.)'
);

-- line #27501
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GES-ONE 100 (RASS HC.)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GES-ONE 100 (RASS HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GES-ONE 200 (RASS HC.)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GES-ONE 200 (RASS HC.)'
);

-- line #27502
-- ignoring line: field [strength_1] not numeric: >>>N.I.<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Progesterone', u'always_empty': u'', u'form': u'CAP', u'brand': u'GESRY', u'strength_3': u'', u'company': u'AAMORB(ST. MORISON)', u'unit': u'N.I.'}

-- line #27503
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GESTASURE 100 (Mankind)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GESTASURE 100 (Mankind)'
);

-- line #27504
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GESTASURE 200 (Mankind)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GESTASURE 200 (Mankind)'
);

-- line #27505
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GESTCARE 100 (Nexus)',
	'Progesterone',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg(NATURAL MICRONISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GESTCARE 100 (Nexus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GESTCARE 200 (Nexus)',
	'Progesterone',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg(NATURAL MICRONISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GESTCARE 200 (Nexus)'
);

-- line #27506
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GESTCARE 400 (Nexus)',
	'Progesterone',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg(NATURAL MICRONISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GESTCARE 400 (Nexus)'
);

-- line #27507
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GESTER-NP 100 (Shinto Org.)',
	'Progesterone',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/4ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GESTER-NP 100 (Shinto Org.)'
);

-- line #27508
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GESTER-NP 200 (Shinto Org.)',
	'Progesterone',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GESTER-NP 200 (Shinto Org.)'
);

-- line #27509
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GESTOEN 400 (Ferring Ph.)',
	'PROGESTERONE',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GESTOEN 400 (Ferring Ph.)'
);

-- line #27510
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GESTOFIT 300 (Dabur Ph.)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GESTOFIT 300 (Dabur Ph.)'
);

-- line #27511
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GESTOFIT 400 (Dabur Ph.)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GESTOFIT 400 (Dabur Ph.)'
);

-- line #27512
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GESTONE 100 (Ferring Ph.)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GESTONE 100 (Ferring Ph.)'
);

-- line #27513
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GESTONE 200 (Ferring Ph.)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GESTONE 200 (Ferring Ph.)'
);

-- line #27514
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GESTONE 50 (Ferring Ph.)',
	'Progesterone',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GESTONE 50 (Ferring Ph.)'
);

-- line #27515
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GESTORIN 100 (Intra Lab)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GESTORIN 100 (Intra Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GESTORIN 200 (Intra Lab)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GESTORIN 200 (Intra Lab)'
);

-- line #27516
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GESTORIN 100 (Intra Lab)',
	'Progesterone',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GESTORIN 100 (Intra Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GESTORIN 200 (Intra Lab)',
	'Progesterone',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GESTORIN 200 (Intra Lab)'
);

-- line #27517
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRAVIGEST 200 (Sven Gen.)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRAVIGEST 200 (Sven Gen.)'
);

-- line #27518
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU.', u'strength_2': u'', u'substance': u'Progesterone', u'always_empty': u'', u'form': u'INJ', u'brand': u'GRAVION', u'strength_3': u'', u'company': u'Obsurge', u'unit': u''}

-- line #27519
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRAVION 100 (Obsurge)',
	'Progesterone',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg(NATURAL MICRONISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRAVION 100 (Obsurge)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRAVION 200 (Obsurge)',
	'Progesterone',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg(NATURAL MICRONISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRAVION 200 (Obsurge)'
);

-- line #27520
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100', u'strength_2': u'200;ML', u'substance': u'Progesterone', u'always_empty': u'', u'form': u'TAB', u'brand': u'GYNOGEST-N', u'strength_3': u'', u'company': u'Stanmark', u'unit': u''}

-- line #27521
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEMA 100 (VENSAT)',
	'Progesterone',
	'AMP',
	gm.nullify_empty_string('100')::numeric,
	'200'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEMA 100 (VENSAT)'
);

-- line #27522
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEMA 100 (VENSAT)',
	'Progesterone',
	'SG CAP',
	gm.nullify_empty_string('100')::numeric,
	'200'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEMA 100 (VENSAT)'
);

-- line #27523
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HERNMP 100 (Torrent)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg(MICRONISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HERNMP 100 (Torrent)'
);

-- line #27524
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HERNMP 200 (Torrent)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg(MICRONISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HERNMP 200 (Torrent)'
);

-- line #27525
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HERNMP 100 (Torrent)',
	'Progesterone',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg(+BENZYL ALCOHOL 0.1'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HERNMP 100 (Torrent)'
);

-- line #27526
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HILGESTRON 100 (HIND. LATEX)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HILGESTRON 100 (HIND. LATEX)'
);

-- line #27527
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HILGESTRON 300 (HIND. LATEX)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HILGESTRON 300 (HIND. LATEX)'
);

-- line #27528
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HOPE-100 SOFTGEL 100 (ROSE LABS)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HOPE-100 SOFTGEL 100 (ROSE LABS)'
);

-- line #27529
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HOPE-200 200 (ROSE LABS)',
	'Progesterone',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HOPE-200 200 (ROSE LABS)'
);

-- line #27530
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HOPE 200 (ROSE LABS)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HOPE 200 (ROSE LABS)'
);

-- line #27531
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HOPE 100 (ROSE LABS)',
	'Progesterone',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HOPE 100 (ROSE LABS)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HOPE 200 (ROSE LABS)',
	'Progesterone',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HOPE 200 (ROSE LABS)'
);

-- line #27532
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Progesterone', u'always_empty': u'', u'form': u'INJ', u'brand': u'HORPEG', u'strength_3': u'', u'company': u'Cubit Hc.', u'unit': u''}

-- line #27533
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYPROGEST 100 (Colinz Lab)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYPROGEST 100 (Colinz Lab)'
);

-- line #27534
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYPROGEST 200 (Colinz Lab)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYPROGEST 200 (Colinz Lab)'
);

-- line #27535
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYPROGEST 50 (Colinz Lab)',
	'Progesterone',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYPROGEST 50 (Colinz Lab)'
);

-- line #27536
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JOPREST 100 (D.R.John''S)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JOPREST 100 (D.R.John''S)'
);

-- line #27537
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JOPREST 200 (D.R.John''S)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JOPREST 200 (D.R.John''S)'
);

-- line #27538
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LGP 100 (LITTLE GREAVE)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'200'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LGP 100 (LITTLE GREAVE)'
);

-- line #27539
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUPIGEST 100 (Lupin)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUPIGEST 100 (Lupin)'
);

-- line #27540
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUPIGEST 200 (Lupin)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUPIGEST 200 (Lupin)'
);

-- line #27541
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUPIGEST 300 (Lupin)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg(MICRONISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUPIGEST 300 (Lupin)'
);

-- line #27542
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUPIGEST 400 (Lupin)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg(MICRONISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUPIGEST 400 (Lupin)'
);

-- line #27543
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUPIGESTRONE 50 (Lupin)',
	'Progesterone',
	'AMP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUPIGESTRONE 50 (Lupin)'
);

-- line #27544
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUTACARE 100 (Biomax Bio.)',
	'Progesterone',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg(NATURAL MICRONISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUTACARE 100 (Biomax Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUTACARE 200 (Biomax Bio.)',
	'Progesterone',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg(NATURAL MICRONISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUTACARE 200 (Biomax Bio.)'
);

-- line #27545
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUTACARE 100 (Biomax Bio.)',
	'Progesterone',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg(NATURAL MICRONISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUTACARE 100 (Biomax Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUTACARE 200 (Biomax Bio.)',
	'Progesterone',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg(NATURAL MICRONISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUTACARE 200 (Biomax Bio.)'
);

-- line #27546
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACGEST 100 (Macleods)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACGEST 100 (Macleods)'
);

-- line #27547
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MECGEST 200 (Macleods)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MECGEST 200 (Macleods)'
);

-- line #27548
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDPRO 100 (STERLING)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDPRO 100 (STERLING)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDPRO 200 (STERLING)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDPRO 200 (STERLING)'
);

-- line #27549
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICPRO 200 (CH.Bhagat)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICPRO 200 (CH.Bhagat)'
);

-- line #27550
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICPRO 100 (CH.Bhagat)',
	'Progesterone',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICPRO 100 (CH.Bhagat)'
);

-- line #27551
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICPRO 200 (CH.Bhagat)',
	'Progesterone',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg/4ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICPRO 200 (CH.Bhagat)'
);

-- line #27552
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICPRO 50 (CH.Bhagat)',
	'Progesterone',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/1ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICPRO 50 (CH.Bhagat)'
);

-- line #27553
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICROGEST 200 (Walter B.)',
	'Progesterone',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICROGEST 200 (Walter B.)'
);

-- line #27554
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICROGEST 50 (Walter B.)',
	'Progesterone',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICROGEST 50 (Walter B.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICROGEST 100 (Walter B.)',
	'Progesterone',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICROGEST 100 (Walter B.)'
);

-- line #27555
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100', u'strength_2': u'', u'substance': u'Progesterone', u'always_empty': u'', u'form': u'', u'brand': u'MICROGEST SGCAP', u'strength_3': u'', u'company': u'Walter B.', u'unit': u'mg (NATURAL MICRON.)'}

-- line #27556
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200', u'strength_2': u'', u'substance': u'Progesterone', u'always_empty': u'', u'form': u'', u'brand': u'MICROGEST SGCAP', u'strength_3': u'', u'company': u'Walter B.', u'unit': u'mg (NATURAL MICRON.)'}

-- line #27557
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'300', u'strength_2': u'', u'substance': u'Progesterone', u'always_empty': u'', u'form': u'', u'brand': u'MICROGEST SGCAP', u'strength_3': u'', u'company': u'Walter B.', u'unit': u'mg (NATURAL MICRON.)'}

-- line #27558
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'400', u'strength_2': u'', u'substance': u'Progesterone', u'always_empty': u'', u'form': u'', u'brand': u'MICROGEST SGCAP', u'strength_3': u'', u'company': u'Walter B.', u'unit': u'mg (NATURAL MICRON.)'}

-- line #27559
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICROPROGESTRA 100 (Sandoz)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICROPROGESTRA 100 (Sandoz)'
);

-- line #27560
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICROPROGESTRA 200 (Sandoz)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICROPROGESTRA 200 (Sandoz)'
);

-- line #27561
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MINAGEST 100 (Ar-Ex Labs.)',
	'PROGESTERONE',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'200'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MINAGEST 100 (Ar-Ex Labs.)'
);

-- line #27562
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIPROGEN 50 (Bharat S.)',
	'Progesterone',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIPROGEN 50 (Bharat S.)'
);

-- line #27563
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100', u'strength_2': u'', u'substance': u'Progesterone', u'always_empty': u'', u'form': u'', u'brand': u'MIPROGEN PES', u'strength_3': u'', u'company': u'Bharat S.', u'unit': u'mg'}

-- line #27564
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200', u'strength_2': u'', u'substance': u'Progesterone', u'always_empty': u'', u'form': u'', u'brand': u'MIPROGEN PES', u'strength_3': u'', u'company': u'Bharat S.', u'unit': u'mg(NAT. MICRONISED)'}

-- line #27565
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'400', u'strength_2': u'', u'substance': u'Progesterone', u'always_empty': u'', u'form': u'', u'brand': u'MIPROGEN PES', u'strength_3': u'', u'company': u'Bharat S.', u'unit': u'mg'}

-- line #27566
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAMGEM SOFTGEL 200 (DEWCARE)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAMGEM SOFTGEL 200 (DEWCARE)'
);

-- line #27567
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NANCE 100 (Zee Lab)',
	'Progesterone',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg(NATURAL MICRONISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NANCE 100 (Zee Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NANCE 200 (Zee Lab)',
	'Progesterone',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg(NATURAL MICRONISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NANCE 200 (Zee Lab)'
);

-- line #27568
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NATRON 100 (Panjon)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg(NATURAL MICRONISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NATRON 100 (Panjon)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NATRON 200 (Panjon)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg(NATURAL MICRONISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NATRON 200 (Panjon)'
);

-- line #27569
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NATRON 200 (Panjon)',
	'Progesterone',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg(NATURAL MICRONISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NATRON 200 (Panjon)'
);

-- line #27570
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NATUROGEST 100 (German R.)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg(NATURAL MICRONISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NATUROGEST 100 (German R.)'
);

-- line #27571
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NATUROGEST 200 (German R.)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NATUROGEST 200 (German R.)'
);

-- line #27572
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NATUROGEST 300 (German R.)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg(NATURAL MICRONISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NATUROGEST 300 (German R.)'
);

-- line #27573
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NATUROGEST 400 (German R.)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg(NATURAL MICRONISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NATUROGEST 400 (German R.)'
);

-- line #27574
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NATUROGEST 100 (German R.)',
	'Progesterone',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NATUROGEST 100 (German R.)'
);

-- line #27575
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NATUROGEST 50 (German R.)',
	'Progesterone',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NATUROGEST 50 (German R.)'
);

-- line #27576
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOGEST 100 (VHB)',
	'Progesterone',
	'AMP',
	gm.nullify_empty_string('100')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOGEST 100 (VHB)'
);

-- line #27577
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOGEST 100 (VHB)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg(NATURAL MICRONISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOGEST 100 (VHB)'
);

-- line #27578
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOGEST 200 (VHB)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg(NATURAL MICRONISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOGEST 200 (VHB)'
);

-- line #27579
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOGEST 400 (VHB)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg(NATURAL MICRONISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOGEST 400 (VHB)'
);

-- line #27580
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOGEST 50 (VHB)',
	'Progesterone',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOGEST 50 (VHB)'
);

-- line #27581
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Progesterone', u'always_empty': u'', u'form': u'INJ', u'brand': u'NEOGEST', u'strength_3': u'', u'company': u'Vhb', u'unit': u''}

-- line #27582
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIDAGEN 100 (Systopic)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIDAGEN 100 (Systopic)'
);

-- line #27583
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIDAGEN 200 (Systopic)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIDAGEN 200 (Systopic)'
);

-- line #27584
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NMP 200 (ZOTICUS)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NMP 200 (ZOTICUS)'
);

-- line #27585
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'N-PROCH 100 (Cadex Lab)',
	'Progesterone',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'N-PROCH 100 (Cadex Lab)'
);

-- line #27586
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'N-PROCH 100 (Cadex Lab)',
	'Progesterone',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'N-PROCH 100 (Cadex Lab)'
);

-- line #27587
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'N-SANIGEST 200 (Sanify)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'N-SANIGEST 200 (Sanify)'
);

-- line #27588
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NT-NATAL MP 100 (Kee Ph.)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NT-NATAL MP 100 (Kee Ph.)'
);

-- line #27589
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NT-NATAL MP 200 (Kee Ph.)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NT-NATAL MP 200 (Kee Ph.)'
);

-- line #27590
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OGEST 100 (Comed)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OGEST 100 (Comed)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OGEST 200 (Comed)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OGEST 200 (Comed)'
);

-- line #27591
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OGEST 100 (Comed Chem.)',
	'Progesterone',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg(NATURAL MICRONISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OGEST 100 (Comed Chem.)'
);

-- line #27592
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OGEST 200 (Comed Chem.)',
	'Progesterone',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg(NATURAL MICRONISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OGEST 200 (Comed Chem.)'
);

-- line #27593
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OGEST 100 (Siomond)',
	'Progesterone',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OGEST 100 (Siomond)'
);

-- line #27594
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONASTRONE 100 (Sayona)',
	'Progesterone',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONASTRONE 100 (Sayona)'
);

-- line #27595
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPTOGEST 100 (Troikaa)',
	'Progesterone',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPTOGEST 100 (Troikaa)'
);

-- line #27596
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPTOGEST 200 (Troikaa)',
	'Progesterone',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPTOGEST 200 (Troikaa)'
);

-- line #27597
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORGAGEST 250 (Organon)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORGAGEST 250 (Organon)'
);

-- line #27598
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXIGEST 100 (AXYZEN LIFE)',
	'Progesterone',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXIGEST 100 (AXYZEN LIFE)'
);

-- line #27599
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXIGEST 200 (AXYZEN LIFE)',
	'Progesterone',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXIGEST 200 (AXYZEN LIFE)'
);

-- line #27600
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXIGEST 100 (AXYZEN LIFE)',
	'Progesterone',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXIGEST 100 (AXYZEN LIFE)'
);

-- line #27601
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXIGEST 200 (AXYZEN LIFE)',
	'Progesterone',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXIGEST 200 (AXYZEN LIFE)'
);

-- line #27602
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGANGEST-N 100 (Espira Life)',
	'Progesterone',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg(NATURAL MICRONISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGANGEST-N 100 (Espira Life)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGANGEST-N 200 (Espira Life)',
	'Progesterone',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg(NATURAL MICRONISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGANGEST-N 200 (Espira Life)'
);

-- line #27603
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGCITIL 100 (MOLEKULE)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGCITIL 100 (MOLEKULE)'
);

-- line #27604
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGCITIL 200 (MOLEKULE)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGCITIL 200 (MOLEKULE)'
);

-- line #27605
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGTAIN 100 (Medley)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGTAIN 100 (Medley)'
);

-- line #27606
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROGESTERONE 25 (KOLSON''S)',
	'Progesterone',
	'AMP',
	gm.nullify_empty_string('25')::numeric,
	'50'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROGESTERONE 25 (KOLSON''S)'
);

-- line #27607
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROGEST 50 (Samarth)',
	'Progesterone',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROGEST 50 (Samarth)'
);

-- line #27608
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROGMINAT 100 (Maneesh)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg(NATURAL MICRONISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROGMINAT 100 (Maneesh)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROGMINAT 200 (Maneesh)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg(NATURAL MICRONISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROGMINAT 200 (Maneesh)'
);

-- line #27609
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRONAT 100 (Candor Bio.)',
	'Progesterone',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRONAT 100 (Candor Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRONAT 200 (Candor Bio.)',
	'Progesterone',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRONAT 200 (Candor Bio.)'
);

-- line #27610
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRONATURE 200 (Viva Labs.)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRONATURE 200 (Viva Labs.)'
);

-- line #27611
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRONIN 200 (Prohealth)',
	'Progesterone',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg(NATURAL MICRONISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRONIN 200 (Prohealth)'
);

-- line #27612
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRONIN 50 (Prohealth)',
	'Progesterone',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg(NATURAL MICRONISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRONIN 50 (Prohealth)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRONIN 100 (Prohealth)',
	'Progesterone',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg(NATURAL MICRONISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRONIN 100 (Prohealth)'
);

-- line #27613
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRO-ONE 200 (Intra(INVISION))',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRO-ONE 200 (Intra(INVISION))'
);

-- line #27614
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRO-ONE 100 (INVISION)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRO-ONE 100 (INVISION)'
);

-- line #27615
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRO-ONE 100 (INVISION)',
	'Progesterone',
	'VIAL',
	gm.nullify_empty_string('100')::numeric,
	'200'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRO-ONE 100 (INVISION)'
);

-- line #27616
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROPEG 100 (Unimarck)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROPEG 100 (Unimarck)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROPEG 200 (Unimarck)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROPEG 200 (Unimarck)'
);

-- line #27617
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROPEG 100 (Unimarck)',
	'Progesterone',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROPEG 100 (Unimarck)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROPEG 200 (Unimarck)',
	'Progesterone',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROPEG 200 (Unimarck)'
);

-- line #27618
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROZY 200 (NEISS)',
	'Progesterone',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROZY 200 (NEISS)'
);

-- line #27619
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Progesterone', u'always_empty': u'', u'form': u'SG CAP', u'brand': u'PROZY', u'strength_3': u'', u'company': u'NEISS', u'unit': u''}

-- line #27620
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRUDENT-400 400 (Medicorp)',
	'PROGESTERONE',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRUDENT-400 400 (Medicorp)'
);

-- line #27621
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PUREGEST 100 (Sun)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PUREGEST 100 (Sun)'
);

-- line #27622
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PUREGEST 200 (Sun)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PUREGEST 200 (Sun)'
);

-- line #27623
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PUREGEST 400 (Sun)',
	'Progesterone',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PUREGEST 400 (Sun)'
);

-- line #27624
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PUREGEST 50 (Sun)',
	'Progesterone',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PUREGEST 50 (Sun)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PUREGEST 100 (Sun)',
	'Progesterone',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PUREGEST 100 (Sun)'
);

-- line #27625
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RECOGEST-N 100 (Radix Bio.)',
	'Progesterone',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RECOGEST-N 100 (Radix Bio.)'
);

-- line #27626
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REMENS 50 (Svizera)',
	'Progesterone',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg(+BENZYL ALCOHOL'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REMENS 50 (Svizera)'
);

-- line #27627
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REMENS 100 (SVIZERA HC.)',
	'Progesterone',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg(WITH BENZYL ALCOHOL 200'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REMENS 100 (SVIZERA HC.)'
);

-- line #27628
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REMENS 100 (Svizera)',
	'Progesterone',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg(NATURAL MICRONISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REMENS 100 (Svizera)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REMENS 200 (Svizera)',
	'Progesterone',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg(NATURAL MICRONISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REMENS 200 (Svizera)'
);

-- line #27629
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RETA DEL 100 (Biocia Hc.)',
	'Progesterone',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/2ML(NATURAL MICRONISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RETA DEL 100 (Biocia Hc.)'
);

-- line #27630
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RETA DEL 100 (Biocia Hc.)',
	'Progesterone',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg(NATURAL MICRONISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RETA DEL 100 (Biocia Hc.)'
);

-- line #27631
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIGEST 100 (RISHAB(OROCHEM))',
	'Progesterone',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'200'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIGEST 100 (RISHAB(OROCHEM))'
);

-- line #27632
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIGEST 100 (RISHAB(OROCHEM))',
	'Progesterone',
	'SG CAP',
	gm.nullify_empty_string('100')::numeric,
	'200'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIGEST 100 (RISHAB(OROCHEM))'
);

-- line #27633
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIMGEST 100 (Heal All Ph.)',
	'Progesterone',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg(NATURAL MICRONISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIMGEST 100 (Heal All Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIMGEST 200 (Heal All Ph.)',
	'Progesterone',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg(NATURAL MICRONISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIMGEST 200 (Heal All Ph.)'
);

-- line #27634
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIMGEST 100 (Heal All Ph.)',
	'Progesterone',
	'SG CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg(NATURAL MICRONISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIMGEST 100 (Heal All Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIMGEST 200 (Heal All Ph.)',
	'Progesterone',
	'SG CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg(NATURAL MICRONISED)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIMGEST 200 (Heal All Ph.)'
);

-- line #27635
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAVERAN 100 (Unicure)',
	'Proguanil Hcl.',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAVERAN 100 (Unicure)'
);

-- line #27636
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROGUNAL 100 (LEXICA)',
	'Proguanil Hcl.',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROGUNAL 100 (LEXICA)'
);

-- line #27637
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROMAL 100 (Astrum Hc.)',
	'Proguanil Hcl.',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROMAL 100 (Astrum Hc.)'
);

-- line #27638
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Promethazine', u'always_empty': u'', u'form': u'ELIXIR', u'brand': u'EMIN', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #27639
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMIN 25 (Cipla)',
	'Promethazine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMIN 25 (Cipla)'
);

-- line #27640
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMISPAN 5 (Unimarck)',
	'Promethazine',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMISPAN 5 (Unimarck)'
);

-- line #27641
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LARGAN 5 (Southsourne)',
	'Promethazine Hcl.',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5 ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LARGAN 5 (Southsourne)'
);

-- line #27642
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOGAN 5 (Rhombus)',
	'Promethazine Hcl.',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5 ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOGAN 5 (Rhombus)'
);

-- line #27643
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METHAZINE 5 (Franklin)',
	'Promethazine Hcl.',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METHAZINE 5 (Franklin)'
);

-- line #27644
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Promethazine Hcl.', u'always_empty': u'', u'form': u'INJ', u'brand': u'ONE-H', u'strength_3': u'', u'company': u'Theo Ph.', u'unit': u''}

-- line #27645
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PGAN 5 (Patson)',
	'Promethazine Hcl.',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PGAN 5 (Patson)'
);

-- line #27646
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHENA KID 25 (Ind-Swift)',
	'Promethazine Hcl.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHENA KID 25 (Ind-Swift)'
);

-- line #27647
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHENA KID 5 (Ind-Swift)',
	'Promethazine Hcl.',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHENA KID 5 (Ind-Swift)'
);

-- line #27648
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHENAZINE 5 (Jagsonpal)',
	'Promethazine Hcl.',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHENAZINE 5 (Jagsonpal)'
);

-- line #27649
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHENERGAN 25 (Nicholas)',
	'Promethazine Hcl.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHENERGAN 25 (Nicholas)'
);

-- line #27650
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHENERGAN 5 (Nicholas)',
	'Promethazine Hcl.',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHENERGAN 5 (Nicholas)'
);

-- line #27651
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHENERGAN 10 (Nicholas)',
	'Promethazine Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHENERGAN 10 (Nicholas)'
);

-- line #27652
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHENERGAN 25 (Nicholas)',
	'Promethazine Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHENERGAN 25 (Nicholas)'
);

-- line #27653
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHENZEE 5 (Shalaks)',
	'Promethazine Hcl.',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHENZEE 5 (Shalaks)'
);

-- line #27654
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREMAGAN 25 (SHINE PH.)',
	'Promethazine Hcl.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREMAGAN 25 (SHINE PH.)'
);

-- line #27655
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIMOZYN 25 (WISCON)',
	'Promethazine Hcl.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIMOZYN 25 (WISCON)'
);

-- line #27656
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIMOZYN 5 (WISCON)',
	'Promethazine Hcl.',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIMOZYN 5 (WISCON)'
);

-- line #27657
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROFIN 5 (Olcare)',
	'Promethazine Hcl.',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5 ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROFIN 5 (Olcare)'
);

-- line #27658
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROMASUN 25 (Sun)',
	'Promethazine Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROMASUN 25 (Sun)'
);

-- line #27659
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROMPT 5 (Neuron Ph.)',
	'Promethazine Hcl.',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROMPT 5 (Neuron Ph.)'
);

-- line #27660
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROPHEN 5 (Ultramark)',
	'Promethazine Hcl.',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROPHEN 5 (Ultramark)'
);

-- line #27661
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROZED 5 (HALO MEDI.)',
	'Promethazine Hcl.',
	'SUS',
	gm.nullify_empty_string('5')::numeric,
	'mg/5 ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROZED 5 (HALO MEDI.)'
);

-- line #27662
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROZ 25 (Tripada Hc.)',
	'Promethazine Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROZ 25 (Tripada Hc.)'
);

-- line #27663
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HISTAZINE 10 (EAST WEST)',
	'Promethazine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HISTAZINE 10 (EAST WEST)'
);

-- line #27664
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORMAGAN 5 (GUJ. TE.)',
	'Promethazine',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORMAGAN 5 (GUJ. TE.)'
);

-- line #27665
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROGENE-25 25 (PSYCOREM)',
	'Promethazine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROGENE-25 25 (PSYCOREM)'
);

-- line #27666
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROZET 5 (ALEXUS(SURYA))',
	'Promethazine',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROZET 5 (ALEXUS(SURYA))'
);

-- line #27667
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVOMINE 25 (Nicholas)',
	'Promethazine Theoclate',
	'MD TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVOMINE 25 (Nicholas)'
);

-- line #27668
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVOMINE 25 (Nicholas)',
	'Promethazine Theoclate',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVOMINE 25 (Nicholas)'
);

-- line #27669
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONE-H 10 (Theo Ph.)',
	'Promethazine Theoclate',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONE-H 10 (Theo Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONE-H 25 (Theo Ph.)',
	'Promethazine Theoclate',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONE-H 25 (Theo Ph.)'
);

-- line #27670
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRADIL 150 (Emcure)',
	'PROPAFENONE',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRADIL 150 (Emcure)'
);

-- line #27671
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RHYTHMONORM 150 (German R.)',
	'PROPAFENONE',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RHYTHMONORM 150 (German R.)'
);

-- line #27672
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROBANTHINE 15 (Rpg Life)',
	'Propantheline Bromide',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROBANTHINE 15 (Rpg Life)'
);

-- line #27673
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRO BANTHINE 15 (Rpg Life)',
	'Propantheline',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRO BANTHINE 15 (Rpg Life)'
);

-- line #27674
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRO-BENTHINE 15 (Rpg Life)',
	'Propantheline',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRO-BENTHINE 15 (Rpg Life)'
);

-- line #27675
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IDOPE EYE 0.5 (Intas)',
	'PROPARACAINE HCL.',
	'DROPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%W/V( BENZALKONIUM CHL. 0.01'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IDOPE EYE 0.5 (Intas)'
);

-- line #27676
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELOFOL 10 (Themis)',
	'PROPOFOL',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELOFOL 10 (Themis)'
);

-- line #27677
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1', u'strength_2': u'', u'substance': u'Propofol', u'always_empty': u'', u'form': u'', u'brand': u'CRITIFOL', u'strength_3': u'', u'company': u'Nicholas', u'unit': u'%'}

-- line #27678
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIPRIVAN % 1 (Nicholas)',
	'Propofol',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIPRIVAN % 1 (Nicholas)'
);

-- line #27679
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FRESOFOL 10 (Fresenius)',
	'Propofol',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FRESOFOL 10 (Fresenius)'
);

-- line #27680
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYPRO 100 (CELON(REVILON))',
	'PROPOFOL',
	'VIAL',
	gm.nullify_empty_string('100')::numeric,
	'200'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYPRO 100 (CELON(REVILON))'
);

-- line #27681
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOROF 10 (Neon)',
	'PROPOFOL',
	'AMP/VIAL',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOROF 10 (Neon)'
);

-- line #27682
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOROF 10 (Neon)',
	'PROPOFOL',
	'VIAL',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOROF 10 (Neon)'
);

-- line #27683
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIRFOL 1 (NIRLIFE HEALTH)',
	'PROPOFOL',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIRFOL 1 (NIRLIFE HEALTH)'
);

-- line #27684
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PACIFOL 10 (Alembic)',
	'PROPOFOL',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PACIFOL 10 (Alembic)'
);

-- line #27685
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10', u'strength_2': u'', u'substance': u'PROPOFOL', u'always_empty': u'', u'form': u'', u'brand': u'PROANES', u'strength_3': u'', u'company': u'German R.', u'unit': u'mg(EXCIPIENTS SOYABEAN OIL USP GLYCEROL IP)'}

-- line #27686
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROFOL % 1 (Claris L.)',
	'Propofol',
	'V',
	gm.nullify_empty_string('1')::numeric,
	'%(WITH EGG LECITHIN 12'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROFOL % 1 (Claris L.)'
);

-- line #27687
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROFOL % 2 (Claris L.)',
	'Propofol',
	'V',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROFOL % 2 (Claris L.)'
);

-- line #27688
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROPOTOP 10 (LYKA LABS)',
	'PROPOFOL',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROPOTOP 10 (LYKA LABS)'
);

-- line #27689
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROPOVAN % 1 (Bharat S.)',
	'Propofol',
	'V',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROPOVAN % 1 (Bharat S.)'
);

-- line #27690
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROPOVAN % 2 (Bharat S.)',
	'Propofol',
	'V',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROPOVAN % 2 (Bharat S.)'
);

-- line #27691
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROSTHETIK 1 (Life Med.)',
	'PROPOFOL',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROSTHETIK 1 (Life Med.)'
);

-- line #27692
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARMINAL 10 (EAST WEST)',
	'Propranolol Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARMINAL 10 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARMINAL 20 (EAST WEST)',
	'Propranolol Hcl.',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARMINAL 20 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARMINAL 40 (EAST WEST)',
	'Propranolol Hcl.',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARMINAL 40 (EAST WEST)'
);

-- line #27693
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BELOC TR 40 (Tripada)',
	'Propranolol Hcl.',
	'CAP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BELOC TR 40 (Tripada)'
);

-- line #27694
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BEPROP TR 40 (NAVNIDHI LIFE)',
	'Propranolol Hcl.',
	'CAP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BEPROP TR 40 (NAVNIDHI LIFE)'
);

-- line #27695
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETABLOC 10 (U S V)',
	'Propranolol Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETABLOC 10 (U S V)'
);

-- line #27696
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BPNORM 40 (Medley)',
	'Propranolol Hcl.',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BPNORM 40 (Medley)'
);

-- line #27697
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BPSTAT 20 (Rhombus)',
	'Propranolol Hcl.',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BPSTAT 20 (Rhombus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BPSTAT 40 (Rhombus)',
	'Propranolol Hcl.',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BPSTAT 40 (Rhombus)'
);

-- line #27698
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARBNOL 10 (Olcare)',
	'Propranolol Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARBNOL 10 (Olcare)'
);

-- line #27699
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARBNOL 40 (Olcare)',
	'Propranolol Hcl.',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARBNOL 40 (Olcare)'
);

-- line #27700
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CENYL 40 (SYKOCURE)',
	'Propranolol Hcl.',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CENYL 40 (SYKOCURE)'
);

-- line #27701
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CERENOL 10 (Olcare)',
	'Propranolol Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CERENOL 10 (Olcare)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CERENOL 40 (Olcare)',
	'Propranolol Hcl.',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CERENOL 40 (Olcare)'
);

-- line #27702
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPLAR 20 (Cipla)',
	'Propranolol Hcl.',
	'LA TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPLAR 20 (Cipla)'
);

-- line #27703
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPLAR 10 (Cipla)',
	'Propranolol Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPLAR 10 (Cipla)'
);

-- line #27704
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPLAR 40 (Cipla)',
	'Propranolol Hcl.',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPLAR 40 (Cipla)'
);

-- line #27705
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPLAR 80 (Cipla)',
	'Propranolol Hcl.',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPLAR 80 (Cipla)'
);

-- line #27706
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORBETA 10 (Nicholas)',
	'Propranolol Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORBETA 10 (Nicholas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORBETA 40 (Nicholas)',
	'Propranolol Hcl.',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORBETA 40 (Nicholas)'
);

-- line #27707
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDERAL 10 (Nicholas)',
	'Propranolol Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDERAL 10 (Nicholas)'
);

-- line #27708
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDERAL 40 (Nicholas)',
	'Propranolol Hcl.',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDERAL 40 (Nicholas)'
);

-- line #27709
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDERAL 80 (Nicholas)',
	'Propranolol Hcl.',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDERAL 80 (Nicholas)'
);

-- line #27710
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOL 40 (Sali Hc.)',
	'Propranolol Hcl.',
	'SR TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOL 40 (Sali Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOL 80 (Sali Hc.)',
	'Propranolol Hcl.',
	'SR TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOL 80 (Sali Hc.)'
);

-- line #27711
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOL 10 (Mano Ph.)',
	'Propranolol Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOL 10 (Mano Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOL 20 (Mano Ph.)',
	'Propranolol Hcl.',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOL 20 (Mano Ph.)'
);

-- line #27712
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOPROLOL 40 (Mano)',
	'Propranolol Hcl.',
	'SR TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOPROLOL 40 (Mano)'
);

-- line #27713
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOPROLOL 10 (Mano)',
	'Propranolol Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOPROLOL 10 (Mano)'
);

-- line #27714
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOPROLOL 20 (Mano)',
	'Propranolol Hcl.',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOPROLOL 20 (Mano)'
);

-- line #27715
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOPROLOL 40 (Mano)',
	'Propranolol Hcl.',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOPROLOL 40 (Mano)'
);

-- line #27716
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIGRABETA-TR 20 (Alkem)',
	'Propranolol Hcl.',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIGRABETA-TR 20 (Alkem)'
);

-- line #27717
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIGRABETA TR 40 (Alkem)',
	'Propranolol Hcl.',
	'CAP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIGRABETA TR 40 (Alkem)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIGRABETA TR 60 (Alkem)',
	'Propranolol Hcl.',
	'CAP',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIGRABETA TR 60 (Alkem)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIGRABETA TR 80 (Alkem)',
	'Propranolol Hcl.',
	'CAP',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIGRABETA TR 80 (Alkem)'
);

-- line #27718
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOVALOL 40 (MOVA PH.)',
	'Propranolol Hcl.',
	'SR CAP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOVALOL 40 (MOVA PH.)'
);

-- line #27719
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOVALOL 80 (MOVA PH.)',
	'Propranolol Hcl.',
	'SR CAP',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOVALOL 80 (MOVA PH.)'
);

-- line #27720
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOVALOL 20 (MOVA PH.)',
	'Propranolol Hcl.',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOVALOL 20 (MOVA PH.)'
);

-- line #27721
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOVALOL 40 (MOVA PH.)',
	'Propranolol Hcl.',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOVALOL 40 (MOVA PH.)'
);

-- line #27722
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORTEN 10 (BARODA)',
	'Propranolol Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORTEN 10 (BARODA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORTEN 20 (BARODA)',
	'Propranolol Hcl.',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORTEN 20 (BARODA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORTEN 40 (BARODA)',
	'Propranolol Hcl.',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORTEN 40 (BARODA)'
);

-- line #27723
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORTEN TR 40 (BARODA)',
	'Propranolol Hcl.',
	'CAP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORTEN TR 40 (BARODA)'
);

-- line #27724
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEELAR 10 (PSYCOREM)',
	'Propranolol Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEELAR 10 (PSYCOREM)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEELAR 20 (PSYCOREM)',
	'Propranolol Hcl.',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEELAR 20 (PSYCOREM)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEELAR 40 (PSYCOREM)',
	'Propranolol Hcl.',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEELAR 40 (PSYCOREM)'
);

-- line #27725
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEERAL 10 (PSYCOREM)',
	'Propranolol Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEERAL 10 (PSYCOREM)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEERAL 20 (PSYCOREM)',
	'Propranolol Hcl.',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEERAL 20 (PSYCOREM)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEERAL 40 (PSYCOREM)',
	'Propranolol Hcl.',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEERAL 40 (PSYCOREM)'
);

-- line #27726
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PINOL 40 (Trio Rem.)',
	'Propranolol Hcl.',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PINOL 40 (Trio Rem.)'
);

-- line #27727
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PONOL 10 (SHINE PH.)',
	'Propranolol Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PONOL 10 (SHINE PH.)'
);

-- line #27728
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PONOL 20 (SHINE PH.)',
	'Propranolol Hcl.',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PONOL 20 (SHINE PH.)'
);

-- line #27729
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PONOL 40 (SHINE PH.)',
	'Propranolol Hcl.',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PONOL 40 (SHINE PH.)'
);

-- line #27730
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRAL 10 (Chemo Bio.)',
	'Propranolol Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRAL 10 (Chemo Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRAL 40 (Chemo Bio.)',
	'Propranolol Hcl.',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRAL 40 (Chemo Bio.)'
);

-- line #27731
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRANOSOL 1 (SG PH.)',
	'Propranolol Hcl.',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRANOSOL 1 (SG PH.)'
);

-- line #27732
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROLOL 10 (Crescent Th.)',
	'Propranolol Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROLOL 10 (Crescent Th.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROLOL 20 (Crescent Th.)',
	'Propranolol Hcl.',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROLOL 20 (Crescent Th.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROLOL 40 (Crescent Th.)',
	'Propranolol Hcl.',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROLOL 40 (Crescent Th.)'
);

-- line #27733
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROLOL-TR 40 (Crescent Th.)',
	'Propranolol Hcl.',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROLOL-TR 40 (Crescent Th.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROLOL-TR 80 (Crescent Th.)',
	'Propranolol Hcl.',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROLOL-TR 80 (Crescent Th.)'
);

-- line #27734
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROMOTIL TR 40 (Torrent)',
	'Propranolol Hcl.',
	'CAP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROMOTIL TR 40 (Torrent)'
);

-- line #27735
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROMOTIL TR 60 (Torrent)',
	'Propranolol Hcl.',
	'CAP',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROMOTIL TR 60 (Torrent)'
);

-- line #27736
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROMOTIL TR 80 (Torrent)',
	'Propranolol Hcl.',
	'CAP',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROMOTIL TR 80 (Torrent)'
);

-- line #27737
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRONOL 10 (Svizera)',
	'Propranolol Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRONOL 10 (Svizera)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRONOL 40 (Svizera)',
	'Propranolol Hcl.',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRONOL 40 (Svizera)'
);

-- line #27738
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROPAL 10 (Svizera)',
	'Propranolol Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROPAL 10 (Svizera)'
);

-- line #27739
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROPAL 40 (Svizera)',
	'Propranolol Hcl.',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROPAL 40 (Svizera)'
);

-- line #27740
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROPEROL 1 (Samarth)',
	'Propranolol Hcl.',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROPEROL 1 (Samarth)'
);

-- line #27741
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROPRANOLOL 1 (Samarth)',
	'Propranolol Hcl.',
	'AMP',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROPRANOLOL 1 (Samarth)'
);

-- line #27742
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROPRANOLOL 10 (Nicholas)',
	'Propranolol Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROPRANOLOL 10 (Nicholas)'
);

-- line #27743
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROPRANOLOL 40 (Nicholas)',
	'Propranolol Hcl.',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROPRANOLOL 40 (Nicholas)'
);

-- line #27744
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROP 40 (MEDIEZ)',
	'Propranolol Hcl.',
	'SR TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROP 40 (MEDIEZ)'
);

-- line #27745
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROVANOL 40 (Intas)',
	'Propranolol Hcl.',
	'SR TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg(SR)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROVANOL 40 (Intas)'
);

-- line #27746
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROVANOL 60 (Intas)',
	'Propranolol Hcl.',
	'SR TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg(SR)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROVANOL 60 (Intas)'
);

-- line #27747
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROVANOL 80 (Intas)',
	'Propranolol Hcl.',
	'SR TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg(SR)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROVANOL 80 (Intas)'
);

-- line #27748
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROVANOL 10 (Intas)',
	'Propranolol Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROVANOL 10 (Intas)'
);

-- line #27749
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROVANOL 20 (Intas)',
	'Propranolol Hcl.',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROVANOL 20 (Intas)'
);

-- line #27750
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROVANOL 40 (Intas)',
	'Propranolol Hcl.',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROVANOL 40 (Intas)'
);

-- line #27751
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETABLOC-F 40 (U S V)',
	'Propronolol Hcl.',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETABLOC-F 40 (U S V)'
);

-- line #27752
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PTU 50 (Macleods)',
	'Propylthiouracil',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PTU 50 (Macleods)'
);

-- line #27753
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'1ML', u'substance': u'Prostaglandin', u'always_empty': u'', u'form': u'INJ', u'brand': u'ALPOSTIN', u'strength_3': u'', u'company': u'Samarth', u'unit': u''}

-- line #27754
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Prostaglandin', u'always_empty': u'', u'form': u'INJ', u'brand': u'BIOGLANDIN', u'strength_3': u'', u'company': u'United Bio.', u'unit': u''}

-- line #27755
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u' %W/V', u'0,15', u' %W/V - M-CRESOL', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,159', u'strength_2': u'', u'substance': u'Protamine Sulph.', u'always_empty': u'', u'form': u'', u'brand': u'INSUMAN COMB "3 CARTRIDGES', u'strength_3': u'', u'company': u'SANOFI AV.', u'unit': u'mg'}

-- line #27756
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u' %W/V', u'0,15', u' %W/V M-CRESOL', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,238', u'strength_2': u'', u'substance': u'Protamine Sulph.', u'always_empty': u'', u'form': u'', u'brand': u'INSUMAN COMB "3 CARTRIDGES', u'strength_3': u'', u'company': u'SANOFI AV.', u'unit': u'mg'}

-- line #27757
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEUTRAHEP 10 (Gland Ph.)',
	'Protamine Sulph.',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEUTRAHEP 10 (Gland Ph.)'
);

-- line #27758
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEWTAIN 50 (CH.Bhagat)',
	'Protamine Sulph.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEWTAIN 50 (CH.Bhagat)'
);

-- line #27759
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROTA 50 (Samarth)',
	'Protamine Sulph.',
	'AMP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROTA 50 (Samarth)'
);

-- line #27760
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Protamine Sulph.', u'always_empty': u'', u'form': u'INJ', u'brand': u'PROTACARD', u'strength_3': u'', u'company': u'Csc Ph.', u'unit': u''}

-- line #27761
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROTAMINE SULPHATE 1 (Biological E.)',
	'Protamine Sulph.',
	'AMP',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROTAMINE SULPHATE 1 (Biological E.)'
);

-- line #27762
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROTAMINE SULPHATE 10 (Gland Ph.)',
	'Protamine Sulph.',
	'AMP',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROTAMINE SULPHATE 10 (Gland Ph.)'
);

-- line #27763
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'PROTEIN SUPPLEMENT FORTIFIED WITH BIOTIN & FIBRE', u'always_empty': u'', u'form': u'TAB', u'brand': u'PRONIDA', u'strength_3': u'', u'company': u'Corolla(Triton)', u'unit': u''}

-- line #27764
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'PROTEIN SUPPLIMENT', u'always_empty': u'', u'form': u'', u'brand': u'GRD SMART', u'strength_3': u'', u'company': u'ZYDUS NUT.', u'unit': u''}

-- line #27765
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MD PRIDE 250 (Maneesh)',
	'Prothionamide',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MD PRIDE 250 (Maneesh)'
);

-- line #27766
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROMATE 250 (CH.Bhagat)',
	'Prothionamide',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROMATE 250 (CH.Bhagat)'
);

-- line #27767
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROTHICID 250 (Themis)',
	'Prothionamide',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROTHICID 250 (Themis)'
);

-- line #27768
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROTHIOBIN 250 (Medispan)',
	'Prothionamide',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROTHIOBIN 250 (Medispan)'
);

-- line #27769
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROTHIOCID 250 (Themis Ph.)',
	'Prothionamide',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROTHIOCID 250 (Themis Ph.)'
);

-- line #27770
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROTOMID 250 (Macleods)',
	'Prothionamide',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROTOMID 250 (Macleods)'
);

-- line #27771
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCOTUF-P 250 (Le Sante)',
	'Protionamide',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCOTUF-P 250 (Le Sante)'
);

-- line #27772
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PETHIDE 250 (Lupin)',
	'Protionamide',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PETHIDE 250 (Lupin)'
);

-- line #27773
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROTOKOX 250 (Radicura)',
	'Protionamide',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROTOKOX 250 (Radicura)'
);

-- line #27774
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPRULI 600 (Alkem)',
	'PRULIFLOXACIN',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPRULI 600 (Alkem)'
);

-- line #27775
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'600', u'strength_2': u'', u'substance': u'PRULIFLOXACIN', u'always_empty': u'', u'form': u'', u'brand': u'INNODROX', u'strength_3': u'', u'company': u'INNOVA LIFESCI.', u'unit': u'mg'}

-- line #27776
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERCIN 600 (Lupin)',
	'PRULIFLOXACIN',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERCIN 600 (Lupin)'
);

-- line #27777
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROQUIN 600 (Alembic)',
	'PRULIFLOXACIN',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROQUIN 600 (Alembic)'
);

-- line #27778
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRUDILA 600 (MAXIMA)',
	'PRULIFLOXACIN',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRUDILA 600 (MAXIMA)'
);

-- line #27779
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRUFLOX 600 (Cipla)',
	'PRULIFLOXACIN',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRUFLOX 600 (Cipla)'
);

-- line #27780
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRULIF 600 (HETERO HC.)',
	'PRULIFLOXACIN',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRULIF 600 (HETERO HC.)'
);

-- line #27781
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRULIN 600 (Meyer Org.)',
	'PRULIFLOXACIN',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRULIN 600 (Meyer Org.)'
);

-- line #27782
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRUTIS 600 (HETERO HC.)',
	'PRULIFLOXACIN',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRUTIS 600 (HETERO HC.)'
);

-- line #27783
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRUTOP 600 (Glenmark)',
	'PRULIFLOXACIN',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRUTOP 600 (Glenmark)'
);

-- line #27784
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PUNOX 600 (Dr. Reddy''S)',
	'PRULIFLOXACIN',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PUNOX 600 (Dr. Reddy''S)'
);

-- line #27785
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PURIBACT 600 (INVISION)',
	'PRULIFLOXACIN',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PURIBACT 600 (INVISION)'
);

-- line #27786
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'PSEUDOEPHEDRINE', u'always_empty': u'', u'form': u'TAB', u'brand': u'ACTIFED', u'strength_3': u'', u'company': u'Gsk', u'unit': u''}

-- line #27787
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLCY 120 (Alembic)',
	'Pseudoephedrine',
	'ER TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLCY 120 (Alembic)'
);

-- line #27788
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANADERM 10 (Wyeth)',
	'Psoralen',
	'OINT',
	gm.nullify_empty_string('10')::numeric,
	'mg/G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANADERM 10 (Wyeth)'
);

-- line #27789
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANADERM 10 (Wyeth)',
	'Psoralen',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANADERM 10 (Wyeth)'
);

-- line #27790
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOSAL 5 (Dial Ph.)',
	'Psoralen',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOSAL 5 (Dial Ph.)'
);

-- line #27791
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISOVAC 65 (Hal)',
	'Psyllium Hydrophylic Mucilloid',
	'POW',
	gm.nullify_empty_string('65')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISOVAC 65 (Hal)'
);

-- line #27792
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100', u'strength_2': u'', u'substance': u'PYGEUM', u'always_empty': u'', u'form': u'', u'brand': u'PROSTA QUIL', u'strength_3': u'', u'company': u'ALCHEM', u'unit': u'mg'}

-- line #27793
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANTIMINTH 250 (Unique)',
	'Pyrantel Pamoate',
	'SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANTIMINTH 250 (Unique)'
);

-- line #27794
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANTIMINTH 250 (Unique)',
	'Pyrantel Pamoate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANTIMINTH 250 (Unique)'
);

-- line #27795
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXPENT 250 (Merind)',
	'Pyrantel Pamoate',
	'SUS',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXPENT 250 (Merind)'
);

-- line #27796
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXPENT 250 (Merind)',
	'Pyrantel Pamoate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXPENT 250 (Merind)'
);

-- line #27797
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOCID 25 (Emil Ph.)',
	'Pyrantel Pamoate',
	'SUS',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOCID 25 (Emil Ph.)'
);

-- line #27798
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEMOCID 250 (Ipca)',
	'Pyrantel Pamoate',
	'SUS',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEMOCID 250 (Ipca)'
);

-- line #27799
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEMOCID 250 (Ipca)',
	'Pyrantel Pamoate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEMOCID 250 (Ipca)'
);

-- line #27800
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAPA 25 (Euphoric)',
	'Pyrantel Pamoate',
	'SUS',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAPA 25 (Euphoric)'
);

-- line #27801
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAPA 250 (Euphoric)',
	'Pyrantel Pamoate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAPA 250 (Euphoric)'
);

-- line #27802
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYMOLAR 250 (Lark Labs)',
	'Pyrantel Pamoate',
	'SUS',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYMOLAR 250 (Lark Labs)'
);

-- line #27803
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYMOLAR 250 (Lark Labs)',
	'Pyrantel Pamoate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYMOLAR 250 (Lark Labs)'
);

-- line #27804
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYRANTHEL 250 (Dolphin)',
	'Pyrantel Pamoate',
	'SUS',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYRANTHEL 250 (Dolphin)'
);

-- line #27805
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYRANTHEL 250 (Dolphin)',
	'Pyrantel Pamoate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYRANTHEL 250 (Dolphin)'
);

-- line #27806
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYRMOATE 250 (Franco I.)',
	'Pyrantel Pamoate',
	'SUS',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYRMOATE 250 (Franco I.)'
);

-- line #27807
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYRMOATE 250 (Franco I.)',
	'Pyrantel Pamoate',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYRMOATE 250 (Franco I.)'
);

-- line #27808
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.5G', u'strength_2': u'', u'substance': u'Pyrazinamide', u'always_empty': u'', u'form': u'TAB', u'brand': u'ACTIZID', u'strength_3': u'', u'company': u'Overseas Hc.', u'unit': u''}

-- line #27809
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Pyrazinamide', u'always_empty': u'', u'form': u'TAB', u'brand': u'ACTIZID', u'strength_3': u'', u'company': u'Overseas Hc.', u'unit': u''}

-- line #27810
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTIZID 750 (Overseas Hc.)',
	'Pyrazinamide',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTIZID 750 (Overseas Hc.)'
);

-- line #27811
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Pyrazinamide', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALZIDE', u'strength_3': u'', u'company': u'N.A.', u'unit': u''}

-- line #27812
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZIDE 500 (N.A.)',
	'Pyrazinamide',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZIDE 500 (N.A.)'
);

-- line #27813
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALZIDE 750 (N.A.)',
	'Pyrazinamide',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALZIDE 750 (N.A.)'
);

-- line #27814
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANTIZIDE 500 (Medispan)',
	'Pyrazinamide',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANTIZIDE 500 (Medispan)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANTIZIDE 750 (Medispan)',
	'Pyrazinamide',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANTIZIDE 750 (Medispan)'
);

-- line #27815
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AQMIDE 750 (Aquila)',
	'Pyrazinamide',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AQMIDE 750 (Aquila)'
);

-- line #27816
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAVIZIDE 500 (Merind)',
	'Pyrazinamide',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAVIZIDE 500 (Merind)'
);

-- line #27817
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COMIDE-750 750 (Chemo D.)',
	'Pyrazinamide',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COMIDE-750 750 (Chemo D.)'
);

-- line #27818
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.5G', u'strength_2': u'', u'substance': u'Pyrazinamide', u'always_empty': u'', u'form': u'TAB', u'brand': u'COPYRAZIN', u'strength_3': u'', u'company': u'P C INDIA', u'unit': u''}

-- line #27819
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Pyrazinamide', u'always_empty': u'', u'form': u'TAB', u'brand': u'COPYRAZIN', u'strength_3': u'', u'company': u'P C INDIA', u'unit': u''}

-- line #27820
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COPYRAZIN 500 (P C INDIA)',
	'Pyrazinamide',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COPYRAZIN 500 (P C INDIA)'
);

-- line #27821
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COPYRAZIN 750 (P C INDIA)',
	'Pyrazinamide',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COPYRAZIN 750 (P C INDIA)'
);

-- line #27822
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMZIDE 750 (Emil Ph.)',
	'Pyrazinamide',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMZIDE 750 (Emil Ph.)'
);

-- line #27823
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISOMIDE-750 750 (Zee Lab)',
	'Pyrazinamide',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISOMIDE-750 750 (Zee Lab)'
);

-- line #27824
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KOXYMIDE 500 (Lark Lab)',
	'Pyrazinamide',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KOXYMIDE 500 (Lark Lab)'
);

-- line #27825
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KOXYMIDE 750 (Lark Lab)',
	'Pyrazinamide',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KOXYMIDE 750 (Lark Lab)'
);

-- line #27826
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYNAMIDE 500 (HETERO HC.)',
	'Pyrazinamide',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYNAMIDE 500 (HETERO HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYNAMIDE 750 (HETERO HC.)',
	'Pyrazinamide',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYNAMIDE 750 (HETERO HC.)'
);

-- line #27827
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACROZIDE-1200 1200 (Macleods)',
	'Pyrazinamide',
	'TAB',
	gm.nullify_empty_string('1200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACROZIDE-1200 1200 (Macleods)'
);

-- line #27828
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.5G', u'strength_2': u'', u'substance': u'Pyrazinamide', u'always_empty': u'', u'form': u'TAB', u'brand': u'MACROZIDE', u'strength_3': u'', u'company': u'Macleods', u'unit': u''}

-- line #27829
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Pyrazinamide', u'always_empty': u'', u'form': u'TAB', u'brand': u'MACROZIDE', u'strength_3': u'', u'company': u'Macleods', u'unit': u''}

-- line #27830
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACROZIDE 500 (Macleods)',
	'Pyrazinamide',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACROZIDE 500 (Macleods)'
);

-- line #27831
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACROZIDE 750 (Macleods)',
	'Pyrazinamide',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACROZIDE 750 (Macleods)'
);

-- line #27832
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MECOY 750 (Orison Ph.)',
	'Pyrazinamide',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MECOY 750 (Orison Ph.)'
);

-- line #27833
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONTOZIN 500 (Shreya)',
	'Pyrazinamide',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONTOZIN 500 (Shreya)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONTOZIN 750 (Shreya)',
	'Pyrazinamide',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONTOZIN 750 (Shreya)'
);

-- line #27834
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MZIDE 500 (Marc Lab)',
	'Pyrazinamide',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MZIDE 500 (Marc Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MZIDE 750 (Marc Lab)',
	'Pyrazinamide',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MZIDE 750 (Marc Lab)'
);

-- line #27835
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLZINA-750 750 (Olcare)',
	'Pyrazinamide',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLZINA-750 750 (Olcare)'
);

-- line #27836
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARAZID-500 500 (PSYCOREM)',
	'Pyrazinamide',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARAZID-500 500 (PSYCOREM)'
);

-- line #27837
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARAZID-750 750 (PSYCOREM)',
	'Pyrazinamide',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARAZID-750 750 (PSYCOREM)'
);

-- line #27838
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEEZA 750 (Emcure)',
	'Pyrazinamide',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEEZA 750 (Emcure)'
);

-- line #27839
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Pyrazinamide', u'always_empty': u'', u'form': u'TAB', u'brand': u'PIRALDINA', u'strength_3': u'', u'company': u'Pharmed', u'unit': u''}

-- line #27840
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIRALDINA 250 (Pharmed)',
	'Pyrazinamide',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIRALDINA 250 (Pharmed)'
);

-- line #27841
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIRALDINA 500 (Pharmed)',
	'Pyrazinamide',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIRALDINA 500 (Pharmed)'
);

-- line #27842
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIRALDINA 750 (Pharmed)',
	'Pyrazinamide',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIRALDINA 750 (Pharmed)'
);

-- line #27843
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIZAMAX 500 (Ind-Swift)',
	'Pyrazinamide',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIZAMAX 500 (Ind-Swift)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIZAMAX 750 (Ind-Swift)',
	'Pyrazinamide',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIZAMAX 750 (Ind-Swift)'
);

-- line #27844
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'P-MIDE 500 (Aristo)',
	'Pyrazinamide',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'P-MIDE 500 (Aristo)'
);

-- line #27845
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'P-MIDE 750 (Aristo)',
	'Pyrazinamide',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'P-MIDE 750 (Aristo)'
);

-- line #27846
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYRA 500 (Kopran)',
	'Pyrazinamide',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYRA 500 (Kopran)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYRA 750 (Kopran)',
	'Pyrazinamide',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYRA 750 (Kopran)'
);

-- line #27847
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYRA 1200 (Maneesh)',
	'Pyrazinamide',
	'TAB',
	gm.nullify_empty_string('1200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYRA 1200 (Maneesh)'
);

-- line #27848
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYRAZED 750 (Zota Hc.)',
	'Pyrazinamide',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYRAZED 750 (Zota Hc.)'
);

-- line #27849
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYRAZID 750 (Auroma Life)',
	'Pyrazinamide',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYRAZID 750 (Auroma Life)'
);

-- line #27850
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYZID 750 (Cipla)',
	'Pyrazinamide',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYZID 750 (Cipla)'
);

-- line #27851
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYZINA 300 (Lupin)',
	'Pyrazinamide',
	'DT',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYZINA 300 (Lupin)'
);

-- line #27852
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Pyrazinamide', u'always_empty': u'', u'form': u'TAB', u'brand': u'PYZINA', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #27853
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYZINA 500 (Lupin)',
	'Pyrazinamide',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYZINA 500 (Lupin)'
);

-- line #27854
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYZINA 750 (Lupin)',
	'Pyrazinamide',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYZINA 750 (Lupin)'
);

-- line #27855
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYZ 500 (Life Line)',
	'Pyrazinamide',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYZ 500 (Life Line)'
);

-- line #27856
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYZ 750 (Life Line)',
	'Pyrazinamide',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYZ 750 (Life Line)'
);

-- line #27857
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PZA-CIBA 250 (Novartis)',
	'Pyrazinamide',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PZA-CIBA 250 (Novartis)'
);

-- line #27858
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PZA-CIBA 250 (Novartis)',
	'Pyrazinamide',
	'SYR',
	gm.nullify_empty_string('250')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PZA-CIBA 250 (Novartis)'
);

-- line #27859
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Pyrazinamide', u'always_empty': u'', u'form': u'TAB', u'brand': u'PZA-CIBA', u'strength_3': u'', u'company': u'Novartis', u'unit': u''}

-- line #27860
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PZA-CIBA 500 (Novartis)',
	'Pyrazinamide',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PZA-CIBA 500 (Novartis)'
);

-- line #27861
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PZA-CIBA 750 (Novartis)',
	'Pyrazinamide',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PZA-CIBA 750 (Novartis)'
);

-- line #27862
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Pyrazinamide', u'always_empty': u'', u'form': u'TAB', u'brand': u'P-ZIDE', u'strength_3': u'', u'company': u'Le Sante', u'unit': u''}

-- line #27863
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'P-ZIDE 500 (Le Sante)',
	'Pyrazinamide',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'P-ZIDE 500 (Le Sante)'
);

-- line #27864
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'P-ZIDE 750 (Le Sante)',
	'Pyrazinamide',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'P-ZIDE 750 (Le Sante)'
);

-- line #27865
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PZN 500 (Lancer)',
	'Pyrazinamide',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PZN 500 (Lancer)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PZN 750 (Lancer)',
	'Pyrazinamide',
	'TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PZN 750 (Lancer)'
);

-- line #27866
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BILAMIDE 500 (Ethnor)',
	'Pyridine-3-Carboxy.Acid-N-Hydrox.Meth.Nicotinamide',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BILAMIDE 500 (Ethnor)'
);

-- line #27867
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MERIPAM 25 (Unimarck)',
	'Pyridine Aldoxime Methiodide',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML(2-)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MERIPAM 25 (Unimarck)'
);

-- line #27868
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOPAM 25 (Troikaa)',
	'Pyridine Aldoxime Methiodide',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML(2-)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOPAM 25 (Troikaa)'
);

-- line #27869
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DISTINON 60 (Samarth)',
	'Pyridostigmine',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DISTINON 60 (Samarth)'
);

-- line #27870
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRAVITOR 180 (Sun)',
	'Pyridostigmine',
	'SR TAB',
	gm.nullify_empty_string('180')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRAVITOR 180 (Sun)'
);

-- line #27871
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRAVITOR 60 (Sun)',
	'Pyridostigmine',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRAVITOR 60 (Sun)'
);

-- line #27872
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Pyridostigmine', u'always_empty': u'', u'form': u'TAB', u'brand': u'MESILON', u'strength_3': u'', u'company': u"KOLSON''S", u'unit': u''}

-- line #27873
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MESTINON (S) 60 (CH.Bhagat)',
	'Pyridostigmine',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MESTINON (S) 60 (CH.Bhagat)'
);

-- line #27874
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MESTINON (W/S) 60 (CH.Bhagat)',
	'Pyridostigmine',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MESTINON (W/S) 60 (CH.Bhagat)'
);

-- line #27875
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUSTONE 60 (CH.Bhagat)',
	'Pyridostigmine',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUSTONE 60 (CH.Bhagat)'
);

-- line #27876
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYESTIN 5 (Vhb)',
	'Pyridostigmine',
	'AMP',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYESTIN 5 (Vhb)'
);

-- line #27877
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYESTIN 30 (Vhb)',
	'Pyridostigmine',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYESTIN 30 (Vhb)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYESTIN 60 (Vhb)',
	'Pyridostigmine',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYESTIN 60 (Vhb)'
);

-- line #27878
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYGRIS 60 (Bharat S.)',
	'Pyridostigmine',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYGRIS 60 (Bharat S.)'
);

-- line #27879
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYRIDO 60 (SG PH.)',
	'Pyridostigmine',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYRIDO 60 (SG PH.)'
);

-- line #27880
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIO-B6 50 (Ordain Hc.)',
	'PYRIDOXAL-5 PHOSPHATE',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIO-B6 50 (Ordain Hc.)'
);

-- line #27881
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ABIX 100 (Triton Hc.)',
	'Pyridoxine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ABIX 100 (Triton Hc.)'
);

-- line #27882
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENADON 40 (Nicholas)',
	'Pyridoxine',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENADON 40 (Nicholas)'
);

-- line #27883
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'B-LONG 100 (Elder)',
	'Pyridoxine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'B-LONG 100 (Elder)'
);

-- line #27884
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INGAVIT B6 10 (Inga)',
	'Pyridoxine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INGAVIT B6 10 (Inga)'
);

-- line #27885
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INGAVIT B6 50 (Inga)',
	'Pyridoxine',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INGAVIT B6 50 (Inga)'
);

-- line #27886
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYRICONTIN 100 (Modi Mundi)',
	'Pyridoxine',
	'CR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYRICONTIN 100 (Modi Mundi)'
);

-- line #27887
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYRIDOX 50 (Neon)',
	'Pyridoxine',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYRIDOX 50 (Neon)'
);

-- line #27888
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYRISIX-100 100 (Chemo Bio.)',
	'Pyridoxine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYRISIX-100 100 (Chemo Bio.)'
);

-- line #27889
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DARAMIN 25 (Indica)',
	'Pyrimethamine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DARAMIN 25 (Indica)'
);

-- line #27890
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENCEPHABOL 20 (Merck)',
	'Pyritinol',
	'SUS',
	gm.nullify_empty_string('20')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENCEPHABOL 20 (Merck)'
);

-- line #27891
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENCEPHABOL 100 (Merck)',
	'Pyritinol',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg(DIHCL.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENCEPHABOL 100 (Merck)'
);

-- line #27892
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENCEPHABOL 200 (Merck)',
	'Pyritinol',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg(DICHL.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENCEPHABOL 200 (Merck)'
);

-- line #27893
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADEQUET 100 (Nicholas)',
	'Quetiapine Fumarate',
	'SR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADEQUET 100 (Nicholas)'
);

-- line #27894
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADEQUET 200 (Nicholas)',
	'Quetiapine Fumarate',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADEQUET 200 (Nicholas)'
);

-- line #27895
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADEQUET 300 (Nicholas)',
	'Quetiapine Fumarate',
	'SR TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADEQUET 300 (Nicholas)'
);

-- line #27896
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADEQUET 25 (Piramal Hc.)',
	'Quetiapine Fumarate',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADEQUET 25 (Piramal Hc.)'
);

-- line #27897
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PINCALM 100 (Mano)',
	'Quetiapine Fumarate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PINCALM 100 (Mano)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PINCALM 200 (Mano)',
	'Quetiapine Fumarate',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PINCALM 200 (Mano)'
);

-- line #27898
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PINCALM 25 (Mano)',
	'Quetiapine Fumarate',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PINCALM 25 (Mano)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PINCALM 50 (Mano)',
	'Quetiapine Fumarate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PINCALM 50 (Mano)'
);

-- line #27899
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLACIDIN 200 (Lupin)',
	'Quetiapine Fumarate',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLACIDIN 200 (Lupin)'
);

-- line #27900
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLACIDIN 25 (Lupin)',
	'Quetiapine Fumarate',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLACIDIN 25 (Lupin)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PLACIDIN 100 (Lupin)',
	'Quetiapine Fumarate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PLACIDIN 100 (Lupin)'
);

-- line #27901
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PSYNIL 100 (Crescent Th.)',
	'Quetiapine Fumarate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PSYNIL 100 (Crescent Th.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PSYNIL 200 (Crescent Th.)',
	'Quetiapine Fumarate',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PSYNIL 200 (Crescent Th.)'
);

-- line #27902
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PSYNIL 25 (Crescent Th.)',
	'Quetiapine Fumarate',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PSYNIL 25 (Crescent Th.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PSYNIL 50 (Crescent Th.)',
	'Quetiapine Fumarate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PSYNIL 50 (Crescent Th.)'
);

-- line #27903
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q-MIND 100 (Torrent)',
	'Quetiapine Fumarate',
	'SR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q-MIND 100 (Torrent)'
);

-- line #27904
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q-MIND 200 (Torrent)',
	'Quetiapine Fumarate',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q-MIND 200 (Torrent)'
);

-- line #27905
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q-MIND 300 (Torrent)',
	'Quetiapine Fumarate',
	'SR TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q-MIND 300 (Torrent)'
);

-- line #27906
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q-MIND 400 (Torrent)',
	'Quetiapine Fumarate',
	'SR TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q-MIND 400 (Torrent)'
);

-- line #27907
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q-MIND 50 (Torrent)',
	'Quetiapine Fumarate',
	'SR TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q-MIND 50 (Torrent)'
);

-- line #27908
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q-MIND 100 (Torrent)',
	'Quetiapine Fumarate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q-MIND 100 (Torrent)'
);

-- line #27909
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q-MIND 200 (Torrent)',
	'Quetiapine Fumarate',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q-MIND 200 (Torrent)'
);

-- line #27910
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q-MIND 25 (Torrent)',
	'Quetiapine Fumarate',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q-MIND 25 (Torrent)'
);

-- line #27911
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q-MIND 300 (Torrent)',
	'Quetiapine Fumarate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q-MIND 300 (Torrent)'
);

-- line #27912
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q PIN 100 (Pentacare)',
	'Quetiapine Fumarate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q PIN 100 (Pentacare)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q PIN 200 (Pentacare)',
	'Quetiapine Fumarate',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q PIN 200 (Pentacare)'
);

-- line #27913
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'25', u'strength_2': u'50 TAB', u'substance': u'Quetiapine Fumarate', u'always_empty': u'', u'form': u'TAB', u'brand': u'Q PIN', u'strength_3': u'', u'company': u'Pentacare', u'unit': u''}

-- line #27914
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q PIN 300 (Pentacare)',
	'Quetiapine Fumarate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q PIN 300 (Pentacare)'
);

-- line #27915
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QTA 25 (SHINE PH.)',
	'Quetiapine Fumarate',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QTA 25 (SHINE PH.)'
);

-- line #27916
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QTA 50 (SHINE PH.)',
	'Quetiapine Fumarate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QTA 50 (SHINE PH.)'
);

-- line #27917
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUEL 100 (Ipca)',
	'Quetiapine Fumarate',
	'SR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUEL 100 (Ipca)'
);

-- line #27918
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUEL 400 (Ipca)',
	'Quetiapine Fumarate',
	'SR TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUEL 400 (Ipca)'
);

-- line #27919
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUEL 50 (Ipca)',
	'Quetiapine Fumarate',
	'SR TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUEL 50 (Ipca)'
);

-- line #27920
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUEL 200 (IPCA LAB.)',
	'Quetiapine Fumarate',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUEL 200 (IPCA LAB.)'
);

-- line #27921
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUEL 300 (IPCA LAB.)',
	'Quetiapine Fumarate',
	'SR TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUEL 300 (IPCA LAB.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUEL 500 (IPCA LAB.)',
	'Quetiapine Fumarate',
	'SR TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUEL 500 (IPCA LAB.)'
);

-- line #27922
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUEL 100 (Ipca)',
	'Quetiapine Fumarate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUEL 100 (Ipca)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUEL 200 (Ipca)',
	'Quetiapine Fumarate',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUEL 200 (Ipca)'
);

-- line #27923
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUEL 25 (Ipca)',
	'Quetiapine Fumarate',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUEL 25 (Ipca)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUEL 50 (Ipca)',
	'Quetiapine Fumarate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUEL 50 (Ipca)'
);

-- line #27924
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUETIA 100 (Unichem)',
	'Quetiapine Fumarate',
	'SR',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUETIA 100 (Unichem)'
);

-- line #27925
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUETIA 200 (Unichem)',
	'Quetiapine Fumarate',
	'SR',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUETIA 200 (Unichem)'
);

-- line #27926
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUETIA 25 (Unichem)',
	'Quetiapine Fumarate',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUETIA 25 (Unichem)'
);

-- line #27927
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUETIA 50 (Unichem)',
	'Quetiapine Fumarate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUETIA 50 (Unichem)'
);

-- line #27928
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'25', u'strength_2': u'', u'substance': u'Quetiapine Fumarate', u'always_empty': u'', u'form': u'', u'brand': u'QUIPS', u'strength_3': u'', u'company': u'Triton', u'unit': u'mg'}

-- line #27929
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUTACE 100 (LA DRUG)',
	'Quetiapine Fumarate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUTACE 100 (LA DRUG)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUTACE 200 (LA DRUG)',
	'Quetiapine Fumarate',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUTACE 200 (LA DRUG)'
);

-- line #27930
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUTACE 25 (LA DRUG)',
	'Quetiapine Fumarate',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUTACE 25 (LA DRUG)'
);

-- line #27931
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUTACE 50 (LA DRUG)',
	'Quetiapine Fumarate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUTACE 50 (LA DRUG)'
);

-- line #27932
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUTAN SR50 50 (INTAS)',
	'Quetiapine Fumarate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUTAN SR50 50 (INTAS)'
);

-- line #27933
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUTAN 100 (Intas)',
	'Quetiapine Fumarate',
	'SR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUTAN 100 (Intas)'
);

-- line #27934
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUTAN 200 (Intas)',
	'Quetiapine Fumarate',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUTAN 200 (Intas)'
);

-- line #27935
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUTAN 300 (Intas)',
	'Quetiapine Fumarate',
	'SR TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUTAN 300 (Intas)'
);

-- line #27936
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUTAN 400 (Intas)',
	'Quetiapine Fumarate',
	'SR TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUTAN 400 (Intas)'
);

-- line #27937
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUTAN 100 (Intas)',
	'Quetiapine Fumarate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUTAN 100 (Intas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUTAN 200 (Intas)',
	'Quetiapine Fumarate',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUTAN 200 (Intas)'
);

-- line #27938
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUTAN 25 (Intas)',
	'Quetiapine Fumarate',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUTAN 25 (Intas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUTAN 50 (Intas)',
	'Quetiapine Fumarate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUTAN 50 (Intas)'
);

-- line #27939
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUTAN 300 (Intas)',
	'Quetiapine Fumarate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUTAN 300 (Intas)'
);

-- line #27940
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUTICOOL 100 (PSYCOREM)',
	'Quetiapine Fumarate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUTICOOL 100 (PSYCOREM)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUTICOOL 200 (PSYCOREM)',
	'Quetiapine Fumarate',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUTICOOL 200 (PSYCOREM)'
);

-- line #27941
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUTICOOL 25 (PSYCOREM)',
	'Quetiapine Fumarate',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUTICOOL 25 (PSYCOREM)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUTICOOL 50 (PSYCOREM)',
	'Quetiapine Fumarate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUTICOOL 50 (PSYCOREM)'
);

-- line #27942
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUTICOOL 300 (PSYCOREM)',
	'Quetiapine Fumarate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUTICOOL 300 (PSYCOREM)'
);

-- line #27943
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUTIPINE 400 (Sun)',
	'Quetiapine Fumarate',
	'SR TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg SR'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUTIPINE 400 (Sun)'
);

-- line #27944
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUTIPINE 50 (Sun)',
	'Quetiapine Fumarate',
	'SR TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg SR'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUTIPINE 50 (Sun)'
);

-- line #27945
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUTIPIN 100 (Sun)',
	'Quetiapine Fumarate',
	'SR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUTIPIN 100 (Sun)'
);

-- line #27946
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUTIPIN 200 (Sun)',
	'Quetiapine Fumarate',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUTIPIN 200 (Sun)'
);

-- line #27947
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUTIPIN 300 (Sun)',
	'Quetiapine Fumarate',
	'SR TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUTIPIN 300 (Sun)'
);

-- line #27948
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUTIPIN 100 (Sun)',
	'Quetiapine Fumarate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUTIPIN 100 (Sun)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUTIPIN 200 (Sun)',
	'Quetiapine Fumarate',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUTIPIN 200 (Sun)'
);

-- line #27949
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUTIPIN 25 (Sun)',
	'Quetiapine Fumarate',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUTIPIN 25 (Sun)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUTIPIN 50 (Sun)',
	'Quetiapine Fumarate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUTIPIN 50 (Sun)'
);

-- line #27950
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUTIPIN 300 (Sun)',
	'Quetiapine Fumarate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUTIPIN 300 (Sun)'
);

-- line #27951
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q-WIN 100 (Synapse)',
	'Quetiapine Fumarate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q-WIN 100 (Synapse)'
);

-- line #27952
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q-WIN 200 (Synapse)',
	'Quetiapine Fumarate',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q-WIN 200 (Synapse)'
);

-- line #27953
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q-WIN 25 (Synapse)',
	'Quetiapine Fumarate',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q-WIN 25 (Synapse)'
);

-- line #27954
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACUPIL 10 (Pfizer)',
	'QUINAPRIL HCL.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACUPIL 10 (Pfizer)'
);

-- line #27955
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACUPIL 20 (Pfizer)',
	'QUINAPRIL HCL.',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACUPIL 20 (Pfizer)'
);

-- line #27956
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACUPIL 5 (Pfizer)',
	'QUINAPRIL HCL.',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACUPIL 5 (Pfizer)'
);

-- line #27957
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q-PRIL 20 (Macleods)',
	'QUINAPRIL HCL.',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q-PRIL 20 (Macleods)'
);

-- line #27958
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q-PRIL 40 (Macleods)',
	'QUINAPRIL HCL.',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q-PRIL 40 (Macleods)'
);

-- line #27959
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q-PRIL 5 (Macleods)',
	'QUINAPRIL HCL.',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q-PRIL 5 (Macleods)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q-PRIL 10 (Macleods)',
	'QUINAPRIL HCL.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q-PRIL 10 (Macleods)'
);

-- line #27960
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NATCARDINE 100 (Franco I.)',
	'Quinidine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NATCARDINE 100 (Franco I.)'
);

-- line #27961
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINIDINE 200 (Gsk)',
	'Quinidine',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINIDINE 200 (Gsk)'
);

-- line #27962
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.3G', u'strength_2': u'ML', u'substance': u'Quinidine', u'always_empty': u'', u'form': u'INJECTION', u'brand': u'QUININGA', u'strength_3': u'', u'company': u'Inga', u'unit': u''}

-- line #27963
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUININGA 100 (Inga)',
	'Quinidine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUININGA 100 (Inga)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUININGA 300 (Inga)',
	'Quinidine',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUININGA 300 (Inga)'
);

-- line #27964
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUININGA 300 (Inga)',
	'Quinidine',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUININGA 300 (Inga)'
);

-- line #27965
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENTEROQUINOL 250 (East India)',
	'Quinidochlor',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENTEROQUINOL 250 (East India)'
);

-- line #27966
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CINKONE 300 (Ipca)',
	'Quinine Dihcl.',
	'INJ',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CINKONE 300 (Ipca)'
);

-- line #27967
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KWINIL 300 (Intas)',
	'Quinine Dihcl.',
	'INJ',
	gm.nullify_empty_string('300')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KWINIL 300 (Intas)'
);

-- line #27968
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QINARSOL 300 (Cipla)',
	'Quinine Dihcl.',
	'INJ',
	gm.nullify_empty_string('300')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QINARSOL 300 (Cipla)'
);

-- line #27969
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QINET 300 (Bennet Ph.)',
	'Quinine Dihcl.',
	'INJ',
	gm.nullify_empty_string('300')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QINET 300 (Bennet Ph.)'
);

-- line #27970
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUNINE 300 (Merck)',
	'Quinine Dihcl.',
	'AMP',
	gm.nullify_empty_string('300')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUNINE 300 (Merck)'
);

-- line #27971
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUNINE 600 (Merck)',
	'Quinine Dihcl.',
	'INJ',
	gm.nullify_empty_string('600')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUNINE 600 (Merck)'
);

-- line #27972
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REZ-Q 300 (SHREYA)',
	'Quinine Dihcl.',
	'INJ',
	gm.nullify_empty_string('300')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REZ-Q 300 (SHREYA)'
);

-- line #27973
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'9Q 300 (MADHAV BIO.)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '9Q 300 (MADHAV BIO.)'
);

-- line #27974
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'A-QUIN 300 (Allure Rem.)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'A-QUIN 300 (Allure Rem.)'
);

-- line #27975
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Quinine Sulphate', u'always_empty': u'', u'form': u'INJ', u'brand': u'CINKONA', u'strength_3': u'', u'company': u'Ipca', u'unit': u''}

-- line #27976
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CINKONA 150 (Ipca)',
	'Quinine Sulphate',
	'SUS',
	gm.nullify_empty_string('150')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CINKONA 150 (Ipca)'
);

-- line #27977
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CINKONA 100 (Ipca)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CINKONA 100 (Ipca)'
);

-- line #27978
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CINKONA 300 (Ipca)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CINKONA 300 (Ipca)'
);

-- line #27979
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CINKONA 600 (Ipca)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CINKONA 600 (Ipca)'
);

-- line #27980
-- ignoring line: field [strength_1] not numeric: >>>A-600<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'A-600', u'strength_2': u'', u'substance': u'Quinine Sulphate+Doxycycline', u'always_empty': u'', u'form': u'TAB', u'brand': u'REZ-Q-D', u'strength_3': u'', u'company': u'Shreya', u'unit': u'mg (21T) + B- 100'}

-- line #27981
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUFAL 100 (Shreeyam)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUFAL 100 (Shreeyam)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUFAL 300 (Shreeyam)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUFAL 300 (Shreeyam)'
);

-- line #27982
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUFAL 600 (Shreeyam)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUFAL 600 (Shreeyam)'
);

-- line #27983
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FALCIQUIN 300 (Brown & B.)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FALCIQUIN 300 (Brown & B.)'
);

-- line #27984
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FALCY 300 (Baroque)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FALCY 300 (Baroque)'
);

-- line #27985
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOQUIN 300 (Forgo Ph.)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOQUIN 300 (Forgo Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOQUIN 600 (Forgo Ph.)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOQUIN 600 (Forgo Ph.)'
);

-- line #27986
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIQUIN 100 (Olcare)',
	'Quinine Sulphate',
	'KID TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIQUIN 100 (Olcare)'
);

-- line #27987
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIQUIN 150 (Olcare)',
	'Quinine Sulphate',
	'SUS',
	gm.nullify_empty_string('150')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIQUIN 150 (Olcare)'
);

-- line #27988
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIQUIN 300 (Olcare)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIQUIN 300 (Olcare)'
);

-- line #27989
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KUNEN 300 (Merind)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KUNEN 300 (Merind)'
);

-- line #27990
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KUNEN 600 (Merind)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KUNEN 600 (Merind)'
);

-- line #27991
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KWINIL 300 (Intas)',
	'Quinine Sulphate',
	'INJ',
	gm.nullify_empty_string('300')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KWINIL 300 (Intas)'
);

-- line #27992
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KWINIL 300 (Intas)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KWINIL 300 (Intas)'
);

-- line #27993
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINQUINE-F 800 (Lincoln)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINQUINE-F 800 (Lincoln)'
);

-- line #27994
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALACURE-Q 150 (Patson)',
	'Quinine Sulphate',
	'SYR',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALACURE-Q 150 (Patson)'
);

-- line #27995
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALACURE-Q 300 (Patson)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALACURE-Q 300 (Patson)'
);

-- line #27996
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALGO 300 (Finecure)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALGO 300 (Finecure)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALGO 600 (Finecure)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALGO 600 (Finecure)'
);

-- line #27997
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOSGARD 300 (Cipla)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOSGARD 300 (Cipla)'
);

-- line #27998
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NINE 300 (Skymax)',
	'Quinine Sulphate',
	'INJ',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NINE 300 (Skymax)'
);

-- line #27999
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NINE 300 (Skymax)',
	'Quinine Sulphate',
	'SUS',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NINE 300 (Skymax)'
);

-- line #28000
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NINE 300 (Skymax)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NINE 300 (Skymax)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NINE 600 (Skymax)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NINE 600 (Skymax)'
);

-- line #28001
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q-150/300 150 (Rhombus)',
	'Quinine Sulphate',
	'SUS',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q-150/300 150 (Rhombus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q-150/300 300 (Rhombus)',
	'Quinine Sulphate',
	'SUS',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q-150/300 300 (Rhombus)'
);

-- line #28002
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q9 30 (LUCENT PH.)',
	'Quinine Sulphate',
	'INJ',
	gm.nullify_empty_string('30')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q9 30 (LUCENT PH.)'
);

-- line #28003
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q9 300 (VENSAT)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q9 300 (VENSAT)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q9 600 (VENSAT)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q9 600 (VENSAT)'
);

-- line #28004
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QINARSOL 300 (Cipla)',
	'Quinine Sulphate',
	'INJ',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QINARSOL 300 (Cipla)'
);

-- line #28005
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QINARSOL 300 (Cipla)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QINARSOL 300 (Cipla)'
);

-- line #28006
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Quinine Sulphate', u'always_empty': u'', u'form': u'SUS', u'brand': u'QINET', u'strength_3': u'', u'company': u'Bennet Ph.', u'unit': u''}

-- line #28007
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QINET 100 (Bennet Ph.)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QINET 100 (Bennet Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QINET 300 (Bennet Ph.)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QINET 300 (Bennet Ph.)'
);

-- line #28008
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QINET 600 (Bennet Ph.)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QINET 600 (Bennet Ph.)'
);

-- line #28009
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q-MAL 600 (Themis Med.)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg(QUININE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q-MAL 600 (Themis Med.)'
);

-- line #28010
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q NEM 150 (NEMI PH.)',
	'Quinine Sulphate',
	'SUS',
	gm.nullify_empty_string('150')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q NEM 150 (NEMI PH.)'
);

-- line #28011
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q NEM 300 (NEMI PH.)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q NEM 300 (NEMI PH.)'
);

-- line #28012
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q-NINE 100 (Southsourne)',
	'Quinine Sulphate',
	'CD TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q-NINE 100 (Southsourne)'
);

-- line #28013
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q-NINE-F 600 (Southsourne)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q-NINE-F 600 (Southsourne)'
);

-- line #28014
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Quinine Sulphate', u'always_empty': u'', u'form': u'SUS', u'brand': u'Q-NINE', u'strength_3': u'', u'company': u'Southsourne', u'unit': u''}

-- line #28015
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q-NINE 300 (Southsourne)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q-NINE 300 (Southsourne)'
);

-- line #28016
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q-SET 300 (Fairdeal Res.)',
	'Quinine Sulphate',
	'INJ',
	gm.nullify_empty_string('300')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q-SET 300 (Fairdeal Res.)'
);

-- line #28017
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q-SET 150 (Fairdeal Res.)',
	'Quinine Sulphate',
	'SUS',
	gm.nullify_empty_string('150')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q-SET 150 (Fairdeal Res.)'
);

-- line #28018
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q-SET 100 (Fairdeal Res.)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q-SET 100 (Fairdeal Res.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q-SET 300 (Fairdeal Res.)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q-SET 300 (Fairdeal Res.)'
);

-- line #28019
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q-SET 600 (Fairdeal Res.)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q-SET 600 (Fairdeal Res.)'
);

-- line #28020
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QSM 100 (Leben)',
	'Quinine Sulphate',
	'EC TAB',
	gm.nullify_empty_string('100')::numeric,
	'300'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QSM 100 (Leben)'
);

-- line #28021
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QSM 300 (Leben)',
	'Quinine Sulphate',
	'INJ',
	gm.nullify_empty_string('300')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QSM 300 (Leben)'
);

-- line #28022
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QSM 150 (Leben)',
	'Quinine Sulphate',
	'SUSP',
	gm.nullify_empty_string('150')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QSM 150 (Leben)'
);

-- line #28023
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QST 300 (Mcw Hc.)',
	'Quinine Sulphate',
	'AMP',
	gm.nullify_empty_string('300')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QST 300 (Mcw Hc.)'
);

-- line #28024
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QST 150 (Mcw Hc.)',
	'Quinine Sulphate',
	'SUS',
	gm.nullify_empty_string('150')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QST 150 (Mcw Hc.)'
);

-- line #28025
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QST 100 (Mcw Hc.)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QST 100 (Mcw Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QST 300 (Mcw Hc.)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QST 300 (Mcw Hc.)'
);

-- line #28026
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QST 600 (Mcw Hc.)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QST 600 (Mcw Hc.)'
);

-- line #28027
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q-TAB 300 (TALENT LAB.)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q-TAB 300 (TALENT LAB.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q-TAB 600 (TALENT LAB.)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q-TAB 600 (TALENT LAB.)'
);

-- line #28028
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUEENOLAR 300 (Lark Lab)',
	'Quinine Sulphate',
	'INJ',
	gm.nullify_empty_string('300')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUEENOLAR 300 (Lark Lab)'
);

-- line #28029
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUEENOLAR 50 (Lark Lab)',
	'Quinine Sulphate',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUEENOLAR 50 (Lark Lab)'
);

-- line #28030
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUEENOLAR 150 (Lark Lab)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUEENOLAR 150 (Lark Lab)'
);

-- line #28031
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUEENOLAR 300 (Lark Lab)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUEENOLAR 300 (Lark Lab)'
);

-- line #28032
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUEENOLAR 600 (Lark Lab)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUEENOLAR 600 (Lark Lab)'
);

-- line #28033
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'60ML', u'strength_2': u'', u'substance': u'Quinine Sulphate', u'always_empty': u'', u'form': u'SUSP', u'brand': u'QUIN-9', u'strength_3': u'', u'company': u'SHINCE', u'unit': u''}

-- line #28034
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUIN-9 300 (SHINCE)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUIN-9 300 (SHINCE)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUIN-9 600 (SHINCE)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUIN-9 600 (SHINCE)'
);

-- line #28035
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINBER 300 (Calibar Ph.)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINBER 300 (Calibar Ph.)'
);

-- line #28036
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINEX 150 (Intra Lab)',
	'Quinine Sulphate',
	'SUS',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINEX 150 (Intra Lab)'
);

-- line #28037
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINEX 300 (Intra Lab)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINEX 300 (Intra Lab)'
);

-- line #28038
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUININE 300 (Merck)',
	'Quinine Sulphate',
	'INJ',
	gm.nullify_empty_string('300')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUININE 300 (Merck)'
);

-- line #28039
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUININE 300 (Merck)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUININE 300 (Merck)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUININE 600 (Merck)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUININE 600 (Merck)'
);

-- line #28040
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINLEX 300 (LEXICA)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINLEX 300 (LEXICA)'
);

-- line #28041
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINLUP 300 (Lupin)',
	'Quinine Sulphate',
	'INJ',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINLUP 300 (Lupin)'
);

-- line #28042
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINOGOLD 150 (LEO)',
	'Quinine Sulphate',
	'SUS',
	gm.nullify_empty_string('150')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINOGOLD 150 (LEO)'
);

-- line #28043
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINOGOLD 300 (LEO)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINOGOLD 300 (LEO)'
);

-- line #28044
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINSUL 300 (Bombay T.)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINSUL 300 (Bombay T.)'
);

-- line #28045
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINTAB 300 (Rhombic)',
	'Quinine Sulphate',
	'TABS',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINTAB 300 (Rhombic)'
);

-- line #28046
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUNINE 300 (Merck)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUNINE 300 (Merck)'
);

-- line #28047
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUNINE 600 (Merck)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUNINE 600 (Merck)'
);

-- line #28048
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUOMORI 300 (ST.MORRISON)',
	'Quinine Sulphate',
	'INJ',
	gm.nullify_empty_string('300')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUOMORI 300 (ST.MORRISON)'
);

-- line #28049
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUOMORI 150 (ST.MORRISON)',
	'Quinine Sulphate',
	'SUS',
	gm.nullify_empty_string('150')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUOMORI 150 (ST.MORRISON)'
);

-- line #28050
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUOMORI 300 (ST.MORRISON)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUOMORI 300 (ST.MORRISON)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUOMORI 600 (ST.MORRISON)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUOMORI 600 (ST.MORRISON)'
);

-- line #28051
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUROSULPH 150 (Medicine & Kure)',
	'Quinine Sulphate',
	'SUS',
	gm.nullify_empty_string('150')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUROSULPH 150 (Medicine & Kure)'
);

-- line #28052
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUROSULPH 100 (Medicine & Kure)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUROSULPH 100 (Medicine & Kure)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUROSULPH 300 (Medicine & Kure)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUROSULPH 300 (Medicine & Kure)'
);

-- line #28053
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUROSULPH 600 (Medicine & Kure)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUROSULPH 600 (Medicine & Kure)'
);

-- line #28054
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUTIL 300 (LITTLE GREAVE)',
	'Quinine Sulphate',
	'EC TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUTIL 300 (LITTLE GREAVE)'
);

-- line #28055
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUTIL 150 (LITTLE GREAVE)',
	'Quinine Sulphate',
	'SUSP',
	gm.nullify_empty_string('150')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUTIL 150 (LITTLE GREAVE)'
);

-- line #28056
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUTOMAL 100 (ALMET)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUTOMAL 100 (ALMET)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUTOMAL 300 (ALMET)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUTOMAL 300 (ALMET)'
);

-- line #28057
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUTROY 300 (Troikaa)',
	'Quinine Sulphate',
	'INJ',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUTROY 300 (Troikaa)'
);

-- line #28058
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUTROY 150 (Troikaa)',
	'Quinine Sulphate',
	'SUSP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUTROY 150 (Troikaa)'
);

-- line #28059
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUTROY 300 (Troikaa)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUTROY 300 (Troikaa)'
);

-- line #28060
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESIST 300 (SYNOPSIS)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESIST 300 (SYNOPSIS)'
);

-- line #28061
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Quinine Sulphate', u'always_empty': u'', u'form': u'SUS', u'brand': u'REZ-Q', u'strength_3': u'', u'company': u'Shreya', u'unit': u''}

-- line #28062
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REZ-Q 100 (Shreya)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REZ-Q 100 (Shreya)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REZ-Q 300 (Shreya)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REZ-Q 300 (Shreya)'
);

-- line #28063
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REZ-Q 600 (Shreya)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REZ-Q 600 (Shreya)'
);

-- line #28064
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REZQUIN 300 (TAJ PH.)',
	'Quinine Sulphate',
	'AMP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REZQUIN 300 (TAJ PH.)'
);

-- line #28065
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REZQUIN 100 (TAJ PH.)',
	'Quinine Sulphate',
	'SUSP',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REZQUIN 100 (TAJ PH.)'
);

-- line #28066
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REZQUIN 300 (TAJ PH.)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REZQUIN 300 (TAJ PH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REZQUIN 600 (TAJ PH.)',
	'Quinine Sulphate',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REZQUIN 600 (TAJ PH.)'
);

-- line #28067
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEQUINOL 250 (Dey''S)',
	'Quiniodochlor',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEQUINOL 250 (Dey''S)'
);

-- line #28068
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DERMO QUINOL % 4 (East India)',
	'Quiniodochlor',
	'CRM',
	gm.nullify_empty_string('4')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DERMO QUINOL % 4 (East India)'
);

-- line #28069
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DERMO QUINOL % 8 (East India)',
	'Quiniodochlor',
	'CRM',
	gm.nullify_empty_string('8')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DERMO QUINOL % 8 (East India)'
);

-- line #28070
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GYNOSAN VAG 200 (Nicholas)',
	'Quiniodochlor',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GYNOSAN VAG 200 (Nicholas)'
);

-- line #28071
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINOFORM 250 (Albert D.)',
	'Quiniodochlor',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINOFORM 250 (Albert D.)'
);

-- line #28072
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACERA 20 (Ipca)',
	'Rabeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACERA 20 (Ipca)'
);

-- line #28073
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACERA-FAST 20 (Ipca)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACERA-FAST 20 (Ipca)'
);

-- line #28074
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACERA 20 (Ipca)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg (RED OXIDE OF IRON)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACERA 20 (Ipca)'
);

-- line #28075
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACILESS 20 (SH PH.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACILESS 20 (SH PH.)'
);

-- line #28076
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACIREST 20 (Surge Bio.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACIREST 20 (Surge Bio.)'
);

-- line #28077
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACISTAL 20 (Unichem)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACISTAL 20 (Unichem)'
);

-- line #28078
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALGIBRA 10 (Cfl Ph.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALGIBRA 10 (Cfl Ph.)'
);

-- line #28079
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALGIBRA 20 (Cfl Ph.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALGIBRA 20 (Cfl Ph.)'
);

-- line #28080
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANTUC 20 (NEISS)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANTUC 20 (NEISS)'
);

-- line #28081
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANTUC 20 (NEISS)',
	'Rabeprazole',
	'VIAL',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANTUC 20 (NEISS)'
);

-- line #28082
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARIFAX 20 (Arbro Ph.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARIFAX 20 (Arbro Ph.)'
);

-- line #28083
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARZOLA 20 (NEISS)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARZOLA 20 (NEISS)'
);

-- line #28084
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVI-R 20 (AVIS LIFE)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVI-R 20 (AVIS LIFE)'
);

-- line #28085
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BEEPRAZ 10 (Galpha)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BEEPRAZ 10 (Galpha)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BEEPRAZ 20 (Galpha)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BEEPRAZ 20 (Galpha)'
);

-- line #28086
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'B-JOY 20 (CONCERTINA)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'B-JOY 20 (CONCERTINA)'
);

-- line #28087
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BK-RAB 20 (BIOKIND HC.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BK-RAB 20 (BIOKIND HC.)'
);

-- line #28088
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BONYRAB-20 20 (BONY MED.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BONYRAB-20 20 (BONY MED.)'
);

-- line #28089
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRIZOL 20 (First Horizon)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRIZOL 20 (First Horizon)'
);

-- line #28090
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHILKUL-20 20 (APTUS PH.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHILKUL-20 20 (APTUS PH.)'
);

-- line #28091
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COOLX 20 (SAVIOUR)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COOLX 20 (SAVIOUR)'
);

-- line #28092
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYRA 20 (Systopic)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYRA 20 (Systopic)'
);

-- line #28093
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEL- 20 (WISCON)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEL- 20 (WISCON)'
);

-- line #28094
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPUMP 20 (TABLETS I.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPUMP 20 (TABLETS I.)'
);

-- line #28095
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIOROB 20 (Divine Life)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIOROB 20 (Divine Life)'
);

-- line #28096
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'Rabeprazole', u'always_empty': u'', u'form': u'', u'brand': u'DREGO', u'strength_3': u'', u'company': u'U S V', u'unit': u'mg'}

-- line #28097
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'Rabeprazole', u'always_empty': u'', u'form': u'', u'brand': u'ECORAB-20', u'strength_3': u'', u'company': u'SPECTRUM HC.', u'unit': u'mg'}

-- line #28098
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'Rabeprazole', u'always_empty': u'', u'form': u'', u'brand': u'EMBIRAZ', u'strength_3': u'', u'company': u'UMBILICAL PH.', u'unit': u'mg'}

-- line #28099
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESO FAST 20 (Nicholas)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESO FAST 20 (Nicholas)'
);

-- line #28100
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUTORAB 20 (Zedip Form.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUTORAB 20 (Zedip Form.)'
);

-- line #28101
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAR 20 (Burgeon Ph.)',
	'Rabeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAR 20 (Burgeon Ph.)'
);

-- line #28102
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FYROB 20 (Phytochem)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FYROB 20 (Phytochem)'
);

-- line #28103
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GASTRAZOLE 20 (Meyer Org.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GASTRAZOLE 20 (Meyer Org.)'
);

-- line #28104
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'Rabeprazole', u'always_empty': u'', u'form': u'', u'brand': u'GASTROBIEN', u'strength_3': u'', u'company': u'BIENSTAR', u'unit': u'mg'}

-- line #28105
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GINORM 20 (SYNOPSIS)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GINORM 20 (SYNOPSIS)'
);

-- line #28106
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HAPPI 10 (German R.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HAPPI 10 (German R.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HAPPI 20 (German R.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HAPPI 20 (German R.)'
);

-- line #28107
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HAPPI 20 (German R.)',
	'Rabeprazole',
	'VIAL',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HAPPI 20 (German R.)'
);

-- line #28108
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HELIRAB 10 (Brown & B.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HELIRAB 10 (Brown & B.)'
);

-- line #28109
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HELIRAB 20 (Brown & B.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HELIRAB 20 (Brown & B.)'
);

-- line #28110
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HUGE-20 20 (ELEMENT PH.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HUGE-20 20 (ELEMENT PH.)'
);

-- line #28111
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYZOLE 20 (Obsurge)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYZOLE 20 (Obsurge)'
);

-- line #28112
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INRAB 20 (VERITAZ)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INRAB 20 (VERITAZ)'
);

-- line #28113
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JEPRAB 20 (Sanify)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JEPRAB 20 (Sanify)'
);

-- line #28114
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOCKER 20 (LEOLIFE)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOCKER 20 (LEOLIFE)'
);

-- line #28115
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYRAB 20 (LYKA LABS)',
	'Rabeprazole',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYRAB 20 (LYKA LABS)'
);

-- line #28116
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAC 20 (Corona)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAC 20 (Corona)'
);

-- line #28117
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEPRAZ 20 (Globus)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEPRAZ 20 (Globus)'
);

-- line #28118
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOPRIDE TOTAL 20 (Intas)',
	'Rabeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOPRIDE TOTAL 20 (Intas)'
);

-- line #28119
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUGILOC 20 (FORAM BIO.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUGILOC 20 (FORAM BIO.)'
);

-- line #28120
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'Rabeprazole', u'always_empty': u'', u'form': u'', u'brand': u'NULOC IV', u'strength_3': u'', u'company': u'Nicholas', u'unit': u'mg'}

-- line #28121
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NULOC 10 (Bergen)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NULOC 10 (Bergen)'
);

-- line #28122
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODIRAB-20 20 (Biochem)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODIRAB-20 20 (Biochem)'
);

-- line #28123
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLEZ 20 (D.R.John''S)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLEZ 20 (D.R.John''S)'
);

-- line #28124
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMNISEC 20 (Cipla)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMNISEC 20 (Cipla)'
);

-- line #28125
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONCE 20 (SHRESHTHA)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONCE 20 (SHRESHTHA)'
);

-- line #28126
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPPI-R 20 (AQUALIFE)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPPI-R 20 (AQUALIFE)'
);

-- line #28127
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORPRO 20 (Ordain Hc.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORPRO 20 (Ordain Hc.)'
);

-- line #28128
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSTEOCID 20 (Wanbury)',
	'Rabeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSTEOCID 20 (Wanbury)'
);

-- line #28129
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'WITH SOD. BICARBONATE', u'strength_2': u'', u'substance': u'Rabeprazole', u'always_empty': u'', u'form': u'', u'brand': u'OZOFAST', u'strength_3': u'', u'company': u'Ozone Ph.', u'unit': u''}

-- line #28130
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEPCIA 10 (F D C)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEPCIA 10 (F D C)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEPCIA 20 (F D C)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEPCIA 20 (F D C)'
);

-- line #28131
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEPRAZ 20 (EAST WEST)',
	'Rabeprazole',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEPRAZ 20 (EAST WEST)'
);

-- line #28132
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEPRAZ 10 (EAST WEST)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEPRAZ 10 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEPRAZ 20 (EAST WEST)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEPRAZ 20 (EAST WEST)'
);

-- line #28133
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'Rabeprazole', u'always_empty': u'', u'form': u'', u'brand': u'PEPTARD FAST', u'strength_3': u'', u'company': u'Indchemie', u'unit': u'mg'}

-- line #28134
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'Rabeprazole', u'always_empty': u'', u'form': u'', u'brand': u'PEPTARD', u'strength_3': u'', u'company': u'Indchemie', u'unit': u'mg'}

-- line #28135
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEPTARD 10 (Indchemie)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEPTARD 10 (Indchemie)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEPTARD 20 (Indchemie)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEPTARD 20 (Indchemie)'
);

-- line #28136
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEPZERA 20 (Pulse Ph.)',
	'Rabeprazole',
	'EC TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEPZERA 20 (Pulse Ph.)'
);

-- line #28137
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEPZERA 20 (Pulse Ph.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEPZERA 20 (Pulse Ph.)'
);

-- line #28138
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREBY 20 (Cadex Lab)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREBY 20 (Cadex Lab)'
);

-- line #28139
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREREB 20 (SUNFLOWER)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREREB 20 (SUNFLOWER)'
);

-- line #28140
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRORAB 10 (Wockhardt)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRORAB 10 (Wockhardt)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRORAB 20 (Wockhardt)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRORAB 20 (Wockhardt)'
);

-- line #28141
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROTOTAG-20 20 (SMENTAG PH.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROTOTAG-20 20 (SMENTAG PH.)'
);

-- line #28142
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROZOHEXT 20 (SANOFI AV.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROZOHEXT 20 (SANOFI AV.)'
);

-- line #28143
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYLOREX 20 (NPIL HC.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYLOREX 20 (NPIL HC.)'
);

-- line #28144
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABAN-20 20 (Dowell)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABAN-20 20 (Dowell)'
);

-- line #28145
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABAX 20 (AXYZEN LIFE)',
	'Rabeprazole',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABAX 20 (AXYZEN LIFE)'
);

-- line #28146
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABAX 20 (AXYZEN LIFE)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABAX 20 (AXYZEN LIFE)'
);

-- line #28147
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABAZIO 20 (AGIO PH.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABAZIO 20 (AGIO PH.)'
);

-- line #28148
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABCI 20 (STEVELS)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABCI 20 (STEVELS)'
);

-- line #28149
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Rabeprazole', u'always_empty': u'', u'form': u'TAB', u'brand': u'RABECA', u'strength_3': u'', u'company': u'NIVCA', u'unit': u''}

-- line #28150
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABECHAR 10 (Charmos Bio.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABECHAR 10 (Charmos Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABECHAR 20 (Charmos Bio.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABECHAR 20 (Charmos Bio.)'
);

-- line #28151
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABECON 20 (Neuron Ph.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABECON 20 (Neuron Ph.)'
);

-- line #28152
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABECOOL 20 (STAUNCH)',
	'RABEPrazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABECOOL 20 (STAUNCH)'
);

-- line #28153
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABEDAL 20 (Pharmed)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABEDAL 20 (Pharmed)'
);

-- line #28154
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'RAbeprazole', u'always_empty': u'', u'form': u'', u'brand': u'RABEE IV', u'strength_3': u'', u'company': u'Rpg Life', u'unit': u'mg'}

-- line #28155
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABEE 10 (Rpg Life)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABEE 10 (Rpg Life)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABEE 20 (Rpg Life)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABEE 20 (Rpg Life)'
);

-- line #28156
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABEFAM 20 (SIFAM PH.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABEFAM 20 (SIFAM PH.)'
);

-- line #28157
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABEFINE 20 (Glenmark)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABEFINE 20 (Glenmark)'
);

-- line #28158
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'Rabeprazole', u'always_empty': u'', u'form': u'', u'brand': u'RABEGEM', u'strength_3': u'', u'company': u'GEMLIFE PH.', u'unit': u'mg'}

-- line #28159
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABEGERD 20 (PARAMOUNT HC.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABEGERD 20 (PARAMOUNT HC.)'
);

-- line #28160
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABEGIN 20 (BENGINN HC.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABEGIN 20 (BENGINN HC.)'
);

-- line #28161
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABEKIND-20 20 (Mankind)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABEKIND-20 20 (Mankind)'
);

-- line #28162
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABEKIND-FAST 20 (Mankind)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABEKIND-FAST 20 (Mankind)'
);

-- line #28163
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABELEX 20 (SHINCE)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABELEX 20 (SHINCE)'
);

-- line #28164
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABELOC FAST 20 (MAGNA)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABELOC FAST 20 (MAGNA)'
);

-- line #28165
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABELOC 20 (Irm Ph.)',
	'Rabeprazole',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABELOC 20 (Irm Ph.)'
);

-- line #28166
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABELOC 40 (Cadila Ph.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg(SOD.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABELOC 40 (Cadila Ph.)'
);

-- line #28167
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABELOC 10 (Irm Ph.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABELOC 10 (Irm Ph.)'
);

-- line #28168
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABELOC 20 (Irm Ph.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABELOC 20 (Irm Ph.)'
);

-- line #28169
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABEMAC FAST 20 (Macleods)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABEMAC FAST 20 (Macleods)'
);

-- line #28170
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABEMAS 20 (Cosmas Ph.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABEMAS 20 (Cosmas Ph.)'
);

-- line #28171
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABEMED 10 (UNISEARCH HC.)',
	'RAbeprazole',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABEMED 10 (UNISEARCH HC.)'
);

-- line #28172
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABEMED 20 (UNISEARCH HC.)',
	'RAbeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABEMED 20 (UNISEARCH HC.)'
);

-- line #28173
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABEMON 20 (ERIS LIFE)',
	'RAbeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABEMON 20 (ERIS LIFE)'
);

-- line #28174
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABENION IV 20 (Dominion)',
	'Rabeprazole',
	'VIAL',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABENION IV 20 (Dominion)'
);

-- line #28175
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABENION 20 (Dominion)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABENION 20 (Dominion)'
);

-- line #28176
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABEPHEX 10 (MOLEKULE)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABEPHEX 10 (MOLEKULE)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABEPHEX 20 (MOLEKULE)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABEPHEX 20 (MOLEKULE)'
);

-- line #28177
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABEPRAZ 20 (Ikon Rem)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABEPRAZ 20 (Ikon Rem)'
);

-- line #28178
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABEPROM 20 (Om Bio.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABEPROM 20 (Om Bio.)'
);

-- line #28179
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABEPRO 10 (Shreya)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABEPRO 10 (Shreya)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABEPRO 20 (Shreya)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABEPRO 20 (Shreya)'
);

-- line #28180
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABEP 20 (Active Hc.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABEP 20 (Active Hc.)'
);

-- line #28181
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABERA 10 (Jenburkt)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABERA 10 (Jenburkt)'
);

-- line #28182
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABERA 20 (Jenburkt)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABERA 20 (Jenburkt)'
);

-- line #28183
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Rabeprazole', u'always_empty': u'', u'form': u'FC TAB', u'brand': u'RABESEC', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #28184
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABESEC 10 (Cipla)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABESEC 10 (Cipla)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABESEC 20 (Cipla)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABESEC 20 (Cipla)'
);

-- line #28185
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABESTAR 20 (TRIGENESIS)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABESTAR 20 (TRIGENESIS)'
);

-- line #28186
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABETAC 20 (Mapra)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABETAC 20 (Mapra)'
);

-- line #28187
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABETO 20 (FLAMINGO PH.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABETO 20 (FLAMINGO PH.)'
);

-- line #28188
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABETROL 20 (RIVAN PH.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABETROL 20 (RIVAN PH.)'
);

-- line #28189
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABET 20 (MADHAV BIO.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABET 20 (MADHAV BIO.)'
);

-- line #28190
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABEZ 10 (HETERO HC.)',
	'Rabeprazole',
	'EC TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABEZ 10 (HETERO HC.)'
);

-- line #28191
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABEZ 20 (HETERO HC.)',
	'Rabeprazole',
	'EC TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABEZ 20 (HETERO HC.)'
);

-- line #28192
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABEZ-FR 20 (GENX)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABEZ-FR 20 (GENX)'
);

-- line #28193
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'Rabeprazole', u'always_empty': u'', u'form': u'', u'brand': u'RABEZ IV', u'strength_3': u'', u'company': u'Genix Ph.', u'unit': u'mg'}

-- line #28194
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABEZ 10 (Genix Ph.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABEZ 10 (Genix Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABEZ 20 (Genix Ph.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABEZ 20 (Genix Ph.)'
);

-- line #28195
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABGY 20 (Indu D.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABGY 20 (Indu D.)'
);

-- line #28196
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABIBIT 20 (Cubit Hc.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABIBIT 20 (Cubit Hc.)'
);

-- line #28197
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABICA 10 (Indica)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABICA 10 (Indica)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABICA 20 (Indica)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABICA 20 (Indica)'
);

-- line #28198
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABICID 20 (AASTHA PH.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABICID 20 (AASTHA PH.)'
);

-- line #28199
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABICIP FAST 20 (Cipla)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABICIP FAST 20 (Cipla)'
);

-- line #28200
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'Rabeprazole', u'always_empty': u'', u'form': u'INJ', u'brand': u'RABICIP', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #28201
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABICIP 10 (Cipla)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABICIP 10 (Cipla)'
);

-- line #28202
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABICIP 20 (Cipla)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABICIP 20 (Cipla)'
);

-- line #28203
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Rabeprazole', u'always_empty': u'', u'form': u'TAB', u'brand': u'RABICON-20', u'strength_3': u'', u'company': u'ECON HC.', u'unit': u''}

-- line #28204
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABICOOL 10 (P C INDIA)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABICOOL 10 (P C INDIA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABICOOL 20 (P C INDIA)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABICOOL 20 (P C INDIA)'
);

-- line #28205
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABICREST 20 (VIDACARE PH.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABICREST 20 (VIDACARE PH.)'
);

-- line #28206
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABIET 10 (J. B. Chem.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABIET 10 (J. B. Chem.)'
);

-- line #28207
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABIET 20 (J. B. Chem.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABIET 20 (J. B. Chem.)'
);

-- line #28208
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABIFAST IV 20 (Zuventus)',
	'Rabeprazole',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABIFAST IV 20 (Zuventus)'
);

-- line #28209
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABIFAST 10 (Zuventus)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABIFAST 10 (Zuventus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABIFAST 20 (Zuventus)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABIFAST 20 (Zuventus)'
);

-- line #28210
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABIFIN 20 (Ind-Swift)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABIFIN 20 (Ind-Swift)'
);

-- line #28211
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABIFIN 20 (Ind-Swift)',
	'Rabeprazole',
	'VIAL',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABIFIN 20 (Ind-Swift)'
);

-- line #28212
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABIGLAM 20 (GENETIC PH.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABIGLAM 20 (GENETIC PH.)'
);

-- line #28213
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'Rabeprazole', u'always_empty': u'', u'form': u'', u'brand': u'RABIGOLD', u'strength_3': u'', u'company': u'Theo Ph.', u'unit': u'mg'}

-- line #28214
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABIKAM 20 (KAMSONS PH.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABIKAM 20 (KAMSONS PH.)'
);

-- line #28215
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABILAC-20 20 (LACTARE PH.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABILAC-20 20 (LACTARE PH.)'
);

-- line #28216
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABILAND 20 (L & V PH.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABILAND 20 (L & V PH.)'
);

-- line #28217
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABILEM 20 (LEMON PH.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABILEM 20 (LEMON PH.)'
);

-- line #28218
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABIMOR 20 (ST.MORRISON)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABIMOR 20 (ST.MORRISON)'
);

-- line #28219
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABIMOR 20 (ST.MORRISON)',
	'Rabeprazole',
	'VIAL',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABIMOR 20 (ST.MORRISON)'
);

-- line #28220
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABINEEL 20 (NEEL REM.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABINEEL 20 (NEEL REM.)'
);

-- line #28221
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABINOM 20 (ACTO)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABINOM 20 (ACTO)'
);

-- line #28222
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABIN 20 (Intra(INVISION))',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABIN 20 (Intra(INVISION))'
);

-- line #28223
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABIN 20 (Intra(INVISION))',
	'Rabeprazole',
	'VIAL',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABIN 20 (Intra(INVISION))'
);

-- line #28224
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABIO 20 (SANCHEZ LAB.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABIO 20 (SANCHEZ LAB.)'
);

-- line #28225
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABIPACE 20 (Shreya)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABIPACE 20 (Shreya)'
);

-- line #28226
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABIPEN 20 (Morepen)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABIPEN 20 (Morepen)'
);

-- line #28227
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABIPLUS 20 (Wanbury)',
	'Rabeprazole',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABIPLUS 20 (Wanbury)'
);

-- line #28228
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABIPLUS FAST 20 (Wanbury)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg(SOD.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABIPLUS FAST 20 (Wanbury)'
);

-- line #28229
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'Rabeprazole', u'always_empty': u'', u'form': u'', u'brand': u'RABIPLUS - IV', u'strength_3': u'', u'company': u'Wanbury', u'unit': u'mg/VIAL(AS ST. POW. FOR RECONST. WITH 5ML. OF ST. WATER)'}

-- line #28230
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABIPURE 20 (STERLING PH.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABIPURE 20 (STERLING PH.)'
);

-- line #28231
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABIROS 10 (MICRO HC.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABIROS 10 (MICRO HC.)'
);

-- line #28232
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABIROS 20 (MICRO HC.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABIROS 20 (MICRO HC.)'
);

-- line #28233
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABIRUN 20 (HARRISUN L.C.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABIRUN 20 (HARRISUN L.C.)'
);

-- line #28234
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABISAFE 20 (UNI OR.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABISAFE 20 (UNI OR.)'
);

-- line #28235
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'Rabeprazole', u'always_empty': u'', u'form': u'', u'brand': u'RABISAL-20', u'strength_3': u'', u'company': u'ORSAL PH.', u'unit': u'mg'}

-- line #28236
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABISENA 20 (BIOSENA)',
	'Rabeprazole',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABISENA 20 (BIOSENA)'
);

-- line #28237
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABISTAR 20 (Salvo Hc.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABISTAR 20 (Salvo Hc.)'
);

-- line #28238
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABISTREAM 20 (MEDISTREAM)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABISTREAM 20 (MEDISTREAM)'
);

-- line #28239
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABITAB 20 (RHINE BIO.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABITAB 20 (RHINE BIO.)'
);

-- line #28240
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABITAC-10 10 (ALEXUS(SURYA))',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABITAC-10 10 (ALEXUS(SURYA))'
);

-- line #28241
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABITAC-20 20 (ALEXUS(SURYA))',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABITAC-20 20 (ALEXUS(SURYA))'
);

-- line #28242
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABITOP FAST 20 (Aristo)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg(WITH SOD.BICARB. AS BUFFER)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABITOP FAST 20 (Aristo)'
);

-- line #28243
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Rabeprazole', u'always_empty': u'', u'form': u'TAB', u'brand': u'RABITOP', u'strength_3': u'', u'company': u'AKESISS', u'unit': u''}

-- line #28244
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABITOP 20 (Aristo)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABITOP 20 (Aristo)'
);

-- line #28245
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'Rabeprazole', u'always_empty': u'', u'form': u'', u'brand': u'RABITRAZ', u'strength_3': u'', u'company': u'MATRIX LIFE', u'unit': u'mg'}

-- line #28246
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABIUM FAST 20 (Intas)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg (SOD.BICARB AS BUFFER)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABIUM FAST 20 (Intas)'
);

-- line #28247
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABIUM 10 (Intas)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABIUM 10 (Intas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABIUM 20 (Intas)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABIUM 20 (Intas)'
);

-- line #28248
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABIX 20 (AXEN PH.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABIX 20 (AXEN PH.)'
);

-- line #28249
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABLET IV 20 (Lupin)',
	'Rabeprazole',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABLET IV 20 (Lupin)'
);

-- line #28250
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABLET 10 (Lupin)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABLET 10 (Lupin)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABLET 20 (Lupin)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABLET 20 (Lupin)'
);

-- line #28251
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABLET 40 (Lupin)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABLET 40 (Lupin)'
);

-- line #28252
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABNOZ 10 (Parenteral)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABNOZ 10 (Parenteral)'
);

-- line #28253
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABNOZ 20 (Parenteral)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABNOZ 20 (Parenteral)'
);

-- line #28254
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABOL 20 (Gufic Bio.)',
	'Rabeprazole',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABOL 20 (Gufic Bio.)'
);

-- line #28255
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABOL 10 (Gufic Bio.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABOL 10 (Gufic Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABOL 20 (Gufic Bio.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABOL 20 (Gufic Bio.)'
);

-- line #28256
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'Rabeprazole', u'always_empty': u'', u'form': u'', u'brand': u'RABONIK DSR', u'strength_3': u'', u'company': u'ERIS LIFE', u'unit': u'mg'}

-- line #28257
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10', u'strength_2': u'', u'substance': u'Rabeprazole', u'always_empty': u'', u'form': u'', u'brand': u'RABONIK', u'strength_3': u'', u'company': u'ERIS LIFE', u'unit': u'mg'}

-- line #28258
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'Rabeprazole', u'always_empty': u'', u'form': u'', u'brand': u'RABONIK', u'strength_3': u'', u'company': u'ERIS LIFE', u'unit': u'mg'}

-- line #28259
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABON 20 (Zenon Hc.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABON 20 (Zenon Hc.)'
);

-- line #28260
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABOT 20 (Kinedex Hc)',
	'Rabeprazole',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABOT 20 (Kinedex Hc)'
);

-- line #28261
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABOT 20 (Kinedex Hc.)',
	'Rabeprazole',
	'SB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABOT 20 (Kinedex Hc.)'
);

-- line #28262
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABOWIN 20 (Ferring Ph.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABOWIN 20 (Ferring Ph.)'
);

-- line #28263
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABPOD 20 (RENAUNT PH.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABPOD 20 (RENAUNT PH.)'
);

-- line #28264
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABSIG 20 (SIGNOVA)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABSIG 20 (SIGNOVA)'
);

-- line #28265
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABSIG 20 (SIGNOVA)',
	'Rabeprazole',
	'VIAL',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABSIG 20 (SIGNOVA)'
);

-- line #28266
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAB 10 (Khandelwal)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAB 10 (Khandelwal)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAB 20 (Khandelwal)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAB 20 (Khandelwal)'
);

-- line #28267
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABTIC 20 (Wisdom Ph.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABTIC 20 (Wisdom Ph.)'
);

-- line #28268
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABTOS 20 (STARTOS)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABTOS 20 (STARTOS)'
);

-- line #28269
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABTUL 20 (Sipra Rem.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABTUL 20 (Sipra Rem.)'
);

-- line #28270
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABWIT 20 (FOREWIT PH.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABWIT 20 (FOREWIT PH.)'
);

-- line #28271
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABXID 20 (Maneesh)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABXID 20 (Maneesh)'
);

-- line #28272
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABZER 20 (Wallace)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABZER 20 (Wallace)'
);

-- line #28273
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAPIROL 20 (ALKEM)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAPIROL 20 (ALKEM)'
);

-- line #28274
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAPO 20 (Apostle Rem.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAPO 20 (Apostle Rem.)'
);

-- line #28275
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAPTAC 20 (Rapross)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAPTAC 20 (Rapross)'
);

-- line #28276
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAVER 20 (BIOMAX BIO.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAVER 20 (BIOMAX BIO.)'
);

-- line #28277
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAZEP 20 (Intra Lab)',
	'Rabeprazole',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAZEP 20 (Intra Lab)'
);

-- line #28278
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAZEP 20 (Intra Lab)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAZEP 20 (Intra Lab)'
);

-- line #28279
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAZ 20 (EXCELLA)',
	'Rabeprazole',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAZ 20 (EXCELLA)'
);

-- line #28280
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'Rabeprazole', u'always_empty': u'', u'form': u'VIAL', u'brand': u'RAZ IV', u'strength_3': u'', u'company': u'EXCELLA', u'unit': u''}

-- line #28281
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAZ 20 (EXCELLA)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAZ 20 (EXCELLA)'
);

-- line #28282
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RB 20 (ZYLONE HC.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RB 20 (ZYLONE HC.)'
);

-- line #28283
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Rabeprazole', u'always_empty': u'', u'form': u'DSR CAP', u'brand': u'RCID', u'strength_3': u'', u'company': u'Tripada BIO.', u'unit': u''}

-- line #28284
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'Rabeprazole', u'always_empty': u'', u'form': u'', u'brand': u'R-CID', u'strength_3': u'', u'company': u'Nicholas', u'unit': u'mg(BUFFERED)'}

-- line #28285
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'R-CID 20 (Tripada BIO.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'R-CID 20 (Tripada BIO.)'
);

-- line #28286
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REBIBIT 10 (Cubit Hc.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REBIBIT 10 (Cubit Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REBIBIT 20 (Cubit Hc.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REBIBIT 20 (Cubit Hc.)'
);

-- line #28287
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REBILEX 10 (Lexus)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REBILEX 10 (Lexus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REBILEX 20 (Lexus)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REBILEX 20 (Lexus)'
);

-- line #28288
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REBILOZ 20 (Torrent)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REBILOZ 20 (Torrent)'
);

-- line #28289
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RECURE 20 (HAMPS BIO)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RECURE 20 (HAMPS BIO)'
);

-- line #28290
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REDURA 20 (ORION BIOTECH.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REDURA 20 (ORION BIOTECH.)'
);

-- line #28291
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Rabeprazole', u'always_empty': u'', u'form': u'INJ', u'brand': u'REKOOL', u'strength_3': u'', u'company': u'ALEMBIC', u'unit': u''}

-- line #28292
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REKOOL RAPID 20 (Alembic)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REKOOL RAPID 20 (Alembic)'
);

-- line #28293
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REKOOL 10 (Alembic)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REKOOL 10 (Alembic)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REKOOL 20 (Alembic)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REKOOL 20 (Alembic)'
);

-- line #28294
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REORAB 20 (RISHAB(OROCHEM))',
	'Rabeprazole',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REORAB 20 (RISHAB(OROCHEM))'
);

-- line #28295
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REORAB 20 (RISHAB(OROCHEM))',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REORAB 20 (RISHAB(OROCHEM))'
);

-- line #28296
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REPRAL 20 (Elder)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REPRAL 20 (Elder)'
);

-- line #28297
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REPRAZ 10 (Medley)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REPRAZ 10 (Medley)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REPRAZ 20 (Medley)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REPRAZ 20 (Medley)'
);

-- line #28298
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REWARD 20 (Aronex Life)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REWARD 20 (Aronex Life)'
);

-- line #28299
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REZOLE 20 (Ritz Ph.)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REZOLE 20 (Ritz Ph.)'
);

-- line #28300
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIFCID 20 (VENSAT)',
	'Rabeprazole',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIFCID 20 (VENSAT)'
);

-- line #28301
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIFKOOL 20 (RASS HC.)',
	'Rabeprazole',
	'VIAL',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIFKOOL 20 (RASS HC.)'
);

-- line #28302
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RABEZOL 20 (Otsira)',
	'RABEZOLE SODIUM',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RABEZOL 20 (Otsira)'
);

-- line #28303
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'ANTI RABIES SERUM', u'strength_2': u'', u'substance': u'Rabies Immunoglobulin', u'always_empty': u'', u'form': u'VACCINE', u'brand': u'ANTI RABIES', u'strength_3': u'', u'company': u'GEN BIO.', u'unit': u''}

-- line #28304
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'300IU.(HUMAN RABIES IMMUN.GLOBU.PAST.)', u'strength_2': u'', u'substance': u'Rabies Immunoglobulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'BERIRAB-P IU', u'strength_3': u'', u'company': u'Zydus Bio.', u'unit': u''}

-- line #28305
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'750IU.(HUMAN RABIES IMMUN.GLOBU.PAST.)', u'strength_2': u'', u'substance': u'Rabies Immunoglobulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'BERIRAB-P IU', u'strength_3': u'', u'company': u'Zydus Bio.', u'unit': u''}

-- line #28306
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1200IU(EQUINE)', u'strength_2': u'', u'substance': u'Rabies Immunoglobulin', u'always_empty': u'', u'form': u'V', u'brand': u'CARIG', u'strength_3': u'', u'company': u'Cadila Ph.', u'unit': u''}

-- line #28307
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'300IU', u'strength_2': u'ML(EQUINE)', u'substance': u'Rabies Immunoglobulin', u'always_empty': u'', u'form': u'V', u'brand': u'EQUIRAB', u'strength_3': u'', u'company': u'Bharat S.', u'unit': u''}

-- line #28308
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000IU. ANTI RABIES SERUM', u'strength_2': u'', u'substance': u'Rabies Immunoglobulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'ERIG IU', u'strength_3': u'', u'company': u'Cadila New.', u'unit': u''}

-- line #28309
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Rabies Immunoglobulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'HRIG', u'strength_3': u'', u'company': u'Cadila New.', u'unit': u''}

-- line #28310
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'300IU. (HUMAN RABIES IG 300IU.)', u'strength_2': u'', u'substance': u'Rabies Immunoglobulin', u'always_empty': u'', u'form': u'', u'brand': u'IMOGAM RABIES', u'strength_3': u'', u'company': u'Ranbaxy', u'unit': u''}

-- line #28311
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000IU.(EQUINE ANTIRABIES IMMUNOGLOB.)', u'strength_2': u'', u'substance': u'Rabies Immunoglobulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'IMORAB IU', u'strength_3': u'', u'company': u'Aventis Pas.', u'unit': u''}

-- line #28312
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'>1000IU.FRAGMENTS OF EQUINE RABIES IMMUNGLOB.', u'strength_2': u'', u'substance': u'Rabies Immunoglobulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'PARS >1000IU', u'strength_3': u'', u'company': u'Cadila New.', u'unit': u''}

-- line #28313
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000IU', u'strength_2': u'', u'substance': u'Rabies Immunoglobulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'PASTEUR ANTIRABIES SERUM', u'strength_3': u'', u'company': u'Cadila', u'unit': u''}

-- line #28314
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'150IU.', u'strength_2': u'', u'substance': u'Rabies Immunoglobulin', u'always_empty': u'', u'form': u'VIAL', u'brand': u'RABGLOB', u'strength_3': u'', u'company': u'Bharat S.', u'unit': u''}

-- line #28315
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Rabies Vaccine', u'always_empty': u'', u'form': u'INJ', u'brand': u'ABHAYRAB', u'strength_3': u'', u'company': u'Human Bio.', u'unit': u''}

-- line #28316
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'RABIES VACCINE', u'always_empty': u'', u'form': u'VACCINE(HDC)', u'brand': u'RABIES', u'strength_3': u'', u'company': u'Serum Inst.', u'unit': u''}

-- line #28317
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'RABIES VACCINE', u'always_empty': u'', u'form': u'VACCINE(HUMAN)', u'brand': u'RABIES', u'strength_3': u'', u'company': u'Haffkine', u'unit': u''}

-- line #28318
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2.5IU', u'strength_2': u'', u'substance': u'Rabies Vaccine', u'always_empty': u'', u'form': u'INJ', u'brand': u'RABIPUR', u'strength_3': u'', u'company': u'Sanofi Aventis', u'unit': u''}

-- line #28319
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Rabies Vaccine', u'always_empty': u'', u'form': u'INJ', u'brand': u'RABIRIX', u'strength_3': u'', u'company': u'Bharat Bio.', u'unit': u''}

-- line #28320
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'RABIES VACCINE', u'always_empty': u'', u'form': u'V', u'brand': u'RABIVAX', u'strength_3': u'', u'company': u'Serum Inst.', u'unit': u''}

-- line #28321
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AD-100 100 (Genx Ph.)',
	'RACECADOTRIL',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AD-100 100 (Genx Ph.)'
);

-- line #28322
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AD-10/30 10 (Genx Ph.)',
	'RACECADOTRIL',
	'DT',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AD-10/30 10 (Genx Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AD-10/30 30 (Genx Ph.)',
	'RACECADOTRIL',
	'DT',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AD-10/30 30 (Genx Ph.)'
);

-- line #28323
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AD 10 (HETERO HC.)',
	'RACECADOTRIL',
	'DT TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AD 10 (HETERO HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AD 30 (HETERO HC.)',
	'RACECADOTRIL',
	'DT TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AD 30 (HETERO HC.)'
);

-- line #28324
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AD EE-10 100 (HETERO HC.)',
	'RACECADOTRIL',
	'SAC',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AD EE-10 100 (HETERO HC.)'
);

-- line #28325
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AD EE-30 100 (HETERO HC.)',
	'RACECADOTRIL',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AD EE-30 100 (HETERO HC.)'
);

-- line #28326
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10', u'strength_2': u'30', u'substance': u'RACECADOTRIL', u'always_empty': u'', u'form': u'', u'brand': u'AD-SAC', u'strength_3': u'', u'company': u'HETERO HC.', u'unit': u'mg'}

-- line #28327
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'RACECADOTRIL', u'always_empty': u'', u'form': u'CAP', u'brand': u'AQUASEC', u'strength_3': u'', u'company': u'Micro Nova', u'unit': u''}

-- line #28328
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CADOTRIL 100 (Ordain Hc.)',
	'RACECADOTRIL',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CADOTRIL 100 (Ordain Hc.)'
);

-- line #28329
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CADOTRIL 15 (Ordain Hc.)',
	'RACECADOTRIL',
	'SAC',
	gm.nullify_empty_string('15')::numeric,
	'mg/SAC.'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CADOTRIL 15 (Ordain Hc.)'
);

-- line #28330
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIRASEC 100 (Nicholas)',
	'RACECADOTRIL',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIRASEC 100 (Nicholas)'
);

-- line #28331
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'RACECADOTRIL', u'always_empty': u'', u'form': u'SAC', u'brand': u'DIRASEC', u'strength_3': u'', u'company': u'Nicholas', u'unit': u''}

-- line #28332
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOTRIL 100 (Apex Labs.)',
	'RACECADOTRIL',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOTRIL 100 (Apex Labs.)'
);

-- line #28333
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOTRIL 10 (Apex Labs.)',
	'RACECADOTRIL',
	'SAC',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOTRIL 10 (Apex Labs.)'
);

-- line #28334
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EDITOR 15 (BIOMIICRON)',
	'RACECADOTRIL',
	'SAC',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EDITOR 15 (BIOMIICRON)'
);

-- line #28335
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENUFE 10 (HETERO HC.)',
	'RACECADOTRIL',
	'DT',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENUFE 10 (HETERO HC.)'
);

-- line #28336
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENUFE 30 (HETERO HC.)',
	'RACECADOTRIL',
	'DT',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENUFE 30 (HETERO HC.)'
);

-- line #28337
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENUFF 100 (HETERO HC.)',
	'RACECADOTRIL',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENUFF 100 (HETERO HC.)'
);

-- line #28338
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENUFF 10 (HETERO HC.)',
	'RACECADOTRIL',
	'DT TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENUFF 10 (HETERO HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENUFF 30 (HETERO HC.)',
	'RACECADOTRIL',
	'DT TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENUFF 30 (HETERO HC.)'
);

-- line #28339
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'RACECADOTRIL', u'always_empty': u'', u'form': u'SAC', u'brand': u'ENUFF', u'strength_3': u'', u'company': u'HETERO HC.', u'unit': u''}

-- line #28340
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENUFF 10 (HETERO HC.)',
	'RACECADOTRIL',
	'SAC',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENUFF 10 (HETERO HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENUFF 30 (HETERO HC.)',
	'RACECADOTRIL',
	'SAC',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENUFF 30 (HETERO HC.)'
);

-- line #28341
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXDARA 100 (Lifeon)',
	'RACECADOTRIL',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXDARA 100 (Lifeon)'
);

-- line #28342
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYDRAL 100 (Alembic)',
	'RACECADOTRIL',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYDRAL 100 (Alembic)'
);

-- line #28343
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'RACECADOTRIL', u'always_empty': u'', u'form': u'SAC', u'brand': u'HYDRAL', u'strength_3': u'', u'company': u'Alembic', u'unit': u''}

-- line #28344
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LACTORACE 15 (HALO MEDI.)',
	'RACECADOTRIL',
	'SAC',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LACTORACE 15 (HALO MEDI.)'
);

-- line #28345
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOMOREST 100 (Zuventus)',
	'RACECADOTRIL',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOMOREST 100 (Zuventus)'
);

-- line #28346
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOMOREST 10 (Zuventus)',
	'RACECADOTRIL',
	'SAC',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOMOREST 10 (Zuventus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOMOREST 30 (Zuventus)',
	'RACECADOTRIL',
	'SAC',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOMOREST 30 (Zuventus)'
);

-- line #28347
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NODI 100 (Comed Chem.)',
	'RACECADOTRIL',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NODI 100 (Comed Chem.)'
);

-- line #28348
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEDIDOT 10 (Elder)',
	'RACECADOTRIL',
	'SAC',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEDIDOT 10 (Elder)'
);

-- line #28349
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RACARIL 100 (EAST WEST)',
	'RACECADOTRIL',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RACARIL 100 (EAST WEST)'
);

-- line #28350
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RACEDOT 100 (Intra(INVISION))',
	'RACECADOTRIL',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RACEDOT 100 (Intra(INVISION))'
);

-- line #28351
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RACE-F 100 (Bestochem)',
	'RACECADOTRIL',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RACE-F 100 (Bestochem)'
);

-- line #28352
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RACE-F 15 (Bestochem)',
	'RACECADOTRIL',
	'SAC',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RACE-F 15 (Bestochem)'
);

-- line #28353
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RACE-F 15 (Bestochem)',
	'RACECADOTRIL',
	'SAC',
	gm.nullify_empty_string('15')::numeric,
	'mg/SAC.'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RACE-F 15 (Bestochem)'
);

-- line #28354
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RACELAC 15 (RADHE BIO.)',
	'RACECADOTRIL',
	'POUCH',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RACELAC 15 (RADHE BIO.)'
);

-- line #28355
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RACELOC 100 (Intra Lab)',
	'RACECADOTRIL',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RACELOC 100 (Intra Lab)'
);

-- line #28356
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RACELOC 15 (Intra Lab)',
	'RACECADOTRIL',
	'SAC',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RACELOC 15 (Intra Lab)'
);

-- line #28357
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RACESTAT 15 (Intra(INVISION))',
	'RACECADOTRIL',
	'SACH',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RACESTAT 15 (Intra(INVISION))'
);

-- line #28358
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RACIGYL 100 (Mankind)',
	'RACECADOTRIL',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RACIGYL 100 (Mankind)'
);

-- line #28359
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RACIGYL 15 (LIFESTAR)',
	'RACECADOTRIL',
	'KID TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RACIGYL 15 (LIFESTAR)'
);

-- line #28360
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RACIGYL 15 (Mankind)',
	'RACECADOTRIL',
	'SAC',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RACIGYL 15 (Mankind)'
);

-- line #28361
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RACOTIL 100 (Cipla)',
	'RACECADOTRIL',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RACOTIL 100 (Cipla)'
);

-- line #28362
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1', u'strength_2': u'3;G', u'substance': u'RACECADOTRIL', u'always_empty': u'', u'form': u'SAC', u'brand': u'RACOTIL', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #28363
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RACY 100 (Nicholas)',
	'RACECADOTRIL',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RACY 100 (Nicholas)'
);

-- line #28364
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'RACECADOTRIL', u'always_empty': u'', u'form': u'ORAL SUS', u'brand': u'RACY', u'strength_3': u'', u'company': u'Piramal Hc.', u'unit': u''}

-- line #28365
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10', u'strength_2': u'30;G', u'substance': u'RACECADOTRIL', u'always_empty': u'', u'form': u'SAC', u'brand': u'RACY', u'strength_3': u'', u'company': u'Nicholas', u'unit': u''}

-- line #28366
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'RACECADOTRIL', u'always_empty': u'', u'form': u'SUS', u'brand': u'RACY', u'strength_3': u'', u'company': u'Piramal Hc.', u'unit': u''}

-- line #28367
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REDOT-100 100 (West Coast)',
	'RACECADOTRIL',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REDOT-100 100 (West Coast)'
);

-- line #28368
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REDOT-10 10 (West Coast)',
	'RACECADOTRIL',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REDOT-10 10 (West Coast)'
);

-- line #28369
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REDOT-30 30 (West Coast)',
	'RACECADOTRIL',
	'TAB',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REDOT-30 30 (West Coast)'
);

-- line #28370
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REDOTIL 100 (Dr.Reddy''S)',
	'RACECADOTRIL',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REDOTIL 100 (Dr.Reddy''S)'
);

-- line #28371
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REDOTIL 10 (Dr.Reddy''S)',
	'RACECADOTRIL',
	'SAC',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REDOTIL 10 (Dr.Reddy''S)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REDOTIL 30 (Dr.Reddy''S)',
	'RACECADOTRIL',
	'SAC',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REDOTIL 30 (Dr.Reddy''S)'
);

-- line #28372
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BONMAX 60 (Zydus A.)',
	'Raloxifene',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BONMAX 60 (Zydus A.)'
);

-- line #28373
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BONTACT 60 (Cadila Ph.)',
	'RALOXIFENE',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BONTACT 60 (Cadila Ph.)'
);

-- line #28374
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESSERM 60 (Torrent)',
	'Raloxifene',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESSERM 60 (Torrent)'
);

-- line #28375
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESTORAL 60 (Neu-Foreva)',
	'Raloxifene',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESTORAL 60 (Neu-Foreva)'
);

-- line #28376
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESTROACT 60 (Kee Ph.)',
	'Raloxifene',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESTROACT 60 (Kee Ph.)'
);

-- line #28377
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EVOMATE 60 (Shreya)',
	'Raloxifene',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EVOMATE 60 (Shreya)'
);

-- line #28378
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIONA 60 (Dr.Reddy''S)',
	'Raloxifene',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIONA 60 (Dr.Reddy''S)'
);

-- line #28379
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GYNISTA 60 (Micro Nova)',
	'Raloxifene',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GYNISTA 60 (Micro Nova)'
);

-- line #28380
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSRAL 60 (Panacea)',
	'Raloxifene',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSRAL 60 (Panacea)'
);

-- line #28381
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RALISTA 60 (Cipla)',
	'Raloxifene',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RALISTA 60 (Cipla)'
);

-- line #28382
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RALOCIUM 60 (Bal Ph.)',
	'Raloxifene',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RALOCIUM 60 (Bal Ph.)'
);

-- line #28383
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RALOFEN 60 (Bal Ph.)',
	'Raloxifene',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RALOFEN 60 (Bal Ph.)'
);

-- line #28384
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RALOSTO 60 (Nicholas)',
	'Raloxifene',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RALOSTO 60 (Nicholas)'
);

-- line #28385
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RALOTAB 60 (Centaur)',
	'Raloxifene',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RALOTAB 60 (Centaur)'
);

-- line #28386
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'60', u'strength_2': u'', u'substance': u'Raloxifene', u'always_empty': u'', u'form': u'', u'brand': u'RALOXIFENE TEMBID', u'strength_3': u'', u'company': u'Zydus N.S.', u'unit': u'mg'}

-- line #28387
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RALOX 60 (Glenmark)',
	'Raloxifene',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RALOX 60 (Glenmark)'
);

-- line #28388
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMITAX 8 (Ranbaxy)',
	'RAMELTEON',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMITAX 8 (Ranbaxy)'
);

-- line #28389
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACEPRIL 2.5 (Sain Med.)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACEPRIL 2.5 (Sain Med.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACEPRIL 5 (Sain Med.)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACEPRIL 5 (Sain Med.)'
);

-- line #28390
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACEPRIL 2.5 (Ultra Chiron)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACEPRIL 2.5 (Ultra Chiron)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACEPRIL 5 (Ultra Chiron)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACEPRIL 5 (Ultra Chiron)'
);

-- line #28391
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACE 2.5 (AEGIS)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACE 2.5 (AEGIS)'
);

-- line #28392
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALVACE 1.25 (NICHOLAS)',
	'Ramipril',
	'CAP',
	gm.nullify_empty_string('1.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALVACE 1.25 (NICHOLAS)'
);

-- line #28393
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALVACE 2.5 (NICHOLAS)',
	'Ramipril',
	'CAP',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALVACE 2.5 (NICHOLAS)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALVACE 5 (NICHOLAS)',
	'Ramipril',
	'CAP',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALVACE 5 (NICHOLAS)'
);

-- line #28394
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDACE 1.25 (Sanofi Aventis)',
	'Ramipril',
	'CAP',
	gm.nullify_empty_string('1.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDACE 1.25 (Sanofi Aventis)'
);

-- line #28395
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDACE 2.5 (Sanofi Aventis)',
	'Ramipril',
	'CAP',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDACE 2.5 (Sanofi Aventis)'
);

-- line #28396
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDACE 5 (Sanofi Aventis)',
	'Ramipril',
	'CAP',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDACE 5 (Sanofi Aventis)'
);

-- line #28397
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDACE 1.25 (Sanofi Aventis)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('1.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDACE 1.25 (Sanofi Aventis)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDACE 2.5 (Sanofi Aventis)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDACE 2.5 (Sanofi Aventis)'
);

-- line #28398
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDACE 5 (Sanofi Aventis)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDACE 5 (Sanofi Aventis)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDACE 10 (Sanofi Aventis)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDACE 10 (Sanofi Aventis)'
);

-- line #28399
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDIF 2.5 (ARCUS LABS)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDIF 2.5 (ARCUS LABS)'
);

-- line #28400
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDIF 5 (ARCUS LABS)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDIF 5 (ARCUS LABS)'
);

-- line #28401
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDIKA 2.5 (Mankind)',
	'Ramipril',
	'CAP',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDIKA 2.5 (Mankind)'
);

-- line #28402
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDIOPRIL 10 (Dr.Reddy''S)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDIOPRIL 10 (Dr.Reddy''S)'
);

-- line #28403
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDIOPRIL 1.25 (DR. REDDY''S)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('1.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDIOPRIL 1.25 (DR. REDDY''S)'
);

-- line #28404
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDIOPRIL 2.5 (Dr.Reddy''S)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDIOPRIL 2.5 (Dr.Reddy''S)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDIOPRIL 5 (Dr.Reddy''S)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDIOPRIL 5 (Dr.Reddy''S)'
);

-- line #28405
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDIRIL 2.5 (SHINE PH.)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDIRIL 2.5 (SHINE PH.)'
);

-- line #28406
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDIRIL 5 (SHINE PH.)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDIRIL 5 (SHINE PH.)'
);

-- line #28407
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONRAM 1.25 (CONCERTINA)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('1.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONRAM 1.25 (CONCERTINA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONRAM 2.5 (CONCERTINA)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONRAM 2.5 (CONCERTINA)'
);

-- line #28408
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONRAM 5 (CONCERTINA)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONRAM 5 (CONCERTINA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONRAM 10 (CONCERTINA)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONRAM 10 (CONCERTINA)'
);

-- line #28409
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORDIMIL 2.5 (Ind-Swift)',
	'Ramipril',
	'CAP',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORDIMIL 2.5 (Ind-Swift)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORDIMIL 5 (Ind-Swift)',
	'Ramipril',
	'CAP',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORDIMIL 5 (Ind-Swift)'
);

-- line #28410
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORPRIL 1.25 (Ranbaxy Cv)',
	'Ramipril',
	'CAP',
	gm.nullify_empty_string('1.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORPRIL 1.25 (Ranbaxy Cv)'
);

-- line #28411
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORPRIL 2.5 (Ranbaxy Cv)',
	'Ramipril',
	'CAP',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORPRIL 2.5 (Ranbaxy Cv)'
);

-- line #28412
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORPRIL 5 (Ranbaxy Cv)',
	'Ramipril',
	'CAP',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORPRIL 5 (Ranbaxy Cv)'
);

-- line #28413
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEXACE 10 (Dexter Lab)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEXACE 10 (Dexter Lab)'
);

-- line #28414
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEXACE 2.5 (Dexter Lab)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEXACE 2.5 (Dexter Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEXACE 5 (Dexter Lab)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEXACE 5 (Dexter Lab)'
);

-- line #28415
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ECATOR 10 (Torrent)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ECATOR 10 (Torrent)'
);

-- line #28416
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ECATOR 2.5 (Torrent)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ECATOR 2.5 (Torrent)'
);

-- line #28417
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ECATOR 5 (Torrent)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ECATOR 5 (Torrent)'
);

-- line #28418
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HECRIL 2.5 (NEISS)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg/5'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HECRIL 2.5 (NEISS)'
);

-- line #28419
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HOPACE 1.25 (Cardicare)',
	'Ramipril',
	'CAP',
	gm.nullify_empty_string('1.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HOPACE 1.25 (Cardicare)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HOPACE 2.5 (Cardicare)',
	'Ramipril',
	'CAP',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HOPACE 2.5 (Cardicare)'
);

-- line #28420
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HOPACE 5 (Cardicare)',
	'Ramipril',
	'CAP',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HOPACE 5 (Cardicare)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HOPACE 10 (Cardicare)',
	'Ramipril',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HOPACE 10 (Cardicare)'
);

-- line #28421
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HOPACE 10 (Cardicare)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HOPACE 10 (Cardicare)'
);

-- line #28422
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HOPECARD 1.25 (Aristo)',
	'Ramipril',
	'CAP',
	gm.nullify_empty_string('1.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HOPECARD 1.25 (Aristo)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HOPECARD 2.5 (Aristo)',
	'Ramipril',
	'CAP',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HOPECARD 2.5 (Aristo)'
);

-- line #28423
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HOPECARD 5 (Aristo)',
	'Ramipril',
	'CAP',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HOPECARD 5 (Aristo)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HOPECARD 10 (Aristo)',
	'Ramipril',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HOPECARD 10 (Aristo)'
);

-- line #28424
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KAMIPRIL-5 5 (Kamron)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KAMIPRIL-5 5 (Kamron)'
);

-- line #28425
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KAMIPRIL 2.5 (Kamron)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KAMIPRIL 2.5 (Kamron)'
);

-- line #28426
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KAPRIL 2.5 (Kapl)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KAPRIL 2.5 (Kapl)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KAPRIL 5 (Kapl)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KAPRIL 5 (Kapl)'
);

-- line #28427
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEPRY 1.25 (Cadex Lab)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('1.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEPRY 1.25 (Cadex Lab)'
);

-- line #28428
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEPRY 2.5 (Cadex Lab)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEPRY 2.5 (Cadex Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEPRY 5 (Cadex Lab)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEPRY 5 (Cadex Lab)'
);

-- line #28429
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACPRIL 1.25 (Macleods)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('1.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACPRIL 1.25 (Macleods)'
);

-- line #28430
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACPRIL 2.5 (Macleods)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACPRIL 2.5 (Macleods)'
);

-- line #28431
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACPRIL 5 (Macleods)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACPRIL 5 (Macleods)'
);

-- line #28432
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MISRY 1.25 (Biocin Hc.)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('1.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MISRY 1.25 (Biocin Hc.)'
);

-- line #28433
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MISRY 2.5 (Biocin Hc.)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MISRY 2.5 (Biocin Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MISRY 5 (Biocin Hc.)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MISRY 5 (Biocin Hc.)'
);

-- line #28434
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOVAPRIL 2.5 (MOVA PH.)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOVAPRIL 2.5 (MOVA PH.)'
);

-- line #28435
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOVAPRIL 5 (MOVA PH.)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOVAPRIL 5 (MOVA PH.)'
);

-- line #28436
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAMIPRIL 2.5 (NPIL)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAMIPRIL 2.5 (NPIL)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAMIPRIL 5 (NPIL)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAMIPRIL 5 (NPIL)'
);

-- line #28437
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODIPRIL 2.5 (Blue Cross)',
	'Ramipril',
	'CAP',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODIPRIL 2.5 (Blue Cross)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODIPRIL 5 (Blue Cross)',
	'Ramipril',
	'CAP',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODIPRIL 5 (Blue Cross)'
);

-- line #28438
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREFACE 2.5 (Centaur)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREFACE 2.5 (Centaur)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREFACE 5 (Centaur)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREFACE 5 (Centaur)'
);

-- line #28439
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRILACE 2.5 (Cipla)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRILACE 2.5 (Cipla)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRILACE 5 (Cipla)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRILACE 5 (Cipla)'
);

-- line #28440
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RACE 1.25 (Pentacare)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('1.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RACE 1.25 (Pentacare)'
);

-- line #28441
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RACE 2.5 (Pentacare)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RACE 2.5 (Pentacare)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RACE 5 (Pentacare)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RACE 5 (Pentacare)'
);

-- line #28442
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMACE 1.25 (Astrazeneca)',
	'Ramipril',
	'CAP',
	gm.nullify_empty_string('1.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMACE 1.25 (Astrazeneca)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMACE 2.5 (Astrazeneca)',
	'Ramipril',
	'CAP',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMACE 2.5 (Astrazeneca)'
);

-- line #28443
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMACE 5 (Astrazeneca)',
	'Ramipril',
	'CAP',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMACE 5 (Astrazeneca)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMACE 10 (Astrazeneca)',
	'Ramipril',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMACE 10 (Astrazeneca)'
);

-- line #28444
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMACE 10 (Astrazeneca)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMACE 10 (Astrazeneca)'
);

-- line #28445
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMACE 1.25 (Astrazeneca)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('1.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMACE 1.25 (Astrazeneca)'
);

-- line #28446
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMACE 2.5 (Astrazeneca)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMACE 2.5 (Astrazeneca)'
);

-- line #28447
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMACE 5 (Astrazeneca)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMACE 5 (Astrazeneca)'
);

-- line #28448
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMEY 1.25 (Zydus Cadila)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('1.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMEY 1.25 (Zydus Cadila)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMEY 2.5 (Zydus Cadila)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMEY 2.5 (Zydus Cadila)'
);

-- line #28449
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMEY 5 (Zydus Cadila)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMEY 5 (Zydus Cadila)'
);

-- line #28450
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMFIRST 10 (SINSAN PH.)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMFIRST 10 (SINSAN PH.)'
);

-- line #28451
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMFIRST 2.5 (SINSAN PH.)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMFIRST 2.5 (SINSAN PH.)'
);

-- line #28452
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMFIRST 5 (SINSAN PH.)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMFIRST 5 (SINSAN PH.)'
);

-- line #28453
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMICARD 1.25 (Intra Lab)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('1.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMICARD 1.25 (Intra Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMICARD 2.5 (Intra Lab)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMICARD 2.5 (Intra Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMICARD 5 (Intra Lab)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMICARD 5 (Intra Lab)'
);

-- line #28454
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMICARD 1.25 (Troikaa)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('1.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMICARD 1.25 (Troikaa)'
);

-- line #28455
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMICARD 2.5 (Troikaa)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMICARD 2.5 (Troikaa)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMICARD 5 (Troikaa)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMICARD 5 (Troikaa)'
);

-- line #28456
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMICHEK 1.25 (Indoco Rem.)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('1.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMICHEK 1.25 (Indoco Rem.)'
);

-- line #28457
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMICHEK 2.5 (Indoco Rem.)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMICHEK 2.5 (Indoco Rem.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMICHEK 5 (Indoco Rem.)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMICHEK 5 (Indoco Rem.)'
);

-- line #28458
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMIC 1.25 (D.R.John''S)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('1.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMIC 1.25 (D.R.John''S)'
);

-- line #28459
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMIC 2.5 (D.R.John''S)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMIC 2.5 (D.R.John''S)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMIC 5 (D.R.John''S)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMIC 5 (D.R.John''S)'
);

-- line #28460
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMICURE 2.5 (HBC LIFESCIENCE)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMICURE 2.5 (HBC LIFESCIENCE)'
);

-- line #28461
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMICURE 5 (HBC LIFESCIENCE)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMICURE 5 (HBC LIFESCIENCE)'
);

-- line #28462
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMIDIL 1.25 (Medley)',
	'Ramipril',
	'CAP',
	gm.nullify_empty_string('1.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMIDIL 1.25 (Medley)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMIDIL 2.5 (Medley)',
	'Ramipril',
	'CAP',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMIDIL 2.5 (Medley)'
);

-- line #28463
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMIDIL 5 (Medley)',
	'Ramipril',
	'CAP',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMIDIL 5 (Medley)'
);

-- line #28464
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMIFAST 2.5 (SIGNOVA)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMIFAST 2.5 (SIGNOVA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMIFAST 5 (SIGNOVA)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMIFAST 5 (SIGNOVA)'
);

-- line #28465
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMILACE 1.25 (SHRRISHTI HC.)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('1.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMILACE 1.25 (SHRRISHTI HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMILACE 2.5 (SHRRISHTI HC.)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMILACE 2.5 (SHRRISHTI HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMILACE 5 (SHRRISHTI HC.)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMILACE 5 (SHRRISHTI HC.)'
);

-- line #28466
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMIL 1.25 (Argus)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('1.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMIL 1.25 (Argus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMIL 2.5 (Argus)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMIL 2.5 (Argus)'
);

-- line #28467
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMIL 5 (Argus)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMIL 5 (Argus)'
);

-- line #28468
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMIPRES 1.25 (Cipla)',
	'Ramipril',
	'CAP',
	gm.nullify_empty_string('1.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMIPRES 1.25 (Cipla)'
);

-- line #28469
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMIPRES 2.5 (Cipla)',
	'Ramipril',
	'CAP',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMIPRES 2.5 (Cipla)'
);

-- line #28470
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMIPRES 5 (Cipla)',
	'Ramipril',
	'CAP',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMIPRES 5 (Cipla)'
);

-- line #28471
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMIPRESS 10 (Cipla)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMIPRESS 10 (Cipla)'
);

-- line #28472
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMIPRO 1.25 (Emcure)',
	'Ramipril',
	'CAP',
	gm.nullify_empty_string('1.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMIPRO 1.25 (Emcure)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMIPRO 2.5 (Emcure)',
	'Ramipril',
	'CAP',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMIPRO 2.5 (Emcure)'
);

-- line #28473
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMIPRO 5 (Emcure)',
	'Ramipril',
	'CAP',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMIPRO 5 (Emcure)'
);

-- line #28474
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMIRIL 10 (Micro Labs)',
	'Ramipril',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMIRIL 10 (Micro Labs)'
);

-- line #28475
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMIRIL 1.25 (Micro Labs)',
	'Ramipril',
	'CAP',
	gm.nullify_empty_string('1.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMIRIL 1.25 (Micro Labs)'
);

-- line #28476
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMIRIL 2.5 (Micro Labs)',
	'Ramipril',
	'CAP',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMIRIL 2.5 (Micro Labs)'
);

-- line #28477
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMIRIL 5 (Micro Labs)',
	'Ramipril',
	'CAP',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMIRIL 5 (Micro Labs)'
);

-- line #28478
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMISAVE 10 (ERIS LIFE)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMISAVE 10 (ERIS LIFE)'
);

-- line #28479
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMISAVE 2.5 (ERIS LIFE)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMISAVE 2.5 (ERIS LIFE)'
);

-- line #28480
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMISAVE 5 (ERIS LIFE)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMISAVE 5 (ERIS LIFE)'
);

-- line #28481
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMISTAR 1.25 (Lupin)',
	'Ramipril',
	'CAP',
	gm.nullify_empty_string('1.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMISTAR 1.25 (Lupin)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMISTAR 2.5 (Lupin)',
	'Ramipril',
	'CAP',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMISTAR 2.5 (Lupin)'
);

-- line #28482
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMISTAR 5 (Lupin)',
	'Ramipril',
	'CAP',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMISTAR 5 (Lupin)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMISTAR 10 (Lupin)',
	'Ramipril',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMISTAR 10 (Lupin)'
);

-- line #28483
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMI 5 (ELIKEM)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMI 5 (ELIKEM)'
);

-- line #28484
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMIVIK 2.5 (ANVIK BIO.)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMIVIK 2.5 (ANVIK BIO.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMIVIK 5 (ANVIK BIO.)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMIVIK 5 (ANVIK BIO.)'
);

-- line #28485
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMLAND 2.5 (L & V PH.)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMLAND 2.5 (L & V PH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMLAND 5 (L & V PH.)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMLAND 5 (L & V PH.)'
);

-- line #28486
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMM 2.5 (Finecure)',
	'Ramipril',
	'CAP',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMM 2.5 (Finecure)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMM 5 (Finecure)',
	'Ramipril',
	'CAP',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMM 5 (Finecure)'
);

-- line #28487
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMPRIL 1.25 (Themis Med.)',
	'Ramipril',
	'CAP',
	gm.nullify_empty_string('1.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMPRIL 1.25 (Themis Med.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMPRIL 2.5 (Themis Med.)',
	'Ramipril',
	'CAP',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMPRIL 2.5 (Themis Med.)'
);

-- line #28488
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMPRIL 5 (Themis Med.)',
	'Ramipril',
	'CAP',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMPRIL 5 (Themis Med.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMPRIL 10 (Themis Med.)',
	'Ramipril',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMPRIL 10 (Themis Med.)'
);

-- line #28489
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMSHO 1.25 (AAMORB(XEENA))',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('1.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMSHO 1.25 (AAMORB(XEENA))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMSHO 2.5 (AAMORB(XEENA))',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMSHO 2.5 (AAMORB(XEENA))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMSHO 5 (AAMORB(XEENA))',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMSHO 5 (AAMORB(XEENA))'
);

-- line #28490
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAM 2.5 (Riasma Life)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAM 2.5 (Riasma Life)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAM 5 (Riasma Life)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAM 5 (Riasma Life)'
);

-- line #28491
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMVAS 1.25 (Indi Ph.)',
	'Ramipril',
	'CAP',
	gm.nullify_empty_string('1.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMVAS 1.25 (Indi Ph.)'
);

-- line #28492
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMVAS 2.5 (Indi Ph.)',
	'Ramipril',
	'CAP',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMVAS 2.5 (Indi Ph.)'
);

-- line #28493
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMVAS 5 (Indi Ph.)',
	'Ramipril',
	'CAP',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMVAS 5 (Indi Ph.)'
);

-- line #28494
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10', u'strength_2': u'', u'substance': u'Ramipril', u'always_empty': u'', u'form': u'', u'brand': u'RAMY', u'strength_3': u'', u'company': u'Panacea', u'unit': u'mg'}

-- line #28495
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5', u'strength_2': u'', u'substance': u'Ramipril', u'always_empty': u'', u'form': u'', u'brand': u'RAMY', u'strength_3': u'', u'company': u'Panacea', u'unit': u'mg'}

-- line #28496
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMZE 2.5 (Zee Lab)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMZE 2.5 (Zee Lab)'
);

-- line #28497
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAXIPRIL 1.25 (Chemo Bio.)',
	'Ramipril',
	'CAP',
	gm.nullify_empty_string('1.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAXIPRIL 1.25 (Chemo Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAXIPRIL 2.5 (Chemo Bio.)',
	'Ramipril',
	'CAP',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAXIPRIL 2.5 (Chemo Bio.)'
);

-- line #28498
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAXIPRIL 5 (Chemo Bio.)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAXIPRIL 5 (Chemo Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAXIPRIL 10 (Chemo Bio.)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAXIPRIL 10 (Chemo Bio.)'
);

-- line #28499
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'R-CORD 2.5 (Intra(INVISION))',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'R-CORD 2.5 (Intra(INVISION))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'R-CORD 5 (Intra(INVISION))',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'R-CORD 5 (Intra(INVISION))'
);

-- line #28500
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REBEAT 10 (LA RENON)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REBEAT 10 (LA RENON)'
);

-- line #28501
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REBEAT 5 (LA RENON)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REBEAT 5 (LA RENON)'
);

-- line #28502
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REMBITZ-5 5 (BEATZ LIFESCI.)',
	'Ramipril',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REMBITZ-5 5 (BEATZ LIFESCI.)'
);

-- line #28503
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIL 1.25 (EAST WEST)',
	'Ramipril',
	'CAP',
	gm.nullify_empty_string('1.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIL 1.25 (EAST WEST)'
);

-- line #28504
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIL 2.5 (EAST WEST)',
	'Ramipril',
	'CAP',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIL 2.5 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIL 5 (EAST WEST)',
	'Ramipril',
	'CAP',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIL 5 (EAST WEST)'
);

-- line #28505
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IBSET 0.5 (ALIDAC CORZA)',
	'RAMOSETRON',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IBSET 0.5 (ALIDAC CORZA)'
);

-- line #28506
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOZIA 0.3 (ALIDAC CORZA)',
	'RAMOSETRON',
	'INJ',
	gm.nullify_empty_string('0.3')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOZIA 0.3 (ALIDAC CORZA)'
);

-- line #28507
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOZIA 0.1 (ALIDAC CORZA)',
	'RAMOSETRON',
	'TAB',
	gm.nullify_empty_string('0.1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOZIA 0.1 (ALIDAC CORZA)'
);

-- line #28508
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACIBLOC 150 (Marc Lab)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACIBLOC 150 (Marc Lab)'
);

-- line #28509
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACIBLOC 300 (Marc Lab)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACIBLOC 300 (Marc Lab)'
);

-- line #28510
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACI-DEJECT 25 (Indus)',
	'Ranitidine',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACI-DEJECT 25 (Indus)'
);

-- line #28511
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACIGO 50 (Pfiscar Ind.)',
	'Ranitidine',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACIGO 50 (Pfiscar Ind.)'
);

-- line #28512
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACILOC 25 (Cadila Ph.)',
	'Ranitidine',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACILOC 25 (Cadila Ph.)'
);

-- line #28513
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACILOC 150 (Cadila Ph.)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACILOC 150 (Cadila Ph.)'
);

-- line #28514
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACILOC 300 (Cadila Ph.)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACILOC 300 (Cadila Ph.)'
);

-- line #28515
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTIRAN 150 (Active Hc.)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTIRAN 150 (Active Hc.)'
);

-- line #28516
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADVENE 150 (ABBOTT)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADVENE 150 (ABBOTT)'
);

-- line #28517
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADVENE 300 (ABBOTT)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADVENE 300 (ABBOTT)'
);

-- line #28518
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPRODINE 150 (Remedies)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPRODINE 150 (Remedies)'
);

-- line #28519
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMITIDINE 150 (AIMCO PH.)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMITIDINE 150 (AIMCO PH.)'
);

-- line #28520
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANCID 150 (Pifer Ph.)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANCID 150 (Pifer Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANCID 300 (Pifer Ph.)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANCID 300 (Pifer Ph.)'
);

-- line #28521
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANTAC 25 (Zee Lab)',
	'Ranitidine',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANTAC 25 (Zee Lab)'
);

-- line #28522
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANTEC 25 (Zee Lab)',
	'Ranitidine',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANTEC 25 (Zee Lab)'
);

-- line #28523
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZTEC 25 (Ind-Swift)',
	'Ranitidine',
	'AMP/V',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZTEC 25 (Ind-Swift)'
);

-- line #28524
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZTEC 150 (Ind-Swift)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZTEC 150 (Ind-Swift)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZTEC 300 (Ind-Swift)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZTEC 300 (Ind-Swift)'
);

-- line #28525
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIDIN 150 (Mamta Ph.)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIDIN 150 (Mamta Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIDIN 300 (Mamta Ph.)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIDIN 300 (Mamta Ph.)'
);

-- line #28526
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONSEC 150 (Jagsonpal)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONSEC 150 (Jagsonpal)'
);

-- line #28527
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COTAC 25 (Dynamic)',
	'Ranitidine',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COTAC 25 (Dynamic)'
);

-- line #28528
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COTAC 150 (Dynamic)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COTAC 150 (Dynamic)'
);

-- line #28529
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DINITAC 25 (DIVINE LAB.)',
	'Ranitidine',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DINITAC 25 (DIVINE LAB.)'
);

-- line #28530
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIN 150 (Mapra)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIN 150 (Mapra)'
);

-- line #28531
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMELTIDINE 150 (Medico)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMELTIDINE 150 (Medico)'
);

-- line #28532
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMELTIDINE 300 (Medico)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMELTIDINE 300 (Medico)'
);

-- line #28533
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMTEC 25 (Sanjivani)',
	'Ranitidine',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMTEC 25 (Sanjivani)'
);

-- line #28534
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMTEC 150 (Emil Ph.)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMTEC 150 (Emil Ph.)'
);

-- line #28535
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENTAC 25 (Neon)',
	'Ranitidine',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENTAC 25 (Neon)'
);

-- line #28536
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GIRAN 150 (Astrazeneca)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GIRAN 150 (Astrazeneca)'
);

-- line #28537
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'H2A 150 (Drakt Int.)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'H2A 150 (Drakt Int.)'
);

-- line #28538
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'H2A 300 (Drakt Int.)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'H2A 300 (Drakt Int.)'
);

-- line #28539
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'H2LOC 25 (Torrent)',
	'Ranitidine',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'H2LOC 25 (Torrent)'
);

-- line #28540
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'H2LOC 150 (Torrent)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'H2LOC 150 (Torrent)'
);

-- line #28541
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'H2LOC 300 (Torrent)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'H2LOC 300 (Torrent)'
);

-- line #28542
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEALCER 150 (Medispan)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEALCER 150 (Medispan)'
);

-- line #28543
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Ranitidine', u'always_empty': u'', u'form': u'INJ', u'brand': u'HELKOSS', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #28544
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HELKOSS 150 (Lupin)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HELKOSS 150 (Lupin)'
);

-- line #28545
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HELKOSS 300 (Lupin)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HELKOSS 300 (Lupin)'
);

-- line #28546
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HISTAC EFF 150 (Ranbaxy)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HISTAC EFF 150 (Ranbaxy)'
);

-- line #28547
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HISTAC 50 (Ranbaxy)',
	'Ranitidine',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HISTAC 50 (Ranbaxy)'
);

-- line #28548
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HISTAC 150 (Ranbaxy)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HISTAC 150 (Ranbaxy)'
);

-- line #28549
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HISTAC 300 (Ranbaxy)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HISTAC 300 (Ranbaxy)'
);

-- line #28550
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTAC 50 (Dwd)',
	'Ranitidine',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTAC 50 (Dwd)'
);

-- line #28551
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTAC 150 (Dwd)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTAC 150 (Dwd)'
);

-- line #28552
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KAMTAC 25 (Kamron)',
	'Ranitidine',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KAMTAC 25 (Kamron)'
);

-- line #28553
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KAMTAC 150 (Kamron)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KAMTAC 150 (Kamron)'
);

-- line #28554
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KAMTAC 300 (Kamron)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KAMTAC 300 (Kamron)'
);

-- line #28555
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANTAC 25 (Laborate)',
	'Ranitidine',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANTAC 25 (Laborate)'
);

-- line #28556
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LANTAC 150 (Laborate)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LANTAC 150 (Laborate)'
);

-- line #28557
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYDIN 150 (HETERO HC.)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYDIN 150 (HETERO HC.)'
);

-- line #28558
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYDIN 300 (HETERO HC.)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYDIN 300 (HETERO HC.)'
);

-- line #28559
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOTAC 50 (Mano)',
	'Ranitidine',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOTAC 50 (Mano)'
);

-- line #28560
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOTAC 150 (Mano)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOTAC 150 (Mano)'
);

-- line #28561
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOTAC 300 (Mano)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOTAC 300 (Mano)'
);

-- line #28562
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOTAC 75 (Mano)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOTAC 75 (Mano)'
);

-- line #28563
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDITIN 25 (Intra Lab)',
	'Ranitidine',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDITIN 25 (Intra Lab)'
);

-- line #28564
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDITIN 150 (Intra Lab)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDITIN 150 (Intra Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDITIN 300 (Intra Lab)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDITIN 300 (Intra Lab)'
);

-- line #28565
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONORIN 150 (Novocare)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONORIN 150 (Novocare)'
);

-- line #28566
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONORIN 300 (Novocare)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONORIN 300 (Novocare)'
);

-- line #28567
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NILCER 150 (Khandelwal)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NILCER 150 (Khandelwal)'
);

-- line #28568
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NILCER 150 (Olcare)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NILCER 150 (Olcare)'
);

-- line #28569
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITIN 150 (Profic)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITIN 150 (Profic)'
);

-- line #28570
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITIN 300 (Profic)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITIN 300 (Profic)'
);

-- line #28571
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORITIN 50 (Ophthal R.)',
	'Ranitidine',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORITIN 50 (Ophthal R.)'
);

-- line #28572
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORITIN 150 (Ophthal R.)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORITIN 150 (Ophthal R.)'
);

-- line #28573
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OTAC 150 (Oshin Lab)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OTAC 150 (Oshin Lab)'
);

-- line #28574
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PELOC 25 (Shaimil)',
	'Ranitidine',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PELOC 25 (Shaimil)'
);

-- line #28575
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PELOC 150 (Shaimil)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PELOC 150 (Shaimil)'
);

-- line #28576
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PELOC 300 (Shaimil)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PELOC 300 (Shaimil)'
);

-- line #28577
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEPLOC 150 (Zydus Cadila(Mm))',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEPLOC 150 (Zydus Cadila(Mm))'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEPLOC 300 (Zydus Cadila(Mm))',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEPLOC 300 (Zydus Cadila(Mm))'
);

-- line #28578
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PURANTIN 150 (Elysium)',
	'Ranitidine',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PURANTIN 150 (Elysium)'
);

-- line #28579
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RANBRO 150 (Arbro Ph.)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RANBRO 150 (Arbro Ph.)'
);

-- line #28580
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RANCAFE 150 (Concept)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RANCAFE 150 (Concept)'
);

-- line #28581
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RANCAFE 300 (Concept)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RANCAFE 300 (Concept)'
);

-- line #28582
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RANCER 150 (Bal Ph.)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RANCER 150 (Bal Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RANCER 300 (Bal Ph.)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RANCER 300 (Bal Ph.)'
);

-- line #28583
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RANEE 150 (Finecure)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RANEE 150 (Finecure)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RANEE 300 (Finecure)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RANEE 300 (Finecure)'
);

-- line #28584
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RANIAL 150 (Albert D.)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RANIAL 150 (Albert D.)'
);

-- line #28585
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RANIAL 300 (Albert D.)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RANIAL 300 (Albert D.)'
);

-- line #28586
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RANICID 150 (AASTHA PH.)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RANICID 150 (AASTHA PH.)'
);

-- line #28587
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RANICOM 150 (Comed)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RANICOM 150 (Comed)'
);

-- line #28588
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RANICOM 300 (Comed)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RANICOM 300 (Comed)'
);

-- line #28589
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RANIGEN 150 (Antigen Hc.)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg(HCL.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RANIGEN 150 (Antigen Hc.)'
);

-- line #28590
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RANIGLO 50 (Global Med.)',
	'Ranitidine',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RANIGLO 50 (Global Med.)'
);

-- line #28591
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RANIGLO 150 (Global Med.)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RANIGLO 150 (Global Med.)'
);

-- line #28592
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RANILINK 150 (Lincoln)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RANILINK 150 (Lincoln)'
);

-- line #28593
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RANILINK 300 (Lincoln)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RANILINK 300 (Lincoln)'
);

-- line #28594
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RANINC 150 (Smiles Inc.)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RANINC 150 (Smiles Inc.)'
);

-- line #28595
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Ranitidine', u'always_empty': u'', u'form': u'INJ', u'brand': u'RANIS', u'strength_3': u'', u'company': u'Finesse Ph.', u'unit': u''}

-- line #28596
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RANISUN 150 (Sunij)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RANISUN 150 (Sunij)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RANISUN 300 (Sunij)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RANISUN 300 (Sunij)'
);

-- line #28597
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RANITIDINE 50 (Gsk)',
	'Ranitidine',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RANITIDINE 50 (Gsk)'
);

-- line #28598
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RANITIDINE 25 (Mankind)',
	'Ranitidine',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RANITIDINE 25 (Mankind)'
);

-- line #28599
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RANITIDINE 50 (Zydus A.)',
	'Ranitidine',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RANITIDINE 50 (Zydus A.)'
);

-- line #28600
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RANITIDINE 150 (Albert D.)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RANITIDINE 150 (Albert D.)'
);

-- line #28601
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RANITIDINE 300 (Albert D.)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RANITIDINE 300 (Albert D.)'
);

-- line #28602
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RANITIDINE 150 (Astrazeneca)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RANITIDINE 150 (Astrazeneca)'
);

-- line #28603
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RANITIN 50 (Torrent)',
	'Ranitidine',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RANITIN 50 (Torrent)'
);

-- line #28604
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RANITIN 150 (Torrent)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RANITIN 150 (Torrent)'
);

-- line #28605
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RANITIN 300 (Torrent)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RANITIN 300 (Torrent)'
);

-- line #28606
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RANITOL 150 (Mefro Ph.)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RANITOL 150 (Mefro Ph.)'
);

-- line #28607
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RANIT 150 (Hal)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RANIT 150 (Hal)'
);

-- line #28608
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RANITY 150 (BIOGEN PH.)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RANITY 150 (BIOGEN PH.)'
);

-- line #28609
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RANIVAR 25 (Zota Hc.)',
	'Ranitidine',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RANIVAR 25 (Zota Hc.)'
);

-- line #28610
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RANIWEL 150 (WELABLE PH.)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RANIWEL 150 (WELABLE PH.)'
);

-- line #28611
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RANIZAC 150 (Parenteral)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RANIZAC 150 (Parenteral)'
);

-- line #28612
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAN-MEX 150 (DR. MEXI LIFE)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAN-MEX 150 (DR. MEXI LIFE)'
);

-- line #28613
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RANNET 150 (P C INDIA)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RANNET 150 (P C INDIA)'
);

-- line #28614
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RANNET 300 (P C INDIA)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RANNET 300 (P C INDIA)'
);

-- line #28615
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RD-150 150 (Brawn Lab)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RD-150 150 (Brawn Lab)'
);

-- line #28616
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RD 50 (Brawn Lab)',
	'Ranitidine',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RD 50 (Brawn Lab)'
);

-- line #28617
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RDIN 150 (Helios Ph.)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RDIN 150 (Helios Ph.)'
);

-- line #28618
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RDIN 300 (Helios Ph.)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RDIN 300 (Helios Ph.)'
);

-- line #28619
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REDEN 150 (Medoz Ph.)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REDEN 150 (Medoz Ph.)'
);

-- line #28620
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REDEN 300 (Medoz Ph.)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REDEN 300 (Medoz Ph.)'
);

-- line #28621
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELITIN 150 (Reliance)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELITIN 150 (Reliance)'
);

-- line #28622
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELITIN 300 (Reliance)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELITIN 300 (Reliance)'
);

-- line #28623
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELTAC 300 (Reliance)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELTAC 300 (Reliance)'
);

-- line #28624
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELTAC 150 (Relish)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELTAC 150 (Relish)'
);

-- line #28625
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RENITAB 150 (Micro Labs)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg/300'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RENITAB 150 (Micro Labs)'
);

-- line #28626
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RETID 150 (Trio Rem.)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RETID 150 (Trio Rem.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RETID 300 (Trio Rem.)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RETID 300 (Trio Rem.)'
);

-- line #28627
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIDCER 25 (Gufic Bio.)',
	'Ranitidine',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIDCER 25 (Gufic Bio.)'
);

-- line #28628
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIDCER 150 (Gufic Bio.)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIDCER 150 (Gufic Bio.)'
);

-- line #28629
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIDCER 300 (Gufic Bio.)',
	'Ranitidine',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIDCER 300 (Gufic Bio.)'
);

-- line #28630
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RINTAC 25 (Nitin Ph.)',
	'Ranitidine',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RINTAC 25 (Nitin Ph.)'
);

-- line #28631
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Ranitidine', u'always_empty': u'', u'form': u'INJ', u'brand': u'RINTO', u'strength_3': u'', u'company': u'Sienna Form.', u'unit': u''}

-- line #28632
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAROZA 500 (Zydus)',
	'RANOLAZINE',
	'ER TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAROZA 500 (Zydus)'
);

-- line #28633
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARTINEX 500 (Micro)',
	'RANOLAZINE',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg S.R.'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARTINEX 500 (Micro)'
);

-- line #28634
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORVELA 500 (Cipla)',
	'RANOLAZINE',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORVELA 500 (Cipla)'
);

-- line #28635
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RANCAD 500 (Lupin)',
	'RANOLAZINE',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RANCAD 500 (Lupin)'
);

-- line #28636
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RANDEAR 1000 (Alkem)',
	'RANOLAZINE',
	'TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RANDEAR 1000 (Alkem)'
);

-- line #28637
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RANDEAR 500 (Alkem)',
	'RANOLAZINE',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RANDEAR 500 (Alkem)'
);

-- line #28638
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RANEX 500 (Cadila Hc.)',
	'RANOLAZINE',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RANEX 500 (Cadila Hc.)'
);

-- line #28639
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RANOLAZ 1000 (Torrent)',
	'RANOLAZINE',
	'OD TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RANOLAZ 1000 (Torrent)'
);

-- line #28640
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RANOLAZ 500 (Torrent)',
	'RANOLAZINE',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RANOLAZ 500 (Torrent)'
);

-- line #28641
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REVULANT 1000 (Ranbaxy)',
	'RANOLAZINE',
	'TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REVULANT 1000 (Ranbaxy)'
);

-- line #28642
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REVULANT 500 (Ranbaxy)',
	'RANOLAZINE',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REVULANT 500 (Ranbaxy)'
);

-- line #28643
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,5', u'strength_2': u'', u'substance': u'RASAGILINE MESYLATE', u'always_empty': u'', u'form': u'', u'brand': u'RASALECT', u'strength_3': u'', u'company': u'Sun', u'unit': u'mg'}

-- line #28644
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1', u'strength_2': u'', u'substance': u'RASAGILINE MESYLATE', u'always_empty': u'', u'form': u'', u'brand': u'RASALECT', u'strength_3': u'', u'company': u'Sun', u'unit': u'mg'}

-- line #28645
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUCOPIDE 100 (ALMIRON)',
	'REBAMIPIDE',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUCOPIDE 100 (ALMIRON)'
);

-- line #28646
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REBATOR 100 (Torrent)',
	'REBAMIPIDE',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REBATOR 100 (Torrent)'
);

-- line #28647
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAREBOX 2 (Zydus N.S.)',
	'Reboxetine',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAREBOX 2 (Zydus N.S.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAREBOX 4 (Zydus N.S.)',
	'Reboxetine',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAREBOX 4 (Zydus N.S.)'
);

-- line #28648
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REBOOT 2 (NICHOLAS)',
	'Reboxetine',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REBOOT 2 (NICHOLAS)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REBOOT 4 (NICHOLAS)',
	'Reboxetine',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REBOOT 4 (NICHOLAS)'
);

-- line #28649
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REBOTIN 2 (Intas)',
	'Reboxetine',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REBOTIN 2 (Intas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REBOTIN 4 (Intas)',
	'Reboxetine',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REBOTIN 4 (Intas)'
);

-- line #28650
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REBOXXIN 2 (Merind)',
	'REBOXETINE',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REBOXXIN 2 (Merind)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REBOXXIN 4 (Merind)',
	'REBOXETINE',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REBOXXIN 4 (Merind)'
);

-- line #28651
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2000IU', u'strength_2': u'ML', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'', u'brand': u'ANFOE IU', u'strength_3': u'', u'company': u'LA RENON', u'unit': u''}

-- line #28652
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'4000IU.', u'strength_2': u'ML', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'', u'brand': u'ANFOE IU', u'strength_3': u'', u'company': u'LA RENON', u'unit': u''}

-- line #28653
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2000IU', u'strength_2': u'', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'', u'brand': u'CARDICRIT IU', u'strength_3': u'', u'company': u'ONCOCARE', u'unit': u''}

-- line #28654
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10000IU.', u'strength_2': u'', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'INJ', u'brand': u'CERITON', u'strength_3': u'', u'company': u'Ranbaxy', u'unit': u''}

-- line #28655
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2000IU.', u'strength_2': u'', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'INJ', u'brand': u'CERITON', u'strength_3': u'', u'company': u'Ranbaxy', u'unit': u''}

-- line #28656
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3000IU.', u'strength_2': u'', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'INJ', u'brand': u'CERITON', u'strength_3': u'', u'company': u'Ranbaxy', u'unit': u''}

-- line #28657
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'4000IU.', u'strength_2': u'', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'INJ', u'brand': u'CERITON', u'strength_3': u'', u'company': u'Ranbaxy', u'unit': u''}

-- line #28658
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2000IU.(AS ACTIVE INGREDIENT AND HUMAN SERUM ALBUMIN SODIUM CITRATE', u'strength_2': u'', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'', u'brand': u'EPOCEPT IU', u'strength_3': u'', u'company': u'Lupin', u'unit': u'SODIUM CHLORIDE & CITRIC ACID)'}

-- line #28659
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'42000IU.(AS ACTIVE INGREDIENT AND HUMAN SERUM ALBUMIN SODIUM CITRATE', u'strength_2': u'', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'', u'brand': u'EPOCEPT IU', u'strength_3': u'', u'company': u'Lupin', u'unit': u'SODIUM CHLORIDE & CITRIC ACID)'}

-- line #28660
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10000IU.', u'strength_2': u'', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'', u'brand': u'EPOFAITH IU', u'strength_3': u'', u'company': u'Ipca', u'unit': u''}

-- line #28661
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2000IU.', u'strength_2': u'', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'', u'brand': u'EPOFAITH IU', u'strength_3': u'', u'company': u'Ipca', u'unit': u''}

-- line #28662
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'4000IU.', u'strength_2': u'', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'', u'brand': u'EPOFAITH IU', u'strength_3': u'', u'company': u'Ipca', u'unit': u''}

-- line #28663
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'6000IU.', u'strength_2': u'', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'', u'brand': u'EPOFAITH IU', u'strength_3': u'', u'company': u'Ipca', u'unit': u''}

-- line #28664
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2000IU.', u'strength_2': u'', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'INJ', u'brand': u'EPOFER', u'strength_3': u'', u'company': u'Emcure', u'unit': u''}

-- line #28665
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3000IU.', u'strength_2': u'', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'INJ', u'brand': u'EPOFER', u'strength_3': u'', u'company': u'Emcure', u'unit': u''}

-- line #28666
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'4000IU.', u'strength_2': u'', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'INJ', u'brand': u'EPOFER', u'strength_3': u'', u'company': u'Emcure', u'unit': u''}

-- line #28667
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'6000IU.', u'strength_2': u'', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'INJ', u'brand': u'EPOFER', u'strength_3': u'', u'company': u'Emcure', u'unit': u''}

-- line #28668
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10000IU.', u'strength_2': u'', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'INJ', u'brand': u'EPOFIT', u'strength_3': u'', u'company': u'Intas', u'unit': u''}

-- line #28669
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3000IU.', u'strength_2': u'', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'INJ', u'brand': u'EPOFIT', u'strength_3': u'', u'company': u'Intas', u'unit': u''}

-- line #28670
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'6000IU.', u'strength_2': u'', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'INJ', u'brand': u'EPOFIT', u'strength_3': u'', u'company': u'Intas', u'unit': u''}

-- line #28671
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'', u'brand': u'EPONIS-K PFS', u'strength_3': u'', u'company': u'NEISS', u'unit': u''}

-- line #28672
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2000IU.', u'strength_2': u'', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'INJ', u'brand': u'EPORISE', u'strength_3': u'', u'company': u'Zuventus', u'unit': u''}

-- line #28673
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3000IU.', u'strength_2': u'', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'INJ', u'brand': u'EPORISE', u'strength_3': u'', u'company': u'Zuventus', u'unit': u''}

-- line #28674
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'4000IU', u'strength_2': u'', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'INJ', u'brand': u'EPORISE', u'strength_3': u'', u'company': u'Zuventus', u'unit': u''}

-- line #28675
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10000IU.', u'strength_2': u'', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'VIAL', u'brand': u'EPOSIS', u'strength_3': u'', u'company': u'Micro Labs', u'unit': u''}

-- line #28676
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2000IU.', u'strength_2': u'', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'VIAL', u'brand': u'EPOSIS', u'strength_3': u'', u'company': u'Micro Labs', u'unit': u''}

-- line #28677
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'4000IU.', u'strength_2': u'', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'VIAL', u'brand': u'EPOSIS', u'strength_3': u'', u'company': u'Micro Labs', u'unit': u''}

-- line #28678
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2000IU.', u'strength_2': u'', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'INJ', u'brand': u'EPOSURE', u'strength_3': u'', u'company': u'Gland Ph.', u'unit': u''}

-- line #28679
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'4000IU.', u'strength_2': u'', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'INJ', u'brand': u'EPOSURE', u'strength_3': u'', u'company': u'Gland Ph.', u'unit': u''}

-- line #28680
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2000', u'strength_2': u'4000;I.U.', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'', u'brand': u'EPOTIN PFS', u'strength_3': u'ML', u'company': u'Claris L.', u'unit': u''}

-- line #28681
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10000IU.', u'strength_2': u'', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'INJ', u'brand': u'EPOTRUST', u'strength_3': u'', u'company': u'Panacea', u'unit': u''}

-- line #28682
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2000IU.', u'strength_2': u'', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'INJ', u'brand': u'EPOTRUST', u'strength_3': u'', u'company': u'Panacea', u'unit': u''}

-- line #28683
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3000IU.', u'strength_2': u'', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'INJ', u'brand': u'EPOTRUST', u'strength_3': u'', u'company': u'Panacea', u'unit': u''}

-- line #28684
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'4000IU.', u'strength_2': u'', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'INJ', u'brand': u'EPOTRUST', u'strength_3': u'', u'company': u'Panacea', u'unit': u''}

-- line #28685
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2000U', u'strength_2': u'ML', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'INJ', u'brand': u'EPOVIN IU', u'strength_3': u'', u'company': u'BIORELM', u'unit': u''}

-- line #28686
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'4000U', u'strength_2': u'ML', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'INJ', u'brand': u'EPOVIN IU', u'strength_3': u'', u'company': u'BIORELM', u'unit': u''}

-- line #28687
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2000U', u'strength_2': u'ML', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'INJ', u'brand': u'EPOX', u'strength_3': u'', u'company': u'Wockhardt', u'unit': u''}

-- line #28688
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'4000U', u'strength_2': u'ML', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'INJ', u'brand': u'EPOX', u'strength_3': u'', u'company': u'Wockhardt', u'unit': u''}

-- line #28689
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10000IU.', u'strength_2': u'ML', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'INJ', u'brand': u'EPREX', u'strength_3': u'', u'company': u'Ethnor', u'unit': u''}

-- line #28690
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000IU.', u'strength_2': u'', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'INJ', u'brand': u'EPREX', u'strength_3': u'', u'company': u'Ethnor', u'unit': u''}

-- line #28691
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2000IU.', u'strength_2': u'5ML', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'INJ', u'brand': u'EPREX', u'strength_3': u'', u'company': u'Ethnor', u'unit': u''}

-- line #28692
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3000IU.', u'strength_2': u'3ML', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'INJ', u'brand': u'EPREX', u'strength_3': u'', u'company': u'Ethnor', u'unit': u''}

-- line #28693
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'4000U.', u'strength_2': u'4ML', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'INJ', u'brand': u'EPREX', u'strength_3': u'', u'company': u'Ethnor', u'unit': u''}

-- line #28694
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40000IU', u'strength_2': u'ML', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'', u'brand': u'EPREX PFS', u'strength_3': u'', u'company': u'J & J DeChane', u'unit': u''}

-- line #28695
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'6000IU', u'strength_2': u'0.6ML', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'', u'brand': u'EPREX PFS', u'strength_3': u'', u'company': u'J & J DeChane', u'unit': u''}

-- line #28696
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10000U', u'strength_2': u'ML', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'VIAL', u'brand': u'ERYPRO IU', u'strength_3': u'', u'company': u'Biocon', u'unit': u''}

-- line #28697
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2000U', u'strength_2': u'ML', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'VIAL', u'brand': u'ERYPRO IU', u'strength_3': u'', u'company': u'Biocon', u'unit': u''}

-- line #28698
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'4000U', u'strength_2': u'ML', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'VIAL', u'brand': u'ERYPRO IU', u'strength_3': u'', u'company': u'Biocon', u'unit': u''}

-- line #28699
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10000IU.', u'strength_2': u'', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'INJ', u'brand': u'ERYPRO SAFE ,000 IU', u'strength_3': u'', u'company': u'BIOCON LTD.', u'unit': u''}

-- line #28700
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2000IU.', u'strength_2': u'', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'INJ', u'brand': u'ERYPRO SAFE IU', u'strength_3': u'', u'company': u'BIOCON LTD.', u'unit': u''}

-- line #28701
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3000IU.', u'strength_2': u'', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'INJ', u'brand': u'ERYPRO SAFE IU', u'strength_3': u'', u'company': u'BIOCON LTD.', u'unit': u''}

-- line #28702
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'4000IU.', u'strength_2': u'ML', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'INJ', u'brand': u'ERYPRO SAFE IU', u'strength_3': u'', u'company': u'BIOCON LTD.', u'unit': u''}

-- line #28703
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5000IU.', u'strength_2': u'', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'INJ', u'brand': u'ERYPRO SAFE IU', u'strength_3': u'', u'company': u'BIOCON LTD.', u'unit': u''}

-- line #28704
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'6000IU.', u'strength_2': u'', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'INJ', u'brand': u'ERYPRO SAFE IU', u'strength_3': u'', u'company': u'BIOCON LTD.', u'unit': u''}

-- line #28705
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2000IU.', u'strength_2': u'', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'INJ', u'brand': u'HEMAX IU', u'strength_3': u'', u'company': u'Hal', u'unit': u''}

-- line #28706
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'4000IU.', u'strength_2': u'', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'INJ', u'brand': u'HEMAX IU', u'strength_3': u'', u'company': u'Hal', u'unit': u''}

-- line #28707
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10000IU', u'strength_2': u'', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'V', u'brand': u'LG ESPOGEN', u'strength_3': u'', u'company': u'Lglsi', u'unit': u''}

-- line #28708
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20000IU', u'strength_2': u'', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'V', u'brand': u'LG ESPOGEN', u'strength_3': u'', u'company': u'Lglsi', u'unit': u''}

-- line #28709
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2000IU', u'strength_2': u'', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'V', u'brand': u'LG ESPOGEN', u'strength_3': u'', u'company': u'Lglsi', u'unit': u''}

-- line #28710
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3000IU', u'strength_2': u'', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'V', u'brand': u'LG ESPOGEN', u'strength_3': u'', u'company': u'Lglsi', u'unit': u''}

-- line #28711
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'4000IU', u'strength_2': u'', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'V', u'brand': u'LG ESPOGEN', u'strength_3': u'', u'company': u'Lglsi', u'unit': u''}

-- line #28712
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10000IU.', u'strength_2': u'', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'INJ', u'brand': u'RELIPOIETIN', u'strength_3': u'', u'company': u'RELIANCE BIO.', u'unit': u''}

-- line #28713
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2000IU.', u'strength_2': u'', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'INJ', u'brand': u'RELIPOIETIN', u'strength_3': u'', u'company': u'RELIANCE BIO.', u'unit': u''}

-- line #28714
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3000IU.', u'strength_2': u'', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'INJ', u'brand': u'RELIPOIETIN', u'strength_3': u'', u'company': u'RELIANCE BIO.', u'unit': u''}

-- line #28715
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40000IU.', u'strength_2': u'', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'INJ', u'brand': u'RELIPOIETIN', u'strength_3': u'', u'company': u'RELIANCE BIO.', u'unit': u''}

-- line #28716
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'4000IU', u'strength_2': u'', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'INJ', u'brand': u'RELIPOIETIN', u'strength_3': u'', u'company': u'RELIANCE BIO.', u'unit': u''}

-- line #28717
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'6000IU.', u'strength_2': u'', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'INJ', u'brand': u'RELIPOIETIN', u'strength_3': u'', u'company': u'RELIANCE BIO.', u'unit': u''}

-- line #28718
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2000IU.', u'strength_2': u'', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'INJ', u'brand': u'REPOITIN IU', u'strength_3': u'', u'company': u'Serum Inst.', u'unit': u''}

-- line #28719
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'4000IU.', u'strength_2': u'', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'INJ', u'brand': u'REPOITIN IU', u'strength_3': u'', u'company': u'Serum Inst.', u'unit': u''}

-- line #28720
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10000IU.', u'strength_2': u'', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'INJ', u'brand': u'REPOMAX IU', u'strength_3': u'', u'company': u'Dabur Ph.', u'unit': u''}

-- line #28721
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40000IU.', u'strength_2': u'', u'substance': u'Recombinant Human Erythropoietin', u'always_empty': u'', u'form': u'INJ', u'brand': u'REPOMAX IU', u'strength_3': u'', u'company': u'Dabur Ph.', u'unit': u''}

-- line #28722
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'18MILL.IU', u'strength_2': u'ML', u'substance': u'Recombinant Human INTERLEUKIN 2', u'always_empty': u'', u'form': u'INJ', u'brand': u'RECIL', u'strength_3': u'', u'company': u'Ranbaxy S.Sp.', u'unit': u''}

-- line #28723
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELAXIM 30 (Emcure)',
	'RECOMBINANT TISSUE PLASMINOGEN ACTIVATOR (TNK-T-PA)',
	'INJ',
	gm.nullify_empty_string('30')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELAXIM 30 (Emcure)'
);

-- line #28724
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELAXIM 40 (Emcure)',
	'RECOMBINANT TISSUE PLASMINOGEN ACTIVATOR (TNK-T-PA)',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELAXIM 40 (Emcure)'
);

-- line #28725
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELAXIM 50 (Emcure)',
	'RECOMBINANT TISSUE PLASMINOGEN ACTIVATOR (TNK-T-PA)',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg (52.5'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELAXIM 50 (Emcure)'
);

-- line #28726
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUREPA 0.5 (Torrent)',
	'Repaglinide',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUREPA 0.5 (Torrent)'
);

-- line #28727
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUREPA 1 (Torrent)',
	'Repaglinide',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUREPA 1 (Torrent)'
);

-- line #28728
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUREPA 2 (Torrent)',
	'Repaglinide',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUREPA 2 (Torrent)'
);

-- line #28729
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAPILIN 0.5 (Sun)',
	'Repaglinide',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAPILIN 0.5 (Sun)'
);

-- line #28730
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAPILIN 1 (Sun)',
	'Repaglinide',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAPILIN 1 (Sun)'
);

-- line #28731
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAPILIN 2 (Sun)',
	'Repaglinide',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAPILIN 2 (Sun)'
);

-- line #28732
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REGAN 0.5 (Stancare)',
	'Repaglinide',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REGAN 0.5 (Stancare)'
);

-- line #28733
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REGAN 1 (Stancare)',
	'Repaglinide',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REGAN 1 (Stancare)'
);

-- line #28734
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REGAN 2 (Stancare)',
	'Repaglinide',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REGAN 2 (Stancare)'
);

-- line #28735
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REPA 0.5 (Mano Ph.)',
	'Repaglinide',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REPA 0.5 (Mano Ph.)'
);

-- line #28736
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REPA 1 (Mano Ph.)',
	'Repaglinide',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REPA 1 (Mano Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REPA 2 (Mano Ph.)',
	'Repaglinide',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REPA 2 (Mano Ph.)'
);

-- line #28737
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REPIDE 0.5 (Wallace)',
	'Repaglinide',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REPIDE 0.5 (Wallace)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REPIDE 1 (Wallace)',
	'Repaglinide',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REPIDE 1 (Wallace)'
);

-- line #28738
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESTRICT 0.5 (EAST WEST)',
	'Repaglinide',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESTRICT 0.5 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESTRICT 1 (EAST WEST)',
	'Repaglinide',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESTRICT 1 (EAST WEST)'
);

-- line #28739
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESTRICT 2 (EAST WEST)',
	'Repaglinide',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESTRICT 2 (EAST WEST)'
);

-- line #28740
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RASIPAR 0.5 (Ajanta Ph.)',
	'RESAGILINE',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RASIPAR 0.5 (Ajanta Ph.)'
);

-- line #28741
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RASIPAR 1 (VERIZON)',
	'RESAGILINE',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RASIPAR 1 (VERIZON)'
);

-- line #28742
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10', u'strength_2': u'', u'substance': u'RETAPAMULIN', u'always_empty': u'', u'form': u'', u'brand': u'RETAREL', u'strength_3': u'', u'company': u'Ajanta Ph.', u'unit': u'mg'}

-- line #28743
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500IU.', u'strength_2': u'G', u'substance': u'RETINOL', u'always_empty': u'', u'form': u'LOT', u'brand': u'LIPOLOTION', u'strength_3': u'', u'company': u'Elder', u'unit': u''}

-- line #28744
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1432IU', u'strength_2': u'', u'substance': u'REVIPARIN SODIUM', u'always_empty': u'', u'form': u'INJ', u'brand': u'CLIVARINE', u'strength_3': u'', u'company': u'ABBOTT', u'unit': u''}

-- line #28745
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'REVIPARIN SODIUM', u'always_empty': u'', u'form': u'VIAL', u'brand': u'CLIVARINE MDV', u'strength_3': u'', u'company': u'ABBOTT', u'unit': u''}

-- line #28746
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3436IU', u'strength_2': u'', u'substance': u'REVIPARIN SODIUM', u'always_empty': u'', u'form': u'', u'brand': u'CLIVARINE PFS', u'strength_3': u'', u'company': u'ABBOTT', u'unit': u''}

-- line #28747
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'REVOLIZER', u'always_empty': u'', u'form': u'', u'brand': u'REVOLIZER', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #28748
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REBETOL 200 (Fulford)',
	'Ribavirin',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REBETOL 200 (Fulford)'
);

-- line #28749
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIBAMAC 200 (Mcneil & A.)',
	'Ribavirin',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIBAMAC 200 (Mcneil & A.)'
);

-- line #28750
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIBAVIN 100 (Lupin)',
	'Ribavirin',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIBAVIN 100 (Lupin)'
);

-- line #28751
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIBAVIN 200 (Lupin)',
	'Ribavirin',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIBAVIN 200 (Lupin)'
);

-- line #28752
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIBAVIN 50 (Lupin)',
	'Ribavirin',
	'SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIBAVIN 50 (Lupin)'
);

-- line #28753
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPABOL 20 (Zydus Cadila)',
	'Riboflavin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPABOL 20 (Zydus Cadila)'
);

-- line #28754
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMBRAN 250 (Elder)',
	'RICEDRAN COMPOUND',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMBRAN 250 (Elder)'
);

-- line #28755
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACBUTIN 150 (Macleods)',
	'RIFABUTIN',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACBUTIN 150 (Macleods)'
);

-- line #28756
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIBUTIN 150 (Lupin)',
	'RIFABUTIN',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIBUTIN 150 (Lupin)'
);

-- line #28757
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'A-COX 450 (Acme Ph)',
	'Rifampicin',
	'TAB',
	gm.nullify_empty_string('450')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'A-COX 450 (Acme Ph)'
);

-- line #28758
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAVIDIN 450 (Merind)',
	'Rifampicin',
	'TAB',
	gm.nullify_empty_string('450')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAVIDIN 450 (Merind)'
);

-- line #28759
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAVIDIN 600 (Merind)',
	'Rifampicin',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAVIDIN 600 (Merind)'
);

-- line #28760
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAVIKID 50 (Merind)',
	'Rifampicin',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAVIKID 50 (Merind)'
);

-- line #28761
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COXID 450 (Aristo)',
	'Rifampicin',
	'CAP',
	gm.nullify_empty_string('450')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COXID 450 (Aristo)'
);

-- line #28762
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COXYWIN 450 (Jaywin)',
	'Rifampicin',
	'CAP',
	gm.nullify_empty_string('450')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COXYWIN 450 (Jaywin)'
);

-- line #28763
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DENEX 450 (Alde Medi.)',
	'Rifampicin',
	'CAP',
	gm.nullify_empty_string('450')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DENEX 450 (Alde Medi.)'
);

-- line #28764
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUFACIN 150 (Euphoric)',
	'Rifampicin',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUFACIN 150 (Euphoric)'
);

-- line #28765
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUFACIN 300 (Euphoric)',
	'Rifampicin',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUFACIN 300 (Euphoric)'
);

-- line #28766
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUFACIN 450 (Euphoric)',
	'Rifampicin',
	'CAP',
	gm.nullify_empty_string('450')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUFACIN 450 (Euphoric)'
);

-- line #28767
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAMCIN 150 (Idpl)',
	'Rifampicin',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAMCIN 150 (Idpl)'
);

-- line #28768
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAMCIN 300 (Idpl)',
	'Rifampicin',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAMCIN 300 (Idpl)'
);

-- line #28769
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAMCIN 450 (Idpl)',
	'Rifampicin',
	'CAP',
	gm.nullify_empty_string('450')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAMCIN 450 (Idpl)'
);

-- line #28770
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAMCIN 600 (Idpl)',
	'Rifampicin',
	'CAP',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAMCIN 600 (Idpl)'
);

-- line #28771
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAMICOX 450 (Lark Lab)',
	'Rifampicin',
	'CAP',
	gm.nullify_empty_string('450')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAMICOX 450 (Lark Lab)'
);

-- line #28772
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAMICOX 600 (Lark Lab)',
	'Rifampicin',
	'CAP',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAMICOX 600 (Lark Lab)'
);

-- line #28773
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GOCOX 300 (Ipca)',
	'Rifampicin',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GOCOX 300 (Ipca)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GOCOX 450 (Ipca)',
	'Rifampicin',
	'CAP',
	gm.nullify_empty_string('450')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GOCOX 450 (Ipca)'
);

-- line #28774
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEMORIFA 450 (Chemo D.)',
	'Rifampicin',
	'TAB',
	gm.nullify_empty_string('450')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEMORIFA 450 (Chemo D.)'
);

-- line #28775
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSITRIL 150 (Hal)',
	'Rifampicin',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSITRIL 150 (Hal)'
);

-- line #28776
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSITRIL 300 (Hal)',
	'Rifampicin',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSITRIL 300 (Hal)'
);

-- line #28777
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOSITRIL 450 (Hal)',
	'Rifampicin',
	'CAP',
	gm.nullify_empty_string('450')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOSITRIL 450 (Hal)'
);

-- line #28778
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LS RIF 450 (Le Sante)',
	'Rifampicin',
	'CAP',
	gm.nullify_empty_string('450')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LS RIF 450 (Le Sante)'
);

-- line #28779
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LS RIF 600 (Le Sante)',
	'Rifampicin',
	'CAP',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LS RIF 600 (Le Sante)'
);

-- line #28780
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACOX 300 (Macleods)',
	'Rifampicin',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACOX 300 (Macleods)'
);

-- line #28781
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACOX 450 (Macleods)',
	'Rifampicin',
	'CAP',
	gm.nullify_empty_string('450')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACOX 450 (Macleods)'
);

-- line #28782
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACOX 600 (Macleods)',
	'Rifampicin',
	'CAP',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACOX 600 (Macleods)'
);

-- line #28783
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACOX 100 (Macleods)',
	'Rifampicin',
	'DT',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACOX 100 (Macleods)'
);

-- line #28784
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOCIN 300 (Overseas Hc.)',
	'Rifampicin',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOCIN 300 (Overseas Hc.)'
);

-- line #28785
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOCIN 450 (Overseas Hc.)',
	'Rifampicin',
	'TAB',
	gm.nullify_empty_string('450')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOCIN 450 (Overseas Hc.)'
);

-- line #28786
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONOCIN 600 (Overseas Hc.)',
	'Rifampicin',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONOCIN 600 (Overseas Hc.)'
);

-- line #28787
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MONTOMYCIN 450 (Shreya)',
	'Rifampicin',
	'CAP',
	gm.nullify_empty_string('450')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MONTOMYCIN 450 (Shreya)'
);

-- line #28788
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMCIN 450 (Maneesh)',
	'Rifampicin',
	'TAB',
	gm.nullify_empty_string('450')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMCIN 450 (Maneesh)'
);

-- line #28789
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'R-CIN 150 (Lupin)',
	'Rifampicin',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'R-CIN 150 (Lupin)'
);

-- line #28790
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'R-CIN 300 (Lupin)',
	'Rifampicin',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'R-CIN 300 (Lupin)'
);

-- line #28791
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'R-CIN 450 (Lupin)',
	'Rifampicin',
	'CAP',
	gm.nullify_empty_string('450')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'R-CIN 450 (Lupin)'
);

-- line #28792
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'R-CIN 600 (Lupin)',
	'Rifampicin',
	'CAP',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'R-CIN 600 (Lupin)'
);

-- line #28793
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'R-CIN 100 (Lupin)',
	'Rifampicin',
	'SUS',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'R-CIN 100 (Lupin)'
);

-- line #28794
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'R-CIN 200 (Lupin)',
	'Rifampicin',
	'SUS',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'R-CIN 200 (Lupin)'
);

-- line #28795
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RICOX-450 450 (Aquila)',
	'Rifampicin',
	'TAB',
	gm.nullify_empty_string('450')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RICOX-450 450 (Aquila)'
);

-- line #28796
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIFACEPT 450 (Concept)',
	'Rifampicin',
	'CAP',
	gm.nullify_empty_string('450')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIFACEPT 450 (Concept)'
);

-- line #28797
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIFACEPT 600 (Concept)',
	'Rifampicin',
	'CAP',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIFACEPT 600 (Concept)'
);

-- line #28798
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIFACILIN 150 (P C INDIA)',
	'Rifampicin',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIFACILIN 150 (P C INDIA)'
);

-- line #28799
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIFACILIN 300 (P C INDIA)',
	'Rifampicin',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIFACILIN 300 (P C INDIA)'
);

-- line #28800
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIFACILIN 450 (P C INDIA)',
	'Rifampicin',
	'CAP',
	gm.nullify_empty_string('450')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIFACILIN 450 (P C INDIA)'
);

-- line #28801
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIFALONE 450 (Medispan)',
	'Rifampicin',
	'CAP',
	gm.nullify_empty_string('450')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIFALONE 450 (Medispan)'
);

-- line #28802
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIFAMINAL 150 (N.A.)',
	'Rifampicin',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIFAMINAL 150 (N.A.)'
);

-- line #28803
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIFAMINAL 300 (N.A.)',
	'Rifampicin',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIFAMINAL 300 (N.A.)'
);

-- line #28804
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIFAMINAL 450 (N.A.)',
	'Rifampicin',
	'CAP',
	gm.nullify_empty_string('450')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIFAMINAL 450 (N.A.)'
);

-- line #28805
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Rifampicin', u'always_empty': u'', u'form': u'TAB', u'brand': u'RIFAMINAL-F', u'strength_3': u'', u'company': u'N.A.', u'unit': u''}

-- line #28806
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIFAMPILA 150 (Albert D.)',
	'Rifampicin',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIFAMPILA 150 (Albert D.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIFAMPILA 300 (Albert D.)',
	'Rifampicin',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIFAMPILA 300 (Albert D.)'
);

-- line #28807
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIFAMPILA 450 (Albert D.)',
	'Rifampicin',
	'CAP',
	gm.nullify_empty_string('450')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIFAMPILA 450 (Albert D.)'
);

-- line #28808
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIFAMYCIN 450 (Biochem)',
	'Rifampicin',
	'CAP',
	gm.nullify_empty_string('450')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIFAMYCIN 450 (Biochem)'
);

-- line #28809
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIFAPLUS 150 (Radicura)',
	'Rifampicin',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIFAPLUS 150 (Radicura)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIFAPLUS 300 (Radicura)',
	'Rifampicin',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIFAPLUS 300 (Radicura)'
);

-- line #28810
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIFAPLUS 450 (Radicura)',
	'Rifampicin',
	'CAP',
	gm.nullify_empty_string('450')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIFAPLUS 450 (Radicura)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIFAPLUS 600 (Radicura)',
	'Rifampicin',
	'CAP',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIFAPLUS 600 (Radicura)'
);

-- line #28811
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIMACTANE 150 (Novartis)',
	'Rifampicin',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIMACTANE 150 (Novartis)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIMACTANE 300 (Novartis)',
	'Rifampicin',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIMACTANE 300 (Novartis)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIMACTANE 450 (Novartis)',
	'Rifampicin',
	'CAP',
	gm.nullify_empty_string('450')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIMACTANE 450 (Novartis)'
);

-- line #28812
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIMACTANE 100 (Novartis)',
	'Rifampicin',
	'SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIMACTANE 100 (Novartis)'
);

-- line #28813
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIMACTANE 450 (Novartis)',
	'Rifampicin',
	'TAB',
	gm.nullify_empty_string('450')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIMACTANE 450 (Novartis)'
);

-- line #28814
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIMPACIN 450 (Zydus Cadila)',
	'Rifampicin',
	'CAP',
	gm.nullify_empty_string('450')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIMPACIN 450 (Zydus Cadila)'
);

-- line #28815
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIMPIN 150 (HETERO HC.)',
	'Rifampicin',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIMPIN 150 (HETERO HC.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIMPIN 300 (HETERO HC.)',
	'Rifampicin',
	'CAP',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIMPIN 300 (HETERO HC.)'
);

-- line #28816
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIMPIN 100 (HETERO HC.)',
	'Rifampicin',
	'SYR',
	gm.nullify_empty_string('100')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIMPIN 100 (HETERO HC.)'
);

-- line #28817
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RCIFAX 200 (Lupin)',
	'RIFAXIMIN',
	'DT TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RCIFAX 200 (Lupin)'
);

-- line #28818
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'RIFAXIMIN', u'always_empty': u'', u'form': u'TAB', u'brand': u'RCIFAX', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #28819
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIFAGUT 200 (Sun)',
	'RIFAXIMIN',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIFAGUT 200 (Sun)'
);

-- line #28820
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIFAGUT 400 (Sun)',
	'RIFAXIMIN',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIFAGUT 400 (Sun)'
);

-- line #28821
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETHIN 20 (Intas)',
	'RIMONABANT',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETHIN 20 (Intas)'
);

-- line #28822
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEFAT 20 (Unisearch)',
	'RIMONABANT',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEFAT 20 (Unisearch)'
);

-- line #28823
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OBERIM 20 (Intas)',
	'RIMONABANT',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OBERIM 20 (Intas)'
);

-- line #28824
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OBITONE 20 (Ranbaxy)',
	'RIMONABANT',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OBITONE 20 (Ranbaxy)'
);

-- line #28825
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIBAFIT 20 (Lupin)',
	'RIMONABANT',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIBAFIT 20 (Lupin)'
);

-- line #28826
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIMBIOS 20 (INEXIOS PH.)',
	'RIMONABANT',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIMBIOS 20 (INEXIOS PH.)'
);

-- line #28827
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIMOBEST 10 (Otsira)',
	'RIMONABANT',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIMOBEST 10 (Otsira)'
);

-- line #28828
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIMOBEST 20 (Otsira)',
	'RIMONABANT',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIMOBEST 20 (Otsira)'
);

-- line #28829
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIMOFIT 20 (Torrent)',
	'RIMONABANT',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIMOFIT 20 (Torrent)'
);

-- line #28830
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIMOSLIM 20 (Torrent)',
	'RIMONABANT',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIMOSLIM 20 (Torrent)'
);

-- line #28831
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIMTRIM 20 (Macleods)',
	'RIMONABANT',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIMTRIM 20 (Macleods)'
);

-- line #28832
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIOBANT 20 (SUN)',
	'RIMONABANT',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIOBANT 20 (SUN)'
);

-- line #28833
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIOMONT 20 (Cipla)',
	'RIMONABANT',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIOMONT 20 (Cipla)'
);

-- line #28834
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'RINGER LACTATE', u'always_empty': u'', u'form': u'INJECTION', u'brand': u'RINGER', u'strength_3': u'', u'company': u'Claris L.', u'unit': u''}

-- line #28835
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'RINGER LACTATE', u'always_empty': u'', u'form': u'INJ', u'brand': u'RINGER LACTATE', u'strength_3': u'', u'company': u'Claris L.', u'unit': u''}

-- line #28836
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'RINGER LACTATE', u'always_empty': u'', u'form': u'SOLINF', u'brand': u'RINGER LACTATE', u'strength_3': u'', u'company': u'Albert D.', u'unit': u''}

-- line #28837
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'RINGER LACTATE', u'always_empty': u'', u'form': u'INF', u'brand': u'RINGER LACTATE SOL', u'strength_3': u'', u'company': u'Claris L.', u'unit': u''}

-- line #28838
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'RINGER LACTATE', u'always_empty': u'', u'form': u'INF', u'brand': u'RINGER LACTATE SOL', u'strength_3': u'', u'company': u'Mount M.', u'unit': u''}

-- line #28839
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'RINGER LACTATE', u'always_empty': u'', u'form': u'INF', u'brand': u'RINGER LACTATE SOL', u'strength_3': u'', u'company': u'Parenteral', u'unit': u''}

-- line #28840
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'RINGER LACTATE', u'always_empty': u'', u'form': u'INF', u'brand': u'RINGERS LACTATE', u'strength_3': u'', u'company': u'K.K.', u'unit': u''}

-- line #28841
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'RINGER LACTATE', u'always_empty': u'', u'form': u'INF', u'brand': u'RINGERS LACTATE', u'strength_3': u'', u'company': u'TABLETS I.', u'unit': u''}

-- line #28842
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'RINGER LACTATE', u'always_empty': u'', u'form': u'SOL', u'brand': u'RINLAC', u'strength_3': u'', u'company': u'Neon', u'unit': u''}

-- line #28843
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTONEL 35 (Sanofi Aventis)',
	'RISEDRONATE SODIUM',
	'TAB',
	gm.nullify_empty_string('35')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTONEL 35 (Sanofi Aventis)'
);

-- line #28844
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BONE-C FOS 35 (MOLEKULE)',
	'RISEDRONATE SODIUM',
	'TAB',
	gm.nullify_empty_string('35')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BONE-C FOS 35 (MOLEKULE)'
);

-- line #28845
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOSSICAL 35 (MEDREICH SAI.)',
	'RISEDRONATE SODIUM',
	'TAB',
	gm.nullify_empty_string('35')::numeric,
	'mg(RISEDRONIC ACID)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOSSICAL 35 (MEDREICH SAI.)'
);

-- line #28846
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GEMFOS 35 (ALKEM)',
	'RISEDRONATE SODIUM',
	'TAB',
	gm.nullify_empty_string('35')::numeric,
	'mg(RISEDRONIC ACID)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GEMFOS 35 (ALKEM)'
);

-- line #28847
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSEDRATE 35 (Aksigen Hosp.)',
	'RISEDRONATE SODIUM',
	'TAB',
	gm.nullify_empty_string('35')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSEDRATE 35 (Aksigen Hosp.)'
);

-- line #28848
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRIS 1 (Biocia Hc.)',
	'Risperidone',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRIS 1 (Biocia Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRIS 2 (Biocia Hc.)',
	'Risperidone',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRIS 2 (Biocia Hc.)'
);

-- line #28849
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRIS 3 (Biocia Hc.)',
	'Risperidone',
	'TAB',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRIS 3 (Biocia Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRIS 4 (Biocia Hc.)',
	'Risperidone',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRIS 4 (Biocia Hc.)'
);

-- line #28850
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIZOSPER 1 (Cadex Lab)',
	'Risperidone',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIZOSPER 1 (Cadex Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIZOSPER 2 (Cadex Lab)',
	'Risperidone',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIZOSPER 2 (Cadex Lab)'
);

-- line #28851
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIZOSPER 3 (Cadex Lab)',
	'Risperidone',
	'TAB',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIZOSPER 3 (Cadex Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIZOSPER 4 (Cadex Lab)',
	'Risperidone',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIZOSPER 4 (Cadex Lab)'
);

-- line #28852
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MESPERI 2 (Merit Org.)',
	'Risperidone',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MESPERI 2 (Merit Org.)'
);

-- line #28853
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERIDON 1 (Reliance)',
	'Risperidone',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERIDON 1 (Reliance)'
);

-- line #28854
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERIDON 2 (Reliance)',
	'Risperidone',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERIDON 2 (Reliance)'
);

-- line #28855
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERIDON 3 (Reliance)',
	'Risperidone',
	'TAB',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERIDON 3 (Reliance)'
);

-- line #28856
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERIDON 4 (Reliance)',
	'Risperidone',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERIDON 4 (Reliance)'
);

-- line #28857
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PSYDON 1 (PSYCOREM)',
	'Risperidone',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PSYDON 1 (PSYCOREM)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PSYDON 2 (PSYCOREM)',
	'Risperidone',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PSYDON 2 (PSYCOREM)'
);

-- line #28858
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PSYDON 3 (PSYCOREM)',
	'Risperidone',
	'TAB',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PSYDON 3 (PSYCOREM)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PSYDON 4 (PSYCOREM)',
	'Risperidone',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PSYDON 4 (PSYCOREM)'
);

-- line #28859
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RASIN 1 (Pifer Ph.)',
	'Risperidone',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RASIN 1 (Pifer Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RASIN 2 (Pifer Ph.)',
	'Risperidone',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RASIN 2 (Pifer Ph.)'
);

-- line #28860
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RASIN 3 (Pifer Ph.)',
	'Risperidone',
	'TAB',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RASIN 3 (Pifer Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RASIN 4 (Pifer Ph.)',
	'Risperidone',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RASIN 4 (Pifer Ph.)'
);

-- line #28861
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'R-DON 1 (Elite Ph.)',
	'Risperidone',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'R-DON 1 (Elite Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'R-DON 2 (Elite Ph.)',
	'Risperidone',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'R-DON 2 (Elite Ph.)'
);

-- line #28862
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'R-DON 3 (Elite Ph.)',
	'Risperidone',
	'TAB',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'R-DON 3 (Elite Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'R-DON 4 (Elite Ph.)',
	'Risperidone',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'R-DON 4 (Elite Ph.)'
);

-- line #28863
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REGRACE 1 (LA DRUG)',
	'Risperidone',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REGRACE 1 (LA DRUG)'
);

-- line #28864
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REGRACE 2 (LA DRUG)',
	'Risperidone',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REGRACE 2 (LA DRUG)'
);

-- line #28865
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REGRACE 3 (LA DRUG)',
	'Risperidone',
	'TAB',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REGRACE 3 (LA DRUG)'
);

-- line #28866
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REGRACE 4 (LA DRUG)',
	'Risperidone',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REGRACE 4 (LA DRUG)'
);

-- line #28867
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REPADONE 2 (SHINE PH.)',
	'Risperidone',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REPADONE 2 (SHINE PH.)'
);

-- line #28868
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REPID 1 (TASMED)',
	'Risperidone',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REPID 1 (TASMED)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REPID 2 (TASMED)',
	'Risperidone',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REPID 2 (TASMED)'
);

-- line #28869
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REPID 3 (TASMED)',
	'Risperidone',
	'TAB',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REPID 3 (TASMED)'
);

-- line #28870
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESPIDON 1 (Torrent)',
	'Risperidone',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESPIDON 1 (Torrent)'
);

-- line #28871
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESPIDON 2 (Torrent)',
	'Risperidone',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESPIDON 2 (Torrent)'
);

-- line #28872
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESPIDON 3 (Torrent)',
	'Risperidone',
	'TAB',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESPIDON 3 (Torrent)'
);

-- line #28873
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESPIDON 4 (Torrent)',
	'Risperidone',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESPIDON 4 (Torrent)'
);

-- line #28874
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESPID 2 (Cyril Ph.)',
	'Risperidone',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESPID 2 (Cyril Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESPID 3 (Cyril Ph.)',
	'Risperidone',
	'TAB',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESPID 3 (Cyril Ph.)'
);

-- line #28875
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESPIMED 1 (Medico)',
	'Risperidone',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESPIMED 1 (Medico)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESPIMED 2 (Medico)',
	'Risperidone',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESPIMED 2 (Medico)'
);

-- line #28876
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESPIRAL 1 (ALPHA TH.)',
	'Risperidone',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESPIRAL 1 (ALPHA TH.)'
);

-- line #28877
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESPIROL 1 (Olcare)',
	'Risperidone',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESPIROL 1 (Olcare)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESPIROL 2 (Olcare)',
	'Risperidone',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESPIROL 2 (Olcare)'
);

-- line #28878
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESPIROL 3 (Olcare)',
	'Risperidone',
	'TAB',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESPIROL 3 (Olcare)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESPIROL 4 (Olcare)',
	'Risperidone',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESPIROL 4 (Olcare)'
);

-- line #28879
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIDON 1 (East India)',
	'Risperidone',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIDON 1 (East India)'
);

-- line #28880
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIDON 2 (East India)',
	'Risperidone',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIDON 2 (East India)'
);

-- line #28881
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIDON 4 (East India)',
	'Risperidone',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIDON 4 (East India)'
);

-- line #28882
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RION 1 (OREVA DARMO.)',
	'Risperidone',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RION 1 (OREVA DARMO.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RION 4 (OREVA DARMO.)',
	'Risperidone',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RION 4 (OREVA DARMO.)'
);

-- line #28883
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RION 1 (Zee Lab)',
	'Risperidone',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RION 1 (Zee Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RION 4 (Zee Lab)',
	'Risperidone',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RION 4 (Zee Lab)'
);

-- line #28884
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RI 1 (Vgr Bio.)',
	'Risperidone',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RI 1 (Vgr Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RI 2 (Vgr Bio.)',
	'Risperidone',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RI 2 (Vgr Bio.)'
);

-- line #28885
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RI 3 (Vgr Bio.)',
	'Risperidone',
	'TAB',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RI 3 (Vgr Bio.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RI 4 (Vgr Bio.)',
	'Risperidone',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RI 4 (Vgr Bio.)'
);

-- line #28886
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGTAR 10 (Shreeyam)',
	'Ritodrine',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGTAR 10 (Shreeyam)'
);

-- line #28887
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREGTAR 10 (Shreeyam)',
	'Ritodrine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREGTAR 10 (Shreeyam)'
);

-- line #28888
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMPETUS 100 (EMCURE(ARV))',
	'Ritonavir',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMPETUS 100 (EMCURE(ARV))'
);

-- line #28889
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REDITUX RA 500 (Dr. Reddy''S)',
	'RITUXIMAB',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REDITUX RA 500 (Dr. Reddy''S)'
);

-- line #28890
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REDITUX 100 (Dr.Reddy''S)',
	'RITUXIMAB',
	'VIAL',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REDITUX 100 (Dr.Reddy''S)'
);

-- line #28891
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REDITUX 500 (Dr.Reddy''S)',
	'RITUXIMAB',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REDITUX 500 (Dr.Reddy''S)'
);

-- line #28892
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXELON 1.5 (Novartis)',
	'Rivastigmine',
	'CAP',
	gm.nullify_empty_string('1.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXELON 1.5 (Novartis)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXELON 3 (Novartis)',
	'Rivastigmine',
	'CAP',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXELON 3 (Novartis)'
);

-- line #28893
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXELON 4.5 (Novartis)',
	'Rivastigmine',
	'CAP',
	gm.nullify_empty_string('4.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXELON 4.5 (Novartis)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXELON 6 (Novartis)',
	'Rivastigmine',
	'CAP',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXELON 6 (Novartis)'
);

-- line #28894
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUROMID 50 (ZENOTECH LAB.)',
	'ROCURONIUM BROMIDE',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUROMID 50 (ZENOTECH LAB.)'
);

-- line #28895
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARKIROP 0.25 (CADILA)',
	'Ropinirole',
	'TAB',
	gm.nullify_empty_string('0.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARKIROP 0.25 (CADILA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARKIROP 0.5 (CADILA)',
	'Ropinirole',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARKIROP 0.5 (CADILA)'
);

-- line #28896
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARKIROP 1 (CADILA)',
	'Ropinirole',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARKIROP 1 (CADILA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARKIROP 2 (CADILA)',
	'Ropinirole',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARKIROP 2 (CADILA)'
);

-- line #28897
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2G(SOD.CHL.9', u'strength_2': u'', u'substance': u'ROPIVACAINE HCL.', u'always_empty': u'', u'form': u'', u'brand': u'NAROPIN %', u'strength_3': u'', u'company': u'Astrazeneca', u'unit': u'mg)'}

-- line #28898
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'7.5G(SOD.CHL.7.5', u'strength_2': u'', u'substance': u'ROPIVACAINE HCL.', u'always_empty': u'', u'form': u'', u'brand': u'NATOPIN %', u'strength_3': u'', u'company': u'Astrazeneca', u'unit': u'mg)'}

-- line #28899
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.5G(ROSE HIP)', u'strength_2': u'', u'substance': u'ROSA CANINA POWDER', u'always_empty': u'', u'form': u'SAC', u'brand': u'RE-FLEX', u'strength_3': u'', u'company': u'SVIZERA HC.', u'unit': u''}

-- line #28900
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENSELIN 2 (Torrent)',
	'Rosiglitazone',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENSELIN 2 (Torrent)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENSELIN 4 (Torrent)',
	'Rosiglitazone',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENSELIN 4 (Torrent)'
);

-- line #28901
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENSELIN 8 (Torrent)',
	'Rosiglitazone',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENSELIN 8 (Torrent)'
);

-- line #28902
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REGLIT 2 (Dr.Reddy''S)',
	'Rosiglitazone',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REGLIT 2 (Dr.Reddy''S)'
);

-- line #28903
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REGLIT 4 (Dr.Reddy''S)',
	'Rosiglitazone',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REGLIT 4 (Dr.Reddy''S)'
);

-- line #28904
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REGLIT 8 (Dr.Reddy''S)',
	'Rosiglitazone',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REGLIT 8 (Dr.Reddy''S)'
);

-- line #28905
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REZULT 2 (Sun)',
	'Rosiglitazone',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REZULT 2 (Sun)'
);

-- line #28906
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REZULT 4 (Sun)',
	'Rosiglitazone',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REZULT 4 (Sun)'
);

-- line #28907
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REZULT 8 (Sun)',
	'Rosiglitazone',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REZULT 8 (Sun)'
);

-- line #28908
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARVAST 40 (Intas)',
	'ROSUVASTATIN',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARVAST 40 (Intas)'
);

-- line #28909
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'ROSUVASTATIN', u'always_empty': u'', u'form': u'', u'brand': u'BESTOR', u'strength_3': u'', u'company': u'Biocon', u'unit': u'mg'}

-- line #28910
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BESTOR 10 (Biocon)',
	'ROSUVASTATIN',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BESTOR 10 (Biocon)'
);

-- line #28911
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BESTOR 5 (Biocon)',
	'ROSUVASTATIN',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BESTOR 5 (Biocon)'
);

-- line #28912
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COLTRO 10 (Intas)',
	'ROSUVASTATIN',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COLTRO 10 (Intas)'
);

-- line #28913
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COLTRO 20 (Intas)',
	'ROSUVASTATIN',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COLTRO 20 (Intas)'
);

-- line #28914
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COLTRO 5 (Intas)',
	'ROSUVASTATIN',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COLTRO 5 (Intas)'
);

-- line #28915
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONSIVAS-20 20 (Emcure)',
	'ROSUVASTATIN',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONSIVAS-20 20 (Emcure)'
);

-- line #28916
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONSIVAS 10 (Emcure)',
	'ROSUVASTATIN',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONSIVAS 10 (Emcure)'
);

-- line #28917
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONSIVAS 5 (Emcure)',
	'ROSUVASTATIN',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONSIVAS 5 (Emcure)'
);

-- line #28918
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CRESTOR 10 (Astrazeneca)',
	'ROSUVASTATIN',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CRESTOR 10 (Astrazeneca)'
);

-- line #28919
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CRESTOR 20 (Astrazeneca)',
	'ROSUVASTATIN',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CRESTOR 20 (Astrazeneca)'
);

-- line #28920
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CRESTOR 40 (Astrazeneca)',
	'ROSUVASTATIN',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CRESTOR 40 (Astrazeneca)'
);

-- line #28921
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CRESTOR 5 (Astrazeneca)',
	'ROSUVASTATIN',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CRESTOR 5 (Astrazeneca)'
);

-- line #28922
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CREVAST-5 5 (ERIS THER.)',
	'ROSUVASTATIN',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CREVAST-5 5 (ERIS THER.)'
);

-- line #28923
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CREVAST 10 (ERIS THER.)',
	'ROSUVASTATIN',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CREVAST 10 (ERIS THER.)'
);

-- line #28924
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CREVAST 20 (ERIS THER.)',
	'ROSUVASTATIN',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CREVAST 20 (ERIS THER.)'
);

-- line #28925
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CREVAST 40 (ERIS THER.)',
	'ROSUVASTATIN',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CREVAST 40 (ERIS THER.)'
);

-- line #28926
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10', u'strength_2': u'', u'substance': u'ROSUVASTATIN', u'always_empty': u'', u'form': u'', u'brand': u'EXEROZ', u'strength_3': u'', u'company': u'Panacea', u'unit': u'mg'}

-- line #28927
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5', u'strength_2': u'', u'substance': u'ROSUVASTATIN', u'always_empty': u'', u'form': u'', u'brand': u'EXEROZ', u'strength_3': u'', u'company': u'Panacea', u'unit': u'mg'}

-- line #28928
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORTIUS 20 (Piramal Hc.)',
	'ROSUVASTATIN',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORTIUS 20 (Piramal Hc.)'
);

-- line #28929
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORTIUS 5 (Piramal Hc.)',
	'ROSUVASTATIN',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORTIUS 5 (Piramal Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORTIUS 10 (Piramal Hc.)',
	'ROSUVASTATIN',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORTIUS 10 (Piramal Hc.)'
);

-- line #28930
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5', u'strength_2': u'', u'substance': u'ROSUVASTATIN', u'always_empty': u'', u'form': u'', u'brand': u'LDNIL', u'strength_3': u'', u'company': u'MSN LAB.', u'unit': u'mg'}

-- line #28931
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LDNIL 10 (SAFE MED(MSN))',
	'ROSUVASTATIN',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LDNIL 10 (SAFE MED(MSN))'
);

-- line #28932
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LDNIL 20 (SAFE MED(MSN))',
	'ROSUVASTATIN',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LDNIL 20 (SAFE MED(MSN))'
);

-- line #28933
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPIRA-10 10 (Emcure)',
	'ROSUVASTATIN',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPIRA-10 10 (Emcure)'
);

-- line #28934
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPIRA-5 5 (Emcure)',
	'ROSUVASTATIN',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPIRA-5 5 (Emcure)'
);

-- line #28935
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPIROSE-10 10 (Mankind)',
	'ROSUVASTATIN',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPIROSE-10 10 (Mankind)'
);

-- line #28936
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIPIROSE-5 5 (Mankind)',
	'ROSUVASTATIN',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIPIROSE-5 5 (Mankind)'
);

-- line #28937
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVASTAT 5 (Lupin)',
	'ROSUVASTATIN',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVASTAT 5 (Lupin)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVASTAT 10 (Lupin)',
	'ROSUVASTATIN',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVASTAT 10 (Lupin)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVASTAT 20 (Lupin)',
	'ROSUVASTATIN',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVASTAT 20 (Lupin)'
);

-- line #28938
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVOSTAT 20 (Lupin)',
	'ROSUVASTATIN',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVOSTAT 20 (Lupin)'
);

-- line #28939
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVOSTAT 5 (Lupin)',
	'ROSUVASTATIN',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVOSTAT 5 (Lupin)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVOSTAT 10 (Lupin)',
	'ROSUVASTATIN',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVOSTAT 10 (Lupin)'
);

-- line #28940
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'R2-10 10 (Piramal Hc.)',
	'ROSUVASTATIN',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'R2-10 10 (Piramal Hc.)'
);

-- line #28941
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'R2-20 20 (Piramal Hc.)',
	'ROSUVASTATIN',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'R2-20 20 (Piramal Hc.)'
);

-- line #28942
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'R2-5 5 (Piramal Hc.)',
	'ROSUVASTATIN',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'R2-5 5 (Piramal Hc.)'
);

-- line #28943
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAZEL 10 (Glenmark)',
	'ROSUVASTATIN',
	'EZ TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAZEL 10 (Glenmark)'
);

-- line #28944
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAZEL 20 (Glenmark)',
	'ROSUVASTATIN',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAZEL 20 (Glenmark)'
);

-- line #28945
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAZEL 5 (Glenmark)',
	'ROSUVASTATIN',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAZEL 5 (Glenmark)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAZEL 10 (Glenmark)',
	'ROSUVASTATIN',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAZEL 10 (Glenmark)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAZEL 20 (Glenmark)',
	'ROSUVASTATIN',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAZEL 20 (Glenmark)'
);

-- line #28946
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAZEL 5 (Glenmark)',
	'ROSUVASTATIN',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAZEL 5 (Glenmark)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAZEL 10 (Glenmark)',
	'ROSUVASTATIN',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAZEL 10 (Glenmark)'
);

-- line #28947
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESTOR 20 (Astrazeneca)',
	'ROSUVASTATIN',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESTOR 20 (Astrazeneca)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESTOR 40 (Astrazeneca)',
	'ROSUVASTATIN',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESTOR 40 (Astrazeneca)'
);

-- line #28948
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESTOR 5 (Astrazeneca)',
	'ROSUVASTATIN',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESTOR 5 (Astrazeneca)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESTOR 10 (Astrazeneca)',
	'ROSUVASTATIN',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESTOR 10 (Astrazeneca)'
);

-- line #28949
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ABROX 150 (ROSE LABS)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ABROX 150 (ROSE LABS)'
);

-- line #28950
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTIROX 50 (Active Hc.)',
	'Roxithromycin',
	'KT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTIROX 50 (Active Hc.)'
);

-- line #28951
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTIROX 150 (Active Hc.)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTIROX 150 (Active Hc.)'
);

-- line #28952
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALROX 50 (Raddison Hc.)',
	'Roxithromycin',
	'KID TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALROX 50 (Raddison Hc.)'
);

-- line #28953
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALROX 150 (Arvind Lab.)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALROX 150 (Arvind Lab.)'
);

-- line #28954
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALROX 150 (Raddison Hc.)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALROX 150 (Raddison Hc.)'
);

-- line #28955
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIROXIN 50 (AIMCO PH.)',
	'Roxithromycin',
	'KID TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIROXIN 50 (AIMCO PH.)'
);

-- line #28956
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIROXIN 150 (AIMCO PH.)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIROXIN 150 (AIMCO PH.)'
);

-- line #28957
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AQROX 150 (Aquila)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AQROX 150 (Aquila)'
);

-- line #28958
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARBID 150 (HETERO HC.)',
	'Roxithromycin',
	'DT',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARBID 150 (HETERO HC.)'
);

-- line #28959
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARBID 50 (HETERO HC.)',
	'Roxithromycin',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARBID 50 (HETERO HC.)'
);

-- line #28960
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AROX 50 (Anikem Lab.)',
	'Roxithromycin',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AROX 50 (Anikem Lab.)'
);

-- line #28961
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AROX 50 (Anikem Lab.)',
	'Roxithromycin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AROX 50 (Anikem Lab.)'
);

-- line #28962
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AROX 150 (Anikem Lab.)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AROX 150 (Anikem Lab.)'
);

-- line #28963
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARTIROX 150 (Panjon)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARTIROX 150 (Panjon)'
);

-- line #28964
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATROX 50 (Atoz Ph.)',
	'Roxithromycin',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATROX 50 (Atoz Ph.)'
);

-- line #28965
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATROX 150 (Atoz Ph.)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATROX 150 (Atoz Ph.)'
);

-- line #28966
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AUROX 50 (Aurobindo)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AUROX 50 (Aurobindo)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AUROX 150 (Aurobindo)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AUROX 150 (Aurobindo)'
);

-- line #28967
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVIROX 300 (Avalanche)',
	'Roxithromycin',
	'F. TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVIROX 300 (Avalanche)'
);

-- line #28968
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVIROX 50 (Avalanche)',
	'Roxithromycin',
	'KT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVIROX 50 (Avalanche)'
);

-- line #28969
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVIROX 150 (Avalanche)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVIROX 150 (Avalanche)'
);

-- line #28970
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Roxithromycin', u'always_empty': u'', u'form': u'SUS', u'brand': u'AXTHRO', u'strength_3': u'', u'company': u'Arbro Ph.', u'unit': u''}

-- line #28971
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXTHRO 150 (Arbro Ph.)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXTHRO 150 (Arbro Ph.)'
);

-- line #28972
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BD-ROX 150 (Panacea)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BD-ROX 150 (Panacea)'
);

-- line #28973
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOLIDE 150 (Alpha Hc.)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOLIDE 150 (Alpha Hc.)'
);

-- line #28974
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOROX 25 (Biochem)',
	'Roxithromycin',
	'DPS',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOROX 25 (Biochem)'
);

-- line #28975
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOROX 50 (Biochem)',
	'Roxithromycin',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOROX 50 (Biochem)'
);

-- line #28976
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOROX 50 (Biochem)',
	'Roxithromycin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOROX 50 (Biochem)'
);

-- line #28977
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOROX 150 (Biochem)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOROX 150 (Biochem)'
);

-- line #28978
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIO-THROX 150 (Bio-Drug)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIO-THROX 150 (Bio-Drug)'
);

-- line #28979
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CANROX 50 (Candor Bio.)',
	'Roxithromycin',
	'LIQ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CANROX 50 (Candor Bio.)'
);

-- line #28980
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIDOCIN 50 (Allure Rem.)',
	'Roxithromycin',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIDOCIN 50 (Allure Rem.)'
);

-- line #28981
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIDOCIN 150 (Allure Rem.)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIDOCIN 150 (Allure Rem.)'
);

-- line #28982
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-ROX 50 (Corona)',
	'Roxithromycin',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-ROX 50 (Corona)'
);

-- line #28983
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-ROX 50 (Corona)',
	'Roxithromycin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-ROX 50 (Corona)'
);

-- line #28984
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-ROX 150 (Corona)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-ROX 150 (Corona)'
);

-- line #28985
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUROX 150 (Cubit Hc.)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUROX 150 (Cubit Hc.)'
);

-- line #28986
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEROX 25 (Dwd)',
	'Roxithromycin',
	'DPS',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEROX 25 (Dwd)'
);

-- line #28987
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEROX 50 (Dwd)',
	'Roxithromycin',
	'KID TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEROX 50 (Dwd)'
);

-- line #28988
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEROX 50 (Dwd)',
	'Roxithromycin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEROX 50 (Dwd)'
);

-- line #28989
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEROX 150 (Dwd)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEROX 150 (Dwd)'
);

-- line #28990
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DRX-150 150 (Cambridge Hc.)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DRX-150 150 (Cambridge Hc.)'
);

-- line #28991
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'D-THROCINE KID/150 50 (Dial Ph.)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'D-THROCINE KID/150 50 (Dial Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'D-THROCINE KID/150 150 (Dial Ph.)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'D-THROCINE KID/150 150 (Dial Ph.)'
);

-- line #28992
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYROX 150 (Dynamic)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYROX 150 (Dynamic)'
);

-- line #28993
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYROX 50 (Dynamic)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYROX 50 (Dynamic)'
);

-- line #28994
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ECOROX 150 (ANAND HC.)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ECOROX 150 (ANAND HC.)'
);

-- line #28995
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'150', u'strength_2': u'', u'substance': u'Roxithromycin', u'always_empty': u'', u'form': u'', u'brand': u'ELROX DT150', u'strength_3': u'', u'company': u'Shreya', u'unit': u'mg'}

-- line #28996
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMROXY 150 (Emil Ph.)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMROXY 150 (Emil Ph.)'
);

-- line #28997
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMROXY 50 (Emil Ph.)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMROXY 50 (Emil Ph.)'
);

-- line #28998
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERO 50 (Rhombus)',
	'Roxithromycin',
	'KT/150 TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERO 50 (Rhombus)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERO 150 (Rhombus)',
	'Roxithromycin',
	'KT/150 TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERO 150 (Rhombus)'
);

-- line #28999
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Roxithromycin', u'always_empty': u'', u'form': u'SUS', u'brand': u'ERO', u'strength_3': u'', u'company': u'Rhombus', u'unit': u''}

-- line #29000
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'E-ROX 150 (MARLINE BIO.)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'E-ROX 150 (MARLINE BIO.)'
);

-- line #29001
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERYSOFT-KID 125 (EAST WEST)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERYSOFT-KID 125 (EAST WEST)'
);

-- line #29002
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERYSOFT 250 (EAST WEST)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERYSOFT 250 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERYSOFT 500 (EAST WEST)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERYSOFT 500 (EAST WEST)'
);

-- line #29003
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERYTHROX KID/150 50 (Unimax Lab)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERYTHROX KID/150 50 (Unimax Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERYTHROX KID/150 150 (Unimax Lab)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERYTHROX KID/150 150 (Unimax Lab)'
);

-- line #29004
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHAREST 50 (Medicamen)',
	'Roxithromycin',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHAREST 50 (Medicamen)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETHAREST 150 (Medicamen)',
	'Roxithromycin',
	'DT',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETHAREST 150 (Medicamen)'
);

-- line #29005
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIROX 150 (Medizone)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIROX 150 (Medizone)'
);

-- line #29006
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYCIN KID/150 50 (Saga Lab)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYCIN KID/150 50 (Saga Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYCIN KID/150 150 (Saga Lab)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYCIN KID/150 150 (Saga Lab)'
);

-- line #29007
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYCIN 50 (Saga Lab)',
	'Roxithromycin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYCIN 50 (Saga Lab)'
);

-- line #29008
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IND-ROX 150 (Indica)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IND-ROX 150 (Indica)'
);

-- line #29009
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INROX 50 (Intra Lab)',
	'Roxithromycin',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INROX 50 (Intra Lab)'
);

-- line #29010
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INROX 150 (Intra Lab)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INROX 150 (Intra Lab)'
);

-- line #29011
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'J-ROXY 50 (Jarson Ph.)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'J-ROXY 50 (Jarson Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'J-ROXY 150 (Jarson Ph.)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'J-ROXY 150 (Jarson Ph.)'
);

-- line #29012
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEXITH 150 (Cadex Lab)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEXITH 150 (Cadex Lab)'
);

-- line #29013
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEXITH 50 (Biocin Hc.)',
	'Roxithromycin',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEXITH 50 (Biocin Hc.)'
);

-- line #29014
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEXITH 150 (Biocin Hc.)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEXITH 150 (Biocin Hc.)'
);

-- line #29015
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUPREX KID/150 50 (Lupin)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUPREX KID/150 50 (Lupin)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUPREX KID/150 150 (Lupin)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUPREX KID/150 150 (Lupin)'
);

-- line #29016
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACLONG 50 (Euphoric)',
	'Roxithromycin',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACLONG 50 (Euphoric)'
);

-- line #29017
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACLONG 50 (Euphoric)',
	'Roxithromycin',
	'KT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACLONG 50 (Euphoric)'
);

-- line #29018
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACLONG 150 (Euphoric)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACLONG 150 (Euphoric)'
);

-- line #29019
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACMYCIN 150 (Mac)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACMYCIN 150 (Mac)'
);

-- line #29020
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACROX 150 (Indu D.)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACROX 150 (Indu D.)'
);

-- line #29021
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANAROX 50 (Maan)',
	'Roxithromycin',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANAROX 50 (Maan)'
);

-- line #29022
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANAROX 50 (Maan)',
	'Roxithromycin',
	'KT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANAROX 50 (Maan)'
);

-- line #29023
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANAROX 150 (Maan)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANAROX 150 (Maan)'
);

-- line #29024
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAROX 150 (Mars Rem.)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAROX 150 (Mars Rem.)'
);

-- line #29025
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDIROX 50 (Medopharm)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDIROX 50 (Medopharm)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDIROX 150 (Medopharm)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDIROX 150 (Medopharm)'
);

-- line #29026
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MED-ROX 50 (MODHIKE)',
	'Roxithromycin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MED-ROX 50 (MODHIKE)'
);

-- line #29027
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MED-ROX 150 (MODHIKE)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MED-ROX 150 (MODHIKE)'
);

-- line #29028
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGAROX 150 (CHEMO HC.)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGAROX 150 (CHEMO HC.)'
);

-- line #29029
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILROX 150 (Shaimil)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILROX 150 (Shaimil)'
);

-- line #29030
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'M-ROX 150 (Mercury)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'M-ROX 150 (Mercury)'
);

-- line #29031
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODIROX 50 (Protec)',
	'Roxithromycin',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODIROX 50 (Protec)'
);

-- line #29032
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODIROX 50 (Protec)',
	'Roxithromycin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODIROX 50 (Protec)'
);

-- line #29033
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODIROX 150 (Protec)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODIROX 150 (Protec)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODIROX 300 (Protec)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODIROX 300 (Protec)'
);

-- line #29034
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPTINO 150 (Shinto Org.)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPTINO 150 (Shinto Org.)'
);

-- line #29035
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPTINO 50 (Shinto Org.)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPTINO 50 (Shinto Org.)'
);

-- line #29036
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORBIS KID/150 50 (Cataliq)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORBIS KID/150 50 (Cataliq)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORBIS KID/150 150 (Cataliq)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORBIS KID/150 150 (Cataliq)'
);

-- line #29037
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PD ROX 150 (Parenteral)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PD ROX 150 (Parenteral)'
);

-- line #29038
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENROX 150 (SAFE PH.)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENROX 150 (SAFE PH.)'
);

-- line #29039
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PUNCHOROX 150 (Moraceae)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PUNCHOROX 150 (Moraceae)'
);

-- line #29040
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q ROX 50 (Que Ph.)',
	'Roxithromycin',
	'KT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q ROX 50 (Que Ph.)'
);

-- line #29041
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q ROX 150 (Que Ph.)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q ROX 150 (Que Ph.)'
);

-- line #29042
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RALROX 50 (Shreya)',
	'Roxithromycin',
	'SUS',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RALROX 50 (Shreya)'
);

-- line #29043
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RALROX 150 (Shreya)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RALROX 150 (Shreya)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RALROX 300 (Shreya)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RALROX 300 (Shreya)'
);

-- line #29044
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RALROX 50 (Shreya)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RALROX 50 (Shreya)'
);

-- line #29045
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RBROX 150 (R.B.REM.)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RBROX 150 (R.B.REM.)'
);

-- line #29046
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REFOXIL 50 (Parasol)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REFOXIL 50 (Parasol)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REFOXIL 150 (Parasol)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REFOXIL 150 (Parasol)'
);

-- line #29047
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REKTHRO 50 (Rekvina)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REKTHRO 50 (Rekvina)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REKTHRO 150 (Rekvina)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REKTHRO 150 (Rekvina)'
);

-- line #29048
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REMS-150 150 (Growell)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REMS-150 150 (Growell)'
);

-- line #29049
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESPRIDE 50 (Kentreck)',
	'Roxithromycin',
	'D.SYR',
	gm.nullify_empty_string('50')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESPRIDE 50 (Kentreck)'
);

-- line #29050
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESPRIDE 50 (Kentreck)',
	'Roxithromycin',
	'KT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESPRIDE 50 (Kentreck)'
);

-- line #29051
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESPRIDE 150 (Kentreck)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESPRIDE 150 (Kentreck)'
);

-- line #29052
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RETROX-150 250 (Royal)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RETROX-150 250 (Royal)'
);

-- line #29053
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RETROX-150 150 (Royal Lab)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RETROX-150 150 (Royal Lab)'
);

-- line #29054
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIM 150 (Unicure)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIM 150 (Unicure)'
);

-- line #29055
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIN 150 (Regent)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIN 150 (Regent)'
);

-- line #29056
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIN 50 (Regent)',
	'Roxithromycin',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIN 50 (Regent)'
);

-- line #29057
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000CCID50 OF MEALES VIRUS AND 1000 CCID 50 OF RUBELLA VIRUS', u'strength_2': u'', u'substance': u'RUBELLA VACCINE', u'always_empty': u'', u'form': u'', u'brand': u'MR-VAC', u'strength_3': u'', u'company': u'Serum Inst.', u'unit': u''}

-- line #29058
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOSTAR-R 10 (Intra Lab)',
	'RUPATADINE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOSTAR-R 10 (Intra Lab)'
);

-- line #29059
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'R-2 10 (Wockhardt)',
	'RUPATADINE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'R-2 10 (Wockhardt)'
);

-- line #29060
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RALIF 10 (Panacea)',
	'RUPATADINE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RALIF 10 (Panacea)'
);

-- line #29061
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RALZAL 10 (F D C)',
	'RUPATADINE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RALZAL 10 (F D C)'
);

-- line #29062
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BASE 282.5 (Bestochem)',
	'Saccharomyces Boulardil',
	'SAC',
	gm.nullify_empty_string('282.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BASE 282.5 (Bestochem)'
);

-- line #29063
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOGIT 100 (Bharat Bio.)',
	'Saccharomyces Boulardil',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOGIT 100 (Bharat Bio.)'
);

-- line #29064
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOGIT 250 (Bharat Bio.)',
	'Saccharomyces Boulardil',
	'SACS',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOGIT 250 (Bharat Bio.)'
);

-- line #29065
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Saccharomyces Boulardil', u'always_empty': u'', u'form': u'SAC', u'brand': u'COMENSAL', u'strength_3': u'', u'company': u'MEDREICH SAI.', u'unit': u''}

-- line #29066
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ECONORM 282.5 (Dr.Reddy''S)',
	'Saccharomyces Boulardil',
	'SAC',
	gm.nullify_empty_string('282.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ECONORM 282.5 (Dr.Reddy''S)'
);

-- line #29067
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'141,25', u'strength_2': u'', u'substance': u'Saccharomyces Boulardil', u'always_empty': u'', u'form': u'', u'brand': u'JONSAC', u'strength_3': u'', u'company': u"D.R.John''S", u'unit': u'mg'}

-- line #29068
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'282,5', u'strength_2': u'', u'substance': u'Saccharomyces Boulardil', u'always_empty': u'', u'form': u'', u'brand': u'JONSAC', u'strength_3': u'', u'company': u"D.R.John''S", u'unit': u'mg'}

-- line #29069
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADESAM 200 (Sun)',
	'S-ADENOSYL-L-METHIONINE',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADESAM 200 (Sun)'
);

-- line #29070
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADESAM 400 (Sun)',
	'S-ADENOSYL-L-METHIONINE',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADESAM 400 (Sun)'
);

-- line #29071
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSTISAVE 200 (ZYDUS NUT.)',
	'S-ADENOSYL METHIONINE',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSTISAVE 200 (ZYDUS NUT.)'
);

-- line #29072
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSTISAVE 400 (ZYDUS NUT.)',
	'S-ADENOSYL METHIONINE',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSTISAVE 400 (ZYDUS NUT.)'
);

-- line #29073
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100MCG', u'strength_2': u'', u'substance': u'Salbutamol', u'always_empty': u'', u'form': u'', u'brand': u'AEROTAZ DISK', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #29074
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200MCG', u'strength_2': u'', u'substance': u'SALBUTAMOL', u'always_empty': u'', u'form': u'', u'brand': u'AEROTAZ DISK', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #29075
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100MCG(EACH ACT.)', u'strength_2': u'', u'substance': u'SALBUTAMOL', u'always_empty': u'', u'form': u'', u'brand': u'AEROTAZ', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #29076
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASMANIL 2 (Inga)',
	'Salbutamol',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASMANIL 2 (Inga)'
);

-- line #29077
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASMANIL 4 (Inga)',
	'Salbutamol',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASMANIL 4 (Inga)'
);

-- line #29078
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100MCG', u'strength_2': u'1PUFF', u'substance': u'Salbutamol', u'always_empty': u'', u'form': u'', u'brand': u'ASTHALIN MDI', u'strength_3': u'', u'company': u'Cipla', u'unit': u'100MCG/1PUFF'}

-- line #29079
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100MCG', u'strength_2': u'PUFF', u'substance': u'salbutamol', u'always_empty': u'', u'form': u'', u'brand': u'ASTHALIN MDI', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #29080
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100MCG', u'strength_2': u'PUFF', u'substance': u'Salbutamol', u'always_empty': u'', u'form': u'', u'brand': u'ASTHALIN MDI', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #29081
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100MCG', u'strength_2': u'', u'substance': u'Salbutamol', u'always_empty': u'', u'form': u'INHALER', u'brand': u'ASTHALIN-M', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #29082
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASTHALIN-SA 4 (Cipla)',
	'Salbutamol',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASTHALIN-SA 4 (Cipla)'
);

-- line #29083
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASTHALIN-SA 8 (Cipla)',
	'Salbutamol',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASTHALIN-SA 8 (Cipla)'
);

-- line #29084
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASTHALIN 2 (Cipla)',
	'Salbutamol',
	'SYR',
	gm.nullify_empty_string('2')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASTHALIN 2 (Cipla)'
);

-- line #29085
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASTHALIN 2 (Cipla)',
	'Salbutamol',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASTHALIN 2 (Cipla)'
);

-- line #29086
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASTHALIN 4 (Cipla)',
	'Salbutamol',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASTHALIN 4 (Cipla)'
);

-- line #29087
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200MCG', u'strength_2': u'', u'substance': u'SALBUTAMOL', u'always_empty': u'', u'form': u'DP CAP', u'brand': u'ASTHAVENT', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #29088
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100MCG', u'strength_2': u'', u'substance': u'SALBUTAMOL', u'always_empty': u'', u'form': u'', u'brand': u'ASTHAVENT INH', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #29089
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASTHAVENT 2.5 (Cipla)',
	'SALBUTAMOL',
	'RES',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASTHAVENT 2.5 (Cipla)'
);

-- line #29090
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASTHAWIN-4 4 (Trio Rem.)',
	'Salbutamol',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASTHAWIN-4 4 (Trio Rem.)'
);

-- line #29091
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRONKONAT 20 (Sun)',
	'Salbutamol',
	'INHALER',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRONKONAT 20 (Sun)'
);

-- line #29092
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRONKOTAB EXT 2 (Gsk)',
	'Salbutamol',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRONKOTAB EXT 2 (Gsk)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRONKOTAB EXT 4 (Gsk)',
	'Salbutamol',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRONKOTAB EXT 4 (Gsk)'
);

-- line #29093
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BROSOL 2 (Lark Labs)',
	'SALBUTAMOL',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BROSOL 2 (Lark Labs)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BROSOL 4 (Lark Labs)',
	'SALBUTAMOL',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BROSOL 4 (Lark Labs)'
);

-- line #29094
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COFAID 1.5 (Meyer Org.)',
	'SALBUTAMOL',
	'SYR',
	gm.nullify_empty_string('1.5')::numeric,
	'mg SULPH.(+VASAKA'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COFAID 1.5 (Meyer Org.)'
);

-- line #29095
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DARASAL 8 (R.B.)',
	'Salbutamol',
	'CR CAP',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DARASAL 8 (R.B.)'
);

-- line #29096
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100MCG', u'strength_2': u'PUFF', u'substance': u'Salbutamol', u'always_empty': u'', u'form': u'', u'brand': u'DERIHALER', u'strength_3': u'', u'company': u'German R.', u'unit': u''}

-- line #29097
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40', u'strength_2': u'', u'substance': u'Salbutamol', u'always_empty': u'', u'form': u'', u'brand': u'DERIHALER NOVOCART', u'strength_3': u'', u'company': u'RESPICARE(GERMAN R.)', u'unit': u'mg'}

-- line #29098
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DERIHALER 2.5 (German R.)',
	'Salbutamol',
	'RES',
	gm.nullify_empty_string('2.5')::numeric,
	'mg/2.5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DERIHALER 2.5 (German R.)'
);

-- line #29099
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200MCG', u'strength_2': u'RESPICAP', u'substance': u'Salbutamol', u'always_empty': u'', u'form': u'RESPICAPS', u'brand': u'DERIHALER', u'strength_3': u'', u'company': u'German R.', u'unit': u''}

-- line #29100
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DERIHALER 500 (German R.)',
	'Salbutamol',
	'SOLN',
	gm.nullify_empty_string('500')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DERIHALER 500 (German R.)'
);

-- line #29101
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100MCG', u'strength_2': u'ACT.', u'substance': u'Salbutamol', u'always_empty': u'', u'form': u'', u'brand': u'DURASAL BREATHALER', u'strength_3': u'', u'company': u'R.B.', u'unit': u''}

-- line #29102
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DURASAL 4 (R.B.)',
	'Salbutamol',
	'CR CAP',
	gm.nullify_empty_string('4')::numeric,
	'mg/8'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DURASAL 4 (R.B.)'
);

-- line #29103
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESMASOL 2.5 (Obsurge)',
	'Salbutamol',
	'INJ',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESMASOL 2.5 (Obsurge)'
);

-- line #29104
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100MCG', u'strength_2': u'1PUFF', u'substance': u'Salbutamol', u'always_empty': u'', u'form': u'', u'brand': u'GLAXO SALBUTAMOL INH', u'strength_3': u'', u'company': u'GSK', u'unit': u''}

-- line #29105
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVOLING 0.31 (Cipla)',
	'Salbutamol',
	'RESP',
	gm.nullify_empty_string('0.31')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVOLING 0.31 (Cipla)'
);

-- line #29106
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVA VENTIPHYLINE-F 4 (Yash Ph.)',
	'SALBUTAMOL',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg(SULPH.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVA VENTIPHYLINE-F 4 (Yash Ph.)'
);

-- line #29107
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVA VENTIPHYLINE 2 (Yash Ph.)',
	'SALBUTAMOL',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg(SULPH.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVA VENTIPHYLINE 2 (Yash Ph.)'
);

-- line #29108
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100', u'strength_2': u'', u'substance': u'Salbutamol', u'always_empty': u'', u'form': u'', u'brand': u'RHEOLIN INH', u'strength_3': u'', u'company': u'Ranbaxy', u'unit': u'mg'}

-- line #29109
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200MCG', u'strength_2': u'', u'substance': u'Salbutamol Sulph.', u'always_empty': u'', u'form': u'CAP', u'brand': u'ASTHALIN R', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #29110
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'400MCG', u'strength_2': u'', u'substance': u'Salbutamol Sulph.', u'always_empty': u'', u'form': u'', u'brand': u'ASTHALIN RC', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #29111
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASTHALIN 2.5 (Cipla)',
	'Salbutamol Sulph.',
	'RESP',
	gm.nullify_empty_string('2.5')::numeric,
	'mg/2.5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASTHALIN 2.5 (Cipla)'
);

-- line #29112
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASTHALIN 5 (Cipla)',
	'Salbutamol Sulph.',
	'RESP',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASTHALIN 5 (Cipla)'
);

-- line #29113
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRONOSOL-4 4 (Alkem)',
	'Salbutamol Sulph.',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRONOSOL-4 4 (Alkem)'
);

-- line #29114
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACNE WASH 1 (Pil)',
	'Salicylic Acid',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACNE WASH 1 (Pil)'
);

-- line #29115
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2', u'strength_2': u'', u'substance': u'Salicylic Acid', u'always_empty': u'', u'form': u'', u'brand': u'AQUASOFT FACE CLEANSER', u'strength_3': u'', u'company': u'Ajanta Ph.', u'unit': u'%W/V'}

-- line #29116
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AQUASOFT-S 2 (Ajanta Ph.)',
	'Salicylic Acid',
	'SOAP',
	gm.nullify_empty_string('2')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AQUASOFT-S 2 (Ajanta Ph.)'
);

-- line #29117
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Salicylic Acid', u'always_empty': u'', u'form': u'', u'brand': u'BIOCLENZ', u'strength_3': u'', u'company': u'Ttk Hc.', u'unit': u''}

-- line #29118
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1', u'strength_2': u'', u'substance': u'Salicylic Acid', u'always_empty': u'', u'form': u'', u'brand': u'CLEENEX', u'strength_3': u'', u'company': u'Serve Ph.', u'unit': u'%W/V'}

-- line #29119
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DERSOL 18 (EAST WEST)',
	'Salicylic Acid',
	'OINT',
	gm.nullify_empty_string('18')::numeric,
	'24'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DERSOL 18 (EAST WEST)'
);

-- line #29120
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DERSOL 6 (EAST WEST)',
	'Salicylic Acid',
	'OINT',
	gm.nullify_empty_string('6')::numeric,
	'12'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DERSOL 6 (EAST WEST)'
);

-- line #29121
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2', u'strength_2': u'', u'substance': u'Salicylic Acid', u'always_empty': u'', u'form': u'', u'brand': u'EREMIS FACE WASH', u'strength_3': u'', u'company': u'AAMORB(SIOUX)', u'unit': u'%W/W'}

-- line #29122
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIDCON CORN 50 (Ranbaxy)',
	'Salicylic Acid',
	'CAPS',
	gm.nullify_empty_string('50')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIDCON CORN 50 (Ranbaxy)'
);

-- line #29123
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZROL 3 (Solares (Sun))',
	'Salmeterol',
	'INHALER',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZROL 3 (Solares (Sun))'
);

-- line #29124
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOVAS-S 2.5 (Macleods)',
	'S-Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOVAS-S 2.5 (Macleods)'
);

-- line #29125
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMLOVAS-S 5 (Macleods)',
	'S-Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMLOVAS-S 5 (Macleods)'
);

-- line #29126
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASOMEX 1.25 (Emcure)',
	'S-Amlodipine',
	'TAB',
	gm.nullify_empty_string('1.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASOMEX 1.25 (Emcure)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASOMEX 5 (Emcure)',
	'S-Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASOMEX 5 (Emcure)'
);

-- line #29127
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASOMEX 2.5 (Emcure)',
	'S-Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASOMEX 2.5 (Emcure)'
);

-- line #29128
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIG-DVR 2.5 (Bestochem)',
	'S-Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIG-DVR 2.5 (Bestochem)'
);

-- line #29129
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESAMLO 2.5 (Mano)',
	'S-Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESAMLO 2.5 (Mano)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESAMLO 5 (Mano)',
	'S-Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESAMLO 5 (Mano)'
);

-- line #29130
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESAMLOVIN 1.25 (EAST WEST)',
	'S-Amlodipine',
	'TAB',
	gm.nullify_empty_string('1.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESAMLOVIN 1.25 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESAMLOVIN 2.5 (EAST WEST)',
	'S-Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESAMLOVIN 2.5 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESAMLOVIN 5 (EAST WEST)',
	'S-Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESAMLOVIN 5 (EAST WEST)'
);

-- line #29131
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESAM 2.5 (Torrent)',
	'S-Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESAM 2.5 (Torrent)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESAM 5 (Torrent)',
	'S-Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESAM 5 (Torrent)'
);

-- line #29132
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESDIL 2.5 (Medley)',
	'S-Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESDIL 2.5 (Medley)'
);

-- line #29133
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESDIL 5 (Medley)',
	'S-Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESDIL 5 (Medley)'
);

-- line #29134
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESPIN 1.25 (Intas)',
	'S-Amlodipine',
	'TAB',
	gm.nullify_empty_string('1.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESPIN 1.25 (Intas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESPIN 2.5 (Intas)',
	'S-Amlodipine',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESPIN 2.5 (Intas)'
);

-- line #29135
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESPIN 5 (Intas)',
	'S-Amlodipine',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESPIN 5 (Intas)'
);

-- line #29136
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'S-Amlodipine', u'always_empty': u'', u'form': u'TAB', u'brand': u'RAMIPRO-A', u'strength_3': u'', u'company': u'Emcure', u'unit': u''}

-- line #29137
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAXIMUM 500 (CIPLA)',
	'SAQULNAVIR',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAXIMUM 500 (CIPLA)'
);

-- line #29138
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORMAPROST 160 (Troikaa)',
	'Saw Palmetto Extract',
	'CAP',
	gm.nullify_empty_string('160')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORMAPROST 160 (Troikaa)'
);

-- line #29139
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'160', u'strength_2': u'', u'substance': u'Saw Palmetto Extract', u'always_empty': u'', u'form': u'', u'brand': u'PROSTANORM SOFGEL', u'strength_3': u'', u'company': u'Macleods', u'unit': u'mg(LIQ.)'}

-- line #29140
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROSTONIL SOFTGEL 320 (Sanat)',
	'Saw Palmetto Extract',
	'CAP',
	gm.nullify_empty_string('320')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROSTONIL SOFTGEL 320 (Sanat)'
);

-- line #29141
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PYGINAL 50 (Serum Inst.)',
	'Saw Palmetto Extract',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PYGINAL 50 (Serum Inst.)'
);

-- line #29142
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONGLYZA 2.5 (BRISTOL MYERS)',
	'SAXAGLIPTIN',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONGLYZA 2.5 (BRISTOL MYERS)'
);

-- line #29143
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONGLYZA 5 (BRISTOL MYERS)',
	'SAXAGLIPTIN',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONGLYZA 5 (BRISTOL MYERS)'
);

-- line #29144
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Secnidazole', u'always_empty': u'', u'form': u'TAB', u'brand': u'AMBIFORM', u'strength_3': u'', u'company': u'Gsk', u'unit': u''}

-- line #29145
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMBIFORM 500 (Gsk)',
	'Secnidazole',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMBIFORM 500 (Gsk)'
);

-- line #29146
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Secnidazole', u'always_empty': u'', u'form': u'TAB', u'brand': u'AMITAB', u'strength_3': u'', u'company': u'Wockhardt', u'unit': u''}

-- line #29147
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Secnidazole', u'always_empty': u'', u'form': u'TAB', u'brand': u'ENTOSEC', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #29148
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1', u'strength_2': u'2;G', u'substance': u'Secnidazole', u'always_empty': u'', u'form': u'SAC', u'brand': u'ETISEC', u'strength_3': u'', u'company': u'NOVARTIS', u'unit': u''}

-- line #29149
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETISEC 500 (NOVARTIS)',
	'Secnidazole',
	'SAC',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETISEC 500 (NOVARTIS)'
);

-- line #29150
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Secnidazole', u'always_empty': u'', u'form': u'TAB', u'brand': u'FLAGENTYL', u'strength_3': u'', u'company': u'Protec', u'unit': u''}

-- line #29151
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Secnidazole', u'always_empty': u'', u'form': u'DS TAB', u'brand': u'NOAMEBA', u'strength_3': u'', u'company': u'Ipca', u'unit': u''}

-- line #29152
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Secnidazole', u'always_empty': u'', u'form': u'TAB', u'brand': u'PROZACTIN', u'strength_3': u'', u'company': u'Kapl', u'unit': u''}

-- line #29153
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYSKINIL 2 (Intas)',
	'Selegiline Hcl.',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYSKINIL 2 (Intas)'
);

-- line #29154
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELDEPRYL 10 (Themis)',
	'Selegiline Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELDEPRYL 10 (Themis)'
);

-- line #29155
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELDEPRYL 5 (Themis)',
	'Selegiline Hcl.',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELDEPRYL 5 (Themis)'
);

-- line #29156
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELEGELIN 5 (Sun)',
	'Selegiline Hcl.',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELEGELIN 5 (Sun)'
);

-- line #29157
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JUMAX 5 (Sanofi Aventis)',
	'Selegiline Hcl.',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JUMAX 5 (Sanofi Aventis)'
);

-- line #29158
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JUMAX 5 (Torrent)',
	'Selegiline Hcl.',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JUMAX 5 (Torrent)'
);

-- line #29159
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JUMEX 5 (Sanofi Aventis)',
	'Selegiline Hcl.',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JUMEX 5 (Sanofi Aventis)'
);

-- line #29160
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACFAST 10 (Kim Lab)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACFAST 10 (Kim Lab)'
);

-- line #29161
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADPEP 10 (Admac Ph.)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADPEP 10 (Admac Ph.)'
);

-- line #29162
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AFDASE 10 (Remedy)',
	'Serratiopeptidase',
	'F. TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AFDASE 10 (Remedy)'
);

-- line #29163
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AFDASE 5 (Remedy)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AFDASE 5 (Remedy)'
);

-- line #29164
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AFFYDASE 5 (AFFY)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AFFYDASE 5 (AFFY)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AFFYDASE 10 (AFFY)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AFFYDASE 10 (AFFY)'
);

-- line #29165
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALDASE 20 (Lincoln)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALDASE 20 (Lincoln)'
);

-- line #29166
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALDASE 5 (Lincoln)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALDASE 5 (Lincoln)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALDASE 10 (Lincoln)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALDASE 10 (Lincoln)'
);

-- line #29167
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALON 5 (Shrinivas)',
	'SERRATIOPEPTIDASE',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALON 5 (Shrinivas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALON 10 (Shrinivas)',
	'SERRATIOPEPTIDASE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALON 10 (Shrinivas)'
);

-- line #29168
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATODASE 10 (Atoz Ph.)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATODASE 10 (Atoz Ph.)'
);

-- line #29169
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVISERA 15 (Avalanche)',
	'SERRATIOPEPTIDASE',
	'F. TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVISERA 15 (Avalanche)'
);

-- line #29170
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AVISERA 5 (Avalanche)',
	'SERRATIOPEPTIDASE',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AVISERA 5 (Avalanche)'
);

-- line #29171
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXYDASE 10 (AXYZEN LIFE)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXYDASE 10 (AXYZEN LIFE)'
);

-- line #29172
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIDANZEN-F 10 (Gsk)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIDANZEN-F 10 (Gsk)'
);

-- line #29173
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIDANZEN 5 (Gsk)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIDANZEN 5 (Gsk)'
);

-- line #29174
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOBIDAN 10 (Biocin Hc.)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOBIDAN 10 (Biocin Hc.)'
);

-- line #29175
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIODASE 10 (BIOMEDICA)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIODASE 10 (BIOMEDICA)'
);

-- line #29176
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOSERA 10 (Panjon)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOSERA 10 (Panjon)'
);

-- line #29177
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOSUGANRIL 10 (Piramal Hc.)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOSUGANRIL 10 (Piramal Hc.)'
);

-- line #29178
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOSUGANRIL 20 (Piramal Hc.)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOSUGANRIL 20 (Piramal Hc.)'
);

-- line #29179
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOSUGANRIL 2.5 (Piramal Hc.)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOSUGANRIL 2.5 (Piramal Hc.)'
);

-- line #29180
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOSUGANRIL 5 (Piramal Hc.)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOSUGANRIL 5 (Piramal Hc.)'
);

-- line #29181
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPLASE 10 (Cipla)',
	'Serratiopeptidase',
	'F. TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPLASE 10 (Cipla)'
);

-- line #29182
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPLASE 5 (Cipla)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPLASE 5 (Cipla)'
);

-- line #29183
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPZEN 5 (Cipla)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPZEN 5 (Cipla)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPZEN 10 (Cipla)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPZEN 10 (Cipla)'
);

-- line #29184
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COPRES-M 10 (Obsurge)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COPRES-M 10 (Obsurge)'
);

-- line #29185
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COPRES-M 20 (Obsurge)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COPRES-M 20 (Obsurge)'
);

-- line #29186
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-SERRA 10 (Corona)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-SERRA 10 (Corona)'
);

-- line #29187
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CUZEN 10 (Cubit Hc.)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CUZEN 10 (Cubit Hc.)'
);

-- line #29188
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DASER 20 (Lanark)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DASER 20 (Lanark)'
);

-- line #29189
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DASER 5 (Lanark)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DASER 5 (Lanark)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DASER 10 (Lanark)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DASER 10 (Lanark)'
);

-- line #29190
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAZEN 10 (Chemo D.)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAZEN 10 (Chemo D.)'
);

-- line #29191
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAZINA 10 (Sayona)',
	'Serratiopeptidase',
	'F. TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAZINA 10 (Sayona)'
);

-- line #29192
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAZINA 5 (Sayona)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAZINA 5 (Sayona)'
);

-- line #29193
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLOZEN 10 (TWILIGHT LIT.)',
	'Serratiopeptidase',
	'F. TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLOZEN 10 (TWILIGHT LIT.)'
);

-- line #29194
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DRANZEN 10 (Drakt Int.)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DRANZEN 10 (Drakt Int.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DRANZEN 20 (Drakt Int.)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DRANZEN 20 (Drakt Int.)'
);

-- line #29195
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DRANZEN 2.5 (Drakt Int.)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DRANZEN 2.5 (Drakt Int.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DRANZEN 5 (Drakt Int.)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DRANZEN 5 (Drakt Int.)'
);

-- line #29196
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EARDIN 10 (Baroque)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EARDIN 10 (Baroque)'
);

-- line #29197
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EDASE 15 (Radix Bio.)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EDASE 15 (Radix Bio.)'
);

-- line #29198
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMANZEN-F 10 (Emcure)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMANZEN-F 10 (Emcure)'
);

-- line #29199
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMANZEN-F 20 (Emcure)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMANZEN-F 20 (Emcure)'
);

-- line #29200
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMANZEN 2.5 (Emcure)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMANZEN 2.5 (Emcure)'
);

-- line #29201
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMANZEN 5 (Emcure)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMANZEN 5 (Emcure)'
);

-- line #29202
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENSERA 10 (Bombay T.)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENSERA 10 (Bombay T.)'
);

-- line #29203
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENSERA 5 (Bombay T.)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENSERA 5 (Bombay T.)'
);

-- line #29204
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERDIN 5 (Baroque)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERDIN 5 (Baroque)'
);

-- line #29205
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FASMIC 10 (Allure Rem.)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FASMIC 10 (Allure Rem.)'
);

-- line #29206
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FASMIC 5 (Allure Rem.)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FASMIC 5 (Allure Rem.)'
);

-- line #29207
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FASTACT 10 (Unimax Lab)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FASTACT 10 (Unimax Lab)'
);

-- line #29208
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLANZEN 10 (Svizera)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLANZEN 10 (Svizera)'
);

-- line #29209
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLANZEN 20 (Svizera)',
	'SERRATIOPEPTIDASE',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLANZEN 20 (Svizera)'
);

-- line #29210
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLANZEN 2.5 (Svizera)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLANZEN 2.5 (Svizera)'
);

-- line #29211
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLANZEN 5 (Svizera)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLANZEN 5 (Svizera)'
);

-- line #29212
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOZEN 10 (Mankind)',
	'Serratiopeptidase',
	'F. TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOZEN 10 (Mankind)'
);

-- line #29213
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOZEN 5 (Mankind)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOZEN 5 (Mankind)'
);

-- line #29214
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEALAR 20 (Biostrass)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEALAR 20 (Biostrass)'
);

-- line #29215
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEALAR 5 (Biostrass)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEALAR 5 (Biostrass)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEALAR 10 (Biostrass)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEALAR 10 (Biostrass)'
);

-- line #29216
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEALASE 20 (Paras Lab)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEALASE 20 (Paras Lab)'
);

-- line #29217
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEALASE 5 (Paras Lab)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEALASE 5 (Paras Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEALASE 10 (Paras Lab)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEALASE 10 (Paras Lab)'
);

-- line #29218
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDODASE 10 (Indo-Reh Ph.)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDODASE 10 (Indo-Reh Ph.)'
);

-- line #29219
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INFLADASE 10 (Centaur)',
	'SERRATIOPEPTIDASE',
	'F.',
	gm.nullify_empty_string('10')::numeric,
	'mg(WITH COBALT MANGANESE'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INFLADASE 10 (Centaur)'
);

-- line #29220
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INFLADASE-F 10 (Centaur)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INFLADASE-F 10 (Centaur)'
);

-- line #29221
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INFLADASE 5 (Centaur)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INFLADASE 5 (Centaur)'
);

-- line #29222
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INFLANIL 10 (Bipl(Radico Lab))',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INFLANIL 10 (Bipl(Radico Lab))'
);

-- line #29223
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INSIDE 10 (Indian R.)',
	'Serratiopeptidase',
	'F. TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INSIDE 10 (Indian R.)'
);

-- line #29224
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INSIDE 5 (Indian R.)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INSIDE 5 (Indian R.)'
);

-- line #29225
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTASE 10 (Indu D.)',
	'Serratiopeptidase',
	'F. TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTASE 10 (Indu D.)'
);

-- line #29226
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTASE 5 (Indu D.)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTASE 5 (Indu D.)'
);

-- line #29227
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KASIDES 10 (Kaiser Ph.)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KASIDES 10 (Kaiser Ph.)'
);

-- line #29228
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEXER 10 (Cadex Lab)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEXER 10 (Cadex Lab)'
);

-- line #29229
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KINASE 5 (Lark Lab)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KINASE 5 (Lark Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KINASE 10 (Lark Lab)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KINASE 10 (Lark Lab)'
);

-- line #29230
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KINETO 10 (Systopic)',
	'Serratiopeptidase',
	'F. TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KINETO 10 (Systopic)'
);

-- line #29231
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KINETO 10 (Systopic)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KINETO 10 (Systopic)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KINETO 20 (Systopic)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KINETO 20 (Systopic)'
);

-- line #29232
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KINEX 10 (Strassenburg)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KINEX 10 (Strassenburg)'
);

-- line #29233
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KINEX 5 (Strassenburg)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KINEX 5 (Strassenburg)'
);

-- line #29234
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KOSER 10 (Briskon)',
	'Serratiopeptidase',
	'F. TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KOSER 10 (Briskon)'
);

-- line #29235
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LORATO 10 (Globus)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LORATO 10 (Globus)'
);

-- line #29236
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUPICT 5 (Lupin)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUPICT 5 (Lupin)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUPICT 10 (Lupin)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUPICT 10 (Lupin)'
);

-- line #29237
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUPISERA 10 (Lupin)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUPISERA 10 (Lupin)'
);

-- line #29238
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYSER-F 10 (Comed)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYSER-F 10 (Comed)'
);

-- line #29239
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYSER 20 (Comed)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYSER 20 (Comed)'
);

-- line #29240
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYSER 5 (Comed)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYSER 5 (Comed)'
);

-- line #29241
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MALOPEP 10 (Malody Hc.)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MALOPEP 10 (Malody Hc.)'
);

-- line #29242
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAUSERA 10 (Mamta Ph.)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAUSERA 10 (Mamta Ph.)'
);

-- line #29243
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAXILASE-F 10 (TABLETS I.)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAXILASE-F 10 (TABLETS I.)'
);

-- line #29244
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAXILASE 5 (TABLETS I.)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAXILASE 5 (TABLETS I.)'
);

-- line #29245
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICRODASE 10 (Winsome Lab)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICRODASE 10 (Winsome Lab)'
);

-- line #29246
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUCOZEN 10 (Zenith Hc.)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUCOZEN 10 (Zenith Hc.)'
);

-- line #29247
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUCOZEN 5 (Zenith Hc.)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUCOZEN 5 (Zenith Hc.)'
);

-- line #29248
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLSERAZ -F 10 (Olcare)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLSERAZ -F 10 (Olcare)'
);

-- line #29249
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLSERAZ 5 (Olcare)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLSERAZ 5 (Olcare)'
);

-- line #29250
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPTASE 10 (Osper)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPTASE 10 (Osper)'
);

-- line #29251
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OP-ZED 10 (Croslands)',
	'Serratiopeptidase',
	'F. TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OP-ZED 10 (Croslands)'
);

-- line #29252
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OP-ZED 5 (Croslands)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OP-ZED 5 (Croslands)'
);

-- line #29253
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORRA-20 20 (ORION BIOTECH.)',
	'SERRATIOPEPTIDASE',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORRA-20 20 (ORION BIOTECH.)'
);

-- line #29254
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEPDOL 10 (VENSAT)',
	'SERRATIOPEPTIDASE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEPDOL 10 (VENSAT)'
);

-- line #29255
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEPSER 5 (Acme Ph)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEPSER 5 (Acme Ph)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEPSER 10 (Acme Ph)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEPSER 10 (Acme Ph)'
);

-- line #29256
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEPSER 10 (Intra Lab)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEPSER 10 (Intra Lab)'
);

-- line #29257
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEPTISOJ 10 (PSYCOREM)',
	'SERRATIOPEPTIDASE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEPTISOJ 10 (PSYCOREM)'
);

-- line #29258
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEPZEN 5 (Cadila Ph.)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEPZEN 5 (Cadila Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEPZEN 10 (Cadila Ph.)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEPZEN 10 (Cadila Ph.)'
);

-- line #29259
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEVANASE 10 (Maneesh)',
	'Serratiopeptidase',
	'F. TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEVANASE 10 (Maneesh)'
);

-- line #29260
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEVANASE 5 (Maneesh)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEVANASE 5 (Maneesh)'
);

-- line #29261
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PIFDASE 10 (Pifer Ph.)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PIFDASE 10 (Pifer Ph.)'
);

-- line #29262
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIMEDASE 10 (Shreya)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIMEDASE 10 (Shreya)'
);

-- line #29263
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRIMEDASE 5 (Shreya)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRIMEDASE 5 (Shreya)'
);

-- line #29264
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRODASE 10 (Dynamic)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRODASE 10 (Dynamic)'
);

-- line #29265
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROKEN 5 (Prochem)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROKEN 5 (Prochem)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROKEN 10 (Prochem)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROKEN 10 (Prochem)'
);

-- line #29266
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROTEO 10 (Mars Rem.)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROTEO 10 (Mars Rem.)'
);

-- line #29267
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAPTIZ 10 (Ophthal R.)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAPTIZ 10 (Ophthal R.)'
);

-- line #29268
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAPTIZ 5 (Ophthal R.)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAPTIZ 5 (Ophthal R.)'
);

-- line #29269
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELIDASE 10 (Relish)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELIDASE 10 (Relish)'
);

-- line #29270
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELIDASE 5 (Relish)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELIDASE 5 (Relish)'
);

-- line #29271
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESERAT 10 (Regent)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESERAT 10 (Regent)'
);

-- line #29272
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESOLVE 10 (Neuron Ph.)',
	'Serratiopeptidase',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESOLVE 10 (Neuron Ph.)'
);

-- line #29273
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'FSERRATIO', u'strength_2': u'', u'substance': u'Serratiopeptidase', u'always_empty': u'', u'form': u'TAB', u'brand': u'RESOLVE', u'strength_3': u'', u'company': u'Neuron Ph.', u'unit': u''}

-- line #29274
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONABET 2 (Glenmark)',
	'SERTACONAZOLE NITRATE',
	'CRM',
	gm.nullify_empty_string('2')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONABET 2 (Glenmark)'
);

-- line #29275
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONABET V1 500 (Glenmark)',
	'SERTACONAZOLE NITRATE',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONABET V1 500 (Glenmark)'
);

-- line #29276
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTISER 100 (Unimarck)',
	'Sertraline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTISER 100 (Unimarck)'
);

-- line #29277
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTISER 25 (Unimarck)',
	'Sertraline',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTISER 25 (Unimarck)'
);

-- line #29278
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTISER 50 (Unimarck)',
	'Sertraline',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTISER 50 (Unimarck)'
);

-- line #29279
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADERTA 50 (Shinto Org.)',
	'Sertraline',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADERTA 50 (Shinto Org.)'
);

-- line #29280
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALSERTRA 50 (ALPHA TH.)',
	'Sertraline',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALSERTRA 50 (ALPHA TH.)'
);

-- line #29281
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CENSIR 50 (Sanify)',
	'Sertraline',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CENSIR 50 (Sanify)'
);

-- line #29282
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAXID 100 (Pfizer)',
	'Sertraline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAXID 100 (Pfizer)'
);

-- line #29283
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAXID 50 (Pfizer)',
	'Sertraline',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAXID 50 (Pfizer)'
);

-- line #29284
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPSERT 100 (Reliance)',
	'Sertraline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPSERT 100 (Reliance)'
);

-- line #29285
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPSERT 25 (Reliance)',
	'Sertraline',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPSERT 25 (Reliance)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPSERT 50 (Reliance)',
	'Sertraline',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPSERT 50 (Reliance)'
);

-- line #29286
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ECCITE 100 (Morepen)',
	'Sertraline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ECCITE 100 (Morepen)'
);

-- line #29287
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ECCITE 50 (Morepen)',
	'Sertraline',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ECCITE 50 (Morepen)'
);

-- line #29288
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPISOD 100 (PSYCOREM)',
	'Sertraline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPISOD 100 (PSYCOREM)'
);

-- line #29289
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPISOD 25 (PSYCOREM)',
	'Sertraline',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'50'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPISOD 25 (PSYCOREM)'
);

-- line #29290
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INOSERT 25 (Ipca)',
	'Sertraline',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INOSERT 25 (Ipca)'
);

-- line #29291
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INOSERT 50 (Ipca)',
	'Sertraline',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INOSERT 50 (Ipca)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INOSERT 100 (Ipca)',
	'Sertraline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INOSERT 100 (Ipca)'
);

-- line #29292
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINDEP 100 (Orchid Hc.)',
	'Sertraline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINDEP 100 (Orchid Hc.)'
);

-- line #29293
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINDEP 25 (Orchid Hc.)',
	'Sertraline',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINDEP 25 (Orchid Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINDEP 50 (Orchid Hc.)',
	'Sertraline',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINDEP 50 (Orchid Hc.)'
);

-- line #29294
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MENTOLIFT 50 (Symbiotic)',
	'Sertraline',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MENTOLIFT 50 (Symbiotic)'
);

-- line #29295
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANOLAM 50 (Tnt Life)',
	'Sertraline',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANOLAM 50 (Tnt Life)'
);

-- line #29296
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESERT 100 (Argus)',
	'Sertraline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESERT 100 (Argus)'
);

-- line #29297
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESERT 50 (Argus)',
	'Sertraline',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESERT 50 (Argus)'
);

-- line #29298
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RETALIN 50 (Pil)',
	'Sertraline',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RETALIN 50 (Pil)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RETALIN 100 (Pil)',
	'Sertraline',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RETALIN 100 (Pil)'
);

-- line #29299
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACUTROL-C 400 (Intas)',
	'SEVELAMER HCL.',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg(CARBONATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACUTROL-C 400 (Intas)'
);

-- line #29300
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACUTROL-C 800 (Intas)',
	'SEVELAMER HCL.',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg(CARBONATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACUTROL-C 800 (Intas)'
);

-- line #29301
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACUTROL 400 (Intas)',
	'SEVELAMER HCL.',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACUTROL 400 (Intas)'
);

-- line #29302
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'400', u'strength_2': u'', u'substance': u'SEVELAMER HCL.', u'always_empty': u'', u'form': u'', u'brand': u'BIOSEV', u'strength_3': u'', u'company': u'Biocon', u'unit': u'mg'}

-- line #29303
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'800', u'strength_2': u'', u'substance': u'SEVELAMER HCL.', u'always_empty': u'', u'form': u'', u'brand': u'BIOSEV', u'strength_3': u'', u'company': u'Biocon', u'unit': u'mg'}

-- line #29304
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'400', u'strength_2': u'', u'substance': u'SEVELAMER HCL.', u'always_empty': u'', u'form': u'', u'brand': u'FOSCHEK S', u'strength_3': u'', u'company': u'Wochardt', u'unit': u'mg(CARBONATE)'}

-- line #29305
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'800', u'strength_2': u'', u'substance': u'SEVELAMER HCL.', u'always_empty': u'', u'form': u'', u'brand': u'FOSCHEK S', u'strength_3': u'', u'company': u'Wochardt', u'unit': u'mg(CARBONATE)'}

-- line #29306
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOSEAL 400 (Emcure)',
	'SEVELAMER HCL.',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOSEAL 400 (Emcure)'
);

-- line #29307
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FOSEAL 800 (Emcure)',
	'SEVELAMER HCL.',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FOSEAL 800 (Emcure)'
);

-- line #29308
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAXORUS 400 (Unichem)',
	'SEVELAMER HCL.',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAXORUS 400 (Unichem)'
);

-- line #29309
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEPHLOMER 400 (Ipca)',
	'SEVELAMER HCL.',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg(CARBONATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEPHLOMER 400 (Ipca)'
);

-- line #29310
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEPHLOMER 800 (Ipca)',
	'SEVELAMER HCL.',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg(CARBONATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEPHLOMER 800 (Ipca)'
);

-- line #29311
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEBIND-400 400 (Emcure)',
	'SEVELAMER HCL.',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg(CARBONATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEBIND-400 400 (Emcure)'
);

-- line #29312
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEBIND-800 800 (Emcure)',
	'SEVELAMER HCL.',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg(CARBONATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEBIND-800 800 (Emcure)'
);

-- line #29313
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RENAVAL 400 (TAJ PH.)',
	'SEVELAMER HCL.',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RENAVAL 400 (TAJ PH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RENAVAL 800 (TAJ PH.)',
	'SEVELAMER HCL.',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RENAVAL 800 (TAJ PH.)'
);

-- line #29314
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REVLAMER 400 (Sun)',
	'SEVELAMER HCL.',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg(CARBONATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REVLAMER 400 (Sun)'
);

-- line #29315
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REVLAMER 800 (Sun)',
	'SEVELAMER HCL.',
	'TAB',
	gm.nullify_empty_string('800')::numeric,
	'mg(CARBONATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REVLAMER 800 (Sun)'
);

-- line #29316
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BEUTER 15 (Sunrise Rem.)',
	'Sibutramine',
	'CAP',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BEUTER 15 (Sunrise Rem.)'
);

-- line #29317
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BEUTER 5 (Sunrise Rem.)',
	'Sibutramine',
	'CAP',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BEUTER 5 (Sunrise Rem.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BEUTER 10 (Sunrise Rem.)',
	'Sibutramine',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BEUTER 10 (Sunrise Rem.)'
);

-- line #29318
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEOBESE-10 10 (Mankind)',
	'Sibutramine',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEOBESE-10 10 (Mankind)'
);

-- line #29319
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FETRASIL 10 (TAJ PH.)',
	'Sibutramine',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FETRASIL 10 (TAJ PH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FETRASIL 15 (TAJ PH.)',
	'Sibutramine',
	'CAP',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FETRASIL 15 (TAJ PH.)'
);

-- line #29320
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEEP FIT 10 (Indilina Ph.)',
	'Sibutramine',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEEP FIT 10 (Indilina Ph.)'
);

-- line #29321
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEPTOS 10 (Abbott)',
	'Sibutramine',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEPTOS 10 (Abbott)'
);

-- line #29322
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEPTOS 15 (Abbott)',
	'Sibutramine',
	'CAP',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEPTOS 15 (Abbott)'
);

-- line #29323
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OBECURE 2.5 (Emcure)',
	'Sibutramine',
	'CAP',
	gm.nullify_empty_string('2.5')::numeric,
	'mg ( R ) -'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OBECURE 2.5 (Emcure)'
);

-- line #29324
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OBECURE 5 (Emcure)',
	'Sibutramine',
	'CAPSULES',
	gm.nullify_empty_string('5')::numeric,
	'mg(( R ) SIBUTRAMINE HCL.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OBECURE 5 (Emcure)'
);

-- line #29325
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OBEGO 5 (Intas)',
	'Sibutramine',
	'CAP',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OBEGO 5 (Intas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OBEGO 10 (Intas)',
	'Sibutramine',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OBEGO 10 (Intas)'
);

-- line #29326
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OBESAVE 10 (ERIS LIFE)',
	'Sibutramine',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OBESAVE 10 (ERIS LIFE)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OBESAVE 15 (ERIS LIFE)',
	'Sibutramine',
	'CAP',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OBESAVE 15 (ERIS LIFE)'
);

-- line #29327
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OBE-SLIM 10 (UNITED LIFE)',
	'Sibutramine',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OBE-SLIM 10 (UNITED LIFE)'
);

-- line #29328
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OBESTAT 5 (Cipla)',
	'Sibutramine',
	'CAP',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OBESTAT 5 (Cipla)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OBESTAT 10 (Cipla)',
	'Sibutramine',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OBESTAT 10 (Cipla)'
);

-- line #29329
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OBIRAX 10 (Micro Labs)',
	'Sibutramine',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OBIRAX 10 (Micro Labs)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OBIRAX 15 (Micro Labs)',
	'Sibutramine',
	'CAP',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OBIRAX 15 (Micro Labs)'
);

-- line #29330
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REDUCE 10 (Ordain Hc.)',
	'Sibutramine',
	'CAP',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REDUCE 10 (Ordain Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REDUCE 15 (Ordain Hc.)',
	'Sibutramine',
	'CAP',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REDUCE 15 (Ordain Hc.)'
);

-- line #29331
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'11PM (100mg) 100 (Wisdom Ph.)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '11PM (100mg) 100 (Wisdom Ph.)'
);

-- line #29332
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'11PM (50 mg) 50 (Wisdom Ph.)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '11PM (50 mg) 50 (Wisdom Ph.)'
);

-- line #29333
-- ignoring line: empty field [company]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'25', u'strength_2': u'50', u'substance': u'Sildenafil Citrate', u'always_empty': u'', u'form': u'TAB', u'brand': u'1-2-3', u'strength_3': u'', u'company': u'', u'unit': u'mg'}

-- line #29334
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'90-E 50 (Khandelwal)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '90-E 50 (Khandelwal)'
);

-- line #29335
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADAMS DELITE 50 (Ind-Swift)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADAMS DELITE 50 (Ind-Swift)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADAMS DELITE 100 (Ind-Swift)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADAMS DELITE 100 (Ind-Swift)'
);

-- line #29336
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AIRBUS 50 (Sanify)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AIRBUS 50 (Sanify)'
);

-- line #29337
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALSIGRA 25 (Alembic)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALSIGRA 25 (Alembic)'
);

-- line #29338
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALSIGRA 50 (Alembic)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALSIGRA 50 (Alembic)'
);

-- line #29339
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANDROZ 100 (Torrent)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANDROZ 100 (Torrent)'
);

-- line #29340
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANDROZ 25 (Torrent)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANDROZ 25 (Torrent)'
);

-- line #29341
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANDROZ 50 (Torrent)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANDROZ 50 (Torrent)'
);

-- line #29342
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASSURANS 20 (Cipla)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASSURANS 20 (Cipla)'
);

-- line #29343
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOGRO 50 (SANCHEZ LAB.)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOGRO 50 (SANCHEZ LAB.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOGRO 100 (SANCHEZ LAB.)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOGRO 100 (SANCHEZ LAB.)'
);

-- line #29344
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BISON 50 (JUGGAT PH.)',
	'Sildenafil Citrate',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BISON 50 (JUGGAT PH.)'
);

-- line #29345
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAVERTA 100 (Ranbaxy)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAVERTA 100 (Ranbaxy)'
);

-- line #29346
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAVERTA 25 (Ranbaxy)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAVERTA 25 (Ranbaxy)'
);

-- line #29347
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAVERTA 50 (Ranbaxy)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAVERTA 50 (Ranbaxy)'
);

-- line #29348
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'C-GRA 50 (Corona)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'C-GRA 50 (Corona)'
);

-- line #29349
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUAGRA 50 (Raddison Hc.)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUAGRA 50 (Raddison Hc.)'
);

-- line #29350
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EDEGRA 100 (Sun)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EDEGRA 100 (Sun)'
);

-- line #29351
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EDEGRA 25 (Sun)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EDEGRA 25 (Sun)'
);

-- line #29352
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EDEGRA 50 (Sun)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EDEGRA 50 (Sun)'
);

-- line #29353
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELIGRA 50 (Esken)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELIGRA 50 (Esken)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELIGRA 100 (Esken)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELIGRA 100 (Esken)'
);

-- line #29354
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENTHUSIA 50 (Lupin)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENTHUSIA 50 (Lupin)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENTHUSIA 100 (Lupin)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENTHUSIA 100 (Lupin)'
);

-- line #29355
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EREC 50 (Panjon)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EREC 50 (Panjon)'
);

-- line #29356
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERIX 100 (Unichem)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERIX 100 (Unichem)'
);

-- line #29357
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERIX 25 (Unichem)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERIX 25 (Unichem)'
);

-- line #29358
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERIX 50 (Unichem)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERIX 50 (Unichem)'
);

-- line #29359
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNN 50 (Sienna Form.)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNN 50 (Sienna Form.)'
);

-- line #29360
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HONYGRA 25 (Bennet Ph.)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HONYGRA 25 (Bennet Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HONYGRA 100 (Bennet Ph.)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HONYGRA 100 (Bennet Ph.)'
);

-- line #29361
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HONYGRA 50 (Bennet Ph.)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HONYGRA 50 (Bennet Ph.)'
);

-- line #29362
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMNIGRA 100 (Cipla)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMNIGRA 100 (Cipla)'
);

-- line #29363
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTEGRA 50 (Intra Lab)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTEGRA 50 (Intra Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTEGRA 100 (Intra Lab)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTEGRA 100 (Intra Lab)'
);

-- line #29364
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTIGRA 50 (Embiotic Lab.)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTIGRA 50 (Embiotic Lab.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTIGRA 100 (Embiotic Lab.)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTIGRA 100 (Embiotic Lab.)'
);

-- line #29365
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JAUN 100 (Cadila)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JAUN 100 (Cadila)'
);

-- line #29366
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JAUN 25 (Cadila)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg/50'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JAUN 25 (Cadila)'
);

-- line #29367
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JUAN 100 (Cadila Ph.)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JUAN 100 (Cadila Ph.)'
);

-- line #29368
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JUAN 25 (Cadila Ph.)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JUAN 25 (Cadila Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JUAN 50 (Cadila Ph.)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JUAN 50 (Cadila Ph.)'
);

-- line #29369
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KAMAGRA 100 (Ajanta Ph.)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KAMAGRA 100 (Ajanta Ph.)'
);

-- line #29370
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KAMAGRA 25 (Ajanta Ph.)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KAMAGRA 25 (Ajanta Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KAMAGRA 50 (Ajanta Ph.)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KAMAGRA 50 (Ajanta Ph.)'
);

-- line #29371
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KYLAGRA 100 (Kylsans D.)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KYLAGRA 100 (Kylsans D.)'
);

-- line #29372
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KYLAGRA 25 (Kylsans D.)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KYLAGRA 25 (Kylsans D.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KYLAGRA 50 (Kylsans D.)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KYLAGRA 50 (Kylsans D.)'
);

-- line #29373
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUPIGRA 50 (LUPin)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUPIGRA 50 (LUPin)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUPIGRA 100 (LUPin)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUPIGRA 100 (LUPin)'
);

-- line #29374
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANEGRA 50 (P C INDIA)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANEGRA 50 (P C INDIA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANEGRA 100 (P C INDIA)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANEGRA 100 (P C INDIA)'
);

-- line #29375
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANFORC-25 25 (Mankind)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANFORC-25 25 (Mankind)'
);

-- line #29376
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANFORCE 100 (Mankind)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANFORCE 100 (Mankind)'
);

-- line #29377
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANFORCE 50 (Mankind)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANFORCE 50 (Mankind)'
);

-- line #29378
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANLY 50 (Dynamic)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANLY 50 (Dynamic)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANLY 100 (Dynamic)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANLY 100 (Dynamic)'
);

-- line #29379
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOGRA 50 (Medoz Ph.)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOGRA 50 (Medoz Ph.)'
);

-- line #29380
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOGRA 25 (TAJ PH.)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOGRA 25 (TAJ PH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOGRA 50 (TAJ PH.)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOGRA 50 (TAJ PH.)'
);

-- line #29381
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIAGRA 100 (Maneesh)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIAGRA 100 (Maneesh)'
);

-- line #29382
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIAGRA 25 (Maneesh)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIAGRA 25 (Maneesh)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIAGRA 50 (Maneesh)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIAGRA 50 (Maneesh)'
);

-- line #29383
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NYTE 100 (Kopran)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NYTE 100 (Kopran)'
);

-- line #29384
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NYTE 25 (Kopran)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NYTE 25 (Kopran)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NYTE 50 (Kopran)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NYTE 50 (Kopran)'
);

-- line #29385
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50', u'strength_2': u'', u'substance': u'Sildenafil Citrate', u'always_empty': u'', u'form': u'', u'brand': u'ONTOP SILDENAFIL CITRATE', u'strength_3': u'', u'company': u'ONTOP', u'unit': u'mg'}

-- line #29386
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEFOMAX 50 (Bestochem)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEFOMAX 50 (Bestochem)'
);

-- line #29387
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEFOMAX 50 (Emcure)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEFOMAX 50 (Emcure)'
);

-- line #29388
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEN-DRIVE 100 (MODHIKE)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEN-DRIVE 100 (MODHIKE)'
);

-- line #29389
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENEGRA 100 (Zydus Cadila)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENEGRA 100 (Zydus Cadila)'
);

-- line #29390
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENEGRA 25 (Zydus Cadila)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENEGRA 25 (Zydus Cadila)'
);

-- line #29391
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENEGRA 50 (Zydus Cadila)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENEGRA 50 (Zydus Cadila)'
);

-- line #29392
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POWERMAN 50 (Piramal Hc.)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POWERMAN 50 (Piramal Hc.)'
);

-- line #29393
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POWERPLAY 100 (Moraceae)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POWERPLAY 100 (Moraceae)'
);

-- line #29394
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROGRA 100 (Protec)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROGRA 100 (Protec)'
);

-- line #29395
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROGRA 25 (Protec)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROGRA 25 (Protec)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROGRA 50 (Protec)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROGRA 50 (Protec)'
);

-- line #29396
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REZUM 100 (Dr.Reddy''S)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REZUM 100 (Dr.Reddy''S)'
);

-- line #29397
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REZUM 25 (Dr.Reddy''S)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REZUM 25 (Dr.Reddy''S)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REZUM 50 (Dr.Reddy''S)',
	'Sildenafil Citrate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REZUM 50 (Dr.Reddy''S)'
);

-- line #29398
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'GEL', u'strength_2': u'', u'substance': u'Silicone OIL', u'always_empty': u'', u'form': u'GEL', u'brand': u'BIO CORNE', u'strength_3': u'', u'company': u'Wockhardt', u'unit': u''}

-- line #29399
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Silicone OIL', u'always_empty': u'', u'form': u'GEL', u'brand': u'KELO-COTE', u'strength_3': u'', u'company': u'Wockhardt', u'unit': u''}

-- line #29400
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10MLV (STERFILE)', u'strength_2': u'', u'substance': u'Silicone Oil', u'always_empty': u'', u'form': u'V', u'brand': u'OCUSIL', u'strength_3': u'', u'company': u'Cadila Ph.', u'unit': u''}

-- line #29401
-- ignoring line: field [strength_1] not numeric: >>>1000CST<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000CST', u'strength_2': u'', u'substance': u'Silicone OIL', u'always_empty': u'', u'form': u'OIL', u'brand': u'RETISIL', u'strength_3': u'', u'company': u'SENSES', u'unit': u'5000CST'}

-- line #29402
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'SILVER NITRATE', u'always_empty': u'', u'form': u'GEL', u'brand': u'IONSIL', u'strength_3': u'', u'company': u'Virchow Bio.', u'unit': u''}

-- line #29403
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AGINATE 1 (Oscar Rem.)',
	'Silver Sulphadiazine',
	'EYE DPS',
	gm.nullify_empty_string('1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AGINATE 1 (Oscar Rem.)'
);

-- line #29404
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Silver Sulphadiazine', u'always_empty': u'', u'form': u'CRM', u'brand': u'CEPTIDAR', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #29405
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPTISIL 1 (Indiana O.)',
	'Silver Sulphadiazine',
	'E/E DPS',
	gm.nullify_empty_string('1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPTISIL 1 (Indiana O.)'
);

-- line #29406
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALRIN-B 70 (Admac Ph.)',
	'Silymarin',
	'CAP',
	gm.nullify_empty_string('70')::numeric,
	'mg(+VIT B COMPLEX)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALRIN-B 70 (Admac Ph.)'
);

-- line #29407
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEPASIL 70 (SIGNOVA)',
	'Silymarin',
	'CAP',
	gm.nullify_empty_string('70')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEPASIL 70 (SIGNOVA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEPASIL 140 (SIGNOVA)',
	'Silymarin',
	'CAP',
	gm.nullify_empty_string('140')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEPASIL 140 (SIGNOVA)'
);

-- line #29408
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEPASIL 35 (SIGNOVA)',
	'Silymarin',
	'SYR',
	gm.nullify_empty_string('35')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEPASIL 35 (SIGNOVA)'
);

-- line #29409
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEPASYL 140 (Allure Rem.)',
	'Silymarin',
	'TAB',
	gm.nullify_empty_string('140')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEPASYL 140 (Allure Rem.)'
);

-- line #29410
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEPASYL 70 (Allure Rem.)',
	'Silymarin',
	'TAB',
	gm.nullify_empty_string('70')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEPASYL 70 (Allure Rem.)'
);

-- line #29411
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEPOX 70 (Apex Form.)',
	'Silymarin',
	'TAB',
	gm.nullify_empty_string('70')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEPOX 70 (Apex Form.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEPOX 140 (Apex Form.)',
	'Silymarin',
	'TAB',
	gm.nullify_empty_string('140')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEPOX 140 (Apex Form.)'
);

-- line #29412
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEPSIL 35 (Shreeyam)',
	'Silymarin',
	'SUS',
	gm.nullify_empty_string('35')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEPSIL 35 (Shreeyam)'
);

-- line #29413
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEPSIL 140 (Shreeyam)',
	'Silymarin',
	'TAB',
	gm.nullify_empty_string('140')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEPSIL 140 (Shreeyam)'
);

-- line #29414
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEPSIL 70 (Shreeyam)',
	'Silymarin',
	'TAB',
	gm.nullify_empty_string('70')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEPSIL 70 (Shreeyam)'
);

-- line #29415
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'LECITHIN', u'strength_2': u'', u'substance': u'Silymarin', u'always_empty': u'', u'form': u'CAP', u'brand': u'LECIVIT', u'strength_3': u'', u'company': u'Life Line', u'unit': u''}

-- line #29416
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LECIVIT-S 35 (Life Line)',
	'Silymarin',
	'SUS',
	gm.nullify_empty_string('35')::numeric,
	'mg/5ML(+LECITHIN 125'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LECIVIT-S 35 (Life Line)'
);

-- line #29417
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVALON 140 (Brown & B.)',
	'Silymarin',
	'TAB',
	gm.nullify_empty_string('140')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVALON 140 (Brown & B.)'
);

-- line #29418
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEVALON 70 (Brown & B.)',
	'Silymarin',
	'TAB',
	gm.nullify_empty_string('70')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEVALON 70 (Brown & B.)'
);

-- line #29419
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIMARIN 35 (Serum Inst.)',
	'Silymarin',
	'SYR',
	gm.nullify_empty_string('35')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIMARIN 35 (Serum Inst.)'
);

-- line #29420
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIMARIN 140 (Serum Inst.)',
	'Silymarin',
	'TAB',
	gm.nullify_empty_string('140')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIMARIN 140 (Serum Inst.)'
);

-- line #29421
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIMARIN 70 (Serum Inst.)',
	'Silymarin',
	'TAB',
	gm.nullify_empty_string('70')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIMARIN 70 (Serum Inst.)'
);

-- line #29422
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIVAD 35 (Aldok Ph.)',
	'Silymarin',
	'SUS',
	gm.nullify_empty_string('35')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIVAD 35 (Aldok Ph.)'
);

-- line #29423
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIVERUBIN 140 (ALCHEM PHY.)',
	'Silymarin',
	'TAB',
	gm.nullify_empty_string('140')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIVERUBIN 140 (ALCHEM PHY.)'
);

-- line #29424
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIVOSIL 140 (Centaur)',
	'Silymarin',
	'F. SYR',
	gm.nullify_empty_string('140')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIVOSIL 140 (Centaur)'
);

-- line #29425
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIVOSIL 35 (Centaur)',
	'Silymarin',
	'SUS',
	gm.nullify_empty_string('35')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIVOSIL 35 (Centaur)'
);

-- line #29426
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIVTEC 35 (Ampus Life)',
	'Silymarin',
	'SYR',
	gm.nullify_empty_string('35')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIVTEC 35 (Ampus Life)'
);

-- line #29427
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIVTEC 70 (Ampus Life)',
	'Silymarin',
	'TAB',
	gm.nullify_empty_string('70')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIVTEC 70 (Ampus Life)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIVTEC 140 (Ampus Life)',
	'Silymarin',
	'TAB',
	gm.nullify_empty_string('140')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIVTEC 140 (Ampus Life)'
);

-- line #29428
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYMA 35 (Alpic Rem.)',
	'Silymarin',
	'SUS',
	gm.nullify_empty_string('35')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYMA 35 (Alpic Rem.)'
);

-- line #29429
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYMO 70 (Alpic Rem.)',
	'Silymarin',
	'TAB',
	gm.nullify_empty_string('70')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYMO 70 (Alpic Rem.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYMO 140 (Alpic Rem.)',
	'Silymarin',
	'TAB',
	gm.nullify_empty_string('140')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYMO 140 (Alpic Rem.)'
);

-- line #29430
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYMY 70 (Biocin Hc.)',
	'Silymarin',
	'TAB',
	gm.nullify_empty_string('70')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYMY 70 (Biocin Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYMY 140 (Biocin Hc.)',
	'Silymarin',
	'TAB',
	gm.nullify_empty_string('140')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYMY 140 (Biocin Hc.)'
);

-- line #29431
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MARISIL 70 (Chemo D.)',
	'Silymarin',
	'TAB',
	gm.nullify_empty_string('70')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MARISIL 70 (Chemo D.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MARISIL 140 (Chemo D.)',
	'Silymarin',
	'TAB',
	gm.nullify_empty_string('140')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MARISIL 140 (Chemo D.)'
);

-- line #29432
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITOLIV 70 (BIOMAX BIO.)',
	'Silymarin',
	'TAB',
	gm.nullify_empty_string('70')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITOLIV 70 (BIOMAX BIO.)'
);

-- line #29433
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'WITH B-COMPLEX', u'strength_2': u'', u'substance': u'Silymarin', u'always_empty': u'', u'form': u'', u'brand': u'OXYLIV NS', u'strength_3': u'', u'company': u'VOTARY LAB', u'unit': u''}

-- line #29434
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'WITH B-COMPLEX', u'strength_2': u'', u'substance': u'Silymarin', u'always_empty': u'', u'form': u'CAP', u'brand': u'PALRON', u'strength_3': u'', u'company': u'AAMORB', u'unit': u''}

-- line #29435
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROHEP 140 (Lupin)',
	'Silymarin',
	'F. TAB',
	gm.nullify_empty_string('140')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROHEP 140 (Lupin)'
);

-- line #29436
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROHEP 70 (Lupin)',
	'Silymarin',
	'TAB',
	gm.nullify_empty_string('70')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROHEP 70 (Lupin)'
);

-- line #29437
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOSIM 10 (Biochem)',
	'Simvastatin',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOSIM 10 (Biochem)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOSIM 20 (Biochem)',
	'Simvastatin',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOSIM 20 (Biochem)'
);

-- line #29438
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOSIM 5 (Biochem)',
	'Simvastatin',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOSIM 5 (Biochem)'
);

-- line #29439
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'SINGLE MALARIA CARD TEST', u'always_empty': u'', u'form': u'', u'brand': u'MALATRIT PAN/PS', u'strength_3': u'', u'company': u'Piramal Hc.', u'unit': u''}

-- line #29440
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMTOR 1 (Emcure)',
	'SIROLIMUS',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMTOR 1 (Emcure)'
);

-- line #29441
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIMUS 1 (Claris L.)',
	'SIROLIMUS',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIMUS 1 (Claris L.)'
);

-- line #29442
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIMUS 1 (Claris L.)',
	'SIROLIMUS',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIMUS 1 (Claris L.)'
);

-- line #29443
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENSAMYCIN 0.1 (Fulford)',
	'Sisomicin',
	'CRM',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENSAMYCIN 0.1 (Fulford)'
);

-- line #29444
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENSAMYCIN 3 (Fulford)',
	'Sisomicin',
	'DPS',
	gm.nullify_empty_string('3')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENSAMYCIN 3 (Fulford)'
);

-- line #29445
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENSAMYCIN 10 (Fulford)',
	'Sisomicin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENSAMYCIN 10 (Fulford)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENSAMYCIN 50 (Fulford)',
	'Sisomicin',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENSAMYCIN 50 (Fulford)'
);

-- line #29446
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESMYCIN 1 (SYNOPSIS)',
	'Sisomicin',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESMYCIN 1 (SYNOPSIS)'
);

-- line #29447
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100', u'strength_2': u'', u'substance': u'SITAGLIPTIN', u'always_empty': u'', u'form': u'', u'brand': u'JANUVIA', u'strength_3': u'', u'company': u'MSD PH.', u'unit': u'mg'}

-- line #29448
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'25', u'strength_2': u'', u'substance': u'SITAGLIPTIN', u'always_empty': u'', u'form': u'', u'brand': u'JANUVIA', u'strength_3': u'', u'company': u'MSD PH.', u'unit': u'mg'}

-- line #29449
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50', u'strength_2': u'', u'substance': u'SITAGLIPTIN', u'always_empty': u'', u'form': u'', u'brand': u'JANUVIA', u'strength_3': u'', u'company': u'MSD PH.', u'unit': u'mg'}

-- line #29450
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'60', u'strength_2': u'', u'substance': u'Sod.Aminosalicylate', u'always_empty': u'', u'form': u'', u'brand': u'MONOPAS JAR', u'strength_3': u'', u'company': u'Macleods', u'unit': u'%W/W'}

-- line #29451
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Sod.Aminosalicylate', u'always_empty': u'', u'form': u'TAB', u'brand': u'MONOPAS', u'strength_3': u'', u'company': u'Macleods', u'unit': u''}

-- line #29452
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q-PAS 800 (Lupin)',
	'Sod.Aminosalicylate',
	'GRAN',
	gm.nullify_empty_string('800')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q-PAS 800 (Lupin)'
);

-- line #29453
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,74', u'strength_2': u'', u'substance': u'Sod.Chl.', u'always_empty': u'', u'form': u'', u'brand': u'CLEARNOZ NS', u'strength_3': u'', u'company': u'Cipla', u'unit': u'%(+BENZALKONIUM CHL. 0.01'}

-- line #29454
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVILINE 0.65 (DIVINE LAB.)',
	'SOD.CHL.',
	'NASAL DROPS',
	gm.nullify_empty_string('0.65')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVILINE 0.65 (DIVINE LAB.)'
);

-- line #29455
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HOLD NASAL 0.74 (Juggat)',
	'SOD.CHL.',
	'SOLN',
	gm.nullify_empty_string('0.74')::numeric,
	'% W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HOLD NASAL 0.74 (Juggat)'
);

-- line #29456
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYPERTON-6 6 (Sunways)',
	'Sod.Chl.',
	'OINT',
	gm.nullify_empty_string('6')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYPERTON-6 6 (Sunways)'
);

-- line #29457
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'I-CHLOR EYE 5 (DIVINE LAB.)',
	'Sod.Chl.',
	'DROPS',
	gm.nullify_empty_string('5')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'I-CHLOR EYE 5 (DIVINE LAB.)'
);

-- line #29458
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISOL-6 6 (Pharmtak)',
	'Sod.Chl.',
	'EYE OINT',
	gm.nullify_empty_string('6')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISOL-6 6 (Pharmtak)'
);

-- line #29459
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAXTRA-S NASAL 0.65 (Zuventus)',
	'Sod.Chl.',
	'DPS',
	gm.nullify_empty_string('0.65')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAXTRA-S NASAL 0.65 (Zuventus)'
);

-- line #29460
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Sod.Chl.', u'always_empty': u'', u'form': u'EYE DPS', u'brand': u'NACL', u'strength_3': u'', u'company': u'Optho Rem.', u'unit': u''}

-- line #29461
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NACL 6 (Optho Rem.)',
	'Sod.Chl.',
	'OINT',
	gm.nullify_empty_string('6')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NACL 6 (Optho Rem.)'
);

-- line #29462
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NASALT-N 0.74 (Greenco Bio.)',
	'SOD.CHL.',
	'DPS',
	gm.nullify_empty_string('0.74')::numeric,
	'% W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NASALT-N 0.74 (Greenco Bio.)'
);

-- line #29463
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NASIVION-S 0.65 (Merck)',
	'Sod.Chl.',
	'DPS',
	gm.nullify_empty_string('0.65')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NASIVION-S 0.65 (Merck)'
);

-- line #29464
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,65', u'strength_2': u'', u'substance': u'Sod.Chl.', u'always_empty': u'', u'form': u'', u'brand': u'NASOCLEAR ALOEGEL', u'strength_3': u'', u'company': u'Liva Hc.', u'unit': u'%W/V(+ALOE VERA'}

-- line #29465
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NASOCLEAR NASAL 0.65 (ZYDUS(LIVA))',
	'Sod.Chl.',
	'DPS',
	gm.nullify_empty_string('0.65')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NASOCLEAR NASAL 0.65 (ZYDUS(LIVA))'
);

-- line #29466
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NASOCLEAR PLUS-N 2 (ZYDUS(LIVA))',
	'Sod.Chl.',
	'DPS',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NASOCLEAR PLUS-N 2 (ZYDUS(LIVA))'
);

-- line #29467
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,65', u'strength_2': u'', u'substance': u'Sod.Chl.', u'always_empty': u'', u'form': u'', u'brand': u'NAZODROP', u'strength_3': u'', u'company': u'Macleods', u'unit': u'% W/V (IN AN AQUEOUS ISOTONIC SOLUTION USING PURIFIED WATER IP BENZALKONIUM CHLORIDE SOLUTION IP 0.022'}

-- line #29468
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOBLOK-X 0.65 (LIFESTAR)',
	'Sod.Chl.',
	'DPS',
	gm.nullify_empty_string('0.65')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOBLOK-X 0.65 (LIFESTAR)'
);

-- line #29469
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Sod.Chl.', u'always_empty': u'', u'form': u'INF', u'brand': u'NORMAL SALINE', u'strength_3': u'', u'company': u'Albert D.', u'unit': u''}

-- line #29470
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORMAL SALINE 0.9 (Claris L.)',
	'Sod.Chl.',
	'INF',
	gm.nullify_empty_string('0.9')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORMAL SALINE 0.9 (Claris L.)'
);

-- line #29471
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Sod.Chl.', u'always_empty': u'', u'form': u'INF', u'brand': u'NORMAL SALINE', u'strength_3': u'', u'company': u'Claris L.', u'unit': u''}

-- line #29472
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Sod.Chl.', u'always_empty': u'', u'form': u'INF', u'brand': u'NORMAL SALINE', u'strength_3': u'', u'company': u'Mount M.', u'unit': u''}

-- line #29473
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Sod.Chl.', u'always_empty': u'', u'form': u'INF', u'brand': u'NORMAL SALINE', u'strength_3': u'', u'company': u'Parenteral', u'unit': u''}

-- line #29474
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOZEL-S 0.65 (GH PH.)',
	'SOD.CHL.',
	'SPRAY',
	gm.nullify_empty_string('0.65')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOZEL-S 0.65 (GH PH.)'
);

-- line #29475
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSMOGEL 5 (Micro Labs)',
	'Sod.Chl.',
	'EYE DPS',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSMOGEL 5 (Micro Labs)'
);

-- line #29476
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSMOGEL 6 (Micro Labs)',
	'Sod.Chl.',
	'EYE OINT',
	gm.nullify_empty_string('6')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSMOGEL 6 (Micro Labs)'
);

-- line #29477
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSMOTEK 5 (Milmet)',
	'Sod.Chl.',
	'DPS',
	gm.nullify_empty_string('5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSMOTEK 5 (Milmet)'
);

-- line #29478
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,74', u'strength_2': u'', u'substance': u'Sod.Chl.', u'always_empty': u'', u'form': u'', u'brand': u'OTRIVIN SALINE NEB', u'strength_3': u'', u'company': u'Novartis', u'unit': u'%W/V'}

-- line #29479
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OTRIVIN-S 0.74 (Novartis)',
	'SOD.CHL.',
	'DPS',
	gm.nullify_empty_string('0.74')::numeric,
	'% W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OTRIVIN-S 0.74 (Novartis)'
);

-- line #29480
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RHINE NASAL 0.65 (Le Sante)',
	'Sod.Chl.',
	'DPS',
	gm.nullify_empty_string('0.65')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RHINE NASAL 0.65 (Le Sante)'
);

-- line #29481
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,65', u'strength_2': u'', u'substance': u'Sod.Chl.', u'always_empty': u'', u'form': u'', u'brand': u'RINOSTAT-NA', u'strength_3': u'', u'company': u'Rpg Life', u'unit': u'%W/V'}

-- line #29482
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2', u'strength_2': u'', u'substance': u'Sod.Cromoglycate', u'always_empty': u'', u'form': u'', u'brand': u'ALLERCOM UNIMS', u'strength_3': u'', u'company': u'F D C', u'unit': u'%'}

-- line #29483
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALLERCROM 2 (F D C)',
	'Sod.Cromoglycate',
	'DPS',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALLERCROM 2 (F D C)'
);

-- line #29484
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALLERCROM 4 (F D C)',
	'Sod.Cromoglycate',
	'F. % DPS',
	gm.nullify_empty_string('4')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALLERCROM 4 (F D C)'
);

-- line #29485
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2', u'strength_2': u'', u'substance': u'Sod.Cromoglycate', u'always_empty': u'', u'form': u'', u'brand': u'CHROMOTOP INH', u'strength_3': u'', u'company': u'Astrazeneca', u'unit': u'mg/PUFF'}

-- line #29486
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHROMOTOP 20 (Astrazeneca)',
	'Sod.Cromoglycate',
	'ROTACAPS',
	gm.nullify_empty_string('20')::numeric,
	'mg/DOSE'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHROMOTOP 20 (Astrazeneca)'
);

-- line #29487
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5', u'strength_2': u'', u'substance': u'Sod.Cromoglycate', u'always_empty': u'', u'form': u'', u'brand': u'CROMAL AEROSOL', u'strength_3': u'', u'company': u'Cipla', u'unit': u'mg/DOSE'}

-- line #29488
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2,8', u'strength_2': u'', u'substance': u'Sod.Cromoglycate', u'always_empty': u'', u'form': u'', u'brand': u'CROMAL AQ', u'strength_3': u'', u'company': u'Cipla', u'unit': u'mg/DOSE'}

-- line #29489
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'4', u'strength_2': u'', u'substance': u'Sod.Cromoglycate', u'always_empty': u'', u'form': u'', u'brand': u'CROMAL MDI', u'strength_3': u'', u'company': u'Cipla', u'unit': u'% W/V'}

-- line #29490
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CROMAL 10 (Cipla)',
	'Sod.Cromoglycate',
	'RESPULE',
	gm.nullify_empty_string('10')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CROMAL 10 (Cipla)'
);

-- line #29491
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CROMAL 20 (Cipla)',
	'Sod.Cromoglycate',
	'ROTACAPS',
	gm.nullify_empty_string('20')::numeric,
	'mg/DOSE'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CROMAL 20 (Cipla)'
);

-- line #29492
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CROM 2 (Parenteral)',
	'Sod.Cromoglycate',
	'EYE DPS',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CROM 2 (Parenteral)'
);

-- line #29493
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Sod.Cromoglycate', u'always_empty': u'', u'form': u'DROPS', u'brand': u'CROM EYE', u'strength_3': u'', u'company': u'DIVINE LAB.', u'unit': u''}

-- line #29494
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FINTAL 1 (Piramal Hc.)',
	'Sod.Cromoglycate',
	'INHALER',
	gm.nullify_empty_string('1')::numeric,
	'mg/1PUFF'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FINTAL 1 (Piramal Hc.)'
);

-- line #29495
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FINTAL 2 (Piramal Hc.)',
	'Sod.Cromoglycate',
	'NASAL SPRAY',
	gm.nullify_empty_string('2')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FINTAL 2 (Piramal Hc.)'
);

-- line #29496
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Sod.Cromoglycate', u'always_empty': u'', u'form': u'CAP', u'brand': u'IFIRAL', u'strength_3': u'', u'company': u'J.B. CHEM', u'unit': u''}

-- line #29497
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'Sod.Cromoglycate', u'always_empty': u'', u'form': u'', u'brand': u'IFIRAL INH', u'strength_3': u'', u'company': u'Unique', u'unit': u'mg/CATRIDGE'}

-- line #29498
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IFIRAL 2 (Unique)',
	'Sod.Cromoglycate',
	'NASAL SPRAY',
	gm.nullify_empty_string('2')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IFIRAL 2 (Unique)'
);

-- line #29499
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPHRAL 2 (Ophthal R.)',
	'Sod.Cromoglycate',
	'EYE DPS',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPHRAL 2 (Ophthal R.)'
);

-- line #29500
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'SOD.FEREDETATE', u'always_empty': u'', u'form': u'SYR', u'brand': u'BAROHEM', u'strength_3': u'', u'company': u'MADHAV BIO.', u'unit': u''}

-- line #29501
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FEPOT 231 (Unimarck)',
	'SOD.FEREDETATE',
	'SYR',
	gm.nullify_empty_string('231')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FEPOT 231 (Unimarck)'
);

-- line #29502
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERADAY 231 (ANIMATE HC.)',
	'SOD.FEREDETATE',
	'SYR',
	gm.nullify_empty_string('231')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERADAY 231 (ANIMATE HC.)'
);

-- line #29503
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERANID 231 (Intra Lab)',
	'SOD.FEREDETATE',
	'SYR',
	gm.nullify_empty_string('231')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERANID 231 (Intra Lab)'
);

-- line #29504
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERFOZ 231 (F D C)',
	'SOD.FEREDETATE',
	'SYR',
	gm.nullify_empty_string('231')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERFOZ 231 (F D C)'
);

-- line #29505
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FE-Z 231 (Mapra)',
	'SOD.FEREDETATE',
	'SYR',
	gm.nullify_empty_string('231')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FE-Z 231 (Mapra)'
);

-- line #29506
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEMICA-FDT 231 (Cadex Lab)',
	'SOD.FEREDETATE',
	'SYR',
	gm.nullify_empty_string('231')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEMICA-FDT 231 (Cadex Lab)'
);

-- line #29507
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IRATE 231 (CRATUS)',
	'SOD.FEREDETATE',
	'SYR',
	gm.nullify_empty_string('231')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IRATE 231 (CRATUS)'
);

-- line #29508
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IREX 231 (Micro)',
	'SOD.FEREDETATE',
	'SYR',
	gm.nullify_empty_string('231')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IREX 231 (Micro)'
);

-- line #29509
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOBEFER 231 (Ochoa)',
	'SOD.FEREDETATE',
	'SYR',
	gm.nullify_empty_string('231')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOBEFER 231 (Ochoa)'
);

-- line #29510
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPTIFER 231 (Gufic Bio.)',
	'SOD.FEREDETATE',
	'SF SYR',
	gm.nullify_empty_string('231')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPTIFER 231 (Gufic Bio.)'
);

-- line #29511
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLUORITOP 0.044 (Icpa)',
	'Sod.Fluoride',
	'MOUTH RINSE',
	gm.nullify_empty_string('0.044')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLUORITOP 0.044 (Icpa)'
);

-- line #29512
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAF 20 (Ordain Hc.)',
	'Sod.Fluoride',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAF 20 (Ordain Hc.)'
);

-- line #29513
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OTOFLOUR 20 (Bell Ph.)',
	'Sod.Fluoride',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OTOFLOUR 20 (Bell Ph.)'
);

-- line #29514
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AUROCRIS 10 (Samarth)',
	'Sodium Aurothiomalate',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AUROCRIS 10 (Samarth)'
);

-- line #29515
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AUROCRIS 20 (Samarth)',
	'Sodium Aurothiomalate',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AUROCRIS 20 (Samarth)'
);

-- line #29516
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AUROCRIS 50 (Samarth)',
	'Sodium Aurothiomalate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AUROCRIS 50 (Samarth)'
);

-- line #29517
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'045% SODIUM CHLORIDE 0.45 (F D C)',
	'SODIUM CHLORIDE',
	'SOL',
	gm.nullify_empty_string('0.45')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '045% SODIUM CHLORIDE 0.45 (F D C)'
);

-- line #29518
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'045% SODIUM CHLORIDE 0.45 (K.K.)',
	'SODIUM CHLORIDE',
	'SOL',
	gm.nullify_empty_string('0.45')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '045% SODIUM CHLORIDE 0.45 (K.K.)'
);

-- line #29519
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'045% SODIUM CHLORIDE 0.45 (Mount M.)',
	'SODIUM CHLORIDE',
	'SOL',
	gm.nullify_empty_string('0.45')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '045% SODIUM CHLORIDE 0.45 (Mount M.)'
);

-- line #29520
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'09% SODIUM CHLORIDE 0.9 (Albert D.)',
	'SODIUM CHLORIDE',
	'SOL',
	gm.nullify_empty_string('0.9')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '09% SODIUM CHLORIDE 0.9 (Albert D.)'
);

-- line #29521
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'09% SODIUM CHLORIDE 0.9 (K.K.)',
	'SODIUM CHLORIDE',
	'SOL',
	gm.nullify_empty_string('0.9')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '09% SODIUM CHLORIDE 0.9 (K.K.)'
);

-- line #29522
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'09% SODIUM CHLORIDE 0.9 (TABLETS I.)',
	'SODIUM CHLORIDE',
	'SOL',
	gm.nullify_empty_string('0.9')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '09% SODIUM CHLORIDE 0.9 (TABLETS I.)'
);

-- line #29523
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'20% SODIUM CHLORIDE 20 (K.K.)',
	'SODIUM CHLORIDE',
	'SOL',
	gm.nullify_empty_string('20')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '20% SODIUM CHLORIDE 20 (K.K.)'
);

-- line #29524
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'SODIUM CHLORIDE', u'always_empty': u'', u'form': u'SPRAY/DROPS', u'brand': u'HYNASAL', u'strength_3': u'', u'company': u'Dwd', u'unit': u''}

-- line #29525
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DERRIM 2 (Alkem)',
	'Sodium Fusidate(FUSIDIC ACID)',
	'CRM',
	gm.nullify_empty_string('2')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DERRIM 2 (Alkem)'
);

-- line #29526
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DERRIM 2 (Alkem(BERGEN))',
	'Sodium Fusidate(FUSIDIC ACID)',
	'CRM',
	gm.nullify_empty_string('2')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DERRIM 2 (Alkem(BERGEN))'
);

-- line #29527
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUCIDIN 20 (Croslands)',
	'Sodium Fusidate(FUSIDIC ACID)',
	'CRM',
	gm.nullify_empty_string('20')::numeric,
	'mg/G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUCIDIN 20 (Croslands)'
);

-- line #29528
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUCIN 2 (Maneesh)',
	'Sodium Fusidate(FUSIDIC ACID)',
	'CRM',
	gm.nullify_empty_string('2')::numeric,
	'%W/W(+ K SORBITATE 2.7'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUCIN 2 (Maneesh)'
);

-- line #29529
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUCINEX 2 (Zuventus)',
	'Sodium Fusidate(FUSIDIC ACID)',
	'OINT',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUCINEX 2 (Zuventus)'
);

-- line #29530
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUCITHALMIC 10 (Win Medicare)',
	'Sodium Fusidate(FUSIDIC ACID)',
	'VISCOUS',
	gm.nullify_empty_string('10')::numeric,
	'mgPHEU (BENZALKONIUM CH. 0.01'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUCITHALMIC 10 (Win Medicare)'
);

-- line #29531
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUSIATE 20 (KIVI LABS)',
	'Sodium Fusidate(FUSIDIC ACID)',
	'CRM',
	gm.nullify_empty_string('20')::numeric,
	'mg/G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUSIATE 20 (KIVI LABS)'
);

-- line #29532
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUSIBACT 20 (EAST WEST)',
	'Sodium Fusidate(FUSIDIC ACID)',
	'CRM',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUSIBACT 20 (EAST WEST)'
);

-- line #29533
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUSIDA 2 (Intas)',
	'Sodium Fusidate(FUSIDIC ACID)',
	'CRM',
	gm.nullify_empty_string('2')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUSIDA 2 (Intas)'
);

-- line #29534
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUSIDERM 20 (Indi Ph.)',
	'Sodium Fusidate(FUSIDIC ACID)',
	'CRM',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUSIDERM 20 (Indi Ph.)'
);

-- line #29535
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUSIDERM 20 (Indi Ph.)',
	'Sodium Fusidate(FUSIDIC ACID)',
	'OINT',
	gm.nullify_empty_string('20')::numeric,
	'mg/G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUSIDERM 20 (Indi Ph.)'
);

-- line #29536
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUSIGEN 20 (Geno Ph.)',
	'Sodium Fusidate(FUSIDIC ACID)',
	'OINT',
	gm.nullify_empty_string('20')::numeric,
	'mg/G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUSIGEN 20 (Geno Ph.)'
);

-- line #29537
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUSIGEN 2 (Geno Ph.)',
	'Sodium Fusidate(FUSIDIC ACID)',
	'SPRAY',
	gm.nullify_empty_string('2')::numeric,
	'%W/W(+ETHANOL 95'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUSIGEN 2 (Geno Ph.)'
);

-- line #29538
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUSIKAB 2 (Lancer)',
	'Sodium Fusidate(FUSIDIC ACID)',
	'CRM',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUSIKAB 2 (Lancer)'
);

-- line #29539
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUSITAL 20 (TALENT LAB.)',
	'Sodium Fusidate(FUSIDIC ACID)',
	'CRM',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUSITAL 20 (TALENT LAB.)'
);

-- line #29540
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUSITOP 20 (Hygeia Ph.)',
	'Sodium Fusidate(FUSIDIC ACID)',
	'OINT',
	gm.nullify_empty_string('20')::numeric,
	'mg/G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUSITOP 20 (Hygeia Ph.)'
);

-- line #29541
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUSIVIC 2 (Elder)',
	'Sodium Fusidate(FUSIDIC ACID)',
	'CRM',
	gm.nullify_empty_string('2')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUSIVIC 2 (Elder)'
);

-- line #29542
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUSIWAL 2 (Wallace)',
	'Sodium Fusidate(FUSIDIC ACID)',
	'OINT',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUSIWAL 2 (Wallace)'
);

-- line #29543
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUSON 2 (AGIO PH.)',
	'Sodium Fusidate(FUSIDIC ACID)',
	'CRM',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUSON 2 (AGIO PH.)'
);

-- line #29544
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUSON 2 (Cosme Hc.)',
	'Sodium Fusidate(FUSIDIC ACID)',
	'CRM',
	gm.nullify_empty_string('2')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUSON 2 (Cosme Hc.)'
);

-- line #29545
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUSON 2 (AGIO PH.)',
	'Sodium Fusidate(FUSIDIC ACID)',
	'OINT',
	gm.nullify_empty_string('2')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUSON 2 (AGIO PH.)'
);

-- line #29546
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUSON 2 (Cosme Hc.)',
	'Sodium Fusidate(FUSIDIC ACID)',
	'OINT',
	gm.nullify_empty_string('2')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUSON 2 (Cosme Hc.)'
);

-- line #29547
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUSTOP 20 (Cfl Ph.)',
	'Sodium Fusidate(FUSIDIC ACID)',
	'OINT',
	gm.nullify_empty_string('20')::numeric,
	'mg/G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUSTOP 20 (Cfl Ph.)'
);

-- line #29548
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUTOP 2 (Cosme Hc.)',
	'Sodium Fusidate(FUSIDIC ACID)',
	'OINT/CREAM',
	gm.nullify_empty_string('2')::numeric,
	'%W/W(+ K SORBITATE 2.7'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUTOP 2 (Cosme Hc.)'
);

-- line #29549
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUZI 20 (Dermatak)',
	'Sodium Fusidate(FUSIDIC ACID)',
	'CRM',
	gm.nullify_empty_string('20')::numeric,
	'mg/G'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUZI 20 (Dermatak)'
);

-- line #29550
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Sodium Fusidate(FUSIDIC ACID)', u'always_empty': u'', u'form': u'CRM', u'brand': u'GENTOPIC -FA', u'strength_3': u'', u'company': u'Systopic', u'unit': u''}

-- line #29551
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMPECID 2 (ZYLONE HC.)',
	'Sodium Fusidate(FUSIDIC ACID)',
	'CRM',
	gm.nullify_empty_string('2')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMPECID 2 (ZYLONE HC.)'
);

-- line #29552
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAFU 20 (ROSE LABS)',
	'Sodium Fusidate(FUSIDIC ACID)',
	'OINT',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAFU 20 (ROSE LABS)'
);

-- line #29553
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOBOYLE 2 (Neiss)',
	'Sodium Fusidate(FUSIDIC ACID)',
	'CRM',
	gm.nullify_empty_string('2')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOBOYLE 2 (Neiss)'
);

-- line #29554
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Sodium hyaluronate', u'always_empty': u'', u'form': u'CRM', u'brand': u'BIOZEL', u'strength_3': u'', u'company': u'Lekar', u'unit': u''}

-- line #29555
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COHEVISC OPHTH 1.4 (Appasamy)',
	'Sodium hyaluronate',
	'SOL',
	gm.nullify_empty_string('1.4')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COHEVISC OPHTH 1.4 (Appasamy)'
);

-- line #29556
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAIN 0.5 (Elder)',
	'Sodium hyaluronate',
	'GEL',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAIN 0.5 (Elder)'
);

-- line #29557
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALONIX 1 (Irm Ph.)',
	'Sodium hyaluronate',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'% (+NACL 0.85'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALONIX 1 (Irm Ph.)'
);

-- line #29558
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1,4', u'strength_2': u'', u'substance': u'Sodium hyaluronate', u'always_empty': u'', u'form': u'', u'brand': u'HEALON-GV', u'strength_3': u'', u'company': u'Pharmacia', u'unit': u'%'}

-- line #29559
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEALON 1 (Pharmacia)',
	'Sodium hyaluronate',
	'VIAL',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEALON 1 (Pharmacia)'
);

-- line #29560
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYALORAL 20 (Nouveau)',
	'Sodium hyaluronate',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYALORAL 20 (Nouveau)'
);

-- line #29561
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Sodium hyaluronate', u'always_empty': u'', u'form': u'DROPS', u'brand': u'HYLO-COMOD EYE', u'strength_3': u'', u'company': u'URSA PH.', u'unit': u''}

-- line #29562
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYLON 1 (CH.Bhagat)',
	'Sodium hyaluronate',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYLON 1 (CH.Bhagat)'
);

-- line #29563
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYRUAN PLUS 1 (LG LIFE)',
	'Sodium hyaluronate',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYRUAN PLUS 1 (LG LIFE)'
);

-- line #29564
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYVISC 0.1 (Sun)',
	'Sodium hyaluronate',
	'EYE DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYVISC 0.1 (Sun)'
);

-- line #29565
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYVISC 0.18 (Sun)',
	'Sodium hyaluronate',
	'EYE DPS',
	gm.nullify_empty_string('0.18')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYVISC 0.18 (Sun)'
);

-- line #29566
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Sodium hyaluronate', u'always_empty': u'', u'form': u'INJ', u'brand': u'LG HYAL', u'strength_3': u'', u'company': u'Lglsi', u'unit': u''}

-- line #29567
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'25G', u'strength_2': u'', u'substance': u'Sodium hyaluronate', u'always_empty': u'', u'form': u'INJ', u'brand': u'LG HYRUAN', u'strength_3': u'', u'company': u'Lglsi', u'unit': u''}

-- line #29568
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,35', u'strength_2': u'', u'substance': u'SODIUM MONO.PHOSPHATE', u'always_empty': u'', u'form': u'', u'brand': u'PEDIFLOR', u'strength_3': u'', u'company': u'Group Ph.', u'unit': u'%W/W'}

-- line #29569
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAXATAB 10 (Eros Ph.)',
	'Sodium picosulphate',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAXATAB 10 (Eros Ph.)'
);

-- line #29570
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELIVAL 200 (Elite Ph.)',
	'Sodium Valproate',
	'CR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELIVAL 200 (Elite Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELIVAL 300 (Elite Ph.)',
	'Sodium Valproate',
	'CR TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELIVAL 300 (Elite Ph.)'
);

-- line #29571
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELIVAL 500 (Elite Ph.)',
	'Sodium Valproate',
	'CR TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELIVAL 500 (Elite Ph.)'
);

-- line #29572
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENCORATE CHRONO 300 (Synergy)',
	'Sodium Valproate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg/500'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENCORATE CHRONO 300 (Synergy)'
);

-- line #29573
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENCORATE 200 (Sun)',
	'Sodium Valproate',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENCORATE 200 (Sun)'
);

-- line #29574
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENPIL 200 (Biocia Hc.)',
	'Sodium Valproate',
	'CR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENPIL 200 (Biocia Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENPIL 300 (Biocia Hc.)',
	'Sodium Valproate',
	'CR TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENPIL 300 (Biocia Hc.)'
);

-- line #29575
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENPIL 500 (Biocia Hc.)',
	'Sodium Valproate',
	'CR TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENPIL 500 (Biocia Hc.)'
);

-- line #29576
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPIVAL 200 (Sun)',
	'Sodium Valproate',
	'EC TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPIVAL 200 (Sun)'
);

-- line #29577
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPIVAL 200 (Sun)',
	'Sodium Valproate',
	'SYR',
	gm.nullify_empty_string('200')::numeric,
	'mg/5 ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPIVAL 200 (Sun)'
);

-- line #29578
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPSOVAL 200 (LA PHARMA)',
	'Sodium Valproate',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg(VALPROIC ACID)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPSOVAL 200 (LA PHARMA)'
);

-- line #29579
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPSOVAL 200 (LA DRUG)',
	'Sodium Valproate',
	'XR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPSOVAL 200 (LA DRUG)'
);

-- line #29580
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPSOVAL 300 (LA DRUG)',
	'Sodium Valproate',
	'XR TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPSOVAL 300 (LA DRUG)'
);

-- line #29581
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPSOVAL 500 (LA DRUG)',
	'Sodium Valproate',
	'XR TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPSOVAL 500 (LA DRUG)'
);

-- line #29582
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOVAL 200 (Orchid Hc.)',
	'Sodium Valproate',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOVAL 200 (Orchid Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOVAL 300 (Orchid Hc.)',
	'Sodium Valproate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOVAL 300 (Orchid Hc.)'
);

-- line #29583
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,38', u'strength_2': u'', u'substance': u'Sod.Monofluorophos.', u'always_empty': u'', u'form': u'', u'brand': u'INISSIATE', u'strength_3': u'', u'company': u'Indoco Rem.', u'unit': u'%W/W'}

-- line #29584
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,38', u'strength_2': u'', u'substance': u'Sod.Monofluorophos.', u'always_empty': u'', u'form': u'', u'brand': u'KIDODENT', u'strength_3': u'', u'company': u'Warren', u'unit': u'%W/W'}

-- line #29585
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIPRESS 50 (Samarth)',
	'Sod.Nitroprusside',
	'AMP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIPRESS 50 (Samarth)'
);

-- line #29586
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITOSIDE 50 (Neon)',
	'Sod.Nitroprusside',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITOSIDE 50 (Neon)'
);

-- line #29587
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRUSIDE 50 (Troikaa)',
	'Sod.Nitroprusside',
	'V',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRUSIDE 50 (Troikaa)'
);

-- line #29588
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLINIDENT 480 (Warren)',
	'Sod.Perborate',
	'TAB',
	gm.nullify_empty_string('480')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLINIDENT 480 (Warren)'
);

-- line #29589
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FITTYDENT DENTCLEANSING 480 (Dr.Reddy''S)',
	'Sod.Perborate',
	'TAB',
	gm.nullify_empty_string('480')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FITTYDENT DENTCLEANSING 480 (Dr.Reddy''S)'
);

-- line #29590
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COLAX 5 (Strassenburg)',
	'Sod.Picosulphate',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COLAX 5 (Strassenburg)'
);

-- line #29591
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COLAX 10 (Strassenburg)',
	'Sod.Picosulphate',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COLAX 10 (Strassenburg)'
);

-- line #29592
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CREMALAX 10 (ABBOTT)',
	'Sod.Picosulphate',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CREMALAX 10 (ABBOTT)'
);

-- line #29593
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYRSET EZE 10 (Symbiotic)',
	'Sod.Picosulphate',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYRSET EZE 10 (Symbiotic)'
);

-- line #29594
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GALDOM-SP 5 (Cerspin Hc.)',
	'Sod.Picosulphate',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GALDOM-SP 5 (Cerspin Hc.)'
);

-- line #29595
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GUDLAX-P 10 (Mankind)',
	'Sod.Picosulphate',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GUDLAX-P 10 (Mankind)'
);

-- line #29596
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAXE 5 (Mdc Ph.)',
	'Sod.Picosulphate',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAXE 5 (Mdc Ph.)'
);

-- line #29597
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAXICARE 10 (AZINE HC.)',
	'Sod.Picosulphate',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAXICARE 10 (AZINE HC.)'
);

-- line #29598
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAXIFAST SP 5 (Emcure)',
	'Sod.Picosulphate',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAXIFAST SP 5 (Emcure)'
);

-- line #29599
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PICATE 5 (Candor Bio.)',
	'Sod.Picosulphate',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PICATE 5 (Candor Bio.)'
);

-- line #29600
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PICATE 10 (Candor Bio.)',
	'Sod.Picosulphate',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PICATE 10 (Candor Bio.)'
);

-- line #29601
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PICOFATE 5 (Osper)',
	'Sod.Picosulphate',
	'LIQ',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PICOFATE 5 (Osper)'
);

-- line #29602
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PICO-SOFT 5 (Chem+Med)',
	'Sod.Picosulphate',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PICO-SOFT 5 (Chem+Med)'
);

-- line #29603
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PICO 5 (NICON)',
	'Sod.Picosulphate',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PICO 5 (NICON)'
);

-- line #29604
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PICSUL 5 (MISSION RES.)',
	'Sod.Picosulphate',
	'SYR',
	gm.nullify_empty_string('5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PICSUL 5 (MISSION RES.)'
);

-- line #29605
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PICSUL 10 (MISSION RES.)',
	'Sod.Picosulphate',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PICSUL 10 (MISSION RES.)'
);

-- line #29606
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BISPEC 10 (DR. REDDY''S)',
	'SOLIFENACIN SUCCINATE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BISPEC 10 (DR. REDDY''S)'
);

-- line #29607
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BISPEC 5 (DR. REDDY''S)',
	'SOLIFENACIN SUCCINATE',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BISPEC 5 (DR. REDDY''S)'
);

-- line #29608
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ESTILO 3 (UNIMARK REM.)',
	'Somatostatin',
	'INJ',
	gm.nullify_empty_string('3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ESTILO 3 (UNIMARK REM.)'
);

-- line #29609
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250MCG', u'strength_2': u'', u'substance': u'Somatostatin', u'always_empty': u'', u'form': u'INJ', u'brand': u'ESTILO MCG', u'strength_3': u'', u'company': u'UNIMARK REM.', u'unit': u''}

-- line #29610
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'12IU.', u'strength_2': u'', u'substance': u'Somatropin', u'always_empty': u'', u'form': u'INJ', u'brand': u'GENOTROPIN', u'strength_3': u'', u'company': u'Pharmacia', u'unit': u''}

-- line #29611
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'16 I.U.', u'strength_2': u'', u'substance': u'Somatropin', u'always_empty': u'', u'form': u'INJ', u'brand': u'GENOTROPIN', u'strength_3': u'', u'company': u'Pharmacia', u'unit': u''}

-- line #29612
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'36IU.', u'strength_2': u'', u'substance': u'Somatropin', u'always_empty': u'', u'form': u'INJ', u'brand': u'GENOTROPIN', u'strength_3': u'', u'company': u'Pharmacia', u'unit': u''}

-- line #29613
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'4IU.', u'strength_2': u'', u'substance': u'Somatropin', u'always_empty': u'', u'form': u'INJ', u'brand': u'GENOTROPIN', u'strength_3': u'', u'company': u'Pharmacia', u'unit': u''}

-- line #29614
-- ignoring line: field [strength_1] not numeric: >>>4IU.(1.6<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'4IU.(1.6', u'strength_2': u'', u'substance': u'Somatropin', u'always_empty': u'', u'form': u'INJ', u'brand': u'HEADON IU', u'strength_3': u'', u'company': u'CROSSLAND', u'unit': u'mg) RECOMBINATE GROWTH HORMONE'}

-- line #29615
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'16I.U.', u'strength_2': u'', u'substance': u'Somatropin', u'always_empty': u'', u'form': u'INJ', u'brand': u'HUMATROPE IU', u'strength_3': u'', u'company': u'Eli Lilly', u'unit': u''}

-- line #29616
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'18I.U.', u'strength_2': u'', u'substance': u'Somatropin', u'always_empty': u'', u'form': u'INJ', u'brand': u'HUMATROPE IU', u'strength_3': u'', u'company': u'Eli Lilly', u'unit': u''}

-- line #29617
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'36I.U.', u'strength_2': u'', u'substance': u'Somatropin', u'always_empty': u'', u'form': u'INJ', u'brand': u'HUMATROPE IU', u'strength_3': u'', u'company': u'Eli Lilly', u'unit': u''}

-- line #29618
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'4I.U.', u'strength_2': u'', u'substance': u'Somatropin', u'always_empty': u'', u'form': u'INJ', u'brand': u'HUMATROPE IU', u'strength_3': u'', u'company': u'Eli Lilly', u'unit': u''}

-- line #29619
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'4I.U.', u'strength_2': u'', u'substance': u'Somatropin', u'always_empty': u'', u'form': u'VIAL', u'brand': u'LG EUTROPIN', u'strength_3': u'', u'company': u'Lglsi', u'unit': u''}

-- line #29620
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORDITROPIN NORDILET 10 (Novo Nordisk)',
	'Somatropin',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg/1.5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORDITROPIN NORDILET 10 (Novo Nordisk)'
);

-- line #29621
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORDITROPIN NORDILET 15 (Novo Nordisk)',
	'Somatropin',
	'INJ',
	gm.nullify_empty_string('15')::numeric,
	'mg/1.5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORDITROPIN NORDILET 15 (Novo Nordisk)'
);

-- line #29622
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORDITROPIN NORDILET 5 (Novo Nordisk)',
	'Somatropin',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg/1.5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORDITROPIN NORDILET 5 (Novo Nordisk)'
);

-- line #29623
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GERILAX 70 (Alembic)',
	'Sorbitol Sol.',
	'SYR',
	gm.nullify_empty_string('70')::numeric,
	'%/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GERILAX 70 (Alembic)'
);

-- line #29624
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'SOYA PROTEIN ISOLATE + SOYA FIBRE VITAMINS', u'always_empty': u'', u'form': u'', u'brand': u'PROSEVENTY', u'strength_3': u'', u'company': u'Panacea', u'unit': u''}

-- line #29625
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'145CC', u'strength_2': u'', u'substance': u'SPACER', u'always_empty': u'', u'form': u'', u'brand': u'AER-O MATE EQUIP', u'strength_3': u'', u'company': u'Medicare', u'unit': u''}

-- line #29626
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'SPACER AND BABY MASK', u'strength_2': u'', u'substance': u'SPACER', u'always_empty': u'', u'form': u'KIT', u'brand': u'HUF PUF', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #29627
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACESPAR 200 (SHREYA)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACESPAR 200 (SHREYA)'
);

-- line #29628
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACROSPAR 200 (Acron Ph.)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACROSPAR 200 (Acron Ph.)'
);

-- line #29629
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTIFLOX 100 (Saga Lab)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTIFLOX 100 (Saga Lab)'
);

-- line #29630
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTIFLOX 200 (Saga Lab)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTIFLOX 200 (Saga Lab)'
);

-- line #29631
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACUSPAR 100 (Themis)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACUSPAR 100 (Themis)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACUSPAR 200 (Themis)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACUSPAR 200 (Themis)'
);

-- line #29632
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANSPAR 200 (ANAND HC.)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANSPAR 200 (ANAND HC.)'
);

-- line #29633
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANSPAR 200 (Cambridge Hc.)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANSPAR 200 (Cambridge Hc.)'
);

-- line #29634
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AQSPAR 200 (Aquila)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AQSPAR 200 (Aquila)'
);

-- line #29635
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARTISPAR 100 (Rpg Life)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'200'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARTISPAR 100 (Rpg Life)'
);

-- line #29636
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASPAR 100 (Admac Ph.)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASPAR 100 (Admac Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASPAR 200 (Admac Ph.)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASPAR 200 (Admac Ph.)'
);

-- line #29637
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATOSPAR 200 (Atoz Ph.)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATOSPAR 200 (Atoz Ph.)'
);

-- line #29638
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AUROSPAR 200 (Auroma Life)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AUROSPAR 200 (Auroma Life)'
);

-- line #29639
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXSPAR 200 (AXYZEN LIFE)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXSPAR 200 (AXYZEN LIFE)'
);

-- line #29640
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIN 100 (Pifer Ph.)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIN 100 (Pifer Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZIN 200 (Pifer Ph.)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZIN 200 (Pifer Ph.)'
);

-- line #29641
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACTOSPAR 200 (Graf Lab.)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACTOSPAR 200 (Graf Lab.)'
);

-- line #29642
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BAL-SPAR 200 (Bal Ph.)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BAL-SPAR 200 (Bal Ph.)'
);

-- line #29643
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENISPAR 200 (Baroque)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENISPAR 200 (Baroque)'
);

-- line #29644
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLUSPAR 100 (Blue Cross)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLUSPAR 100 (Blue Cross)'
);

-- line #29645
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLUSPAR 200 (Blue Cross)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLUSPAR 200 (Blue Cross)'
);

-- line #29646
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DINOR 100 (Nucron Ph.)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DINOR 100 (Nucron Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DINOR 200 (Nucron Ph.)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DINOR 200 (Nucron Ph.)'
);

-- line #29647
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DURASPAR 200 (Makers)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DURASPAR 200 (Makers)'
);

-- line #29648
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYSPAR 100 (Dynamic)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYSPAR 100 (Dynamic)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYSPAR 200 (Dynamic)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYSPAR 200 (Dynamic)'
);

-- line #29649
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ECOSPAR 200 (Skymax)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ECOSPAR 200 (Skymax)'
);

-- line #29650
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EFOSPAR 200 (Reliance)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EFOSPAR 200 (Reliance)'
);

-- line #29651
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPRAX 200 (Emil Ph.)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPRAX 200 (Emil Ph.)'
);

-- line #29652
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXCELSPAR 200 (Svizera)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXCELSPAR 200 (Svizera)'
);

-- line #29653
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EYPAR 0.3 (Solitaire)',
	'Sparfloxacin',
	'E/E DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EYPAR 0.3 (Solitaire)'
);

-- line #29654
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOQUIN 100 (Hal)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOQUIN 100 (Hal)'
);

-- line #29655
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOQUIN 200 (Hal)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOQUIN 200 (Hal)'
);

-- line #29656
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOSPAR 200 (Unichem)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOSPAR 200 (Unichem)'
);

-- line #29657
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOTOME 200 (EPITOME)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOTOME 200 (EPITOME)'
);

-- line #29658
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXPAR 200 (INVISION)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXPAR 200 (INVISION)'
);

-- line #29659
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXY 100 (Jaywin)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXY 100 (Jaywin)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOXY 200 (Jaywin)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOXY 200 (Jaywin)'
);

-- line #29660
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORSPAR 200 (FORTUNE HC.)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORSPAR 200 (FORTUNE HC.)'
);

-- line #29661
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GENSPAR 200 (Genix Ph.)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GENSPAR 200 (Genix Ph.)'
);

-- line #29662
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GUSPAR 200 (Unicure)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GUSPAR 200 (Unicure)'
);

-- line #29663
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GYROSPAR 100 (Ipca)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GYROSPAR 100 (Ipca)'
);

-- line #29664
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GYROSPAR 200 (Ipca)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GYROSPAR 200 (Ipca)'
);

-- line #29665
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HFSPAR 200 (HEXAL PH.)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HFSPAR 200 (HEXAL PH.)'
);

-- line #29666
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDOSPAR 0.3 (Indo-Reh Ph.)',
	'Sparfloxacin',
	'E/E DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDOSPAR 0.3 (Indo-Reh Ph.)'
);

-- line #29667
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INSPAR 200 (Intra Lab)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INSPAR 200 (Intra Lab)'
);

-- line #29668
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INSPAR 200 (Waves Bio.)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INSPAR 200 (Waves Bio.)'
);

-- line #29669
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'JUGAM 200 (Natco Ph.)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'JUGAM 200 (Natco Ph.)'
);

-- line #29670
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LASPAR 100 (Lark Labs)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LASPAR 100 (Lark Labs)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LASPAR 200 (Lark Labs)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LASPAR 200 (Lark Labs)'
);

-- line #29671
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LERISPAR 100 (Biocin Hc.)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LERISPAR 100 (Biocin Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LERISPAR 200 (Biocin Hc.)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LERISPAR 200 (Biocin Hc.)'
);

-- line #29672
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LICASPAR 200 (Semsun Ph.)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LICASPAR 200 (Semsun Ph.)'
);

-- line #29673
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LICORIL 200 (Shinto Org.)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LICORIL 200 (Shinto Org.)'
);

-- line #29674
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MESPAR 200 (MILMET)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MESPAR 200 (MILMET)'
);

-- line #29675
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILSPAR 100 (Shaimil)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILSPAR 100 (Shaimil)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MILSPAR 200 (Shaimil)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MILSPAR 200 (Shaimil)'
);

-- line #29676
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVOSPAR 200 (Zydus Cadila)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVOSPAR 200 (Zydus Cadila)'
);

-- line #29677
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ODISPAR 200 (Allure Rem.)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ODISPAR 200 (Allure Rem.)'
);

-- line #29678
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONESPAR 200 (Euphoric)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONESPAR 200 (Euphoric)'
);

-- line #29679
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORYSPAR 200 (Jrs Oryx.)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORYSPAR 200 (Jrs Oryx.)'
);

-- line #29680
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSPAR 200 (Osper)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSPAR 200 (Osper)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSPAR 400 (Osper)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSPAR 400 (Osper)'
);

-- line #29681
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSPAR 100 (Southsourne)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSPAR 100 (Southsourne)'
);

-- line #29682
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSPAR 200 (Southsourne)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSPAR 200 (Southsourne)'
);

-- line #29683
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAAR 200 (Finecure)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAAR 200 (Finecure)'
);

-- line #29684
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARCIN 200 (Ascent Lab)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARCIN 200 (Ascent Lab)'
);

-- line #29685
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARCY 200 (Chemo D.)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARCY 200 (Chemo D.)'
);

-- line #29686
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENSPAR 200 (SAFE PH.)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENSPAR 200 (SAFE PH.)'
);

-- line #29687
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRESPAR 100 (WISCON)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRESPAR 100 (WISCON)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRESPAR 200 (WISCON)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRESPAR 200 (WISCON)'
);

-- line #29688
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PUFAM 200 (Emcure)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PUFAM 200 (Emcure)'
);

-- line #29689
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q SPAR 100 (Que Ph.)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q SPAR 100 (Que Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'Q SPAR 200 (Que Ph.)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'Q SPAR 200 (Que Ph.)'
);

-- line #29690
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUINSPAR 200 (Smiles Inc.)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUINSPAR 200 (Smiles Inc.)'
);

-- line #29691
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUNA 200 (Tnt Life)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUNA 200 (Tnt Life)'
);

-- line #29692
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUSPAR 100 (Life Line)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUSPAR 100 (Life Line)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'QUSPAR 200 (Life Line)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'QUSPAR 200 (Life Line)'
);

-- line #29693
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAPISPAR 200 (TWILIGHT LIT.)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAPISPAR 200 (TWILIGHT LIT.)'
);

-- line #29694
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REXPAR 100 (Ranbaxy)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REXPAR 100 (Ranbaxy)'
);

-- line #29695
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REXPAR 200 (Ranbaxy)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REXPAR 200 (Ranbaxy)'
);

-- line #29696
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RHOMBISPAR 200 (Rhombus)',
	'Sparfloxacin',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RHOMBISPAR 200 (Rhombus)'
);

-- line #29697
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2G', u'strength_2': u'', u'substance': u'Spectinomycin', u'always_empty': u'', u'form': u'INJ', u'brand': u'MYSPEC', u'strength_3': u'', u'company': u'Neon', u'unit': u''}

-- line #29698
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50MIL.', u'strength_2': u'', u'substance': u'Spiramycin', u'always_empty': u'', u'form': u'TAB', u'brand': u'MOD-SPIRO', u'strength_3': u'', u'company': u'MODHIKE', u'unit': u''}

-- line #29699
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALDACTONE 100 (Rpg Life)',
	'Spironolactone',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALDACTONE 100 (Rpg Life)'
);

-- line #29700
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALDACTONE 25 (Rpg Life)',
	'Spironolactone',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALDACTONE 25 (Rpg Life)'
);

-- line #29701
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALDACTONE 50 (Rpg Life)',
	'Spironolactone',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALDACTONE 50 (Rpg Life)'
);

-- line #29702
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LACTONE 100 (Sun)',
	'Spironolactone',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LACTONE 100 (Sun)'
);

-- line #29703
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LACTONE 25 (Sun)',
	'Spironolactone',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LACTONE 25 (Sun)'
);

-- line #29704
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Spirulina', u'always_empty': u'', u'form': u'TAB', u'brand': u'ADENT-F', u'strength_3': u'', u'company': u'Dynamic', u'unit': u''}

-- line #29705
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADENT 500 (Dynamic)',
	'Spirulina',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADENT 500 (Dynamic)'
);

-- line #29706
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Spirulina', u'always_empty': u'', u'form': u'TAB', u'brand': u'EUFIT', u'strength_3': u'', u'company': u'Euphoric', u'unit': u''}

-- line #29707
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUFIT 500 (Euphoric)',
	'Spirulina',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUFIT 500 (Euphoric)'
);

-- line #29708
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FITNESS 500 (Cipla)',
	'Spirulina',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FITNESS 500 (Cipla)'
);

-- line #29709
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMPETUS 500 (Emcure)',
	'Spirulina',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMPETUS 500 (Emcure)'
);

-- line #29710
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUCLINA 500 (Mapra)',
	'Spirulina',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUCLINA 500 (Mapra)'
);

-- line #29711
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROMIC-S 500 (Cosmic Ph.)',
	'Spirulina',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROMIC-S 500 (Cosmic Ph.)'
);

-- line #29712
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROMIC-S 500 (Cosmic Ph.)',
	'Spirulina',
	'POW',
	gm.nullify_empty_string('500')::numeric,
	'mg/10GM'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROMIC-S 500 (Cosmic Ph.)'
);

-- line #29713
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RECOLINA 500 (Zydus Cadila)',
	'Spirulina',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RECOLINA 500 (Zydus Cadila)'
);

-- line #29714
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REVOLINA 500 (Intra Lab)',
	'Spirulina',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg(+BRAHMI 50'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REVOLINA 500 (Intra Lab)'
);

-- line #29715
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'WITH BRAHMI', u'strength_2': u'', u'substance': u'Spirulina', u'always_empty': u'', u'form': u'GRAN', u'brand': u'REVOLINA', u'strength_3': u'', u'company': u'Intra Lab', u'unit': u''}

-- line #29716
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MENABOL 2 (Cfl Ph.)',
	'Stanozolol',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MENABOL 2 (Cfl Ph.)'
);

-- line #29717
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEURABOL 2 (Zydus A.)',
	'Stanozolol',
	'CAP',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEURABOL 2 (Zydus A.)'
);

-- line #29718
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'(GLYCERINE IN NEUTRAL PH SOAP BAR)', u'strength_2': u'', u'substance': u'STERYL ESTERS', u'always_empty': u'', u'form': u'', u'brand': u'HIDRATE BAR', u'strength_3': u'', u'company': u'Unichem', u'unit': u''}

-- line #29719
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'STEVIA ZERO CALORIC NATURAL SWEETENER', u'always_empty': u'', u'form': u'', u'brand': u'NATURE SWEET', u'strength_3': u'', u'company': u'Samarth', u'unit': u''}

-- line #29720
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPGARD 300 (Sanat)',
	'ST.JOHN''S WORT',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPGARD 300 (Sanat)'
);

-- line #29721
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'J-WORT 300 (Lupin)',
	'ST.JOHN''S WORT',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'J-WORT 300 (Lupin)'
);

-- line #29722
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.75MIU', u'strength_2': u'', u'substance': u'Streptokinase', u'always_empty': u'', u'form': u'INJ', u'brand': u'CARDIOSTREP', u'strength_3': u'', u'company': u'Kee Ph.', u'unit': u''}

-- line #29723
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.50MIU', u'strength_2': u'', u'substance': u'Streptokinase', u'always_empty': u'', u'form': u'INJ', u'brand': u'CARDIOSTREP', u'strength_3': u'', u'company': u'Kee Ph.', u'unit': u''}

-- line #29724
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'15LAC IU.', u'strength_2': u'', u'substance': u'Streptokinase', u'always_empty': u'', u'form': u'INJ', u'brand': u'ECOKINASE', u'strength_3': u'', u'company': u'DELVIN', u'unit': u''}

-- line #29725
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.75 I.U.', u'strength_2': u'', u'substance': u'Streptokinase', u'always_empty': u'', u'form': u'V', u'brand': u'ESKINASE IU', u'strength_3': u'', u'company': u'Dabur Ph.', u'unit': u''}

-- line #29726
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.5MI.U.', u'strength_2': u'', u'substance': u'Streptokinase', u'always_empty': u'', u'form': u'', u'brand': u'ESKINASE-M IU', u'strength_3': u'', u'company': u'Dabur Ph.', u'unit': u''}

-- line #29727
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.50MIU', u'strength_2': u'', u'substance': u'Streptokinase', u'always_empty': u'', u'form': u'INJ', u'brand': u'FIBROKINASE', u'strength_3': u'', u'company': u'Otsira', u'unit': u''}

-- line #29728
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.5MIU', u'strength_2': u'', u'substance': u'Streptokinase', u'always_empty': u'', u'form': u'INJ', u'brand': u'HAEMOKINASE', u'strength_3': u'', u'company': u'BIOSENA', u'unit': u''}

-- line #29729
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'7.5 LAC I.U.', u'strength_2': u'', u'substance': u'Streptokinase', u'always_empty': u'', u'form': u'V', u'brand': u'ICIKINASE LAC', u'strength_3': u'', u'company': u'Nicholas', u'unit': u''}

-- line #29730
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.5 M.I.U.', u'strength_2': u'', u'substance': u'Streptokinase', u'always_empty': u'', u'form': u'VIAL', u'brand': u'ICIKINASE', u'strength_3': u'', u'company': u'Piramal Hc.', u'unit': u''}

-- line #29731
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.75M.I.U.', u'strength_2': u'', u'substance': u'Streptokinase', u'always_empty': u'', u'form': u'INJ', u'brand': u'INDIKINASE-M', u'strength_3': u'', u'company': u'Bharat Bio.', u'unit': u''}

-- line #29732
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.5M.I.U.', u'strength_2': u'', u'substance': u'Streptokinase', u'always_empty': u'', u'form': u'INJ', u'brand': u'INDIKINASE-M', u'strength_3': u'', u'company': u'Bharat Bio.', u'unit': u''}

-- line #29733
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.5M.I.U.', u'strength_2': u'', u'substance': u'Streptokinase', u'always_empty': u'', u'form': u'VIAL', u'brand': u'KABIKINASE-M', u'strength_3': u'', u'company': u'Pharmacia', u'unit': u''}

-- line #29734
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.75M.I.U.', u'strength_2': u'', u'substance': u'Streptokinase', u'always_empty': u'', u'form': u'V', u'brand': u'KABIKINASE-M', u'strength_3': u'', u'company': u'Pharmacia', u'unit': u''}

-- line #29735
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KLOTBUSTER 15 (Alembic)',
	'Streptokinase',
	'INJ',
	gm.nullify_empty_string('15')::numeric,
	'0'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KLOTBUSTER 15 (Alembic)'
);

-- line #29736
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KLOTBUSTER 7 (Alembic)',
	'Streptokinase',
	'INJ',
	gm.nullify_empty_string('7')::numeric,
	'50'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KLOTBUSTER 7 (Alembic)'
);

-- line #29737
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'15 LAC I.U.', u'strength_2': u'', u'substance': u'Streptokinase', u'always_empty': u'', u'form': u'', u'brand': u'LUPIFLO (1500000 IU)', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #29738
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'7.5 LAC I.U.', u'strength_2': u'', u'substance': u'Streptokinase', u'always_empty': u'', u'form': u'', u'brand': u'LUPIFLO (750000 IU)', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #29739
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYOKINASE 1 (BIOCON LTD.)',
	'Streptokinase',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'500'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYOKINASE 1 (BIOCON LTD.)'
);

-- line #29740
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'7.5L', u'strength_2': u'15L', u'substance': u'Streptokinase', u'always_empty': u'', u'form': u'INJ', u'brand': u'NISKINASE', u'strength_3': u'', u'company': u'NEISS', u'unit': u''}

-- line #29741
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.75M.I.U.', u'strength_2': u'', u'substance': u'Streptokinase', u'always_empty': u'', u'form': u'VIAL', u'brand': u'PROKINASE-M', u'strength_3': u'', u'company': u'Emcure', u'unit': u''}

-- line #29742
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1.5M.I.U.', u'strength_2': u'', u'substance': u'Streptokinase', u'always_empty': u'', u'form': u'VIAL', u'brand': u'PROKINASE-M', u'strength_3': u'', u'company': u'Emcure', u'unit': u''}

-- line #29743
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.75G', u'strength_2': u'', u'substance': u'Streptomycin', u'always_empty': u'', u'form': u'INJ', u'brand': u'AMBISTRYN-S', u'strength_3': u'', u'company': u'Nicholas', u'unit': u''}

-- line #29744
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Streptomycin', u'always_empty': u'', u'form': u'INJ', u'brand': u'AMBISTRYN-S', u'strength_3': u'', u'company': u'Nicholas', u'unit': u''}

-- line #29745
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Streptomycin', u'always_empty': u'', u'form': u'INJ', u'brand': u'CIPSTRYN', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #29746
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CIPSTRYN 750 (Cipla)',
	'Streptomycin',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CIPSTRYN 750 (Cipla)'
);

-- line #29747
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Streptomycin', u'always_empty': u'', u'form': u'INJ', u'brand': u'ISOS', u'strength_3': u'', u'company': u'Neon', u'unit': u''}

-- line #29748
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISOS 750 (Neon)',
	'Streptomycin',
	'INJ',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISOS 750 (Neon)'
);

-- line #29749
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Streptomycin', u'always_empty': u'', u'form': u'INJ', u'brand': u'MERSTREP', u'strength_3': u'', u'company': u'Merind', u'unit': u''}

-- line #29750
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Strontium Brom.', u'always_empty': u'', u'form': u'INJ', u'brand': u'EKZEBROL', u'strength_3': u'', u'company': u'Juggat', u'unit': u''}

-- line #29751
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAVISAN 10 (Muller & Ph.)',
	'Strontium Chl.',
	'CRM',
	gm.nullify_empty_string('10')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAVISAN 10 (Muller & Ph.)'
);

-- line #29752
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DESENT 10 (Indoco Rem.)',
	'Strontium Chl.',
	'TOOTH PASTE',
	gm.nullify_empty_string('10')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DESENT 10 (Indoco Rem.)'
);

-- line #29753
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2G', u'strength_2': u'', u'substance': u'Strontium RENELATE', u'always_empty': u'', u'form': u'SAC', u'brand': u'OSTERAM', u'strength_3': u'', u'company': u'Croslands', u'unit': u''}

-- line #29754
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2G', u'strength_2': u'', u'substance': u'Strontium RENELATE', u'always_empty': u'', u'form': u'SACHATE', u'brand': u'RENELATE', u'strength_3': u'', u'company': u'Shreya', u'unit': u''}

-- line #29755
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENTUBATE 50 (Nicholas)',
	'Succinylcholine',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENTUBATE 50 (Nicholas)'
);

-- line #29756
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIDARINE 50 (Gsk)',
	'Succinylcholine',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIDARINE 50 (Gsk)'
);

-- line #29757
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYORELEX 100 (Neon)',
	'Succinylcholine',
	'VIAL',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYORELEX 100 (Neon)'
);

-- line #29758
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYORELEX 500 (Neon)',
	'Succinylcholine',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYORELEX 500 (Neon)'
);

-- line #29759
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'10ML', u'substance': u'Sucralfate', u'always_empty': u'', u'form': u'SUS', u'brand': u'ACICRAL', u'strength_3': u'', u'company': u'TALENT LAB.', u'unit': u''}

-- line #29760
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'10ML', u'substance': u'Sucralfate', u'always_empty': u'', u'form': u'GEL', u'brand': u'ACRAL G/10', u'strength_3': u'', u'company': u'ACTO', u'unit': u''}

-- line #29761
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'5ML', u'substance': u'Sucralfate', u'always_empty': u'', u'form': u'SUS', u'brand': u'ALFATE', u'strength_3': u'', u'company': u'Stadmed', u'unit': u''}

-- line #29762
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Sucralfate', u'always_empty': u'', u'form': u'SUSP', u'brand': u'ARALFATE', u'strength_3': u'', u'company': u'SHINCE', u'unit': u''}

-- line #29763
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Sucralfate', u'always_empty': u'', u'form': u'SYR', u'brand': u'CURAL', u'strength_3': u'', u'company': u'Curex', u'unit': u''}

-- line #29764
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'10ML', u'substance': u'Sucralfate', u'always_empty': u'', u'form': u'SUS', u'brand': u'ELPHATE', u'strength_3': u'', u'company': u'Lancer', u'unit': u''}

-- line #29765
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPOCRAL 20 (EPOCH PH.)',
	'Sucralfate',
	'SUS',
	gm.nullify_empty_string('20')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPOCRAL 20 (EPOCH PH.)'
);

-- line #29766
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'5ML', u'substance': u'Sucralfate', u'always_empty': u'', u'form': u'SUSP', u'brand': u'EROCOT G/5', u'strength_3': u'', u'company': u'NODYSIS PH.', u'unit': u''}

-- line #29767
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Sucralfate', u'always_empty': u'', u'form': u'TAB', u'brand': u'MUCOGARD', u'strength_3': u'', u'company': u'Themis', u'unit': u''}

-- line #29768
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Sucralfate', u'always_empty': u'', u'form': u'TAB', u'brand': u'PRONORM', u'strength_3': u'', u'company': u'Tnt Life', u'unit': u''}

-- line #29769
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'5ML', u'substance': u'Sucralfate', u'always_empty': u'', u'form': u'SUSP', u'brand': u'RADIFLUX G/5', u'strength_3': u'', u'company': u'Radicura', u'unit': u''}

-- line #29770
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Sucralfate', u'always_empty': u'', u'form': u'SYR', u'brand': u'RALFAT', u'strength_3': u'', u'company': u'Ultra Chiron', u'unit': u''}

-- line #29771
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Sucralfate', u'always_empty': u'', u'form': u'TAB', u'brand': u'RECOLFATE', u'strength_3': u'', u'company': u'Reckitt B.', u'unit': u''}

-- line #29772
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Sucralfate', u'always_empty': u'', u'form': u'TAB', u'brand': u'REGEL', u'strength_3': u'', u'company': u'Solitaire', u'unit': u''}

-- line #29773
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARCALION 200 (Serdia)',
	'Sulbutiamine',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARCALION 200 (Serdia)'
);

-- line #29774
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBUCID % 10 (Allergan)',
	'Sulphacetamide Sod.',
	'DPS',
	gm.nullify_empty_string('10')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBUCID % 10 (Allergan)'
);

-- line #29775
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBUCID % 20 (Allergan)',
	'Sulphacetamide Sod.',
	'DPS',
	gm.nullify_empty_string('20')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBUCID % 20 (Allergan)'
);

-- line #29776
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBUCID % 30 (Allergan)',
	'Sulphacetamide Sod.',
	'DPS',
	gm.nullify_empty_string('30')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBUCID % 30 (Allergan)'
);

-- line #29777
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBUSOL % 10 (Indus)',
	'Sulphacetamide Sod.',
	'EYE DPS',
	gm.nullify_empty_string('10')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBUSOL % 10 (Indus)'
);

-- line #29778
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALBUSOL % 20 (Indus)',
	'Sulphacetamide Sod.',
	'EYE DPS',
	gm.nullify_empty_string('20')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALBUSOL % 20 (Indus)'
);

-- line #29779
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLEPH % 20 (Allergan)',
	'Sulphacetamide Sod.',
	'DPS',
	gm.nullify_empty_string('20')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLEPH % 20 (Allergan)'
);

-- line #29780
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLEPH % 30 (Allergan)',
	'Sulphacetamide Sod.',
	'DPS',
	gm.nullify_empty_string('30')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLEPH % 30 (Allergan)'
);

-- line #29781
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOCULA % 10 (East India)',
	'Sulphacetamide Sod.',
	'DPS',
	gm.nullify_empty_string('10')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOCULA % 10 (East India)'
);

-- line #29782
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOCULA % 20 (East India)',
	'Sulphacetamide Sod.',
	'DPS',
	gm.nullify_empty_string('20')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOCULA % 20 (East India)'
);

-- line #29783
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOCULA % 30 (East India)',
	'Sulphacetamide Sod.',
	'DPS',
	gm.nullify_empty_string('30')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOCULA % 30 (East India)'
);

-- line #29784
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCU-SULF 20 (Cipla)',
	'Sulphacetamide Sod.',
	'EYE DPS',
	gm.nullify_empty_string('20')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCU-SULF 20 (Cipla)'
);

-- line #29785
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMIDE 20 (Ophthal R.)',
	'Sulphacetamide Sod.',
	'DPS',
	gm.nullify_empty_string('20')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMIDE 20 (Ophthal R.)'
);

-- line #29786
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPTACID % 10 (Dey''S)',
	'Sulphacetamide Sod.',
	'EYE DPS',
	gm.nullify_empty_string('10')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPTACID % 10 (Dey''S)'
);

-- line #29787
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPTACID % 20 (Dey''S)',
	'Sulphacetamide Sod.',
	'EYE DPS',
	gm.nullify_empty_string('20')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPTACID % 20 (Dey''S)'
);

-- line #29788
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IWATA 500 (Cadila Ph.)',
	'Sulphasalazine',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IWATA 500 (Cadila Ph.)'
);

-- line #29789
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'6,38', u'strength_2': u'', u'substance': u'SULPHONATED SURFACTANT BLEND', u'always_empty': u'', u'form': u'', u'brand': u'ACNE AID BAR', u'strength_3': u'', u'company': u'Elder', u'unit': u'%'}

-- line #29790
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACNEX 6.38 (Unichem)',
	'SULPHONATED SURFACTANT BLEND',
	'SOAP',
	gm.nullify_empty_string('6.38')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACNEX 6.38 (Unichem)'
);

-- line #29791
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'SULPHONATED SURFACTANT BLEND', u'always_empty': u'', u'form': u'SOAP', u'brand': u'MEDSOP', u'strength_3': u'', u'company': u'Croslands', u'unit': u''}

-- line #29792
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'WITH NEEM', u'strength_2': u'', u'substance': u'Sulphur', u'always_empty': u'', u'form': u'', u'brand': u'EXEX BAR', u'strength_3': u'', u'company': u'AXYZEN LIFE', u'unit': u''}

-- line #29793
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMPIROK 250 (Astrum Hc.)',
	'Sultamicillin',
	'DT',
	gm.nullify_empty_string('250')::numeric,
	'mg(TOSYLATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMPIROK 250 (Astrum Hc.)'
);

-- line #29794
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMPIROK 375 (Astrum Hc.)',
	'Sultamicillin',
	'TAB',
	gm.nullify_empty_string('375')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMPIROK 375 (Astrum Hc.)'
);

-- line #29795
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BETAMP ORAL 375 (Torrent)',
	'Sultamicillin',
	'TAB',
	gm.nullify_empty_string('375')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BETAMP ORAL 375 (Torrent)'
);

-- line #29796
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIGRATAN 100 (Dabur Ph.)',
	'Sumatriptan Succinate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIGRATAN 100 (Dabur Ph.)'
);

-- line #29797
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIGRATAN 50 (Dabur Ph.)',
	'Sumatriptan Succinate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIGRATAN 50 (Dabur Ph.)'
);

-- line #29798
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'COLLAGEN DRESSING SOFT SPONGE PAD', u'strength_2': u'', u'substance': u'SURGICAL PREPARATION', u'always_empty': u'', u'form': u'PAD', u'brand': u'GELFIX', u'strength_3': u'', u'company': u'Alembic', u'unit': u''}

-- line #29799
-- ignoring line: field [strength_1] not numeric: >>>MYDRATE<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'MYDRATE', u'strength_2': u'', u'substance': u'SURGICAL PREPARATION', u'always_empty': u'', u'form': u'LIQ', u'brand': u'OXOFERIN', u'strength_3': u'', u'company': u'Elder', u'unit': u'GLYCEROL IN 98ML CLEANSED WATER / 100ML 2.09'}

-- line #29800
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'PHYSIOLOGICAL LIPIDS', u'strength_2': u'', u'substance': u'SURGICAL PREPARATION', u'always_empty': u'', u'form': u'CRM', u'brand': u'PHYSIOGEL', u'strength_3': u'', u'company': u'Elder', u'unit': u''}

-- line #29801
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'I.V. CANULA', u'strength_2': u'', u'substance': u'SURGICAL PREPARATIONS', u'always_empty': u'', u'form': u'', u'brand': u'BIOFLON IV CANULA', u'strength_3': u'', u'company': u'Chpl', u'unit': u''}

-- line #29802
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'SURGICAL PREPARATIONS', u'always_empty': u'', u'form': u'POW', u'brand': u'BIO-SORB', u'strength_3': u'', u'company': u'J.&J.', u'unit': u''}

-- line #29803
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'OLEORESIN CAPSICUM', u'strength_2': u'', u'substance': u'SURGICAL PREPARATIONS', u'always_empty': u'', u'form': u'', u'brand': u'CAPSOLA PLASTER CM*12CM', u'strength_3': u'', u'company': u'Ranbaxy', u'unit': u''}

-- line #29804
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'OLEORESIN CAPSICUM', u'strength_2': u'', u'substance': u'SURGICAL PREPARATIONS', u'always_empty': u'', u'form': u'', u'brand': u'CAPSOLA PLUS PLASTER', u'strength_3': u'', u'company': u'Ranbaxy', u'unit': u'METHYL SALICYLATE'}

-- line #29805
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'DRESSING', u'strength_2': u'', u'substance': u'SURGICAL PREPARATIONS', u'always_empty': u'', u'form': u'BANDAGE', u'brand': u'DYNACREPE', u'strength_3': u'', u'company': u'J.&J.', u'unit': u''}

-- line #29806
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'SYNDET CU 0033', u'always_empty': u'', u'form': u'', u'brand': u'DIASOFT', u'strength_3': u'', u'company': u'CURATIO HC.', u'unit': u''}

-- line #29807
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'SYNDET BASE CU 0033 98.5', u'strength_2': u'', u'substance': u'SYNDET CU 0033', u'always_empty': u'', u'form': u'', u'brand': u'FASH BAR', u'strength_3': u'', u'company': u'CURATIO HC.', u'unit': u'% TO 99.5'}

-- line #29808
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'SYNTHETIC AND VEGETABLE GUMS', u'always_empty': u'', u'form': u'', u'brand': u'KY LUBRICATING JALLY', u'strength_3': u'', u'company': u'J.&J.', u'unit': u''}

-- line #29809
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'11,25', u'strength_2': u'', u'substance': u'SYNTHETIC AND VEGETABLE GUMS', u'always_empty': u'', u'form': u'', u'brand': u'K-Y LUBRICATING JELLY', u'strength_3': u'', u'company': u'J. & J.', u'unit': u'%'}

-- line #29810
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'SYNTHETIC AND VEGETABLE GUMS', u'always_empty': u'', u'form': u'', u'brand': u'LUBIC JELLY', u'strength_3': u'', u'company': u'Neon', u'unit': u''}

-- line #29811
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOMUS 1 (BIONICHE)',
	'TACROLIMUS',
	'CAP',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOMUS 1 (BIONICHE)'
);

-- line #29812
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CROLIM 0.5 (Ranbaxy S.Sp.)',
	'TACROLIMUS',
	'CAP',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CROLIM 0.5 (Ranbaxy S.Sp.)'
);

-- line #29813
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CROLIM 1 (Ranbaxy S.Sp.)',
	'TACROLIMUS',
	'CAP',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CROLIM 1 (Ranbaxy S.Sp.)'
);

-- line #29814
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CROLIM 5 (Ranbaxy S.Sp.)',
	'TACROLIMUS',
	'CAP',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CROLIM 5 (Ranbaxy S.Sp.)'
);

-- line #29815
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMGRAF 0.5 (Emcure)',
	'TACROLIMUS',
	'CAP',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMGRAF 0.5 (Emcure)'
);

-- line #29816
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMGRAF 1 (Emcure)',
	'TACROLIMUS',
	'CAP',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMGRAF 1 (Emcure)'
);

-- line #29817
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMGRAF 2 (Emcure)',
	'TACROLIMUS',
	'CAP',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMGRAF 2 (Emcure)'
);

-- line #29818
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'TACROLIMUS', u'always_empty': u'', u'form': u'OINT', u'brand': u'MUSTOPIC', u'strength_3': u'', u'company': u'Systopic', u'unit': u''}

-- line #29819
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLMIS 1 (Unichem)',
	'TACROLIMUS',
	'F. GM',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLMIS 1 (Unichem)'
);

-- line #29820
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,03', u'strength_2': u'', u'substance': u'TACROLIMUS', u'always_empty': u'', u'form': u'', u'brand': u'OLMIS GM', u'strength_3': u'', u'company': u'Unichem', u'unit': u'mg'}

-- line #29821
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLMIS 0.5 (Unisearch)',
	'TACROLIMUS',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLMIS 0.5 (Unisearch)'
);

-- line #29822
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLMIS 1 (Unisearch)',
	'TACROLIMUS',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLMIS 1 (Unisearch)'
);

-- line #29823
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLMIS 5 (Unisearch)',
	'TACROLIMUS',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLMIS 5 (Unisearch)'
);

-- line #29824
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANGRAF 0.5 (Panacea)',
	'TACROLIMUS',
	'CAP',
	gm.nullify_empty_string('0.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANGRAF 0.5 (Panacea)'
);

-- line #29825
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANGRAF 1 (Panacea)',
	'TACROLIMUS',
	'CAP',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANGRAF 1 (Panacea)'
);

-- line #29826
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PANGRAF 5 (Panacea)',
	'TACROLIMUS',
	'CAP',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PANGRAF 5 (Panacea)'
);

-- line #29827
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENGRAF 2 (Panacea)',
	'TACROLIMUS',
	'CAP',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENGRAF 2 (Panacea)'
);

-- line #29828
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'36 HOURS 10 (Cadila Ph.)',
	'TADALAFIL',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '36 HOURS 10 (Cadila Ph.)'
);

-- line #29829
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'36 HOURS 20 (Cadila Ph.)',
	'TADALAFIL',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '36 HOURS 20 (Cadila Ph.)'
);

-- line #29830
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERECTALIS 20 (Cipla)',
	'TADALAFIL',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERECTALIS 20 (Cipla)'
);

-- line #29831
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EROTID 10 (Ochoa)',
	'TADALAFIL',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EROTID 10 (Ochoa)'
);

-- line #29832
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EROTID 20 (Ochoa)',
	'TADALAFIL',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EROTID 20 (Ochoa)'
);

-- line #29833
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FILDA 10 (Intas)',
	'TADALAFIL',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FILDA 10 (Intas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FILDA 20 (Intas)',
	'TADALAFIL',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FILDA 20 (Intas)'
);

-- line #29834
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORZEST 10 (Ranbaxy)',
	'TADALAFIL',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORZEST 10 (Ranbaxy)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORZEST 20 (Ranbaxy)',
	'TADALAFIL',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORZEST 20 (Ranbaxy)'
);

-- line #29835
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GETCO-20 20 (OVERSEAS MED.)',
	'TADALAFIL',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GETCO-20 20 (OVERSEAS MED.)'
);

-- line #29836
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GETGO 10 (OVERSEAS MED.)',
	'TADALAFIL',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GETGO 10 (OVERSEAS MED.)'
);

-- line #29837
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANFORCE MORE 10 (Mankind)',
	'TADALAFIL',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANFORCE MORE 10 (Mankind)'
);

-- line #29838
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POPUP 10 (NPIL)',
	'TADALAFIL',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POPUP 10 (NPIL)'
);

-- line #29839
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PULMOPRES 20 (Cipla)',
	'TADALAFIL',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PULMOPRES 20 (Cipla)'
);

-- line #29840
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLASTOFEN 10 (CH.Bhagat)',
	'Tamoxifen',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLASTOFEN 10 (CH.Bhagat)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLASTOFEN 20 (CH.Bhagat)',
	'Tamoxifen',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLASTOFEN 20 (CH.Bhagat)'
);

-- line #29841
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYTOPAM 10 (Cipla)',
	'Tamoxifen',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYTOPAM 10 (Cipla)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYTOPAM 20 (Cipla)',
	'Tamoxifen',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYTOPAM 20 (Cipla)'
);

-- line #29842
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYTOTAM 10 (Cipla)',
	'Tamoxifen',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYTOTAM 10 (Cipla)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYTOTAM 20 (Cipla)',
	'Tamoxifen',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYTOTAM 20 (Cipla)'
);

-- line #29843
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELDTAM 10 (Elder)',
	'Tamoxifen',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELDTAM 10 (Elder)'
);

-- line #29844
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELDTAM 20 (Elder)',
	'Tamoxifen',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELDTAM 20 (Elder)'
);

-- line #29845
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAMOFEN 10 (Khandelwal)',
	'Tamoxifen',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAMOFEN 10 (Khandelwal)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAMOFEN 20 (Khandelwal)',
	'Tamoxifen',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAMOFEN 20 (Khandelwal)'
);

-- line #29846
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXIFEN 10 (VHB)',
	'Tamoxifen',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXIFEN 10 (VHB)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOXIFEN 20 (VHB)',
	'Tamoxifen',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOXIFEN 20 (VHB)'
);

-- line #29847
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOTAM 10 (Biological E.)',
	'Tamoxifen',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOTAM 10 (Biological E.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOTAM 20 (Biological E.)',
	'Tamoxifen',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOTAM 20 (Biological E.)'
);

-- line #29848
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOLVADEX 10 (Astrazeneca)',
	'Tamoxifen',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOLVADEX 10 (Astrazeneca)'
);

-- line #29849
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONCOMOX 10 (Sun)',
	'Tamoxifen',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONCOMOX 10 (Sun)'
);

-- line #29850
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONCOTAM 10 (Zydus A.)',
	'Tamoxifen',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONCOTAM 10 (Zydus A.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONCOTAM 20 (Zydus A.)',
	'Tamoxifen',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONCOTAM 20 (Zydus A.)'
);

-- line #29851
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AIVO 0.4 (Pfizer)',
	'Tamsulosin Hcl.',
	'CAP',
	gm.nullify_empty_string('0.4')::numeric,
	'mg(MR)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AIVO 0.4 (Pfizer)'
);

-- line #29852
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AKSITAM 0.4 (Aksigen Hosp.)',
	'Tamsulosin Hcl.',
	'CAP',
	gm.nullify_empty_string('0.4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AKSITAM 0.4 (Aksigen Hosp.)'
);

-- line #29853
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALFATAM 0.2 (German R.)',
	'Tamsulosin Hcl.',
	'CAP',
	gm.nullify_empty_string('0.2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALFATAM 0.2 (German R.)'
);

-- line #29854
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALFATAM 0.4 (German R.)',
	'Tamsulosin Hcl.',
	'CAP',
	gm.nullify_empty_string('0.4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALFATAM 0.4 (German R.)'
);

-- line #29855
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BEZIP-02 0.2 (Emcure)',
	'Tamsulosin Hcl.',
	'CAP',
	gm.nullify_empty_string('0.2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BEZIP-02 0.2 (Emcure)'
);

-- line #29856
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BEZIP-04 0.4 (Emcure)',
	'Tamsulosin Hcl.',
	'CAP',
	gm.nullify_empty_string('0.4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BEZIP-04 0.4 (Emcure)'
);

-- line #29857
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONTIFLO 0.2 (Ranbaxy)',
	'Tamsulosin Hcl.',
	'OD CAP',
	gm.nullify_empty_string('0.2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONTIFLO 0.2 (Ranbaxy)'
);

-- line #29858
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONTIFLO 0.4 (Ranbaxy)',
	'Tamsulosin Hcl.',
	'OD CAP',
	gm.nullify_empty_string('0.4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONTIFLO 0.4 (Ranbaxy)'
);

-- line #29859
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200MCG', u'strength_2': u'', u'substance': u'Tamsulosin Hcl.', u'always_empty': u'', u'form': u'CAP', u'brand': u'DYNAPRES', u'strength_3': u'', u'company': u"Dr.Reddy''S", u'unit': u''}

-- line #29860
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'400MCG', u'strength_2': u'', u'substance': u'Tamsulosin Hcl.', u'always_empty': u'', u'form': u'CAP', u'brand': u'DYNAPRES', u'strength_3': u'', u'company': u"Dr.Reddy''S", u'unit': u''}

-- line #29861
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLODART 0.4 (Otsira)',
	'Tamsulosin Hcl.',
	'CAP',
	gm.nullify_empty_string('0.4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLODART 0.4 (Otsira)'
);

-- line #29862
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROSTOCARE 0.4 (Royal)',
	'Tamsulosin Hcl.',
	'TAB',
	gm.nullify_empty_string('0.4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROSTOCARE 0.4 (Royal)'
);

-- line #29863
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIFLO 0.4 (BIOMAX BIO.)',
	'Tamsulosin Hcl.',
	'CAP',
	gm.nullify_empty_string('0.4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIFLO 0.4 (BIOMAX BIO.)'
);

-- line #29864
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALENFAST-25 25 (ALEMBIC)',
	'TAPENTADOL',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg(AS TAPENTADOL HCL.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALENFAST-25 25 (ALEMBIC)'
);

-- line #29865
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALENFAST-50 50 (ALEMBIC)',
	'TAPENTADOL',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg(AS TAPENTADOL HCL.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALENFAST-50 50 (ALEMBIC)'
);

-- line #29866
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORAC 500 (Juggat)',
	'TAURINE',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORAC 500 (Juggat)'
);

-- line #29867
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LA TEZ 0.05 (Nicholas)',
	'TAZOROTENE',
	'GEL',
	gm.nullify_empty_string('0.05')::numeric,
	'%/0.1'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LA TEZ 0.05 (Nicholas)'
);

-- line #29868
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,04', u'strength_2': u'', u'substance': u'Tea Tree Oil', u'always_empty': u'', u'form': u'GEL', u'brand': u'BURNAID', u'strength_3': u'', u'company': u'Elder', u'unit': u''}

-- line #29869
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1', u'strength_2': u'', u'substance': u'TEA TREE OIL', u'always_empty': u'', u'form': u'', u'brand': u'GORGEUS BAR', u'strength_3': u'', u'company': u'Ajanta Ph.', u'unit': u'%W/W(MELALEUCA OIL)'}

-- line #29870
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GORGEUS FACE CLEANSING 0.75 (Ajanta Ph.)',
	'TEA TREE OIL',
	'GEL',
	gm.nullify_empty_string('0.75')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GORGEUS FACE CLEANSING 0.75 (Ajanta Ph.)'
);

-- line #29871
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IBSINORM 2 (Sun)',
	'Tegaserod',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IBSINORM 2 (Sun)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IBSINORM 6 (Sun)',
	'Tegaserod',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IBSINORM 6 (Sun)'
);

-- line #29872
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IRBEZ 6 (Emcure)',
	'Tegaserod',
	'TAB',
	gm.nullify_empty_string('6')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IRBEZ 6 (Emcure)'
);

-- line #29873
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COL 200 (Gufic Bio.)',
	'Teicoplanin',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COL 200 (Gufic Bio.)'
);

-- line #29874
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COL 400 (Gufic Bio.)',
	'Teicoplanin',
	'INJ',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COL 400 (Gufic Bio.)'
);

-- line #29875
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORPLUS-400 400 (Zuventus)',
	'Teicoplanin',
	'INJ',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORPLUS-400 400 (Zuventus)'
);

-- line #29876
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GERTIC 200 (German R.)',
	'Teicoplanin',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GERTIC 200 (German R.)'
);

-- line #29877
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GERTIC 400 (German R.)',
	'Teicoplanin',
	'INJ',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GERTIC 400 (German R.)'
);

-- line #29878
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYCOPLAN 200 (Lyka)',
	'Teicoplanin',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYCOPLAN 200 (Lyka)'
);

-- line #29879
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYCOPLAN 400 (Lyka)',
	'Teicoplanin',
	'INJ',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYCOPLAN 400 (Lyka)'
);

-- line #29880
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200', u'strength_2': u'', u'substance': u'Teicoplanin', u'always_empty': u'', u'form': u'', u'brand': u'MEROPLAN', u'strength_3': u'', u'company': u'Piramal Hc.', u'unit': u'mg'}

-- line #29881
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANZITEL 40 (ESSWEIL)',
	'Telmisartan',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANZITEL 40 (ESSWEIL)'
);

-- line #29882
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARBITEL 20 (Micro Labs)',
	'Telmisartan',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARBITEL 20 (Micro Labs)'
);

-- line #29883
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARBITEL 40 (Micro Labs)',
	'Telmisartan',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARBITEL 40 (Micro Labs)'
);

-- line #29884
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARBITEL 80 (Micro Labs)',
	'Telmisartan',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARBITEL 80 (Micro Labs)'
);

-- line #29885
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASTEL 20 (AS PHARMA)',
	'Telmisartan',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASTEL 20 (AS PHARMA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASTEL 40 (AS PHARMA)',
	'Telmisartan',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASTEL 40 (AS PHARMA)'
);

-- line #29886
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXETEN 20 (Organon)',
	'Telmisartan',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXETEN 20 (Organon)'
);

-- line #29887
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXETEN 40 (Organon)',
	'Telmisartan',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXETEN 40 (Organon)'
);

-- line #29888
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORTEL 20 (Corona)',
	'Telmisartan',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORTEL 20 (Corona)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORTEL 40 (Corona)',
	'Telmisartan',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORTEL 40 (Corona)'
);

-- line #29889
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CRESAR 20 (Cipla)',
	'Telmisartan',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CRESAR 20 (Cipla)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CRESAR 40 (Cipla)',
	'Telmisartan',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CRESAR 40 (Cipla)'
);

-- line #29890
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CRESAR 80 (Cipla)',
	'Telmisartan',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CRESAR 80 (Cipla)'
);

-- line #29891
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ECOTEL 20 (Ordain Hc.)',
	'Telmisartan',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ECOTEL 20 (Ordain Hc.)'
);

-- line #29892
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ECOTEL 40 (Ordain Hc.)',
	'Telmisartan',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ECOTEL 40 (Ordain Hc.)'
);

-- line #29893
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERITEL 20 (ERIS LIFE)',
	'Telmisartan',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERITEL 20 (ERIS LIFE)'
);

-- line #29894
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERITEL 40 (ERIS LIFE)',
	'Telmisartan',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERITEL 40 (ERIS LIFE)'
);

-- line #29895
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ERITEL 80 (ERIS LIFE)',
	'Telmisartan',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ERITEL 80 (ERIS LIFE)'
);

-- line #29896
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETELA 40 (VENUS REM.)',
	'Telmisartan',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETELA 40 (VENUS REM.)'
);

-- line #29897
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HITARGET-40 40 (Panacea)',
	'Telmisartan',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HITARGET-40 40 (Panacea)'
);

-- line #29898
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HITARGET 20 (Panacea)',
	'Telmisartan',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HITARGET 20 (Panacea)'
);

-- line #29899
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYTEL 20 (EAST WEST)',
	'Telmisartan',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYTEL 20 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYTEL 40 (EAST WEST)',
	'Telmisartan',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYTEL 40 (EAST WEST)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYTEL 80 (EAST WEST)',
	'Telmisartan',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYTEL 80 (EAST WEST)'
);

-- line #29900
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDITEL 20 (Zydus Med.)',
	'Telmisartan',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDITEL 20 (Zydus Med.)'
);

-- line #29901
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDITEL 40 (Zydus Med.)',
	'Telmisartan',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDITEL 40 (Zydus Med.)'
);

-- line #29902
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INDITEL 80 (Zydus Med.)',
	'Telmisartan',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INDITEL 80 (Zydus Med.)'
);

-- line #29903
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACSART 20 (Macleods)',
	'Telmisartan',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACSART 20 (Macleods)'
);

-- line #29904
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MACSART 40 (Macleods)',
	'Telmisartan',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MACSART 40 (Macleods)'
);

-- line #29905
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MISART 40 (MISSION RES.)',
	'Telmisartan',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MISART 40 (MISSION RES.)'
);

-- line #29906
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYTEL 40 (RHINE BIO.)',
	'Telmisartan',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYTEL 40 (RHINE BIO.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYTEL 80 (RHINE BIO.)',
	'Telmisartan',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYTEL 80 (RHINE BIO.)'
);

-- line #29907
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEWTEL 20 (Systopic)',
	'Telmisartan',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEWTEL 20 (Systopic)'
);

-- line #29908
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEWTEL 40 (Systopic)',
	'Telmisartan',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEWTEL 40 (Systopic)'
);

-- line #29909
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OZOTEL 40 (Ozone Ph.)',
	'Telmisartan',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OZOTEL 40 (Ozone Ph.)'
);

-- line #29910
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELMISART 40 (LA RENON)',
	'Telmisartan',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELMISART 40 (LA RENON)'
);

-- line #29911
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELMISART 80 (LA RENON)',
	'Telmisartan',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELMISART 80 (LA RENON)'
);

-- line #29912
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMZOLAM 100 (MIRACALUS)',
	'TEMOZOLOMIDE',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMZOLAM 100 (MIRACALUS)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMZOLAM 250 (MIRACALUS)',
	'TEMOZOLOMIDE',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMZOLAM 250 (MIRACALUS)'
);

-- line #29913
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMZOLAM 20 (MIRACALUS)',
	'TEMOZOLOMIDE',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMZOLAM 20 (MIRACALUS)'
);

-- line #29914
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIOMIDE 100 (ZEN LIFE)',
	'TEMOZOLOMIDE',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIOMIDE 100 (ZEN LIFE)'
);

-- line #29915
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIOMIDE 250 (ZEN LIFE)',
	'TEMOZOLOMIDE',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIOMIDE 250 (ZEN LIFE)'
);

-- line #29916
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIOZ 100 (Dr.Reddy''S)',
	'TEMOZOLOMIDE',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIOZ 100 (Dr.Reddy''S)'
);

-- line #29917
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIOZ 20 (Dr.Reddy''S)',
	'TEMOZOLOMIDE',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIOZ 20 (Dr.Reddy''S)'
);

-- line #29918
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLIOZ 250 (Dr.Reddy''S)',
	'TEMOZOLOMIDE',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLIOZ 250 (Dr.Reddy''S)'
);

-- line #29919
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLISTROMA 100 (Alkem)',
	'TEMOZOLOMIDE',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLISTROMA 100 (Alkem)'
);

-- line #29920
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLISTROMA 250 (Alkem)',
	'TEMOZOLOMIDE',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLISTROMA 250 (Alkem)'
);

-- line #29921
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMOZIDE 100 (RANBAXY (S.S.))',
	'TEMOZOLOMIDE',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMOZIDE 100 (RANBAXY (S.S.))'
);

-- line #29922
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMOZIDE 250 (RANBAXY (S.S.))',
	'TEMOZOLOMIDE',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMOZIDE 250 (RANBAXY (S.S.))'
);

-- line #29923
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUBLAST 20 (ZYDUS ONC.)',
	'TEMOZOLOMIDE',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUBLAST 20 (ZYDUS ONC.)'
);

-- line #29924
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVOTIL 20 (Zydus Cadila)',
	'Tenoxicam',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVOTIL 20 (Zydus Cadila)'
);

-- line #29925
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYTRIN 1 (Abbott)',
	'Terazosin Hcl.',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYTRIN 1 (Abbott)'
);

-- line #29926
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYTRIN 2 (Abbott)',
	'Terazosin Hcl.',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYTRIN 2 (Abbott)'
);

-- line #29927
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYTRIN 5 (Abbott)',
	'Terazosin Hcl.',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYTRIN 5 (Abbott)'
);

-- line #29928
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLYSTER 1 (Zydus A.)',
	'Terazosin Hcl.',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLYSTER 1 (Zydus A.)'
);

-- line #29929
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLYSTER 2 (Zydus A.)',
	'Terazosin Hcl.',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLYSTER 2 (Zydus A.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLYSTER 5 (Zydus A.)',
	'Terazosin Hcl.',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLYSTER 5 (Zydus A.)'
);

-- line #29930
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AF-TER 1 (Palsons)',
	'Terbinafine',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AF-TER 1 (Palsons)'
);

-- line #29931
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AF-TER 1 (Palsons)',
	'Terbinafine',
	'LOT',
	gm.nullify_empty_string('1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AF-TER 1 (Palsons)'
);

-- line #29932
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AF-TER 250 (Palsons)',
	'Terbinafine',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AF-TER 250 (Palsons)'
);

-- line #29933
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Terbinafine', u'always_empty': u'', u'form': u'CRM', u'brand': u'BINAFIN', u'strength_3': u'', u'company': u'Issar Ph.', u'unit': u''}

-- line #29934
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DASKIL 1 (Novartis)',
	'Terbinafine',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DASKIL 1 (Novartis)'
);

-- line #29935
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DASKIL 250 (Novartis)',
	'Terbinafine',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DASKIL 250 (Novartis)'
);

-- line #29936
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DERMAFINE 1 (SHREYA)',
	'Terbinafine',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DERMAFINE 1 (SHREYA)'
);

-- line #29937
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXIFINE 1 (Dr.Reddy''S)',
	'Terbinafine',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXIFINE 1 (Dr.Reddy''S)'
);

-- line #29938
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXIFINE 125 (Dr.Reddy''S)',
	'Terbinafine',
	'TAB',
	gm.nullify_empty_string('125')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXIFINE 125 (Dr.Reddy''S)'
);

-- line #29939
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXIFINE 250 (Dr.Reddy''S)',
	'Terbinafine',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXIFINE 250 (Dr.Reddy''S)'
);

-- line #29940
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FINTRIX 1 (Micro)',
	'Terbinafine',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FINTRIX 1 (Micro)'
);

-- line #29941
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FINTRIX 250 (Micro Labs)',
	'Terbinafine',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FINTRIX 250 (Micro Labs)'
);

-- line #29942
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNGICREME 1 (Cipla)',
	'Terbinafine',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNGICREME 1 (Cipla)'
);

-- line #29943
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNGI 1 (Cipla)',
	'Terbinafine',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNGI 1 (Cipla)'
);

-- line #29944
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1', u'strength_2': u'', u'substance': u'Terbinafine', u'always_empty': u'', u'form': u'', u'brand': u'FUNGOTEK CRAM', u'strength_3': u'', u'company': u'F D C', u'unit': u'%W/W'}

-- line #29945
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FUNGOTEK 250 (F D C)',
	'Terbinafine',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FUNGOTEK 250 (F D C)'
);

-- line #29946
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIFEN 1 (HETERO HC.)',
	'Terbinafine',
	'CRM/LOT',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIFEN 1 (HETERO HC.)'
);

-- line #29947
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HIFEN 250 (HETERO HC.)',
	'Terbinafine',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HIFEN 250 (HETERO HC.)'
);

-- line #29948
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMISIL 1 (Novartis)',
	'Terbinafine',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMISIL 1 (Novartis)'
);

-- line #29949
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAMISIL 250 (Novartis)',
	'Terbinafine',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAMISIL 250 (Novartis)'
);

-- line #29950
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCOFEM 1 (Fem Care)',
	'Terbinafine',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCOFEM 1 (Fem Care)'
);

-- line #29951
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCOSEAL 1 (Organic Lab)',
	'Terbinafine',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCOSEAL 1 (Organic Lab)'
);

-- line #29952
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYCOSOL 250 (SOL DERMA)',
	'Terbinafine',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYCOSOL 250 (SOL DERMA)'
);

-- line #29953
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHYTE 1 (INVIDA)',
	'Terbinafine',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHYTE 1 (INVIDA)'
);

-- line #29954
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHYTE 250 (INVIDA)',
	'Terbinafine',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHYTE 250 (INVIDA)'
);

-- line #29955
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHYTE 250 (INVIDA)',
	'Terbinafine',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHYTE 250 (INVIDA)'
);

-- line #29956
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'TerbutaliNE', u'always_empty': u'', u'form': u'SYR', u'brand': u'ASMARIL', u'strength_3': u'', u'company': u'Dwd', u'unit': u''}

-- line #29957
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASMATERB 1.5 (Rpg Life)',
	'Terbutaline Sulph.',
	'SYR',
	gm.nullify_empty_string('1.5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASMATERB 1.5 (Rpg Life)'
);

-- line #29958
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASMATERB 2.5 (Rpg Life)',
	'Terbutaline Sulph.',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASMATERB 2.5 (Rpg Life)'
);

-- line #29959
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASMATERB 5 (Rpg Life)',
	'Terbutaline Sulph.',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASMATERB 5 (Rpg Life)'
);

-- line #29960
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250MCG', u'strength_2': u'', u'substance': u'Terbutaline Sulph.', u'always_empty': u'', u'form': u'', u'brand': u'BICANYL MISTHALER', u'strength_3': u'', u'company': u'Astrazeneca', u'unit': u''}

-- line #29961
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5', u'strength_2': u'', u'substance': u'Terbutaline Sulph.', u'always_empty': u'', u'form': u'', u'brand': u'BRICANYL DURULES', u'strength_3': u'', u'company': u'Astrazeneca', u'unit': u'mg'}

-- line #29962
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'7,5', u'strength_2': u'', u'substance': u'Terbutaline Sulph.', u'always_empty': u'', u'form': u'', u'brand': u'BRICANYL DURULES', u'strength_3': u'', u'company': u'Astrazeneca', u'unit': u'mg'}

-- line #29963
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250MCG', u'strength_2': u'DOSE', u'substance': u'Terbutaline Sulph.', u'always_empty': u'', u'form': u'INHALER/MISTHALER', u'brand': u'BRICANYL', u'strength_3': u'', u'company': u'Astrazeneca', u'unit': u''}

-- line #29964
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRICANYL 0.5 (Astrazeneca)',
	'Terbutaline Sulph.',
	'INJ',
	gm.nullify_empty_string('0.5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRICANYL 0.5 (Astrazeneca)'
);

-- line #29965
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250MCG', u'strength_2': u'1PUFF', u'substance': u'Terbutaline Sulph.', u'always_empty': u'', u'form': u'', u'brand': u'BRICANYL MDI', u'strength_3': u'', u'company': u'ASTRAZENECA', u'unit': u''}

-- line #29966
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRICANYL NEBULISING 10 (Astrazeneca)',
	'Terbutaline Sulph.',
	'SOL',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRICANYL NEBULISING 10 (Astrazeneca)'
);

-- line #29967
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRICANYL NEBULISING 10 (Astrazeneca)',
	'Terbutaline Sulph.',
	'SOLN',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRICANYL NEBULISING 10 (Astrazeneca)'
);

-- line #29968
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRICANYL 1.5 (Astrazeneca)',
	'Terbutaline Sulph.',
	'SYR',
	gm.nullify_empty_string('1.5')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRICANYL 1.5 (Astrazeneca)'
);

-- line #29969
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRICANYL 2.5 (Astrazeneca)',
	'Terbutaline Sulph.',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRICANYL 2.5 (Astrazeneca)'
);

-- line #29970
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRICANYL 5 (Astrazeneca)',
	'Terbutaline Sulph.',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRICANYL 5 (Astrazeneca)'
);

-- line #29971
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRONTALINE 2.5 (Nicholas)',
	'Terbutaline Sulph.',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRONTALINE 2.5 (Nicholas)'
);

-- line #29972
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRONTALINE 5 (Nicholas)',
	'Terbutaline Sulph.',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRONTALINE 5 (Nicholas)'
);

-- line #29973
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GYNO-TERAZOL 0.8 (Ethnor)',
	'Terconazole',
	'CRM',
	gm.nullify_empty_string('0.8')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GYNO-TERAZOL 0.8 (Ethnor)'
);

-- line #29974
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'80', u'strength_2': u'', u'substance': u'Terconazole', u'always_empty': u'', u'form': u'', u'brand': u'GYNO-TERAZOL OVULES', u'strength_3': u'', u'company': u'Ethnor', u'unit': u'mg'}

-- line #29975
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAYLERT 30 (Micro Labs)',
	'Terfenadine',
	'SYR',
	gm.nullify_empty_string('30')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAYLERT 30 (Micro Labs)'
);

-- line #29976
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAYLERT 60 (Micro Labs)',
	'Terfenadine',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAYLERT 60 (Micro Labs)'
);

-- line #29977
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HISTAFEN 60 (Dey''S)',
	'Terfenadine',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HISTAFEN 60 (Dey''S)'
);

-- line #29978
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HITERF 30 (HETERO HC.)',
	'Terfenadine',
	'SYR',
	gm.nullify_empty_string('30')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HITERF 30 (HETERO HC.)'
);

-- line #29979
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HITERF 120 (HETERO HC.)',
	'Terfenadine',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HITERF 120 (HETERO HC.)'
);

-- line #29980
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HITERF 60 (HETERO HC.)',
	'Terfenadine',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HITERF 60 (HETERO HC.)'
);

-- line #29981
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OLDIN 60 (Olcare)',
	'Terfenadine',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OLDIN 60 (Olcare)'
);

-- line #29982
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RHITER 30 (Panacea)',
	'Terfenadine',
	'SYR',
	gm.nullify_empty_string('30')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RHITER 30 (Panacea)'
);

-- line #29983
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RHITER 120 (Panacea)',
	'Terfenadine',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RHITER 120 (Panacea)'
);

-- line #29984
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RHITER 60 (Panacea)',
	'Terfenadine',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RHITER 60 (Panacea)'
);

-- line #29985
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I. ( R- HUMAN PARATHYROID HORMONE 1-34)', u'strength_2': u'', u'substance': u'TERIPARATIDE', u'always_empty': u'', u'form': u'INJ', u'brand': u'BONISTA', u'strength_3': u'', u'company': u'Ranbaxy', u'unit': u''}

-- line #29986
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'750MCG', u'strength_2': u'3ML(TERIPARATIDE(R-HUMAN) PARATHYROID HORMONE (1-34) (250MCG', u'substance': u'TERIPARATIDE', u'always_empty': u'', u'form': u'', u'brand': u'BONISTA PEN CARTRIDGE', u'strength_3': u'ML))', u'company': u'Ranbaxy', u'unit': u''}

-- line #29987
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REMESTYP 1 (Ferring Ph.)',
	'TERLIPRESSIN',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'mg(IN 10ML OF SOL. FOR INJ)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REMESTYP 1 (Ferring Ph.)'
);

-- line #29988
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'TERMINALIA ARJUNA TRIBULUS TERRESTRIES CUBIA CORDIFOLIA ETC', u'always_empty': u'', u'form': u'', u'brand': u'HART SMART', u'strength_3': u'', u'company': u'PINK HEALTH', u'unit': u''}

-- line #29989
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANDROSURE % 1 (German R.)',
	'Testosterone',
	'GEL',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANDROSURE % 1 (German R.)'
);

-- line #29990
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CERNOS 100 (SUN)',
	'Testosterone CYPIONATE',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CERNOS 100 (SUN)'
);

-- line #29991
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CERNOS 200 (SUN)',
	'Testosterone CYPIONATE',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CERNOS 200 (SUN)'
);

-- line #29992
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARNOLD 250 (Ind-Swift)',
	'Testosterone Enanthate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARNOLD 250 (Ind-Swift)'
);

-- line #29993
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROSTERONE 250 (Prohealth)',
	'Testosterone Enanthate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROSTERONE 250 (Prohealth)'
);

-- line #29994
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANDRIOL 40 (Organon)',
	'Testosterone Undecanoate',
	'CAP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANDRIOL 40 (Organon)'
);

-- line #29995
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANDROFIL 40 (Cipla)',
	'Testosterone Undecanoate',
	'CAP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANDROFIL 40 (Cipla)'
);

-- line #29996
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANDROSURE GM 1000 (German R.)',
	'Testosterone Undecanoate',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg/4ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANDROSURE GM 1000 (German R.)'
);

-- line #29997
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANDROSURE SOFT 40 (German R.)',
	'Testosterone Undecanoate',
	'CAP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANDROSURE SOFT 40 (German R.)'
);

-- line #29998
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CERNOS 40 (Sun)',
	'Testosterone Undecanoate',
	'CAP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CERNOS 40 (Sun)'
);

-- line #29999
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CERNOS DEPOT 250 (Sun)',
	'Testosterone Undecanoate',
	'INJ',
	gm.nullify_empty_string('250')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CERNOS DEPOT 250 (Sun)'
);

-- line #30000
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUVIR 40 (Infar)',
	'Testosterone Undecanoate',
	'CAP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUVIR 40 (Infar)'
);

-- line #30001
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10000IU.', u'strength_2': u'3.3ML(ANTI TETANUS SERUM PURIF.)', u'substance': u'Tetanus Immunoglobulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'ANTI-TET', u'strength_3': u'', u'company': u'Vhb', u'unit': u''}

-- line #30002
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500IU.', u'strength_2': u'', u'substance': u'Tetanus Immunoglobulin', u'always_empty': u'', u'form': u'INJ', u'brand': u'BEATS', u'strength_3': u'', u'company': u'Biological E.', u'unit': u''}

-- line #30003
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Tetanus Immunoglobulin', u'always_empty': u'', u'form': u'', u'brand': u'IGANTET IU PFS', u'strength_3': u'', u'company': u'Bharat S.', u'unit': u''}

-- line #30004
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250IU.', u'strength_2': u'500IU.', u'substance': u'Tetanus Immunoglobulin', u'always_empty': u'', u'form': u'', u'brand': u'IGANTET PFS', u'strength_3': u'', u'company': u'GRIFOLS', u'unit': u''}

-- line #30005
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'TETANUS TOXOID', u'always_empty': u'', u'form': u'VACCINE', u'brand': u'BE TETANUS', u'strength_3': u'', u'company': u'Biolgical', u'unit': u''}

-- line #30006
-- ignoring line: field [strength_1] not numeric: >>>5 LF (ADSORBED ON ALUM.PHOSPHATE NOT LESS THAN 1.5<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5 LF (ADSORBED ON ALUM.PHOSPHATE NOT LESS THAN 1.5', u'strength_2': u'', u'substance': u'TETANUS TOXOID', u'always_empty': u'', u'form': u'INJ', u'brand': u'BETT', u'strength_3': u'', u'company': u'Biological E.', u'unit': u'mg)'}

-- line #30007
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REVOCON 25 (Sun)',
	'Tetrabenazine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REVOCON 25 (Sun)'
);

-- line #30008
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACHROMYCIN 250 (Wyeth)',
	'Tetracycline Hcl.',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACHROMYCIN 250 (Wyeth)'
);

-- line #30009
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICICYCLIN 250 (Indoco Rem.)',
	'Tetracycline Hcl.',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICICYCLIN 250 (Indoco Rem.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DICICYCLIN 500 (Indoco Rem.)',
	'Tetracycline Hcl.',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DICICYCLIN 500 (Indoco Rem.)'
);

-- line #30010
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HOSTACYCLINE 250 (Sanofi Aventis)',
	'Tetracycline Hcl.',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HOSTACYCLINE 250 (Sanofi Aventis)'
);

-- line #30011
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HOSTACYCLINE 500 (Sanofi Aventis)',
	'Tetracycline Hcl.',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HOSTACYCLINE 500 (Sanofi Aventis)'
);

-- line #30012
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IDILIN 250 (Idpl)',
	'Tetracycline Hcl.',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IDILIN 250 (Idpl)'
);

-- line #30013
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IDILIN 500 (Idpl)',
	'Tetracycline Hcl.',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IDILIN 500 (Idpl)'
);

-- line #30014
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INGACYCLINE 250 (Inga)',
	'Tetracycline Hcl.',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INGACYCLINE 250 (Inga)'
);

-- line #30015
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINEMETT 333 (Mercury)',
	'Tetracycline Hcl.',
	'TAB',
	gm.nullify_empty_string('333')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINEMETT 333 (Mercury)'
);

-- line #30016
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LINEMETT 500 (Mercury)',
	'Tetracycline Hcl.',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LINEMETT 500 (Mercury)'
);

-- line #30017
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUPITERRA 500 (Lupin)',
	'Tetracycline Hcl.',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUPITERRA 500 (Lupin)'
);

-- line #30018
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDOCYCLINE 250 (Medoz Ph.)',
	'Tetracycline Hcl.',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDOCYCLINE 250 (Medoz Ph.)'
);

-- line #30019
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEDOCYCLINE 500 (Medoz Ph.)',
	'Tetracycline Hcl.',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEDOCYCLINE 500 (Medoz Ph.)'
);

-- line #30020
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESTECLIN 250 (Nicholas)',
	'Tetracycline Hcl.',
	'CAP',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESTECLIN 250 (Nicholas)'
);

-- line #30021
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESTECLIN 500 (Nicholas)',
	'Tetracycline Hcl.',
	'CAP',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESTECLIN 500 (Nicholas)'
);

-- line #30022
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RESTECLIN 500 (Piramal Hc.)',
	'Tetracycline Hcl.',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RESTECLIN 500 (Piramal Hc.)'
);

-- line #30023
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONCOTHAL 100 (ONCOCARE)',
	'THALIDOMIDE',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONCOTHAL 100 (ONCOCARE)'
);

-- line #30024
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASMA 400 (Indosurge)',
	'Theophylline',
	'OD TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg(SR)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASMA 400 (Indosurge)'
);

-- line #30025
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIRYTH 300 (Emcure)',
	'Theophylline',
	'SR TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIRYTH 300 (Emcure)'
);

-- line #30026
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRONCORDIL 25 (Lifeon)',
	'Theophylline',
	'SYR',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRONCORDIL 25 (Lifeon)'
);

-- line #30027
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BRONCORDIL 200 (U S V)',
	'Theophylline',
	'XL TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BRONCORDIL 200 (U S V)'
);

-- line #30028
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DELIN 400 (Ind-Swift)',
	'Theophylline',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg(CR)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DELIN 400 (Ind-Swift)'
);

-- line #30029
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DURALYN 200 (R.B.)',
	'Theophylline',
	'CR CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg/400'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DURALYN 200 (R.B.)'
);

-- line #30030
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETOPHYLATE 125 (Walter B.)',
	'Theophylline',
	'SYR',
	gm.nullify_empty_string('125')::numeric,
	'mg/5ML(ETHANOATE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETOPHYLATE 125 (Walter B.)'
);

-- line #30031
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KLON-T 400 (Olcare)',
	'Theophylline',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg(C.R.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KLON-T 400 (Olcare)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KLON-T 600 (Olcare)',
	'Theophylline',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg(C.R.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KLON-T 600 (Olcare)'
);

-- line #30032
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LONTIF 400 (Strassenburg)',
	'Theophylline',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg(CR)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LONTIF 400 (Strassenburg)'
);

-- line #30033
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUNGFYL 200 (Yash Vision)',
	'Theophylline',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUNGFYL 200 (Yash Vision)'
);

-- line #30034
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OD-PHYLLIN 400 (Sun)',
	'Theophylline',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg(CR)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OD-PHYLLIN 400 (Sun)'
);

-- line #30035
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OD-PHYLLIN 600 (Sun)',
	'Theophylline',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg(CR)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OD-PHYLLIN 600 (Sun)'
);

-- line #30036
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHYLIN-1 400 (Obsurge)',
	'Theophylline',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHYLIN-1 400 (Obsurge)'
);

-- line #30037
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHYLOBID 200 (Wockhardt)',
	'Theophylline',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg/300'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHYLOBID 200 (Wockhardt)'
);

-- line #30038
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHYLOBID 200 (Wockhardt)',
	'Theophylline',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHYLOBID 200 (Wockhardt)'
);

-- line #30039
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHYLOBID 300 (Wockhardt)',
	'Theophylline',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHYLOBID 300 (Wockhardt)'
);

-- line #30040
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHYLODAY 400 (Wockhardt)',
	'Theophylline',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg(CR)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHYLODAY 400 (Wockhardt)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHYLODAY 600 (Wockhardt)',
	'Theophylline',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg(CR)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHYLODAY 600 (Wockhardt)'
);

-- line #30041
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHYNE-400 400 (Zee Lab)',
	'Theophylline',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg(SR)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHYNE-400 400 (Zee Lab)'
);

-- line #30042
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BERIN 100 (Gsk)',
	'Thiamine',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BERIN 100 (Gsk)'
);

-- line #30043
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BERIN 100 (Gsk)',
	'Thiamine',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BERIN 100 (Gsk)'
);

-- line #30044
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BENALGIS 75 (Franco I.)',
	'Thiamine Propyl Disulphide',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BENALGIS 75 (Franco I.)'
);

-- line #30045
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BAKFLEX 4 (Intas)',
	'THIOCOLCHICOSIDE',
	'CAP',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BAKFLEX 4 (Intas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BAKFLEX 8 (Intas)',
	'THIOCOLCHICOSIDE',
	'CAP',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BAKFLEX 8 (Intas)'
);

-- line #30046
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BAKFLEX 4 (Intas)',
	'THIOCOLCHICOSIDE',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BAKFLEX 4 (Intas)'
);

-- line #30047
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BAKFLEX 15 (Intas)',
	'THIOCOLCHICOSIDE',
	'SR',
	gm.nullify_empty_string('15')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BAKFLEX 15 (Intas)'
);

-- line #30048
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BAKWEL-4 4 (Pulse Ph.)',
	'THIOCOLCHICOSIDE',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BAKWEL-4 4 (Pulse Ph.)'
);

-- line #30049
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BAKWEL-8 8 (Pulse Ph.)',
	'THIOCOLCHICOSIDE',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BAKWEL-8 8 (Pulse Ph.)'
);

-- line #30050
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COLCHICO 4 (Medley)',
	'THIOCOLCHICOSIDE',
	'CAP',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COLCHICO 4 (Medley)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COLCHICO 8 (Medley)',
	'THIOCOLCHICOSIDE',
	'CAP',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COLCHICO 8 (Medley)'
);

-- line #30051
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COLCOSIDE 4 (Alembic)',
	'THIOCOLCHICOSIDE',
	'CAP',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COLCOSIDE 4 (Alembic)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COLCOSIDE 8 (Alembic)',
	'THIOCOLCHICOSIDE',
	'CAP',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COLCOSIDE 8 (Alembic)'
);

-- line #30052
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENDEAVOUR''S MIOFREE 4 (Lupin)',
	'THIOCOLCHICOSIDE',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENDEAVOUR''S MIOFREE 4 (Lupin)'
);

-- line #30053
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIOFREE 4 (Lupin)',
	'THIOCOLCHICOSIDE',
	'CAP',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIOFREE 4 (Lupin)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MIOFREE 8 (Lupin)',
	'THIOCOLCHICOSIDE',
	'CAP',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MIOFREE 8 (Lupin)'
);

-- line #30054
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOBIWOK 4 (Wockhardt)',
	'THIOCOLCHICOSIDE',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOBIWOK 4 (Wockhardt)'
);

-- line #30055
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOBIWOK 4 (Wockhardt)',
	'THIOCOLCHICOSIDE',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOBIWOK 4 (Wockhardt)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOBIWOK 8 (Wockhardt)',
	'THIOCOLCHICOSIDE',
	'TAB',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOBIWOK 8 (Wockhardt)'
);

-- line #30056
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYOFLEX 4 (Rpg Life)',
	'THIOCOLCHICOSIDE',
	'CAP',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYOFLEX 4 (Rpg Life)'
);

-- line #30057
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYOFLEX 8 (Rpg Life)',
	'THIOCOLCHICOSIDE',
	'CAP',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYOFLEX 8 (Rpg Life)'
);

-- line #30058
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYORIL 4 (Sanofi Aventis)',
	'THIOCOLCHICOSIDE',
	'CAP',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYORIL 4 (Sanofi Aventis)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYORIL 8 (Sanofi Aventis)',
	'THIOCOLCHICOSIDE',
	'CAP',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYORIL 8 (Sanofi Aventis)'
);

-- line #30059
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYORIL 4 (Sanofi Aventis)',
	'THIOCOLCHICOSIDE',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYORIL 4 (Sanofi Aventis)'
);

-- line #30060
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYOSIDE 4 (Torrent)',
	'THIOCOLCHICOSIDE',
	'CAP',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYOSIDE 4 (Torrent)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYOSIDE 8 (Torrent)',
	'THIOCOLCHICOSIDE',
	'CAP',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYOSIDE 8 (Torrent)'
);

-- line #30061
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEROLAX 4 (Meyer Org.)',
	'THIOCOLCHICOSIDE',
	'CAP',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEROLAX 4 (Meyer Org.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEROLAX 8 (Meyer Org.)',
	'THIOCOLCHICOSIDE',
	'CAP',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEROLAX 8 (Meyer Org.)'
);

-- line #30062
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOCRAMP 4 (STEIGEN PH.)',
	'THIOCOLCHICOSIDE',
	'CAP',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOCRAMP 4 (STEIGEN PH.)'
);

-- line #30063
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOCRAMP 8 (STEIGEN PH.)',
	'THIOCOLCHICOSIDE',
	'CAP',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOCRAMP 8 (STEIGEN PH.)'
);

-- line #30064
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELMUS 4 (Novartis)',
	'THIOCOLCHICOSIDE',
	'CAP',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELMUS 4 (Novartis)'
);

-- line #30065
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELMUS 8 (Novartis)',
	'THIOCOLCHICOSIDE',
	'CAP',
	gm.nullify_empty_string('8')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELMUS 8 (Novartis)'
);

-- line #30066
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'6-TG 40 (Vhb)',
	'Thioguanine',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '6-TG 40 (Vhb)'
);

-- line #30067
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENTASOL 500 (Jackson)',
	'THIOPENTAL SODIUM',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENTASOL 500 (Jackson)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENTASOL 1000 (Jackson)',
	'THIOPENTAL SODIUM',
	'INJ',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENTASOL 1000 (Jackson)'
);

-- line #30068
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Thiopentone', u'always_empty': u'', u'form': u'INJ', u'brand': u'ANESTHAL', u'strength_3': u'', u'company': u'Jagsonpal', u'unit': u''}

-- line #30069
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANESTHAL 500 (Jagsonpal)',
	'Thiopentone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANESTHAL 500 (Jagsonpal)'
);

-- line #30070
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Thiopentone', u'always_empty': u'', u'form': u'INJ', u'brand': u'INTRAVAL SODIUM', u'strength_3': u'', u'company': u'Nicholas', u'unit': u''}

-- line #30071
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTRAVAL SODIUM 500 (Nicholas)',
	'Thiopentone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTRAVAL SODIUM 500 (Nicholas)'
);

-- line #30072
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Thiopentone', u'always_empty': u'', u'form': u'INJ', u'brand': u'PENTONE', u'strength_3': u'', u'company': u'CH.Bhagat', u'unit': u''}

-- line #30073
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENTONE 500 (CH.Bhagat)',
	'Thiopentone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENTONE 500 (CH.Bhagat)'
);

-- line #30074
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Thiopentone', u'always_empty': u'', u'form': u'INJ', u'brand': u'PENTOSAL', u'strength_3': u'', u'company': u'Csc Ph.', u'unit': u''}

-- line #30075
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENTOSAL 500 (Csc Ph.)',
	'Thiopentone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENTOSAL 500 (Csc Ph.)'
);

-- line #30076
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Thiopentone', u'always_empty': u'', u'form': u'INJ', u'brand': u'PENTOTHAL', u'strength_3': u'', u'company': u'Pharmacia', u'unit': u''}

-- line #30077
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENTOTHAL 500 (Pharmacia)',
	'Thiopentone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENTOTHAL 500 (Pharmacia)'
);

-- line #30078
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1GM', u'strength_2': u'', u'substance': u'Thiopentone', u'always_empty': u'', u'form': u'INJ', u'brand': u'REPANTENAL', u'strength_3': u'', u'company': u'Ind-Swift', u'unit': u''}

-- line #30079
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REPANTENAL 500 (Ind-Swift)',
	'Thiopentone',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REPANTENAL 500 (Ind-Swift)'
);

-- line #30080
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELLERIL 100 (Novartis)',
	'Thioridazine Hcl.',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELLERIL 100 (Novartis)'
);

-- line #30081
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELLERIL 25 (Novartis)',
	'Thioridazine Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELLERIL 25 (Novartis)'
);

-- line #30082
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELOZINE 100 (Intas)',
	'Thioridazine Hcl.',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELOZINE 100 (Intas)'
);

-- line #30083
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELOZINE 10 (Intas)',
	'Thioridazine Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELOZINE 10 (Intas)'
);

-- line #30084
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELOZINE 25 (Intas)',
	'Thioridazine Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELOZINE 25 (Intas)'
);

-- line #30085
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MELOZINE 50 (Intas)',
	'Thioridazine Hcl.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MELOZINE 50 (Intas)'
);

-- line #30086
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIDAZIN 100 (Sun)',
	'Thioridazine Hcl.',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIDAZIN 100 (Sun)'
);

-- line #30087
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIDAZIN 10 (Sun)',
	'Thioridazine Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIDAZIN 10 (Sun)'
);

-- line #30088
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIDAZIN 25 (Sun)',
	'Thioridazine Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIDAZIN 25 (Sun)'
);

-- line #30089
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIDAZIN 50 (Sun)',
	'Thioridazine Hcl.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIDAZIN 50 (Sun)'
);

-- line #30090
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000MCG', u'strength_2': u'', u'substance': u'Thyroxine', u'always_empty': u'', u'form': u'TAB', u'brand': u'EL-THYRO', u'strength_3': u'', u'company': u'INNOVA LIFESCI.', u'unit': u''}

-- line #30091
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'25MCG', u'strength_2': u'', u'substance': u'Thyroxine', u'always_empty': u'', u'form': u'TAB', u'brand': u'EL-THYRO', u'strength_3': u'', u'company': u'INNOVA LIFESCI.', u'unit': u''}

-- line #30092
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50MCG', u'strength_2': u'', u'substance': u'Thyroxine', u'always_empty': u'', u'form': u'TAB', u'brand': u'EL-THYRO', u'strength_3': u'', u'company': u'INNOVA LIFESCI.', u'unit': u''}

-- line #30093
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'25MCG', u'strength_2': u'', u'substance': u'Thyroxine', u'always_empty': u'', u'form': u'TAB', u'brand': u'ELTROXIN MCG', u'strength_3': u'', u'company': u'Gsk', u'unit': u''}

-- line #30094
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100MCG', u'strength_2': u'', u'substance': u'Thyroxine', u'always_empty': u'', u'form': u'TAB', u'brand': u'ELTROXIN', u'strength_3': u'', u'company': u'Gsk', u'unit': u''}

-- line #30095
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50MCG', u'strength_2': u'', u'substance': u'Thyroxine', u'always_empty': u'', u'form': u'TAB', u'brand': u'ELTROXIN', u'strength_3': u'', u'company': u'Gsk', u'unit': u''}

-- line #30096
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100MCG', u'strength_2': u'', u'substance': u'Thyroxine', u'always_empty': u'', u'form': u'TAB', u'brand': u'LETHYROX', u'strength_3': u'', u'company': u'Intas', u'unit': u''}

-- line #30097
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'25MCG', u'strength_2': u'', u'substance': u'Thyroxine', u'always_empty': u'', u'form': u'TAB', u'brand': u'LETHYROX', u'strength_3': u'', u'company': u'Intas', u'unit': u''}

-- line #30098
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50MCG', u'strength_2': u'', u'substance': u'Thyroxine', u'always_empty': u'', u'form': u'TAB', u'brand': u'LETHYROX', u'strength_3': u'', u'company': u'Intas', u'unit': u''}

-- line #30099
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75MCG', u'strength_2': u'', u'substance': u'Thyroxine', u'always_empty': u'', u'form': u'TAB', u'brand': u'LETHYROX', u'strength_3': u'', u'company': u'Intas', u'unit': u''}

-- line #30100
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'88MCG', u'strength_2': u'', u'substance': u'Thyroxine', u'always_empty': u'', u'form': u'TAB', u'brand': u'LETHYROX', u'strength_3': u'', u'company': u'Intas', u'unit': u''}

-- line #30101
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIVIAL 2.5 (Infar)',
	'Tibolone',
	'TAB',
	gm.nullify_empty_string('2.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIVIAL 2.5 (Infar)'
);

-- line #30102
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'APLAKET 250 (Elder)',
	'Ticlopidine Hcl.',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'APLAKET 250 (Elder)'
);

-- line #30103
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLOTHIN 250 (Indi Ph.)',
	'Ticlopidine Hcl.',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLOTHIN 250 (Indi Ph.)'
);

-- line #30104
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RCIFAX 400 (Lupin)',
	'TIFAXIMIN',
	'TAB',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RCIFAX 400 (Lupin)'
);

-- line #30105
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVERCIL 50 (UNIMARCK)',
	'TIGECYCLINE',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVERCIL 50 (UNIMARCK)'
);

-- line #30106
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50', u'strength_2': u'', u'substance': u'TIGECYCLINE', u'always_empty': u'', u'form': u'', u'brand': u'INNOCYCLINE', u'strength_3': u'', u'company': u'INNOVA LIFESCI.', u'unit': u'mg'}

-- line #30107
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOTIM 0.5 (Bio-Tech Opth.)',
	'Timolol Maleate',
	'EYE DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOTIM 0.5 (Bio-Tech Opth.)'
);

-- line #30108
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EYMOL 0.5 (Solitaire)',
	'Timolol Maleate',
	'EYE DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EYMOL 0.5 (Solitaire)'
);

-- line #30109
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLOCOMOL 0.25 (Allergan)',
	'Timolol Maleate',
	'EYE DPS',
	gm.nullify_empty_string('0.25')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLOCOMOL 0.25 (Allergan)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLOCOMOL 0.5 (Allergan)',
	'Timolol Maleate',
	'EYE DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLOCOMOL 0.5 (Allergan)'
);

-- line #30110
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUCOMOL 0.25 (Allergan)',
	'Timolol Maleate',
	'EYE DPS',
	gm.nullify_empty_string('0.25')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUCOMOL 0.25 (Allergan)'
);

-- line #30111
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUCOMOL 0.5 (Allergan)',
	'Timolol Maleate',
	'EYE DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUCOMOL 0.5 (Allergan)'
);

-- line #30112
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUCOMOL 0.5 (Allergan)',
	'Timolol Maleate',
	'OD EYE DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUCOMOL 0.5 (Allergan)'
);

-- line #30113
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUCONIL 0.5 (Ophthal R.)',
	'Timolol Maleate',
	'EYE DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUCONIL 0.5 (Ophthal R.)'
);

-- line #30114
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUCOTIM 0.25 (Centaur)',
	'Timolol Maleate',
	'EYE DPS',
	gm.nullify_empty_string('0.25')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUCOTIM 0.25 (Centaur)'
);

-- line #30115
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUCOTIM 0.5 (Centaur)',
	'Timolol Maleate',
	'EYE DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUCOTIM 0.5 (Centaur)'
);

-- line #30116
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUNIL 0.5 (Oscar Rem.)',
	'Timolol Maleate',
	'DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUNIL 0.5 (Oscar Rem.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUNIL 0.25 (Oscar Rem.)',
	'Timolol Maleate',
	'DPS',
	gm.nullify_empty_string('0.25')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUNIL 0.25 (Oscar Rem.)'
);

-- line #30117
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GUNIL OPHTH 0.25 (Oscar Rem.)',
	'Timolol Maleate',
	'SOL',
	gm.nullify_empty_string('0.25')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GUNIL OPHTH 0.25 (Oscar Rem.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GUNIL OPHTH 0.5 (Oscar Rem.)',
	'Timolol Maleate',
	'SOL',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GUNIL OPHTH 0.5 (Oscar Rem.)'
);

-- line #30118
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IOTIM 0.25 (F D C)',
	'Timolol Maleate',
	'DPS',
	gm.nullify_empty_string('0.25')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IOTIM 0.25 (F D C)'
);

-- line #30119
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IOTIM 0.5 (F D C)',
	'Timolol Maleate',
	'DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IOTIM 0.5 (F D C)'
);

-- line #30120
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,5', u'strength_2': u'', u'substance': u'Timolol Maleate', u'always_empty': u'', u'form': u'', u'brand': u'IOTIM UNIMS', u'strength_3': u'', u'company': u'F D C', u'unit': u'%'}

-- line #30121
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOPRES 0.25 (Micro V.)',
	'Timolol Maleate',
	'EYE DPS',
	gm.nullify_empty_string('0.25')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOPRES 0.25 (Micro V.)'
);

-- line #30122
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOPRES 0.5 (Micro V.)',
	'Timolol Maleate',
	'EYE DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOPRES 0.5 (Micro V.)'
);

-- line #30123
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NYOLOL 0.5 (Novartis)',
	'Timolol Maleate',
	'DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NYOLOL 0.5 (Novartis)'
);

-- line #30124
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCLEAN 0.25 (Cosme Hc.)',
	'Timolol Maleate',
	'EYE DPS',
	gm.nullify_empty_string('0.25')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCLEAN 0.25 (Cosme Hc.)'
);

-- line #30125
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCLEAN 0.5 (Cosme Hc.)',
	'Timolol Maleate',
	'EYE DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCLEAN 0.5 (Cosme Hc.)'
);

-- line #30126
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCOBAR 0.25 (P C INDIA)',
	'Timolol Maleate',
	'DPS',
	gm.nullify_empty_string('0.25')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCOBAR 0.25 (P C INDIA)'
);

-- line #30127
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCOBAR 0.5 (P C INDIA)',
	'Timolol Maleate',
	'DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCOBAR 0.5 (P C INDIA)'
);

-- line #30128
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCULAN 0.25 (Bal Ph.)',
	'Timolol Maleate',
	'DPS',
	gm.nullify_empty_string('0.25')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCULAN 0.25 (Bal Ph.)'
);

-- line #30129
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCULAN 0.5 (Bal Ph.)',
	'Timolol Maleate',
	'DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCULAN 0.5 (Bal Ph.)'
);

-- line #30130
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCUPRES 0.5 (Cadila Ph.)',
	'Timolol Maleate',
	'GEL',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCUPRES 0.5 (Cadila Ph.)'
);

-- line #30131
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCUPRES 2.5 (Le Sante)',
	'Timolol Maleate',
	'SOL',
	gm.nullify_empty_string('2.5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCUPRES 2.5 (Le Sante)'
);

-- line #30132
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCUPRES 5 (Le Sante)',
	'Timolol Maleate',
	'SOL',
	gm.nullify_empty_string('5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCUPRES 5 (Le Sante)'
);

-- line #30133
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCUTIM 0.25 (Sante V.)',
	'Timolol Maleate',
	'EYE DPS',
	gm.nullify_empty_string('0.25')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCUTIM 0.25 (Sante V.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCUTIM 0.5 (Sante V.)',
	'Timolol Maleate',
	'EYE DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCUTIM 0.5 (Sante V.)'
);

-- line #30134
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPTILAX 0.5 (Zuventus)',
	'TIMOLOL',
	'EYE DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPTILAX 0.5 (Zuventus)'
);

-- line #30135
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMEBAMAGMA 300 (Wyeth)',
	'Tinidazole',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMEBAMAGMA 300 (Wyeth)'
);

-- line #30136
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMIS 500 (Depone)',
	'Tinidazole',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMIS 500 (Depone)'
);

-- line #30137
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Tinidazole', u'always_empty': u'', u'form': u'TAB', u'brand': u'ANABAC', u'strength_3': u'', u'company': u'Camlin', u'unit': u''}

-- line #30138
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAMITOL 300 (Camlin)',
	'Tinidazole',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAMITOL 300 (Camlin)'
);

-- line #30139
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAMITOL 500 (Camlin)',
	'Tinidazole',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAMITOL 500 (Camlin)'
);

-- line #30140
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Tinidazole', u'always_empty': u'', u'form': u'TAB', u'brand': u'COSTINI', u'strength_3': u'', u'company': u'Cfl Ph.', u'unit': u''}

-- line #30141
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COSTINI 500 (Cfl Ph.)',
	'Tinidazole',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COSTINI 500 (Cfl Ph.)'
);

-- line #30142
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COZIT 500 (Emcure)',
	'Tinidazole',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COZIT 500 (Emcure)'
);

-- line #30143
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DATISOLE 500 (Ajanta Ph.)',
	'TINIDAZOLE',
	'SR TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DATISOLE 500 (Ajanta Ph.)'
);

-- line #30144
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Tinidazole', u'always_empty': u'', u'form': u'TAB', u'brand': u'ENIDAZOL', u'strength_3': u'', u'company': u'East India', u'unit': u''}

-- line #30145
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENIDAZOL 300 (East India)',
	'Tinidazole',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENIDAZOL 300 (East India)'
);

-- line #30146
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENIDAZOL 500 (East India)',
	'Tinidazole',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENIDAZOL 500 (East India)'
);

-- line #30147
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Tinidazole', u'always_empty': u'', u'form': u'DT TAB', u'brand': u'FASIGYN', u'strength_3': u'', u'company': u'Pfizer', u'unit': u''}

-- line #30148
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FASIGYN 500 (Pfizer)',
	'Tinidazole',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FASIGYN 500 (Pfizer)'
);

-- line #30149
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Tinidazole', u'always_empty': u'', u'form': u'DS TAB', u'brand': u'MOBITIDE', u'strength_3': u'', u'company': u'Jenburkt', u'unit': u''}

-- line #30150
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOBITIDE 500 (Jenburkt)',
	'Tinidazole',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOBITIDE 500 (Jenburkt)'
);

-- line #30151
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1G', u'strength_2': u'', u'substance': u'Tinidazole', u'always_empty': u'', u'form': u'TAB', u'brand': u'MOOBITIDE', u'strength_3': u'', u'company': u'Jenburkt', u'unit': u''}

-- line #30152
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMMUMAX 500 (Nicholas)',
	'Tinocordin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMMUMAX 500 (Nicholas)'
);

-- line #30153
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'NA', u'strength_2': u'', u'substance': u'Tinocordin', u'always_empty': u'', u'form': u'SYR', u'brand': u'IMMUMOD', u'strength_3': u'', u'company': u'Merind', u'unit': u''}

-- line #30154
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMMUMOD 100 (Merind)',
	'Tinocordin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMMUMOD 100 (Merind)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IMMUMOD 500 (Merind)',
	'Tinocordin',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IMMUMOD 500 (Merind)'
);

-- line #30155
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'18MCG', u'strength_2': u'', u'substance': u'TIOTROPIUM BROMIDE', u'always_empty': u'', u'form': u'CAP', u'brand': u'AEROTROP', u'strength_3': u'', u'company': u'Macleods', u'unit': u''}

-- line #30156
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'9MCG', u'strength_2': u'', u'substance': u'TIOTROPIUM BROMIDE', u'always_empty': u'', u'form': u'', u'brand': u'AEROTROP INHALATION', u'strength_3': u'', u'company': u'Macleods', u'unit': u''}

-- line #30157
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AGGRAMED 5 (Zydus Cadila)',
	'TIROFIBAN',
	'INF',
	gm.nullify_empty_string('5')::numeric,
	'mg/100ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AGGRAMED 5 (Zydus Cadila)'
);

-- line #30158
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AGGRASTAT 0.25 (MSD)',
	'TIROFIBAN',
	'INJ',
	gm.nullify_empty_string('0.25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AGGRASTAT 0.25 (MSD)'
);

-- line #30159
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AGGRIBLOC 5 (Piramal Hc.)',
	'TIROFIBAN',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg/100ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AGGRIBLOC 5 (Piramal Hc.)'
);

-- line #30160
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'5', u'strength_2': u'', u'substance': u'TIROFIBAN', u'always_empty': u'', u'form': u'', u'brand': u'AGGRILEK', u'strength_3': u'', u'company': u'J. B. Chem.', u'unit': u'mg/100ML'}

-- line #30161
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AGGRITOR 5 (TORRENT)',
	'TIROFIBAN',
	'VIAL',
	gm.nullify_empty_string('5')::numeric,
	'mg/100ML(+SOD. CHL. 0.9'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AGGRITOR 5 (TORRENT)'
);

-- line #30162
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AGRABAN 5 (Emcure)',
	'TIROFIBAN',
	'INF',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AGRABAN 5 (Emcure)'
);

-- line #30163
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIBROBAN 5 (Cadila Ph.)',
	'TIROFIBAN',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg (+SOD.CHL. 0.9'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIBROBAN 5 (Cadila Ph.)'
);

-- line #30164
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GP-2 5 (Gland Ph.)',
	'TIROFIBAN',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg(+NACL 0.9'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GP-2 5 (Gland Ph.)'
);

-- line #30165
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GP MAX 5 (U S V)',
	'TIROFIBAN',
	'INJ',
	gm.nullify_empty_string('5')::numeric,
	'mg/100ML(+SOD. CHL. 0.9'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GP MAX 5 (U S V)'
);

-- line #30166
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTILYSE 20 (German R.)',
	'Tissue Type Plasminogen Activator',
	'VIAL',
	gm.nullify_empty_string('20')::numeric,
	'50'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTILYSE 20 (German R.)'
);

-- line #30167
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'8,4', u'strength_2': u'', u'substance': u'TITANIUM DIOXIDE', u'always_empty': u'', u'form': u'', u'brand': u'LUMIXYL MOISTURE LOCK SPF', u'strength_3': u'', u'company': u'THEMIS MEDICARE', u'unit': u'%'}

-- line #30168
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACTOB 0.3 (Radix Bio.)',
	'Tobramycin',
	'E/E DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACTOB 0.3 (Radix Bio.)'
);

-- line #30169
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BACTOB 80 (Radix Bio.)',
	'Tobramycin',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BACTOB 80 (Radix Bio.)'
);

-- line #30170
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CINOTEB 0.3 (Biocin Hc.)',
	'Tobramycin',
	'EYE DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CINOTEB 0.3 (Biocin Hc.)'
);

-- line #30171
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CINTOB 0.3 (Biocin Hc.)',
	'Tobramycin',
	'EYE DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CINTOB 0.3 (Biocin Hc.)'
);

-- line #30172
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORAL 0.3 (Shinto Org.)',
	'Tobramycin',
	'EYE DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORAL 0.3 (Shinto Org.)'
);

-- line #30173
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORAL 80 (Shinto Org.)',
	'Tobramycin',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORAL 80 (Shinto Org.)'
);

-- line #30174
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELTOL 80 (Elfin Ph.)',
	'Tobramycin',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELTOL 80 (Elfin Ph.)'
);

-- line #30175
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EYTOB 0.3 (Solitaire)',
	'Tobramycin',
	'E/E DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EYTOB 0.3 (Solitaire)'
);

-- line #30176
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Tobramycin', u'always_empty': u'', u'form': u'EYE DPS', u'brand': u'EYTOB', u'strength_3': u'', u'company': u'Eg Ph.', u'unit': u''}

-- line #30177
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Tobramycin', u'always_empty': u'', u'form': u'DPS', u'brand': u'FINTOB', u'strength_3': u'', u'company': u'Finesse Ph.', u'unit': u''}

-- line #30178
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FYTOBRA 80 (Sanify)',
	'Tobramycin',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FYTOBRA 80 (Sanify)'
);

-- line #30179
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Tobramycin', u'always_empty': u'', u'form': u'EYE DPS', u'brand': u'GLYTOB', u'strength_3': u'', u'company': u'Globus', u'unit': u''}

-- line #30180
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'IBREX 0.3 (Cadila Ph.)',
	'Tobramycin',
	'EYE DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'IBREX 0.3 (Cadila Ph.)'
);

-- line #30181
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEBRACIN 0.3 (Sunways)',
	'Tobramycin',
	'EYE DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEBRACIN 0.3 (Sunways)'
);

-- line #30182
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEBRACIN 0.3 (Sunways)',
	'Tobramycin',
	'EYE OINT',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEBRACIN 0.3 (Sunways)'
);

-- line #30183
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OBRIN 0.3 (SENSES)',
	'Tobramycin',
	'EYE DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OBRIN 0.3 (SENSES)'
);

-- line #30184
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OCUTOB 0.3 (Centaur)',
	'Tobramycin',
	'EYE DPS',
	gm.nullify_empty_string('0.3')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OCUTOB 0.3 (Centaur)'
);

-- line #30185
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROMYCIN 20 (Prohealth)',
	'Tobramycin',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROMYCIN 20 (Prohealth)'
);

-- line #30186
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROMYCIN 60 (Prohealth)',
	'Tobramycin',
	'INJ',
	gm.nullify_empty_string('60')::numeric,
	'mg/2.5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROMYCIN 60 (Prohealth)'
);

-- line #30187
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROMYCIN 80 (Prohealth)',
	'Tobramycin',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROMYCIN 80 (Prohealth)'
);

-- line #30188
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PULCIN 80 (Intracin)',
	'Tobramycin',
	'INJ',
	gm.nullify_empty_string('80')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PULCIN 80 (Intracin)'
);

-- line #30189
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Tobramycin', u'always_empty': u'', u'form': u'EYE DPS', u'brand': u'REBREX', u'strength_3': u'', u'company': u'RENOVA HC.', u'unit': u''}

-- line #30190
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Tobramycin', u'always_empty': u'', u'form': u'EYE OINT', u'brand': u'REBREX', u'strength_3': u'', u'company': u'RENOVA HC.', u'unit': u''}

-- line #30191
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RASTINONE 500 (Sanofi Aventis)',
	'Tolbutamide',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RASTINONE 500 (Sanofi Aventis)'
);

-- line #30192
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOTAN 200 (Elder)',
	'Tolfenamic Acid',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOTAN 200 (Elder)'
);

-- line #30193
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYO 150 (GRANDIX)',
	'TOLPERISONE',
	'MR TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYO 150 (GRANDIX)'
);

-- line #30194
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYOTOP 450 (Zuventus)',
	'TOLPERISONE',
	'SR',
	gm.nullify_empty_string('450')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYOTOP 450 (Zuventus)'
);

-- line #30195
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'150', u'strength_2': u'', u'substance': u'TOLPERISONE', u'always_empty': u'', u'form': u'', u'brand': u'MYOTOP', u'strength_3': u'', u'company': u'Zuventus', u'unit': u'mg'}

-- line #30196
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Tolterodine Tart.', u'always_empty': u'', u'form': u'TAB', u'brand': u'DETRUSITOL', u'strength_3': u'', u'company': u'Pharmacia', u'unit': u''}

-- line #30197
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEZROLALA 1 (TAJ PH.)',
	'Tolterodine Tart.',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEZROLALA 1 (TAJ PH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEZROLALA 2 (TAJ PH.)',
	'Tolterodine Tart.',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEZROLALA 2 (TAJ PH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEZROLALA 4 (TAJ PH.)',
	'Tolterodine Tart.',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEZROLALA 4 (TAJ PH.)'
);

-- line #30198
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEZROLALA 2 (TAJ PH.)',
	'Tolterodine Tart.',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEZROLALA 2 (TAJ PH.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEZROLALA 4 (TAJ PH.)',
	'Tolterodine Tart.',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEZROLALA 4 (TAJ PH.)'
);

-- line #30199
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOCHEK 2 (Alkem)',
	'Tolterodine Tart.',
	'CAP',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOCHEK 2 (Alkem)'
);

-- line #30200
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOCHEK 4 (Alkem)',
	'Tolterodine Tart.',
	'CAP',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOCHEK 4 (Alkem)'
);

-- line #30201
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPIMATE 100 (PSYCOREM)',
	'Topiramate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPIMATE 100 (PSYCOREM)'
);

-- line #30202
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPIMATE 25 (PSYCOREM)',
	'Topiramate',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'50'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPIMATE 25 (PSYCOREM)'
);

-- line #30203
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPITOME 25 (Triton Hc.)',
	'Topiramate',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'50'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPITOME 25 (Triton Hc.)'
);

-- line #30204
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPITOP 100 (Synchro)',
	'Topiramate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPITOP 100 (Synchro)'
);

-- line #30205
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPITOP 25 (Synchro)',
	'Topiramate',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPITOP 25 (Synchro)'
);

-- line #30206
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPITOP 50 (Synchro)',
	'Topiramate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPITOP 50 (Synchro)'
);

-- line #30207
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEXTOP 100 (Torrent)',
	'Topiramate',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEXTOP 100 (Torrent)'
);

-- line #30208
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEXTOP 25 (Torrent)',
	'Topiramate',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEXTOP 25 (Torrent)'
);

-- line #30209
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEXTOP 50 (Torrent)',
	'Topiramate',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEXTOP 50 (Torrent)'
);

-- line #30210
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUTOP 25 (STRIVE PH.)',
	'Topiramate',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUTOP 25 (STRIVE PH.)'
);

-- line #30211
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEMATOR 10 (Rpg Life)',
	'TORASEMIDE',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEMATOR 10 (Rpg Life)'
);

-- line #30212
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEMATOR 100 (Rpg Life)',
	'TORASEMIDE',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEMATOR 100 (Rpg Life)'
);

-- line #30213
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIURATOR 10 (Elder)',
	'TORASEMIDE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIURATOR 10 (Elder)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIURATOR 20 (Elder)',
	'TORASEMIDE',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIURATOR 20 (Elder)'
);

-- line #30214
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYLOOP 100 (SINSAN PH.)',
	'TORASEMIDE',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYLOOP 100 (SINSAN PH.)'
);

-- line #30215
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYLOOP 10 (SINSAN PH.)',
	'TORASEMIDE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYLOOP 10 (SINSAN PH.)'
);

-- line #30216
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYLOOP 20 (SINSAN PH.)',
	'TORASEMIDE',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYLOOP 20 (SINSAN PH.)'
);

-- line #30217
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYTOR 100 (Cipla)',
	'TORASEMIDE',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYTOR 100 (Cipla)'
);

-- line #30218
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYTOR 100 (Cipla)',
	'TORASEMIDE',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYTOR 100 (Cipla)'
);

-- line #30219
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYTOR 10 (Cipla)',
	'TORASEMIDE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYTOR 10 (Cipla)'
);

-- line #30220
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYTOR 20 (Cipla)',
	'TORASEMIDE',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYTOR 20 (Cipla)'
);

-- line #30221
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYTOR 40 (Cipla)',
	'TORASEMIDE',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYTOR 40 (Cipla)'
);

-- line #30222
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYTOR 5 (Cipla)',
	'TORASEMIDE',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYTOR 5 (Cipla)'
);

-- line #30223
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EDETO 100 (Dr.Reddy''S)',
	'TORASEMIDE',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EDETO 100 (Dr.Reddy''S)'
);

-- line #30224
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EDETO 10 (Dr.Reddy''S)',
	'TORASEMIDE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EDETO 10 (Dr.Reddy''S)'
);

-- line #30225
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EDETO 20 (Dr.Reddy''S)',
	'TORASEMIDE',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EDETO 20 (Dr.Reddy''S)'
);

-- line #30226
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOFRE 10 (Emcure)',
	'TORASEMIDE',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOFRE 10 (Emcure)'
);

-- line #30227
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOFRE 10 (Emcure)',
	'TORASEMIDE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOFRE 10 (Emcure)'
);

-- line #30228
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOFRE 20 (Emcure)',
	'TORASEMIDE',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOFRE 20 (Emcure)'
);

-- line #30229
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'TORASEMIDE', u'always_empty': u'', u'form': u'INJ', u'brand': u'RETORLIX', u'strength_3': u'', u'company': u'Lupin', u'unit': u''}

-- line #30230
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RETORLIX 20 (Lupin)',
	'TORASEMIDE',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RETORLIX 20 (Lupin)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RETORLIX 100 (Lupin)',
	'TORASEMIDE',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RETORLIX 100 (Lupin)'
);

-- line #30231
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RETORLIX 5 (Lupin)',
	'TORASEMIDE',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RETORLIX 5 (Lupin)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RETORLIX 10 (Lupin)',
	'TORASEMIDE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RETORLIX 10 (Lupin)'
);

-- line #30232
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEMATOR 10 (Rpg Life)',
	'TORSEMIDE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEMATOR 10 (Rpg Life)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEMATOR 20 (Rpg Life)',
	'TORSEMIDE',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEMATOR 20 (Rpg Life)'
);

-- line #30233
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYAMIDE 20 (Macleods)',
	'TORSEMIDE',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYAMIDE 20 (Macleods)'
);

-- line #30234
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYAMIDE 5 (Macleods)',
	'TORSEMIDE',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYAMIDE 5 (Macleods)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYAMIDE 10 (Macleods)',
	'TORSEMIDE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYAMIDE 10 (Macleods)'
);

-- line #30235
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LHD-10 10 (Ipca)',
	'TORSEMIDE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LHD-10 10 (Ipca)'
);

-- line #30236
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LHD-20 20 (Ipca)',
	'TORSEMIDE',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LHD-20 20 (Ipca)'
);

-- line #30237
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LHD-40 40 (Ipca)',
	'TORSEMIDE',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LHD-40 40 (Ipca)'
);

-- line #30238
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LHD-5 5 (Ipca)',
	'TORSEMIDE',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LHD-5 5 (Ipca)'
);

-- line #30239
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACUGESIC 50 (B.M.Ph.)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACUGESIC 50 (B.M.Ph.)'
);

-- line #30240
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACUPAIN 50 (Eden Hc.)',
	'Tramadol Hcl.',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACUPAIN 50 (Eden Hc.)'
);

-- line #30241
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACUPAIN 50 (Eden Hc.)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACUPAIN 50 (Eden Hc.)'
);

-- line #30242
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADAMON 50 (German R.)',
	'Tramadol Hcl.',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADAMON 50 (German R.)'
);

-- line #30243
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADAMON 100 (German R.)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/2 ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADAMON 100 (German R.)'
);

-- line #30244
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADAMON 50 (German R.)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADAMON 50 (German R.)'
);

-- line #30245
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADAMON 100 (German R.)',
	'Tramadol Hcl.',
	'SUSCAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADAMON 100 (German R.)'
);

-- line #30246
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADMADOL 50 (Admac Ph.)',
	'Tramadol Hcl.',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADMADOL 50 (Admac Ph.)'
);

-- line #30247
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADMADOL 100 (Admac Ph.)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADMADOL 100 (Admac Ph.)'
);

-- line #30248
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMDOL 50 (Curex)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMDOL 50 (Curex)'
);

-- line #30249
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARISTO ULTRAMOL 100 (Aristo)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARISTO ULTRAMOL 100 (Aristo)'
);

-- line #30250
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARISTO ULTRAMOL 50 (Aristo)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARISTO ULTRAMOL 50 (Aristo)'
);

-- line #30251
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATDOL 50 (Atoz Ph.)',
	'Tramadol Hcl.',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATDOL 50 (Atoz Ph.)'
);

-- line #30252
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATDOL 100 (Atoz Ph.)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATDOL 100 (Atoz Ph.)'
);

-- line #30253
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Tramadol Hcl.', u'always_empty': u'', u'form': u'INJ', u'brand': u'AXYTRAM', u'strength_3': u'', u'company': u'AXYZEN LIFE', u'unit': u''}

-- line #30254
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AXYTRAM 50 (AXYZEN LIFE)',
	'Tramadol Hcl.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AXYTRAM 50 (AXYZEN LIFE)'
);

-- line #30255
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BESTODOL 100 (Bestochem)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BESTODOL 100 (Bestochem)'
);

-- line #30256
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BESTODOL 50 (Bestochem)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/1ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BESTODOL 50 (Bestochem)'
);

-- line #30257
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BOLODOL 50 (Ultramark)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BOLODOL 50 (Ultramark)'
);

-- line #30258
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEMADOL 100 (Life Med.)',
	'Tramadol Hcl.',
	'CR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEMADOL 100 (Life Med.)'
);

-- line #30259
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEMADOL 50 (Life Med.)',
	'Tramadol Hcl.',
	'CR TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEMADOL 50 (Life Med.)'
);

-- line #30260
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CEMADOL 50 (Life Med.)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CEMADOL 50 (Life Med.)'
);

-- line #30261
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CENTRADOL (2) 50 (TABLETS I.)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CENTRADOL (2) 50 (TABLETS I.)'
);

-- line #30262
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CENTRADOL 50 (TABLETS I.)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CENTRADOL 50 (TABLETS I.)'
);

-- line #30263
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CENTRA 50 (MEDIMARK)',
	'Tramadol Hcl.',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CENTRA 50 (MEDIMARK)'
);

-- line #30264
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CENTRA 50 (MEDIMARK)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CENTRA 50 (MEDIMARK)'
);

-- line #30265
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONTRADAC 50 (Biocin Hc.)',
	'Tramadol Hcl.',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONTRADAC 50 (Biocin Hc.)'
);

-- line #30266
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONTRADAC 50 (Biocin Hc.)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONTRADAC 50 (Biocin Hc.)'
);

-- line #30267
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONTRADAC 50 (Biocin Hc.)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONTRADAC 50 (Biocin Hc.)'
);

-- line #30268
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONTRAMAL 50 (Nicholas)',
	'Tramadol Hcl.',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONTRAMAL 50 (Nicholas)'
);

-- line #30269
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONTRAMAL 50 (Nicholas)',
	'Tramadol Hcl.',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONTRAMAL 50 (Nicholas)'
);

-- line #30270
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONTRAMAL 50 (Nicholas)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONTRAMAL 50 (Nicholas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONTRAMAL 100 (Nicholas)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONTRAMAL 100 (Nicholas)'
);

-- line #30271
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CONTRAMAL 100 (Nicholas)',
	'Tramadol Hcl.',
	'SR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CONTRAMAL 100 (Nicholas)'
);

-- line #30272
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYPREMAL 50 (STAUNCH)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYPREMAL 50 (STAUNCH)'
);

-- line #30273
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Tramadol Hcl.', u'always_empty': u'', u'form': u'INJ', u'brand': u'CYPREMAL', u'strength_3': u'', u'company': u'STAUNCH', u'unit': u''}

-- line #30274
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DAMED 50 (Ronak Lab.)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DAMED 50 (Ronak Lab.)'
);

-- line #30275
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVIDOL 50 (DIVINE LAB.)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVIDOL 50 (DIVINE LAB.)'
);

-- line #30276
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIVIFEN 25 (DIVINE LAB.)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('25')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIVIFEN 25 (DIVINE LAB.)'
);

-- line #30277
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLCIN 50 (Intracin)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLCIN 50 (Intracin)'
);

-- line #30278
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLFI 50 (Pfiscar Ind.)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLFI 50 (Pfiscar Ind.)'
);

-- line #30279
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOL 50 (P C INDIA)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOL 50 (P C INDIA)'
);

-- line #30280
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLOMED-T 50 (Comed)',
	'Tramadol Hcl.',
	'AMP',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLOMED-T 50 (Comed)'
);

-- line #30281
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLOMED-T 100 (Comed)',
	'Tramadol Hcl.',
	'SR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLOMED-T 100 (Comed)'
);

-- line #30282
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLOMED-T 50 (Comed)',
	'Tramadol Hcl.',
	'SR TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLOMED-T 50 (Comed)'
);

-- line #30283
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLOSPAN 100 (Emcure)',
	'Tramadol Hcl.',
	'SR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLOSPAN 100 (Emcure)'
);

-- line #30284
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLOTRAM 50 (Sun)',
	'Tramadol Hcl.',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLOTRAM 50 (Sun)'
);

-- line #30285
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLOTRAM 50 (Sun)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLOTRAM 50 (Sun)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLOTRAM 100 (Sun)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLOTRAM 100 (Sun)'
);

-- line #30286
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOL-P 50 (Ravian)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOL-P 50 (Ravian)'
);

-- line #30287
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLS 100 (SHRESHTHA)',
	'Tramadol Hcl.',
	'AMP',
	gm.nullify_empty_string('100')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLS 100 (SHRESHTHA)'
);

-- line #30288
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLWIN 50 (Phytochem)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLWIN 50 (Phytochem)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOLWIN 100 (Phytochem)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOLWIN 100 (Phytochem)'
);

-- line #30289
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMADOL 50 (Unichem)',
	'Tramadol Hcl.',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMADOL 50 (Unichem)'
);

-- line #30290
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMADOL 50 (Unichem)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMADOL 50 (Unichem)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMADOL 100 (Unichem)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMADOL 100 (Unichem)'
);

-- line #30291
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DOMADOL 100 (Unichem)',
	'Tramadol Hcl.',
	'SR CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DOMADOL 100 (Unichem)'
);

-- line #30292
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'E-DOL 100 (Elfin Ph.)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'E-DOL 100 (Elfin Ph.)'
);

-- line #30293
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELTRAM 100 (Captab)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELTRAM 100 (Captab)'
);

-- line #30294
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORMADOR 100 (Forgo Ph.)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORMADOR 100 (Forgo Ph.)'
);

-- line #30295
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FS 100 (Biomax Bio.)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FS 100 (Biomax Bio.)'
);

-- line #30296
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HALDOTRAM 50 (Hallmark)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HALDOTRAM 50 (Hallmark)'
);

-- line #30297
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEXTRADOL 100 (SANOFI AV.)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEXTRADOL 100 (SANOFI AV.)'
);

-- line #30298
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYPNOTEX 50 (P C INDIA)',
	'Tramadol Hcl.',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYPNOTEX 50 (P C INDIA)'
);

-- line #30299
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KAMADOL 100 (Kapl)',
	'Tramadol Hcl.',
	'AMP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KAMADOL 100 (Kapl)'
);

-- line #30300
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KAMADOL 50 (Kapl)',
	'Tramadol Hcl.',
	'AMP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KAMADOL 50 (Kapl)'
);

-- line #30301
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KAMADOL 100 (Kapl)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KAMADOL 100 (Kapl)'
);

-- line #30302
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUCITRAM 50 (LUCIFER & H.)',
	'Tramadol Hcl.',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUCITRAM 50 (LUCIFER & H.)'
);

-- line #30303
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'M-DOL 50 (Mercury Hc.)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'M-DOL 50 (Mercury Hc.)'
);

-- line #30304
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'M-DOL 50 (Oscar Rem.)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'M-DOL 50 (Oscar Rem.)'
);

-- line #30305
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'M-DOL 50 (Mercury Hc.)',
	'Tramadol Hcl.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'M-DOL 50 (Mercury Hc.)'
);

-- line #30306
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MERIDOL 50 (Unimarck)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MERIDOL 50 (Unimarck)'
);

-- line #30307
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MUSTRA 50 (Merit Org.)',
	'Tramadol Hcl.',
	'DT',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MUSTRA 50 (Merit Org.)'
);

-- line #30308
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEUTRAM 50 (EAST WEST)',
	'Tramadol Hcl.',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEUTRAM 50 (EAST WEST)'
);

-- line #30309
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEUTRAM 50 (EAST WEST)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEUTRAM 50 (EAST WEST)'
);

-- line #30310
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEXDOL 100 (Zuventus)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEXDOL 100 (Zuventus)'
);

-- line #30311
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEXDOL 100 (Zuventus)',
	'Tramadol Hcl.',
	'SR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEXDOL 100 (Zuventus)'
);

-- line #30312
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NICTRAM 50 (Nitin Ph.)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NICTRAM 50 (Nitin Ph.)'
);

-- line #30313
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOBLIGAN 100 (Nicholas)',
	'Tramadol Hcl.',
	'AMP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOBLIGAN 100 (Nicholas)'
);

-- line #30314
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOBLIGAN 50 (Nicholas)',
	'Tramadol Hcl.',
	'AMP',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOBLIGAN 50 (Nicholas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOBLIGAN 100 (Nicholas)',
	'Tramadol Hcl.',
	'AMP',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOBLIGAN 100 (Nicholas)'
);

-- line #30315
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOBLIGAN 100 (Nicholas)',
	'Tramadol Hcl.',
	'SR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOBLIGAN 100 (Nicholas)'
);

-- line #30316
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOBLIGAN 50 (Nicholas)',
	'Tramadol Hcl.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOBLIGAN 50 (Nicholas)'
);

-- line #30317
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOPIDOL 100 (Elysium)',
	'Tramadol Hcl.',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOPIDOL 100 (Elysium)'
);

-- line #30318
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOPIDOL 50 (Elysium)',
	'Tramadol Hcl.',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOPIDOL 50 (Elysium)'
);

-- line #30319
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOPIDOL 100 (Elysium)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOPIDOL 100 (Elysium)'
);

-- line #30320
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOPIDOL 50 (Elysium)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOPIDOL 50 (Elysium)'
);

-- line #30321
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOTIL 50 (D.R.John''S)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOTIL 50 (D.R.John''S)'
);

-- line #30322
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOVADOL 50 (Radicura)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOVADOL 50 (Radicura)'
);

-- line #30323
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMODEL 50 (Eg Ph.)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMODEL 50 (Eg Ph.)'
);

-- line #30324
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMODOL 50 (Solitaire)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMODOL 50 (Solitaire)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OMODOL 100 (Solitaire)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OMODOL 100 (Solitaire)'
);

-- line #30325
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONDOL 50 (Shreeyam)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONDOL 50 (Shreeyam)'
);

-- line #30326
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONDOL 50 (Shreeyam)',
	'Tramadol Hcl.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONDOL 50 (Shreeyam)'
);

-- line #30327
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPIATE 100 (Sanify)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPIATE 100 (Sanify)'
);

-- line #30328
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPI-OT-100 100 (Elder)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPI-OT-100 100 (Elder)'
);

-- line #30329
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPI-OT-50 50 (Elder)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPI-OT-50 50 (Elder)'
);

-- line #30330
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPLGESIC 50 (Healthgaurd)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPLGESIC 50 (Healthgaurd)'
);

-- line #30331
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPLGESIC 50 (Healthgaurd)',
	'Tramadol Hcl.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPLGESIC 50 (Healthgaurd)'
);

-- line #30332
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORCHIDOL 100 (Orchid Hc.)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORCHIDOL 100 (Orchid Hc.)'
);

-- line #30333
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORCHIDOL 50 (Orchid Hc.)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORCHIDOL 50 (Orchid Hc.)'
);

-- line #30334
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORCHIDOL 50 (Orchid Hc.)',
	'Tramadol Hcl.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORCHIDOL 50 (Orchid Hc.)'
);

-- line #30335
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSPIDOL 50 (Osper)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSPIDOL 50 (Osper)'
);

-- line #30336
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSPIDOL 100 (Osper)',
	'Tramadol Hcl.',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSPIDOL 100 (Osper)'
);

-- line #30337
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAINADOL 100 (F D C)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAINADOL 100 (F D C)'
);

-- line #30338
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAINADOL 50 (F D C)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAINADOL 50 (F D C)'
);

-- line #30339
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAINADOL 100 (F D C)',
	'Tramadol Hcl.',
	'SR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAINADOL 100 (F D C)'
);

-- line #30340
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAINADOL 50 (F D C)',
	'Tramadol Hcl.',
	'SR TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAINADOL 50 (F D C)'
);

-- line #30341
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAXMAX 50 (MOLEKULE)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAXMAX 50 (MOLEKULE)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAXMAX 100 (MOLEKULE)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAXMAX 100 (MOLEKULE)'
);

-- line #30342
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PENTAZEN 100 (Ind-Swift)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PENTAZEN 100 (Ind-Swift)'
);

-- line #30343
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POSTADOL 50 (Nicholas)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POSTADOL 50 (Nicholas)'
);

-- line #30344
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRD 100 (MISSION RES.)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRD 100 (MISSION RES.)'
);

-- line #30345
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRD 50 (MISSION RES.)',
	'Tramadol Hcl.',
	'MD TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRD 50 (MISSION RES.)'
);

-- line #30346
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRD 100 (MISSION RES.)',
	'Tramadol Hcl.',
	'SR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRD 100 (MISSION RES.)'
);

-- line #30347
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMADOL 50 (ORDAIN HC.)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMADOL 50 (ORDAIN HC.)'
);

-- line #30348
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMADOL 200 (Ordain Hc.)',
	'Tramadol Hcl.',
	'SR TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMADOL 200 (Ordain Hc.)'
);

-- line #30349
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMAX 50 (Zydus Cadila)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMAX 50 (Zydus Cadila)'
);

-- line #30350
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMAX 5 (Zydus Cadila)',
	'Tramadol Hcl.',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMAX 5 (Zydus Cadila)'
);

-- line #30351
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMCET 50 (Dyota N.)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMCET 50 (Dyota N.)'
);

-- line #30352
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RAMDOL 50 (KPL LIFE)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RAMDOL 50 (KPL LIFE)'
);

-- line #30353
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELIDOL 50 (Juggat)',
	'Tramadol Hcl.',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELIDOL 50 (Juggat)'
);

-- line #30354
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELIDOL 50 (Juggat)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELIDOL 50 (Juggat)'
);

-- line #30355
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELIDOL 50 (Juggat)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELIDOL 50 (Juggat)'
);

-- line #30356
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REVODOL 100 (Torrent)',
	'Tramadol Hcl.',
	'SR TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REVODOL 100 (Torrent)'
);

-- line #30357
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REVODOL 50 (Torrent)',
	'Tramadol Hcl.',
	'SR TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REVODOL 50 (Torrent)'
);

-- line #30358
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIDIL-50 50 (Dynamic)',
	'Tramadol Hcl.',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIDIL-50 50 (Dynamic)'
);

-- line #30359
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIO STAT 500 (Intra(INVISION))',
	'Tranexamic Acid',
	'AMP',
	gm.nullify_empty_string('500')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIO STAT 500 (Intra(INVISION))'
);

-- line #30360
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CAPITRAX 500 (Evacare)',
	'Tranexamic Acid',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CAPITRAX 500 (Evacare)'
);

-- line #30361
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLIP 500 (F D C)',
	'Tranexamic Acid',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLIP 500 (F D C)'
);

-- line #30362
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOTAWIN-T 100 (Bestochem)',
	'Tranexamic Acid',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOTAWIN-T 100 (Bestochem)'
);

-- line #30363
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOT 500 (Shrinivas)',
	'Tranexamic Acid',
	'XL TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOT 500 (Shrinivas)'
);

-- line #30364
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYKLOKAPRON 500 (Pfizer)',
	'Tranexamic Acid',
	'TM IV',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYKLOKAPRON 500 (Pfizer)'
);

-- line #30365
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYMIN 250 (Wockhardt)',
	'Tranexamic Acid',
	'TAB',
	gm.nullify_empty_string('250')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYMIN 250 (Wockhardt)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYMIN 500 (Wockhardt)',
	'Tranexamic Acid',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYMIN 500 (Wockhardt)'
);

-- line #30366
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUBATRAN 500 (Alembic)',
	'Tranexamic Acid',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUBATRAN 500 (Alembic)'
);

-- line #30367
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DUBATRAN 500 (Alembic)',
	'Tranexamic Acid',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DUBATRAN 500 (Alembic)'
);

-- line #30368
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXAMIC 500 (Tnt Life)',
	'Tranexamic Acid',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXAMIC 500 (Tnt Life)'
);

-- line #30369
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXAMIC 500 (BLUBELL)',
	'Tranexamic Acid',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXAMIC 500 (BLUBELL)'
);

-- line #30370
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EXTAM 500 (Inga)',
	'Tranexamic Acid',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EXTAM 500 (Inga)'
);

-- line #30371
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FIBRAN 500 (Obsurge)',
	'Tranexamic Acid',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FIBRAN 500 (Obsurge)'
);

-- line #30372
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HXA 500 (ROSE LABS)',
	'Tranexamic Acid',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HXA 500 (ROSE LABS)'
);

-- line #30373
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MENOGIA 500 (Gufic Bio.)',
	'Tranexamic Acid',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MENOGIA 500 (Gufic Bio.)'
);

-- line #30374
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOUZEX 500 (LITTLE GREAVE)',
	'Tranexamic Acid',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOUZEX 500 (LITTLE GREAVE)'
);

-- line #30375
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEXAMIN-500 500 (MEDIMARK)',
	'Tranexamic acid',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEXAMIN-500 500 (MEDIMARK)'
);

-- line #30376
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100', u'strength_2': u'', u'substance': u'Tranexamic acid', u'always_empty': u'', u'form': u'', u'brand': u'NEXAMIN', u'strength_3': u'', u'company': u'MEDIMARK', u'unit': u'mg'}

-- line #30377
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEXA 500 (Kamron)',
	'Tranexamic Acid',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEXA 500 (Kamron)'
);

-- line #30378
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEXI 500 (Zee Lab)',
	'Tranexamic Acid',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEXI 500 (Zee Lab)'
);

-- line #30379
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIXA 500 (Biomax Bio.)',
	'Tranexamic Acid',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIXA 500 (Biomax Bio.)'
);

-- line #30380
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORSIK-T 500 (Ornate Ph.)',
	'Tranexamic Acid',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORSIK-T 500 (Ornate Ph.)'
);

-- line #30381
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORSIK-T 500 (ORNATE PH.)',
	'Tranexamic Acid',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORSIK-T 500 (ORNATE PH.)'
);

-- line #30382
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAUSE 500 (Emcure)',
	'Tranexamic Acid',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAUSE 500 (Emcure)'
);

-- line #30383
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAUSE 750 (Emcure)',
	'Tranexamic Acid',
	'SR TAB',
	gm.nullify_empty_string('750')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAUSE 750 (Emcure)'
);

-- line #30384
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAUSE 1000 (Emcure)',
	'Tranexamic Acid',
	'TAB',
	gm.nullify_empty_string('1000')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAUSE 1000 (Emcure)'
);

-- line #30385
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PAUSE 500 (Emcure)',
	'Tranexamic Acid',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PAUSE 500 (Emcure)'
);

-- line #30386
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RHEONEX 500 (Micro Labs)',
	'Tranexamic Acid',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RHEONEX 500 (Micro Labs)'
);

-- line #30387
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUPITROS EYE 0.004 (Lupin)',
	'TRAVOPROST',
	'DROPS',
	gm.nullify_empty_string('0.004')::numeric,
	'%W/V(BENZALKONIUM CHLORIDE SOLUTION IP 0.02'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUPITROS EYE 0.004 (Lupin)'
);

-- line #30388
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPRYL 100 (Cipla)',
	'Trazodone Hcl.',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPRYL 100 (Cipla)'
);

-- line #30389
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPRYL 25 (Cipla)',
	'Trazodone Hcl.',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPRYL 25 (Cipla)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEPRYL 50 (Cipla)',
	'Trazodone Hcl.',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEPRYL 50 (Cipla)'
);

-- line #30390
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AIROL 0.05 (Piramal Hc.)',
	'Tretinoin',
	'CRM (005%)',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AIROL 0.05 (Piramal Hc.)'
);

-- line #30391
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AIROL 0.025 (Piramal Hc.)',
	'Tretinoin',
	'CRM',
	gm.nullify_empty_string('0.025')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AIROL 0.025 (Piramal Hc.)'
);

-- line #30392
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'A-RET 0.025 (Shalaks)',
	'Tretinoin',
	'GEL (0025%)',
	gm.nullify_empty_string('0.025')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'A-RET 0.025 (Shalaks)'
);

-- line #30393
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'A-RET 0.05 (Shalaks)',
	'Tretinoin',
	'GEL (005%)',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'A-RET 0.05 (Shalaks)'
);

-- line #30394
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'A-RET 0.1 (Shalaks)',
	'Tretinoin',
	'GEL (01%)',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'A-RET 0.1 (Shalaks)'
);

-- line #30395
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'A-RET 0.05 (Shalaks)',
	'Tretinoin',
	'SOL (005%)',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'A-RET 0.05 (Shalaks)'
);

-- line #30396
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COMEDOLYTIC 0.025 (Fem care)',
	'Tretinoin',
	'CRM',
	gm.nullify_empty_string('0.025')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COMEDOLYTIC 0.025 (Fem care)'
);

-- line #30397
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EUDYNA 0.05 (German R.)',
	'Tretinoin',
	'CRM',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EUDYNA 0.05 (German R.)'
);

-- line #30398
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Tretinoin', u'always_empty': u'', u'form': u'CRM', u'brand': u'MORTRET', u'strength_3': u'', u'company': u'NORTECH REM.', u'unit': u''}

-- line #30399
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEXRET % 0.01 (DR. REDDY''S)',
	'Tretinoin',
	'GEL',
	gm.nullify_empty_string('0.01')::numeric,
	'%(AS MICROSPHERES)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEXRET % 0.01 (DR. REDDY''S)'
);

-- line #30400
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEXRET % 0.025 (DR. REDDY''S)',
	'Tretinoin',
	'GEL',
	gm.nullify_empty_string('0.025')::numeric,
	'%(AS MICROSPHERES)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEXRET % 0.025 (DR. REDDY''S)'
);

-- line #30401
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PINOIN 0.03 (EAST WEST)',
	'Tretinoin',
	'OINT',
	gm.nullify_empty_string('0.03')::numeric,
	'0.05'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PINOIN 0.03 (EAST WEST)'
);

-- line #30402
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RETINO-A 0.025 (Ethnor)',
	'Tretinoin',
	'CRM %',
	gm.nullify_empty_string('0.025')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RETINO-A 0.025 (Ethnor)'
);

-- line #30403
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RETINO-A 0.05 (Ethnor)',
	'Tretinoin',
	'CRM %',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RETINO-A 0.05 (Ethnor)'
);

-- line #30404
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,025', u'strength_2': u'', u'substance': u'Tretinoin', u'always_empty': u'', u'form': u'', u'brand': u'RETINOL %', u'strength_3': u'', u'company': u'PSYCOREM', u'unit': u'%W/W'}

-- line #30405
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,05', u'strength_2': u'', u'substance': u'Tretinoin', u'always_empty': u'', u'form': u'', u'brand': u'RETINOL %', u'strength_3': u'', u'company': u'PSYCOREM', u'unit': u'%W/W'}

-- line #30406
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RETO 0.025 (AGIO PH.)',
	'Tretinoin',
	'CRM %',
	gm.nullify_empty_string('0.025')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RETO 0.025 (AGIO PH.)'
);

-- line #30407
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RETO 0.05 (AGIO PH.)',
	'Tretinoin',
	'CRM %',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RETO 0.05 (AGIO PH.)'
);

-- line #30408
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMCORT 40 (Pharma Drugs)',
	'Triamcinolone',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMCORT 40 (Pharma Drugs)'
);

-- line #30409
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,1', u'strength_2': u'', u'substance': u'Triamcinolone', u'always_empty': u'', u'form': u'', u'brand': u'CAZIQ CREA', u'strength_3': u'', u'company': u"Dr.Reddy''S", u'unit': u'%W/W(ACETONIDE)'}

-- line #30410
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COMCORT 10 (Comed)',
	'Triamcinolone',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COMCORT 10 (Comed)'
);

-- line #30411
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COMCORT 40 (Comed)',
	'Triamcinolone',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COMCORT 40 (Comed)'
);

-- line #30412
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORTRIMA 0.01 (Nulife)',
	'Triamcinolone',
	'CRM',
	gm.nullify_empty_string('0.01')::numeric,
	'%W/W(ACETONIDE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORTRIMA 0.01 (Nulife)'
);

-- line #30413
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'D-CORT 10 (Dwd)',
	'Triamcinolone',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'D-CORT 10 (Dwd)'
);

-- line #30414
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'D-CORT 40 (Dwd)',
	'Triamcinolone',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'D-CORT 40 (Dwd)'
);

-- line #30415
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Triamcinolone', u'always_empty': u'', u'form': u'INJ', u'brand': u'EXCORT-40', u'strength_3': u'', u'company': u'OMNI LIFE', u'unit': u''}

-- line #30416
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HUCORT 40 (ROSE LABS)',
	'Triamcinolone',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HUCORT 40 (ROSE LABS)'
);

-- line #30417
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KENACORT 10 (Nicholas)',
	'Triamcinolone',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KENACORT 10 (Nicholas)'
);

-- line #30418
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KENACORT 40 (Nicholas)',
	'Triamcinolone',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KENACORT 40 (Nicholas)'
);

-- line #30419
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,1', u'strength_2': u'', u'substance': u'Triamcinolone', u'always_empty': u'', u'form': u'', u'brand': u'KENACORT ORAL PASTE', u'strength_3': u'', u'company': u'Nicholas', u'unit': u'%W/V(ACETONIDE)'}

-- line #30420
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KENACORT 4 (Nicholas)',
	'Triamcinolone',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KENACORT 4 (Nicholas)'
);

-- line #30421
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KLOG-10 10 (Suvik Hit.)',
	'Triamcinolone',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KLOG-10 10 (Suvik Hit.)'
);

-- line #30422
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KLOG-40 40 (Suvik Hit.)',
	'Triamcinolone',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KLOG-40 40 (Suvik Hit.)'
);

-- line #30423
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEDERCORT 0.1 (Wyeth)',
	'Triamcinolone',
	'OINT',
	gm.nullify_empty_string('0.1')::numeric,
	'%(ACETONIDE)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEDERCORT 0.1 (Wyeth)'
);

-- line #30424
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEDERCORT 4 (Wyeth)',
	'Triamcinolone',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEDERCORT 4 (Wyeth)'
);

-- line #30425
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,1', u'strength_2': u'', u'substance': u'Triamcinolone', u'always_empty': u'', u'form': u'', u'brand': u'ORAPASTE ORAL PASTE', u'strength_3': u'', u'company': u'Palsons', u'unit': u'%W/W'}

-- line #30426
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PERICORT-4 4 (Themis)',
	'Triamcinolone',
	'TAB',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PERICORT-4 4 (Themis)'
);

-- line #30427
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RETILONE 40 (Cipla)',
	'Triamcinolone',
	'INJ',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RETILONE 40 (Cipla)'
);

-- line #30428
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Trichlorocarbanilide', u'always_empty': u'', u'form': u'SOAP', u'brand': u'NEKO', u'strength_3': u'', u'company': u'PFIZER', u'unit': u''}

-- line #30429
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.55G', u'strength_2': u'', u'substance': u'Tricholine Cit.', u'always_empty': u'', u'form': u'SYR', u'brand': u'HEPASTAR', u'strength_3': u'', u'company': u'Intra(INVISION)', u'unit': u''}

-- line #30430
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIVAT 275 (ROSE)',
	'Tricholine Cit.',
	'DS LIQ',
	gm.nullify_empty_string('275')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIVAT 275 (ROSE)'
);

-- line #30431
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.275G', u'strength_2': u'5ML', u'substance': u'Tricholine Citrate', u'always_empty': u'', u'form': u'SYR', u'brand': u'LIVODEX', u'strength_3': u'', u'company': u'Ikon Rem', u'unit': u''}

-- line #30432
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FERMER 500 (HALO MEDI.)',
	'Triclofos',
	'SYR',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FERMER 500 (HALO MEDI.)'
);

-- line #30433
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NA-RO 500 (Kosha Lab.)',
	'Triclofos sodium',
	'SYR',
	gm.nullify_empty_string('500')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NA-RO 500 (Kosha Lab.)'
);

-- line #30434
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NUCLORYL 500 (ICARUS)',
	'Triclofos sodium',
	'LIQD',
	gm.nullify_empty_string('500')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NUCLORYL 500 (ICARUS)'
);

-- line #30435
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEDICLORYL 500 (Dr.Reddy''S)',
	'Triclofos sodium',
	'SYR',
	gm.nullify_empty_string('500')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEDICLORYL 500 (Dr.Reddy''S)'
);

-- line #30436
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACGUARD 1 (HAMPS BIO)',
	'Triclosan',
	'SOAP',
	gm.nullify_empty_string('1')::numeric,
	'%+ALOE VERA 2'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACGUARD 1 (HAMPS BIO)'
);

-- line #30437
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Triclosan', u'always_empty': u'', u'form': u'SOAP', u'brand': u'ACNELAK', u'strength_3': u'', u'company': u'Shalaks', u'unit': u''}

-- line #30438
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMRED-TRC 1 (ADVENTUS)',
	'Triclosan',
	'SOAP',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMRED-TRC 1 (ADVENTUS)'
);

-- line #30439
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AQUABACT 0.5 (Ajanta Ph.)',
	'Triclosan',
	'SOAP',
	gm.nullify_empty_string('0.5')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AQUABACT 0.5 (Ajanta Ph.)'
);

-- line #30440
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'(+MENTHOL)', u'strength_2': u'', u'substance': u'Triclosan', u'always_empty': u'', u'form': u'SOAP', u'brand': u'DEOSAN', u'strength_3': u'', u'company': u'BIOMEDICA', u'unit': u''}

-- line #30441
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GAMOPHEN 0.5 (J.&J.)',
	'Triclosan',
	'SOL',
	gm.nullify_empty_string('0.5')::numeric,
	'%W/W'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GAMOPHEN 0.5 (J.&J.)'
);

-- line #30442
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KLIN 0.5 (KLM LAB.)',
	'Triclosan',
	'SOAP',
	gm.nullify_empty_string('0.5')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KLIN 0.5 (KLM LAB.)'
);

-- line #30443
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MICROSHIELD-T 1 (J.&J.)',
	'Triclosan',
	'SOL',
	gm.nullify_empty_string('1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MICROSHIELD-T 1 (J.&J.)'
);

-- line #30444
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'WITH ALOE VERA & MENTHOL', u'strength_2': u'', u'substance': u'TRICLOSAN', u'always_empty': u'', u'form': u'CRM', u'brand': u'OVEE', u'strength_3': u'', u'company': u'OREVA DARMO.', u'unit': u''}

-- line #30445
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORZINE 1 (SYKOCURE)',
	'Trifluoperazine Hcl.',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORZINE 1 (SYKOCURE)'
);

-- line #30446
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOCALM 10 (Orchid Hc.)',
	'Trifluoperazine Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOCALM 10 (Orchid Hc.)'
);

-- line #30447
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOCALM 2 (Orchid Hc.)',
	'Trifluoperazine Hcl.',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOCALM 2 (Orchid Hc.)'
);

-- line #30448
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOCALM 5 (Orchid Hc.)',
	'Trifluoperazine Hcl.',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOCALM 5 (Orchid Hc.)'
);

-- line #30449
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOCALM 10 (Intas)',
	'Trifluoperazine Hcl.',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOCALM 10 (Intas)'
);

-- line #30450
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOCALM 5 (Intas)',
	'Trifluoperazine Hcl.',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOCALM 5 (Intas)'
);

-- line #30451
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PSYCALM 1 (Saga Lab)',
	'Trifluoperazine Hcl.',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'5'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PSYCALM 1 (Saga Lab)'
);

-- line #30452
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELICALM 5 (Reliance)',
	'Trifluoperazine Hcl.',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELICALM 5 (Reliance)'
);

-- line #30453
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELICLAM 5 (Reliance)',
	'Trifluoperazine Hcl.',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELICLAM 5 (Reliance)'
);

-- line #30454
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'TRIGONELLA FOENUM GRACE COMMIPHORA MUKUL PLUMBAGP ZEYLANICA', u'always_empty': u'', u'form': u'', u'brand': u'OOLEST', u'strength_3': u'', u'company': u'PINK HEALTH', u'unit': u''}

-- line #30455
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Trihexyphenidyl Hcl.', u'always_empty': u'', u'form': u'TAB', u'brand': u'BAROHEXY', u'strength_3': u'', u'company': u'BARODA', u'unit': u''}

-- line #30456
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AP 2 (Olcare)',
	'Trihexyphenidyl Hcl.(BENZHEXOL)',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AP 2 (Olcare)'
);

-- line #30457
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOHEXY 2 (Rhombus)',
	'Trihexyphenidyl Hcl.(BENZHEXOL)',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOHEXY 2 (Rhombus)'
);

-- line #30458
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DYSTONIL 2 (Pil)',
	'Trihexyphenidyl Hcl.(BENZHEXOL)',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DYSTONIL 2 (Pil)'
);

-- line #30459
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEXINAL 2 (Torrent)',
	'Trihexyphenidyl Hcl.(BENZHEXOL)',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEXINAL 2 (Torrent)'
);

-- line #30460
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LAHEXY 2 (LA DRUG)',
	'Trihexyphenidyl Hcl.(BENZHEXOL)',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LAHEXY 2 (LA DRUG)'
);

-- line #30461
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOHEXY 2 (Mano)',
	'Trihexyphenidyl Hcl.(BENZHEXOL)',
	'INJ',
	gm.nullify_empty_string('2')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOHEXY 2 (Mano)'
);

-- line #30462
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOHEXY 2 (Mano)',
	'Trihexyphenidyl Hcl.(BENZHEXOL)',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOHEXY 2 (Mano)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MANOHEXY 5 (Mano)',
	'Trihexyphenidyl Hcl.(BENZHEXOL)',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MANOHEXY 5 (Mano)'
);

-- line #30463
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOVAHEXY 2 (MOVA PH.)',
	'Trihexyphenidyl Hcl.(BENZHEXOL)',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOVAHEXY 2 (MOVA PH.)'
);

-- line #30464
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PACIDYL 2 (Synokem)',
	'Trihexyphenidyl Hcl.(BENZHEXOL)',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PACIDYL 2 (Synokem)'
);

-- line #30465
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PACIGO 2 (NAVNIDHI LIFE)',
	'Trihexyphenidyl Hcl.(BENZHEXOL)',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PACIGO 2 (NAVNIDHI LIFE)'
);

-- line #30466
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARNON 2 (Svizera)',
	'Trihexyphenidyl Hcl.(BENZHEXOL)',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARNON 2 (Svizera)'
);

-- line #30467
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PTEMPT 2 (S P Ph.)',
	'Trihexyphenidyl Hcl.(BENZHEXOL)',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PTEMPT 2 (S P Ph.)'
);

-- line #30468
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELIHEXY 2 (Reliance)',
	'Trihexyphenidyl Hcl.(BENZHEXOL)',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELIHEXY 2 (Reliance)'
);

-- line #30469
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BEXOL 2 (Intas)',
	'Trihexyphenidyl Hcl.',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BEXOL 2 (Intas)'
);

-- line #30470
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2', u'strength_2': u'', u'substance': u'Trihexyphenidyl Hcl.', u'always_empty': u'', u'form': u'', u'brand': u'HEKSI', u'strength_3': u'', u'company': u'KIVI HC.', u'unit': u'mg'}

-- line #30471
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEXIPINE 2 (AMEE PH.)',
	'Trihexyphenidyl Hcl.',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEXIPINE 2 (AMEE PH.)'
);

-- line #30472
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEXIPINE 5 (AMEE PH.)',
	'Trihexyphenidyl Hcl.',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEXIPINE 5 (AMEE PH.)'
);

-- line #30473
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2', u'strength_2': u'', u'substance': u'Trihexyphenidyl Hcl.', u'always_empty': u'', u'form': u'', u'brand': u'KIN', u'strength_3': u'', u'company': u'MEDIFORECE', u'unit': u'mg'}

-- line #30474
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PACITANE 2 (Wyeth)',
	'Trihexyphenidyl Hcl.',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PACITANE 2 (Wyeth)'
);

-- line #30475
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARALES 2 (PSYCOREM)',
	'Trihexyphenidyl Hcl.',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'5'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARALES 2 (PSYCOREM)'
);

-- line #30476
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARKIN 2 (Synapse)',
	'Trihexyphenidyl Hcl.',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARKIN 2 (Synapse)'
);

-- line #30477
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PARKITANE 2 (Sun)',
	'Trihexyphenidyl Hcl.',
	'TAB',
	gm.nullify_empty_string('2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PARKITANE 2 (Sun)'
);

-- line #30478
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'3 KAT 60 (SHRRISHTI HC.)',
	'Trimetazidine',
	'TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = '3 KAT 60 (SHRRISHTI HC.)'
);

-- line #30479
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDIMAX 60 (U S V)',
	'Trimetazidine',
	'SR TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDIMAX 60 (U S V)'
);

-- line #30480
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARDIMAX 20 (U S V)',
	'Trimetazidine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARDIMAX 20 (U S V)'
);

-- line #30481
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Trimetazidine', u'always_empty': u'', u'form': u'MR TAB', u'brand': u'CARVIDON', u'strength_3': u'', u'company': u'Carsyon', u'unit': u''}

-- line #30482
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARVIDON 60 (Carsyon)',
	'Trimetazidine',
	'OD CAP',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARVIDON 60 (Carsyon)'
);

-- line #30483
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARVIDON 20 (Carsyon)',
	'Trimetazidine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARVIDON 20 (Carsyon)'
);

-- line #30484
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CARVIDON 35 (Carsyon)',
	'Trimetazidine',
	'TAB',
	gm.nullify_empty_string('35')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CARVIDON 35 (Carsyon)'
);

-- line #30485
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYTOGARD 60 (Piramal Hc.)',
	'Trimetazidine',
	'OD CAP',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYTOGARD 60 (Piramal Hc.)'
);

-- line #30486
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYTOGARD 20 (Piramal Hc.)',
	'Trimetazidine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYTOGARD 20 (Piramal Hc.)'
);

-- line #30487
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ELDON 20 (Lancer)',
	'Trimetazidine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ELDON 20 (Lancer)'
);

-- line #30488
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLAVEDON 35 (Serdia)',
	'Trimetazidine',
	'MR TAB',
	gm.nullify_empty_string('35')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLAVEDON 35 (Serdia)'
);

-- line #30489
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLAVEDON 20 (Serdia)',
	'Trimetazidine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLAVEDON 20 (Serdia)'
);

-- line #30490
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GUARD 20 (Admac Ph.)',
	'Trimetazidine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GUARD 20 (Admac Ph.)'
);

-- line #30491
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INVIDON 20 (Intra(INVISION))',
	'Trimetazidine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INVIDON 20 (Intra(INVISION))'
);

-- line #30492
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INVIDON 35 (Intra(INVISION))',
	'Trimetazidine',
	'XR TAB',
	gm.nullify_empty_string('35')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INVIDON 35 (Intra(INVISION))'
);

-- line #30493
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISVEDON 35 (Life Med.)',
	'Trimetazidine',
	'CR TAB',
	gm.nullify_empty_string('35')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISVEDON 35 (Life Med.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISVEDON 60 (Life Med.)',
	'Trimetazidine',
	'CR TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISVEDON 60 (Life Med.)'
);

-- line #30494
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ISVEDON 20 (Life Med.)',
	'Trimetazidine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ISVEDON 20 (Life Med.)'
);

-- line #30495
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAYOSEST 20 (Otsira)',
	'Trimetazidine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAYOSEST 20 (Otsira)'
);

-- line #30496
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MAYOZEST 20 (Otsira)',
	'Trimetazidine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MAYOZEST 20 (Otsira)'
);

-- line #30497
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'METAGARD 20 (Ipca)',
	'Trimetazidine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'METAGARD 20 (Ipca)'
);

-- line #30498
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYONERG 20 (Modi Mundi)',
	'Trimetazidine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYONERG 20 (Modi Mundi)'
);

-- line #30499
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYOVEDON 60 (Argus)',
	'Trimetazidine',
	'SR TAB',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYOVEDON 60 (Argus)'
);

-- line #30500
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYOVEDON 20 (Argus)',
	'Trimetazidine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYOVEDON 20 (Argus)'
);

-- line #30501
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRODIUM 20 (Macleods)',
	'Trimetazidine',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRODIUM 20 (Macleods)'
);

-- line #30502
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DSOROLEN 25 (Dwd)',
	'Trioxsalen',
	'F. TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DSOROLEN 25 (Dwd)'
);

-- line #30503
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DSOROLEN 0.2 (Dwd)',
	'Trioxsalen',
	'LOT',
	gm.nullify_empty_string('0.2')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DSOROLEN 0.2 (Dwd)'
);

-- line #30504
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DSOROLEN 5 (Dwd)',
	'Trioxsalen',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DSOROLEN 5 (Dwd)'
);

-- line #30505
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUKOSIS 25 (Ind-Swift(SUPER SP.))',
	'Trioxsalen',
	'F. TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUKOSIS 25 (Ind-Swift(SUPER SP.))'
);

-- line #30506
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LUKOSIS 5 (Ind-Swift(SUPER SP.))',
	'Trioxsalen',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LUKOSIS 5 (Ind-Swift(SUPER SP.))'
);

-- line #30507
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOSAL 5 (Dial Ph.)',
	'Trioxsalen',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOSAL 5 (Dial Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOSAL 25 (Dial Ph.)',
	'Trioxsalen',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOSAL 25 (Dial Ph.)'
);

-- line #30508
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOSORALEN 25 (Mac)',
	'Trioxsalen',
	'F. DRA',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOSORALEN 25 (Mac)'
);

-- line #30509
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Trioxsalen', u'always_empty': u'', u'form': u'LOT', u'brand': u'NEOSORALEN', u'strength_3': u'', u'company': u'Mac', u'unit': u''}

-- line #30510
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOSORALEN 5 (Mac)',
	'Trioxsalen',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOSORALEN 5 (Mac)'
);

-- line #30511
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DENOL 120 (Elder)',
	'Tripotassium Dicitrato Bismuthate',
	'TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DENOL 120 (Elder)'
);

-- line #30512
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECAPEPTYL DAILY 0.1 (Ferring Ph.)',
	'TRIPTORELIN',
	'INJ',
	gm.nullify_empty_string('0.1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECAPEPTYL DAILY 0.1 (Ferring Ph.)'
);

-- line #30513
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECAPEPTYL DEPOT 3.75 (Ferring Ph.)',
	'TRIPTORELIN',
	'INJ',
	gm.nullify_empty_string('3.75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECAPEPTYL DEPOT 3.75 (Ferring Ph.)'
);

-- line #30514
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEPASULFOL 12.5 (Franco I.)',
	'Trithioparamethoxyphenyl Propene',
	'TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEPASULFOL 12.5 (Franco I.)'
);

-- line #30515
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Tropicamide', u'always_empty': u'', u'form': u'EYE DPS', u'brand': u'BIOMIDE', u'strength_3': u'', u'company': u'Bio-Tech Opth.', u'unit': u''}

-- line #30516
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MYDRIACYL 1 (Ophthal R.)',
	'Tropicamide',
	'EYE DPS',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MYDRIACYL 1 (Ophthal R.)'
);

-- line #30517
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OPTIMIDE 1 (Micro V.)',
	'Tropicamide',
	'EYE DPS',
	gm.nullify_empty_string('1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OPTIMIDE 1 (Micro V.)'
);

-- line #30518
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLOTROS 60 (IPCA LAB.)',
	'TROSPIUM CHLORIDE',
	'SR CAP',
	gm.nullify_empty_string('60')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLOTROS 60 (IPCA LAB.)'
);

-- line #30519
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OXERUTE 500 (Fourrts)',
	'TROXERUTIN',
	'DS TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OXERUTE 500 (Fourrts)'
);

-- line #30520
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIO-BLUE 0.6 (Bio-Tech Opth.)',
	'Trypan Blue',
	'EYE DPS',
	gm.nullify_empty_string('0.6')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIO-BLUE 0.6 (Bio-Tech Opth.)'
);

-- line #30521
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLURING 0.6 (Milmet)',
	'Trypan Blue',
	'SOL',
	gm.nullify_empty_string('0.6')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLURING 0.6 (Milmet)'
);

-- line #30522
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100000U.', u'strength_2': u'', u'substance': u'Trypsin-Chymotrypsin', u'always_empty': u'', u'form': u'TAB', u'brand': u'ALFAPSIN', u'strength_3': u'', u'company': u'HETERO HC.', u'unit': u''}

-- line #30523
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Trypsin-Chymotrypsin', u'always_empty': u'', u'form': u'F. TAB', u'brand': u'BANRAL', u'strength_3': u'', u'company': u'Bantom', u'unit': u''}

-- line #30524
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1LAC AU.', u'strength_2': u'', u'substance': u'Trypsin-Chymotrypsin', u'always_empty': u'', u'form': u'F. TAB', u'brand': u'BANRAL', u'strength_3': u'', u'company': u'Elder', u'unit': u''}

-- line #30525
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1 LAC U.', u'strength_2': u'', u'substance': u'Trypsin-Chymotrypsin', u'always_empty': u'', u'form': u'F. TAB', u'brand': u'CEZE', u'strength_3': u'', u'company': u'Zee Lab', u'unit': u''}

-- line #30526
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1LAC AU.', u'strength_2': u'', u'substance': u'Trypsin-Chymotrypsin', u'always_empty': u'', u'form': u'F. TAB', u'brand': u'CHYMASE', u'strength_3': u'', u'company': u'Indu D.', u'unit': u''}

-- line #30527
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Trypsin-Chymotrypsin', u'always_empty': u'', u'form': u'F.', u'brand': u'CHYMIN', u'strength_3': u'', u'company': u'EMAR', u'unit': u''}

-- line #30528
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100000U', u'strength_2': u'', u'substance': u'Trypsin-Chymotrypsin', u'always_empty': u'', u'form': u'F. TAB', u'brand': u'CHYMOBEL', u'strength_3': u'', u'company': u'BLUBELL', u'unit': u''}

-- line #30529
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHYMOCIP 100 (Cipla)',
	'Trypsin-Chymotrypsin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'000AU(ARMOUR UNITS ENZYMATIC ACTIVITY)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHYMOCIP 100 (Cipla)'
);

-- line #30530
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Trypsin-Chymotrypsin', u'always_empty': u'', u'form': u'TAB', u'brand': u'CHYMOLEK', u'strength_3': u'', u'company': u'Lekar', u'unit': u''}

-- line #30531
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'2 LAC AU.', u'strength_2': u'', u'substance': u'Trypsin-Chymotrypsin', u'always_empty': u'', u'form': u'F. TAB', u'brand': u'CHYMORAL', u'strength_3': u'', u'company': u'Elder', u'unit': u''}

-- line #30532
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1LAC AU.', u'strength_2': u'', u'substance': u'Trypsin-Chymotrypsin', u'always_empty': u'', u'form': u'', u'brand': u'CHYMORAL LAC AUTAB', u'strength_3': u'', u'company': u'Elder', u'unit': u''}

-- line #30533
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50000AU.', u'strength_2': u'', u'substance': u'Trypsin-Chymotrypsin', u'always_empty': u'', u'form': u'TAB', u'brand': u'CHYMORAL', u'strength_3': u'', u'company': u'Elder', u'unit': u''}

-- line #30534
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHYMUTRIP 100 (Bombay T.)',
	'Trypsin-Chymotrypsin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'000UPS U.'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHYMUTRIP 100 (Bombay T.)'
);

-- line #30535
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1 LAC U.', u'strength_2': u'', u'substance': u'Trypsin-Chymotrypsin', u'always_empty': u'', u'form': u'', u'brand': u'CHYZOBID', u'strength_3': u'', u'company': u'AASHRAY', u'unit': u''}

-- line #30536
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1 LAC U.', u'strength_2': u'', u'substance': u'Trypsin-Chymotrypsin', u'always_empty': u'', u'form': u'TAB', u'brand': u'COPTRIN', u'strength_3': u'', u'company': u'Dynamic', u'unit': u''}

-- line #30537
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1 LAC U.', u'strength_2': u'', u'substance': u'Trypsin-Chymotrypsin', u'always_empty': u'', u'form': u'F. TAB', u'brand': u'ENZYTRIP', u'strength_3': u'', u'company': u'CHEMO HC.', u'unit': u''}

-- line #30538
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1 LAC U.', u'strength_2': u'', u'substance': u'Trypsin-Chymotrypsin', u'always_empty': u'', u'form': u'TAB', u'brand': u'FIBOLYTE', u'strength_3': u'', u'company': u'Shaimil', u'unit': u''}

-- line #30539
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLAMOTRYP 100 (ELDER)',
	'Trypsin-Chymotrypsin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'000IU.(PURF.PROTEOLYTIC ENZYME CONC.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLAMOTRYP 100 (ELDER)'
);

-- line #30540
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1LAC AU.', u'strength_2': u'', u'substance': u'Trypsin-Chymotrypsin', u'always_empty': u'', u'form': u'F. TAB', u'brand': u'FLOTRIP', u'strength_3': u'', u'company': u'LIFESTAR', u'unit': u''}

-- line #30541
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Trypsin-Chymotrypsin', u'always_empty': u'', u'form': u'F. TAB', u'brand': u'FODASE', u'strength_3': u'', u'company': u'Forgo Ph.', u'unit': u''}

-- line #30542
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100000U', u'strength_2': u'', u'substance': u'Trypsin-Chymotrypsin', u'always_empty': u'', u'form': u'F. TAB', u'brand': u'K-TRIP', u'strength_3': u'', u'company': u'FDC(SPECTRA)', u'unit': u''}

-- line #30543
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Trypsin-Chymotrypsin', u'always_empty': u'', u'form': u'F. TAB', u'brand': u'KYMOVIL', u'strength_3': u'', u'company': u'VILBERRY HC.', u'unit': u''}

-- line #30544
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KYMOVIL 100 (VILBERRY HC.)',
	'Trypsin-Chymotrypsin',
	'TAB',
	gm.nullify_empty_string('100')::numeric,
	'000AU(ARMOUR UNITS ENZYMATIC ACTIVITY)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KYMOVIL 100 (VILBERRY HC.)'
);

-- line #30545
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Trypsin-Chymotrypsin', u'always_empty': u'', u'form': u'F. TAB', u'brand': u'ORTHAL', u'strength_3': u'', u'company': u'Cipla', u'unit': u''}

-- line #30546
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1 LAC IU.', u'strength_2': u'', u'substance': u'Trypsin-Chymotrypsin', u'always_empty': u'', u'form': u'TAB', u'brand': u'RESTOCHYME', u'strength_3': u'', u'company': u'Walter B.', u'unit': u''}

-- line #30547
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'7500M.', u'strength_2': u'', u'substance': u'Tyndallised Lactobacillus Acidophillus Cells', u'always_empty': u'', u'form': u'GRAN', u'brand': u'LACTROL', u'strength_3': u'', u'company': u'R.B.', u'unit': u''}

-- line #30548
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.5ML', u'strength_2': u'', u'substance': u'TYPHOID VACCINE', u'always_empty': u'', u'form': u'', u'brand': u'BIOVAC TYPHOID', u'strength_3': u'', u'company': u'Wockhardt', u'unit': u''}

-- line #30549
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75IU.', u'strength_2': u'150IU.', u'substance': u'Urofollitrophin', u'always_empty': u'', u'form': u'VIAL', u'brand': u'GONOTROP-F', u'strength_3': u'', u'company': u'Win-Medicare', u'unit': u''}

-- line #30550
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75IU', u'strength_2': u'', u'substance': u'Urofollitrophin', u'always_empty': u'', u'form': u'INJ', u'brand': u'METRODIN', u'strength_3': u'', u'company': u'Serum Inst.', u'unit': u''}

-- line #30551
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'75', u'strength_2': u'150;IU.', u'substance': u'Urofollitrophin', u'always_empty': u'', u'form': u'VIAL', u'brand': u'OVITROP', u'strength_3': u'', u'company': u'Sun', u'unit': u''}

-- line #30552
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250000 I.U.', u'strength_2': u'', u'substance': u'Urokinase', u'always_empty': u'', u'form': u'VIAL', u'brand': u'DABUNASE ,000 IU', u'strength_3': u'', u'company': u'Dabur Ph.', u'unit': u''}

-- line #30553
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500000 I.U.', u'strength_2': u'', u'substance': u'Urokinase', u'always_empty': u'', u'form': u'VIAL', u'brand': u'DABUNASE ,000 IU', u'strength_3': u'', u'company': u'Dabur Ph.', u'unit': u''}

-- line #30554
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250000IU.', u'strength_2': u'', u'substance': u'Urokinase', u'always_empty': u'', u'form': u'INJ', u'brand': u'DUKINASE', u'strength_3': u'', u'company': u'Samarth', u'unit': u''}

-- line #30555
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500000IU.', u'strength_2': u'', u'substance': u'Urokinase', u'always_empty': u'', u'form': u'INJ', u'brand': u'DUKINASE', u'strength_3': u'', u'company': u'Samarth', u'unit': u''}

-- line #30556
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000000I.U.', u'strength_2': u'', u'substance': u'Urokinase', u'always_empty': u'', u'form': u'V', u'brand': u'KD-UNASE ,000,000 IU', u'strength_3': u'', u'company': u'Vhb', u'unit': u''}

-- line #30557
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250000 I.U.', u'strength_2': u'', u'substance': u'Urokinase', u'always_empty': u'', u'form': u'V', u'brand': u'KD-UNASE ,000 IU', u'strength_3': u'', u'company': u'Vhb', u'unit': u''}

-- line #30558
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500000 I.U.', u'strength_2': u'', u'substance': u'Urokinase', u'always_empty': u'', u'form': u'V', u'brand': u'KD-UNASE ,000 IU', u'strength_3': u'', u'company': u'Vhb', u'unit': u''}

-- line #30559
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'750000 I.U.', u'strength_2': u'', u'substance': u'Urokinase', u'always_empty': u'', u'form': u'V', u'brand': u'KD-UNASE ,000 IU', u'strength_3': u'', u'company': u'Vhb', u'unit': u''}

-- line #30560
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'250000 I.U.', u'strength_2': u'', u'substance': u'Urokinase', u'always_empty': u'', u'form': u'V', u'brand': u'MEDINASE ,000 IU', u'strength_3': u'', u'company': u'Life Med.', u'unit': u''}

-- line #30561
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500000 I.U.', u'strength_2': u'', u'substance': u'Urokinase', u'always_empty': u'', u'form': u'V', u'brand': u'MEDINASE ,000 IU', u'strength_3': u'', u'company': u'Life Med.', u'unit': u''}

-- line #30562
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500000 I.U.', u'strength_2': u'', u'substance': u'Urokinase', u'always_empty': u'', u'form': u'INJ', u'brand': u'RENOKINASE-L U', u'strength_3': u'', u'company': u'BIOSENA', u'unit': u''}

-- line #30563
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTIBILE 150 (Albert D.)',
	'Ursodeoxycholic Acid',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTIBILE 150 (Albert D.)'
);

-- line #30564
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTIBILE 300 (Albert D.)',
	'Ursodeoxycholic Acid',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTIBILE 300 (Albert D.)'
);

-- line #30565
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ANALIV UD 300 (Systopic)',
	'Ursodeoxycholic Acid',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ANALIV UD 300 (Systopic)'
);

-- line #30566
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORTIBILE 150 (Dey''S)',
	'Ursodeoxycholic Acid',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORTIBILE 150 (Dey''S)'
);

-- line #30567
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORTIBILE 300 (Dey''S)',
	'Ursodeoxycholic Acid',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORTIBILE 300 (Dey''S)'
);

-- line #30568
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GOLBI 450 (Intas)',
	'Ursodeoxycholic Acid',
	'SR TAB',
	gm.nullify_empty_string('450')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GOLBI 450 (Intas)'
);

-- line #30569
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GOLSTON 150 (GLOBELA PH.)',
	'Ursodeoxycholic Acid',
	'CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GOLSTON 150 (GLOBELA PH.)'
);

-- line #30570
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEPEXA 150 (ERIS LIFE)',
	'Ursodeoxycholic Acid',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEPEXA 150 (ERIS LIFE)'
);

-- line #30571
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HEPEXA 300 (ERIS LIFE)',
	'Ursodeoxycholic Acid',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HEPEXA 300 (ERIS LIFE)'
);

-- line #30572
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTRALIV-UD 150 (Intra Lab)',
	'Ursodeoxycholic Acid',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTRALIV-UD 150 (Intra Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INTRALIV-UD 300 (Intra Lab)',
	'Ursodeoxycholic Acid',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INTRALIV-UD 300 (Intra Lab)'
);

-- line #30573
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIVOKIND 150 (Discovery M.)',
	'Ursodeoxycholic Acid',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIVOKIND 150 (Discovery M.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIVOKIND 300 (Discovery M.)',
	'Ursodeoxycholic Acid',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIVOKIND 300 (Discovery M.)'
);

-- line #30574
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTIBILE 600 (Albert D.)',
	'URSODIOL',
	'TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTIBILE 600 (Albert D.)'
);

-- line #30575
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACTIBLILE CHILD 75 (Albert D.)',
	'URSODIOL',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACTIBLILE CHILD 75 (Albert D.)'
);

-- line #30576
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GOLBI 150 (Intas)',
	'URSODIOL',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GOLBI 150 (Intas)'
);

-- line #30577
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GOLBI 300 (Intas)',
	'URSODIOL',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GOLBI 300 (Intas)'
);

-- line #30578
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LIVGARD 300 (Dr.Arvind Shah''S)',
	'URSODIOL',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LIVGARD 300 (Dr.Arvind Shah''S)'
);

-- line #30579
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARTIVAL 10 (Geno Ph.)',
	'Valdecoxib',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARTIVAL 10 (Geno Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ARTIVAL 20 (Geno Ph.)',
	'Valdecoxib',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ARTIVAL 20 (Geno Ph.)'
);

-- line #30580
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOVAL 10 (Biochem)',
	'Valdecoxib',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOVAL 10 (Biochem)'
);

-- line #30581
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOVAL 20 (Biochem)',
	'Valdecoxib',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOVAL 20 (Biochem)'
);

-- line #30582
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CREVAL 10 (Croslands)',
	'Valdecoxib',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CREVAL 10 (Croslands)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CREVAL 20 (Croslands)',
	'Valdecoxib',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CREVAL 20 (Croslands)'
);

-- line #30583
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CREVAL 40 (Croslands)',
	'Valdecoxib',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CREVAL 40 (Croslands)'
);

-- line #30584
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MOBYLE-V-20 20 (Lincoln)',
	'Valdecoxib',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MOBYLE-V-20 20 (Lincoln)'
);

-- line #30585
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSRA 10 (Bennet Ph.)',
	'Valdecoxib',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSRA 10 (Bennet Ph.)'
);

-- line #30586
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSRA 20 (Bennet Ph.)',
	'Valdecoxib',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSRA 20 (Bennet Ph.)'
);

-- line #30587
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OVAL 20 (Cubit Hc.)',
	'Valdecoxib',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OVAL 20 (Cubit Hc.)'
);

-- line #30588
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POWERCOXIB 20 (Jenburkt)',
	'Valdecoxib',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POWERCOXIB 20 (Jenburkt)'
);

-- line #30589
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Valdecoxib', u'always_empty': u'', u'form': u'GEL', u'brand': u'REVALDO', u'strength_3': u'', u'company': u'Zydus Cadila', u'unit': u''}

-- line #30590
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REVALDO QR 40 (Zydus Cadila)',
	'Valdecoxib',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REVALDO QR 40 (Zydus Cadila)'
);

-- line #30591
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REVALDO 10 (Zydus Cadila)',
	'Valdecoxib',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REVALDO 10 (Zydus Cadila)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REVALDO 20 (Zydus Cadila)',
	'Valdecoxib',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REVALDO 20 (Zydus Cadila)'
);

-- line #30592
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'VALERIAN', u'always_empty': u'', u'form': u'TAB', u'brand': u'NATURBOTIC', u'strength_3': u'', u'company': u"KOLSON''S", u'unit': u''}

-- line #30593
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPIDOSIN 8 (Ttk Hc.)',
	'VALETHAMATE',
	'INJ',
	gm.nullify_empty_string('8')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPIDOSIN 8 (Ttk Hc.)'
);

-- line #30594
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPIDOSIN 10 (Ttk Hc.)',
	'Valethamate',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPIDOSIN 10 (Ttk Hc.)'
);

-- line #30595
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Valethamate', u'always_empty': u'', u'form': u'INJ', u'brand': u'GARDIN', u'strength_3': u'', u'company': u'Destin Lab', u'unit': u''}

-- line #30596
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OSDIL 8 (Troikaa)',
	'Valethamate',
	'INJ',
	gm.nullify_empty_string('8')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OSDIL 8 (Troikaa)'
);

-- line #30597
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENCORATE 100 (Sun)',
	'Valproate',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENCORATE 100 (Sun)'
);

-- line #30598
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENCORATE 200 (Sun)',
	'Valproate',
	'SYR',
	gm.nullify_empty_string('200')::numeric,
	'mg/5 ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENCORATE 200 (Sun)'
);

-- line #30599
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENCORATE 300 (Sun)',
	'Valproate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENCORATE 300 (Sun)'
);

-- line #30600
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENCORATE 500 (Sun)',
	'Valproate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENCORATE 500 (Sun)'
);

-- line #30601
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPILEX 200 (ABBOTT)',
	'Valproate',
	'SYR',
	gm.nullify_empty_string('200')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPILEX 200 (ABBOTT)'
);

-- line #30602
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPILEX 200 (ABBOTT)',
	'Valproate',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'500'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPILEX 200 (ABBOTT)'
);

-- line #30603
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIOVAN 80 (Novartis)',
	'Valsartan',
	'CAP',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIOVAN 80 (Novartis)'
);

-- line #30604
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIOVAN 160 (Novartis)',
	'Valsartan',
	'TAB',
	gm.nullify_empty_string('160')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIOVAN 160 (Novartis)'
);

-- line #30605
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIOVAN 40 (Novartis)',
	'Valsartan',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIOVAN 40 (Novartis)'
);

-- line #30606
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIOVAN 80 (Novartis)',
	'Valsartan',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIOVAN 80 (Novartis)'
);

-- line #30607
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COVANC 500 (NUCLEUS  INC.)',
	'Vancomycin',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COVANC 500 (NUCLEUS  INC.)'
);

-- line #30608
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYTOVAN 500 (Alkem)',
	'Vancomycin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYTOVAN 500 (Alkem)'
);

-- line #30609
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FORSTAF 500 (Gsk)',
	'Vancomycin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FORSTAF 500 (Gsk)'
);

-- line #30610
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'G-VANC 500 (Gland Ph.)',
	'Vancomycin',
	'VIAL',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'G-VANC 500 (Gland Ph.)'
);

-- line #30611
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LOCKMYCIN 500 (Samarth Life)',
	'Vancomycin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LOCKMYCIN 500 (Samarth Life)'
);

-- line #30612
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1GM', u'strength_2': u'', u'substance': u'Vancomycin', u'always_empty': u'', u'form': u'INJ', u'brand': u'MEGO GM', u'strength_3': u'', u'company': u'Gufic Bio.', u'unit': u''}

-- line #30613
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MEGO 500 (Gufic Bio.)',
	'Vancomycin',
	'INJ',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MEGO 500 (Gufic Bio.)'
);

-- line #30614
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CHMPIX 1 (Pfizer)',
	'VARENICLINE',
	'TAB',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CHMPIX 1 (Pfizer)'
);

-- line #30615
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000PFU', u'strength_2': u'DOSE', u'substance': u'Varicella (Chikenpox) Vaccine', u'always_empty': u'', u'form': u'VAC', u'brand': u'OKAVAX', u'strength_3': u'', u'company': u'Aventis Pas.', u'unit': u''}

-- line #30616
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10U', u'strength_2': u'ML', u'substance': u'Vasopressin', u'always_empty': u'', u'form': u'INJ', u'brand': u'CPRESSIN -P', u'strength_3': u'', u'company': u'Samarth Life', u'unit': u''}

-- line #30617
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20U.', u'strength_2': u'', u'substance': u'Vasopressin', u'always_empty': u'', u'form': u'INJ', u'brand': u'CPRESSIN-P -U', u'strength_3': u'', u'company': u'Samarth LIFE', u'unit': u''}

-- line #30618
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'40U.', u'strength_2': u'', u'substance': u'Vasopressin', u'always_empty': u'', u'form': u'INJ', u'brand': u'CPRESSIN -U', u'strength_3': u'', u'company': u'Samarth LIFE', u'unit': u''}

-- line #30619
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20U.', u'strength_2': u'', u'substance': u'Vasopressin', u'always_empty': u'', u'form': u'AMP', u'brand': u'PETRESIN', u'strength_3': u'', u'company': u'SG PH.', u'unit': u''}

-- line #30620
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLEXIVEC 10 (Bharat S.)',
	'Vecuronium',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLEXIVEC 10 (Bharat S.)'
);

-- line #30621
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLEXIVEC 4 (Bharat S.)',
	'Vecuronium',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLEXIVEC 4 (Bharat S.)'
);

-- line #30622
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GERVEC 10 (German R.)',
	'Vecuronium',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GERVEC 10 (German R.)'
);

-- line #30623
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GERVEC 4 (German R.)',
	'Vecuronium',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GERVEC 4 (German R.)'
);

-- line #30624
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYVEC 10 (Lyka)',
	'Vecuronium',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYVEC 10 (Lyka)'
);

-- line #30625
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYVEC 4 (LYKA LABS)',
	'Vecuronium',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYVEC 4 (LYKA LABS)'
);

-- line #30626
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOVAC 4 (Neon)',
	'Vecuronium',
	'AMP',
	gm.nullify_empty_string('4')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOVAC 4 (Neon)'
);

-- line #30627
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOVAC 10 (Neon)',
	'Vecuronium',
	'VIAL',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOVAC 10 (Neon)'
);

-- line #30628
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOVEC 20 (Neon)',
	'Vecuronium',
	'INJ',
	gm.nullify_empty_string('20')::numeric,
	'mg(MANNITOL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOVEC 20 (Neon)'
);

-- line #30629
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOVEC 4 (Neon)',
	'Vecuronium',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOVEC 4 (Neon)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOVEC 10 (Neon)',
	'Vecuronium',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOVEC 10 (Neon)'
);

-- line #30630
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NORCURON 4 (Infar)',
	'Vecuronium',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NORCURON 4 (Infar)'
);

-- line #30631
-- ignoring line: field [strength_1] not numeric: >>>33(EQ. TO CELLULASES & HEMICELLULASES ACTIVITY OF 6<<<
-- {u'list_of_values_of_unknown_fields': [u' mg)', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'33(EQ. TO CELLULASES & HEMICELLULASES ACTIVITY OF 6', u'strength_2': u'', u'substance': u'VEGETABLE ENZYMES', u'always_empty': u'', u'form': u'TAB', u'brand': u'DISPEPTAL', u'strength_3': u'', u'company': u'Nicholas', u'unit': u'BILE SALTS 25'}

-- line #30632
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DALIUM 25 (Nicholas)',
	'Venlafaxine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DALIUM 25 (Nicholas)'
);

-- line #30633
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DALIUM 37.5 (Nicholas)',
	'Venlafaxine',
	'TAB',
	gm.nullify_empty_string('37.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DALIUM 37.5 (Nicholas)'
);

-- line #30634
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DALIUM 75 (Nicholas)',
	'Venlafaxine',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DALIUM 75 (Nicholas)'
);

-- line #30635
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENVELAF 150 (Pentacare)',
	'Venlafaxine',
	'XR CAP',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENVELAF 150 (Pentacare)'
);

-- line #30636
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENVELAF 37.5 (Pentacare)',
	'Venlafaxine',
	'XR CAP',
	gm.nullify_empty_string('37.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENVELAF 37.5 (Pentacare)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ENVELAF 75 (Pentacare)',
	'Venlafaxine',
	'XR CAP',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ENVELAF 75 (Pentacare)'
);

-- line #30637
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAXINE 37.5 (Theo Ph.)',
	'Venlafaxine',
	'XR TAB',
	gm.nullify_empty_string('37.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAXINE 37.5 (Theo Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAXINE 75 (Theo Ph.)',
	'Venlafaxine',
	'XR TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAXINE 75 (Theo Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAXINE 150 (Theo Ph.)',
	'Venlafaxine',
	'XR TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAXINE 150 (Theo Ph.)'
);

-- line #30638
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAXIVEN 37.5 (Triton Hc.)',
	'Venlafaxine',
	'XR TAB',
	gm.nullify_empty_string('37.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAXIVEN 37.5 (Triton Hc.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FAXIVEN 75 (Triton Hc.)',
	'Venlafaxine',
	'XR TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FAXIVEN 75 (Triton Hc.)'
);

-- line #30639
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLAVIX 25 (Merind)',
	'Venlafaxine',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLAVIX 25 (Merind)'
);

-- line #30640
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLAVIX 37.5 (Merind)',
	'Venlafaxine',
	'TAB',
	gm.nullify_empty_string('37.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLAVIX 37.5 (Merind)'
);

-- line #30641
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLAVIX 75 (Merind)',
	'Venlafaxine',
	'TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLAVIX 75 (Merind)'
);

-- line #30642
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLAVIX 37.5 (Merind)',
	'Venlafaxine',
	'XR TAB',
	gm.nullify_empty_string('37.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLAVIX 37.5 (Merind)'
);

-- line #30643
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'FLAVIX 75 (Merind)',
	'Venlafaxine',
	'XR TAB',
	gm.nullify_empty_string('75')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'FLAVIX 75 (Merind)'
);

-- line #30644
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALAPTIN 2.5 (Piramal Hc.)',
	'Verapamil Hcl.',
	'AMP',
	gm.nullify_empty_string('2.5')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALAPTIN 2.5 (Piramal Hc.)'
);

-- line #30645
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALAPTIN 120 (Piramal Hc.)',
	'Verapamil Hcl.',
	'SR TAB',
	gm.nullify_empty_string('120')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALAPTIN 120 (Piramal Hc.)'
);

-- line #30646
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALAPTIN 240 (Piramal Hc.)',
	'Verapamil Hcl.',
	'SR TAB',
	gm.nullify_empty_string('240')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALAPTIN 240 (Piramal Hc.)'
);

-- line #30647
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALAPTIN 40 (Piramal Hc.)',
	'Verapamil Hcl.',
	'TAB',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALAPTIN 40 (Piramal Hc.)'
);

-- line #30648
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CALAPTIN 80 (Piramal Hc.)',
	'Verapamil Hcl.',
	'TAB',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CALAPTIN 80 (Piramal Hc.)'
);

-- line #30649
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CELOVERA 5 (CELON(REVILON))',
	'Verapamil Hcl.',
	'AMP',
	gm.nullify_empty_string('5')::numeric,
	'mg/2ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CELOVERA 5 (CELON(REVILON))'
);

-- line #30650
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50', u'strength_2': u'', u'substance': u'VILDAGLIPTIN', u'always_empty': u'', u'form': u'', u'brand': u'JALRA', u'strength_3': u'', u'company': u'USV CONDOR', u'unit': u'mg'}

-- line #30651
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CYTOBLASTIN 10 (Cipla)',
	'Vinblastine',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg/10ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CYTOBLASTIN 10 (Cipla)'
);

-- line #30652
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALCRIST 1 (Cytomed(Alkem))',
	'VINCRISTINE',
	'VIAL',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALCRIST 1 (Cytomed(Alkem))'
);

-- line #30653
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOCRISTIN AQ 1 (Biochem)',
	'VINCRISTINE',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOCRISTIN AQ 1 (Biochem)'
);

-- line #30654
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BIOCRISTINE 1 (Biochem)',
	'Vincristine',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BIOCRISTINE 1 (Biochem)'
);

-- line #30655
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEOCRISTIN 1 (Gsk)',
	'Vincristine',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEOCRISTIN 1 (Gsk)'
);

-- line #30656
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ONCOCRISTIN-AQ 1 (Sun)',
	'Vincristine',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ONCOCRISTIN-AQ 1 (Sun)'
);

-- line #30657
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELBOVIN 10 (MIRACALUS)',
	'Vinorelbine',
	'VIAL',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELBOVIN 10 (MIRACALUS)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RELBOVIN 50 (MIRACALUS)',
	'Vinorelbine',
	'VIAL',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RELBOVIN 50 (MIRACALUS)'
);

-- line #30658
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COGNITOL 5 5 (Sun)',
	'VINPOCETINE 5 MG',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COGNITOL 5 5 (Sun)'
);

-- line #30659
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEUROVIN 5 (Micro Labs)',
	'VINPOCETINE',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEUROVIN 5 (Micro Labs)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NEUROVIN 10 (Micro Labs)',
	'VINPOCETINE',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NEUROVIN 10 (Micro Labs)'
);

-- line #30660
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50000IU.', u'strength_2': u'', u'substance': u'Vit.A', u'always_empty': u'', u'form': u'CAP', u'brand': u'AQUASOL-A', u'strength_3': u'', u'company': u'Lifeon', u'unit': u''}

-- line #30661
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50000IU.', u'strength_2': u'ML', u'substance': u'Vit.A', u'always_empty': u'', u'form': u'', u'brand': u'AQUASOL-A (PAR.)INJ.', u'strength_3': u'', u'company': u'U S V', u'unit': u''}

-- line #30662
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AROCAP 50 (Pil)',
	'Vit.A',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'000I.U.'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AROCAP 50 (Pil)'
);

-- line #30663
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'150000IU.', u'strength_2': u'ML', u'substance': u'Vit.A', u'always_empty': u'', u'form': u'DROP', u'brand': u'AROVIT', u'strength_3': u'', u'company': u'Piramal Hc.', u'unit': u''}

-- line #30664
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100000IU.', u'strength_2': u'ML', u'substance': u'Vit.A', u'always_empty': u'', u'form': u'INJ.', u'brand': u'AROVIT', u'strength_3': u'', u'company': u'Piramal Hc.', u'unit': u''}

-- line #30665
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50000IU.', u'strength_2': u'', u'substance': u'Vit.A', u'always_empty': u'', u'form': u'CAP', u'brand': u'A-VIT', u'strength_3': u'', u'company': u'Medicamen', u'unit': u''}

-- line #30666
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1500IU.(AS PALMITATE)', u'strength_2': u'', u'substance': u'Vit.A', u'always_empty': u'', u'form': u'LOT', u'brand': u'LIPO', u'strength_3': u'', u'company': u'Elder', u'unit': u''}

-- line #30667
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'VITAMIN B. COMPLEX', u'always_empty': u'', u'form': u'CAP', u'brand': u'BECOFINE', u'strength_3': u'', u'company': u'Finecure', u'unit': u''}

-- line #30668
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'VITAMIN B. COMPLEX', u'always_empty': u'', u'form': u'DPS', u'brand': u'NEUROBEX', u'strength_3': u'', u'company': u'Ind-Swift', u'unit': u''}

-- line #30669
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'50MCG', u'strength_2': u'', u'substance': u'VITAMIN K2-7', u'always_empty': u'', u'form': u'TAB', u'brand': u'KVION (VITAMIN K2-7', u'strength_3': u'', u'company': u'J.B. CHEM', u'unit': u''}

-- line #30670
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000MCG', u'strength_2': u'ML', u'substance': u'Vit.B12', u'always_empty': u'', u'form': u'INJ', u'brand': u'INGAVIT B12', u'strength_3': u'', u'company': u'Inga', u'unit': u''}

-- line #30671
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'ML', u'substance': u'Vit.B12', u'always_empty': u'', u'form': u'V', u'brand': u'INGAVIT B12', u'strength_3': u'', u'company': u'Inga', u'unit': u''}

-- line #30672
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000MCG', u'strength_2': u'ML', u'substance': u'Vit.B12', u'always_empty': u'', u'form': u'INJ', u'brand': u'MACRABIN', u'strength_3': u'', u'company': u'Gsk', u'unit': u''}

-- line #30673
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'500MCG', u'strength_2': u'', u'substance': u'Vit.B12', u'always_empty': u'', u'form': u'INJ', u'brand': u'MACRABIN', u'strength_3': u'', u'company': u'Gsk', u'unit': u''}

-- line #30674
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'12', u'strength_2': u'ML(PROTEOLYSED LIVER EXT.DERIVED FROM 62.5G OF FRESH LIVER HAVING VIT.B12 ACTIVITY)', u'substance': u'VIT.B12', u'always_empty': u'', u'form': u'INJ', u'brand': u'NEO-HEPATEX', u'strength_3': u'', u'company': u'Biological E.', u'unit': u''}

-- line #30675
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'12', u'strength_2': u'ML(PROTEOLYSED LIVER EXT.DERIVED FROM 62.5G OF FRESH LIVER HAVING VIT.B12 ACTIVITY)', u'substance': u'VIT.B12', u'always_empty': u'', u'form': u'VIAL', u'brand': u'NEO-HEPATEX', u'strength_3': u'', u'company': u'Biological E.', u'unit': u''}

-- line #30676
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RIBOFLAVINE 10 (Shreya)',
	'VIT.B2',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RIBOFLAVINE 10 (Shreya)'
);

-- line #30677
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'30000IU.', u'strength_2': u'60000IU.', u'substance': u'Vit.D3', u'always_empty': u'', u'form': u'INJ', u'brand': u'ARACHITOL', u'strength_3': u'', u'company': u'Solvay Ph.', u'unit': u''}

-- line #30678
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'60000IU', u'strength_2': u'SAC', u'substance': u'Vit.D3', u'always_empty': u'', u'form': u'SAC', u'brand': u'CALCIROL', u'strength_3': u'', u'company': u'Cadila Ph.', u'unit': u''}

-- line #30679
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3', u'strength_2': u'6;LAC U.', u'substance': u'Vit.D3', u'always_empty': u'', u'form': u'INJ', u'brand': u'DURACAL', u'strength_3': u'', u'company': u'Ultramark', u'unit': u''}

-- line #30680
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3000IU', u'strength_2': u'', u'substance': u'VIT.D3', u'always_empty': u'', u'form': u'DROPS', u'brand': u'DVITAL', u'strength_3': u'', u'company': u'Astrum Hc.', u'unit': u''}

-- line #30681
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'1000IU', u'strength_2': u'', u'substance': u'VIT.D3', u'always_empty': u'', u'form': u'TAB', u'brand': u'DVITAL', u'strength_3': u'', u'company': u'Astrum Hc.', u'unit': u''}

-- line #30682
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'3 LAC IU.', u'strength_2': u'', u'substance': u'Vit.D3', u'always_empty': u'', u'form': u'INJ', u'brand': u'RADIX-D3', u'strength_3': u'', u'company': u'Radix Bio.', u'unit': u''}

-- line #30683
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'6 LAC IU.', u'strength_2': u'', u'substance': u'Vit.D3', u'always_empty': u'', u'form': u'INJ', u'brand': u'RADIX-D6', u'strength_3': u'', u'company': u'Radix Bio.', u'unit': u''}

-- line #30684
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Vit.E', u'always_empty': u'', u'form': u'CRM 60GM', u'brand': u'ELOVERA', u'strength_3': u'', u'company': u'Glenmark', u'unit': u''}

-- line #30685
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200IU.', u'strength_2': u'', u'substance': u'Vit.E(Tocopherol)', u'always_empty': u'', u'form': u'CAP', u'brand': u'BIO-8888', u'strength_3': u'', u'company': u"Dr.Reddy''S", u'unit': u''}

-- line #30686
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100', u'strength_2': u'200;IU', u'substance': u'Vit.E(Tocopherol)', u'always_empty': u'', u'form': u'CAP', u'brand': u'BIO-E', u'strength_3': u'', u'company': u"Dr.Reddy''S", u'unit': u''}

-- line #30687
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200IU.', u'strength_2': u'', u'substance': u'Vit.E(Tocopherol)', u'always_empty': u'', u'form': u'CAP', u'brand': u'BIO-E', u'strength_3': u'', u'company': u"Dr.Reddy''S", u'unit': u''}

-- line #30688
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'400IU.', u'strength_2': u'', u'substance': u'Vit.E(Tocopherol)', u'always_empty': u'', u'form': u'CAP', u'brand': u'BIO-E', u'strength_3': u'', u'company': u"Dr.Reddy''S", u'unit': u''}

-- line #30689
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COVITA 100 (U S V)',
	'Vit.E(Tocopherol)',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COVITA 100 (U S V)'
);

-- line #30690
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COVITA 200 (U S V)',
	'Vit.E(Tocopherol)',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COVITA 200 (U S V)'
);

-- line #30691
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COVITA 400 (U S V)',
	'Vit.E(Tocopherol)',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COVITA 400 (U S V)'
);

-- line #30692
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'E 200 (Glenmark)',
	'Vit.E(Tocopherol)',
	'CAP CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'E 200 (Glenmark)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'E 400 (Glenmark)',
	'Vit.E(Tocopherol)',
	'CAP CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'E 400 (Glenmark)'
);

-- line #30693
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ECAP 200 (Glenmark)',
	'Vit.E(Tocopherol)',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg/400'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ECAP 200 (Glenmark)'
);

-- line #30694
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'E CARE 200 (Guj. Liq.)',
	'Vit.E(Tocopherol)',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg(ACET.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'E CARE 200 (Guj. Liq.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'E CARE 400 (Guj. Liq.)',
	'Vit.E(Tocopherol)',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg(ACET.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'E CARE 400 (Guj. Liq.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'E CARE 600 (Guj. Liq.)',
	'Vit.E(Tocopherol)',
	'CAP',
	gm.nullify_empty_string('600')::numeric,
	'mg(ACET.)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'E CARE 600 (Guj. Liq.)'
);

-- line #30695
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EDGE 200 (Elder)',
	'Vit.E(Tocopherol)',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg(NATURAL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EDGE 200 (Elder)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EDGE 400 (Elder)',
	'Vit.E(Tocopherol)',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg(NATURAL)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EDGE 400 (Elder)'
);

-- line #30696
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EEE 200 (Cadila Ph.)',
	'Vit.E(Tocopherol)',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EEE 200 (Cadila Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EEE 400 (Cadila Ph.)',
	'Vit.E(Tocopherol)',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EEE 400 (Cadila Ph.)'
);

-- line #30697
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200', u'strength_2': u'400;IU', u'substance': u'Vit.E(Tocopherol)', u'always_empty': u'', u'form': u'CAP', u'brand': u'ENSULES', u'strength_3': u'', u'company': u'Macleods', u'unit': u''}

-- line #30698
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPHYNAL 200 (Nicholas)',
	'Vit.E(Tocopherol)',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPHYNAL 200 (Nicholas)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPHYNAL 400 (Nicholas)',
	'Vit.E(Tocopherol)',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPHYNAL 400 (Nicholas)'
);

-- line #30699
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EROVIT 400 (Royal Lab)',
	'Vit.E(Tocopherol)',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EROVIT 400 (Royal Lab)'
);

-- line #30700
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETOPLEX 200 (U S V)',
	'Vit.E(Tocopherol)',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETOPLEX 200 (U S V)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ETOPLEX 400 (U S V)',
	'Vit.E(Tocopherol)',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ETOPLEX 400 (U S V)'
);

-- line #30701
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EVION 1 (Merck)',
	'Vit.E(Tocopherol)',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'5'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EVION 1 (Merck)'
);

-- line #30702
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EVION 50 (Merck)',
	'Vit.E(Tocopherol)',
	'DPS',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EVION 50 (Merck)'
);

-- line #30703
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100', u'strength_2': u'', u'substance': u'Vit.E(Tocopherol)', u'always_empty': u'', u'form': u'', u'brand': u'EVION PEARLS', u'strength_3': u'', u'company': u'Merck', u'unit': u'mg'}

-- line #30704
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200', u'strength_2': u'', u'substance': u'Vit.E(Tocopherol)', u'always_empty': u'', u'form': u'', u'brand': u'EVION PEARLS', u'strength_3': u'', u'company': u'Merck', u'unit': u'mg'}

-- line #30705
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'400', u'strength_2': u'', u'substance': u'Vit.E(Tocopherol)', u'always_empty': u'', u'form': u'', u'brand': u'EVION PEARLS', u'strength_3': u'', u'company': u'Merck', u'unit': u'mg'}

-- line #30706
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'600', u'strength_2': u'', u'substance': u'Vit.E(Tocopherol)', u'always_empty': u'', u'form': u'', u'brand': u'EVION PEARLS', u'strength_3': u'', u'company': u'Merck', u'unit': u'mg'}

-- line #30707
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EVITAM 200 (Cipla)',
	'Vit.E(Tocopherol)',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EVITAM 200 (Cipla)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EVITAM 400 (Cipla)',
	'Vit.E(Tocopherol)',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EVITAM 400 (Cipla)'
);

-- line #30708
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EVIT 200 (Abbott)',
	'Vit.E(Tocopherol)',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EVIT 200 (Abbott)'
);

-- line #30709
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EVIT 400 (Abbott)',
	'Vit.E(Tocopherol)',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EVIT 400 (Abbott)'
);

-- line #30710
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EVITOL 200 (Pharmacia)',
	'Vit.E(Tocopherol)',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EVITOL 200 (Pharmacia)'
);

-- line #30711
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EVITOP-400 400 (Ind-Swift)',
	'Vit.E(Tocopherol)',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EVITOP-400 400 (Ind-Swift)'
);

-- line #30712
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLYVION 200 (Globus)',
	'Vit.E(Tocopherol)',
	'CAP',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLYVION 200 (Globus)'
);

-- line #30713
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100IU', u'strength_2': u'', u'substance': u'Vit.E(Tocopherol)', u'always_empty': u'', u'form': u'CAP', u'brand': u'MONOVIT EN', u'strength_3': u'', u'company': u'Mano Ph.', u'unit': u''}

-- line #30714
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200', u'strength_2': u'400;IU', u'substance': u'Vit.E(Tocopherol)', u'always_empty': u'', u'form': u'CAP', u'brand': u'MONOVIT EN', u'strength_3': u'', u'company': u'Mano Ph.', u'unit': u''}

-- line #30715
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100IU.', u'strength_2': u'', u'substance': u'Vit.E(Tocopherol)', u'always_empty': u'', u'form': u'CAP', u'brand': u'NATVIE', u'strength_3': u'', u'company': u'Franco I.', u'unit': u''}

-- line #30716
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200IU.', u'strength_2': u'', u'substance': u'Vit.E(Tocopherol)', u'always_empty': u'', u'form': u'CAP', u'brand': u'NATVIE', u'strength_3': u'', u'company': u'Franco I.', u'unit': u''}

-- line #30717
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'400IU.', u'strength_2': u'', u'substance': u'Vit.E(Tocopherol)', u'always_empty': u'', u'form': u'CAP', u'brand': u'NATVIE', u'strength_3': u'', u'company': u'Franco I.', u'unit': u''}

-- line #30718
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200IU.', u'strength_2': u'400IU.', u'substance': u'Vit.E(Tocopherol)', u'always_empty': u'', u'form': u'CAP', u'brand': u'NE-200/400', u'strength_3': u'', u'company': u'Cachet', u'unit': u''}

-- line #30719
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'200IU.', u'strength_2': u'', u'substance': u'Vit.E(Tocopherol)', u'always_empty': u'', u'form': u'CAP', u'brand': u'NE-200', u'strength_3': u'', u'company': u'Cachet', u'unit': u''}

-- line #30720
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'400IU.', u'strength_2': u'', u'substance': u'Vit.E(Tocopherol)', u'always_empty': u'', u'form': u'CAP', u'brand': u'NE-400', u'strength_3': u'', u'company': u'Cachet', u'unit': u''}

-- line #30721
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'750MCG(VIT.K2)', u'strength_2': u'', u'substance': u'VIT.K', u'always_empty': u'', u'form': u'TAB', u'brand': u'KARDIVIN', u'strength_3': u'', u'company': u'Themis Med.', u'unit': u''}

-- line #30722
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'K-ONE 5 (DELVIN)',
	'VIT.K',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'K-ONE 5 (DELVIN)'
);

-- line #30723
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KVI 1 (DEWCARE)',
	'VIT.K',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KVI 1 (DEWCARE)'
);

-- line #30724
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'750MCG(VIT.K2)', u'strength_2': u'', u'substance': u'VIT.K', u'always_empty': u'', u'form': u'TAB', u'brand': u'MENAQ', u'strength_3': u'', u'company': u'OSTEOLIFE', u'unit': u''}

-- line #30725
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHYTO-K1 10MG 10 (DELVIN)',
	'VIT.K',
	'INJ',
	gm.nullify_empty_string('10')::numeric,
	'mg/ML(VIT.K1)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHYTO-K1 10MG 10 (DELVIN)'
);

-- line #30726
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PHYTO-K1 1MG 1 (DELVIN)',
	'VIT.K',
	'INJ',
	gm.nullify_empty_string('1')::numeric,
	'mg/ML(VIT.K1)'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PHYTO-K1 1MG 1 (DELVIN)'
);

-- line #30727
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADVOG 0.2 (ERIS THER.)',
	'VOGLIBOSE',
	'TAB',
	gm.nullify_empty_string('0.2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADVOG 0.2 (ERIS THER.)'
);

-- line #30728
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ADVOG 0.3 (ERIS THER.)',
	'VOGLIBOSE',
	'TAB',
	gm.nullify_empty_string('0.3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ADVOG 0.3 (ERIS THER.)'
);

-- line #30729
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASVOGLI 0.2 (AS PHARMA)',
	'VOGLIBOSE',
	'TAB',
	gm.nullify_empty_string('0.2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASVOGLI 0.2 (AS PHARMA)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASVOGLI 0.3 (AS PHARMA)',
	'VOGLIBOSE',
	'TAB',
	gm.nullify_empty_string('0.3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASVOGLI 0.3 (AS PHARMA)'
);

-- line #30730
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'D BOSE 0.2 (SINSAN PH.)',
	'VOGLIBOSE',
	'TAB',
	gm.nullify_empty_string('0.2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'D BOSE 0.2 (SINSAN PH.)'
);

-- line #30731
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'D BOSE 0.3 (SINSAN PH.)',
	'VOGLIBOSE',
	'TAB',
	gm.nullify_empty_string('0.3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'D BOSE 0.3 (SINSAN PH.)'
);

-- line #30732
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIBOSET 0.2 (Alkem)',
	'VOGLIBOSE',
	'MD',
	gm.nullify_empty_string('0.2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIBOSET 0.2 (Alkem)'
);

-- line #30733
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIBOSET 0.3 (Alkem)',
	'VOGLIBOSE',
	'MD',
	gm.nullify_empty_string('0.3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIBOSET 0.3 (Alkem)'
);

-- line #30734
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIBOSET 0.2 (Alkem)',
	'VOGLIBOSE',
	'TAB',
	gm.nullify_empty_string('0.2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIBOSET 0.2 (Alkem)'
);

-- line #30735
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DIBOSET 0.3 (Alkem)',
	'VOGLIBOSE',
	'TAB',
	gm.nullify_empty_string('0.3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DIBOSET 0.3 (Alkem)'
);

-- line #30736
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUCOCUT 0.2 (Troikaa)',
	'VOGLIBOSE',
	'TAB',
	gm.nullify_empty_string('0.2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUCOCUT 0.2 (Troikaa)'
);

-- line #30737
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GLUCOCUT 0.3 (Troikaa)',
	'VOGLIBOSE',
	'TAB',
	gm.nullify_empty_string('0.3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GLUCOCUT 0.3 (Troikaa)'
);

-- line #30738
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'I-BOSE 0.2 (INNOVA LIFESCI.)',
	'VOGLIBOSE',
	'TAB',
	gm.nullify_empty_string('0.2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'I-BOSE 0.2 (INNOVA LIFESCI.)'
);

-- line #30739
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'I-BOSE 0.3 (INNOVA LIFESCI.)',
	'VOGLIBOSE',
	'TAB',
	gm.nullify_empty_string('0.3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'I-BOSE 0.3 (INNOVA LIFESCI.)'
);

-- line #30740
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'K-VOG 0.2 (Blue Cross)',
	'VOGLIBOSE',
	'TAB',
	gm.nullify_empty_string('0.2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'K-VOG 0.2 (Blue Cross)'
);

-- line #30741
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'K-VOG 0.3 (Blue Cross)',
	'VOGLIBOSE',
	'TAB',
	gm.nullify_empty_string('0.3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'K-VOG 0.3 (Blue Cross)'
);

-- line #30742
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OGLIBO 0.2 (Panacea)',
	'VOGLIBOSE',
	'MD TAB',
	gm.nullify_empty_string('0.2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OGLIBO 0.2 (Panacea)'
);

-- line #30743
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OGLIBO 0.3 (Panacea)',
	'VOGLIBOSE',
	'MD TAB',
	gm.nullify_empty_string('0.3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OGLIBO 0.3 (Panacea)'
);

-- line #30744
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POSEMEAL 0.2 (Unichem)',
	'VOGLIBOSE',
	'MD TAB',
	gm.nullify_empty_string('0.2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POSEMEAL 0.2 (Unichem)'
);

-- line #30745
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POSEMEAL 0.3 (Unichem)',
	'VOGLIBOSE',
	'MD TAB',
	gm.nullify_empty_string('0.3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POSEMEAL 0.3 (Unichem)'
);

-- line #30746
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POSMEAL 0.2 (Unichem)',
	'VOGLIBOSE',
	'TAB',
	gm.nullify_empty_string('0.2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POSMEAL 0.2 (Unichem)'
);

-- line #30747
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'POSMEAL 0.3 (Unichem)',
	'VOGLIBOSE',
	'TAB',
	gm.nullify_empty_string('0.3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'POSMEAL 0.3 (Unichem)'
);

-- line #30748
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PPG 0.2 (Piramal Hc.)',
	'VOGLIBOSE',
	'TAB',
	gm.nullify_empty_string('0.2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PPG 0.2 (Piramal Hc.)'
);

-- line #30749
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PPG 0.3 (Piramal Hc.)',
	'VOGLIBOSE',
	'TAB',
	gm.nullify_empty_string('0.3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PPG 0.3 (Piramal Hc.)'
);

-- line #30750
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRANDIAL 0.2 (Cipla)',
	'VOGLIBOSE',
	'MD',
	gm.nullify_empty_string('0.2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRANDIAL 0.2 (Cipla)'
);

-- line #30751
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PRANDIAL 0.3 (Cipla)',
	'VOGLIBOSE',
	'MD',
	gm.nullify_empty_string('0.3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PRANDIAL 0.3 (Cipla)'
);

-- line #30752
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREVOG 0.2 (Zydus cnd)',
	'VOGLIBOSE',
	'TAB',
	gm.nullify_empty_string('0.2')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREVOG 0.2 (Zydus cnd)'
);

-- line #30753
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PREVOG 0.3 (Zydus cnd)',
	'VOGLIBOSE',
	'TAB',
	gm.nullify_empty_string('0.3')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PREVOG 0.3 (Zydus cnd)'
);

-- line #30754
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REXTRO 200 (DR. REDDY''S)',
	'VORICONAZOLE',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REXTRO 200 (DR. REDDY''S)'
);

-- line #30755
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REXTRO 200 (DR. REDDY''S)',
	'VORICONAZOLE',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REXTRO 200 (DR. REDDY''S)'
);

-- line #30756
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REXTRO 50 (DR. REDDY''S)',
	'VORICONAZOLE',
	'TAB',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REXTRO 50 (DR. REDDY''S)'
);

-- line #30757
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'100', u'strength_2': u'', u'substance': u'WHEAT DEXTRIN', u'always_empty': u'', u'form': u'', u'brand': u'BENEFIBER', u'strength_3': u'', u'company': u'Novartis', u'unit': u'%'}

-- line #30758
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPAD 400 (Tripada BIO.)',
	'WHEAT GERM OIL',
	'CAP',
	gm.nullify_empty_string('400')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPAD 400 (Tripada BIO.)'
);

-- line #30759
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'61', u'strength_2': u'', u'substance': u'WHEY PROTEIN', u'always_empty': u'', u'form': u'', u'brand': u'RALISH TIN', u'strength_3': u'', u'company': u'Profic', u'unit': u'%'}

-- line #30760
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'20', u'strength_2': u'', u'substance': u'WRIGHTIA', u'always_empty': u'', u'form': u'', u'brand': u'EPIDERMEND', u'strength_3': u'', u'company': u'Grandix', u'unit': u'%W/W'}

-- line #30761
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CERVAS 150 (Mano)',
	'Xanthinol Nicotinate',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CERVAS 150 (Mano)'
);

-- line #30762
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COMPLAMINA 150 (German R.)',
	'Xanthinol Nicotinate',
	'INJ',
	gm.nullify_empty_string('150')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COMPLAMINA 150 (German R.)'
);

-- line #30763
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COMPLAMINA RETARD 500 (German R.)',
	'Xanthinol Nicotinate',
	'TAB',
	gm.nullify_empty_string('500')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COMPLAMINA RETARD 500 (German R.)'
);

-- line #30764
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COMPLAMINA 150 (German R.)',
	'Xanthinol Nicotinate',
	'TAB',
	gm.nullify_empty_string('150')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COMPLAMINA 150 (German R.)'
);

-- line #30765
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'COMPLAMINA 300 (German R.)',
	'Xanthinol Nicotinate',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'COMPLAMINA 300 (German R.)'
);

-- line #30766
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ACOLATE 0.1 (GUJ. TE.)',
	'Xylometazoline Hcl.',
	'DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'% W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ACOLATE 0.1 (GUJ. TE.)'
);

-- line #30767
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATROVIN 0.1 (Admac Ph.)',
	'Xylometazoline Hcl.',
	'DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATROVIN 0.1 (Admac Ph.)'
);

-- line #30768
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATROVIN 0.65 (Admac Ph.)',
	'Xylometazoline Hcl.',
	'DPS',
	gm.nullify_empty_string('0.65')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATROVIN 0.65 (Admac Ph.)'
);

-- line #30769
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ATROVIN-P 0.05 (Admac Ph.)',
	'Xylometazoline Hcl.',
	'DPS',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ATROVIN-P 0.05 (Admac Ph.)'
);

-- line #30770
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLEARNOZ % NASAL 0.05 (Cipla)',
	'Xylometazoline Hcl.',
	'DPS',
	gm.nullify_empty_string('0.05')::numeric,
	'% (NF CHLORIDE 0.01'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLEARNOZ % NASAL 0.05 (Cipla)'
);

-- line #30771
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLEARNOZ % NASAL 0.1 (Cipla)',
	'Xylometazoline Hcl.',
	'DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'% (NF CHLORIDE 0.01'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLEARNOZ % NASAL 0.1 (Cipla)'
);

-- line #30772
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CORIVIN 0.1 (Olcare)',
	'Xylometazoline Hcl.',
	'DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CORIVIN 0.1 (Olcare)'
);

-- line #30773
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECON NASAL 0.1 (Cadila Ph.)',
	'Xylometazoline Hcl.',
	'DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECON NASAL 0.1 (Cadila Ph.)'
);

-- line #30774
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DECON-P NASAL 0.05 (Cadila Ph.)',
	'Xylometazoline Hcl.',
	'DPS',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DECON-P NASAL 0.05 (Cadila Ph.)'
);

-- line #30775
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DRYOXY NASAL 0.1 (Yash Vision)',
	'Xylometazoline Hcl.',
	'DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DRYOXY NASAL 0.1 (Yash Vision)'
);

-- line #30776
-- ignoring line: field [strength_1] not numeric: >>>0.05 W<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.05 W', u'strength_2': u'V', u'substance': u'Xylometazoline Hcl.', u'always_empty': u'', u'form': u'DPS', u'brand': u'GOAIR KID-N', u'strength_3': u'', u'company': u'Intra(INVISION)', u'unit': u'0.02'}

-- line #30777
-- ignoring line: field [strength_1] not numeric: >>>0.1 W<<<
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0.1 W', u'strength_2': u'V', u'substance': u'Xylometazoline Hcl.', u'always_empty': u'', u'form': u'DPS', u'brand': u'GOAIR-N', u'strength_3': u'', u'company': u'Intra(INVISION)', u'unit': u'0.02'}

-- line #30778
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRIPFREE NASAL 0.05 (Om Bio.)',
	'Xylometazoline Hcl.',
	'DPS',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRIPFREE NASAL 0.05 (Om Bio.)'
);

-- line #30779
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'HYNASAL 0.1 (Dwd)',
	'Xylometazoline Hcl.',
	'XL DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'HYNASAL 0.1 (Dwd)'
);

-- line #30780
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'KEXIVIN NASAL 0.1 (Cadex Lab)',
	'Xylometazoline Hcl.',
	'DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'KEXIVIN NASAL 0.1 (Cadex Lab)'
);

-- line #30781
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAM COLD NASAL 0.1 (Lincoln)',
	'Xylometazoline Hcl.',
	'DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAM COLD NASAL 0.1 (Lincoln)'
);

-- line #30782
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NASCON 0.1 (DIVINE LAB.)',
	'Xylometazoline Hcl.',
	'NASAL DROPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NASCON 0.1 (DIVINE LAB.)'
);

-- line #30783
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NASCON-P 0.05 (DIVINE LAB.)',
	'Xylometazoline Hcl.',
	'NASAL DROPS',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NASCON-P 0.05 (DIVINE LAB.)'
);

-- line #30784
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'Xylometazoline Hcl.', u'always_empty': u'', u'form': u'DROPS', u'brand': u'NASOCA', u'strength_3': u'', u'company': u'NIVCA', u'unit': u''}

-- line #30785
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NASOMET 0.1 (Sun)',
	'Xylometazoline Hcl.',
	'DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NASOMET 0.1 (Sun)'
);

-- line #30786
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAZALIN 0.1 (Bell Ph.)',
	'Xylometazoline Hcl.',
	'DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAZALIN 0.1 (Bell Ph.)'
);

-- line #30787
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NAZALIN PAED 0.05 (Bell Ph.)',
	'Xylometazoline Hcl.',
	'DPS',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NAZALIN PAED 0.05 (Bell Ph.)'
);

-- line #30788
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Xylometazoline Hcl.', u'always_empty': u'', u'form': u'DPS', u'brand': u'NAZIVIN', u'strength_3': u'', u'company': u'Eg Ph.', u'unit': u''}

-- line #30789
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'N.I.', u'strength_2': u'', u'substance': u'Xylometazoline Hcl.', u'always_empty': u'', u'form': u'DPS', u'brand': u'NESOPAB NASAL', u'strength_3': u'', u'company': u'Finesse Ph.', u'unit': u''}

-- line #30790
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOBLOK 0.1 (LIFESTAR)',
	'Xylometazoline Hcl.',
	'DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOBLOK 0.1 (LIFESTAR)'
);

-- line #30791
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOMOCON 0.1 (Cadila Ph.)',
	'Xylometazoline Hcl.',
	'DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'% W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOMOCON 0.1 (Cadila Ph.)'
);

-- line #30792
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOSIKIND 0.1 (Mankind)',
	'Xylometazoline Hcl.',
	'DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOSIKIND 0.1 (Mankind)'
);

-- line #30793
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOSIKIND 0.5 (Mankind)',
	'Xylometazoline Hcl.',
	'DPS',
	gm.nullify_empty_string('0.5')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOSIKIND 0.5 (Mankind)'
);

-- line #30794
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOSIKIND-P 0.055 (Mankind)',
	'Xylometazoline Hcl.',
	'SOL',
	gm.nullify_empty_string('0.055')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOSIKIND-P 0.055 (Mankind)'
);

-- line #30795
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOZEL 0.1 (GH PH.)',
	'Xylometazoline Hcl.',
	'SPRAY',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOZEL 0.1 (GH PH.)'
);

-- line #30796
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOZIN KID NASAL 0.05 (Intra Lab)',
	'Xylometazoline Hcl.',
	'DPS',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOZIN KID NASAL 0.05 (Intra Lab)'
);

-- line #30797
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOZIN NASAL 0.1 (Intra Lab)',
	'Xylometazoline Hcl.',
	'DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOZIN NASAL 0.1 (Intra Lab)'
);

-- line #30798
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOZOLIN NASAL 0.05 (Pfiscar Ind.)',
	'Xylometazoline Hcl.',
	'DPS',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOZOLIN NASAL 0.05 (Pfiscar Ind.)'
);

-- line #30799
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOZOLIN O1 NASAL 0.1 (Pfiscar Ind.)',
	'Xylometazoline Hcl.',
	'DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOZOLIN O1 NASAL 0.1 (Pfiscar Ind.)'
);

-- line #30800
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NOZY NASAL 0.1 (Ind-Swift)',
	'Xylometazoline Hcl.',
	'DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'% W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NOZY NASAL 0.1 (Ind-Swift)'
);

-- line #30801
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORINASE MICROMIST 0.1 (Entod Ph.)',
	'Xylometazoline Hcl.',
	'SPRAY',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORINASE MICROMIST 0.1 (Entod Ph.)'
);

-- line #30802
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ORTINASE-N 0.1 (Osper)',
	'Xylometazoline Hcl.',
	'DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'% W/V/10ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ORTINASE-N 0.1 (Osper)'
);

-- line #30803
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OTRINOZ BABY 0.025 (Novartis)',
	'Xylometazoline Hcl.',
	'DPS',
	gm.nullify_empty_string('0.025')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OTRINOZ BABY 0.025 (Novartis)'
);

-- line #30804
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OTRINOZ-N 0.1 (Novartis)',
	'Xylometazoline Hcl.',
	'DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OTRINOZ-N 0.1 (Novartis)'
);

-- line #30805
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OTRINOZ PAED 0.05 (Novartis)',
	'Xylometazoline Hcl.',
	'DPS',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OTRINOZ PAED 0.05 (Novartis)'
);

-- line #30806
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OTRIVIN ADULT-N 0.1 (Novartis)',
	'Xylometazoline Hcl.',
	'SPRAY/DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OTRIVIN ADULT-N 0.1 (Novartis)'
);

-- line #30807
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'0,025', u'strength_2': u'', u'substance': u'Xylometazoline Hcl.', u'always_empty': u'', u'form': u'', u'brand': u'OTRIVIN MINI', u'strength_3': u'', u'company': u'Novartis', u'unit': u'%'}

-- line #30808
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OTRIVIN NASAL 0.1 (Novartis)',
	'Xylometazoline Hcl.',
	'DPS',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OTRIVIN NASAL 0.1 (Novartis)'
);

-- line #30809
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'OTRIVIN PAED 0.05 (Novartis)',
	'Xylometazoline Hcl.',
	'DPS',
	gm.nullify_empty_string('0.05')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'OTRIVIN PAED 0.05 (Novartis)'
);

-- line #30810
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RECOFAST 0.05 (Shreya)',
	'Xylometazoline Hcl.',
	'DPS',
	gm.nullify_empty_string('0.05')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RECOFAST 0.05 (Shreya)'
);

-- line #30811
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RECOFAST 0.1 (Shreya)',
	'Xylometazoline Hcl.',
	'SPRAY',
	gm.nullify_empty_string('0.1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RECOFAST 0.1 (Shreya)'
);

-- line #30812
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RINOSTAT 0.1 (Rpg Life)',
	'Xylometazoline Hcl.',
	'XL',
	gm.nullify_empty_string('0.1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RINOSTAT 0.1 (Rpg Life)'
);

-- line #30813
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BARACLUDE 0.5 (BRISTOL MYERS)',
	'Zidovudine',
	'TAB',
	gm.nullify_empty_string('0.5')::numeric,
	'1'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BARACLUDE 0.5 (BRISTOL MYERS)'
);

-- line #30814
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RETROVIR 100 (Gsk)',
	'Zidovudine',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RETROVIR 100 (Gsk)'
);

-- line #30815
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'RETROVIR 300 (Gsk)',
	'Zidovudine',
	'TAB',
	gm.nullify_empty_string('300')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'RETROVIR 300 (Gsk)'
);

-- line #30816
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GRILUTO 600 (German R.)',
	'ZILEUTIN',
	'CR TAB',
	gm.nullify_empty_string('600')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GRILUTO 600 (German R.)'
);

-- line #30817
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMZINC 20 (EMCURE)',
	'ZINC ACETATE',
	'SYR',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMZINC 20 (EMCURE)'
);

-- line #30818
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EMZINC 20 (Emcure)',
	'ZINC ACETATE',
	'TAB',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EMZINC 20 (Emcure)'
);

-- line #30819
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'MINTONIA 20 (Serum Int.)',
	'ZINC ACETATE',
	'SYR',
	gm.nullify_empty_string('20')::numeric,
	'mg/5ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'MINTONIA 20 (Serum Int.)'
);

-- line #30820
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ALPHADINE 1 (Nicholas)',
	'Zinc Chl.',
	'MOUTH WASH',
	gm.nullify_empty_string('1')::numeric,
	'%W/V'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ALPHADINE 1 (Nicholas)'
);

-- line #30821
-- ignoring line: empty field [form]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'10', u'strength_2': u'', u'substance': u'Zinc Oxide', u'always_empty': u'', u'form': u'', u'brand': u'BANRAY KIDZ', u'strength_3': u'', u'company': u'Ajanta Ph.', u'unit': u'%(MICRONISED)W/W'}

-- line #30822
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BELLE 1 (Bell Ph.)',
	'Zinc Oxide',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BELLE 1 (Bell Ph.)'
);

-- line #30823
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DERMASEAL 1 (Organic Lab)',
	'Zinc Oxide',
	'CRM',
	gm.nullify_empty_string('1')::numeric,
	'%'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DERMASEAL 1 (Organic Lab)'
);

-- line #30824
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'ASCAZIN 140 (Apex Labs.)',
	'Zinc Sulph.',
	'CAP',
	gm.nullify_empty_string('140')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'ASCAZIN 140 (Apex Labs.)'
);

-- line #30825
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'ZINC GLUCONATE EQ. TO ZINC', u'strength_2': u'', u'substance': u'Zinc Sulph.', u'always_empty': u'', u'form': u'SYR', u'brand': u'PEDIZINC', u'strength_3': u'', u'company': u'Votary Lab', u'unit': u''}

-- line #30826
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PROZINK 200 (Tripada BIO.)',
	'Zinc Sulph.',
	'TAB',
	gm.nullify_empty_string('200')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PROZINK 200 (Tripada BIO.)'
);

-- line #30827
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZONA 20 (Torrent)',
	'ZIPRASIDONE',
	'CAP',
	gm.nullify_empty_string('20')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZONA 20 (Torrent)'
);

-- line #30828
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZONA 40 (Torrent)',
	'ZIPRASIDONE',
	'CAP',
	gm.nullify_empty_string('40')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZONA 40 (Torrent)'
);

-- line #30829
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AZONA 80 (Torrent)',
	'ZIPRASIDONE',
	'CAP',
	gm.nullify_empty_string('80')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AZONA 80 (Torrent)'
);

-- line #30830
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLASTOZEN 4 (SUPER SPE.)',
	'ZOLEDRONIC ACID',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLASTOZEN 4 (SUPER SPE.)'
);

-- line #30831
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'BLAZTERE 4 (Dr.Reddy''S)',
	'ZOLEDRONIC ACID',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'BLAZTERE 4 (Dr.Reddy''S)'
);

-- line #30832
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DRONICAD 4 (Cadila Ph.)',
	'ZOLEDRONIC ACID',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DRONICAD 4 (Cadila Ph.)'
);

-- line #30833
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LEDRONZOL 4 (Cytomed(Alkem))',
	'ZOLEDRONIC ACID',
	'INJ',
	gm.nullify_empty_string('4')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LEDRONZOL 4 (Cytomed(Alkem))'
);

-- line #30834
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NATZOLD 5 (Natco Ph.)',
	'ZOLEDRONIC ACID',
	'INF',
	gm.nullify_empty_string('5')::numeric,
	'mg/10ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NATZOLD 5 (Natco Ph.)'
);

-- line #30835
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMBIZ 10 (Neu-Foreva)',
	'Zolpidem',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMBIZ 10 (Neu-Foreva)'
);

-- line #30836
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMBULAX-Z 10 (Unimarck)',
	'Zolpidem',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMBULAX-Z 10 (Unimarck)'
);

-- line #30837
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'AMBULAX-Z 5 (Unimarck)',
	'Zolpidem',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'AMBULAX-Z 5 (Unimarck)'
);

-- line #30838
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DACTIVE 12.5 (Zydus N.S.)',
	'Zolpidem',
	'SR TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DACTIVE 12.5 (Zydus N.S.)'
);

-- line #30839
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DACTIVE 6.25 (Zydus N.S.)',
	'Zolpidem',
	'SR TAB',
	gm.nullify_empty_string('6.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DACTIVE 6.25 (Zydus N.S.)'
);

-- line #30840
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DACTIVE 10 (Zydus N.S.)',
	'Zolpidem',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DACTIVE 10 (Zydus N.S.)'
);

-- line #30841
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DACTIVE 5 (Zydus N.S.)',
	'Zolpidem',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DACTIVE 5 (Zydus N.S.)'
);

-- line #30842
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEM 5 (Mano)',
	'Zolpidem',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEM 5 (Mano)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'DEM 10 (Mano)',
	'Zolpidem',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'DEM 10 (Mano)'
);

-- line #30843
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GOODNOCT 12.5 (Lupin)',
	'Zolpidem',
	'XR TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GOODNOCT 12.5 (Lupin)'
);

-- line #30844
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'GOODNOCT 6.25 (Lupin)',
	'Zolpidem',
	'XR TAB',
	gm.nullify_empty_string('6.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'GOODNOCT 6.25 (Lupin)'
);

-- line #30845
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INSONIA 10 (Unimarck)',
	'Zolpidem',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INSONIA 10 (Unimarck)'
);

-- line #30846
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'INSONIA 5 (Unimarck)',
	'Zolpidem',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'INSONIA 5 (Unimarck)'
);

-- line #30847
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIDRA 10 (Jagsonpal)',
	'Zolpidem',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIDRA 10 (Jagsonpal)'
);

-- line #30848
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NIDRA 5 (Jagsonpal)',
	'Zolpidem',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NIDRA 5 (Jagsonpal)'
);

-- line #30849
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITEST 12.5 (SUN)',
	'Zolpidem',
	'CR TAB',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITEST 12.5 (SUN)'
);

-- line #30850
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITEST 6.25 (SUN)',
	'Zolpidem',
	'CR TAB',
	gm.nullify_empty_string('6.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITEST 6.25 (SUN)'
);

-- line #30851
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITREST 12.5 (Sun)',
	'Zolpidem',
	'CR',
	gm.nullify_empty_string('12.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITREST 12.5 (Sun)'
);

-- line #30852
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITREST 6.25 (Sun)',
	'Zolpidem',
	'CR',
	gm.nullify_empty_string('6.25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITREST 6.25 (Sun)'
);

-- line #30853
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITREST 10 (Sun)',
	'Zolpidem',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITREST 10 (Sun)'
);

-- line #30854
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'NITREST 5 (Sun)',
	'Zolpidem',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'NITREST 5 (Sun)'
);

-- line #30855
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEDO 5 (Dexter Lab)',
	'Zolpidem',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEDO 5 (Dexter Lab)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'PEDO 10 (Dexter Lab)',
	'Zolpidem',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'PEDO 10 (Dexter Lab)'
);

-- line #30856
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REFRESH 5 (Theo Ph.)',
	'Zolpidem',
	'TAB',
	gm.nullify_empty_string('5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REFRESH 5 (Theo Ph.)'
);

INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'REFRESH 10 (Theo Ph.)',
	'Zolpidem',
	'TAB',
	gm.nullify_empty_string('10')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'REFRESH 10 (Theo Ph.)'
);

-- line #30857
-- ignoring line: empty field [unit]
-- {u'list_of_values_of_unknown_fields': [u'', u'', u'', u'', u'', u'', u'', u'', u''], u'strength_1': u'-', u'strength_2': u'', u'substance': u'ZONISAMIDE', u'always_empty': u'', u'form': u'CAP', u'brand': u'CAESAR', u'strength_3': u'', u'company': u'Emcure', u'unit': u''}

-- line #30858
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPIGRAN 100 (ZYDUS N.S.)',
	'ZONISAMIDE',
	'CAP',
	gm.nullify_empty_string('100')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPIGRAN 100 (ZYDUS N.S.)'
);

-- line #30859
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPIGRAN 25 (ZYDUS N.S.)',
	'ZONISAMIDE',
	'CAP',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPIGRAN 25 (ZYDUS N.S.)'
);

-- line #30860
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'EPIGRAN 50 (ZYDUS N.S.)',
	'ZONISAMIDE',
	'CAP',
	gm.nullify_empty_string('50')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'EPIGRAN 50 (ZYDUS N.S.)'
);

-- line #30861
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'LYZOP 7.5 (HETERO HC.)',
	'Zopiclone',
	'TAB',
	gm.nullify_empty_string('7.5')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'LYZOP 7.5 (HETERO HC.)'
);

-- line #30862
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOPIXOL ACUPHASE 100 (Lundbeck)',
	'Zuclopenthixol Acetate',
	'INJ',
	gm.nullify_empty_string('100')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOPIXOL ACUPHASE 100 (Lundbeck)'
);

-- line #30863
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOPIXOL ACUPHASE 50 (Lundbeck)',
	'Zuclopenthixol Acetate',
	'INJ',
	gm.nullify_empty_string('50')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOPIXOL ACUPHASE 50 (Lundbeck)'
);

-- line #30864
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOPIXOL DEPOT 200 (Lundbeck)',
	'Zuclopenthixol',
	'INJ',
	gm.nullify_empty_string('200')::numeric,
	'mg/ML'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOPIXOL DEPOT 200 (Lundbeck)'
);

-- line #30865
INSERT INTO staging.india_drugs (brand_name, substance, form, strength, unit) SELECT
	'CLOPIXOL 25 (Lundbeck)',
	'Zuclopenthixol Decanoate',
	'TAB',
	gm.nullify_empty_string('25')::numeric,
	'mg'
WHERE NOT EXISTS (
	SELECT 1 FROM staging.india_drugs WHERE brand_name = 'CLOPIXOL 25 (Lundbeck)'
);

-- ---------------------------------------------------------
-- transfer data to real tables

-- substances
INSERT INTO ref.consumable_substance (description, amount, unit) SELECT
	DISTINCT ON (s_id.substance, s_id.strength, s_id.unit)
	s_id.substance, s_id.strength, s_id.unit
FROM 
	staging.india_drugs s_id
WHERE
	s_id.strength IS NOT NULL
		AND
	NOT EXISTS (
		SELECT 1 FROM ref.consumable_substance r_cs WHERE
			r_cs.description = s_id.substance
				AND
			r_cs.amount = s_id.strength
				AND
			r_cs.unit = s_id.unit
	)
;

-- brands
INSERT INTO ref.branded_drug (description, preparation) SELECT
	s_id.brand_name, s_id.form
FROM
	staging.india_drugs s_id
WHERE NOT EXISTS (
	SELECT 1 FROM ref.branded_drug r_bd WHERE
		r_bd.description = s_id.brand_name
			AND
		r_bd.preparation = s_id.form
);

-- link components
INSERT INTO ref.lnk_substance2brand (fk_brand, fk_substance) SELECT
	(SELECT pk FROM ref.branded_drug r_bd
	 WHERE
		r_bd.description = s_id.brand_name
			AND
		r_bd.preparation = s_id.form
	),
	(SELECT pk FROM ref.consumable_substance r_cs WHERE
		r_cs.description = s_id.substance
			AND
		r_cs.amount = s_id.strength
			AND
		r_cs.unit = s_id.unit
	)
FROM
	staging.india_drugs s_id
WHERE NOT EXISTS (
	SELECT 1 FROM ref.lnk_substance2brand WHERE
		fk_brand = (
			SELECT pk FROM ref.branded_drug WHERE
				description = s_id.brand_name
					AND
				preparation = s_id.form
		)
			AND
		fk_substance = (
			SELECT pk FROM ref.consumable_substance r_cs WHERE
				r_cs.description = s_id.substance
					AND
				r_cs.amount = s_id.strength
					AND
				r_cs.unit = s_id.unit
		)
);

-- ---------------------------------------------------------
-- drop staging tables again, if needed --
\unset ON_ERROR_STOP
DROP TABLE staging.india_drugs CASCADE;
\set ON_ERROR_STOP 1

-- ---------------------------------------------------------

-- finalize transaction --
-- uncomment this once you are satisfied your script works:
COMMIT;
-- ---------------------------------------------------------

